(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    499466,       8379]
NotebookOptionsPosition[    498800,       8350]
NotebookOutlinePosition[    499332,       8373]
CellTagsIndexPosition[    499245,       8368]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
 RowBox[{
  RowBox[{"?", "EyeModel"}], "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.510970707273507*^9, 3.510970711931445*^9}}],

Cell[BoxData[
 StyleBox["\<\"EyeModel[dx_, dy_, defocusangle_, scatter_, pupilsize_, \
opts___] creates an optical model of a standard human eye.\\n \\nEyeModel is \
based on the work of Navarro (See the OSA paper: Off-axis aberrations of an \
wide-angle schematic eye model by Isabel Escudero-Sanz and Rafael Navarro) \
and uses a spherical retinal surface as well as thin-lens defocusing element \
that is governed by the input defocus parameters: dx and dy (given in units \
of diopters). The defocusangle determines the angle of rotation (degrees) \
about the pupil center for the defocus effects. The scatter parameter is used \
to specify the amount of diffuseness of the retina (See \
SphericalDiffuserMirror). The pupilsize parameter determines the diameter of \
the pupil opening. In general, EyeModel is created with spatial units of \
millimeters.\\n \\nThe Resonate -> False option offers the fastest ray-trace \
model and generates a list of optical surfaces that assumes a sequential \
light path that begins with the outer cornea surface and then progresses \
through to the retina before reflecting and reverse tracing sequentially back \
out the cornea. Otherwise, Resonate -> True can be used to model arbitrary \
paths through the eye with multiple bounces.\\n \\nThe Reflectance and \
Transmittance options control the optical behavior of the retina. By default, \
the retina is modelled as a diffusely reflective surface. With Reflectance -> \
0, the retina is instead modelled as screen that allows the rays to pass \
through. With Transmittance -> 0, the retina is otherwise modelled as an \
opaque surface that absorbs the rays.\\n \\nYou can use the Source option to \
insert light sources within the eye. In particular, EyeModel changes the \
starting refractive index value of the specified light source according to \
its starting position within the eye model structure.\\n \\nSee also: \
CorneaData, PupilData, LensData, RetinaData, CorneaMedium, AqueousMedium, \
LensMedium, and VitreousMedium.\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.5110515684444838`*^9},
 CellTags->"Info3511033568-5293371"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ManipulateSystem", "[", 
  RowBox[{
   RowBox[{"{", "\n", "\t", 
    RowBox[{
     RowBox[{"Move", "[", 
      RowBox[{
       RowBox[{"LineOfRays", "[", 
        RowBox[{"3", ",", 
         RowBox[{"NumberOfRays", "\[Rule]", "5"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"x", ",", 
           RowBox[{"-", "5"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"y", ",", "0"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"th", ",", "0"}], "}"}]}], "]"}], ",", "\n", "\t", 
     RowBox[{"EyeModel", "[", 
      RowBox[{"0", ",", "0", ",", "30", ",", "5", ",", 
       RowBox[{"PupilData", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"10", ",", ".05"}], "}"}]}], ",", 
       RowBox[{"Resonate", "\[Rule]", "False"}], ",", 
       RowBox[{"Transmittance", "\[Rule]", "0"}], ",", 
       RowBox[{"CrossRendering", "\[Rule]", "Trace"}]}], "]"}]}], "}"}], ",", 
   "\n", "\t", 
   RowBox[{"DynamicFrame", "[", 
    RowBox[{
     RowBox[{"PlotType", "->", "TopView"}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<Eye Model\>\""}]}], "]"}], ",", 
   RowBox[{"Deployed", "\[Rule]", "False"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.510970478986664*^9, 3.510970480335705*^9}, {
  3.510970611651248*^9, 3.510970637730556*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`lastlocposth$$ = {-4.0058676564455595`, 
    0.}, $CellContext`laststartposth$$ = {-5., 0.}, $CellContext`lastth$$ = 
    0, $CellContext`maxth$$ = 
    180., $CellContext`maxx$$ = -0.05, $CellContext`maxy$$ = 
    10, $CellContext`minth$$ = -180., $CellContext`minx$$ = -10, \
$CellContext`miny$$ = -10, $CellContext`radiusth$$ = 
    0.9941323435544405, \
$CellContext`staticpolygons1183869201251111755406940$$ = {
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[CompressedData["
1:eJyFmntwj1cax19JRCJBIheXpi5RSdbWpXLpopxHd9wvI7TYYq1bp2vdVjtL
U9av7uuyli7N1pa1LG2pVdUO2vGeZtRiltpixU5WQzPYimxExC1if37vOTr5
vDOb30z++M7znnOe8zyf5/v7vUPbiTOHTwl3HCcq+Dci+BcW/Dta+MYv15SV
uE7o00IXryvbtX7Pfz2tm+mTufHZyYcqPR1I1i1HPZXfOueupyVJnzydH19/
0AOzPlFnDO3zxI6FjvbWN9VHxyxcfTs7zNOBeJ0ze0VVbkG4pyVOT3577JgW
Hep72mmsa/584+SQmZHm+Rg958fj8za91cDEo3XGhrWD5+RHmXik3jm+9YKY
BdEmHqGTci664/o3NPF6+ux3D37X95bRTo177+qP+r2+NMbou27epBduLKu2
utLtMeb8Ty+PijW6zJ02zJ1emm91iTsgbfJn51yrz7h/D32sdhzEFdYr7K9w
vkJ+Cvkr3E9wf0F9BPUT1FdQf0F/BP0T9FfQfwEfAn4EfAn482k+z/185yEf
5sv78L6sB+vFerLe7Af7xX6y3+SBvJAn8lYHjz6eyTvngfPCeeK8cR45r5xn
zjv9gH5BP6Hf0I98fgU/o9/RD33+2CIucvmblx/v/15a3KKa9Wa9k6BfSW/V
9VDhTaOb6tI97QfJ/NtGx+vyiuWtf3vkntFx+s7yuR16uTbfxnrxR6cbFjxr
7uPE6nuXbrUum1HP6Ib6eGq7+YeWmfs7UbrqxPr7uYtNfZxI/XLoE/G4/h9E
JrSd1tnWM0zndfzVO78vttrRm1rsaPbvPFN/p9qNffKJouSHVt9xZxw8MP76
dNuvSjesdG3stb9ZXe4ej045P6+R6a9z1e20cu+9yl5WF7tpVTH/WjXW6lOu
l5/VjoO4wnqF/RXOV8hPIX+F+yncX1AfQf0E9RXUX9AfQf8E/RX0X8CHgB8B
XwL+fJrPcz+ex3yYL+/D+7IerBfryXqzH+wX+8l+kwfyQp7IWx08+ngm75wH
zgvnifPGeeS8cp457/QD+gX9hH5DP6Jf0c/od/RD6nf+8Ojzvmvzr63DocOg
60E70DVubV0NfQ/6DnQVdCV0BXQ5dCn0VegS6GLoQuhT0BracRBXWA9dCF0M
XQJ9FboUuhy6AroSugr6DvQ96GroGmhHwAd0GHQ4dEQdms9zP57HfJgv78P7
sh6sF+vJerMf7Bf7yX6TB/JCnsibj8c6eCbvnAfOC+eJ88Z55Lxynjnv9AP6
Bf2EfkM/ol/Rz+h39ENq+KdOqK0D0ALtQAd/H9deDy3QDrSOx3pogXagdRzW
Qwu0w+ebIA4daIw4dKAR4tCBWMShg+8ntePQgYaIQweiEYcORCEOHWiAOHQg
EnHoQH3EoQN18RhRx/Pcj+cxH+bL+/C+rAfrxXqy3uwH+8V+st/kgbyQJ/JG
HskreSbvdcwL54nzxnnkvHKeOe/0A/oF/YR+Qz+iX9HP6He+35O+35e1v48D
/H6vjzh08H0FfCLeAHHo4PsP+EQ8GnHo4PsU+EQ8BnHo4PsZ+ES8EeLQwfc9
8Il4E8Shg++P4BPPQ2vo4Pso+MR6aA0dfL8Fn1gPraGD78vgE+uhNXTw/fv/
aj7P/Xge82G+vA/vy3qwXqwn681+sF/sJ/tNHny8kCfyRh7JK3km75wHzgvn
ifPGeeS8cp457/QD+gX9hH5DP6Jf0c/qer+JkCEqNWnqlVvmd3yy3lLdcdeB
6pvqQKsl13LnJukDVzI71k+tUOe2zurZcFSizlh5e2Pv0eWqKmPsmoLsBP1x
0YmcIrmuknb3u5iX2FTv6HHwQfvb/1FZmcHPzTgdsWJf9JtnL6ttweXntjbR
5Sf2Tmx54Vt1KS9xd78JjfTo1D4L0hMuqtbB4/a3itGvdS/PL7hepIK738oo
itLlZ7rtrk627yGROu6lKz1Gbz9t8onQnboPXNRKvlKJofPDdOn72T1fjDtq
znvoZi2/lHrp8BeqVWj/+27Rk+mvjjq2X+WH9qtyh3eMndDz3F/N+gq3d8wF
Ca/aotqEnr/m/mPcqqx/1qxRcaH4JXfIqoUfTI+YZfTXpo7ff6aaeBsvrq6b
9c299Qr7q5+Z8714hSox+f3Ry089a/L3nr+vcD+VY+6f7N1fmpr6FHr1kVum
ft5+kYL6yk9M/b39Y+Sm6U+J1x9B/wT9lU9N/73zmwr4kM8MP14+ibLV8HXQ
44v8+TR4FPDoOw88+vLlfcCjgEdfvcCjgEcBj8J+gUcFHhV49PECHhV4VHXw
6IJHH+/g0QWPLnh0OW/gUYNHDR598w4eNXj0+Qn9Bjz6/Ao8avCo6YfUXTZU
Tzw283sdmNX8mw4b7j72y8HfRWTFL33w2C+P1LvY5dBmR+z57S6kZ+VMCBPr
l88FbzGrQYTY/BOXli2Yvq6+2Pttz51x9OmwBmL9snLayPm7R0aJ9cuH57Zv
qlgTLbZ+R9aNf/ruh/Z7KlIPfDeQVrAnRqxf/uZ29Ooh+bFi/XLJlvvjN05u
JLZ/PTe+uHlnUmOxfrm3pNmgX+9sLNYvL81/flJCWhOxfvnVy2evTF3SRCw/
r28+Vbj4WBOxfhm6boXVXz/+HWD5tHHrl3PNeuuX2F/Z861ffmTys35p87d+
ifup5eb+1i8HmPpYv/zS1M/6Jeortv7WL7eZ/li/RP8E/ZVU03/rl+BD+ht+
rF/OM3xZvwR/Pg0eBTz6zgOPvnx5H/Ao4NFXL/Ao4FHAo7Bf4FGBRwUefbyA
RwUeVR08uuDRxzt4dMGjCx5dzht41OBRg0ffvINHDR59fkK/AY8+vwKPGjz6
/JB6w+y/XO57JtX7d7/L6bp6+MSk61MzvH7tS9MN580P+8GAH0rwNmPXLGyv
v5m6ZeOUX3SUULrDntJzJw5JWdm+s+l/O/1Gx4hFhwd3kdB/ayhtq18adibt
7dIu8ui6Fw+20YXO+Xob5zwjwYeXXItvrT/pMWz1yBvPyIePrrc7RZ8MP76/
19iuEv0IwIEtdVlO+VspB7vKlFB+zXT3whUL+8ZmyhehfJJ0713jthWMyDTn
J+glP1/x7ti1mea8OH166LTyj7/MlF2h/WP1yOxPP+9zI1Mmh/ZroCdFpC16
NTFLUkLrw/Wf5nW7vKxzlrwXer7abdsuu97B57OkeSh+0207ovKTzkOzJC6k
v3V3XO3f6WFuluGz+Dkb7+LFlV2f4a1Xdv/93v7Knu/xES42v1e8/MTmv8fL
Xxab+83z7idi7u+tT5Bupj6HvfqIrZ+3XzOx9Y316iv7TP29/VPE9ucFrz9i
++ed10byTH9Pev2V10z/vfPbSZHhY7bHh0Qafrx82kuV4SvZ40sChj8vv3QB
jwIeBTwKeBTwKOBRwKOARwGPAh4FPAp4FPAo4FHAo4BHAY8CHhV4VOBRgcfP
waMLHl3w6IJHDR41eNTgUYNHDR41eNTgUYNHDR41eNTgUYNHDR41eNTgUYNH
nz/+D+GN6rw=
      "]]}, $CellContext`th$$ = 
    0, $CellContext`x$$ = -5., $CellContext`xoffth$$ = 
    0.9941323435544405, $CellContext`xth$$ = -4.0058676564455595`, \
$CellContext`y$$ = 0., $CellContext`yoffth$$ = 0., $CellContext`yth$$ = 0., 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`th$$], 0.}, -180., 180.}, {{
       Hold[$CellContext`x$$], -5.}, -10, -0.05}, {{
       Hold[$CellContext`y$$], 0.}, -10, 10}, {{
       Hold[$CellContext`minth$$], -180.}}, {{
       Hold[$CellContext`maxth$$], 180.}}, {{
       Hold[$CellContext`minx$$], -10}}, {{
       Hold[$CellContext`maxx$$], -0.05}}, {{
       Hold[$CellContext`miny$$], -10}}, {{
       Hold[$CellContext`maxy$$], 10}}, {
      Hold[
       Button[
       "Report", 
        Optica`Optica`$OpticalSystemSettings = {
          Optica`Optica`SymbolicValues -> 
           MapThread[
            ToExpression[#] -> #2& , {{
              "th", "x", 
               "y"}, {$CellContext`th$$, $CellContext`x$$, \
$CellContext`y$$}}], 
           Optica`Optica`SymbolicRanges -> {$CellContext`th$$ -> {-180., 
              180.}, $CellContext`x$$ -> {-10, -0.05}, $CellContext`y$$ -> \
{-10, 10}}}; 
        Optica`Optica`$OpticalSystemScript = 
         "{Move[LineOfRays[3, NumberOfRays -> 5], {{x, -5.}, {y, 0}}, {th, \
0.}, SymbolicValues -> {th -> 0, x -> -5, y -> 0}], EyeModel[0, 0, 0, 30, 5, \
{PupilData -> {10, 0.05}, Resonate -> False, Transmittance -> 0, \
CrossRendering -> Trace}]}"; Print[
          InputForm[
           StringJoin["SymbolicValues -> ", 
            ToString[
             MapThread[StringJoin[#, "->", 
               ToString[#2, InputForm]]& , {{
               "th", "x", 
                "y"}, {$CellContext`th$$, $CellContext`x$$, \
$CellContext`y$$}}]]]]], ImageSize -> Automatic]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`xth$$], -4.4019925}}, {{
       Hold[$CellContext`yth$$], 0.}}, {{
       Hold[$CellContext`radiusth$$], 0.5980074999999999}}, {{
       Hold[$CellContext`xoffth$$], 0.5980074999999999}}, {{
       Hold[$CellContext`yoffth$$], 0.}}, {{
       Hold[$CellContext`laststartposth$$], {-5., 0.}}}, {{
       Hold[$CellContext`lastlocposth$$], {-4.4019925, 0.}}}, {{
       Hold[$CellContext`lastth$$], 0}}, {{
       Hold[$CellContext`staticpolygons1183869201251111755406940$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[CompressedData["
1:eJyFmntwj1cax19JRCJBIheXpi5RSdbWpXLpopxHd9wvI7TYYq1bp2vdVjtL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         "]]}}}}, Typeset`size$$ = {
    815., {399.84375, 405.15625}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = False, $CellContext`th$9491$$ = 
    0, $CellContext`x$9496$$ = 0, $CellContext`y$9497$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`lastlocposth$$ = {-4.4019925, 
         0.}, $CellContext`laststartposth$$ = {-5., 
         0.}, $CellContext`lastth$$ = 0, $CellContext`maxth$$ = 
        180., $CellContext`maxx$$ = -0.05, $CellContext`maxy$$ = 
        10, $CellContext`minth$$ = -180., $CellContext`minx$$ = -10, \
$CellContext`miny$$ = -10, $CellContext`radiusth$$ = 
        0.5980074999999999, \
$CellContext`staticpolygons1183869201251111755406940$$ = {
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[CompressedData["
1:eJyFmntwj1cax19JRCJBIheXpi5RSdbWpXLpopxHd9wvI7TYYq1bp2vdVjtL
U9av7uuyli7N1pa1LG2pVdUO2vGeZtRiltpixU5WQzPYimxExC1if37vOTr5
vDOb30z++M7znnOe8zyf5/v7vUPbiTOHTwl3HCcq+Dci+BcW/Dta+MYv15SV
uE7o00IXryvbtX7Pfz2tm+mTufHZyYcqPR1I1i1HPZXfOueupyVJnzydH19/
0AOzPlFnDO3zxI6FjvbWN9VHxyxcfTs7zNOBeJ0ze0VVbkG4pyVOT3577JgW
Hep72mmsa/584+SQmZHm+Rg958fj8za91cDEo3XGhrWD5+RHmXik3jm+9YKY
BdEmHqGTci664/o3NPF6+ux3D37X95bRTo177+qP+r2+NMbou27epBduLKu2
utLtMeb8Ty+PijW6zJ02zJ1emm91iTsgbfJn51yrz7h/D32sdhzEFdYr7K9w
vkJ+Cvkr3E9wf0F9BPUT1FdQf0F/BP0T9FfQfwEfAn4EfAn482k+z/185yEf
5sv78L6sB+vFerLe7Af7xX6y3+SBvJAn8lYHjz6eyTvngfPCeeK8cR45r5xn
zjv9gH5BP6Hf0I98fgU/o9/RD33+2CIucvmblx/v/15a3KKa9Wa9k6BfSW/V
9VDhTaOb6tI97QfJ/NtGx+vyiuWtf3vkntFx+s7yuR16uTbfxnrxR6cbFjxr
7uPE6nuXbrUum1HP6Ib6eGq7+YeWmfs7UbrqxPr7uYtNfZxI/XLoE/G4/h9E
JrSd1tnWM0zndfzVO78vttrRm1rsaPbvPFN/p9qNffKJouSHVt9xZxw8MP76
dNuvSjesdG3stb9ZXe4ej045P6+R6a9z1e20cu+9yl5WF7tpVTH/WjXW6lOu
l5/VjoO4wnqF/RXOV8hPIX+F+yncX1AfQf0E9RXUX9AfQf8E/RX0X8CHgB8B
XwL+fJrPcz+ex3yYL+/D+7IerBfryXqzH+wX+8l+kwfyQp7IWx08+ngm75wH
zgvnifPGeeS8cp457/QD+gX9hH5DP6Jf0c/od/RD6nf+8Ojzvmvzr63DocOg
60E70DVubV0NfQ/6DnQVdCV0BXQ5dCn0VegS6GLoQuhT0BracRBXWA9dCF0M
XQJ9FboUuhy6AroSugr6DvQ96GroGmhHwAd0GHQ4dEQdms9zP57HfJgv78P7
sh6sF+vJerMf7Bf7yX6TB/JCnsibj8c6eCbvnAfOC+eJ88Z55Lxynjnv9AP6
Bf2EfkM/ol/Rz+h39ENq+KdOqK0D0ALtQAd/H9deDy3QDrSOx3pogXagdRzW
Qwu0w+ebIA4daIw4dKAR4tCBWMShg+8ntePQgYaIQweiEYcORCEOHWiAOHQg
EnHoQH3EoQN18RhRx/Pcj+cxH+bL+/C+rAfrxXqy3uwH+8V+st/kgbyQJ/JG
HskreSbvdcwL54nzxnnkvHKeOe/0A/oF/YR+Qz+iX9HP6He+35O+35e1v48D
/H6vjzh08H0FfCLeAHHo4PsP+EQ8GnHo4PsU+EQ8BnHo4PsZ+ES8EeLQwfc9
8Il4E8Shg++P4BPPQ2vo4Pso+MR6aA0dfL8Fn1gPraGD78vgE+uhNXTw/fv/
aj7P/Xge82G+vA/vy3qwXqwn681+sF/sJ/tNHny8kCfyRh7JK3km75wHzgvn
ifPGeeS8cp457/QD+gX9hH5DP6Jf0c/qer+JkCEqNWnqlVvmd3yy3lLdcdeB
6pvqQKsl13LnJukDVzI71k+tUOe2zurZcFSizlh5e2Pv0eWqKmPsmoLsBP1x
0YmcIrmuknb3u5iX2FTv6HHwQfvb/1FZmcHPzTgdsWJf9JtnL6ttweXntjbR
5Sf2Tmx54Vt1KS9xd78JjfTo1D4L0hMuqtbB4/a3itGvdS/PL7hepIK738oo
itLlZ7rtrk627yGROu6lKz1Gbz9t8onQnboPXNRKvlKJofPDdOn72T1fjDtq
znvoZi2/lHrp8BeqVWj/+27Rk+mvjjq2X+WH9qtyh3eMndDz3F/N+gq3d8wF
Ca/aotqEnr/m/mPcqqx/1qxRcaH4JXfIqoUfTI+YZfTXpo7ff6aaeBsvrq6b
9c299Qr7q5+Z8714hSox+f3Ry089a/L3nr+vcD+VY+6f7N1fmpr6FHr1kVum
ft5+kYL6yk9M/b39Y+Sm6U+J1x9B/wT9lU9N/73zmwr4kM8MP14+ibLV8HXQ
44v8+TR4FPDoOw88+vLlfcCjgEdfvcCjgEcBj8J+gUcFHhV49PECHhV4VHXw
6IJHH+/g0QWPLnh0OW/gUYNHDR598w4eNXj0+Qn9Bjz6/Ao8avCo6YfUXTZU
Tzw283sdmNX8mw4b7j72y8HfRWTFL33w2C+P1LvY5dBmR+z57S6kZ+VMCBPr
l88FbzGrQYTY/BOXli2Yvq6+2Pttz51x9OmwBmL9snLayPm7R0aJ9cuH57Zv
qlgTLbZ+R9aNf/ruh/Z7KlIPfDeQVrAnRqxf/uZ29Ooh+bFi/XLJlvvjN05u
JLZ/PTe+uHlnUmOxfrm3pNmgX+9sLNYvL81/flJCWhOxfvnVy2evTF3SRCw/
r28+Vbj4WBOxfhm6boXVXz/+HWD5tHHrl3PNeuuX2F/Z861ffmTys35p87d+
ifup5eb+1i8HmPpYv/zS1M/6Jeortv7WL7eZ/li/RP8E/ZVU03/rl+BD+ht+
rF/OM3xZvwR/Pg0eBTz6zgOPvnx5H/Ao4NFXL/Ao4FHAo7Bf4FGBRwUefbyA
RwUeVR08uuDRxzt4dMGjCx5dzht41OBRg0ffvINHDR59fkK/AY8+vwKPGjz6
/JB6w+y/XO57JtX7d7/L6bp6+MSk61MzvH7tS9MN580P+8GAH0rwNmPXLGyv
v5m6ZeOUX3SUULrDntJzJw5JWdm+s+l/O/1Gx4hFhwd3kdB/ayhtq18adibt
7dIu8ui6Fw+20YXO+Xob5zwjwYeXXItvrT/pMWz1yBvPyIePrrc7RZ8MP76/
19iuEv0IwIEtdVlO+VspB7vKlFB+zXT3whUL+8ZmyhehfJJ0713jthWMyDTn
J+glP1/x7ti1mea8OH166LTyj7/MlF2h/WP1yOxPP+9zI1Mmh/ZroCdFpC16
NTFLUkLrw/Wf5nW7vKxzlrwXer7abdsuu97B57OkeSh+0207ovKTzkOzJC6k
v3V3XO3f6WFuluGz+Dkb7+LFlV2f4a1Xdv/93v7Knu/xES42v1e8/MTmv8fL
Xxab+83z7idi7u+tT5Bupj6HvfqIrZ+3XzOx9Y316iv7TP29/VPE9ucFrz9i
++ed10byTH9Pev2V10z/vfPbSZHhY7bHh0Qafrx82kuV4SvZ40sChj8vv3QB
jwIeBTwKeBTwKOBRwKOARwGPAh4FPAp4FPAo4FHAo4BHAY8CHhV4VOBRgcfP
waMLHl3w6IJHDR41eNTgUYNHDR41eNTgUYNHDR41eNTgUYNHDR41eNTgUYNH
nz/+D+GN6rw=
           "]]}, $CellContext`th$$ = 
        0., $CellContext`x$$ = -5., $CellContext`xoffth$$ = 
        0.5980074999999999, $CellContext`xth$$ = -4.4019925, $CellContext`y$$ = 
        0., $CellContext`yoffth$$ = 0., $CellContext`yth$$ = 0.}, 
      "ControllerVariables" :> {
        Hold[$CellContext`th$$, $CellContext`th$9491$$, 0], 
        Hold[$CellContext`x$$, $CellContext`x$9496$$, 0], 
        Hold[$CellContext`y$$, $CellContext`y$9497$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Column[{
         OpenerView[{"Eye Model", 
           Show[{
             Graphics[{{
                Opacity[
                0.8], $CellContext`staticpolygons1183869201251111755406940$$, 
                
                Opacity[1], 
                RGBColor[
                0.038747429704798886`, 0.9161617552424038, 
                 0.039847212269181365`], 
                AbsoluteThickness[Medium], 
                Line[
                 Dynamic[
                  Refresh[
                   Map[{
                    Part[#, {1, 2}], 
                    Part[#, {4, 5}]}& , 
                    Select[
                    $CellContext`raytracefunction183869201251111755413171[$\
CellContext`th$$, $CellContext`x$$, $CellContext`y$$], And[
                    Length[#] == 6, Part[#, 1] > -9.87654321*^8]& ]], 
                   TrackedSymbols :> {$CellContext`th$$, $CellContext`x$$, \
$CellContext`y$$}], SynchronousUpdating -> False]], 
                Arrowheads[Large], 
                Thickness[Large], 
                Dashing[{Small, Small}], 
                RGBColor[1, 1, 0], 
                Arrow[
                 Dynamic[If[
                    
                    Or[$CellContext`laststartposth$$ != {$CellContext`x$$, \
$CellContext`y$$}, $CellContext`lastth$$ =!= $CellContext`th$$], \
$CellContext`laststartposth$$ = {$CellContext`x$$, $CellContext`y$$}; \
$CellContext`lastth$$ = $CellContext`th$$; {$CellContext`xth$$, \
$CellContext`yth$$} = $CellContext`laststartposth$$ + $CellContext`radiusth$$ {
                    Cos[$CellContext`th$$ Degree], 
                    
                    Sin[$CellContext`th$$ 
                    Degree]}]; {$CellContext`laststartposth$$, \
{$CellContext`xth$$, $CellContext`yth$$}}, ({$CellContext`laststartposth$$, \
{$CellContext`xth$$, $CellContext`yth$$}} = #)& ]], 
                Tooltip[
                 Locator[
                  Dynamic[BesselJ[1., 3.]; (If[
                    
                    Or[{$CellContext`xth$$, $CellContext`yth$$} != \
$CellContext`lastlocposth$$, $CellContext`lastth$$ != $CellContext`th$$], \
$CellContext`lastlocposth$$ = {$CellContext`xth$$, $CellContext`yth$$}; \
$CellContext`lastth$$ = $CellContext`th$$; {$CellContext`xth$$, \
$CellContext`yth$$} = $CellContext`laststartposth$$ + $CellContext`radiusth$$ {
                    Cos[$CellContext`th$$ Degree], 
                    
                    Sin[$CellContext`th$$ 
                    Degree]}]; {$CellContext`xth$$, $CellContext`yth$$}), \
({$CellContext`xth$$, $CellContext`yth$$} = #; $CellContext`xoffth$$ = \
$CellContext`xth$$ - $CellContext`x$$; $CellContext`yoffth$$ = \
$CellContext`yth$$ - $CellContext`y$$; $CellContext`radiusth$$ = 
                    Sqrt[$CellContext`xoffth$$^2 + $CellContext`yoffth$$^2]; \
$CellContext`th$$ = Chop[
                    ArcTan[$CellContext`xoffth$$, $CellContext`yoffth$$]/
                    Degree]; {$CellContext`xth$$, $CellContext`yth$$})& ], 
                  Graphics[{
                    RGBColor[1/3, 1/3, 1], 
                    Disk[{0, 0}, 0.5]}, ImageSize -> 10]], 
                 Dynamic[
                  StringJoin["th = ", 
                   ToString[$CellContext`th$$]]]], 
                Tooltip[
                 Locator[
                  Dynamic[
                  BesselJ[
                    1., 3.]; {$CellContext`x$$, $CellContext`y$$}, \
({$CellContext`x$$, $CellContext`y$$} = Chop[#])& ], 
                  Graphics[{
                    RGBColor[1, 1/3, 1/3], 
                    Disk[{0, 0}, 0.8]}, ImageSize -> 10]], 
                 Dynamic[
                  StringJoin["{x, y} = ", 
                   ToString[
                    Chop[{$CellContext`x$$, $CellContext`y$$}]]]]]}}]}, {
            PlotLabel -> "Eye Model", ImageSize -> 800, AspectRatio -> 
             Automatic}]}, True], 
         Tooltip[
          Row[{
            Style["", Italic, 10], 
            Hyperlink[
             Style["<< Crafted with Optica\[Trademark] >>", Italic, 10], 
             "http://www.opticasoftware.com"], 
            Style["", Italic, 10]}], 
          "Click here to visit www.opticasoftware.com"]}, Center], 
      "Specifications" :> {{{$CellContext`th$$, 0.}, -180., 180., ControlType -> 
         None}, {{$CellContext`x$$, -5.}, -10, -0.05, ControlType -> 
         None}, {{$CellContext`y$$, 0.}, -10, 10, ControlType -> 
         None}, {{$CellContext`minth$$, -180.}, ControlType -> 
         None}, {{$CellContext`maxth$$, 180.}, ControlType -> 
         None}, {{$CellContext`minx$$, -10}, ControlType -> 
         None}, {{$CellContext`maxx$$, -0.05}, ControlType -> 
         None}, {{$CellContext`miny$$, -10}, ControlType -> 
         None}, {{$CellContext`maxy$$, 10}, ControlType -> None}, 
        Button[
        "Report", 
         Optica`Optica`$OpticalSystemSettings = {
           Optica`Optica`SymbolicValues -> 
            MapThread[
             ToExpression[#] -> #2& , {{
               "th", "x", 
                "y"}, {$CellContext`th$$, $CellContext`x$$, \
$CellContext`y$$}}], 
            Optica`Optica`SymbolicRanges -> {$CellContext`th$$ -> {-180., 
               180.}, $CellContext`x$$ -> {-10, -0.05}, $CellContext`y$$ -> \
{-10, 10}}}; 
         Optica`Optica`$OpticalSystemScript = 
          "{Move[LineOfRays[3, NumberOfRays -> 5], {{x, -5.}, {y, 0}}, {th, \
0.}, SymbolicValues -> {th -> 0, x -> -5, y -> 0}], EyeModel[0, 0, 0, 30, 5, \
{PupilData -> {10, 0.05}, Resonate -> False, Transmittance -> 0, \
CrossRendering -> Trace}]}"; Print[
           InputForm[
            StringJoin["SymbolicValues -> ", 
             ToString[
              MapThread[StringJoin[#, "->", 
                ToString[#2, InputForm]]& , {{
                "th", "x", 
                 "y"}, {$CellContext`th$$, $CellContext`x$$, \
$CellContext`y$$}}]]]]], ImageSize -> 
         Automatic], {{$CellContext`xth$$, -4.4019925}, ControlType -> 
         None}, {{$CellContext`yth$$, 0.}, ControlType -> 
         None}, {{$CellContext`radiusth$$, 0.5980074999999999}, ControlType -> 
         None}, {{$CellContext`xoffth$$, 0.5980074999999999}, ControlType -> 
         None}, {{$CellContext`yoffth$$, 0.}, ControlType -> 
         None}, {{$CellContext`laststartposth$$, {-5., 0.}}, ControlType -> 
         None}, {{$CellContext`lastlocposth$$, {-4.4019925, 0.}}, ControlType -> 
         None}, {{$CellContext`lastth$$, 0}, ControlType -> 
         None}, {{$CellContext`staticpolygons1183869201251111755406940$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[CompressedData["
1:eJyFmntwj1cax19JRCJBIheXpi5RSdbWpXLpopxHd9wvI7TYYq1bp2vdVjtL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            "]]}}, ControlType -> None}}, 
      "Options" :> {
       TrackedSymbols -> Manipulate, Deployed -> False, 
        AutorunSequencing -> {1, 2, 3}, SynchronousInitialization -> False, 
        SynchronousUpdating -> False, 
        BaseStyle -> {DynamicEvaluationTimeout -> 100}}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{858., {444., 450.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>($CellContext`raytracefunction183869201251111755413171 = 
      Compile[{{$CellContext`th$$, 
          Blank[Real]}, {$CellContext`x$$, 
          Blank[Real]}, {$CellContext`y$$, 
          Blank[Real]}}, 
        Module[{$CellContext`activeregion$, \
$CellContext`allcreatedamplitudes$, $CellContext`allcreatedrays$, \
$CellContext`allowzeroraylength$, $CellContext`alternateindex$, \
$CellContext`amplitude$, $CellContext`axismagnitude$, \
$CellContext`axismatrix$, $CellContext`clonedata$, \
$CellContext`clonegenerationnumber$, $CellContext`cloneinput$, \
$CellContext`clonenumber$, $CellContext`cloneposition$, \
$CellContext`clonereportedrays$, $CellContext`clonerotation$, \
$CellContext`clonescale$, $CellContext`clonescalevector$, \
$CellContext`clonesorthistogram$, $CellContext`clonetraceinput$, \
$CellContext`clonetraceoutput$, $CellContext`closestdistances$, \
$CellContext`closestposition$, $CellContext`closestpositions$, \
$CellContext`closestraylength$, $CellContext`completedray$, \
$CellContext`componentnumber$, $CellContext`cosangle$, \
$CellContext`crossmatrix$, $CellContext`deflecteddummyrayspresent$, \
$CellContext`deflectedlocalrays$, $CellContext`deflectedrays$, \
$CellContext`deflectedrayspresent$, $CellContext`dummymatrix$, \
$CellContext`dummymatrixlist$, $CellContext`dummyvector$, \
$CellContext`frontid$, $CellContext`generationlimit$, \
$CellContext`generationnumber$, $CellContext`holeintersections$, \
$CellContext`holeQ$, $CellContext`holeQlist$, $CellContext`hor$, \
$CellContext`index$, $CellContext`index1$, $CellContext`index2$, \
$CellContext`inrays$, $CellContext`intensity$, $CellContext`intensityscale$, \
$CellContext`intersectionnumber$, $CellContext`intersections$, \
$CellContext`intersectionslist$, $CellContext`intersectionspresent$, \
$CellContext`localdummyoutrayspresent$, $CellContext`localoutrays$, \
$CellContext`localoutrayspresent$, $CellContext`magnitude$, \
$CellContext`maxclonegenerationnumber$, $CellContext`maximumposition$, \
$CellContext`minimumraylength$, $CellContext`minresonateraylength$, \
$CellContext`n12$, $CellContext`newcomponentnumber$, \
$CellContext`newdeflectedrays$, $CellContext`newdistance$, \
$CellContext`newsurfaceid$, $CellContext`newsurfacenumber$, \
$CellContext`nonintersectingrays$, $CellContext`normalizedpolarization$, \
$CellContext`oldgenerationnumber$, $CellContext`opticallength$, \
$CellContext`originalray$, $CellContext`originalraytilt$, \
$CellContext`originalrotation$, $CellContext`originalsurfnorm$, \
$CellContext`outrays$, $CellContext`parallelamplitude$, $CellContext`PAxis$, \
$CellContext`perpendicularamplitude$, $CellContext`phaseshift$, \
$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$, \
$CellContext`previoustilt$, $CellContext`propagate$, \
$CellContext`propagatedrays$, $CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$, $CellContext`r4$, $CellContext`r5$, $CellContext`r6$, \
$CellContext`r7$, $CellContext`r8$, $CellContext`r9$, $CellContext`ray1$, \
$CellContext`ray2$, $CellContext`ray3$, $CellContext`LocRayL$, \
$CellContext`rayslot$, $CellContext`raysreported$, $CellContext`raytiltx$, \
$CellContext`raytiltz$, $CellContext`reporteddummyrayspresent$, \
$CellContext`reportedlocalrays$, $CellContext`reportedrays$, \
$CellContext`reportedrayspresent$, $CellContext`resonateintersections$, \
$CellContext`resonatenumber$, $CellContext`resonateraylength$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`rotationaxis$, $CellContext`rsx$, $CellContext`LocRSx$, \
$CellContext`rsy$, $CellContext`LocRSy$, $CellContext`rsz$, \
$CellContext`LocRSz$, 
          Optica`Optica`RTx$, $CellContext`LocRTy$, $CellContext`LocRTz$, \
$CellContext`rx$, $CellContext`rxhlp$, $CellContext`ry$, $CellContext`ryhlp$, \
$CellContext`rz$, $CellContext`rzhlp$, $CellContext`LocSCx$, \
$CellContext`LocSCy$, $CellContext`sid$, $CellContext`sinangle$, \
$CellContext`sno1$, $CellContext`sno2$, $CellContext`sno3$, \
$CellContext`sno4$, $CellContext`surfaceid$, $CellContext`surfacenumber$, \
$CellContext`surfacerotationmatrix$, $CellContext`surfacetranslationvector$, \
$CellContext`surfnorm$, $CellContext`symr1$, $CellContext`symr2$, \
$CellContext`symr3$, $CellContext`symr4$, $CellContext`symr5$, \
$CellContext`symr6$, $CellContext`symr7$, $CellContext`symr8$, \
$CellContext`symr9$, $CellContext`tempclonedata$, \
$CellContext`terminatedeflection$, $CellContext`thresholdintensity$, \
$CellContext`tiltmagnitude$, $CellContext`transmatrix$, $CellContext`LocTV1$, \
$CellContext`LocTV10$, $CellContext`LocTV2$, $CellContext`LocTV3$, \
$CellContext`LocTV4$, $CellContext`LocTV5$, $CellContext`LocTV6$, \
$CellContext`LocTV7$, $CellContext`LocTV8$, $CellContext`LocTV9$, \
$CellContext`u$, $CellContext`unfilteredintersections$, $CellContext`unit$, \
$CellContext`uu$, $CellContext`ver$, $CellContext`wavelength$, \
$CellContext`XAxis$, $CellContext`xunit$, $CellContext`YAxis$, \
$CellContext`yunit$, $CellContext`ZAxis$, $CellContext`zunit$}, \
$CellContext`activeregion$ = 
          1.; $CellContext`allcreatedamplitudes$ = {{
            0. + 0. I, 0. + 0. I, 0. + 
             0. I}}; $CellContext`allcreatedrays$ = {{
           1.}}; $CellContext`allowzeroraylength$ = 
          True; $CellContext`alternateindex$ = 
          1.; $CellContext`amplitude$ = {
           1. + 0. I, 0. + 0. I, 0. + 0. I}; $CellContext`axismagnitude$ = 
          1.; $CellContext`axismatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0.,
            1.}}; $CellContext`clonedata$ = {{
           1.}}; $CellContext`clonegenerationnumber$ = 
          1.; $CellContext`cloneinput$ = {1.}; $CellContext`clonenumber$ = 
          1; $CellContext`cloneposition$ = {0., 0., 
           0.}; $CellContext`clonereportedrays$ = {{
           1.}}; $CellContext`clonerotation$ = {{
           1.}}; $CellContext`clonescale$ = 
          1.; $CellContext`clonescalevector$ = {
           1.}; $CellContext`clonesorthistogram$ = {
           1}; $CellContext`clonetraceinput$ = {{
           1.}}; $CellContext`clonetraceoutput$ = {{
           1.}}; $CellContext`closestdistances$ = {
           1.}; $CellContext`closestposition$ = 
          0; $CellContext`closestpositions$ = {
           0}; $CellContext`closestraylength$ = 
          1.; $CellContext`completedray$ = {
           1.}; $CellContext`componentnumber$ = -1.; $CellContext`cosangle$ = 
          1.; $CellContext`crossmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
           0., 1.}}; $CellContext`deflecteddummyrayspresent$ = 
          False; $CellContext`deflectedlocalrays$ = {{
           1.}}; $CellContext`deflectedrays$ = {{
           1.}}; $CellContext`deflectedrayspresent$ = 
          False; $CellContext`dummymatrix$ = {{
           1.}}; $CellContext`dummymatrixlist$ = {{{
           1.}}}; $CellContext`dummyvector$ = {1.}; $CellContext`frontid$ = 
          1.; $CellContext`generationlimit$ = 
          200.; $CellContext`generationnumber$ = 
          1.; $CellContext`holeintersections$ = {{-1., 0., 
           0.}}; $CellContext`holeQ$ = 
          False; $CellContext`holeQlist$ = {0}; $CellContext`hor$ = 
          1. + 0. I; $CellContext`index$ = 1.; $CellContext`index1$ = 
          1.; $CellContext`index2$ = 
          1.; $CellContext`inrays$ = {{1.}}; $CellContext`intensity$ = 
          1.; $CellContext`intensityscale$ = 
          1.; $CellContext`intersectionnumber$ = 
          1.; $CellContext`intersections$ = {{-1., 0., 
           0.}}; $CellContext`intersectionslist$ = {{{-1., 0., 
           0.}}}; $CellContext`intersectionspresent$ = 
          False; $CellContext`localdummyoutrayspresent$ = 
          False; $CellContext`localoutrays$ = {{
           1.}}; $CellContext`localoutrayspresent$ = 
          False; $CellContext`magnitude$ = 
          1.; $CellContext`maxclonegenerationnumber$ = 
          1.; $CellContext`maximumposition$ = 
          1; $CellContext`minimumraylength$ = 
          0.0001; $CellContext`minresonateraylength$ = 1.; $CellContext`n12$ = 
          1.; $CellContext`newcomponentnumber$ = -1.; \
$CellContext`newdeflectedrays$ = {{1.}}; $CellContext`newdistance$ = 
          1.; $CellContext`newsurfaceid$ = -1.; \
$CellContext`newsurfacenumber$ = -1.; $CellContext`nonintersectingrays$ = {{
           1.}}; $CellContext`normalizedpolarization$ = {1., 
           1.}; $CellContext`oldgenerationnumber$ = 
          1.; $CellContext`opticallength$ = 
          1.; $CellContext`originalray$ = {
           1.}; $CellContext`originalraytilt$ = {
           1.}; $CellContext`originalrotation$ = {{1., 0., 0.}, {0., 1., 
           0.}, {0., 0., 1.}}; $CellContext`originalsurfnorm$ = {{
           1.}}; $CellContext`outrays$ = {{
           1.}}; $CellContext`parallelamplitude$ = 
          1. + 0. I; $CellContext`PAxis$ = {1., 0., 
           0.}; $CellContext`perpendicularamplitude$ = 
          1. + 0. I; $CellContext`phaseshift$ = 0.; $CellContext`pol1$ = 
          1.; $CellContext`pol2$ = 1.; $CellContext`pol3$ = 
          1.; $CellContext`previoustilt$ = {1., 0., 
           0.}; $CellContext`propagate$ = 
          True; $CellContext`propagatedrays$ = {{1.}}; $CellContext`r1$ = 
          1.; $CellContext`r2$ = 1.; $CellContext`r3$ = 1.; $CellContext`r4$ = 
          1.; $CellContext`r5$ = 1.; $CellContext`r6$ = 1.; $CellContext`r7$ = 
          1.; $CellContext`r8$ = 1.; $CellContext`r9$ = 
          1.; $CellContext`ray1$ = 1.; $CellContext`ray2$ = 
          1.; $CellContext`ray3$ = 1.; $CellContext`LocRayL$ = 
          1.; $CellContext`rayslot$ = 1.; $CellContext`raysreported$ = 
          False; $CellContext`raytiltx$ = 1.; $CellContext`raytiltz$ = 
          1.; $CellContext`reporteddummyrayspresent$ = 
          False; $CellContext`reportedlocalrays$ = {{
           1.}}; $CellContext`reportedrays$ = {{
           1.}}; $CellContext`reportedrayspresent$ = 
          False; $CellContext`resonateintersections$ = {{-1., 0., 
           0.}}; $CellContext`resonatenumber$ = 
          0; $CellContext`resonateraylength$ = 1.; $CellContext`rex$ = 
          1.; $CellContext`rey$ = 1.; $CellContext`rez$ = 
          1.; $CellContext`rsx$ = 1.; $CellContext`LocRSx$ = 
          1.; $CellContext`rsy$ = 1.; $CellContext`LocRSy$ = 
          1.; $CellContext`rsz$ = 1.; $CellContext`LocRSz$ = 1.; 
         Optica`Optica`RTx$ = 1.; $CellContext`LocRTy$ = 
          1.; $CellContext`LocRTz$ = 1.; $CellContext`rx$ = 
          1.; $CellContext`rxhlp$ = 1.; $CellContext`ry$ = 
          1.; $CellContext`ryhlp$ = 1.; $CellContext`rz$ = 
          1.; $CellContext`rzhlp$ = 1.; $CellContext`LocSCx$ = 
          1.; $CellContext`LocSCy$ = 1.; $CellContext`sid$ = 
          1.; $CellContext`sinangle$ = 1.; $CellContext`sno1$ = 
          1.; $CellContext`sno2$ = 1.; $CellContext`sno3$ = 
          1.; $CellContext`sno4$ = 
          1.; $CellContext`surfaceid$ = -1.; $CellContext`surfacenumber$ = \
-1.; $CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
           0., 1.}}; $CellContext`surfacetranslationvector$ = {0., 0., 
           0.}; $CellContext`surfnorm$ = {{1.}}; $CellContext`symr1$ = 
          1.; $CellContext`symr2$ = 1.; $CellContext`symr3$ = 
          1.; $CellContext`symr4$ = 1.; $CellContext`symr5$ = 
          1.; $CellContext`symr6$ = 1.; $CellContext`symr7$ = 
          1.; $CellContext`symr8$ = 1.; $CellContext`symr9$ = 
          1.; $CellContext`tempclonedata$ = {{
           1.}}; $CellContext`terminatedeflection$ = 
          False; $CellContext`thresholdintensity$ = 
          1.; $CellContext`tiltmagnitude$ = 
          1.; $CellContext`transmatrix$ = {{{1., 0., 0.}, {0., 1., 0.}, {0., 
           0., 1.}}}; $CellContext`LocTV1$ = 1.; $CellContext`LocTV10$ = 
          1.; $CellContext`LocTV2$ = 1.; $CellContext`LocTV3$ = 
          1.; $CellContext`LocTV4$ = 1.; $CellContext`LocTV5$ = 
          1.; $CellContext`LocTV6$ = 1.; $CellContext`LocTV7$ = 
          1.; $CellContext`LocTV8$ = 1.; $CellContext`LocTV9$ = 
          1.; $CellContext`u$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
           1.}}; $CellContext`unfilteredintersections$ = {{-1., 0., 
           0.}}; $CellContext`unit$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
           1.}}; $CellContext`uu$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
           1.}}; $CellContext`ver$ = 0. + 0. I; $CellContext`wavelength$ = 
          1.; $CellContext`XAxis$ = {1., 0., 0.}; $CellContext`xunit$ = 
          1.; $CellContext`YAxis$ = {1., 0., 0.}; $CellContext`yunit$ = 
          1.; $CellContext`ZAxis$ = {1., 0., 0.}; $CellContext`zunit$ = 
          1.; $CellContext`propagatedrays$ = 
          Join[{$CellContext`symr1$, $CellContext`symr2$, \
$CellContext`symr3$, $CellContext`symr4$, $CellContext`symr5$, \
$CellContext`symr6$, $CellContext`symr7$, $CellContext`symr8$, \
$CellContext`symr9$} = Re[{
                Cos[Degree $CellContext`th$$], 
                Sin[Degree $CellContext`th$$], 0, -
                Sin[Degree $CellContext`th$$], 
                Cos[Degree $CellContext`th$$], 0, 0, 0, 1}]; 
            Map[({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {$CellContext`LocTV1$, $CellContext`LocTV2$, \
$CellContext`LocTV3$} = {$CellContext`rsx$ $CellContext`symr1$ + \
$CellContext`rsy$ $CellContext`symr4$ + $CellContext`rsz$ $CellContext`symr7$ + \
$CellContext`x$$, $CellContext`rsx$ $CellContext`symr2$ + $CellContext`rsy$ \
$CellContext`symr5$ + $CellContext`rsz$ $CellContext`symr8$ + \
$CellContext`y$$, $CellContext`rsx$ $CellContext`symr3$ + $CellContext`rsy$ \
$CellContext`symr6$ + $CellContext`rsz$ $CellContext`symr9$}; \
{$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$} = \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$}; \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$} = \
{$CellContext`rex$ $CellContext`symr1$ + $CellContext`rey$ \
$CellContext`symr4$ + $CellContext`rez$ $CellContext`symr7$ + \
$CellContext`x$$, $CellContext`rex$ $CellContext`symr2$ + $CellContext`rey$ \
$CellContext`symr5$ + $CellContext`rez$ $CellContext`symr8$ + \
$CellContext`y$$, $CellContext`rex$ $CellContext`symr3$ + $CellContext`rey$ \
$CellContext`symr6$ + $CellContext`rez$ $CellContext`symr9$}; \
{$CellContext`rex$, $CellContext`rey$, $CellContext`rez$} = \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$}; \
{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$} = \
{$CellContext`r1$ $CellContext`symr1$ + $CellContext`r2$ $CellContext`symr4$ + \
$CellContext`r3$ $CellContext`symr7$, $CellContext`r1$ $CellContext`symr2$ + \
$CellContext`r2$ $CellContext`symr5$ + $CellContext`r3$ $CellContext`symr8$, \
$CellContext`r1$ $CellContext`symr3$ + $CellContext`r2$ $CellContext`symr6$ + \
$CellContext`r3$ $CellContext`symr9$}; {$CellContext`LocTV4$, \
$CellContext`LocTV5$, $CellContext`LocTV6$} = {$CellContext`r4$ \
$CellContext`symr1$ + $CellContext`r5$ $CellContext`symr4$ + $CellContext`r6$ \
$CellContext`symr7$, $CellContext`r4$ $CellContext`symr2$ + $CellContext`r5$ \
$CellContext`symr5$ + $CellContext`r6$ $CellContext`symr8$, $CellContext`r4$ \
$CellContext`symr3$ + $CellContext`r5$ $CellContext`symr6$ + $CellContext`r6$ \
$CellContext`symr9$}; {$CellContext`LocTV7$, $CellContext`LocTV8$, \
$CellContext`LocTV9$} = {$CellContext`r7$ $CellContext`symr1$ + \
$CellContext`r8$ $CellContext`symr4$ + $CellContext`r9$ $CellContext`symr7$, \
$CellContext`r7$ $CellContext`symr2$ + $CellContext`r8$ $CellContext`symr5$ + \
$CellContext`r9$ $CellContext`symr8$, $CellContext`r7$ $CellContext`symr3$ + \
$CellContext`r8$ $CellContext`symr6$ + $CellContext`r9$ $CellContext`symr9$}; \
{{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}} = {{$CellContext`LocTV1$, $CellContext`LocTV2$, \
$CellContext`LocTV3$}, {$CellContext`LocTV4$, $CellContext`LocTV5$, \
$CellContext`LocTV6$}, {$CellContext`LocTV7$, $CellContext`LocTV8$, \
$CellContext`LocTV9$}}; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , CompressedData["
1:eJxTTMoPSmViYGBgBWJ1BnTwYz+GEFbxD/bY1REvv0BK/64K20OoukiHWTNB
4CRc3xOl4C4pRlzmEDIfCir2OKDQcH0iaHzi3Y1d/AWOcEMXH6rhxgClRdD4
xLubKHvJ1j9Yw40DSoug8Yl3N3bxF0SKD9VwE4DSImh84t2NXfwHkeJDNdxE
cNDEuxvGAgD1v379
              "]]]; $CellContext`propagatedrays$ = 
          Map[({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`componentnumber$ = 
             1.; $CellContext`frontid$ = 
             1.; {$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`propagatedrays$]; \
$CellContext`thresholdintensity$ = 1.; $CellContext`generationlimit$ = 
          200.; $CellContext`reportedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`generationnumber$ = 0.; (
          AddTo[$CellContext`generationnumber$, 
            1.]; $CellContext`reportedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, 
              0, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`deflectedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; ($CellContext`deflectedrayspresent$ = 
            False; $CellContext`reportedrayspresent$ = 
            False; $CellContext`deflecteddummyrayspresent$ = 
            False; $CellContext`reporteddummyrayspresent$ = 
            False; {$CellContext`deflectedlocalrays$, \
$CellContext`reportedlocalrays$} = Transpose[
              
              Map[(({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                 Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                 Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                 Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                   2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                 3.5999999999999996` + $CellContext`rex$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                 Chop[$CellContext`rx$]; $CellContext`ry$ = 
                 Chop[$CellContext`ry$]; $CellContext`rz$ = 
                 Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                 False; $CellContext`intersections$ = {{-1., 0., 0.}}); 
               If[$CellContext`intensity$ > $CellContext`thresholdintensity$, \
$CellContext`deflectedrayspresent$ = 
                  True; ($CellContext`intersections$ = 
                   Block[{Compile`$37, Compile`$41, Compile`$75, Compile`$49, 
                    Compile`$82, Compile`$72, Compile`$38, Compile`$43, 
                    Compile`$52, Compile`$53, Compile`$54, Compile`$70, 
                    Compile`$74, Compile`$76, Compile`$79, Compile`$80, 
                    Compile`$81, Compile`$83, Compile`$84, Compile`$87, 
                    Compile`$88, Compile`$89, Compile`$90, Compile`$91, 
                    Compile`$92, Compile`$93, Compile`$94, Compile`$55, 
                    Compile`$59, Compile`$65, Compile`$69, Compile`$98, 
                    Compile`$101, Compile`$102, Compile`$104, Compile`$105, 
                    Compile`$113, Compile`$115, Compile`$117, Compile`$118, 
                    Compile`$119, Compile`$151, Compile`$152, Compile`$153}, 
                    
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 
                    1. + 0. I; $CellContext`LocSCx$ = 
                    1. + 0. I; $CellContext`LocSCy$ = 1. + 0. I; (
                    Compile`$37 = $CellContext`xunit$^2; 
                    Compile`$41 = $CellContext`yunit$^2; 
                    Compile`$75 = $CellContext`rz$^2; 
                    Compile`$49 = $CellContext`zunit$^2; 
                    Compile`$82 = $CellContext`rx$^2; 
                    Compile`$72 = $CellContext`ry$^2; 
                    Compile`$38 = 37. Compile`$37; 
                    Compile`$43 = 50. Compile`$41; 
                    Compile`$52 = 50. Compile`$49; 
                    Compile`$53 = Compile`$38 + Compile`$43 + Compile`$52; 
                    Compile`$54 = Compile`$53^(-1); 
                    Compile`$70 = 74498. Compile`$37; 
                    Compile`$74 = (-925.) Compile`$72 Compile`$37; 
                    Compile`$76 = (-925.) Compile`$75 Compile`$37; 
                    Compile`$79 = (-19300.) $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$; 
                    Compile`$80 = 
                    1850. $CellContext`rx$ $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$; 
                    Compile`$81 = 19300. $CellContext`rx$ Compile`$41; 
                    Compile`$83 = (-925.) Compile`$82 Compile`$41; 
                    Compile`$84 = (-1250.) Compile`$75 Compile`$41; 
                    Compile`$87 = (-19300.) $CellContext`rz$ \
$CellContext`xunit$ $CellContext`zunit$; 
                    Compile`$88 = 
                    1850. $CellContext`rx$ $CellContext`rz$ \
$CellContext`xunit$ $CellContext`zunit$; 
                    Compile`$89 = 
                    2500. $CellContext`ry$ $CellContext`rz$ \
$CellContext`yunit$ $CellContext`zunit$; 
                    Compile`$90 = 19300. $CellContext`rx$ Compile`$49; 
                    Compile`$91 = (-925.) Compile`$82 Compile`$49; 
                    Compile`$92 = (-1250.) Compile`$72 Compile`$49; 
                    Compile`$93 = 
                    Compile`$70 + Compile`$74 + Compile`$76 + Compile`$79 + 
                    Compile`$80 + Compile`$81 + Compile`$83 + Compile`$84 + 
                    Compile`$87 + Compile`$88 + Compile`$89 + Compile`$90 + 
                    Compile`$91 + Compile`$92; 
                    Compile`$94 = Sqrt[Compile`$93]; 
                    Compile`$55 = 386. $CellContext`xunit$; 
                    Compile`$59 = (-37.) $CellContext`rx$ $CellContext`xunit$; 
                    Compile`$65 = (-50.) $CellContext`ry$ $CellContext`yunit$; 
                    Compile`$69 = (-50.) $CellContext`rz$ $CellContext`zunit$; 
                    Compile`$98 = 37. $CellContext`ry$ Compile`$37; 
                    Compile`$101 = 
                    386. $CellContext`xunit$ $CellContext`yunit$; 
                    Compile`$102 = (-37.) $CellContext`rx$ \
$CellContext`xunit$ $CellContext`yunit$; 
                    Compile`$104 = (-50.) $CellContext`rz$ \
$CellContext`yunit$ $CellContext`zunit$; 
                    Compile`$105 = 50. $CellContext`ry$ Compile`$49; 
                    Compile`$113 = 37. $CellContext`rz$ Compile`$37; 
                    Compile`$115 = 50. $CellContext`rz$ Compile`$41; 
                    Compile`$117 = 
                    386. $CellContext`xunit$ $CellContext`zunit$; 
                    Compile`$118 = (-37.) $CellContext`rx$ \
$CellContext`xunit$ $CellContext`zunit$; 
                    Compile`$119 = (-50.) $CellContext`ry$ \
$CellContext`yunit$ $CellContext`zunit$; Re[
                    
                    Select[{{-1. + 0. I, 0. + 0. I, 0. + 0. I}, {
                    Compile`$54 (Compile`$55 + Compile`$59 + Compile`$65 + 
                    Compile`$69 - 1.4142135623730951` Compile`$94), 
                    Compile`$54 (Compile`$98 + Compile`$101 + Compile`$102 + 
                    Compile`$104 + Compile`$105 - 
                    1.4142135623730951` $CellContext`yunit$ Compile`$94), 
                    Compile`$54 (Compile`$113 + Compile`$115 + Compile`$117 + 
                    Compile`$118 + Compile`$119 - 
                    1.4142135623730951` $CellContext`zunit$ Compile`$94)}, {
                    Compile`$54 (Compile`$55 + Compile`$59 + Compile`$65 + 
                    Compile`$69 + 1.4142135623730951` Compile`$94), 
                    Compile`$54 (Compile`$98 + Compile`$101 + Compile`$102 + 
                    Compile`$104 + Compile`$105 + 
                    1.4142135623730951` $CellContext`yunit$ Compile`$94), 
                    Compile`$54 (Compile`$113 + Compile`$115 + Compile`$117 + 
                    Compile`$118 + Compile`$119 + 
                    1.4142135623730951` $CellContext`zunit$ 
                    Compile`$94)}}, ({$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = #; (
                    Compile`$151 = $CellContext`LocSCx$^2; 
                    Compile`$152 = $CellContext`LocSCy$^2; 
                    Compile`$153 = Compile`$151 + Compile`$152; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, 
                    And[Chop[
                    Im[#]] == {0, 0, 0}, N[
                    Chop[
                    Re[$CellContext`LocRayL$]]] >= 0., 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    
                    Abs[$CellContext`rx$ + $CellContext`LocRayL$ \
$CellContext`xunit$ - (25 Compile`$153)/(
                    193 (1 + Sqrt[1 - (925 Compile`$153)/74498]))] < 1.*^-7, 
                    Re[$CellContext`LocSCx$]^2 + Re[$CellContext`LocSCy$]^2 <= 
                    39.0625]]))& ]])]]; 
                  AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 8341.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                  Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                  If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]); 
                 If[$CellContext`intersections$ != {{-1., 0., 
                    0.}}, $CellContext`intersectionspresent$ = 
                    True; ({$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 1., 
                    8341.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 1., 
                    8341.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
-3.5999999999999996` + $CellContext`rxhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}); ($CellContext`reportedrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{
                    1., ((-0.0016083472422043674`) $CellContext`ray2$^3)/(
                    Sqrt[1. - 
                    0.012416440709817716` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)] (1. + Sqrt[
                    1. - 
                    0.012416440709817716` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)])^2) - (
                    0.0016083472422043674` $CellContext`ray2$ \
$CellContext`ray3$^2)/(Sqrt[
                    1. - 0.012416440709817716` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)] (1. + Sqrt[
                    1. - 0.012416440709817716` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)])^2) - (0.2590673575129534 $CellContext`ray2$)/(1. + 
                    Sqrt[1. - 
                    0.012416440709817716` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)]), ((-0.0016083472422043674`) $CellContext`ray2$^2 \
$CellContext`ray3$)/(Sqrt[1. - 
                    0.012416440709817716` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)] (1. + Sqrt[
                    1. - 0.012416440709817716` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)])^2) - (0.0016083472422043674` $CellContext`ray3$^3)/(
                    Sqrt[1. - 
                    0.012416440709817716` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)] (1. + Sqrt[
                    1. - 0.012416440709817716` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)])^2) - (0.2590673575129534 $CellContext`ray3$)/(1. + 
                    Sqrt[1. - 
                    0.012416440709817716` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)])}, {(
                    0.0016083472422043674` $CellContext`ray2$ \
($CellContext`ray2$^2 + $CellContext`ray3$^2))/(
                    Sqrt[1. - 
                    0.012416440709817716` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)] (1. + Sqrt[
                    1. - 0.012416440709817716` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)])^2) + (0.2590673575129534 $CellContext`ray2$)/(1. + 
                    Sqrt[1. - 
                    0.012416440709817716` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)]), 1., 
                    0.}, {(0.0016083472422043674` $CellContext`ray3$ \
($CellContext`ray2$^2 + $CellContext`ray3$^2))/(
                    Sqrt[1. - 
                    0.012416440709817716` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)] (1. + Sqrt[
                    1. - 0.012416440709817716` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)])^2) + (0.2590673575129534 $CellContext`ray3$)/(1. + 
                    Sqrt[1. - 
                    0.012416440709817716` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)]), 0., 1.}}]; If[
                    Or[Part[$CellContext`surfnorm$, 1] == {0., 0., 0.}, 
                    Part[$CellContext`surfnorm$, 2] == {0., 0., 0.}, 
                    Part[$CellContext`surfnorm$, 3] == {0., 0., 
                    0.}], $CellContext`surfnorm$ = 
                    1. Re[{{1., ((-0.0016083472422043674`) (
                    1.*^-6 + $CellContext`ray2$)^3)/(
                    Sqrt[1. - 0.012416440709817716` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)] (1. + 
                    Sqrt[1. - 0.012416440709817716` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)])^2) - (
                    0.0016083472422043674` (
                    1.*^-6 + $CellContext`ray2$) (
                    1.*^-6 + $CellContext`ray3$)^2)/(
                    Sqrt[1. - 0.012416440709817716` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)] (1. + 
                    Sqrt[1. - 0.012416440709817716` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)])^2) - (
                    0.2590673575129534 (1.*^-6 + $CellContext`ray2$))/(1. + 
                    Sqrt[1. - 0.012416440709817716` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)]), \
((-0.0016083472422043674`) (1.*^-6 + $CellContext`ray2$)^2 (
                    1.*^-6 + $CellContext`ray3$))/(
                    Sqrt[1. - 0.012416440709817716` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)] (1. + 
                    Sqrt[1. - 0.012416440709817716` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)])^2) - (
                    0.0016083472422043674` (1.*^-6 + $CellContext`ray3$)^3)/(
                    Sqrt[1. - 0.012416440709817716` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)] (1. + 
                    Sqrt[1. - 0.012416440709817716` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)])^2) - (
                    0.2590673575129534 (1.*^-6 + $CellContext`ray3$))/(1. + 
                    Sqrt[1. - 0.012416440709817716` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)])}, {(
                    0.0016083472422043674` (
                    1.*^-6 + $CellContext`ray2$) ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2))/(
                    Sqrt[1. - 0.012416440709817716` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)] (1. + 
                    Sqrt[1. - 0.012416440709817716` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)])^2) + (
                    0.2590673575129534 (1.*^-6 + $CellContext`ray2$))/(1. + 
                    Sqrt[1. - 0.012416440709817716` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)]), 1., 
                    0.}, {(0.0016083472422043674` (
                    1.*^-6 + $CellContext`ray3$) ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2))/(
                    Sqrt[1. - 0.012416440709817716` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)] (1. + 
                    Sqrt[1. - 0.012416440709817716` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)])^2) + (
                    0.2590673575129534 (1.*^-6 + $CellContext`ray3$))/(1. + 
                    Sqrt[1. - 0.012416440709817716` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)]), 0., 1.}}]; 1., 
                    1.]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = \
{-3.5999999999999996`, 0, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; 
                    If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{I 0., I 0., I 0.}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    1.5392664079785883` - 
                    0.723219952199223 $CellContext`wavelength$ + 
                    1.098444937226872 $CellContext`wavelength$^2 - 
                    0.5792106405023153 $CellContext`wavelength$^3; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[
                    1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    1.5392664079785883` - 
                    0.723219952199223 $CellContext`wavelength$ + 
                    1.098444937226872 $CellContext`wavelength$^2 - 
                    0.5792106405023153 $CellContext`wavelength$^3; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    1.5392664079785883` - 
                    0.723219952199223 $CellContext`wavelength$ + 
                    1.098444937226872 $CellContext`wavelength$^2 - 
                    0.5792106405023153 $CellContext`wavelength$^3]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    0., $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1.]; $CellContext`sinangle$ = 
                    1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$])); {
                    
                    First[$CellContext`allcreatedrays$], \
$CellContext`completedray$}, $CellContext`reporteddummyrayspresent$ = 
                    True; {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, CompressedData["
1:eJxTTMoPSmVkYGBQZ4CBD/YDRzdEmOSfPUicerh79+Og6eZuAGaoMiY=
                   
                     "]}], $CellContext`reporteddummyrayspresent$ = 
                  True; $CellContext`deflecteddummyrayspresent$ = 
                  True; CompressedData["
1:eJxTTMoPSmViYGAAYXUGGPhgP3B0Q4RJ/tmDxKmHu3c/DnoA/UFvemiGGwCy
wWJ9
                  "]])& , $CellContext`propagatedrays$]]; If[
             
             And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
              Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ]; 
             1., 1.]; If[
             
             And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
              Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 1.,
              1.]); (If[$CellContext`reportedrayspresent$, \
$CellContext`reportedrays$ = Join[$CellContext`reportedrays$, CompressedData["

1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                
                "], $CellContext`reportedlocalrays$]; 1., 
             1.]; $CellContext`propagatedrays$ = \
$CellContext`deflectedlocalrays$); $CellContext`raysreported$ = \
$CellContext`reportedrayspresent$; 1.); (
          AddTo[$CellContext`generationnumber$, 
            1.]; $CellContext`reportedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, 
              0, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`deflectedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; ($CellContext`deflectedrayspresent$ = 
            False; $CellContext`reportedrayspresent$ = 
            False; $CellContext`deflecteddummyrayspresent$ = 
            False; $CellContext`reporteddummyrayspresent$ = 
            False; {$CellContext`deflectedlocalrays$, \
$CellContext`reportedlocalrays$} = Transpose[
              
              Map[(({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                 Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                 Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                 Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                   2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                 3.05 + $CellContext`rex$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                 Chop[$CellContext`rx$]; $CellContext`ry$ = 
                 Chop[$CellContext`ry$]; $CellContext`rz$ = 
                 Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                 False; $CellContext`intersections$ = {{-1., 0., 0.}}); 
               If[$CellContext`intensity$ > $CellContext`thresholdintensity$, \
$CellContext`deflectedrayspresent$ = 
                  True; ($CellContext`intersections$ = 
                   Block[{Compile`$132, Compile`$138, Compile`$139}, 
                    
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, 
                    Optica`Optica`TempVar3, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; 
                    Optica`Optica`TempVar1 = $CellContext`rx$^2 + \
$CellContext`ry$^2 + $CellContext`rz$^2; 
                    Optica`Optica`TempVar2 = $CellContext`rx$ \
$CellContext`xunit$ + $CellContext`ry$ $CellContext`yunit$ + $CellContext`rz$ \
$CellContext`zunit$ - 6.5 $CellContext`xunit$; 
                    Optica`Optica`TempVar3 = -Optica`Optica`TempVar1 + 
                    Optica`Optica`TempVar2^2 + 2 $CellContext`rx$ 6.5; 
                    Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; 
                    If[N[
                    Chop[Optica`Optica`TempVar3]] >= 0., 
                    Optica`Optica`TempVar3 = Sqrt[Optica`Optica`TempVar3]; 
                    
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = (
                    Compile`$132 = 
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3; {-Optica`Optica`TempVar2 - 
                    Optica`Optica`TempVar3, $CellContext`ry$ - 
                    Compile`$132 $CellContext`yunit$, $CellContext`rz$ - 
                    Compile`$132 $CellContext`zunit$}); If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    25., Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-6.5 + $CellContext`rx$ + $CellContext`LocRayL$ \
$CellContext`xunit$ + 
                    Sqrt[42.25 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = (Compile`$138 = -Optica`Optica`TempVar2; 
                    Compile`$139 = Compile`$138 + Optica`Optica`TempVar3; {
                    Compile`$139, $CellContext`ry$ + 
                    Compile`$139 $CellContext`yunit$, $CellContext`rz$ + 
                    Compile`$139 $CellContext`zunit$}); If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    25., Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-6.5 + $CellContext`rx$ + $CellContext`LocRayL$ \
$CellContext`xunit$ + 
                    Sqrt[42.25 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    If[Part[Optica`Optica`TempVar, 1] == 
                    Part[Optica`Optica`TempVar, 2], {
                    Part[Optica`Optica`TempVar, 1]}, 
                    Optica`Optica`TempVar], {{-1., 0., 0.}}]]]; 
                  AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 8342.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                  Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                  If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]); 
                 If[$CellContext`intersections$ != {{-1., 0., 
                    0.}}, $CellContext`intersectionspresent$ = 
                    True; ({$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 2., 
                    8342.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 2., 
                    8342.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
-3.05 + $CellContext`rxhlp$; $CellContext`rey$ = $CellContext`ryhlp$; \
$CellContext`rez$ = $CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}); ($CellContext`reportedrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{
                    1., -($CellContext`ray2$/(
                    42.25 - $CellContext`ray2$^2 - $CellContext`ray3$^2)^(
                    2^(-1))), -($CellContext`ray3$/(
                    42.25 - $CellContext`ray2$^2 - $CellContext`ray3$^2)^(
                    2^(-1)))}, {$CellContext`ray2$/(
                    42.25 - $CellContext`ray2$^2 - $CellContext`ray3$^2)^(
                    2^(-1)), 1., 
                    0.}, {$CellContext`ray3$/(
                    42.25 - $CellContext`ray2$^2 - $CellContext`ray3$^2)^(
                    2^(-1)), 0., 1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {-3.05, 0, 
                    0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; 
                    If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{I 0., I 0., I 0.}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    1.553268208581225 - 
                    1.0054245500499506` $CellContext`wavelength$ + 
                    1.6027810806802931` $CellContext`wavelength$^2 - 
                    0.8794405514295299 $CellContext`wavelength$^3; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    1.5392664079785883` - 
                    0.723219952199223 $CellContext`wavelength$ + 
                    1.098444937226872 $CellContext`wavelength$^2 - 
                    0.5792106405023153 $CellContext`wavelength$^3; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    1.5392664079785883` - 
                    0.723219952199223 $CellContext`wavelength$ + 
                    1.098444937226872 $CellContext`wavelength$^2 - 
                    0.5792106405023153 $CellContext`wavelength$^3], \
$CellContext`index2$ = 1.5392664079785883` - 
                    0.723219952199223 $CellContext`wavelength$ + 
                    1.098444937226872 $CellContext`wavelength$^2 - 
                    0.5792106405023153 $CellContext`wavelength$^3; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    1.553268208581225 - 
                    1.0054245500499506` $CellContext`wavelength$ + 
                    1.6027810806802931` $CellContext`wavelength$^2 - 
                    0.8794405514295299 $CellContext`wavelength$^3; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    1.553268208581225 - 
                    1.0054245500499506` $CellContext`wavelength$ + 
                    1.6027810806802931` $CellContext`wavelength$^2 - 
                    0.8794405514295299 $CellContext`wavelength$^3]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    0., $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1.]; $CellContext`sinangle$ = 
                    1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$])); {
                    
                    First[$CellContext`allcreatedrays$], \
$CellContext`completedray$}, $CellContext`reporteddummyrayspresent$ = 
                    True; {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, CompressedData["
1:eJxTTMoPSmVkYGBQZ4CBD/YDRzdEmOSfPUicerh79+Og6eZuAGaoMiY=
                   
                     "]}], $CellContext`reporteddummyrayspresent$ = 
                  True; $CellContext`deflecteddummyrayspresent$ = 
                  True; CompressedData["
1:eJxTTMoPSmViYGAAYXUGGPhgP3B0Q4RJ/tmDxKmHu3c/DnoA/UFvemiGGwCy
wWJ9
                  "]])& , $CellContext`propagatedrays$]]; If[
             
             And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
              Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ]; 
             1., 1.]; If[
             
             And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
              Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 1.,
              1.]); (If[$CellContext`reportedrayspresent$, \
$CellContext`reportedrays$ = Join[$CellContext`reportedrays$, CompressedData["

1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                
                "], $CellContext`reportedlocalrays$]; 1., 
             1.]; $CellContext`propagatedrays$ = \
$CellContext`deflectedlocalrays$); $CellContext`raysreported$ = \
$CellContext`reportedrayspresent$; 1.); (
          AddTo[$CellContext`generationnumber$, 
            1.]; $CellContext`reportedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, 
              0, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`deflectedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; ($CellContext`deflectedrayspresent$ = 
            False; $CellContext`reportedrayspresent$ = 
            False; $CellContext`deflecteddummyrayspresent$ = 
            False; $CellContext`reporteddummyrayspresent$ = 
            False; {$CellContext`deflectedlocalrays$, \
$CellContext`reportedlocalrays$} = Transpose[
              
              Map[(({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                 Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                 Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                 Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                   2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                 0.05 + $CellContext`rex$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                 Chop[$CellContext`rx$]; $CellContext`ry$ = 
                 Chop[$CellContext`ry$]; $CellContext`rz$ = 
                 Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                 False; $CellContext`intersections$ = {{-1., 0., 0.}}); 
               If[$CellContext`intensity$ > $CellContext`thresholdintensity$, \
$CellContext`deflectedrayspresent$ = 
                  True; ($CellContext`intersections$ = Block[{Compile`$95}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., Part[#, 2]^2 + Part[#, 3]^2 <= 6.25], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$95 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$95), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$95, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$95}]}, {{-1., 0., 0.}}]]; 
                  AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 8343.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                  Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                  If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]); 
                 If[$CellContext`intersections$ != {{-1., 0., 
                    0.}}, $CellContext`intersectionspresent$ = 
                    True; ({$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 3., 
                    8343.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 3., 
                    8343.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
-0.05 + $CellContext`rxhlp$; $CellContext`rey$ = $CellContext`ryhlp$; \
$CellContext`rez$ = $CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}); ($CellContext`reportedrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {-0.05, 0, 
                    0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}})); {
                    
                    First[$CellContext`allcreatedrays$], \
$CellContext`completedray$}, $CellContext`reporteddummyrayspresent$ = 
                    True; {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, CompressedData["
1:eJxTTMoPSmVkYGBQZ4CBD/YDRzdEmOSfPUicerh79+Og6eZuAGaoMiY=
                   
                     "]}], $CellContext`reporteddummyrayspresent$ = 
                  True; $CellContext`deflecteddummyrayspresent$ = 
                  True; CompressedData["
1:eJxTTMoPSmViYGAAYXUGGPhgP3B0Q4RJ/tmDxKmHu3c/DnoA/UFvemiGGwCy
wWJ9
                  "]])& , $CellContext`propagatedrays$]]; If[
             
             And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
              Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ]; 
             1., 1.]; If[
             
             And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
              Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 1.,
              1.]); (If[$CellContext`reportedrayspresent$, \
$CellContext`reportedrays$ = Join[$CellContext`reportedrays$, CompressedData["

1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                
                "], $CellContext`reportedlocalrays$]; 1., 
             1.]; $CellContext`propagatedrays$ = \
$CellContext`deflectedlocalrays$); $CellContext`raysreported$ = \
$CellContext`reportedrayspresent$; 1.); (
          AddTo[$CellContext`generationnumber$, 
            1.]; $CellContext`reportedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, 
              0, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`deflectedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; ($CellContext`deflectedrayspresent$ = 
            False; $CellContext`reportedrayspresent$ = 
            False; $CellContext`deflecteddummyrayspresent$ = 
            False; $CellContext`reporteddummyrayspresent$ = 
            False; {$CellContext`deflectedlocalrays$, \
$CellContext`reportedlocalrays$} = Transpose[
              
              Map[(({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                 Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                 Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                 Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                   2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                 0.05 + $CellContext`rex$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                 Chop[$CellContext`rx$]; $CellContext`ry$ = 
                 Chop[$CellContext`ry$]; $CellContext`rz$ = 
                 Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                 False; $CellContext`intersections$ = {{-1., 0., 0.}}); 
               If[$CellContext`intensity$ > $CellContext`thresholdintensity$, \
$CellContext`deflectedrayspresent$ = 
                  True; ($CellContext`intersections$ = Block[{Compile`$96}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., Part[#, 2]^2 + Part[#, 3]^2 <= 25.], {
                    
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$96 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$96), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$96, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$96}]}, {{-1., 0., 0.}}]]; 
                  AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 8344.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                  Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                  If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; $CellContext`intersections$ = Union[
                    Map[
                    If[Part[#, 2]^2 + Part[#, 3]^2 <= 
                    6.25, $CellContext`holeQ$ = True; {-1., 0., 
                    0.}, #]& , $CellContext`unfilteredintersections$]]; 
                  If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]); 
                 If[$CellContext`intersections$ != {{-1., 0., 
                    0.}}, $CellContext`intersectionspresent$ = 
                    True; ({$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 4., 
                    8344.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 4., 
                    8344.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
-0.05 + $CellContext`rxhlp$; $CellContext`rey$ = $CellContext`ryhlp$; \
$CellContext`rez$ = $CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}); ($CellContext`reportedrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {-0.05, 0, 
                    0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}})); {
                    
                    First[$CellContext`allcreatedrays$], \
$CellContext`completedray$}, $CellContext`reporteddummyrayspresent$ = 
                    
                    True; {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, CompressedData["
1:eJxTTMoPSmVkYGBQZ4CBD/YDRzdEmOSfPUicerh79+Og6eZuAGaoMiY=
                   
                     "]}], $CellContext`reporteddummyrayspresent$ = 
                  True; $CellContext`deflecteddummyrayspresent$ = 
                  True; CompressedData["
1:eJxTTMoPSmViYGAAYXUGGPhgP3B0Q4RJ/tmDxKmHu3c/DnoA/UFvemiGGwCy
wWJ9
                  "]])& , $CellContext`propagatedrays$]]; If[
             
             And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
              Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ]; 
             1., 1.]; If[
             
             And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
              Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 1.,
              1.]); (If[$CellContext`reportedrayspresent$, \
$CellContext`reportedrays$ = Join[$CellContext`reportedrays$, CompressedData["

1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                
                "], $CellContext`reportedlocalrays$]; 1., 
             1.]; $CellContext`propagatedrays$ = \
$CellContext`deflectedlocalrays$); $CellContext`raysreported$ = \
$CellContext`reportedrayspresent$; 1.); (
          AddTo[$CellContext`generationnumber$, 
            1.]; $CellContext`reportedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, 
              0, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`deflectedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; ($CellContext`deflectedrayspresent$ = 
            False; $CellContext`reportedrayspresent$ = 
            False; $CellContext`deflecteddummyrayspresent$ = 
            False; $CellContext`reporteddummyrayspresent$ = 
            False; {$CellContext`deflectedlocalrays$, \
$CellContext`reportedlocalrays$} = Transpose[
              
              Map[(({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                 Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                 Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                 Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                   2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                 Chop[$CellContext`rx$]; $CellContext`ry$ = 
                 Chop[$CellContext`ry$]; $CellContext`rz$ = 
                 Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                 False; $CellContext`intersections$ = {{-1., 0., 0.}}); 
               If[$CellContext`intensity$ > $CellContext`thresholdintensity$, \
$CellContext`deflectedrayspresent$ = 
                  True; ($CellContext`intersections$ = Block[{Compile`$97}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., Part[#, 2]^2 + Part[#, 3]^2 <= 
                    35.19455625000001], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$97 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$97), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$97, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$97}]}, {{-1., 0., 0.}}]]; 
                  AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 8345.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                  Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                  If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; $CellContext`intersections$ = Union[
                    Map[
                    If[Part[#, 2]^2 + Part[#, 3]^2 <= 
                    28.810056249999995`, $CellContext`holeQ$ = True; {-1., 0.,
                     0.}, #]& , $CellContext`unfilteredintersections$]]; 
                  If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]); 
                 If[$CellContext`intersections$ != {{-1., 0., 
                    0.}}, $CellContext`intersectionspresent$ = 
                    True; ({$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 5., 
                    8345.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 5., 
                    8345.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
$CellContext`rxhlp$; $CellContext`rey$ = $CellContext`ryhlp$; \
$CellContext`rez$ = $CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}); ($CellContext`reportedrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1, 0, 0}, {0, 1, 0}, {0, 0, 
                    1}}; $CellContext`surfacetranslationvector$ = {0, 0, 
                    0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}})); {
                    
                    First[$CellContext`allcreatedrays$], \
$CellContext`completedray$}, $CellContext`reporteddummyrayspresent$ = 
                    True; {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, CompressedData["
1:eJxTTMoPSmVkYGBQZ4CBD/YDRzdEmOSfPUicerh79+Og6eZuAGaoMiY=
                   
                     "]}], $CellContext`reporteddummyrayspresent$ = 
                  True; $CellContext`deflecteddummyrayspresent$ = 
                  True; CompressedData["
1:eJxTTMoPSmViYGAAYXUGGPhgP3B0Q4RJ/tmDxKmHu3c/DnoA/UFvemiGGwCy
wWJ9
                  "]])& , $CellContext`propagatedrays$]]; If[
             
             And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
              Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ]; 
             1., 1.]; If[
             
             And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
              Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 1.,
              1.]); (If[$CellContext`reportedrayspresent$, \
$CellContext`reportedrays$ = Join[$CellContext`reportedrays$, CompressedData["

1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                
                "], $CellContext`reportedlocalrays$]; 1., 
             1.]; $CellContext`propagatedrays$ = \
$CellContext`deflectedlocalrays$); $CellContext`raysreported$ = \
$CellContext`reportedrayspresent$; 1.); (
          AddTo[$CellContext`generationnumber$, 
            1.]; $CellContext`reportedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, 
              0, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`deflectedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; ($CellContext`deflectedrayspresent$ = 
            False; $CellContext`reportedrayspresent$ = 
            False; $CellContext`deflecteddummyrayspresent$ = 
            False; $CellContext`reporteddummyrayspresent$ = 
            False; {$CellContext`deflectedlocalrays$, \
$CellContext`reportedlocalrays$} = Transpose[
              
              Map[(({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                 Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                 Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                 
                 Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                   2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                 Chop[$CellContext`rx$]; $CellContext`ry$ = 
                 Chop[$CellContext`ry$]; $CellContext`rz$ = 
                 Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                 False; $CellContext`intersections$ = {{-1., 0., 0.}}); 
               If[$CellContext`intensity$ > $CellContext`thresholdintensity$, \
$CellContext`deflectedrayspresent$ = 
                  True; ($CellContext`intersections$ = 
                   Block[{$CellContext`surfaceapprox, \
$CellContext`tempapprox, $CellContext`intersects, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, $CellContext`LocRayL$ = 
                    1.; $CellContext`LocSCx$ = 1.; $CellContext`LocSCy$ = 
                    1.; $CellContext`surfaceapprox = {{-1., 0., 
                    0.}}; $CellContext`tempapprox = {{-1., 0., 
                    0.}}; $CellContext`intersects = {{-1., 0., 
                    0.}}; $CellContext`surfaceapprox = 
                    Block[{Compile`$135, Compile`$143, Compile`$144}, 
                    
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, 
                    Optica`Optica`TempVar3, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; 
                    Optica`Optica`TempVar1 = $CellContext`rx$^2 + \
$CellContext`ry$^2 + $CellContext`rz$^2; 
                    Optica`Optica`TempVar2 = $CellContext`rx$ \
$CellContext`xunit$ + $CellContext`ry$ $CellContext`yunit$ + $CellContext`rz$ \
$CellContext`zunit$ - 10.2 $CellContext`xunit$; 
                    Optica`Optica`TempVar3 = -Optica`Optica`TempVar1 + 
                    Optica`Optica`TempVar2^2 + 2 $CellContext`rx$ 10.2; 
                    Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; 
                    If[N[
                    Chop[Optica`Optica`TempVar3]] >= 0., 
                    Optica`Optica`TempVar3 = Sqrt[Optica`Optica`TempVar3]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = (
                    Compile`$135 = Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3; {-Optica`Optica`TempVar2 - 
                    Optica`Optica`TempVar3, $CellContext`ry$ - 
                    Compile`$135 $CellContext`yunit$, $CellContext`rz$ - 
                    Compile`$135 $CellContext`zunit$}); If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    31.922500000000003`, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-10.2 + $CellContext`rx$ + $CellContext`LocRayL$ \
$CellContext`xunit$ + 
                    Sqrt[104.03999999999999` - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = (Compile`$143 = -Optica`Optica`TempVar2; 
                    Compile`$144 = Compile`$143 + Optica`Optica`TempVar3; {
                    Compile`$144, $CellContext`ry$ + 
                    Compile`$144 $CellContext`yunit$, $CellContext`rz$ + 
                    Compile`$144 $CellContext`zunit$}); If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    31.922500000000003`, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-10.2 + $CellContext`rx$ + $CellContext`LocRayL$ \
$CellContext`xunit$ + 
                    Sqrt[104.03999999999999` - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    If[Part[Optica`Optica`TempVar, 1] == 
                    Part[Optica`Optica`TempVar, 2], {
                    Part[Optica`Optica`TempVar, 1]}, 
                    Optica`Optica`TempVar], {{-1., 0., 
                    0.}}]]]; $CellContext`tempapprox = Union[
                    Join[
                    Map[Take[#, 3]& , $CellContext`surfaceapprox], {{-1., 0., 
                    0.}}]]; If[Length[
                    Select[$CellContext`tempapprox, Chop[
                    First[#]] <= 0& ]] != 
                    Length[$CellContext`tempapprox], \
$CellContext`surfaceapprox = Select[$CellContext`tempapprox, Chop[
                    First[#]] > 0& ], $CellContext`surfaceapprox = {{-1., 0., 
                    0.}}]; If[$CellContext`surfaceapprox != {{-1., 0., 
                    0.}}, $CellContext`intersects = {{-1., 0., 0.}}; 
                    Scan[(AppendTo[$CellContext`intersects, \
{$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}; If[Apply[Plus, 
                    
                    Abs[{$CellContext`rx$ + $CellContext`LocRayL$ \
$CellContext`xunit$, $CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$, $CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$} - {(
                    0.09803921568627452 ($CellContext`LocSCx$^2 + \
$CellContext`LocSCy$^2))/(1 + Sqrt[
                    1 + 0.020488273740868906` ($CellContext`LocSCx$^2 + \
$CellContext`LocSCy$^2)]), $CellContext`LocSCx$, $CellContext`LocSCy$}]] < 
                    1.*^-9, {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 0.99 $CellContext`LocRayL$; 
                    Function[{$CellContext`rx, $CellContext`ry, \
$CellContext`rz, $CellContext`xunit, $CellContext`yunit, $CellContext`zunit, \
$CellContext`startpoint}, 
                    
                    Block[{$CellContext`values, $CellContext`stepsizes, \
$CellContext`fvector, $CellContext`success, $CellContext`steps, \
$CellContext`denominator}, $CellContext`values = {
                    1.}; $CellContext`stepsizes = {
                    1.}; $CellContext`fvector = {1.}; $CellContext`success = 
                    False; $CellContext`steps = 0; $CellContext`denominator = 
                    1.; $CellContext`stepsizes = 
                    Table[1.0000000000000001`*^-7, {
                    3}]; $CellContext`values = $CellContext`startpoint; 
                    While[
                    
                    And[$CellContext`steps < 50, $CellContext`success = True; 
                    Map[If[Abs[#] > 1.*^-9, $CellContext`success = False; 1., 
                    1.]& , $CellContext`stepsizes]; 
                    Not[$CellContext`success]], $CellContext`steps = \
$CellContext`steps + 
                    1; $CellContext`fvector = {$CellContext`rx + \
$CellContext`xunit Part[$CellContext`values, 
                    1], $CellContext`ry + $CellContext`yunit 
                    Part[$CellContext`values, 
                    1], $CellContext`rz + $CellContext`zunit 
                    Part[$CellContext`values, 1]} - {(
                    0.09803921568627452 (Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2))/(1 + 
                    Sqrt[1 + 0.020488273740868906` (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2)]), 
                    Part[$CellContext`values, 2], 
                    
                    Part[$CellContext`values, 
                    3]}; $CellContext`denominator = $CellContext`xunit - \
$CellContext`yunit (((0.002008654288320481 
                    Part[$CellContext`values, 2] (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2))/(
                    Sqrt[1 + 0.020488273740868906` (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2)] (1 + 
                    Sqrt[1 + 0.020488273740868906` (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2)])^2) - (
                    0.19607843137254904` Part[$CellContext`values, 2])/(1 + 
                    Sqrt[1 + 0.020488273740868906` (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 
                    3]^2)])) (-1)) - $CellContext`zunit (((
                    0.002008654288320481 
                    Part[$CellContext`values, 3] (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2))/(
                    Sqrt[1 + 0.020488273740868906` (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2)] (1 + 
                    Sqrt[1 + 0.020488273740868906` (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2)])^2) - (
                    0.19607843137254904` Part[$CellContext`values, 3])/(1 + 
                    Sqrt[1 + 0.020488273740868906` (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2)])) (-1)); 
                    If[Chop[$CellContext`denominator] != 
                    0, $CellContext`denominator, $CellContext`denominator = 
                    1.]; $CellContext`stepsizes = -
                    Map[Dot[#, $CellContext`fvector]& , {{
                    1, -(((0.002008654288320481 
                    Part[$CellContext`values, 2] (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2))/(
                    Sqrt[1 + 0.020488273740868906` (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2)] (1 + 
                    Sqrt[1 + 0.020488273740868906` (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2)])^2) - (
                    0.19607843137254904` Part[$CellContext`values, 2])/(1 + 
                    Sqrt[1 + 0.020488273740868906` (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2)])) (-1)), -(((
                    0.002008654288320481 Part[$CellContext`values, 3] (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2))/(
                    Sqrt[1 + 0.020488273740868906` (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2)] (1 + 
                    Sqrt[1 + 0.020488273740868906` (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2)])^2) - (
                    0.19607843137254904` Part[$CellContext`values, 3])/(1 + 
                    Sqrt[1 + 0.020488273740868906` (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 
                    3]^2)])) (-1))}, {$CellContext`yunit, -$CellContext`xunit - \
((0.002008654288320481 Part[$CellContext`values, 3] (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2))/(
                    Sqrt[1 + 0.020488273740868906` (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2)] (1 + 
                    Sqrt[1 + 0.020488273740868906` (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2)])^2) - (
                    0.19607843137254904` Part[$CellContext`values, 3])/(1 + 
                    Sqrt[1 + 0.020488273740868906` (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2)])) $CellContext`zunit, ((
                    0.002008654288320481 Part[$CellContext`values, 3] (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2))/(
                    Sqrt[1 + 0.020488273740868906` (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2)] (1 + 
                    Sqrt[1 + 0.020488273740868906` (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2)])^2) - (
                    0.19607843137254904` Part[$CellContext`values, 3])/(1 + 
                    Sqrt[1 + 0.020488273740868906` (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 
                    3]^2)])) $CellContext`yunit}, {$CellContext`zunit, ((
                    0.002008654288320481 Part[$CellContext`values, 2] (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2))/(
                    Sqrt[1 + 0.020488273740868906` (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2)] (1 + 
                    Sqrt[1 + 0.020488273740868906` (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2)])^2) - (
                    0.19607843137254904` Part[$CellContext`values, 2])/(1 + 
                    Sqrt[1 + 0.020488273740868906` (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 
                    3]^2)])) $CellContext`zunit, -$CellContext`xunit - ((
                    0.002008654288320481 Part[$CellContext`values, 2] (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2))/(
                    Sqrt[1 + 0.020488273740868906` (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2)] (1 + 
                    Sqrt[1 + 0.020488273740868906` (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2)])^2) - (
                    0.19607843137254904` Part[$CellContext`values, 2])/(1 + 
                    Sqrt[1 + 0.020488273740868906` (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 
                    3]^2)])) $CellContext`yunit}}/$CellContext`denominator]; \
$CellContext`values = $CellContext`values + $CellContext`stepsizes]; 
                    If[$CellContext`steps >= 50, 
                    If[First[$CellContext`values] > 
                    0, $CellContext`values = -$CellContext`values; 1., 
                    1.]; $CellContext`denominator = 1., 
                    1.]; $CellContext`values]][$CellContext`rx$, \
$CellContext`ry$, $CellContext`rz$, $CellContext`xunit$, $CellContext`yunit$, \
$CellContext`zunit$, {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}]]]; {-1., 0., 0.})& , $CellContext`surfaceapprox]; Union[
                    Re[
                    
                    Select[$CellContext`intersects, ({$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, 
                    And[Chop[
                    Im[#]] == {0, 0, 0}, N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    31.922500000000003`, Apply[Plus, 
                    
                    Abs[{$CellContext`rx$ + $CellContext`LocRayL$ \
$CellContext`xunit$, $CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$, $CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$} - {(
                    0.09803921568627452 ($CellContext`LocSCx$^2 + \
$CellContext`LocSCy$^2))/(1 + Sqrt[
                    1 + 0.020488273740868906` ($CellContext`LocSCx$^2 + \
$CellContext`LocSCy$^2)]), $CellContext`LocSCx$, $CellContext`LocSCy$}]] < 
                    1.*^-9]])& ]]], {{-1., 0., 0.}}]]; 
                  AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 8346.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                  Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                  If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]); 
                 If[$CellContext`intersections$ != {{-1., 0., 
                    0.}}, $CellContext`intersectionspresent$ = 
                    True; ({$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 6., 
                    8346.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 6., 
                    8346.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
$CellContext`rxhlp$; $CellContext`rey$ = $CellContext`ryhlp$; \
$CellContext`rez$ = $CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}); ($CellContext`reportedrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{
                    1., (0.002008654288320481 $CellContext`ray2$^3)/(
                    Sqrt[1. + 
                    0.020488273740868906` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)] (1. + Sqrt[
                    1. + 0.020488273740868906` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)])^2) + (
                    0.002008654288320481 $CellContext`ray2$ \
$CellContext`ray3$^2)/(Sqrt[1. + 
                    0.020488273740868906` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)] (1. + Sqrt[
                    1. + 0.020488273740868906` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)])^2) - (0.19607843137254904` $CellContext`ray2$)/(1. + 
                    Sqrt[1. + 
                    0.020488273740868906` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)]), (
                    0.002008654288320481 $CellContext`ray2$^2 \
$CellContext`ray3$)/(Sqrt[1. + 
                    0.020488273740868906` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)] (1. + Sqrt[
                    1. + 0.020488273740868906` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)])^2) + (0.002008654288320481 $CellContext`ray3$^3)/(
                    Sqrt[1. + 
                    0.020488273740868906` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)] (1. + Sqrt[
                    1. + 0.020488273740868906` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)])^2) - (0.19607843137254904` $CellContext`ray3$)/(1. + 
                    Sqrt[1. + 
                    0.020488273740868906` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)])}, {((-0.002008654288320481) $CellContext`ray2$ \
($CellContext`ray2$^2 + $CellContext`ray3$^2))/(
                    Sqrt[1. + 
                    0.020488273740868906` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)] (1. + Sqrt[
                    1. + 0.020488273740868906` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)])^2) + (0.19607843137254904` $CellContext`ray2$)/(1. + 
                    Sqrt[1. + 
                    0.020488273740868906` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)]), 1., 
                    0.}, {((-0.002008654288320481) $CellContext`ray3$ \
($CellContext`ray2$^2 + $CellContext`ray3$^2))/(
                    Sqrt[1. + 
                    0.020488273740868906` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)] (1. + Sqrt[
                    1. + 0.020488273740868906` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)])^2) + (0.19607843137254904` $CellContext`ray3$)/(1. + 
                    Sqrt[1. + 
                    0.020488273740868906` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)]), 0., 1.}}]; If[
                    Or[
                    Part[$CellContext`surfnorm$, 1] == {0., 0., 0.}, 
                    Part[$CellContext`surfnorm$, 2] == {0., 0., 0.}, 
                    Part[$CellContext`surfnorm$, 3] == {0., 0., 
                    0.}], $CellContext`surfnorm$ = 
                    1. Re[{{1., (
                    0.002008654288320481 (1.*^-6 + $CellContext`ray2$)^3)/(
                    Sqrt[1. + 0.020488273740868906` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)] (1. + 
                    Sqrt[1. + 0.020488273740868906` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)])^2) + (
                    0.002008654288320481 (
                    1.*^-6 + $CellContext`ray2$) (
                    1.*^-6 + $CellContext`ray3$)^2)/(
                    Sqrt[1. + 0.020488273740868906` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)] (1. + 
                    Sqrt[1. + 0.020488273740868906` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)])^2) - (
                    0.19607843137254904` (1.*^-6 + $CellContext`ray2$))/(1. + 
                    Sqrt[1. + 0.020488273740868906` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)]), (
                    0.002008654288320481 (1.*^-6 + $CellContext`ray2$)^2 (
                    1.*^-6 + $CellContext`ray3$))/(
                    Sqrt[1. + 0.020488273740868906` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)] (1. + 
                    Sqrt[1. + 0.020488273740868906` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)])^2) + (
                    0.002008654288320481 (1.*^-6 + $CellContext`ray3$)^3)/(
                    Sqrt[1. + 0.020488273740868906` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)] (1. + 
                    Sqrt[1. + 0.020488273740868906` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)])^2) - (
                    0.19607843137254904` (1.*^-6 + $CellContext`ray3$))/(1. + 
                    Sqrt[1. + 0.020488273740868906` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)])}, \
{((-0.002008654288320481) (1.*^-6 + $CellContext`ray2$) ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2))/(
                    Sqrt[1. + 0.020488273740868906` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)] (1. + 
                    Sqrt[1. + 0.020488273740868906` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)])^2) + (
                    0.19607843137254904` (1.*^-6 + $CellContext`ray2$))/(1. + 
                    Sqrt[1. + 0.020488273740868906` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)]), 1., 
                    0.}, {((-0.002008654288320481) (
                    1.*^-6 + $CellContext`ray3$) ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2))/(
                    Sqrt[1. + 0.020488273740868906` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)] (1. + 
                    Sqrt[1. + 0.020488273740868906` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)])^2) + (
                    0.19607843137254904` (1.*^-6 + $CellContext`ray3$))/(1. + 
                    Sqrt[1. + 0.020488273740868906` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)]), 0., 1.}}]; 1., 
                    1.]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1, 0, 0}, {0, 1, 0}, {0, 0, 
                    1}}; $CellContext`surfacetranslationvector$ = {0, 0, 
                    0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; 
                    If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{I 0., I 0., I 0.}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    1.6765916828640575` - 
                    1.1701284013478312` $CellContext`wavelength$ + 
                    1.824530254455841 $CellContext`wavelength$^2 - 
                    0.9804493049167722 $CellContext`wavelength$^3; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    1.553268208581225 - 
                    1.0054245500499506` $CellContext`wavelength$ + 
                    1.6027810806802931` $CellContext`wavelength$^2 - 
                    0.8794405514295299 $CellContext`wavelength$^3; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    1.553268208581225 - 
                    1.0054245500499506` $CellContext`wavelength$ + 
                    1.6027810806802931` $CellContext`wavelength$^2 - 
                    0.8794405514295299 $CellContext`wavelength$^3], \
$CellContext`index2$ = 1.553268208581225 - 
                    1.0054245500499506` $CellContext`wavelength$ + 
                    1.6027810806802931` $CellContext`wavelength$^2 - 
                    0.8794405514295299 $CellContext`wavelength$^3; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    1.6765916828640575` - 
                    1.1701284013478312` $CellContext`wavelength$ + 
                    1.824530254455841 $CellContext`wavelength$^2 - 
                    0.9804493049167722 $CellContext`wavelength$^3; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    1.6765916828640575` - 
                    1.1701284013478312` $CellContext`wavelength$ + 
                    1.824530254455841 $CellContext`wavelength$^2 - 
                    0.9804493049167722 $CellContext`wavelength$^3]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    0., $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1.]; $CellContext`sinangle$ = 
                    1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$])); {
                    
                    First[$CellContext`allcreatedrays$], \
$CellContext`completedray$}, $CellContext`reporteddummyrayspresent$ = 
                    True; {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, CompressedData["
1:eJxTTMoPSmVkYGBQZ4CBD/YDRzdEmOSfPUicerh79+Og6eZuAGaoMiY=
                   
                     "]}], $CellContext`reporteddummyrayspresent$ = 
                  True; $CellContext`deflecteddummyrayspresent$ = 
                  True; CompressedData["
1:eJxTTMoPSmViYGAAYXUGGPhgP3B0Q4RJ/tmDxKmHu3c/DnoA/UFvemiGGwCy
wWJ9
                  "]])& , $CellContext`propagatedrays$]]; If[
             
             And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
              Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ]; 
             1., 1.]; If[
             
             And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
              Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 1.,
              1.]); (If[$CellContext`reportedrayspresent$, \
$CellContext`reportedrays$ = Join[$CellContext`reportedrays$, CompressedData["

1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                
                "], $CellContext`reportedlocalrays$]; 1., 
             1.]; $CellContext`propagatedrays$ = \
$CellContext`deflectedlocalrays$); $CellContext`raysreported$ = \
$CellContext`reportedrayspresent$; 1.); (
          AddTo[$CellContext`generationnumber$, 
            1.]; $CellContext`reportedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, 
              0, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`deflectedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; ($CellContext`deflectedrayspresent$ = 
            False; $CellContext`reportedrayspresent$ = 
            False; $CellContext`deflecteddummyrayspresent$ = 
            False; $CellContext`reporteddummyrayspresent$ = 
            False; {$CellContext`deflectedlocalrays$, \
$CellContext`reportedlocalrays$} = Transpose[
              
              Map[(({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                 Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                 Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                 Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                   2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -4. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                 Chop[$CellContext`rx$]; $CellContext`ry$ = 
                 Chop[$CellContext`ry$]; $CellContext`rz$ = 
                 Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                 False; $CellContext`intersections$ = {{-1., 0., 0.}}); 
               If[$CellContext`intensity$ > $CellContext`thresholdintensity$, \
$CellContext`deflectedrayspresent$ = 
                  True; ($CellContext`intersections$ = 
                   Block[{Compile`$121, Compile`$122, Compile`$126, 
                    Compile`$127, Compile`$128, Compile`$129, Compile`$134, 
                    Compile`$136, Compile`$137, Compile`$140, Compile`$141, 
                    Compile`$142, Compile`$145, Compile`$146, Compile`$147, 
                    Compile`$148, Compile`$149, Compile`$150, Compile`$154, 
                    Compile`$130, Compile`$131, Compile`$133, Compile`$158, 
                    Compile`$159, Compile`$160, Compile`$164, Compile`$165, 
                    Compile`$166}, 
                    
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 
                    1. + 0. I; $CellContext`LocSCx$ = 
                    1. + 0. I; $CellContext`LocSCy$ = 1. + 0. I; Re[
                    Select[
                    
                    If[$CellContext`yunit$^2 + $CellContext`zunit$^2 == 0., 
                    Compile`$121 = $CellContext`xunit$^2; 
                    Compile`$122 = 
                    Sqrt[Compile`$121]; {{-1. + 0. I, 0. + 0. I, 0. + 
                    0. I}, {((-0.08333333333333333) (
                    12. $CellContext`rx$ + $CellContext`ry$^2 + \
$CellContext`rz$^2) Compile`$122)/$CellContext`xunit$^2, ($CellContext`ry$ 
                    Compile`$122)/$CellContext`xunit$, $CellContext`rz$}}, 
                    Compile`$126 = $CellContext`yunit$^2; 
                    Compile`$127 = $CellContext`zunit$^2; 
                    Compile`$128 = Compile`$126 + Compile`$127; 
                    Compile`$129 = Compile`$128^(-1); 
                    Compile`$134 = $CellContext`xunit$^2; 
                    Compile`$136 = 36. Compile`$134; 
                    Compile`$137 = 
                    12. $CellContext`ry$ $CellContext`xunit$ \
$CellContext`yunit$; Compile`$140 = (-12.) $CellContext`rx$ Compile`$126; 
                    Compile`$141 = $CellContext`rz$^2; 
                    Compile`$142 = -Compile`$141 Compile`$126; 
                    Compile`$145 = 
                    12. $CellContext`rz$ $CellContext`xunit$ \
$CellContext`zunit$; Compile`$146 = 
                    2. $CellContext`ry$ $CellContext`rz$ $CellContext`yunit$ \
$CellContext`zunit$; Compile`$147 = (-12.) $CellContext`rx$ Compile`$127; 
                    Compile`$148 = $CellContext`ry$^2; 
                    Compile`$149 = -Compile`$148 Compile`$127; 
                    Compile`$150 = 
                    Compile`$136 + Compile`$137 + Compile`$140 + Compile`$142 + 
                    Compile`$145 + Compile`$146 + Compile`$147 + Compile`$149; 
                    Compile`$154 = Sqrt[Compile`$150]; 
                    Compile`$130 = (-6.) $CellContext`xunit$; 
                    Compile`$131 = -$CellContext`ry$ $CellContext`yunit$; 
                    Compile`$133 = -$CellContext`rz$ $CellContext`zunit$; 
                    Compile`$158 = (-6.) $CellContext`xunit$ \
$CellContext`yunit$; 
                    Compile`$159 = -$CellContext`rz$ $CellContext`yunit$ \
$CellContext`zunit$; Compile`$160 = $CellContext`ry$ Compile`$127; 
                    Compile`$164 = $CellContext`rz$ Compile`$126; 
                    Compile`$165 = (-6.) $CellContext`xunit$ \
$CellContext`zunit$; 
                    Compile`$166 = -$CellContext`ry$ $CellContext`yunit$ \
$CellContext`zunit$; {{-1. + 0. I, 0. + 0. I, 0. + 0. I}, {
                    Compile`$129 (Compile`$130 + Compile`$131 + Compile`$133 - 
                    1. Compile`$154), 
                    Compile`$129 (Compile`$158 + Compile`$159 + Compile`$160 - 
                    1. $CellContext`yunit$ Compile`$154), 
                    Compile`$129 (Compile`$164 + Compile`$165 + Compile`$166 - 
                    1. $CellContext`zunit$ Compile`$154)}, {
                    Compile`$129 (Compile`$130 + Compile`$131 + Compile`$133 + 
                    Compile`$154), 
                    Compile`$129 (Compile`$158 + Compile`$159 + 
                    Compile`$160 + $CellContext`yunit$ Compile`$154), 
                    Compile`$129 (Compile`$164 + Compile`$165 + 
                    Compile`$166 + $CellContext`zunit$ 
                    Compile`$154)}}], ({$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, 
                    And[Chop[
                    Im[#]] == {0, 0, 0}, N[
                    Chop[
                    Re[$CellContext`LocRayL$]]] >= 0., 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[$CellContext`rx$ + $CellContext`LocRayL$ \
$CellContext`xunit$ + ($CellContext`LocSCx$^2 + $CellContext`LocSCy$^2)/12] < 
                    1.*^-7, Re[$CellContext`LocSCx$]^2 + 
                    Re[$CellContext`LocSCy$]^2 <= 
                    31.922500000000003`]])& ]]]]; 
                  AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 8347.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                  
                  Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                  If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]); 
                 If[$CellContext`intersections$ != {{-1., 0., 
                    0.}}, $CellContext`intersectionspresent$ = 
                    True; ({$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 7., 
                    8347.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 7., 
                    8347.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    4. + $CellContext`rxhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}); ($CellContext`reportedrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 1. Re[{{1., 
                    Plus[0.16666666666666666` $CellContext`ray2$], 
                    Plus[
                    0.16666666666666666` $CellContext`ray3$]}, \
{(-0.16666666666666666`) $CellContext`ray2$, 1., 
                    0.}, {(-0.16666666666666666`) $CellContext`ray3$, 0., 
                    1.}}]; If[
                    Or[
                    Part[$CellContext`surfnorm$, 1] == {0., 0., 0.}, 
                    Part[$CellContext`surfnorm$, 2] == {0., 0., 0.}, 
                    Part[$CellContext`surfnorm$, 3] == {0., 0., 
                    0.}], $CellContext`surfnorm$ = 1. Re[{{1., 
                    Plus[0.16666666666666666` (1.*^-6 + $CellContext`ray2$)], 
                    
                    Plus[
                    0.16666666666666666` (
                    1.*^-6 + $CellContext`ray3$)]}, {(-0.16666666666666666`) (
                    1.*^-6 + $CellContext`ray2$), 1., 
                    0.}, {(-0.16666666666666666`) (
                    1.*^-6 + $CellContext`ray3$), 0., 1.}}]; 1., 
                    1.]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    4., 0, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; 
                    If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{I 0., I 0., I 0.}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    1.4992664079787135` - 
                    0.7232199521999264 $CellContext`wavelength$ + 
                    1.098444937228181 $CellContext`wavelength$^2 - 
                    0.5792106405031204 $CellContext`wavelength$^3; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    1.6765916828640575` - 
                    1.1701284013478312` $CellContext`wavelength$ + 
                    1.824530254455841 $CellContext`wavelength$^2 - 
                    0.9804493049167722 $CellContext`wavelength$^3; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    1.6765916828640575` - 
                    1.1701284013478312` $CellContext`wavelength$ + 
                    1.824530254455841 $CellContext`wavelength$^2 - 
                    0.9804493049167722 $CellContext`wavelength$^3], \
$CellContext`index2$ = 1.6765916828640575` - 
                    1.1701284013478312` $CellContext`wavelength$ + 
                    1.824530254455841 $CellContext`wavelength$^2 - 
                    0.9804493049167722 $CellContext`wavelength$^3; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    1.4992664079787135` - 
                    0.7232199521999264 $CellContext`wavelength$ + 
                    1.098444937228181 $CellContext`wavelength$^2 - 
                    0.5792106405031204 $CellContext`wavelength$^3; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    1.4992664079787135` - 
                    0.7232199521999264 $CellContext`wavelength$ + 
                    1.098444937228181 $CellContext`wavelength$^2 - 
                    0.5792106405031204 $CellContext`wavelength$^3]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    0., $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1.]; $CellContext`sinangle$ = 
                    1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$])); {
                    
                    First[$CellContext`allcreatedrays$], \
$CellContext`completedray$}, $CellContext`reporteddummyrayspresent$ = 
                    True; {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, CompressedData["
1:eJxTTMoPSmVkYGBQZ4CBD/YDRzdEmOSfPUicerh79+Og6eZuAGaoMiY=
                   
                     "]}], $CellContext`reporteddummyrayspresent$ = 
                  True; $CellContext`deflecteddummyrayspresent$ = 
                  True; CompressedData["
1:eJxTTMoPSmViYGAAYXUGGPhgP3B0Q4RJ/tmDxKmHu3c/DnoA/UFvemiGGwCy
wWJ9
                  "]])& , $CellContext`propagatedrays$]]; If[
             
             And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
              Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ]; 
             1., 1.]; If[
             
             And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
              Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 1.,
              1.]); (If[$CellContext`reportedrayspresent$, \
$CellContext`reportedrays$ = Join[$CellContext`reportedrays$, CompressedData["

1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                
                "], $CellContext`reportedlocalrays$]; 1., 
             1.]; $CellContext`propagatedrays$ = \
$CellContext`deflectedlocalrays$); $CellContext`raysreported$ = \
$CellContext`reportedrayspresent$; 1.); (
          AddTo[$CellContext`generationnumber$, 
            1.]; $CellContext`reportedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, 
              0, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`deflectedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; ($CellContext`deflectedrayspresent$ = 
            False; $CellContext`reportedrayspresent$ = 
            False; $CellContext`deflecteddummyrayspresent$ = 
            False; $CellContext`reporteddummyrayspresent$ = 
            False; {$CellContext`deflectedlocalrays$, \
$CellContext`reportedlocalrays$} = Transpose[
              
              Map[(({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                 Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                 Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                 Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                   2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -20.3203 + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                 Chop[$CellContext`rx$]; $CellContext`ry$ = 
                 Chop[$CellContext`ry$]; $CellContext`rz$ = 
                 Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                 False; $CellContext`intersections$ = {{-1., 0., 0.}}); 
               If[$CellContext`intensity$ > $CellContext`thresholdintensity$, \
$CellContext`deflectedrayspresent$ = 
                  True; ($CellContext`intersections$ = 
                   Block[{Compile`$171, Compile`$177, Compile`$178}, 
                    
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, 
                    Optica`Optica`TempVar3, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; 
                    Optica`Optica`TempVar1 = $CellContext`rx$^2 + \
$CellContext`ry$^2 + $CellContext`rz$^2; 
                    Optica`Optica`TempVar2 = $CellContext`rx$ \
$CellContext`xunit$ + $CellContext`ry$ $CellContext`yunit$ + $CellContext`rz$ \
$CellContext`zunit$ - (-12) $CellContext`xunit$; 
                    Optica`Optica`TempVar3 = -Optica`Optica`TempVar1 + 
                    Optica`Optica`TempVar2^2 + 2 $CellContext`rx$ (-12); 
                    Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; 
                    If[N[
                    Chop[Optica`Optica`TempVar3]] >= 0., 
                    Optica`Optica`TempVar3 = Sqrt[Optica`Optica`TempVar3]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = (
                    Compile`$171 = 
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3; {-Optica`Optica`TempVar2 - 
                    Optica`Optica`TempVar3, $CellContext`ry$ - 
                    Compile`$171 $CellContext`yunit$, $CellContext`rz$ - 
                    Compile`$171 $CellContext`zunit$}); If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    142.80249999999998`, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[12 + $CellContext`rx$ + $CellContext`LocRayL$ \
$CellContext`xunit$ - 
                    Sqrt[144 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = (Compile`$177 = -Optica`Optica`TempVar2; 
                    Compile`$178 = Compile`$177 + Optica`Optica`TempVar3; {
                    Compile`$178, $CellContext`ry$ + 
                    Compile`$178 $CellContext`yunit$, $CellContext`rz$ + 
                    Compile`$178 $CellContext`zunit$}); If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    142.80249999999998`, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[12 + $CellContext`rx$ + $CellContext`LocRayL$ \
$CellContext`xunit$ - 
                    Sqrt[144 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    If[Part[Optica`Optica`TempVar, 1] == 
                    Part[Optica`Optica`TempVar, 2], {
                    Part[Optica`Optica`TempVar, 1]}, 
                    Optica`Optica`TempVar], {{-1., 0., 0.}}]]]; 
                  AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 8348.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                  Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                  If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]); 
                 If[$CellContext`intersections$ != {{-1., 0., 
                    0.}}, $CellContext`intersectionspresent$ = 
                    True; ({$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 8., 
                    8348.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 8., 
                    8348.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    20.3203 + $CellContext`rxhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}); ($CellContext`reportedrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{
                    1., -(-$CellContext`ray2$/(
                    144 - $CellContext`ray2$^2 - $CellContext`ray3$^2)^(
                    2^(-1))), -(-$CellContext`ray3$/(
                    144 - $CellContext`ray2$^2 - $CellContext`ray3$^2)^(
                    2^(-1)))}, {-$CellContext`ray2$/(
                    144 - $CellContext`ray2$^2 - $CellContext`ray3$^2)^(
                    2^(-1)), 1., 
                    0.}, {-$CellContext`ray3$/(
                    144 - $CellContext`ray2$^2 - $CellContext`ray3$^2)^(
                    2^(-1)), 0., 1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    20.3203, 0, 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}})); {
                    
                    First[$CellContext`allcreatedrays$], \
$CellContext`completedray$}, $CellContext`reporteddummyrayspresent$ = 
                    True; {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, CompressedData["
1:eJxTTMoPSmVkYGBQZ4CBD/YDRzdEmOSfPUicerh79+Og6eZuAGaoMiY=
                   
                     "]}], $CellContext`reporteddummyrayspresent$ = 
                  True; $CellContext`deflecteddummyrayspresent$ = 
                  True; CompressedData["
1:eJxTTMoPSmViYGAAYXUGGPhgP3B0Q4RJ/tmDxKmHu3c/DnoA/UFvemiGGwCy
wWJ9
                  "]])& , $CellContext`propagatedrays$]]; If[
             
             And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
              Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ]; 
             1., 1.]; If[
             
             And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
              Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 1.,
              1.]); (If[$CellContext`reportedrayspresent$, \
$CellContext`reportedrays$ = Join[$CellContext`reportedrays$, CompressedData["

1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                
                "], $CellContext`reportedlocalrays$]; 1., 
             1.]; $CellContext`propagatedrays$ = \
$CellContext`deflectedlocalrays$); $CellContext`raysreported$ = \
$CellContext`reportedrayspresent$; 1.); (
          AddTo[$CellContext`generationnumber$, 
            1.]; $CellContext`reportedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, 
              0, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`deflectedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; ($CellContext`deflectedrayspresent$ = 
            False; $CellContext`reportedrayspresent$ = 
            False; $CellContext`deflecteddummyrayspresent$ = 
            False; $CellContext`reporteddummyrayspresent$ = 
            False; {$CellContext`deflectedlocalrays$, \
$CellContext`reportedlocalrays$} = Transpose[
              
              Map[(({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                 Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                 Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                 Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                   2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -4. + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                 Chop[$CellContext`rx$]; $CellContext`ry$ = 
                 Chop[$CellContext`ry$]; $CellContext`rz$ = 
                 Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                 False; $CellContext`intersections$ = {{-1., 0., 0.}}); 
               If[$CellContext`intensity$ > $CellContext`thresholdintensity$, \
$CellContext`deflectedrayspresent$ = 
                  True; ($CellContext`intersections$ = 
                   Block[{Compile`$121, Compile`$122, Compile`$126, 
                    Compile`$127, Compile`$128, Compile`$129, Compile`$134, 
                    Compile`$136, Compile`$137, Compile`$140, Compile`$141, 
                    Compile`$142, Compile`$145, Compile`$146, Compile`$147, 
                    Compile`$148, Compile`$149, Compile`$150, Compile`$154, 
                    Compile`$130, Compile`$131, Compile`$133, Compile`$158, 
                    Compile`$159, Compile`$160, Compile`$164, Compile`$165, 
                    Compile`$166}, 
                    
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 
                    1. + 0. I; $CellContext`LocSCx$ = 
                    1. + 0. I; $CellContext`LocSCy$ = 1. + 0. I; Re[
                    Select[
                    
                    If[$CellContext`yunit$^2 + $CellContext`zunit$^2 == 0., 
                    Compile`$121 = $CellContext`xunit$^2; 
                    Compile`$122 = 
                    Sqrt[Compile`$121]; {{-1. + 0. I, 0. + 0. I, 0. + 
                    0. I}, {((-0.08333333333333333) (
                    12. $CellContext`rx$ + $CellContext`ry$^2 + \
$CellContext`rz$^2) Compile`$122)/$CellContext`xunit$^2, ($CellContext`ry$ 
                    Compile`$122)/$CellContext`xunit$, $CellContext`rz$}}, 
                    Compile`$126 = $CellContext`yunit$^2; 
                    Compile`$127 = $CellContext`zunit$^2; 
                    Compile`$128 = Compile`$126 + Compile`$127; 
                    Compile`$129 = Compile`$128^(-1); 
                    Compile`$134 = $CellContext`xunit$^2; 
                    Compile`$136 = 36. Compile`$134; 
                    Compile`$137 = 
                    12. $CellContext`ry$ $CellContext`xunit$ \
$CellContext`yunit$; Compile`$140 = (-12.) $CellContext`rx$ Compile`$126; 
                    Compile`$141 = $CellContext`rz$^2; 
                    Compile`$142 = -Compile`$141 Compile`$126; 
                    Compile`$145 = 
                    12. $CellContext`rz$ $CellContext`xunit$ \
$CellContext`zunit$; Compile`$146 = 
                    2. $CellContext`ry$ $CellContext`rz$ $CellContext`yunit$ \
$CellContext`zunit$; Compile`$147 = (-12.) $CellContext`rx$ Compile`$127; 
                    Compile`$148 = $CellContext`ry$^2; 
                    Compile`$149 = -Compile`$148 Compile`$127; 
                    Compile`$150 = 
                    Compile`$136 + Compile`$137 + Compile`$140 + Compile`$142 + 
                    Compile`$145 + Compile`$146 + Compile`$147 + Compile`$149; 
                    Compile`$154 = Sqrt[Compile`$150]; 
                    Compile`$130 = (-6.) $CellContext`xunit$; 
                    Compile`$131 = -$CellContext`ry$ $CellContext`yunit$; 
                    Compile`$133 = -$CellContext`rz$ $CellContext`zunit$; 
                    Compile`$158 = (-6.) $CellContext`xunit$ \
$CellContext`yunit$; 
                    Compile`$159 = -$CellContext`rz$ $CellContext`yunit$ \
$CellContext`zunit$; Compile`$160 = $CellContext`ry$ Compile`$127; 
                    Compile`$164 = $CellContext`rz$ Compile`$126; 
                    Compile`$165 = (-6.) $CellContext`xunit$ \
$CellContext`zunit$; 
                    Compile`$166 = -$CellContext`ry$ $CellContext`yunit$ \
$CellContext`zunit$; {{-1. + 0. I, 0. + 0. I, 0. + 0. I}, {
                    Compile`$129 (Compile`$130 + Compile`$131 + Compile`$133 - 
                    1. Compile`$154), 
                    Compile`$129 (Compile`$158 + Compile`$159 + Compile`$160 - 
                    1. $CellContext`yunit$ Compile`$154), 
                    Compile`$129 (Compile`$164 + Compile`$165 + Compile`$166 - 
                    1. $CellContext`zunit$ Compile`$154)}, {
                    Compile`$129 (Compile`$130 + Compile`$131 + Compile`$133 + 
                    Compile`$154), 
                    Compile`$129 (Compile`$158 + Compile`$159 + 
                    Compile`$160 + $CellContext`yunit$ Compile`$154), 
                    Compile`$129 (Compile`$164 + Compile`$165 + 
                    Compile`$166 + $CellContext`zunit$ 
                    Compile`$154)}}], ({$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, 
                    And[Chop[
                    Im[#]] == {0, 0, 0}, N[
                    Chop[
                    Re[$CellContext`LocRayL$]]] >= 0., 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[$CellContext`rx$ + $CellContext`LocRayL$ \
$CellContext`xunit$ + ($CellContext`LocSCx$^2 + $CellContext`LocSCy$^2)/12] < 
                    1.*^-7, Re[$CellContext`LocSCx$]^2 + 
                    Re[$CellContext`LocSCy$]^2 <= 
                    31.922500000000003`]])& ]]]]; 
                  AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 8349.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                  Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                  If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]); 
                 If[$CellContext`intersections$ != {{-1., 0., 
                    0.}}, $CellContext`intersectionspresent$ = 
                    True; ({$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 9., 
                    
                    8349.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 9., 
                    8349.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    4. + $CellContext`rxhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}); ($CellContext`reportedrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 1. Re[{{1., 
                    Plus[0.16666666666666666` $CellContext`ray2$], 
                    Plus[
                    0.16666666666666666` $CellContext`ray3$]}, \
{(-0.16666666666666666`) $CellContext`ray2$, 1., 
                    0.}, {(-0.16666666666666666`) $CellContext`ray3$, 0., 
                    1.}}]; If[
                    Or[
                    Part[$CellContext`surfnorm$, 1] == {0., 0., 0.}, 
                    Part[$CellContext`surfnorm$, 2] == {0., 0., 0.}, 
                    Part[$CellContext`surfnorm$, 3] == {0., 0., 
                    0.}], $CellContext`surfnorm$ = 1. Re[{{1., 
                    Plus[0.16666666666666666` (1.*^-6 + $CellContext`ray2$)], 
                    
                    Plus[
                    0.16666666666666666` (
                    1.*^-6 + $CellContext`ray3$)]}, {(-0.16666666666666666`) (
                    1.*^-6 + $CellContext`ray2$), 1., 
                    0.}, {(-0.16666666666666666`) (
                    1.*^-6 + $CellContext`ray3$), 0., 1.}}]; 1., 
                    1.]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    4., 0, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; 
                    If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{I 0., I 0., I 0.}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    1.4992664079787135` - 
                    0.7232199521999264 $CellContext`wavelength$ + 
                    1.098444937228181 $CellContext`wavelength$^2 - 
                    0.5792106405031204 $CellContext`wavelength$^3; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    1.6765916828640575` - 
                    1.1701284013478312` $CellContext`wavelength$ + 
                    1.824530254455841 $CellContext`wavelength$^2 - 
                    0.9804493049167722 $CellContext`wavelength$^3; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    1.6765916828640575` - 
                    1.1701284013478312` $CellContext`wavelength$ + 
                    1.824530254455841 $CellContext`wavelength$^2 - 
                    0.9804493049167722 $CellContext`wavelength$^3], \
$CellContext`index2$ = 1.6765916828640575` - 
                    1.1701284013478312` $CellContext`wavelength$ + 
                    1.824530254455841 $CellContext`wavelength$^2 - 
                    0.9804493049167722 $CellContext`wavelength$^3; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    1.4992664079787135` - 
                    0.7232199521999264 $CellContext`wavelength$ + 
                    1.098444937228181 $CellContext`wavelength$^2 - 
                    0.5792106405031204 $CellContext`wavelength$^3; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    1.4992664079787135` - 
                    0.7232199521999264 $CellContext`wavelength$ + 
                    1.098444937228181 $CellContext`wavelength$^2 - 
                    0.5792106405031204 $CellContext`wavelength$^3]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    0., $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1.]; $CellContext`sinangle$ = 
                    1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$])); {
                    
                    First[$CellContext`allcreatedrays$], \
$CellContext`completedray$}, $CellContext`reporteddummyrayspresent$ = 
                    True; {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, CompressedData["
1:eJxTTMoPSmVkYGBQZ4CBD/YDRzdEmOSfPUicerh79+Og6eZuAGaoMiY=
                   
                     "]}], $CellContext`reporteddummyrayspresent$ = 
                  True; $CellContext`deflecteddummyrayspresent$ = 
                  True; CompressedData["
1:eJxTTMoPSmViYGAAYXUGGPhgP3B0Q4RJ/tmDxKmHu3c/DnoA/UFvemiGGwCy
wWJ9
                  "]])& , $CellContext`propagatedrays$]]; If[
             
             And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
              Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ]; 
             1., 1.]; If[
             
             And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
              Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 1.,
              1.]); (If[$CellContext`reportedrayspresent$, \
$CellContext`reportedrays$ = Join[$CellContext`reportedrays$, CompressedData["

1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                
                "], $CellContext`reportedlocalrays$]; 1., 
             1.]; $CellContext`propagatedrays$ = \
$CellContext`deflectedlocalrays$); $CellContext`raysreported$ = \
$CellContext`reportedrayspresent$; 1.); (
          AddTo[$CellContext`generationnumber$, 
            1.]; $CellContext`reportedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, 
              0, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`deflectedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; ($CellContext`deflectedrayspresent$ = 
            False; $CellContext`reportedrayspresent$ = 
            False; $CellContext`deflecteddummyrayspresent$ = 
            False; $CellContext`reporteddummyrayspresent$ = 
            False; {$CellContext`deflectedlocalrays$, \
$CellContext`reportedlocalrays$} = Transpose[
              
              Map[(({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                 Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                 Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                 Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                   2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                 Chop[$CellContext`rx$]; $CellContext`ry$ = 
                 Chop[$CellContext`ry$]; $CellContext`rz$ = 
                 Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                 False; $CellContext`intersections$ = {{-1., 0., 0.}}); 
               If[$CellContext`intensity$ > $CellContext`thresholdintensity$, \
$CellContext`deflectedrayspresent$ = 
                  True; ($CellContext`intersections$ = 
                   Block[{$CellContext`surfaceapprox, \
$CellContext`tempapprox, $CellContext`intersects, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, $CellContext`LocRayL$ = 
                    1.; $CellContext`LocSCx$ = 1.; $CellContext`LocSCy$ = 
                    1.; $CellContext`surfaceapprox = {{-1., 0., 
                    0.}}; $CellContext`tempapprox = {{-1., 0., 
                    0.}}; $CellContext`intersects = {{-1., 0., 
                    0.}}; $CellContext`surfaceapprox = 
                    Block[{Compile`$135, Compile`$143, Compile`$144}, 
                    
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, 
                    Optica`Optica`TempVar3, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; 
                    Optica`Optica`TempVar1 = $CellContext`rx$^2 + \
$CellContext`ry$^2 + $CellContext`rz$^2; 
                    Optica`Optica`TempVar2 = $CellContext`rx$ \
$CellContext`xunit$ + $CellContext`ry$ $CellContext`yunit$ + $CellContext`rz$ \
$CellContext`zunit$ - 10.2 $CellContext`xunit$; 
                    Optica`Optica`TempVar3 = -Optica`Optica`TempVar1 + 
                    Optica`Optica`TempVar2^2 + 2 $CellContext`rx$ 10.2; 
                    Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; 
                    If[N[
                    Chop[Optica`Optica`TempVar3]] >= 0., 
                    Optica`Optica`TempVar3 = Sqrt[Optica`Optica`TempVar3]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = (
                    Compile`$135 = Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3; {-Optica`Optica`TempVar2 - 
                    Optica`Optica`TempVar3, $CellContext`ry$ - 
                    Compile`$135 $CellContext`yunit$, $CellContext`rz$ - 
                    Compile`$135 $CellContext`zunit$}); If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    31.922500000000003`, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-10.2 + $CellContext`rx$ + $CellContext`LocRayL$ \
$CellContext`xunit$ + 
                    Sqrt[104.03999999999999` - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = (Compile`$143 = -Optica`Optica`TempVar2; 
                    Compile`$144 = Compile`$143 + Optica`Optica`TempVar3; {
                    Compile`$144, $CellContext`ry$ + 
                    Compile`$144 $CellContext`yunit$, $CellContext`rz$ + 
                    Compile`$144 $CellContext`zunit$}); If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    31.922500000000003`, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-10.2 + $CellContext`rx$ + $CellContext`LocRayL$ \
$CellContext`xunit$ + 
                    Sqrt[104.03999999999999` - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    If[Part[Optica`Optica`TempVar, 1] == 
                    Part[Optica`Optica`TempVar, 2], {
                    Part[Optica`Optica`TempVar, 1]}, 
                    Optica`Optica`TempVar], {{-1., 0., 
                    0.}}]]]; $CellContext`tempapprox = Union[
                    Join[
                    Map[Take[#, 3]& , $CellContext`surfaceapprox], {{-1., 0., 
                    0.}}]]; If[Length[
                    Select[$CellContext`tempapprox, Chop[
                    First[#]] <= 0& ]] != 
                    Length[$CellContext`tempapprox], \
$CellContext`surfaceapprox = Select[$CellContext`tempapprox, Chop[
                    First[#]] > 0& ], $CellContext`surfaceapprox = {{-1., 0., 
                    0.}}]; If[$CellContext`surfaceapprox != {{-1., 0., 
                    0.}}, $CellContext`intersects = {{-1., 0., 0.}}; 
                    Scan[(AppendTo[$CellContext`intersects, \
{$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}; If[Apply[Plus, 
                    
                    Abs[{$CellContext`rx$ + $CellContext`LocRayL$ \
$CellContext`xunit$, $CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$, $CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$} - {(
                    0.09803921568627452 ($CellContext`LocSCx$^2 + \
$CellContext`LocSCy$^2))/(1 + Sqrt[
                    1 + 0.020488273740868906` ($CellContext`LocSCx$^2 + \
$CellContext`LocSCy$^2)]), $CellContext`LocSCx$, $CellContext`LocSCy$}]] < 
                    1.*^-9, {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 0.99 $CellContext`LocRayL$; 
                    Function[{$CellContext`rx, $CellContext`ry, \
$CellContext`rz, $CellContext`xunit, $CellContext`yunit, $CellContext`zunit, \
$CellContext`startpoint}, 
                    
                    Block[{$CellContext`values, $CellContext`stepsizes, \
$CellContext`fvector, $CellContext`success, $CellContext`steps, \
$CellContext`denominator}, $CellContext`values = {
                    1.}; $CellContext`stepsizes = {
                    1.}; $CellContext`fvector = {1.}; $CellContext`success = 
                    False; $CellContext`steps = 0; $CellContext`denominator = 
                    1.; $CellContext`stepsizes = 
                    Table[1.0000000000000001`*^-7, {
                    3}]; $CellContext`values = $CellContext`startpoint; 
                    While[
                    
                    And[$CellContext`steps < 50, $CellContext`success = True; 
                    Map[If[Abs[#] > 1.*^-9, $CellContext`success = False; 1., 
                    1.]& , $CellContext`stepsizes]; 
                    Not[$CellContext`success]], $CellContext`steps = \
$CellContext`steps + 
                    1; $CellContext`fvector = {$CellContext`rx + \
$CellContext`xunit Part[$CellContext`values, 
                    1], $CellContext`ry + $CellContext`yunit 
                    Part[$CellContext`values, 
                    1], $CellContext`rz + $CellContext`zunit 
                    Part[$CellContext`values, 1]} - {(
                    0.09803921568627452 (Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2))/(1 + 
                    Sqrt[1 + 0.020488273740868906` (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2)]), 
                    Part[$CellContext`values, 2], 
                    
                    Part[$CellContext`values, 
                    3]}; $CellContext`denominator = $CellContext`xunit - \
$CellContext`yunit (((0.002008654288320481 
                    Part[$CellContext`values, 2] (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2))/(
                    Sqrt[1 + 0.020488273740868906` (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2)] (1 + 
                    Sqrt[1 + 0.020488273740868906` (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2)])^2) - (
                    0.19607843137254904` Part[$CellContext`values, 2])/(1 + 
                    Sqrt[1 + 0.020488273740868906` (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 
                    3]^2)])) (-1)) - $CellContext`zunit (((
                    0.002008654288320481 
                    Part[$CellContext`values, 3] (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2))/(
                    Sqrt[1 + 0.020488273740868906` (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2)] (1 + 
                    Sqrt[1 + 0.020488273740868906` (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2)])^2) - (
                    0.19607843137254904` Part[$CellContext`values, 3])/(1 + 
                    Sqrt[1 + 0.020488273740868906` (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2)])) (-1)); 
                    If[Chop[$CellContext`denominator] != 
                    0, $CellContext`denominator, $CellContext`denominator = 
                    1.]; $CellContext`stepsizes = -
                    Map[Dot[#, $CellContext`fvector]& , {{
                    1, -(((0.002008654288320481 
                    Part[$CellContext`values, 2] (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2))/(
                    Sqrt[1 + 0.020488273740868906` (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2)] (1 + 
                    Sqrt[1 + 0.020488273740868906` (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2)])^2) - (
                    0.19607843137254904` Part[$CellContext`values, 2])/(1 + 
                    Sqrt[1 + 0.020488273740868906` (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2)])) (-1)), -(((
                    0.002008654288320481 Part[$CellContext`values, 3] (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2))/(
                    Sqrt[1 + 0.020488273740868906` (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2)] (1 + 
                    Sqrt[1 + 0.020488273740868906` (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2)])^2) - (
                    0.19607843137254904` Part[$CellContext`values, 3])/(1 + 
                    Sqrt[1 + 0.020488273740868906` (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 
                    3]^2)])) (-1))}, {$CellContext`yunit, -$CellContext`xunit - \
((0.002008654288320481 Part[$CellContext`values, 3] (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2))/(
                    Sqrt[1 + 0.020488273740868906` (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2)] (1 + 
                    Sqrt[1 + 0.020488273740868906` (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2)])^2) - (
                    0.19607843137254904` Part[$CellContext`values, 3])/(1 + 
                    Sqrt[1 + 0.020488273740868906` (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2)])) $CellContext`zunit, ((
                    0.002008654288320481 Part[$CellContext`values, 3] (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2))/(
                    Sqrt[1 + 0.020488273740868906` (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2)] (1 + 
                    Sqrt[1 + 0.020488273740868906` (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2)])^2) - (
                    0.19607843137254904` Part[$CellContext`values, 3])/(1 + 
                    Sqrt[1 + 0.020488273740868906` (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 
                    3]^2)])) $CellContext`yunit}, {$CellContext`zunit, ((
                    0.002008654288320481 Part[$CellContext`values, 2] (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2))/(
                    Sqrt[1 + 0.020488273740868906` (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2)] (1 + 
                    Sqrt[1 + 0.020488273740868906` (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2)])^2) - (
                    0.19607843137254904` Part[$CellContext`values, 2])/(1 + 
                    Sqrt[1 + 0.020488273740868906` (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 
                    3]^2)])) $CellContext`zunit, -$CellContext`xunit - ((
                    0.002008654288320481 Part[$CellContext`values, 2] (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2))/(
                    Sqrt[1 + 0.020488273740868906` (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2)] (1 + 
                    Sqrt[1 + 0.020488273740868906` (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 3]^2)])^2) - (
                    0.19607843137254904` Part[$CellContext`values, 2])/(1 + 
                    Sqrt[1 + 0.020488273740868906` (
                    Part[$CellContext`values, 2]^2 + 
                    Part[$CellContext`values, 
                    3]^2)])) $CellContext`yunit}}/$CellContext`denominator]; \
$CellContext`values = $CellContext`values + $CellContext`stepsizes]; 
                    If[$CellContext`steps >= 50, 
                    If[First[$CellContext`values] > 
                    0, $CellContext`values = -$CellContext`values; 1., 
                    1.]; $CellContext`denominator = 1., 
                    1.]; $CellContext`values]][$CellContext`rx$, \
$CellContext`ry$, $CellContext`rz$, $CellContext`xunit$, $CellContext`yunit$, \
$CellContext`zunit$, {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}]]]; {-1., 0., 0.})& , $CellContext`surfaceapprox]; Union[
                    Re[
                    
                    Select[$CellContext`intersects, ({$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, 
                    And[Chop[
                    Im[#]] == {0, 0, 0}, N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    31.922500000000003`, Apply[Plus, 
                    
                    Abs[{$CellContext`rx$ + $CellContext`LocRayL$ \
$CellContext`xunit$, $CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$, $CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$} - {(
                    0.09803921568627452 ($CellContext`LocSCx$^2 + \
$CellContext`LocSCy$^2))/(1 + Sqrt[
                    1 + 0.020488273740868906` ($CellContext`LocSCx$^2 + \
$CellContext`LocSCy$^2)]), $CellContext`LocSCx$, $CellContext`LocSCy$}]] < 
                    1.*^-9]])& ]]], {{-1., 0., 0.}}]]; 
                  AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 8350.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                  Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                  If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]); 
                 If[$CellContext`intersections$ != {{-1., 0., 
                    0.}}, $CellContext`intersectionspresent$ = 
                    True; ({$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 10., 
                    8350.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 10., 
                    8350.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
$CellContext`rxhlp$; $CellContext`rey$ = $CellContext`ryhlp$; \
$CellContext`rez$ = $CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}); ($CellContext`reportedrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{
                    1., (0.002008654288320481 $CellContext`ray2$^3)/(
                    Sqrt[1. + 
                    0.020488273740868906` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)] (1. + Sqrt[
                    1. + 0.020488273740868906` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)])^2) + (
                    0.002008654288320481 $CellContext`ray2$ \
$CellContext`ray3$^2)/(Sqrt[1. + 
                    0.020488273740868906` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)] (1. + Sqrt[
                    1. + 0.020488273740868906` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)])^2) - (0.19607843137254904` $CellContext`ray2$)/(1. + 
                    Sqrt[1. + 
                    0.020488273740868906` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)]), (
                    0.002008654288320481 $CellContext`ray2$^2 \
$CellContext`ray3$)/(Sqrt[1. + 
                    0.020488273740868906` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)] (1. + Sqrt[
                    1. + 0.020488273740868906` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)])^2) + (0.002008654288320481 $CellContext`ray3$^3)/(
                    Sqrt[1. + 
                    0.020488273740868906` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)] (1. + Sqrt[
                    1. + 0.020488273740868906` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)])^2) - (0.19607843137254904` $CellContext`ray3$)/(1. + 
                    Sqrt[1. + 
                    0.020488273740868906` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)])}, {((-0.002008654288320481) $CellContext`ray2$ \
($CellContext`ray2$^2 + $CellContext`ray3$^2))/(
                    Sqrt[1. + 
                    0.020488273740868906` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)] (1. + Sqrt[
                    1. + 0.020488273740868906` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)])^2) + (0.19607843137254904` $CellContext`ray2$)/(1. + 
                    Sqrt[1. + 
                    0.020488273740868906` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)]), 1., 
                    0.}, {((-0.002008654288320481) $CellContext`ray3$ \
($CellContext`ray2$^2 + $CellContext`ray3$^2))/(
                    Sqrt[1. + 
                    0.020488273740868906` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)] (1. + Sqrt[
                    1. + 0.020488273740868906` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)])^2) + (0.19607843137254904` $CellContext`ray3$)/(1. + 
                    Sqrt[1. + 
                    0.020488273740868906` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)]), 0., 1.}}]; If[
                    Or[
                    Part[$CellContext`surfnorm$, 1] == {0., 0., 0.}, 
                    Part[$CellContext`surfnorm$, 2] == {0., 0., 0.}, 
                    Part[$CellContext`surfnorm$, 3] == {0., 0., 
                    0.}], $CellContext`surfnorm$ = 
                    1. Re[{{1., (
                    0.002008654288320481 (1.*^-6 + $CellContext`ray2$)^3)/(
                    Sqrt[1. + 0.020488273740868906` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)] (1. + 
                    Sqrt[1. + 0.020488273740868906` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)])^2) + (
                    0.002008654288320481 (
                    1.*^-6 + $CellContext`ray2$) (
                    1.*^-6 + $CellContext`ray3$)^2)/(
                    Sqrt[1. + 0.020488273740868906` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)] (1. + 
                    Sqrt[1. + 0.020488273740868906` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)])^2) - (
                    0.19607843137254904` (1.*^-6 + $CellContext`ray2$))/(1. + 
                    Sqrt[1. + 0.020488273740868906` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)]), (
                    0.002008654288320481 (1.*^-6 + $CellContext`ray2$)^2 (
                    1.*^-6 + $CellContext`ray3$))/(
                    Sqrt[1. + 0.020488273740868906` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)] (1. + 
                    Sqrt[1. + 0.020488273740868906` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)])^2) + (
                    0.002008654288320481 (1.*^-6 + $CellContext`ray3$)^3)/(
                    Sqrt[1. + 0.020488273740868906` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)] (1. + 
                    Sqrt[1. + 0.020488273740868906` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)])^2) - (
                    0.19607843137254904` (1.*^-6 + $CellContext`ray3$))/(1. + 
                    Sqrt[1. + 0.020488273740868906` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)])}, \
{((-0.002008654288320481) (1.*^-6 + $CellContext`ray2$) ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2))/(
                    Sqrt[1. + 0.020488273740868906` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)] (1. + 
                    Sqrt[1. + 0.020488273740868906` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)])^2) + (
                    0.19607843137254904` (1.*^-6 + $CellContext`ray2$))/(1. + 
                    Sqrt[1. + 0.020488273740868906` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)]), 1., 
                    0.}, {((-0.002008654288320481) (
                    1.*^-6 + $CellContext`ray3$) ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2))/(
                    Sqrt[1. + 0.020488273740868906` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)] (1. + 
                    Sqrt[1. + 0.020488273740868906` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)])^2) + (
                    0.19607843137254904` (1.*^-6 + $CellContext`ray3$))/(1. + 
                    Sqrt[1. + 0.020488273740868906` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)]), 0., 1.}}]; 1., 
                    1.]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1, 0, 0}, {0, 1, 0}, {0, 0, 
                    1}}; $CellContext`surfacetranslationvector$ = {0, 0, 
                    0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; 
                    If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{I 0., I 0., I 0.}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    1.6765916828640575` - 
                    1.1701284013478312` $CellContext`wavelength$ + 
                    1.824530254455841 $CellContext`wavelength$^2 - 
                    0.9804493049167722 $CellContext`wavelength$^3; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    1.553268208581225 - 
                    1.0054245500499506` $CellContext`wavelength$ + 
                    1.6027810806802931` $CellContext`wavelength$^2 - 
                    0.8794405514295299 $CellContext`wavelength$^3; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    1.553268208581225 - 
                    1.0054245500499506` $CellContext`wavelength$ + 
                    1.6027810806802931` $CellContext`wavelength$^2 - 
                    0.8794405514295299 $CellContext`wavelength$^3], \
$CellContext`index2$ = 1.553268208581225 - 
                    1.0054245500499506` $CellContext`wavelength$ + 
                    1.6027810806802931` $CellContext`wavelength$^2 - 
                    0.8794405514295299 $CellContext`wavelength$^3; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    1.6765916828640575` - 
                    1.1701284013478312` $CellContext`wavelength$ + 
                    1.824530254455841 $CellContext`wavelength$^2 - 
                    0.9804493049167722 $CellContext`wavelength$^3; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    1.6765916828640575` - 
                    1.1701284013478312` $CellContext`wavelength$ + 
                    1.824530254455841 $CellContext`wavelength$^2 - 
                    0.9804493049167722 $CellContext`wavelength$^3]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    0., $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1.]; $CellContext`sinangle$ = 
                    1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$])); {
                    
                    First[$CellContext`allcreatedrays$], \
$CellContext`completedray$}, $CellContext`reporteddummyrayspresent$ = 
                    True; {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, CompressedData["
1:eJxTTMoPSmVkYGBQZ4CBD/YDRzdEmOSfPUicerh79+Og6eZuAGaoMiY=
                   
                     "]}], $CellContext`reporteddummyrayspresent$ = 
                  True; $CellContext`deflecteddummyrayspresent$ = 
                  True; CompressedData["
1:eJxTTMoPSmViYGAAYXUGGPhgP3B0Q4RJ/tmDxKmHu3c/DnoA/UFvemiGGwCy
wWJ9
                  "]])& , $CellContext`propagatedrays$]]; If[
             
             And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
              Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ]; 
             1., 1.]; If[
             
             And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
              Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 1.,
              1.]); (If[$CellContext`reportedrayspresent$, \
$CellContext`reportedrays$ = Join[$CellContext`reportedrays$, CompressedData["

1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                
                "], $CellContext`reportedlocalrays$]; 1., 
             1.]; $CellContext`propagatedrays$ = \
$CellContext`deflectedlocalrays$); $CellContext`raysreported$ = \
$CellContext`reportedrayspresent$; 1.); (
          AddTo[$CellContext`generationnumber$, 
            1.]; $CellContext`reportedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, 
              0, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`deflectedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; ($CellContext`deflectedrayspresent$ = 
            False; $CellContext`reportedrayspresent$ = 
            False; $CellContext`deflecteddummyrayspresent$ = 
            False; $CellContext`reporteddummyrayspresent$ = 
            False; {$CellContext`deflectedlocalrays$, \
$CellContext`reportedlocalrays$} = Transpose[
              
              Map[(({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                 Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                 Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                 Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                   2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                 Chop[$CellContext`rx$]; $CellContext`ry$ = 
                 Chop[$CellContext`ry$]; $CellContext`rz$ = 
                 Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                 False; $CellContext`intersections$ = {{-1., 0., 0.}}); 
               If[$CellContext`intensity$ > $CellContext`thresholdintensity$, \
$CellContext`deflectedrayspresent$ = 
                  True; ($CellContext`intersections$ = Block[{Compile`$107}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., Part[#, 2]^2 + Part[#, 3]^2 <= 
                    32.56414225], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$107 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$107), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$107, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$107}]}, {{-1., 0., 0.}}]]; 
                  AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 8351.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                  Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                  If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; $CellContext`intersections$ = Union[
                    Map[
                    If[Part[#, 2]^2 + Part[#, 3]^2 <= 
                    31.287242250000006`, $CellContext`holeQ$ = True; {-1., 0.,
                     0.}, #]& , $CellContext`unfilteredintersections$]]; 
                  If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]); 
                 If[$CellContext`intersections$ != {{-1., 0., 
                    0.}}, $CellContext`intersectionspresent$ = 
                    True; ({$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 11., 
                    8351.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 11., 
                    8351.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
$CellContext`rxhlp$; $CellContext`rey$ = $CellContext`ryhlp$; \
$CellContext`rez$ = $CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}); ($CellContext`reportedrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1, 0, 0}, {0, 1, 0}, {0, 0, 
                    1}}; $CellContext`surfacetranslationvector$ = {0, 0, 
                    0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}})); {
                    
                    First[$CellContext`allcreatedrays$], \
$CellContext`completedray$}, $CellContext`reporteddummyrayspresent$ = 
                    True; {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, CompressedData["
1:eJxTTMoPSmVkYGBQZ4CBD/YDRzdEmOSfPUicerh79+Og6eZuAGaoMiY=
                   
                     "]}], $CellContext`reporteddummyrayspresent$ = 
                  True; $CellContext`deflecteddummyrayspresent$ = 
                  True; CompressedData["
1:eJxTTMoPSmViYGAAYXUGGPhgP3B0Q4RJ/tmDxKmHu3c/DnoA/UFvemiGGwCy
wWJ9
                  "]])& , $CellContext`propagatedrays$]]; If[
             
             And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
              Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ]; 
             1., 1.]; If[
             
             And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
              Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 1.,
              1.]); (If[$CellContext`reportedrayspresent$, \
$CellContext`reportedrays$ = Join[$CellContext`reportedrays$, CompressedData["

1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                
                "], $CellContext`reportedlocalrays$]; 1., 
             1.]; $CellContext`propagatedrays$ = \
$CellContext`deflectedlocalrays$); $CellContext`raysreported$ = \
$CellContext`reportedrayspresent$; 1.); (
          AddTo[$CellContext`generationnumber$, 
            1.]; $CellContext`reportedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, 
              0, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`deflectedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; ($CellContext`deflectedrayspresent$ = 
            False; $CellContext`reportedrayspresent$ = 
            False; $CellContext`deflecteddummyrayspresent$ = 
            False; $CellContext`reporteddummyrayspresent$ = 
            False; {$CellContext`deflectedlocalrays$, \
$CellContext`reportedlocalrays$} = Transpose[
              
              Map[(({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                 Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                 Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                 Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                   2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                 0.05 + $CellContext`rex$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                 Chop[$CellContext`rx$]; $CellContext`ry$ = 
                 Chop[$CellContext`ry$]; $CellContext`rz$ = 
                 Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                 False; $CellContext`intersections$ = {{-1., 0., 0.}}); 
               If[$CellContext`intensity$ > $CellContext`thresholdintensity$, \
$CellContext`deflectedrayspresent$ = 
                  True; ($CellContext`intersections$ = Block[{Compile`$95}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., Part[#, 2]^2 + Part[#, 3]^2 <= 6.25], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$95 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$95), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$95, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$95}]}, {{-1., 0., 0.}}]]; 
                  AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 8352.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                  Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                  If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]); 
                 If[$CellContext`intersections$ != {{-1., 0., 
                    0.}}, $CellContext`intersectionspresent$ = 
                    True; ({$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 12., 
                    8352.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 12., 
                    8352.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
-0.05 + $CellContext`rxhlp$; $CellContext`rey$ = $CellContext`ryhlp$; \
$CellContext`rez$ = $CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}); ($CellContext`reportedrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {-0.05, 0, 
                    0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}})); {
                    
                    First[$CellContext`allcreatedrays$], \
$CellContext`completedray$}, $CellContext`reporteddummyrayspresent$ = 
                    True; {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, CompressedData["
1:eJxTTMoPSmVkYGBQZ4CBD/YDRzdEmOSfPUicerh79+Og6eZuAGaoMiY=
                   
                     "]}], $CellContext`reporteddummyrayspresent$ = 
                  True; $CellContext`deflecteddummyrayspresent$ = 
                  True; CompressedData["
1:eJxTTMoPSmViYGAAYXUGGPhgP3B0Q4RJ/tmDxKmHu3c/DnoA/UFvemiGGwCy
wWJ9
                  "]])& , $CellContext`propagatedrays$]]; If[
             
             And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
              Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ]; 
             1., 1.]; If[
             
             And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
              Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 1.,
              1.]); (If[$CellContext`reportedrayspresent$, \
$CellContext`reportedrays$ = Join[$CellContext`reportedrays$, CompressedData["

1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                
                "], $CellContext`reportedlocalrays$]; 1., 
             1.]; $CellContext`propagatedrays$ = \
$CellContext`deflectedlocalrays$); $CellContext`raysreported$ = \
$CellContext`reportedrayspresent$; 1.); (
          AddTo[$CellContext`generationnumber$, 
            1.]; $CellContext`reportedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, 
              0, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`deflectedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; ($CellContext`deflectedrayspresent$ = 
            False; $CellContext`reportedrayspresent$ = 
            False; $CellContext`deflecteddummyrayspresent$ = 
            False; $CellContext`reporteddummyrayspresent$ = 
            False; {$CellContext`deflectedlocalrays$, \
$CellContext`reportedlocalrays$} = Transpose[
              
              Map[(({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                 Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                 Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                 Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                   2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                 0.05 + $CellContext`rex$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                 Chop[$CellContext`rx$]; $CellContext`ry$ = 
                 Chop[$CellContext`ry$]; $CellContext`rz$ = 
                 Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                 False; $CellContext`intersections$ = {{-1., 0., 0.}}); 
               If[$CellContext`intensity$ > $CellContext`thresholdintensity$, \
$CellContext`deflectedrayspresent$ = 
                  True; ($CellContext`intersections$ = Block[{Compile`$96}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., Part[#, 2]^2 + Part[#, 3]^2 <= 25.], {
                    
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$96 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$96), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$96, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$96}]}, {{-1., 0., 0.}}]]; 
                  AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 8353.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                  Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                  If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; $CellContext`intersections$ = Union[
                    Map[
                    If[Part[#, 2]^2 + Part[#, 3]^2 <= 
                    6.25, $CellContext`holeQ$ = True; {-1., 0., 
                    0.}, #]& , $CellContext`unfilteredintersections$]]; 
                  If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]); 
                 If[$CellContext`intersections$ != {{-1., 0., 
                    0.}}, $CellContext`intersectionspresent$ = 
                    True; ({$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 13., 
                    8353.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 13., 
                    8353.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
-0.05 + $CellContext`rxhlp$; $CellContext`rey$ = $CellContext`ryhlp$; \
$CellContext`rez$ = $CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}); ($CellContext`reportedrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {-0.05, 0, 
                    0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}})); {
                    
                    First[$CellContext`allcreatedrays$], \
$CellContext`completedray$}, $CellContext`reporteddummyrayspresent$ = 
                    True; {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, CompressedData["
1:eJxTTMoPSmVkYGBQZ4CBD/YDRzdEmOSfPUicerh79+Og6eZuAGaoMiY=
                   
                     "]}], $CellContext`reporteddummyrayspresent$ = 
                  True; $CellContext`deflecteddummyrayspresent$ = 
                  True; CompressedData["
1:eJxTTMoPSmViYGAAYXUGGPhgP3B0Q4RJ/tmDxKmHu3c/DnoA/UFvemiGGwCy
wWJ9
                  "]])& , $CellContext`propagatedrays$]]; If[
             
             And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
              Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ]; 
             1., 1.]; If[
             
             And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
              Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 1.,
              1.]); (If[$CellContext`reportedrayspresent$, \
$CellContext`reportedrays$ = Join[$CellContext`reportedrays$, CompressedData["

1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                
                "], $CellContext`reportedlocalrays$]; 1., 
             1.]; $CellContext`propagatedrays$ = \
$CellContext`deflectedlocalrays$); $CellContext`raysreported$ = \
$CellContext`reportedrayspresent$; 1.); (
          AddTo[$CellContext`generationnumber$, 
            1.]; $CellContext`reportedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, 
              0, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`deflectedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; ($CellContext`deflectedrayspresent$ = 
            False; $CellContext`reportedrayspresent$ = 
            False; $CellContext`deflecteddummyrayspresent$ = 
            False; $CellContext`reporteddummyrayspresent$ = 
            False; {$CellContext`deflectedlocalrays$, \
$CellContext`reportedlocalrays$} = Transpose[
              
              Map[(({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                 Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                 Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                 Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                   2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                 3.05 + $CellContext`rex$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                 Chop[$CellContext`rx$]; $CellContext`ry$ = 
                 Chop[$CellContext`ry$]; $CellContext`rz$ = 
                 Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                 False; $CellContext`intersections$ = {{-1., 0., 0.}}); 
               If[$CellContext`intensity$ > $CellContext`thresholdintensity$, \
$CellContext`deflectedrayspresent$ = 
                  True; ($CellContext`intersections$ = 
                   Block[{Compile`$132, Compile`$138, Compile`$139}, 
                    
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, 
                    Optica`Optica`TempVar3, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; 
                    Optica`Optica`TempVar1 = $CellContext`rx$^2 + \
$CellContext`ry$^2 + $CellContext`rz$^2; 
                    Optica`Optica`TempVar2 = $CellContext`rx$ \
$CellContext`xunit$ + $CellContext`ry$ $CellContext`yunit$ + $CellContext`rz$ \
$CellContext`zunit$ - 6.5 $CellContext`xunit$; 
                    Optica`Optica`TempVar3 = -Optica`Optica`TempVar1 + 
                    Optica`Optica`TempVar2^2 + 2 $CellContext`rx$ 6.5; 
                    Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; 
                    If[N[
                    Chop[Optica`Optica`TempVar3]] >= 0., 
                    Optica`Optica`TempVar3 = Sqrt[Optica`Optica`TempVar3]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = (
                    Compile`$132 = 
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3; {-Optica`Optica`TempVar2 - 
                    Optica`Optica`TempVar3, $CellContext`ry$ - 
                    Compile`$132 $CellContext`yunit$, $CellContext`rz$ - 
                    Compile`$132 $CellContext`zunit$}); If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    25., Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-6.5 + $CellContext`rx$ + $CellContext`LocRayL$ \
$CellContext`xunit$ + 
                    Sqrt[42.25 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = (Compile`$138 = -Optica`Optica`TempVar2; 
                    Compile`$139 = Compile`$138 + Optica`Optica`TempVar3; {
                    Compile`$139, $CellContext`ry$ + 
                    Compile`$139 $CellContext`yunit$, $CellContext`rz$ + 
                    Compile`$139 $CellContext`zunit$}); If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    25., Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-6.5 + $CellContext`rx$ + $CellContext`LocRayL$ \
$CellContext`xunit$ + 
                    Sqrt[42.25 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    If[Part[Optica`Optica`TempVar, 1] == 
                    Part[Optica`Optica`TempVar, 2], {
                    Part[Optica`Optica`TempVar, 1]}, 
                    Optica`Optica`TempVar], {{-1., 0., 0.}}]]]; 
                  AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 8354.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                  Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                  If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]); 
                 If[$CellContext`intersections$ != {{-1., 0., 
                    0.}}, $CellContext`intersectionspresent$ = 
                    True; ({$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 14., 
                    8354.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 14., 
                    8354.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
-3.05 + $CellContext`rxhlp$; $CellContext`rey$ = $CellContext`ryhlp$; \
$CellContext`rez$ = $CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}); ($CellContext`reportedrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{
                    1., -($CellContext`ray2$/(
                    42.25 - $CellContext`ray2$^2 - $CellContext`ray3$^2)^(
                    2^(-1))), -($CellContext`ray3$/(
                    42.25 - $CellContext`ray2$^2 - $CellContext`ray3$^2)^(
                    2^(-1)))}, {$CellContext`ray2$/(
                    42.25 - $CellContext`ray2$^2 - $CellContext`ray3$^2)^(
                    2^(-1)), 1., 
                    0.}, {$CellContext`ray3$/(
                    42.25 - $CellContext`ray2$^2 - $CellContext`ray3$^2)^(
                    2^(-1)), 0., 1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {-3.05, 0, 
                    0}; $CellContext`activeregion$ = 
                    
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; 
                    If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{I 0., I 0., I 0.}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    1.553268208581225 - 
                    1.0054245500499506` $CellContext`wavelength$ + 
                    1.6027810806802931` $CellContext`wavelength$^2 - 
                    0.8794405514295299 $CellContext`wavelength$^3; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    1.5392664079785883` - 
                    0.723219952199223 $CellContext`wavelength$ + 
                    1.098444937226872 $CellContext`wavelength$^2 - 
                    0.5792106405023153 $CellContext`wavelength$^3; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    1.5392664079785883` - 
                    0.723219952199223 $CellContext`wavelength$ + 
                    1.098444937226872 $CellContext`wavelength$^2 - 
                    0.5792106405023153 $CellContext`wavelength$^3], \
$CellContext`index2$ = 1.5392664079785883` - 
                    0.723219952199223 $CellContext`wavelength$ + 
                    1.098444937226872 $CellContext`wavelength$^2 - 
                    0.5792106405023153 $CellContext`wavelength$^3; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    1.553268208581225 - 
                    1.0054245500499506` $CellContext`wavelength$ + 
                    1.6027810806802931` $CellContext`wavelength$^2 - 
                    0.8794405514295299 $CellContext`wavelength$^3; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    1.553268208581225 - 
                    1.0054245500499506` $CellContext`wavelength$ + 
                    1.6027810806802931` $CellContext`wavelength$^2 - 
                    0.8794405514295299 $CellContext`wavelength$^3]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    0., $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1.]; $CellContext`sinangle$ = 
                    1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$])); {
                    
                    First[$CellContext`allcreatedrays$], \
$CellContext`completedray$}, $CellContext`reporteddummyrayspresent$ = 
                    True; {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, CompressedData["
1:eJxTTMoPSmVkYGBQZ4CBD/YDRzdEmOSfPUicerh79+Og6eZuAGaoMiY=
                   
                     "]}], $CellContext`reporteddummyrayspresent$ = 
                  True; $CellContext`deflecteddummyrayspresent$ = 
                  True; CompressedData["
1:eJxTTMoPSmViYGAAYXUGGPhgP3B0Q4RJ/tmDxKmHu3c/DnoA/UFvemiGGwCy
wWJ9
                  "]])& , $CellContext`propagatedrays$]]; If[
             
             And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
              Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ]; 
             1., 1.]; If[
             
             And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
              Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 1.,
              1.]); (If[$CellContext`reportedrayspresent$, \
$CellContext`reportedrays$ = Join[$CellContext`reportedrays$, CompressedData["

1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                
                "], $CellContext`reportedlocalrays$]; 1., 
             1.]; $CellContext`propagatedrays$ = \
$CellContext`deflectedlocalrays$); $CellContext`raysreported$ = \
$CellContext`reportedrayspresent$; 1.); (
          AddTo[$CellContext`generationnumber$, 
            1.]; $CellContext`reportedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, 
              0, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`deflectedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; ($CellContext`deflectedrayspresent$ = 
            False; $CellContext`reportedrayspresent$ = 
            False; $CellContext`deflecteddummyrayspresent$ = 
            False; $CellContext`reporteddummyrayspresent$ = 
            False; {$CellContext`deflectedlocalrays$, \
$CellContext`reportedlocalrays$} = Transpose[
              
              Map[(({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                 Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                 Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                 Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                   2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                 3.5999999999999996` + $CellContext`rex$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                 Chop[$CellContext`rx$]; $CellContext`ry$ = 
                 Chop[$CellContext`ry$]; $CellContext`rz$ = 
                 Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                 False; $CellContext`intersections$ = {{-1., 0., 0.}}); 
               If[$CellContext`intensity$ > $CellContext`thresholdintensity$, \
$CellContext`deflectedrayspresent$ = 
                  True; ($CellContext`intersections$ = 
                   Block[{Compile`$37, Compile`$41, Compile`$75, Compile`$49, 
                    Compile`$82, Compile`$72, Compile`$38, Compile`$43, 
                    Compile`$52, Compile`$53, Compile`$54, Compile`$70, 
                    Compile`$74, Compile`$76, Compile`$79, Compile`$80, 
                    Compile`$81, Compile`$83, Compile`$84, Compile`$87, 
                    Compile`$88, Compile`$89, Compile`$90, Compile`$91, 
                    Compile`$92, Compile`$93, Compile`$94, Compile`$55, 
                    Compile`$59, Compile`$65, Compile`$69, Compile`$98, 
                    Compile`$101, Compile`$102, Compile`$104, Compile`$105, 
                    Compile`$113, Compile`$115, Compile`$117, Compile`$118, 
                    Compile`$119, Compile`$151, Compile`$152, Compile`$153}, 
                    
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 
                    1. + 0. I; $CellContext`LocSCx$ = 
                    1. + 0. I; $CellContext`LocSCy$ = 1. + 0. I; (
                    Compile`$37 = $CellContext`xunit$^2; 
                    Compile`$41 = $CellContext`yunit$^2; 
                    Compile`$75 = $CellContext`rz$^2; 
                    Compile`$49 = $CellContext`zunit$^2; 
                    Compile`$82 = $CellContext`rx$^2; 
                    Compile`$72 = $CellContext`ry$^2; 
                    Compile`$38 = 37. Compile`$37; 
                    Compile`$43 = 50. Compile`$41; 
                    Compile`$52 = 50. Compile`$49; 
                    Compile`$53 = Compile`$38 + Compile`$43 + Compile`$52; 
                    Compile`$54 = Compile`$53^(-1); 
                    Compile`$70 = 74498. Compile`$37; 
                    Compile`$74 = (-925.) Compile`$72 Compile`$37; 
                    Compile`$76 = (-925.) Compile`$75 Compile`$37; 
                    Compile`$79 = (-19300.) $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$; 
                    Compile`$80 = 
                    1850. $CellContext`rx$ $CellContext`ry$ \
$CellContext`xunit$ $CellContext`yunit$; 
                    Compile`$81 = 19300. $CellContext`rx$ Compile`$41; 
                    Compile`$83 = (-925.) Compile`$82 Compile`$41; 
                    Compile`$84 = (-1250.) Compile`$75 Compile`$41; 
                    Compile`$87 = (-19300.) $CellContext`rz$ \
$CellContext`xunit$ $CellContext`zunit$; 
                    Compile`$88 = 
                    1850. $CellContext`rx$ $CellContext`rz$ \
$CellContext`xunit$ $CellContext`zunit$; 
                    Compile`$89 = 
                    2500. $CellContext`ry$ $CellContext`rz$ \
$CellContext`yunit$ $CellContext`zunit$; 
                    Compile`$90 = 19300. $CellContext`rx$ Compile`$49; 
                    Compile`$91 = (-925.) Compile`$82 Compile`$49; 
                    Compile`$92 = (-1250.) Compile`$72 Compile`$49; 
                    Compile`$93 = 
                    Compile`$70 + Compile`$74 + Compile`$76 + Compile`$79 + 
                    Compile`$80 + Compile`$81 + Compile`$83 + Compile`$84 + 
                    Compile`$87 + Compile`$88 + Compile`$89 + Compile`$90 + 
                    Compile`$91 + Compile`$92; 
                    Compile`$94 = Sqrt[Compile`$93]; 
                    Compile`$55 = 386. $CellContext`xunit$; 
                    Compile`$59 = (-37.) $CellContext`rx$ $CellContext`xunit$; 
                    Compile`$65 = (-50.) $CellContext`ry$ $CellContext`yunit$; 
                    Compile`$69 = (-50.) $CellContext`rz$ $CellContext`zunit$; 
                    Compile`$98 = 37. $CellContext`ry$ Compile`$37; 
                    Compile`$101 = 
                    386. $CellContext`xunit$ $CellContext`yunit$; 
                    Compile`$102 = (-37.) $CellContext`rx$ \
$CellContext`xunit$ $CellContext`yunit$; 
                    Compile`$104 = (-50.) $CellContext`rz$ \
$CellContext`yunit$ $CellContext`zunit$; 
                    Compile`$105 = 50. $CellContext`ry$ Compile`$49; 
                    Compile`$113 = 37. $CellContext`rz$ Compile`$37; 
                    Compile`$115 = 50. $CellContext`rz$ Compile`$41; 
                    Compile`$117 = 
                    386. $CellContext`xunit$ $CellContext`zunit$; 
                    Compile`$118 = (-37.) $CellContext`rx$ \
$CellContext`xunit$ $CellContext`zunit$; 
                    Compile`$119 = (-50.) $CellContext`ry$ \
$CellContext`yunit$ $CellContext`zunit$; Re[
                    
                    Select[{{-1. + 0. I, 0. + 0. I, 0. + 0. I}, {
                    Compile`$54 (Compile`$55 + Compile`$59 + Compile`$65 + 
                    Compile`$69 - 1.4142135623730951` Compile`$94), 
                    Compile`$54 (Compile`$98 + Compile`$101 + Compile`$102 + 
                    Compile`$104 + Compile`$105 - 
                    1.4142135623730951` $CellContext`yunit$ Compile`$94), 
                    Compile`$54 (Compile`$113 + Compile`$115 + Compile`$117 + 
                    Compile`$118 + Compile`$119 - 
                    1.4142135623730951` $CellContext`zunit$ Compile`$94)}, {
                    Compile`$54 (Compile`$55 + Compile`$59 + Compile`$65 + 
                    Compile`$69 + 1.4142135623730951` Compile`$94), 
                    Compile`$54 (Compile`$98 + Compile`$101 + Compile`$102 + 
                    Compile`$104 + Compile`$105 + 
                    1.4142135623730951` $CellContext`yunit$ Compile`$94), 
                    Compile`$54 (Compile`$113 + Compile`$115 + Compile`$117 + 
                    Compile`$118 + Compile`$119 + 
                    1.4142135623730951` $CellContext`zunit$ 
                    Compile`$94)}}, ({$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = #; (
                    Compile`$151 = $CellContext`LocSCx$^2; 
                    Compile`$152 = $CellContext`LocSCy$^2; 
                    Compile`$153 = Compile`$151 + Compile`$152; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, 
                    And[Chop[
                    Im[#]] == {0, 0, 0}, N[
                    Chop[
                    Re[$CellContext`LocRayL$]]] >= 0., 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[$CellContext`rx$ + $CellContext`LocRayL$ \
$CellContext`xunit$ - (25 Compile`$153)/(
                    193 (1 + Sqrt[1 - (925 Compile`$153)/74498]))] < 1.*^-7, 
                    Re[$CellContext`LocSCx$]^2 + Re[$CellContext`LocSCy$]^2 <= 
                    39.0625]]))& ]])]]; 
                  AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 8355.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                  Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                  If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]); 
                 If[$CellContext`intersections$ != {{-1., 0., 
                    0.}}, $CellContext`intersectionspresent$ = 
                    True; ({$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 15., 
                    
                    8355.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 15., 
                    8355.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
-3.5999999999999996` + $CellContext`rxhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}); ($CellContext`reportedrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{
                    1., ((-0.0016083472422043674`) $CellContext`ray2$^3)/(
                    Sqrt[1. - 
                    0.012416440709817716` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)] (1. + Sqrt[
                    1. - 0.012416440709817716` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)])^2) - (
                    0.0016083472422043674` $CellContext`ray2$ \
$CellContext`ray3$^2)/(Sqrt[
                    1. - 0.012416440709817716` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)] (1. + Sqrt[
                    1. - 0.012416440709817716` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)])^2) - (0.2590673575129534 $CellContext`ray2$)/(1. + 
                    Sqrt[1. - 
                    0.012416440709817716` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)]), ((-0.0016083472422043674`) $CellContext`ray2$^2 \
$CellContext`ray3$)/(Sqrt[1. - 
                    0.012416440709817716` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)] (1. + Sqrt[
                    1. - 0.012416440709817716` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)])^2) - (0.0016083472422043674` $CellContext`ray3$^3)/(
                    Sqrt[1. - 
                    0.012416440709817716` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)] (1. + Sqrt[
                    1. - 0.012416440709817716` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)])^2) - (0.2590673575129534 $CellContext`ray3$)/(1. + 
                    Sqrt[1. - 
                    0.012416440709817716` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)])}, {(
                    0.0016083472422043674` $CellContext`ray2$ \
($CellContext`ray2$^2 + $CellContext`ray3$^2))/(
                    Sqrt[1. - 
                    0.012416440709817716` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)] (1. + Sqrt[
                    1. - 0.012416440709817716` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)])^2) + (0.2590673575129534 $CellContext`ray2$)/(1. + 
                    Sqrt[1. - 
                    0.012416440709817716` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)]), 1., 
                    0.}, {(0.0016083472422043674` $CellContext`ray3$ \
($CellContext`ray2$^2 + $CellContext`ray3$^2))/(
                    Sqrt[1. - 
                    0.012416440709817716` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)] (1. + Sqrt[
                    1. - 0.012416440709817716` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)])^2) + (0.2590673575129534 $CellContext`ray3$)/(1. + 
                    Sqrt[1. - 
                    0.012416440709817716` ($CellContext`ray2$^2 + \
$CellContext`ray3$^2)]), 0., 1.}}]; If[
                    Or[
                    Part[$CellContext`surfnorm$, 1] == {0., 0., 0.}, 
                    Part[$CellContext`surfnorm$, 2] == {0., 0., 0.}, 
                    Part[$CellContext`surfnorm$, 3] == {0., 0., 
                    0.}], $CellContext`surfnorm$ = 
                    1. Re[{{1., ((-0.0016083472422043674`) (
                    1.*^-6 + $CellContext`ray2$)^3)/(
                    Sqrt[1. - 0.012416440709817716` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)] (1. + 
                    Sqrt[1. - 0.012416440709817716` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)])^2) - (
                    0.0016083472422043674` (
                    1.*^-6 + $CellContext`ray2$) (
                    1.*^-6 + $CellContext`ray3$)^2)/(
                    Sqrt[1. - 0.012416440709817716` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)] (1. + 
                    Sqrt[1. - 0.012416440709817716` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)])^2) - (
                    0.2590673575129534 (1.*^-6 + $CellContext`ray2$))/(1. + 
                    Sqrt[1. - 0.012416440709817716` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)]), \
((-0.0016083472422043674`) (1.*^-6 + $CellContext`ray2$)^2 (
                    1.*^-6 + $CellContext`ray3$))/(
                    Sqrt[1. - 0.012416440709817716` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)] (1. + 
                    Sqrt[1. - 0.012416440709817716` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)])^2) - (
                    0.0016083472422043674` (1.*^-6 + $CellContext`ray3$)^3)/(
                    Sqrt[1. - 0.012416440709817716` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)] (1. + 
                    Sqrt[1. - 0.012416440709817716` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)])^2) - (
                    0.2590673575129534 (1.*^-6 + $CellContext`ray3$))/(1. + 
                    Sqrt[1. - 0.012416440709817716` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)])}, {(
                    0.0016083472422043674` (
                    1.*^-6 + $CellContext`ray2$) ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2))/(
                    Sqrt[1. - 0.012416440709817716` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)] (1. + 
                    Sqrt[1. - 0.012416440709817716` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)])^2) + (
                    0.2590673575129534 (1.*^-6 + $CellContext`ray2$))/(1. + 
                    Sqrt[1. - 0.012416440709817716` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)]), 1., 
                    0.}, {(0.0016083472422043674` (
                    1.*^-6 + $CellContext`ray3$) ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2))/(
                    Sqrt[1. - 0.012416440709817716` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)] (1. + 
                    Sqrt[1. - 0.012416440709817716` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)])^2) + (
                    0.2590673575129534 (1.*^-6 + $CellContext`ray3$))/(1. + 
                    Sqrt[1. - 0.012416440709817716` ((
                    1.*^-6 + $CellContext`ray2$)^2 + (
                    1.*^-6 + $CellContext`ray3$)^2)]), 0., 1.}}]; 1., 
                    1.]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = \
{-3.5999999999999996`, 0, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; 
                    If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{I 0., I 0., I 0.}}; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    1.5392664079785883` - 
                    0.723219952199223 $CellContext`wavelength$ + 
                    1.098444937226872 $CellContext`wavelength$^2 - 
                    0.5792106405023153 $CellContext`wavelength$^3; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[
                    1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    1.5392664079785883` - 
                    0.723219952199223 $CellContext`wavelength$ + 
                    1.098444937226872 $CellContext`wavelength$^2 - 
                    0.5792106405023153 $CellContext`wavelength$^3; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    1.5392664079785883` - 
                    0.723219952199223 $CellContext`wavelength$ + 
                    1.098444937226872 $CellContext`wavelength$^2 - 
                    0.5792106405023153 $CellContext`wavelength$^3]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    0., $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1.]; $CellContext`sinangle$ = 
                    1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$])); {
                    
                    First[$CellContext`allcreatedrays$], \
$CellContext`completedray$}, $CellContext`reporteddummyrayspresent$ = 
                    True; {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, CompressedData["
1:eJxTTMoPSmVkYGBQZ4CBD/YDRzdEmOSfPUicerh79+Og6eZuAGaoMiY=
                   
                     "]}], $CellContext`reporteddummyrayspresent$ = 
                  True; $CellContext`deflecteddummyrayspresent$ = 
                  True; CompressedData["
1:eJxTTMoPSmViYGAAYXUGGPhgP3B0Q4RJ/tmDxKmHu3c/DnoA/UFvemiGGwCy
wWJ9
                  "]])& , $CellContext`propagatedrays$]]; If[
             
             And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
              Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ]; 
             1., 1.]; If[
             
             And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
              Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 1.,
              1.]); (If[$CellContext`reportedrayspresent$, \
$CellContext`reportedrays$ = Join[$CellContext`reportedrays$, CompressedData["

1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                
                "], $CellContext`reportedlocalrays$]; 1., 
             1.]; $CellContext`propagatedrays$ = \
$CellContext`deflectedlocalrays$); $CellContext`raysreported$ = \
$CellContext`reportedrayspresent$; 1.); 
         If[Length[$CellContext`reportedrays$] > 
           2, $CellContext`reportedrays$ = 
           Drop[$CellContext`reportedrays$, 2], $CellContext`reportedrays$]; 
         Map[{
            Part[#, 1], 
            Part[#, 2], 
            Part[#, 3], 
            Part[#, 4], 
            Part[#, 5], 
            Part[#, 6]}& , $CellContext`reportedrays$]], {
        CompilationTarget -> "MVM", RuntimeAttributes -> {Listable}, 
         Parallelization -> False, RuntimeOptions -> {}}]; 
     Typeset`initDone$$ = True),
    SynchronousInitialization->False,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False,
   DynamicEvaluationTimeout->100],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.5448778814520903`*^9}]
}, Open  ]]
},
WindowSize->{1280, 679},
WindowMargins->{{72, Automatic}, {Automatic, 22}},
ShowSelection->True,
FrontEndVersion->"8.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (October 5, \
2011)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Info3511033568-5293371"->{
  Cell[723, 27, 2144, 29, 323, "Print",
   CellTags->"Info3511033568-5293371"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Info3511033568-5293371", 499141, 8362}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 153, 3, 43, "Input"],
Cell[723, 27, 2144, 29, 323, "Print",
 CellTags->"Info3511033568-5293371"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2904, 61, 1333, 34, 73, "Input"],
Cell[4240, 97, 494544, 8250, 911, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
