(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[   1003233,      17231]
NotebookOptionsPosition[   1002768,      17212]
NotebookOutlinePosition[   1003201,      17229]
CellTagsIndexPosition[   1003158,      17226]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 StyleBox["\n", "Section"],
 StyleBox[" ", "Section",
  FontFamily->"Helvetica",
  FontSize->18],
 StyleBox[" SLR Camera with Tessar Lens, ", "Section",
  FontFamily->"Helvetica",
  FontSize->24],
 StyleBox["\n  \n \n\nSLR cameras use pentaprisms for direct viewing. When \
the shutter is closed, \nlight is reflected by a movable mirror  upwards into \
a pentaprism and into\nthe viewfinder. When the shutter is released, the \
mirror moves out of the \nlight path.  The light then shines directly on  \
film.  This example uses a Tessar Lens. \n \n", "Section",
  FontFamily->"Helvetica",
  FontSize->18],
 StyleBox["\n  ",
  FontFamily->"Helvetica",
  FontSize->18]
}], "Input",
 CellChangeTimes->{{3.434951258411371*^9, 3.434951261554386*^9}, {
   3.4349542498083982`*^9, 3.434954251044462*^9}, {3.4349543046972446`*^9, 
   3.434954371793632*^9}, {3.434974428905411*^9, 3.434974444024024*^9}, {
   3.435070098374023*^9, 3.435070240738367*^9}, {3.435234613894524*^9, 
   3.435234627516985*^9}, {3.435234662875003*^9, 3.435234729046459*^9}, {
   3.435234778431143*^9, 3.435234787142662*^9}, 3.440429419977398*^9, {
   3.440429457233911*^9, 3.440429687210169*^9}, {3.44042982772113*^9, 
   3.440429841636491*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ManipulateSystem", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Move", "[", 
      RowBox[{
       RowBox[{"LineOfRays", "[", 
        RowBox[{".98", ",", " ", 
         RowBox[{"NumberOfRays", " ", "\[Rule]", " ", "8"}], ",", 
         RowBox[{"WaveLength", "\[Rule]", "lam"}]}], "]"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"lightX", ",", " ", 
         RowBox[{"-", ".930"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"LightAng", ",", " ", "0"}], "}"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Move", "[", 
      RowBox[{
       RowBox[{"ApertureStop", "[", 
        RowBox[{"3", ",", " ", ".90"}], "]"}], ",", 
       RowBox[{"-", ".3"}]}], "]"}], ",", " ", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"Move", "[", 
      RowBox[{
       RowBox[{"SphericalLens", "[", 
        RowBox[{"1.3147", ",", " ", 
         RowBox[{"-", "21.0190"}], ",", " ", "1.5", ",", ".329", ",", " ", 
         RowBox[{"ComponentMedium", " ", "\[Rule]", " ", "SK15"}]}], "]"}], 
       ",", "0"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Move", "[", 
      RowBox[{
       RowBox[{"SphericalLens", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"cs21", ",", " ", 
           RowBox[{"-", "2.4330"}]}], "}"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{"cs22", ",", "1.1718"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"as2", ",", " ", ".98"}], "}"}], ",", "  ", 
         RowBox[{"{", 
          RowBox[{"ts2", ",", ".081"}], "}"}], ",", " ", 
         RowBox[{"ComponentMedium", " ", "\[Rule]", " ", "F2"}]}], "]"}], ",",
        " ", 
       RowBox[{"{", 
        RowBox[{"xs2", ",", " ", ".552"}], "}"}]}], "]"}], ",", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"Move", "[", 
      RowBox[{
       RowBox[{"ApertureStop", "[", 
        RowBox[{"1.16", ",", " ", ".90"}], "]"}], ",", " ", ".827"}], "]"}], 
     ",", " ", "\[IndentingNewLine]", 
     RowBox[{"Move", "[", 
      RowBox[{
       RowBox[{"LensDoublet", "[", " ", 
        RowBox[{
         RowBox[{"-", "31.8418"}], ",", " ", "1.4005", ",", " ", 
         RowBox[{"-", "1.6991"}], ",", " ", "1.16", ",", " ", ".082", ",", 
         " ", ".278", ",", "  ", "K10", ",", " ", "SK15"}], "]"}], ",", 
       "1.034"}], "]"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"Move", "[", 
      RowBox[{
       RowBox[{"Move", "[", 
        RowBox[{
         RowBox[{"Move", "[", 
          RowBox[{
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"Mirror", "[", "1.0", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", 
               RowBox[{"-", ".5"}]}], "}"}]}], "]"}], ",", "0", ",", 
           RowBox[{"{", " ", 
            RowBox[{"MirrorAngle", ",", "0"}], "}"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", ".5"}], "}"}]}], "]"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"3", ",", " ", "0"}], "}"}], ",", 
       RowBox[{"-", "45"}]}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Move", "[", 
      RowBox[{
       RowBox[{"Screen", "[", "1.16", "]"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"3", ",", " ", "1.617"}], "}"}], ",", " ", "90"}], "]"}], ",",
      "\[IndentingNewLine]", 
     RowBox[{"Move", "[", 
      RowBox[{
       RowBox[{"SphericalLens", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"c11", ",", " ", 
           RowBox[{"-", "21.0"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"c12", ",", " ", 
           RowBox[{"-", "2"}]}], "}"}], ",", " ", "1.16", ",", " ", 
         RowBox[{"{", " ", 
          RowBox[{"t1", ",", " ", ".08"}], "}"}]}], "]"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"3", ",", " ", 
         RowBox[{"{", 
          RowBox[{"y1", ",", "  ", "1.8"}], "}"}]}], "}"}], ",", " ", "90", 
       ",", "  ", 
       RowBox[{"ComponentMedium", " ", "\[Rule]", " ", "SK15"}]}], "]"}], ",",
      "\[IndentingNewLine]", 
     RowBox[{"Move", "[", 
      RowBox[{
       RowBox[{"PentaPrism", "[", "1", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}], ",", "90"}], "]"}], ",", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"Move", "[", 
      RowBox[{
       RowBox[{"SphericalLens", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"c21", ",", "2.0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"c22", ",", 
           RowBox[{"-", "2"}]}], "}"}], ",", " ", "1.16", ",", 
         RowBox[{"{", 
          RowBox[{"t2", ",", ".2"}], "}"}]}], "]"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"x2", ",", " ", "4"}], "}"}], ",", " ", "2.5"}], "}"}], ",",
        " ", 
       RowBox[{"ComponentMedium", " ", "\[Rule]", " ", "SK15"}]}], "]"}], ",",
      "\[IndentingNewLine]", 
     RowBox[{"Move", "[", 
      RowBox[{
       RowBox[{"Screen", "[", "1.16", "]"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"xs", ",", " ", "4.617"}], "}"}], ",", " ", "2.5"}], 
        "}"}]}], "]"}], ",", "\[IndentingNewLine]", " ", 
     RowBox[{"Move", "[", 
      RowBox[{
       RowBox[{"Screen", "[", "1.16", "]"}], ",", " ", "4.617"}], "]"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"MirrorAngle", ",", "0", ",", " ", "\"\<Click for Photo\>\""}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0", " ", "\[Rule]", " ", "\"\<Viewfinder\>\""}], ",", 
       RowBox[{
        RowBox[{"-", "45"}], " ", "\[Rule]", " ", "\"\<Film\>\""}]}], "}"}]}],
     "}"}], " ", ",", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"lam", ",", ".532"}], "}"}], ",", ".4", ",", ".7"}], "}"}], ",",
    " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"c21", ",", " ", "3.02", ",", " ", "\"\<Eyepiece c1\>\""}], 
      "}"}], ",", " ", "2.0", ",", "4.0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"c22", ",", " ", 
       RowBox[{"-", "3.34"}], ",", " ", "\"\<Eyepiece c2\>\""}], "}"}], ",", 
     " ", 
     RowBox[{"-", "4"}], ",", 
     RowBox[{"-", "2"}]}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"t2", ",", " ", ".2", ",", " ", "\"\<Eyepiece thickness\>\""}], 
      "}"}], ",", " ", ".15", ",", ".4"}], "}"}], ",", " ", 
   RowBox[{"PlotType", " ", "\[Rule]", " ", "TopView"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "xs2", ",", " ", ".552", ",", " ", "\"\<Tessar Middle Lens x\>\""}], 
      "}"}], ",", " ", ".5", ",", ".6"}], "}"}], ",", " ", 
   RowBox[{"Axes", " ", "\[Rule]", " ", "True"}], ",", 
   RowBox[{"ImageSize", " ", "\[Rule]", " ", "600"}], ",", " ", 
   "\[IndentingNewLine]", 
   RowBox[{"SliderLabelReplacements", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<lam\>\"", "->", "\"\<Wavelength\>\""}], "}"}]}], ",", 
   RowBox[{"SymbolicValues", " ", "->", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"c11", "->", 
       RowBox[{"-", "21."}]}], ",", " ", 
      RowBox[{"c12", "->", 
       RowBox[{"-", "2."}]}], ",", " ", 
      RowBox[{"c21", "->", "3.02"}], ",", " ", 
      RowBox[{"c22", "->", 
       RowBox[{"-", "3.34"}]}], ",", 
      RowBox[{"t1", "->", "0.08"}], ",", " ", 
      RowBox[{"t2", "->", "0.2"}], ",", " ", 
      RowBox[{"x2", "->", "3.754060778668004"}], ",", " ", 
      RowBox[{"xs", "->", "4.617000000000002"}], ",", " ", 
      RowBox[{"y1", "->", "1.8"}]}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4352307793141603`*^9, 3.435230839439682*^9}, {
   3.4404289318684187`*^9, 3.440428952403283*^9}, 3.544877948727455*^9}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`as2$$ = 
    0.98, $CellContext`c11$$ = -21., $CellContext`c12$$ = -2., \
$CellContext`c21$$ = 
    3.02, $CellContext`c22$$ = -3.34, $CellContext`cs21$$ = -2.433, \
$CellContext`cs22$$ = 1.1718, $CellContext`lam$$ = 
    0.532, $CellContext`lastLightAng$$ = 
    0., $CellContext`lastlocposLightAng$$ = {-0.807075, 
    0.}, $CellContext`laststartposLightAng$$ = {-0.93, 
     0}, $CellContext`LightAng$$ = 
    0., $CellContext`lightX$$ = -0.93, $CellContext`maxas2$$ = 
    1.47, $CellContext`maxc11$$ = -0.21, $CellContext`maxc12$$ = -0.02, \
$CellContext`maxc21$$ = 
    4., $CellContext`maxc22$$ = -2, $CellContext`maxcs21$$ = -0.024, \
$CellContext`maxcs22$$ = 1.7576999999999998`, $CellContext`maxlam$$ = 
    0.7, $CellContext`maxLightAng$$ = 
    180., $CellContext`maxlightX$$ = -0.009, $CellContext`maxMirrorAngle$$ = 
    180., $CellContext`maxt1$$ = 0.8, $CellContext`maxt2$$ = 
    0.30000000000000004`, $CellContext`maxts2$$ = 0.81, $CellContext`maxx2$$ =
     8, $CellContext`maxxs$$ = 9, $CellContext`maxxs2$$ = 
    0.6, $CellContext`maxy1$$ = 4, $CellContext`minas2$$ = 
    0.1, $CellContext`minc11$$ = -42, $CellContext`minc12$$ = -4, \
$CellContext`minc21$$ = 
    0.03, $CellContext`minc22$$ = -7, $CellContext`mincs21$$ = -5, \
$CellContext`mincs22$$ = 0.1, $CellContext`minlam$$ = 
    0.1, $CellContext`minLightAng$$ = -180., $CellContext`minlightX$$ = \
-1.86, $CellContext`minMirrorAngle$$ = -180., $CellContext`mint1$$ = -0.8, \
$CellContext`mint2$$ = 
    0.1, $CellContext`mints2$$ = -0.81, $CellContext`minx2$$ = 
    0.037, $CellContext`minxs$$ = 0.046, $CellContext`minxs2$$ = 
    0.1, $CellContext`miny1$$ = 0.018, $CellContext`MirrorAngle$$ = 
    0, $CellContext`radiusLightAng$$ = 
    0.12292500000000005`, \
$CellContext`staticpolygons1118898201471941642905813$$ = {
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[CompressedData["
1:eJxdk09I2nEYxsUgwg6B18VG0CFWCFGwuQKjQ4ctSrpqVmOy1axfhxI2on90
qKA6FBUbNQg6CXUQAsklxBiLjC1ym5kkCNEfKDLN2kFa+erzg+cLIh9evt/3
fZ73+RW9VprsORqNRnv/K8/8V6TPnm/H/3DCpixfPa0a8Uyo3Kq3xKd3D9T6
q48vZj6HwG9dw8/yYkHw40Dly+r9P2BHo8lqaQ6APTajp250F/wz3d8P7pnP
mT3SfQf/zVes0V9fwe6N0mGffgVcY9oocX0bqM7ygtR90Cf3wV3yPnhL+oPX
ZD7we5kfXCj6wHbRD874A24R/9S6+KvOJ/6D41Rvo/sJev8d9X9C8yk0/zrp
C5D+PvLnlPw7In+7Vydtg3tz3izP0n42aX/ttN9N2r+b8tFB+XlE+XpD+YtR
Pm2U3xjlm/OvSZ9bNY8N5RfK9g3YPOW8XjaonDi1H5jLkuBBY60h/CMB7rIM
nVh1cXDIEfE7by/BkYWWSO/zc7A23f8EnH+nTbXbouDDMeuSN6jqrekpnvtS
sAXWjS/WGz98wvdgkDr29Vvug3PlfXDq7uEcg0MyH3hf5gd3ij7wgOhX8yr+
gBvFP3DGX3DGf3Av1c10P0nvD1F/heYL0/xR0pcr/oP15M85+ddB/o4eO/+d
hdz4HkpoP37an5b2eyP+gwOUjyDlx0H56qf8xSmfDZRfznc2//8B03zARQ==

      "]]}, $CellContext`staticpolygons1218898201471941642908865$$ = {
     AbsoluteThickness[1], 
     AbsolutePointSize[1], 
     EdgeForm[], 
     RGBColor[0.4, 0.6, 0.8], 
     Polygon[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGYC4gdvHshvEDxnzwAGL/bfmL22KdH6CJT/ZH/C
trkhIV47ofwH+x3qdp1b8W01lH9jvwPPBcviCTOg/Av7GdaF7rFMrYDyD+xn
QAeo8vZo+u3RzLdHs98ezX32aO63d/jpbsJpfAXOPyBzTIm/7ApcfcPspq+P
1lyBm+eg7KPVdv0K3L4D/x69/Pn1Ctw9B0oUOew5riLcO1mCJYwPxgeKoMrv
R9O/H838/Wj270dz33409+9Hjx8Am/yJ9A==
      
      "]]}, $CellContext`staticpolygons1418898201471941642968786$$ = {
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[CompressedData["
1:eJx1k19Ik2EUxke7KUOYuxFxLBJkkleCGE7h88oLrQRBSJ3zz9zc1NrAGBrR
auxiXeiCDRXCrgNBg5kw0n1jxiiYTG3UzIJtIrYgaFtCF4GZp50XHmjwMX4c
3vec5znPe3XE3m1WKhSKC2dfw79/1e3mtbfOb9J2/O/vs1TiwrUWT2hW8JC6
v+jfPRD1zvv6wLNPzGPL7usX8ylmbbKxo3X/A/Nkl2ToH0gyh4zNoXbvLnPi
vH+c+d6icv6oLMb88bLdkN3ZZA6G692yeoW5TQrXLb9xtZZ4ieoy66PzzHfp
fuZ31J95neZjnqD5mTWkj9lM+mXwh3mQ/JPBXxn8Zy5CfRjO/4T7rdD/Csxn
h/lfg74k6H8A/uTAvyPw17E6Z3z0fmGjxPOwnyjszwb7jcL+g5CPcchPNeRr
FPKXh3waIb95yDfm3xc9qTP4sswtp8qadYvgr5rfVc7vGeYbmcH61VrBhbYy
a1ydZn6c6osop74wWzUulUMS800kdC8PF4Wep+f995grjRFdhU34k9QX2n81
bYn398LfOz4cZJ5+Ylson/Hwe+ilusgbnWdW0f3Ms9Rf5IvmYx6j+ZldpI85
T/pl8If5mPyTwV8Z/P9vPQfnb8L9RejvhvkmYf47oC8A+mvAnzT45wV/G29p
TYFXz/k99MB+YrC/S7BfL+zfBPmwQH4eQr5+QP46IZ/HkF895LuU/z8JwBJE

      "]]}, $CellContext`staticpolygons1518898201471941642973884$$ = {
     AbsoluteThickness[1], 
     AbsolutePointSize[1], 
     EdgeForm[], 
     RGBColor[0.4, 0.6, 0.8], 
     Polygon[CompressedData["
1:eJxTTMoPSmVmYGBgAmJpKL1g4xPNBaUf7PsPfdWI6X+0f8PSBXdsaj7YvwOD
e/sLjObuXtr4wX5/xKdu1f039n/YtuLCrdYP9hPA6i/tvxCZrHyn44P9AbD8
if0JfvY7V3bB+Dv2K7A1TnXu/mDPAAYL9sDkd0Dk7WH690D028PM74OYbw+z
fx/Efns099nD3N8Lcb+9SelCdoN7n2H+sVedVrhiivVnuPr/az4ekdr1CeYf
+9tNdhbl4Z9g/rE/oetygk/oE8w/9kpXfTQuvvgI84+9U8LTC0q3P8L8YwOT
h/pnP0w/1D/7YeZD/bMfZj/UP/vR3Lcf5n6of/ajxw+a/zD0o/lvP5r/9qP5
bz+a//aj+W8Pmv/s0fxnj+Y/ezT/YYQ/mv/sLys5zT61+gs8vi7daJjkq/cV
rj4145uX+fSv8Pj6fWbDpC3Pv8Ljy1Bs2fH5Ct/g8dXiut201+kbPL5e/F75
8ZLvN3h8weRh8QXTD4svmPmw+ILZD4svNPfth7m/F0f8AAAD/+uM
      
      "]]}, $CellContext`staticpolygons1718898201471941642981873$$ = {
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGYC4iUFtlzXF/M4rJGJSrG+/9P+3l0Q4IbzJbzr
Nj4RR/CDdsi1vg7kgvN7VPdHfOrmhPOPTYrX+XmUA85nAAME3yp3wWU2K3Y4
v+SWw3LeEjY4f537wyqRdaxw/ostjX7SL1jgfCUwQPBj+w991YhhhvNj0Pjo
6tHNQ7cP3T3o7kX3D7p/0cMDPbzQwxM9vBejxQd6/AAAE++7vA==
      
      "]]}, $CellContext`staticpolygons1918898201471941642994612$$ = {
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[{{{3.5, 2.}, {2.5, 2.}, {2.5, 2.}, {3.5, 2.}, {3.5, 2.}}, {{2.5, 
       2.}, {2.085786437626905, 3.}, {2.085786437626905, 3.}, {2.5, 2.}, {2.5,
        2.}}, {{2.5, 3.414213562373095}, {2.085786437626905, 3.}, {
       2.085786437626905, 3.}, {2.5, 3.414213562373095}, {2.5, 
       3.414213562373095}}, {{3.5, 3.}, {2.5, 3.414213562373095}, {2.5, 
       3.414213562373095}, {3.5, 3.}, {3.5, 3.}}, {{3.5, 2.}, {3.5, 3.}, {3.5,
        3.}, {3.5, 2.}, {3.5, 2.}}, {{3.500341421356237, 
       1.9996585786437628`}, {2.4998414213562374`, 1.9996585786437628`}, {
       2.085420752201956, 3.0001585786437626`}, {2.4998414213562374`, 
       3.414579247798044}, {3.500341421356237, 3.0001585786437626`}, {
       3.500341421356237, 1.9996585786437628`}}, {{3.500341421356237, 
       1.9996585786437628`}, {2.4998414213562374`, 1.9996585786437628`}, {
       2.085420752201956, 3.0001585786437626`}, {2.4998414213562374`, 
       3.414579247798044}, {3.500341421356237, 3.0001585786437626`}, {
       3.500341421356237, 
       1.9996585786437628`}}}]}, \
$CellContext`staticpolygons2118898201471941643006643$$ = {
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGZiQID+Q181Yvof7Yfx34HBPTh/f8SnbtX9N+D8
CWD1l+D8A2D5E2j8HXA+BCzYA2PtgMjbw/h7IPrh/D6I+XD+Poj9cD7UfXB+
L8T9cH4/Gh9d/X408yag2XcAzT0H0NwL9Y8Nmn/g/t2DFh59aOG1Dy080cO7
Fy0+YPEDAKxSgy8=
      
      "]]}, $CellContext`staticpolygons2218898201471941643007768$$ = {
     GrayLevel[0], 
     AbsoluteThickness[0.5], 
     Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGYCYu12sZvnyoUc+g991Yjpf7Qfxn8HBvfg/P0R
n7pV99+A8yeA1V+C8w+A5U+g8XfA+QxgsGAPjL8DIm8P4++B6Ifz+yDmw/n7
IPbbo7kPzu+FuN8ezT841e9HM28Cmn0H0NxzAM29UP/YoPlnP5p/9qP5Zz+a
f3CGdy9afMDiBwCT4NoX
      "]]}, $CellContext`t1$$ = 0.08, $CellContext`t2$$ =
     0.2, $CellContext`ts2$$ = 0.081, $CellContext`x2$$ = 
    3.754060778668004, $CellContext`xLightAng$$ = -0.807075, \
$CellContext`xoffLightAng$$ = 0.12292500000000005`, $CellContext`xs$$ = 
    4.617000000000002, $CellContext`xs2$$ = 0.552, $CellContext`y1$$ = 
    1.8, $CellContext`yLightAng$$ = 0., $CellContext`yoffLightAng$$ = 0., 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`lam$$], 0.532}, 0.4, 0.7}, {{
       Hold[$CellContext`LightAng$$], 0.}, -180., 180.}, {{
       Hold[$CellContext`lightX$$], -0.93}, -1.86, -0.009}, {{
       Hold[$CellContext`as2$$], 0.98}, 0.1, 1.47}, {{
       Hold[$CellContext`c11$$], -21.}, -42, -0.21}, {{
       Hold[$CellContext`c12$$], -2.}, -4, -0.02}, {{
       Hold[$CellContext`c21$$], 3.02}, 2., 4.}, {{
       Hold[$CellContext`c22$$], -3.34}, -4, -2}, {{
       Hold[$CellContext`cs21$$], -2.433}, -5, -0.024}, {{
       Hold[$CellContext`cs22$$], 1.1718}, 0.1, 1.7576999999999998`}, {{
       Hold[$CellContext`MirrorAngle$$], 0.}, -180., 180.}, {{
       Hold[$CellContext`t1$$], 0.08}, -0.8, 0.8}, {{
       Hold[$CellContext`t2$$], 0.2}, 0.15, 0.4}, {{
       Hold[$CellContext`ts2$$], 0.081}, -0.81, 0.81}, {{
       Hold[$CellContext`x2$$], 3.754060778668004}, 0.037, 8}, {{
       Hold[$CellContext`xs$$], 4.617000000000002}, 0.046, 9}, {{
       Hold[$CellContext`xs2$$], 0.552}, 0.5, 0.6}, {{
       Hold[$CellContext`y1$$], 1.8}, 0.018, 4}, {{
       Hold[$CellContext`MirrorAngle$$], 0, "Click for Photo"}, {
      0 -> "Viewfinder", -45 -> "Film"}}, {{
       Hold[$CellContext`minlam$$], 0.1}}, {{
       Hold[$CellContext`maxlam$$], 0.798}}, {{
       Hold[$CellContext`minLightAng$$], -180.}}, {{
       Hold[$CellContext`maxLightAng$$], 180.}}, {{
       Hold[$CellContext`minlightX$$], -1.86}}, {{
       Hold[$CellContext`maxlightX$$], -0.009}}, {{
       Hold[$CellContext`minas2$$], 0.1}}, {{
       Hold[$CellContext`maxas2$$], 1.47}}, {{
       Hold[$CellContext`minc11$$], -42}}, {{
       Hold[$CellContext`maxc11$$], -0.21}}, {{
       Hold[$CellContext`minc12$$], -4}}, {{
       Hold[$CellContext`maxc12$$], -0.02}}, {{
       Hold[$CellContext`minc21$$], 0.03}}, {{
       Hold[$CellContext`maxc21$$], 6}}, {{
       Hold[$CellContext`minc22$$], -7}}, {{
       Hold[$CellContext`maxc22$$], -0.033}}, {{
       Hold[$CellContext`mincs21$$], -5}}, {{
       Hold[$CellContext`maxcs21$$], -0.024}}, {{
       Hold[$CellContext`mincs22$$], 0.1}}, {{
       Hold[$CellContext`maxcs22$$], 1.7576999999999998`}}, {{
       Hold[$CellContext`minMirrorAngle$$], -180.}}, {{
       Hold[$CellContext`maxMirrorAngle$$], 180.}}, {{
       Hold[$CellContext`mint1$$], -0.8}}, {{
       Hold[$CellContext`maxt1$$], 0.8}}, {{
       Hold[$CellContext`mint2$$], 0.1}}, {{
       Hold[$CellContext`maxt2$$], 0.30000000000000004`}}, {{
       Hold[$CellContext`mints2$$], -0.81}}, {{
       Hold[$CellContext`maxts2$$], 0.81}}, {{
       Hold[$CellContext`minx2$$], 0.037}}, {{
       Hold[$CellContext`maxx2$$], 8}}, {{
       Hold[$CellContext`minxs$$], 0.046}}, {{
       Hold[$CellContext`maxxs$$], 9}}, {{
       Hold[$CellContext`minxs2$$], 0.1}}, {{
       Hold[$CellContext`maxxs2$$], 0.8280000000000001}}, {{
       Hold[$CellContext`miny1$$], 0.018}}, {{
       Hold[$CellContext`maxy1$$], 4}}, {
      Hold[
       Style[
        Grid[{{"Wavelength", 
           InputField[
            Dynamic[$CellContext`minlam$$], Number, FieldSize -> 5], 
           Manipulator[
            
            Dynamic[$CellContext`\
nonexistantvariable159318898201471941649834335; $CellContext`lam$$, \
($CellContext`lam$$ = #)& ], {
             Dynamic[$CellContext`minlam$$], 
             Dynamic[$CellContext`maxlam$$]}, ImageSize -> 800], 
           InputField[
            Dynamic[$CellContext`maxlam$$], Number, FieldSize -> 5], 
           
           Dynamic[$CellContext`\
nonexistantvariable159318898201471941649834335; $CellContext`lam$$, \
($CellContext`lam$$ = #)& ]}}]]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`minlam$$], 0.4}}, {{
       Hold[$CellContext`maxlam$$], 0.7}}, {
      Hold[
       Style[
        Grid[{{"Eyepiece c1", 
           InputField[
            Dynamic[$CellContext`minc21$$], Number, FieldSize -> 5], 
           Manipulator[
            
            Dynamic[$CellContext`\
nonexistantvariable159318898201471941649834547; $CellContext`c21$$, \
($CellContext`c21$$ = #)& ], {
             Dynamic[$CellContext`minc21$$], 
             Dynamic[$CellContext`maxc21$$]}, ImageSize -> 800], 
           InputField[
            Dynamic[$CellContext`maxc21$$], Number, FieldSize -> 5], 
           
           Dynamic[$CellContext`\
nonexistantvariable159318898201471941649834547; $CellContext`c21$$, \
($CellContext`c21$$ = #)& ]}}]]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`minc21$$], 2.}}, {{
       Hold[$CellContext`maxc21$$], 4.}}, {
      Hold[
       Style[
        Grid[{{"Eyepiece c2", 
           InputField[
            Dynamic[$CellContext`minc22$$], Number, FieldSize -> 5], 
           Manipulator[
            
            Dynamic[$CellContext`\
nonexistantvariable159318898201471941649834706; $CellContext`c22$$, \
($CellContext`c22$$ = #)& ], {
             Dynamic[$CellContext`minc22$$], 
             Dynamic[$CellContext`maxc22$$]}, ImageSize -> 800], 
           InputField[
            Dynamic[$CellContext`maxc22$$], Number, FieldSize -> 5], 
           
           Dynamic[$CellContext`\
nonexistantvariable159318898201471941649834706; $CellContext`c22$$, \
($CellContext`c22$$ = #)& ]}}]]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`minc22$$], -4}}, {{
       Hold[$CellContext`maxc22$$], -2}}, {
      Hold[
       Style[
        Grid[{{"Eyepiece thickness", 
           InputField[
            Dynamic[$CellContext`mint2$$], Number, FieldSize -> 5], 
           Manipulator[
            
            Dynamic[$CellContext`\
nonexistantvariable159318898201471941649834856; $CellContext`t2$$, \
($CellContext`t2$$ = #)& ], {
             Dynamic[$CellContext`mint2$$], 
             Dynamic[$CellContext`maxt2$$]}, ImageSize -> 800], 
           InputField[
            Dynamic[$CellContext`maxt2$$], Number, FieldSize -> 5], 
           
           Dynamic[$CellContext`\
nonexistantvariable159318898201471941649834856; $CellContext`t2$$, \
($CellContext`t2$$ = #)& ]}}]]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`mint2$$], 0.15}}, {{
       Hold[$CellContext`maxt2$$], 0.4}}, {
      Hold[
       Style[
        Grid[{{"Tessar Middle Lens x", 
           InputField[
            Dynamic[$CellContext`minxs2$$], Number, FieldSize -> 5], 
           Manipulator[
            
            Dynamic[$CellContext`\
nonexistantvariable159318898201471941649835000; $CellContext`xs2$$, \
($CellContext`xs2$$ = #)& ], {
             Dynamic[$CellContext`minxs2$$], 
             Dynamic[$CellContext`maxxs2$$]}, ImageSize -> 800], 
           InputField[
            Dynamic[$CellContext`maxxs2$$], Number, FieldSize -> 5], 
           
           Dynamic[$CellContext`\
nonexistantvariable159318898201471941649835000; $CellContext`xs2$$, \
($CellContext`xs2$$ = #)& ]}}]]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`minxs2$$], 0.5}}, {{
       Hold[$CellContext`maxxs2$$], 0.6}}, {{
       Hold[$CellContext`minlam$$], 0.1}}, {{
       Hold[$CellContext`maxlam$$], 0.798}}, {{
       Hold[$CellContext`minLightAng$$], -180.}}, {{
       Hold[$CellContext`maxLightAng$$], 180.}}, {{
       Hold[$CellContext`minlightX$$], -1.86}}, {{
       Hold[$CellContext`maxlightX$$], -0.009}}, {{
       Hold[$CellContext`minas2$$], 0.1}}, {{
       Hold[$CellContext`maxas2$$], 1.47}}, {{
       Hold[$CellContext`minc11$$], -42}}, {{
       Hold[$CellContext`maxc11$$], -0.21}}, {{
       Hold[$CellContext`minc12$$], -4}}, {{
       Hold[$CellContext`maxc12$$], -0.02}}, {{
       Hold[$CellContext`minc21$$], 0.03}}, {{
       Hold[$CellContext`maxc21$$], 6}}, {{
       Hold[$CellContext`minc22$$], -7}}, {{
       Hold[$CellContext`maxc22$$], -0.033}}, {{
       Hold[$CellContext`mincs21$$], -5}}, {{
       Hold[$CellContext`maxcs21$$], -0.024}}, {{
       Hold[$CellContext`mincs22$$], 0.1}}, {{
       Hold[$CellContext`maxcs22$$], 1.7576999999999998`}}, {{
       Hold[$CellContext`minMirrorAngle$$], -180.}}, {{
       Hold[$CellContext`maxMirrorAngle$$], 180.}}, {{
       Hold[$CellContext`mint1$$], -0.8}}, {{
       Hold[$CellContext`maxt1$$], 0.8}}, {{
       Hold[$CellContext`mint2$$], 0.1}}, {{
       Hold[$CellContext`maxt2$$], 0.30000000000000004`}}, {{
       Hold[$CellContext`mints2$$], -0.81}}, {{
       Hold[$CellContext`maxts2$$], 0.81}}, {{
       Hold[$CellContext`minx2$$], 0.037}}, {{
       Hold[$CellContext`maxx2$$], 8}}, {{
       Hold[$CellContext`minxs$$], 0.046}}, {{
       Hold[$CellContext`maxxs$$], 9}}, {{
       Hold[$CellContext`minxs2$$], 0.1}}, {{
       Hold[$CellContext`maxxs2$$], 0.8280000000000001}}, {{
       Hold[$CellContext`miny1$$], 0.018}}, {{
       Hold[$CellContext`maxy1$$], 4}}, {{
       Hold[$CellContext`minlam$$], 0.4}}, {{
       Hold[$CellContext`maxlam$$], 0.7}}, {{
       Hold[$CellContext`minc21$$], 2.}}, {{
       Hold[$CellContext`maxc21$$], 4.}}, {{
       Hold[$CellContext`minc22$$], -4}}, {{
       Hold[$CellContext`maxc22$$], -2}}, {{
       Hold[$CellContext`mint2$$], 0.15}}, {{
       Hold[$CellContext`maxt2$$], 0.4}}, {{
       Hold[$CellContext`minxs2$$], 0.5}}, {{
       Hold[$CellContext`maxxs2$$], 0.6}}, {
      Hold[
       Button[
       "Report", 
        Optica`Optica`$OpticalSystemSettings = {
          Optica`Optica`SymbolicValues -> 
           MapThread[
            ToExpression[#] -> #2& , {{
              "LightAng", "lightX", "as2", "c11", "c12", "Eyepiece c1", 
               "Eyepiece c2", "cs21", "cs22", "MirrorAngle", "t1", 
               "Eyepiece thickness", "ts2", "x2", "xs", 
               "Tessar Middle Lens x", 
               "y1"}, {$CellContext`LightAng$$, $CellContext`lightX$$, \
$CellContext`as2$$, $CellContext`c11$$, $CellContext`c12$$, \
$CellContext`c21$$, $CellContext`c22$$, $CellContext`cs21$$, \
$CellContext`cs22$$, $CellContext`MirrorAngle$$, $CellContext`t1$$, \
$CellContext`t2$$, $CellContext`ts2$$, $CellContext`x2$$, $CellContext`xs$$, \
$CellContext`xs2$$, $CellContext`y1$$}}], Optica`Optica`SymbolicRanges -> 
           Map[ToExpression[
               Part[#, 1]] -> {
               Part[#, 2], 
               Part[#, 3]}& , 
             Select[
              
              Transpose[{{
                "LightAng", "lightX", "as2", "c11", "c12", "Eyepiece c1", 
                 "Eyepiece c2", "cs21", "cs22", "MirrorAngle", "t1", 
                 "Eyepiece thickness", "ts2", "x2", "xs", 
                 "Tessar Middle Lens x", 
                 "y1"}, {$CellContext`minLightAng$$, \
$CellContext`minlightX$$, $CellContext`minas2$$, $CellContext`minc11$$, \
$CellContext`minc12$$, $CellContext`minc21$$, $CellContext`minc22$$, \
$CellContext`mincs21$$, $CellContext`mincs22$$, \
$CellContext`minMirrorAngle$$, $CellContext`mint1$$, $CellContext`mint2$$, \
$CellContext`mints2$$, $CellContext`minx2$$, $CellContext`minxs$$, \
$CellContext`minxs2$$, $CellContext`miny1$$}, {$CellContext`maxLightAng$$, \
$CellContext`maxlightX$$, $CellContext`maxas2$$, $CellContext`maxc11$$, \
$CellContext`maxc12$$, $CellContext`maxc21$$, $CellContext`maxc22$$, \
$CellContext`maxcs21$$, $CellContext`maxcs22$$, \
$CellContext`maxMirrorAngle$$, $CellContext`maxt1$$, $CellContext`maxt2$$, \
$CellContext`maxts2$$, $CellContext`maxx2$$, $CellContext`maxxs$$, \
$CellContext`maxxs2$$, $CellContext`maxy1$$}}], NumberQ[
               Part[#, 2]]& ]]}; 
        Optica`Optica`$OpticalSystemScript = 
         "{Move[LineOfRays[0.98, NumberOfRays -> 8, WaveLength -> lam], \
{lightX, -0.93}, {LightAng, 0.}, SymbolicValues -> {LightAng -> 0, lightX -> \
-0.93}], Move[ApertureStop[3, 0.9], -0.3], SphericalLens[1.3147, -21.019, \
1.5, 0.329, {ComponentMedium -> SK15}], Move[SphericalLens[{cs21, -2.433}, \
{cs22, 1.1718}, {as2, 0.98}, {ts2, 0.081}, {ComponentMedium -> F2}], {xs2, \
0.552}, SymbolicValues -> {xs2 -> 0.552}], Move[ApertureStop[1.16, 0.9], \
0.827], Move[LensDoublet[-31.8418, 1.4005, -1.6991, 1.16, 0.082, 0.278, K10, \
SK15], 1.034], Move[Mirror[1.], {{3 + (0.5 - \
0.5*Cos[Degree*MirrorAngle])/Sqrt[2] + \
0.35355339059327373*Sin[Degree*MirrorAngle], 3.}, {(0.5 - \
0.5*Cos[Degree*MirrorAngle])/Sqrt[2] - \
0.35355339059327373*Sin[Degree*MirrorAngle], 0}}, {MirrorAngle - \
Pi/(4*Degree), -45.}, SymbolicValues -> {MirrorAngle -> 0}], \
Move[Screen[1.16], {3., 1.617}, 90.], Move[SphericalLens[{c11, -21.}, {c12, \
-2}, 1.16, {t1, 0.08}], {3., {y1, 1.8}}, 90., SymbolicValues -> {y1 -> 1.8}], \
Move[PentaPrism[1], {3., 2.}, 90.], Move[SphericalLens[{c21, 2.}, {c22, -2}, \
1.16, {t2, 0.2}], {{x2, 4.}, 2.5}, SymbolicValues -> {x2 -> 4}], \
Move[Screen[1.16], {{xs, 4.617}, 2.5}, SymbolicValues -> {xs -> 4.617}], \
Move[Screen[1.16], 4.617]}"; Print[
          InputForm[
           StringJoin["{SymbolicValues -> ", 
            ToString[
             MapThread[StringJoin[#, "->", 
               ToString[#2, InputForm]]& , {{
               "LightAng", "lightX", "as2", "c11", "c12", "Eyepiece c1", 
                "Eyepiece c2", "cs21", "cs22", "MirrorAngle", "t1", 
                "Eyepiece thickness", "ts2", "x2", "xs", 
                "Tessar Middle Lens x", 
                "y1"}, {$CellContext`LightAng$$, $CellContext`lightX$$, \
$CellContext`as2$$, $CellContext`c11$$, $CellContext`c12$$, \
$CellContext`c21$$, $CellContext`c22$$, $CellContext`cs21$$, \
$CellContext`cs22$$, $CellContext`MirrorAngle$$, $CellContext`t1$$, \
$CellContext`t2$$, $CellContext`ts2$$, $CellContext`x2$$, $CellContext`xs$$, \
$CellContext`xs2$$, $CellContext`y1$$}}]], ", SymbolicRanges -> ", 
            ToString[
             Map[StringJoin[
               Part[#, 1], "->", 
               ToString[{
                 Part[#, 2], 
                 Part[#, 3]}, InputForm]]& , 
              Select[
               
               Transpose[{{
                 "LightAng", "lightX", "as2", "c11", "c12", "Eyepiece c1", 
                  "Eyepiece c2", "cs21", "cs22", "MirrorAngle", "t1", 
                  "Eyepiece thickness", "ts2", "x2", "xs", 
                  "Tessar Middle Lens x", 
                  "y1"}, {$CellContext`minLightAng$$, \
$CellContext`minlightX$$, $CellContext`minas2$$, $CellContext`minc11$$, \
$CellContext`minc12$$, $CellContext`minc21$$, $CellContext`minc22$$, \
$CellContext`mincs21$$, $CellContext`mincs22$$, \
$CellContext`minMirrorAngle$$, $CellContext`mint1$$, $CellContext`mint2$$, \
$CellContext`mints2$$, $CellContext`minx2$$, $CellContext`minxs$$, \
$CellContext`minxs2$$, $CellContext`miny1$$}, {$CellContext`maxLightAng$$, \
$CellContext`maxlightX$$, $CellContext`maxas2$$, $CellContext`maxc11$$, \
$CellContext`maxc12$$, $CellContext`maxc21$$, $CellContext`maxc22$$, \
$CellContext`maxcs21$$, $CellContext`maxcs22$$, \
$CellContext`maxMirrorAngle$$, $CellContext`maxt1$$, $CellContext`maxt2$$, \
$CellContext`maxts2$$, $CellContext`maxx2$$, $CellContext`maxxs$$, \
$CellContext`maxxs2$$, $CellContext`maxy1$$}}], NumberQ[
                Part[#, 2]]& ]]], "}"]]], ImageSize -> Automatic]], 
      Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`xLightAng$$], -0.807075}}, {{
       Hold[$CellContext`yLightAng$$], 0.}}, {{
       Hold[$CellContext`radiusLightAng$$], 0.12292500000000005`}}, {{
       Hold[$CellContext`xoffLightAng$$], 0.12292500000000005`}}, {{
       Hold[$CellContext`yoffLightAng$$], 0.}}, {{
       Hold[$CellContext`laststartposLightAng$$], {-0.93, 0}}}, {{
       Hold[$CellContext`lastlocposLightAng$$], {-0.807075, 0.}}}, {{
       Hold[$CellContext`lastLightAng$$], 0}}, {{
       Hold[$CellContext`staticpolygons1118898201471941642905813$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[CompressedData["
1:eJxdk09I2nEYxsUgwg6B18VG0CFWCFGwuQKjQ4ctSrpqVmOy1axfhxI2on90
qKA6FBUbNQg6CXUQAsklxBiLjC1ym5kkCNEfKDLN2kFa+erzg+cLIh9evt/3
fZ73+RW9VprsORqNRnv/K8/8V6TPnm/H/3DCpixfPa0a8Uyo3Kq3xKd3D9T6
q48vZj6HwG9dw8/yYkHw40Dly+r9P2BHo8lqaQ6APTajp250F/wz3d8P7pnP
mT3SfQf/zVes0V9fwe6N0mGffgVcY9oocX0bqM7ygtR90Cf3wV3yPnhL+oPX
ZD7we5kfXCj6wHbRD874A24R/9S6+KvOJ/6D41Rvo/sJev8d9X9C8yk0/zrp
C5D+PvLnlPw7In+7Vydtg3tz3izP0n42aX/ttN9N2r+b8tFB+XlE+XpD+YtR
Pm2U3xjlm/OvSZ9bNY8N5RfK9g3YPOW8XjaonDi1H5jLkuBBY60h/CMB7rIM
nVh1cXDIEfE7by/BkYWWSO/zc7A23f8EnH+nTbXbouDDMeuSN6jqrekpnvtS
sAXWjS/WGz98wvdgkDr29Vvug3PlfXDq7uEcg0MyH3hf5gd3ij7wgOhX8yr+
gBvFP3DGX3DGf3Av1c10P0nvD1F/heYL0/xR0pcr/oP15M85+ddB/o4eO/+d
hdz4HkpoP37an5b2eyP+gwOUjyDlx0H56qf8xSmfDZRfznc2//8B03zARQ==

         "]]}}}, {{
       Hold[$CellContext`staticpolygons1218898201471941642908865$$], {
        AbsoluteThickness[1], 
        AbsolutePointSize[1], 
        EdgeForm[], 
        RGBColor[0.4, 0.6, 0.8], 
        Polygon[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGYC4gdvHshvEDxnzwAGL/bfmL22KdH6CJT/ZH/C
trkhIV47ofwH+x3qdp1b8W01lH9jvwPPBcviCTOg/Av7GdaF7rFMrYDyD+xn
QAeo8vZo+u3RzLdHs98ezX32aO63d/jpbsJpfAXOPyBzTIm/7ApcfcPspq+P
1lyBm+eg7KPVdv0K3L4D/x69/Pn1Ctw9B0oUOew5riLcO1mCJYwPxgeKoMrv
R9O/H838/Wj270dz33409+9Hjx8Am/yJ9A==
         "]]}}}, {{
       Hold[$CellContext`staticpolygons1418898201471941642968786$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[CompressedData["
1:eJx1k19Ik2EUxke7KUOYuxFxLBJkkleCGE7h88oLrQRBSJ3zz9zc1NrAGBrR
auxiXeiCDRXCrgNBg5kw0n1jxiiYTG3UzIJtIrYgaFtCF4GZp50XHmjwMX4c
3vec5znPe3XE3m1WKhSKC2dfw79/1e3mtbfOb9J2/O/vs1TiwrUWT2hW8JC6
v+jfPRD1zvv6wLNPzGPL7usX8ylmbbKxo3X/A/Nkl2ToH0gyh4zNoXbvLnPi
vH+c+d6icv6oLMb88bLdkN3ZZA6G692yeoW5TQrXLb9xtZZ4ieoy66PzzHfp
fuZ31J95neZjnqD5mTWkj9lM+mXwh3mQ/JPBXxn8Zy5CfRjO/4T7rdD/Csxn
h/lfg74k6H8A/uTAvyPw17E6Z3z0fmGjxPOwnyjszwb7jcL+g5CPcchPNeRr
FPKXh3waIb95yDfm3xc9qTP4sswtp8qadYvgr5rfVc7vGeYbmcH61VrBhbYy
a1ydZn6c6osop74wWzUulUMS800kdC8PF4Wep+f995grjRFdhU34k9QX2n81
bYn398LfOz4cZJ5+Ylson/Hwe+ilusgbnWdW0f3Ms9Rf5IvmYx6j+ZldpI85
T/pl8If5mPyTwV8Z/P9vPQfnb8L9RejvhvkmYf47oC8A+mvAnzT45wV/G29p
TYFXz/k99MB+YrC/S7BfL+zfBPmwQH4eQr5+QP46IZ/HkF895LuU/z8JwBJE

         "]]}}}, {{
       Hold[$CellContext`staticpolygons1518898201471941642973884$$], {
        AbsoluteThickness[1], 
        AbsolutePointSize[1], 
        EdgeForm[], 
        RGBColor[0.4, 0.6, 0.8], 
        Polygon[CompressedData["
1:eJxTTMoPSmVmYGBgAmJpKL1g4xPNBaUf7PsPfdWI6X+0f8PSBXdsaj7YvwOD
e/sLjObuXtr4wX5/xKdu1f039n/YtuLCrdYP9hPA6i/tvxCZrHyn44P9AbD8
if0JfvY7V3bB+Dv2K7A1TnXu/mDPAAYL9sDkd0Dk7WH690D028PM74OYbw+z
fx/Efns099nD3N8Lcb+9SelCdoN7n2H+sVedVrhiivVnuPr/az4ekdr1CeYf
+9tNdhbl4Z9g/rE/oetygk/oE8w/9kpXfTQuvvgI84+9U8LTC0q3P8L8YwOT
h/pnP0w/1D/7YeZD/bMfZj/UP/vR3Lcf5n6of/ajxw+a/zD0o/lvP5r/9qP5
bz+a//aj+W8Pmv/s0fxnj+Y/ezT/YYQ/mv/sLys5zT61+gs8vi7daJjkq/cV
rj4145uX+fSv8Pj6fWbDpC3Pv8Ljy1Bs2fH5Ct/g8dXiut201+kbPL5e/F75
8ZLvN3h8weRh8QXTD4svmPmw+ILZD4svNPfth7m/F0f8AAAD/+uM
         "]]}}}, {{
       Hold[$CellContext`staticpolygons1718898201471941642981873$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGYC4iUFtlzXF/M4rJGJSrG+/9P+3l0Q4IbzJbzr
Nj4RR/CDdsi1vg7kgvN7VPdHfOrmhPOPTYrX+XmUA85nAAME3yp3wWU2K3Y4
v+SWw3LeEjY4f537wyqRdaxw/ostjX7SL1jgfCUwQPBj+w991YhhhvNj0Pjo
6tHNQ7cP3T3o7kX3D7p/0cMDPbzQwxM9vBejxQd6/AAAE++7vA==
         "]]}}}, {{
       Hold[$CellContext`staticpolygons1918898201471941642994612$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[{{{3.5, 2.}, {2.5, 2.}, {2.5, 2.}, {3.5, 2.}, {3.5, 2.}}, {{2.5, 
          2.}, {2.085786437626905, 3.}, {2.085786437626905, 3.}, {2.5, 2.}, {
          2.5, 2.}}, {{2.5, 3.414213562373095}, {2.085786437626905, 3.}, {
          2.085786437626905, 3.}, {2.5, 3.414213562373095}, {2.5, 
          3.414213562373095}}, {{3.5, 3.}, {2.5, 3.414213562373095}, {2.5, 
          3.414213562373095}, {3.5, 3.}, {3.5, 3.}}, {{3.5, 2.}, {3.5, 3.}, {
          3.5, 3.}, {3.5, 2.}, {3.5, 2.}}, {{3.500341421356237, 
          1.9996585786437628`}, {2.4998414213562374`, 1.9996585786437628`}, {
          2.085420752201956, 3.0001585786437626`}, {2.4998414213562374`, 
          3.414579247798044}, {3.500341421356237, 3.0001585786437626`}, {
          3.500341421356237, 1.9996585786437628`}}, {{3.500341421356237, 
          1.9996585786437628`}, {2.4998414213562374`, 1.9996585786437628`}, {
          2.085420752201956, 3.0001585786437626`}, {2.4998414213562374`, 
          3.414579247798044}, {3.500341421356237, 3.0001585786437626`}, {
          3.500341421356237, 1.9996585786437628`}}}]}}}, {{
       Hold[$CellContext`staticpolygons2118898201471941643006643$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGZiQID+Q181Yvof7Yfx34HBPTh/f8SnbtX9N+D8
CWD1l+D8A2D5E2j8HXA+BCzYA2PtgMjbw/h7IPrh/D6I+XD+Poj9cD7UfXB+
L8T9cH4/Gh9d/X408yag2XcAzT0H0NwL9Y8Nmn/g/t2DFh59aOG1Dy080cO7
Fy0+YPEDAKxSgy8=
         "]]}}}, {{
       Hold[$CellContext`staticpolygons2218898201471941643007768$$], {
        GrayLevel[0], 
        AbsoluteThickness[0.5], 
        Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGYCYu12sZvnyoUc+g991Yjpf7Qfxn8HBvfg/P0R
n7pV99+A8yeA1V+C8w+A5U+g8XfA+QxgsGAPjL8DIm8P4++B6Ifz+yDmw/n7
IPbbo7kPzu+FuN8ezT841e9HM28Cmn0H0NxzAM29UP/YoPlnP5p/9qP5Zz+a
f3CGdy9afMDiBwCT4NoX
         "]]}}}}, Typeset`size$$ = {
    600., {278.84375, 284.15625}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = False, $CellContext`lam$801997$$ = 
    0, $CellContext`LightAng$801998$$ = 0, $CellContext`lightX$801999$$ = 
    0, $CellContext`as2$802000$$ = 0, $CellContext`c11$802001$$ = 
    0, $CellContext`c12$802002$$ = 0, $CellContext`c21$802003$$ = 
    0, $CellContext`c22$802004$$ = 0, $CellContext`cs21$802005$$ = 
    0, $CellContext`cs22$802006$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`as2$$ = 
        0.98, $CellContext`c11$$ = -21., $CellContext`c12$$ = -2., \
$CellContext`c21$$ = 
        3.02, $CellContext`c22$$ = -3.34, $CellContext`cs21$$ = -2.433, \
$CellContext`cs22$$ = 1.1718, $CellContext`lam$$ = 
        0.532, $CellContext`lastLightAng$$ = 
        0, $CellContext`lastlocposLightAng$$ = {-0.807075, 
         0.}, $CellContext`laststartposLightAng$$ = {-0.93, 
          0}, $CellContext`LightAng$$ = 
        0., $CellContext`lightX$$ = -0.93, $CellContext`maxas2$$ = 
        1.47, $CellContext`maxc11$$ = -0.21, $CellContext`maxc12$$ = -0.02, \
$CellContext`maxc21$$ = 
        4., $CellContext`maxc22$$ = -2, $CellContext`maxcs21$$ = -0.024, \
$CellContext`maxcs22$$ = 1.7576999999999998`, $CellContext`maxlam$$ = 
        0.7, $CellContext`maxLightAng$$ = 
        180., $CellContext`maxlightX$$ = -0.009, \
$CellContext`maxMirrorAngle$$ = 180., $CellContext`maxt1$$ = 
        0.8, $CellContext`maxt2$$ = 
        0.30000000000000004`, $CellContext`maxts2$$ = 
        0.81, $CellContext`maxx2$$ = 8, $CellContext`maxxs$$ = 
        9, $CellContext`maxxs2$$ = 0.6, $CellContext`maxy1$$ = 
        4, $CellContext`minas2$$ = 
        0.1, $CellContext`minc11$$ = -42, $CellContext`minc12$$ = -4, \
$CellContext`minc21$$ = 
        0.03, $CellContext`minc22$$ = -7, $CellContext`mincs21$$ = -5, \
$CellContext`mincs22$$ = 0.1, $CellContext`minlam$$ = 
        0.1, $CellContext`minLightAng$$ = -180., $CellContext`minlightX$$ = \
-1.86, $CellContext`minMirrorAngle$$ = -180., $CellContext`mint1$$ = -0.8, \
$CellContext`mint2$$ = 
        0.1, $CellContext`mints2$$ = -0.81, $CellContext`minx2$$ = 
        0.037, $CellContext`minxs$$ = 0.046, $CellContext`minxs2$$ = 
        0.1, $CellContext`miny1$$ = 0.018, $CellContext`MirrorAngle$$ = 
        0, $CellContext`radiusLightAng$$ = 
        0.12292500000000005`, \
$CellContext`staticpolygons1118898201471941642905813$$ = {
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[CompressedData["
1:eJxdk09I2nEYxsUgwg6B18VG0CFWCFGwuQKjQ4ctSrpqVmOy1axfhxI2on90
qKA6FBUbNQg6CXUQAsklxBiLjC1ym5kkCNEfKDLN2kFa+erzg+cLIh9evt/3
fZ73+RW9VprsORqNRnv/K8/8V6TPnm/H/3DCpixfPa0a8Uyo3Kq3xKd3D9T6
q48vZj6HwG9dw8/yYkHw40Dly+r9P2BHo8lqaQ6APTajp250F/wz3d8P7pnP
mT3SfQf/zVes0V9fwe6N0mGffgVcY9oocX0bqM7ygtR90Cf3wV3yPnhL+oPX
ZD7we5kfXCj6wHbRD874A24R/9S6+KvOJ/6D41Rvo/sJev8d9X9C8yk0/zrp
C5D+PvLnlPw7In+7Vydtg3tz3izP0n42aX/ttN9N2r+b8tFB+XlE+XpD+YtR
Pm2U3xjlm/OvSZ9bNY8N5RfK9g3YPOW8XjaonDi1H5jLkuBBY60h/CMB7rIM
nVh1cXDIEfE7by/BkYWWSO/zc7A23f8EnH+nTbXbouDDMeuSN6jqrekpnvtS
sAXWjS/WGz98wvdgkDr29Vvug3PlfXDq7uEcg0MyH3hf5gd3ij7wgOhX8yr+
gBvFP3DGX3DGf3Av1c10P0nvD1F/heYL0/xR0pcr/oP15M85+ddB/o4eO/+d
hdz4HkpoP37an5b2eyP+gwOUjyDlx0H56qf8xSmfDZRfznc2//8B03zARQ==

           "]]}, $CellContext`staticpolygons1218898201471941642908865$$ = {
          AbsoluteThickness[1], 
          AbsolutePointSize[1], 
          EdgeForm[], 
          RGBColor[0.4, 0.6, 0.8], 
          Polygon[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGYC4gdvHshvEDxnzwAGL/bfmL22KdH6CJT/ZH/C
trkhIV47ofwH+x3qdp1b8W01lH9jvwPPBcviCTOg/Av7GdaF7rFMrYDyD+xn
QAeo8vZo+u3RzLdHs98ezX32aO63d/jpbsJpfAXOPyBzTIm/7ApcfcPspq+P
1lyBm+eg7KPVdv0K3L4D/x69/Pn1Ctw9B0oUOew5riLcO1mCJYwPxgeKoMrv
R9O/H838/Wj270dz33409+9Hjx8Am/yJ9A==
           
           "]]}, $CellContext`staticpolygons1418898201471941642968786$$ = {
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[CompressedData["
1:eJx1k19Ik2EUxke7KUOYuxFxLBJkkleCGE7h88oLrQRBSJ3zz9zc1NrAGBrR
auxiXeiCDRXCrgNBg5kw0n1jxiiYTG3UzIJtIrYgaFtCF4GZp50XHmjwMX4c
3vec5znPe3XE3m1WKhSKC2dfw79/1e3mtbfOb9J2/O/vs1TiwrUWT2hW8JC6
v+jfPRD1zvv6wLNPzGPL7usX8ylmbbKxo3X/A/Nkl2ToH0gyh4zNoXbvLnPi
vH+c+d6icv6oLMb88bLdkN3ZZA6G692yeoW5TQrXLb9xtZZ4ieoy66PzzHfp
fuZ31J95neZjnqD5mTWkj9lM+mXwh3mQ/JPBXxn8Zy5CfRjO/4T7rdD/Csxn
h/lfg74k6H8A/uTAvyPw17E6Z3z0fmGjxPOwnyjszwb7jcL+g5CPcchPNeRr
FPKXh3waIb95yDfm3xc9qTP4sswtp8qadYvgr5rfVc7vGeYbmcH61VrBhbYy
a1ydZn6c6osop74wWzUulUMS800kdC8PF4Wep+f995grjRFdhU34k9QX2n81
bYn398LfOz4cZJ5+Ylson/Hwe+ilusgbnWdW0f3Ms9Rf5IvmYx6j+ZldpI85
T/pl8If5mPyTwV8Z/P9vPQfnb8L9RejvhvkmYf47oC8A+mvAnzT45wV/G29p
TYFXz/k99MB+YrC/S7BfL+zfBPmwQH4eQr5+QP46IZ/HkF895LuU/z8JwBJE

           "]]}, $CellContext`staticpolygons1518898201471941642973884$$ = {
          AbsoluteThickness[1], 
          AbsolutePointSize[1], 
          EdgeForm[], 
          RGBColor[0.4, 0.6, 0.8], 
          Polygon[CompressedData["
1:eJxTTMoPSmVmYGBgAmJpKL1g4xPNBaUf7PsPfdWI6X+0f8PSBXdsaj7YvwOD
e/sLjObuXtr4wX5/xKdu1f039n/YtuLCrdYP9hPA6i/tvxCZrHyn44P9AbD8
if0JfvY7V3bB+Dv2K7A1TnXu/mDPAAYL9sDkd0Dk7WH690D028PM74OYbw+z
fx/Efns099nD3N8Lcb+9SelCdoN7n2H+sVedVrhiivVnuPr/az4ekdr1CeYf
+9tNdhbl4Z9g/rE/oetygk/oE8w/9kpXfTQuvvgI84+9U8LTC0q3P8L8YwOT
h/pnP0w/1D/7YeZD/bMfZj/UP/vR3Lcf5n6of/ajxw+a/zD0o/lvP5r/9qP5
bz+a//aj+W8Pmv/s0fxnj+Y/ezT/YYQ/mv/sLys5zT61+gs8vi7daJjkq/cV
rj4145uX+fSv8Pj6fWbDpC3Pv8Ljy1Bs2fH5Ct/g8dXiut201+kbPL5e/F75
8ZLvN3h8weRh8QXTD4svmPmw+ILZD4svNPfth7m/F0f8AAAD/+uM
           
           "]]}, $CellContext`staticpolygons1718898201471941642981873$$ = {
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGYC4iUFtlzXF/M4rJGJSrG+/9P+3l0Q4IbzJbzr
Nj4RR/CDdsi1vg7kgvN7VPdHfOrmhPOPTYrX+XmUA85nAAME3yp3wWU2K3Y4
v+SWw3LeEjY4f537wyqRdaxw/ostjX7SL1jgfCUwQPBj+w991YhhhvNj0Pjo
6tHNQ7cP3T3o7kX3D7p/0cMDPbzQwxM9vBejxQd6/AAAE++7vA==
           
           "]]}, $CellContext`staticpolygons1918898201471941642994612$$ = {
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          
          Line[{{{3.5, 2.}, {2.5, 2.}, {2.5, 2.}, {3.5, 2.}, {3.5, 2.}}, {{
            2.5, 2.}, {2.085786437626905, 3.}, {2.085786437626905, 3.}, {2.5, 
            2.}, {2.5, 2.}}, {{2.5, 3.414213562373095}, {2.085786437626905, 
            3.}, {2.085786437626905, 3.}, {2.5, 3.414213562373095}, {2.5, 
            3.414213562373095}}, {{3.5, 3.}, {2.5, 3.414213562373095}, {2.5, 
            3.414213562373095}, {3.5, 3.}, {3.5, 3.}}, {{3.5, 2.}, {3.5, 
            3.}, {3.5, 3.}, {3.5, 2.}, {3.5, 2.}}, {{3.500341421356237, 
            1.9996585786437628`}, {2.4998414213562374`, 
            1.9996585786437628`}, {2.085420752201956, 3.0001585786437626`}, {
            2.4998414213562374`, 3.414579247798044}, {3.500341421356237, 
            3.0001585786437626`}, {3.500341421356237, 
            1.9996585786437628`}}, {{3.500341421356237, 
            1.9996585786437628`}, {2.4998414213562374`, 
            1.9996585786437628`}, {2.085420752201956, 3.0001585786437626`}, {
            2.4998414213562374`, 3.414579247798044}, {3.500341421356237, 
            3.0001585786437626`}, {3.500341421356237, 
            1.9996585786437628`}}}]}, \
$CellContext`staticpolygons2118898201471941643006643$$ = {
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGZiQID+Q181Yvof7Yfx34HBPTh/f8SnbtX9N+D8
CWD1l+D8A2D5E2j8HXA+BCzYA2PtgMjbw/h7IPrh/D6I+XD+Poj9cD7UfXB+
L8T9cH4/Gh9d/X408yag2XcAzT0H0NwL9Y8Nmn/g/t2DFh59aOG1Dy080cO7
Fy0+YPEDAKxSgy8=
           
           "]]}, $CellContext`staticpolygons2218898201471941643007768$$ = {
          GrayLevel[0], 
          AbsoluteThickness[0.5], 
          Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGYCYu12sZvnyoUc+g991Yjpf7Qfxn8HBvfg/P0R
n7pV99+A8yeA1V+C8w+A5U+g8XfA+QxgsGAPjL8DIm8P4++B6Ifz+yDmw/n7
IPbbo7kPzu+FuN8ezT841e9HM28Cmn0H0NxzAM29UP/YoPlnP5p/9qP5Zz+a
f3CGdy9afMDiBwCT4NoX
           "]]}, $CellContext`t1$$ = 
        0.08, $CellContext`t2$$ = 0.2, $CellContext`ts2$$ = 
        0.081, $CellContext`x2$$ = 
        3.754060778668004, $CellContext`xLightAng$$ = -0.807075, \
$CellContext`xoffLightAng$$ = 0.12292500000000005`, $CellContext`xs$$ = 
        4.617000000000002, $CellContext`xs2$$ = 0.552, $CellContext`y1$$ = 
        1.8, $CellContext`yLightAng$$ = 0., $CellContext`yoffLightAng$$ = 0.},
       "ControllerVariables" :> {
        Hold[$CellContext`lam$$, $CellContext`lam$801997$$, 0], 
        Hold[$CellContext`LightAng$$, $CellContext`LightAng$801998$$, 0], 
        Hold[$CellContext`lightX$$, $CellContext`lightX$801999$$, 0], 
        Hold[$CellContext`as2$$, $CellContext`as2$802000$$, 0], 
        Hold[$CellContext`c11$$, $CellContext`c11$802001$$, 0], 
        Hold[$CellContext`c12$$, $CellContext`c12$802002$$, 0], 
        Hold[$CellContext`c21$$, $CellContext`c21$802003$$, 0], 
        Hold[$CellContext`c22$$, $CellContext`c22$802004$$, 0], 
        Hold[$CellContext`cs21$$, $CellContext`cs21$802005$$, 0], 
        Hold[$CellContext`cs22$$, $CellContext`cs22$802006$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Column[{
         Show[{
           Graphics[{{
              Opacity[
              0.8], $CellContext`staticpolygons1118898201471941642905813$$, \
$CellContext`staticpolygons1218898201471941642908865$$, 
              GeometricTransformation[{
                AbsoluteThickness[1], 
                AbsolutePointSize[1], 
                EdgeForm[], 
                RGBColor[0.4, 0.6, 0.8], 
                Polygon[
                 Dynamic[
                  (Map[
                   Function[{$CellContext`element}, 
                    Take[#, $CellContext`element]], {{1, 5}, {6, 10}, {11, 
                   15}, {16, 20}, {21, 25}, {26, 30}, {31, 35}, {36, 40}, {41,
                    45}, {46, 50}, {51, 55}, {56, 60}, {61, 65}, {66, 70}, {
                   71, 75}, {76, 80}, {81, 85}, {86, 90}, {91, 95}, {96, 
                   100}, {101, 105}, {106, 110}, {111, 115}, {116, 120}}]& )[
                   $CellContext`polygons1318898201471941642964617[$\
CellContext`as2$$, $CellContext`cs21$$, $CellContext`cs22$$, \
$CellContext`ts2$$]]]], 
                GrayLevel[0], 
                AbsoluteThickness[0.5], 
                Line[
                 Dynamic[
                  (Map[
                   Function[{$CellContext`element}, 
                    Take[#, $CellContext`element]], {{1, 1}, {2, 2}, {3, 7}, {
                   8, 12}, {13, 17}, {18, 22}, {23, 27}, {28, 32}, {33, 37}, {
                   38, 42}, {43, 47}, {48, 52}, {53, 57}, {58, 62}, {63, 
                   67}, {68, 72}, {73, 77}, {78, 82}, {83, 87}, {88, 92}, {93,
                    97}, {98, 102}, {103, 107}, {108, 112}, {113, 117}, {118, 
                   122}, {123, 127}, {128, 132}, {133, 137}, {138, 142}, {143,
                    147}, {148, 152}, {153, 157}, {158, 162}, {163, 167}, {
                   168, 172}, {173, 177}, {178, 182}, {183, 187}, {188, 
                   192}, {193, 197}, {198, 202}, {203, 207}, {208, 212}, {213,
                    217}, {218, 222}, {223, 227}, {228, 232}, {233, 237}, {
                   238, 242}}]& )[
                   $CellContext`lines1318898201471941642965473[$CellContext`\
as2$$, $CellContext`cs21$$, $CellContext`cs22$$, $CellContext`ts2$$]]]]}, 
               Dynamic[
               BesselJ[
                 1., 3.]; {{{1, 0}, {0, 
                  1}}, {$CellContext`xs2$$, 
                   0}}]], $CellContext`\
staticpolygons1418898201471941642968786$$, \
$CellContext`staticpolygons1518898201471941642973884$$, 
              GeometricTransformation[{
                GrayLevel[0], 
                AbsoluteThickness[0.5], 
                Line[
                 Dynamic[
                  (Map[
                   Function[{$CellContext`element}, 
                    Take[#, $CellContext`element]], {{1, 27}}]& )[
                   $CellContext`lines1618898201471941642980591[$CellContext`\
MirrorAngle$$]]]]}, 
               Dynamic[
               BesselJ[
                 1., 3.]; {{{
                   Cos[Degree $CellContext`MirrorAngle$$]/Sqrt[2] + 
                    Sin[Degree $CellContext`MirrorAngle$$]/Sqrt[2], 
                    Cos[Degree $CellContext`MirrorAngle$$]/Sqrt[2] - 
                    Sin[Degree $CellContext`MirrorAngle$$]/Sqrt[
                    2]}, {-(Cos[Degree $CellContext`MirrorAngle$$]/Sqrt[2]) + 
                    Sin[Degree $CellContext`MirrorAngle$$]/Sqrt[2], 
                    Cos[Degree $CellContext`MirrorAngle$$]/Sqrt[2] + 
                    Sin[Degree $CellContext`MirrorAngle$$]/Sqrt[2]}}, {
                  3 + (0.5 - 0.5 Cos[Degree $CellContext`MirrorAngle$$])/Sqrt[
                    2] + 0.35355339059327373` 
                    Sin[Degree $CellContext`MirrorAngle$$], (0.5 - 0.5 
                    Cos[Degree $CellContext`MirrorAngle$$])/Sqrt[2] - 
                   0.35355339059327373` 
                   Sin[Degree $CellContext`MirrorAngle$$]}}]], \
$CellContext`staticpolygons1718898201471941642981873$$, 
              GeometricTransformation[{
                AbsoluteThickness[1], 
                AbsolutePointSize[1], 
                EdgeForm[], 
                RGBColor[0.4, 0.6, 0.8], 
                Polygon[
                 Dynamic[
                  (Map[
                   Function[{$CellContext`element}, 
                    Take[#, $CellContext`element]], {{1, 27}}]& )[
                   $CellContext`polygons1818898201471941642992831[$\
CellContext`c11$$, $CellContext`c12$$, $CellContext`t1$$]]]]}, 
               Dynamic[
               BesselJ[
                 1., 3.]; {{{0, -1}, {1, 0}}, {
                  3, $CellContext`y1$$}}]], \
$CellContext`staticpolygons1918898201471941642994612$$, 
              GeometricTransformation[{
                AbsoluteThickness[1], 
                AbsolutePointSize[1], 
                EdgeForm[], 
                RGBColor[0.4, 0.6, 0.8], 
                Polygon[
                 Dynamic[
                  (Map[
                   Function[{$CellContext`element}, 
                    Take[#, $CellContext`element]], {{1, 27}}]& )[
                   $CellContext`polygons2018898201471941643005225[$\
CellContext`c21$$, $CellContext`c22$$, $CellContext`t2$$]]]]}, 
               Dynamic[
               BesselJ[
                 1., 3.]; {{{1, 0}, {0, 1}}, {$CellContext`x2$$, 2.5}}]], 
              
              GeometricTransformation[$CellContext`\
staticpolygons2118898201471941643006643$$, 
               Dynamic[
               BesselJ[
                 1., 3.]; {{{1, 0}, {0, 
                  1}}, {$CellContext`xs$$, 
                   2.5}}]], \
$CellContext`staticpolygons2218898201471941643007768$$, 
              Opacity[1], 
              RGBColor[
               
               Abs[(-0.3183098861837907) 
                 ArcTan[63.75 - 0.25 
                   Abs[-500. + 2. Mod[100. + 500. $CellContext`lam$$, 500.]]] + 
                0.3183098861837907 
                 ArcTan[43. - 0.1 
                   Abs[-500. + 
                    2. Mod[100. + 500. $CellContext`lam$$, 500.]]]], 
               Abs[
               0.3183098861837907 
                 ArcTan[60. - 0.2 
                   Abs[-500. + 2. Mod[100. + 500. $CellContext`lam$$, 500.]]] - 
                0.3183098861837907 
                ArcTan[18. - 0.1 
                  Abs[-500. + 2. Mod[100. + 500. $CellContext`lam$$, 500.]]]], 
               
               Abs[(-0.3183098861837907) 
                 ArcTan[10. - 0.2 
                   Abs[-500. + 2. Mod[100. + 500. $CellContext`lam$$, 500.]]] + 
                0.3183098861837907 
                 ArcTan[22.5 - 0.125 
                   Abs[-500. + 
                    2. Mod[100. + 500. $CellContext`lam$$, 500.]]]]], 
              AbsoluteThickness[Medium], 
              Line[
               Dynamic[
                Refresh[
                 Map[{
                   Part[#, {1, 2}], 
                   Part[#, {4, 5}]}& , 
                  Select[
                   $CellContext`raytracefunction118898201471941643017026[$\
CellContext`LightAng$$, $CellContext`lightX$$, $CellContext`as2$$, \
$CellContext`c11$$, $CellContext`c12$$, $CellContext`c21$$, \
$CellContext`c22$$, $CellContext`cs21$$, $CellContext`cs22$$, \
$CellContext`MirrorAngle$$, $CellContext`t1$$, $CellContext`t2$$, \
$CellContext`ts2$$, $CellContext`x2$$, $CellContext`xs$$, $CellContext`xs2$$, \
$CellContext`y1$$], And[Length[#] == 6, Part[#, 1] > -9.87654321*^8]& ]], 
                 TrackedSymbols :> {$CellContext`LightAng$$, \
$CellContext`lightX$$, $CellContext`as2$$, $CellContext`c11$$, \
$CellContext`c12$$, $CellContext`c21$$, $CellContext`c22$$, \
$CellContext`cs21$$, $CellContext`cs22$$, $CellContext`MirrorAngle$$, \
$CellContext`t1$$, $CellContext`t2$$, $CellContext`ts2$$, $CellContext`x2$$, \
$CellContext`xs$$, $CellContext`xs2$$, $CellContext`y1$$}], 
                SynchronousUpdating -> False]], 
              Arrowheads[Large], 
              Thickness[Large], 
              Dashing[{Small, Small}], 
              RGBColor[1, 1, 0], 
              Arrow[
               Dynamic[If[
                  
                  Or[$CellContext`laststartposLightAng$$ != \
{$CellContext`lightX$$, 
                    0}, $CellContext`lastLightAng$$ =!= \
$CellContext`LightAng$$], $CellContext`laststartposLightAng$$ = \
{$CellContext`lightX$$, 
                    0}; $CellContext`lastLightAng$$ = $CellContext`LightAng$$; \
{$CellContext`xLightAng$$, $CellContext`yLightAng$$} = \
$CellContext`laststartposLightAng$$ + $CellContext`radiusLightAng$$ {
                    Cos[$CellContext`LightAng$$ Degree], 
                    
                    Sin[$CellContext`LightAng$$ 
                    Degree]}]; {$CellContext`laststartposLightAng$$, \
{$CellContext`xLightAng$$, $CellContext`yLightAng$$}}, \
({$CellContext`laststartposLightAng$$, {$CellContext`xLightAng$$, \
$CellContext`yLightAng$$}} = #)& ]], 
              Tooltip[
               Locator[
                Dynamic[BesselJ[1., 3.]; (If[
                    
                    Or[{$CellContext`xLightAng$$, $CellContext`yLightAng$$} != \
$CellContext`lastlocposLightAng$$, $CellContext`lastLightAng$$ != \
$CellContext`LightAng$$], $CellContext`lastlocposLightAng$$ = \
{$CellContext`xLightAng$$, $CellContext`yLightAng$$}; \
$CellContext`lastLightAng$$ = $CellContext`LightAng$$; \
{$CellContext`xLightAng$$, $CellContext`yLightAng$$} = \
$CellContext`laststartposLightAng$$ + $CellContext`radiusLightAng$$ {
                    Cos[$CellContext`LightAng$$ Degree], 
                    
                    Sin[$CellContext`LightAng$$ 
                    Degree]}]; {$CellContext`xLightAng$$, \
$CellContext`yLightAng$$}), ({$CellContext`xLightAng$$, \
$CellContext`yLightAng$$} = #; $CellContext`xoffLightAng$$ = \
$CellContext`xLightAng$$ - $CellContext`lightX$$; $CellContext`yoffLightAng$$ = \
$CellContext`yLightAng$$ + 0; $CellContext`radiusLightAng$$ = 
                  Sqrt[$CellContext`xoffLightAng$$^2 + \
$CellContext`yoffLightAng$$^2]; $CellContext`LightAng$$ = 
                  Chop[ArcTan[$CellContext`xoffLightAng$$, \
$CellContext`yoffLightAng$$]/
                    Degree]; {$CellContext`xLightAng$$, \
$CellContext`yLightAng$$})& ], 
                Graphics[{
                  RGBColor[1/3, 1/3, 1], 
                  Disk[{0, 0}, 0.5]}, ImageSize -> 10]], 
               Dynamic[
                StringJoin["LightAng = ", 
                 ToString[$CellContext`LightAng$$]]]], 
              Tooltip[
               Locator[
                Dynamic[
                BesselJ[
                  1., 3.]; {$CellContext`lightX$$, 0}, ($CellContext`lightX$$ = 
                 Chop[
                   Part[#, 1]])& ], 
                Graphics[{
                  RGBColor[1, 1/3, 1/3], 
                  Disk[{0, 0}, 0.8]}, ImageSize -> 10]], 
               Dynamic[
                StringJoin["lightX = ", 
                 ToString[$CellContext`lightX$$]]]], 
              Tooltip[
               Locator[
                Dynamic[
                BesselJ[1., 3.]; {$CellContext`xs2$$, 0}, ($CellContext`xs2$$ = 
                 Chop[
                   Part[#, 1]])& ], 
                Graphics[{
                  RGBColor[1, 1/3, 1/3], 
                  Disk[{0, 0}, 0.8]}, ImageSize -> 10]], 
               Dynamic[
                StringJoin["Tessar Middle Lens x = ", 
                 ToString[$CellContext`xs2$$]]]], 
              Tooltip[
               Locator[
                Dynamic[
                BesselJ[1., 3.]; {3, $CellContext`y1$$}, ($CellContext`y1$$ = 
                 Chop[
                   Part[#, 2]])& ], 
                Graphics[{
                  RGBColor[1, 1/3, 1/3], 
                  Disk[{0, 0}, 0.8]}, ImageSize -> 10]], 
               Dynamic[
                StringJoin["y1 = ", 
                 ToString[$CellContext`y1$$]]]], 
              Tooltip[
               Locator[
                Dynamic[
                BesselJ[1., 3.]; {$CellContext`x2$$, 2.5}, ($CellContext`x2$$ = 
                 Chop[
                   Part[#, 1]])& ], 
                Graphics[{
                  RGBColor[1, 1/3, 1/3], 
                  Disk[{0, 0}, 0.8]}, ImageSize -> 10]], 
               Dynamic[
                StringJoin["x2 = ", 
                 ToString[$CellContext`x2$$]]]], 
              Tooltip[
               Locator[
                Dynamic[
                BesselJ[1., 3.]; {$CellContext`xs$$, 2.5}, ($CellContext`xs$$ = 
                 Chop[
                   Part[#, 1]])& ], 
                Graphics[{
                  RGBColor[1, 1/3, 1/3], 
                  Disk[{0, 0}, 0.8]}, ImageSize -> 10]], 
               Dynamic[
                StringJoin["xs = ", 
                 ToString[$CellContext`xs$$]]]]}}]}, {
          PlotLabel -> "TopView", Axes -> True, ImageSize -> 600, ImageSize -> 
           800, AspectRatio -> Automatic}], 
         Tooltip[
          Row[{
            Style["", Italic, 10], 
            Hyperlink[
             Style["<< Crafted with Optica\[Trademark] >>", Italic, 10], 
             "http://www.opticasoftware.com"], 
            Style["", Italic, 10]}], 
          "Click here to visit www.opticasoftware.com"]}, Center], 
      "Specifications" :> {{{$CellContext`lam$$, 0.532}, 0.4, 0.7, 
         ControlType -> None}, {{$CellContext`LightAng$$, 0.}, -180., 180., 
         ControlType -> None}, {{$CellContext`lightX$$, -0.93}, -1.86, -0.009,
          ControlType -> None}, {{$CellContext`as2$$, 0.98}, 0.1, 1.47, 
         ControlType -> None}, {{$CellContext`c11$$, -21.}, -42, -0.21, 
         ControlType -> None}, {{$CellContext`c12$$, -2.}, -4, -0.02, 
         ControlType -> None}, {{$CellContext`c21$$, 3.02}, 2., 4., 
         ControlType -> None}, {{$CellContext`c22$$, -3.34}, -4, -2, 
         ControlType -> None}, {{$CellContext`cs21$$, -2.433}, -5, -0.024, 
         ControlType -> None}, {{$CellContext`cs22$$, 1.1718}, 0.1, 
         1.7576999999999998`, ControlType -> 
         None}, {{$CellContext`MirrorAngle$$, 0.}, -180., 180., ControlType -> 
         None}, {{$CellContext`t1$$, 0.08}, -0.8, 0.8, ControlType -> 
         None}, {{$CellContext`t2$$, 0.2}, 0.15, 0.4, ControlType -> 
         None}, {{$CellContext`ts2$$, 0.081}, -0.81, 0.81, ControlType -> 
         None}, {{$CellContext`x2$$, 3.754060778668004}, 0.037, 8, 
         ControlType -> None}, {{$CellContext`xs$$, 4.617000000000002}, 0.046,
          9, ControlType -> None}, {{$CellContext`xs2$$, 0.552}, 0.5, 0.6, 
         ControlType -> None}, {{$CellContext`y1$$, 1.8}, 0.018, 4, 
         ControlType -> 
         None}, {{$CellContext`MirrorAngle$$, 0, "Click for Photo"}, {
         0 -> "Viewfinder", -45 -> "Film"}}, {{$CellContext`minlam$$, 0.1}, 
         ControlType -> None}, {{$CellContext`maxlam$$, 0.798}, ControlType -> 
         None}, {{$CellContext`minLightAng$$, -180.}, ControlType -> 
         None}, {{$CellContext`maxLightAng$$, 180.}, ControlType -> 
         None}, {{$CellContext`minlightX$$, -1.86}, ControlType -> 
         None}, {{$CellContext`maxlightX$$, -0.009}, ControlType -> 
         None}, {{$CellContext`minas2$$, 0.1}, ControlType -> 
         None}, {{$CellContext`maxas2$$, 1.47}, ControlType -> 
         None}, {{$CellContext`minc11$$, -42}, ControlType -> 
         None}, {{$CellContext`maxc11$$, -0.21}, ControlType -> 
         None}, {{$CellContext`minc12$$, -4}, ControlType -> 
         None}, {{$CellContext`maxc12$$, -0.02}, ControlType -> 
         None}, {{$CellContext`minc21$$, 0.03}, ControlType -> 
         None}, {{$CellContext`maxc21$$, 6}, ControlType -> 
         None}, {{$CellContext`minc22$$, -7}, ControlType -> 
         None}, {{$CellContext`maxc22$$, -0.033}, ControlType -> 
         None}, {{$CellContext`mincs21$$, -5}, ControlType -> 
         None}, {{$CellContext`maxcs21$$, -0.024}, ControlType -> 
         None}, {{$CellContext`mincs22$$, 0.1}, ControlType -> 
         None}, {{$CellContext`maxcs22$$, 1.7576999999999998`}, ControlType -> 
         None}, {{$CellContext`minMirrorAngle$$, -180.}, ControlType -> 
         None}, {{$CellContext`maxMirrorAngle$$, 180.}, ControlType -> 
         None}, {{$CellContext`mint1$$, -0.8}, ControlType -> 
         None}, {{$CellContext`maxt1$$, 0.8}, ControlType -> 
         None}, {{$CellContext`mint2$$, 0.1}, ControlType -> 
         None}, {{$CellContext`maxt2$$, 0.30000000000000004`}, ControlType -> 
         None}, {{$CellContext`mints2$$, -0.81}, ControlType -> 
         None}, {{$CellContext`maxts2$$, 0.81}, ControlType -> 
         None}, {{$CellContext`minx2$$, 0.037}, ControlType -> 
         None}, {{$CellContext`maxx2$$, 8}, ControlType -> 
         None}, {{$CellContext`minxs$$, 0.046}, ControlType -> 
         None}, {{$CellContext`maxxs$$, 9}, ControlType -> 
         None}, {{$CellContext`minxs2$$, 0.1}, ControlType -> 
         None}, {{$CellContext`maxxs2$$, 0.8280000000000001}, ControlType -> 
         None}, {{$CellContext`miny1$$, 0.018}, ControlType -> 
         None}, {{$CellContext`maxy1$$, 4}, ControlType -> None}, 
        Style[
         Grid[{{"Wavelength", 
            InputField[
             Dynamic[$CellContext`minlam$$], Number, FieldSize -> 5], 
            Manipulator[
             
             Dynamic[$CellContext`\
nonexistantvariable159318898201471941649834335; $CellContext`lam$$, \
($CellContext`lam$$ = #)& ], {
              Dynamic[$CellContext`minlam$$], 
              Dynamic[$CellContext`maxlam$$]}, ImageSize -> 800], 
            InputField[
             Dynamic[$CellContext`maxlam$$], Number, FieldSize -> 5], 
            
            Dynamic[$CellContext`\
nonexistantvariable159318898201471941649834335; $CellContext`lam$$, \
($CellContext`lam$$ = #)& ]}}]], {{$CellContext`minlam$$, 0.4}, ControlType -> 
         None}, {{$CellContext`maxlam$$, 0.7}, ControlType -> None}, 
        Style[
         Grid[{{"Eyepiece c1", 
            InputField[
             Dynamic[$CellContext`minc21$$], Number, FieldSize -> 5], 
            Manipulator[
             
             Dynamic[$CellContext`\
nonexistantvariable159318898201471941649834547; $CellContext`c21$$, \
($CellContext`c21$$ = #)& ], {
              Dynamic[$CellContext`minc21$$], 
              Dynamic[$CellContext`maxc21$$]}, ImageSize -> 800], 
            InputField[
             Dynamic[$CellContext`maxc21$$], Number, FieldSize -> 5], 
            
            Dynamic[$CellContext`\
nonexistantvariable159318898201471941649834547; $CellContext`c21$$, \
($CellContext`c21$$ = #)& ]}}]], {{$CellContext`minc21$$, 2.}, ControlType -> 
         None}, {{$CellContext`maxc21$$, 4.}, ControlType -> None}, 
        Style[
         Grid[{{"Eyepiece c2", 
            InputField[
             Dynamic[$CellContext`minc22$$], Number, FieldSize -> 5], 
            Manipulator[
             
             Dynamic[$CellContext`\
nonexistantvariable159318898201471941649834706; $CellContext`c22$$, \
($CellContext`c22$$ = #)& ], {
              Dynamic[$CellContext`minc22$$], 
              Dynamic[$CellContext`maxc22$$]}, ImageSize -> 800], 
            InputField[
             Dynamic[$CellContext`maxc22$$], Number, FieldSize -> 5], 
            
            Dynamic[$CellContext`\
nonexistantvariable159318898201471941649834706; $CellContext`c22$$, \
($CellContext`c22$$ = #)& ]}}]], {{$CellContext`minc22$$, -4}, ControlType -> 
         None}, {{$CellContext`maxc22$$, -2}, ControlType -> None}, 
        Style[
         Grid[{{"Eyepiece thickness", 
            InputField[
             Dynamic[$CellContext`mint2$$], Number, FieldSize -> 5], 
            Manipulator[
             
             Dynamic[$CellContext`\
nonexistantvariable159318898201471941649834856; $CellContext`t2$$, \
($CellContext`t2$$ = #)& ], {
              Dynamic[$CellContext`mint2$$], 
              Dynamic[$CellContext`maxt2$$]}, ImageSize -> 800], 
            InputField[
             Dynamic[$CellContext`maxt2$$], Number, FieldSize -> 5], 
            
            Dynamic[$CellContext`\
nonexistantvariable159318898201471941649834856; $CellContext`t2$$, \
($CellContext`t2$$ = #)& ]}}]], {{$CellContext`mint2$$, 0.15}, ControlType -> 
         None}, {{$CellContext`maxt2$$, 0.4}, ControlType -> None}, 
        Style[
         Grid[{{"Tessar Middle Lens x", 
            InputField[
             Dynamic[$CellContext`minxs2$$], Number, FieldSize -> 5], 
            Manipulator[
             
             Dynamic[$CellContext`\
nonexistantvariable159318898201471941649835000; $CellContext`xs2$$, \
($CellContext`xs2$$ = #)& ], {
              Dynamic[$CellContext`minxs2$$], 
              Dynamic[$CellContext`maxxs2$$]}, ImageSize -> 800], 
            InputField[
             Dynamic[$CellContext`maxxs2$$], Number, FieldSize -> 5], 
            
            Dynamic[$CellContext`\
nonexistantvariable159318898201471941649835000; $CellContext`xs2$$, \
($CellContext`xs2$$ = #)& ]}}]], {{$CellContext`minxs2$$, 0.5}, ControlType -> 
         None}, {{$CellContext`maxxs2$$, 0.6}, ControlType -> 
         None}, {{$CellContext`minlam$$, 0.1}, ControlType -> 
         None}, {{$CellContext`maxlam$$, 0.798}, ControlType -> 
         None}, {{$CellContext`minLightAng$$, -180.}, ControlType -> 
         None}, {{$CellContext`maxLightAng$$, 180.}, ControlType -> 
         None}, {{$CellContext`minlightX$$, -1.86}, ControlType -> 
         None}, {{$CellContext`maxlightX$$, -0.009}, ControlType -> 
         None}, {{$CellContext`minas2$$, 0.1}, ControlType -> 
         None}, {{$CellContext`maxas2$$, 1.47}, ControlType -> 
         None}, {{$CellContext`minc11$$, -42}, ControlType -> 
         None}, {{$CellContext`maxc11$$, -0.21}, ControlType -> 
         None}, {{$CellContext`minc12$$, -4}, ControlType -> 
         None}, {{$CellContext`maxc12$$, -0.02}, ControlType -> 
         None}, {{$CellContext`minc21$$, 0.03}, ControlType -> 
         None}, {{$CellContext`maxc21$$, 6}, ControlType -> 
         None}, {{$CellContext`minc22$$, -7}, ControlType -> 
         None}, {{$CellContext`maxc22$$, -0.033}, ControlType -> 
         None}, {{$CellContext`mincs21$$, -5}, ControlType -> 
         None}, {{$CellContext`maxcs21$$, -0.024}, ControlType -> 
         None}, {{$CellContext`mincs22$$, 0.1}, ControlType -> 
         None}, {{$CellContext`maxcs22$$, 1.7576999999999998`}, ControlType -> 
         None}, {{$CellContext`minMirrorAngle$$, -180.}, ControlType -> 
         None}, {{$CellContext`maxMirrorAngle$$, 180.}, ControlType -> 
         None}, {{$CellContext`mint1$$, -0.8}, ControlType -> 
         None}, {{$CellContext`maxt1$$, 0.8}, ControlType -> 
         None}, {{$CellContext`mint2$$, 0.1}, ControlType -> 
         None}, {{$CellContext`maxt2$$, 0.30000000000000004`}, ControlType -> 
         None}, {{$CellContext`mints2$$, -0.81}, ControlType -> 
         None}, {{$CellContext`maxts2$$, 0.81}, ControlType -> 
         None}, {{$CellContext`minx2$$, 0.037}, ControlType -> 
         None}, {{$CellContext`maxx2$$, 8}, ControlType -> 
         None}, {{$CellContext`minxs$$, 0.046}, ControlType -> 
         None}, {{$CellContext`maxxs$$, 9}, ControlType -> 
         None}, {{$CellContext`minxs2$$, 0.1}, ControlType -> 
         None}, {{$CellContext`maxxs2$$, 0.8280000000000001}, ControlType -> 
         None}, {{$CellContext`miny1$$, 0.018}, ControlType -> 
         None}, {{$CellContext`maxy1$$, 4}, ControlType -> 
         None}, {{$CellContext`minlam$$, 0.4}, ControlType -> 
         None}, {{$CellContext`maxlam$$, 0.7}, ControlType -> 
         None}, {{$CellContext`minc21$$, 2.}, ControlType -> 
         None}, {{$CellContext`maxc21$$, 4.}, ControlType -> 
         None}, {{$CellContext`minc22$$, -4}, ControlType -> 
         None}, {{$CellContext`maxc22$$, -2}, ControlType -> 
         None}, {{$CellContext`mint2$$, 0.15}, ControlType -> 
         None}, {{$CellContext`maxt2$$, 0.4}, ControlType -> 
         None}, {{$CellContext`minxs2$$, 0.5}, ControlType -> 
         None}, {{$CellContext`maxxs2$$, 0.6}, ControlType -> None}, 
        Button[
        "Report", 
         Optica`Optica`$OpticalSystemSettings = {
           Optica`Optica`SymbolicValues -> 
            MapThread[
             ToExpression[#] -> #2& , {{
               "LightAng", "lightX", "as2", "c11", "c12", "Eyepiece c1", 
                "Eyepiece c2", "cs21", "cs22", "MirrorAngle", "t1", 
                "Eyepiece thickness", "ts2", "x2", "xs", 
                "Tessar Middle Lens x", 
                "y1"}, {$CellContext`LightAng$$, $CellContext`lightX$$, \
$CellContext`as2$$, $CellContext`c11$$, $CellContext`c12$$, \
$CellContext`c21$$, $CellContext`c22$$, $CellContext`cs21$$, \
$CellContext`cs22$$, $CellContext`MirrorAngle$$, $CellContext`t1$$, \
$CellContext`t2$$, $CellContext`ts2$$, $CellContext`x2$$, $CellContext`xs$$, \
$CellContext`xs2$$, $CellContext`y1$$}}], Optica`Optica`SymbolicRanges -> 
            Map[ToExpression[
                Part[#, 1]] -> {
                Part[#, 2], 
                Part[#, 3]}& , 
              Select[
               
               Transpose[{{
                 "LightAng", "lightX", "as2", "c11", "c12", "Eyepiece c1", 
                  "Eyepiece c2", "cs21", "cs22", "MirrorAngle", "t1", 
                  "Eyepiece thickness", "ts2", "x2", "xs", 
                  "Tessar Middle Lens x", 
                  "y1"}, {$CellContext`minLightAng$$, \
$CellContext`minlightX$$, $CellContext`minas2$$, $CellContext`minc11$$, \
$CellContext`minc12$$, $CellContext`minc21$$, $CellContext`minc22$$, \
$CellContext`mincs21$$, $CellContext`mincs22$$, \
$CellContext`minMirrorAngle$$, $CellContext`mint1$$, $CellContext`mint2$$, \
$CellContext`mints2$$, $CellContext`minx2$$, $CellContext`minxs$$, \
$CellContext`minxs2$$, $CellContext`miny1$$}, {$CellContext`maxLightAng$$, \
$CellContext`maxlightX$$, $CellContext`maxas2$$, $CellContext`maxc11$$, \
$CellContext`maxc12$$, $CellContext`maxc21$$, $CellContext`maxc22$$, \
$CellContext`maxcs21$$, $CellContext`maxcs22$$, \
$CellContext`maxMirrorAngle$$, $CellContext`maxt1$$, $CellContext`maxt2$$, \
$CellContext`maxts2$$, $CellContext`maxx2$$, $CellContext`maxxs$$, \
$CellContext`maxxs2$$, $CellContext`maxy1$$}}], NumberQ[
                Part[#, 2]]& ]]}; 
         Optica`Optica`$OpticalSystemScript = 
          "{Move[LineOfRays[0.98, NumberOfRays -> 8, WaveLength -> lam], \
{lightX, -0.93}, {LightAng, 0.}, SymbolicValues -> {LightAng -> 0, lightX -> \
-0.93}], Move[ApertureStop[3, 0.9], -0.3], SphericalLens[1.3147, -21.019, \
1.5, 0.329, {ComponentMedium -> SK15}], Move[SphericalLens[{cs21, -2.433}, \
{cs22, 1.1718}, {as2, 0.98}, {ts2, 0.081}, {ComponentMedium -> F2}], {xs2, \
0.552}, SymbolicValues -> {xs2 -> 0.552}], Move[ApertureStop[1.16, 0.9], \
0.827], Move[LensDoublet[-31.8418, 1.4005, -1.6991, 1.16, 0.082, 0.278, K10, \
SK15], 1.034], Move[Mirror[1.], {{3 + (0.5 - \
0.5*Cos[Degree*MirrorAngle])/Sqrt[2] + \
0.35355339059327373*Sin[Degree*MirrorAngle], 3.}, {(0.5 - \
0.5*Cos[Degree*MirrorAngle])/Sqrt[2] - \
0.35355339059327373*Sin[Degree*MirrorAngle], 0}}, {MirrorAngle - \
Pi/(4*Degree), -45.}, SymbolicValues -> {MirrorAngle -> 0}], \
Move[Screen[1.16], {3., 1.617}, 90.], Move[SphericalLens[{c11, -21.}, {c12, \
-2}, 1.16, {t1, 0.08}], {3., {y1, 1.8}}, 90., SymbolicValues -> {y1 -> 1.8}], \
Move[PentaPrism[1], {3., 2.}, 90.], Move[SphericalLens[{c21, 2.}, {c22, -2}, \
1.16, {t2, 0.2}], {{x2, 4.}, 2.5}, SymbolicValues -> {x2 -> 4}], \
Move[Screen[1.16], {{xs, 4.617}, 2.5}, SymbolicValues -> {xs -> 4.617}], \
Move[Screen[1.16], 4.617]}"; Print[
           InputForm[
            StringJoin["{SymbolicValues -> ", 
             ToString[
              MapThread[StringJoin[#, "->", 
                ToString[#2, InputForm]]& , {{
                "LightAng", "lightX", "as2", "c11", "c12", "Eyepiece c1", 
                 "Eyepiece c2", "cs21", "cs22", "MirrorAngle", "t1", 
                 "Eyepiece thickness", "ts2", "x2", "xs", 
                 "Tessar Middle Lens x", 
                 "y1"}, {$CellContext`LightAng$$, $CellContext`lightX$$, \
$CellContext`as2$$, $CellContext`c11$$, $CellContext`c12$$, \
$CellContext`c21$$, $CellContext`c22$$, $CellContext`cs21$$, \
$CellContext`cs22$$, $CellContext`MirrorAngle$$, $CellContext`t1$$, \
$CellContext`t2$$, $CellContext`ts2$$, $CellContext`x2$$, $CellContext`xs$$, \
$CellContext`xs2$$, $CellContext`y1$$}}]], ", SymbolicRanges -> ", 
             ToString[
              Map[StringJoin[
                Part[#, 1], "->", 
                ToString[{
                  Part[#, 2], 
                  Part[#, 3]}, InputForm]]& , 
               Select[
                
                Transpose[{{
                  "LightAng", "lightX", "as2", "c11", "c12", "Eyepiece c1", 
                   "Eyepiece c2", "cs21", "cs22", "MirrorAngle", "t1", 
                   "Eyepiece thickness", "ts2", "x2", "xs", 
                   "Tessar Middle Lens x", 
                   "y1"}, {$CellContext`minLightAng$$, \
$CellContext`minlightX$$, $CellContext`minas2$$, $CellContext`minc11$$, \
$CellContext`minc12$$, $CellContext`minc21$$, $CellContext`minc22$$, \
$CellContext`mincs21$$, $CellContext`mincs22$$, \
$CellContext`minMirrorAngle$$, $CellContext`mint1$$, $CellContext`mint2$$, \
$CellContext`mints2$$, $CellContext`minx2$$, $CellContext`minxs$$, \
$CellContext`minxs2$$, $CellContext`miny1$$}, {$CellContext`maxLightAng$$, \
$CellContext`maxlightX$$, $CellContext`maxas2$$, $CellContext`maxc11$$, \
$CellContext`maxc12$$, $CellContext`maxc21$$, $CellContext`maxc22$$, \
$CellContext`maxcs21$$, $CellContext`maxcs22$$, \
$CellContext`maxMirrorAngle$$, $CellContext`maxt1$$, $CellContext`maxt2$$, \
$CellContext`maxts2$$, $CellContext`maxx2$$, $CellContext`maxxs$$, \
$CellContext`maxxs2$$, $CellContext`maxy1$$}}], NumberQ[
                 Part[#, 2]]& ]]], "}"]]], ImageSize -> 
         Automatic], {{$CellContext`xLightAng$$, -0.807075}, ControlType -> 
         None}, {{$CellContext`yLightAng$$, 0.}, ControlType -> 
         None}, {{$CellContext`radiusLightAng$$, 0.12292500000000005`}, 
         ControlType -> 
         None}, {{$CellContext`xoffLightAng$$, 0.12292500000000005`}, 
         ControlType -> None}, {{$CellContext`yoffLightAng$$, 0.}, 
         ControlType -> 
         None}, {{$CellContext`laststartposLightAng$$, {-0.93, 0}}, 
         ControlType -> 
         None}, {{$CellContext`lastlocposLightAng$$, {-0.807075, 0.}}, 
         ControlType -> None}, {{$CellContext`lastLightAng$$, 0}, ControlType -> 
         None}, {{$CellContext`staticpolygons1118898201471941642905813$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[CompressedData["
1:eJxdk09I2nEYxsUgwg6B18VG0CFWCFGwuQKjQ4ctSrpqVmOy1axfhxI2on90
qKA6FBUbNQg6CXUQAsklxBiLjC1ym5kkCNEfKDLN2kFa+erzg+cLIh9evt/3
fZ73+RW9VprsORqNRnv/K8/8V6TPnm/H/3DCpixfPa0a8Uyo3Kq3xKd3D9T6
q48vZj6HwG9dw8/yYkHw40Dly+r9P2BHo8lqaQ6APTajp250F/wz3d8P7pnP
mT3SfQf/zVes0V9fwe6N0mGffgVcY9oocX0bqM7ygtR90Cf3wV3yPnhL+oPX
ZD7we5kfXCj6wHbRD874A24R/9S6+KvOJ/6D41Rvo/sJev8d9X9C8yk0/zrp
C5D+PvLnlPw7In+7Vydtg3tz3izP0n42aX/ttN9N2r+b8tFB+XlE+XpD+YtR
Pm2U3xjlm/OvSZ9bNY8N5RfK9g3YPOW8XjaonDi1H5jLkuBBY60h/CMB7rIM
nVh1cXDIEfE7by/BkYWWSO/zc7A23f8EnH+nTbXbouDDMeuSN6jqrekpnvtS
sAXWjS/WGz98wvdgkDr29Vvug3PlfXDq7uEcg0MyH3hf5gd3ij7wgOhX8yr+
gBvFP3DGX3DGf3Av1c10P0nvD1F/heYL0/xR0pcr/oP15M85+ddB/o4eO/+d
hdz4HkpoP37an5b2eyP+gwOUjyDlx0H56qf8xSmfDZRfznc2//8B03zARQ==

            "]]}}, ControlType -> 
         None}, {{$CellContext`staticpolygons1218898201471941642908865$$, {
           AbsoluteThickness[1], 
           AbsolutePointSize[1], 
           EdgeForm[], 
           RGBColor[0.4, 0.6, 0.8], 
           Polygon[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGYC4gdvHshvEDxnzwAGL/bfmL22KdH6CJT/ZH/C
trkhIV47ofwH+x3qdp1b8W01lH9jvwPPBcviCTOg/Av7GdaF7rFMrYDyD+xn
QAeo8vZo+u3RzLdHs98ezX32aO63d/jpbsJpfAXOPyBzTIm/7ApcfcPspq+P
1lyBm+eg7KPVdv0K3L4D/x69/Pn1Ctw9B0oUOew5riLcO1mCJYwPxgeKoMrv
R9O/H838/Wj270dz33409+9Hjx8Am/yJ9A==
            "]]}}, ControlType -> 
         None}, {{$CellContext`staticpolygons1418898201471941642968786$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[CompressedData["
1:eJx1k19Ik2EUxke7KUOYuxFxLBJkkleCGE7h88oLrQRBSJ3zz9zc1NrAGBrR
auxiXeiCDRXCrgNBg5kw0n1jxiiYTG3UzIJtIrYgaFtCF4GZp50XHmjwMX4c
3vec5znPe3XE3m1WKhSKC2dfw79/1e3mtbfOb9J2/O/vs1TiwrUWT2hW8JC6
v+jfPRD1zvv6wLNPzGPL7usX8ylmbbKxo3X/A/Nkl2ToH0gyh4zNoXbvLnPi
vH+c+d6icv6oLMb88bLdkN3ZZA6G692yeoW5TQrXLb9xtZZ4ieoy66PzzHfp
fuZ31J95neZjnqD5mTWkj9lM+mXwh3mQ/JPBXxn8Zy5CfRjO/4T7rdD/Csxn
h/lfg74k6H8A/uTAvyPw17E6Z3z0fmGjxPOwnyjszwb7jcL+g5CPcchPNeRr
FPKXh3waIb95yDfm3xc9qTP4sswtp8qadYvgr5rfVc7vGeYbmcH61VrBhbYy
a1ydZn6c6osop74wWzUulUMS800kdC8PF4Wep+f995grjRFdhU34k9QX2n81
bYn398LfOz4cZJ5+Ylson/Hwe+ilusgbnWdW0f3Ms9Rf5IvmYx6j+ZldpI85
T/pl8If5mPyTwV8Z/P9vPQfnb8L9RejvhvkmYf47oC8A+mvAnzT45wV/G29p
TYFXz/k99MB+YrC/S7BfL+zfBPmwQH4eQr5+QP46IZ/HkF895LuU/z8JwBJE

            "]]}}, ControlType -> 
         None}, {{$CellContext`staticpolygons1518898201471941642973884$$, {
           AbsoluteThickness[1], 
           AbsolutePointSize[1], 
           EdgeForm[], 
           RGBColor[0.4, 0.6, 0.8], 
           Polygon[CompressedData["
1:eJxTTMoPSmVmYGBgAmJpKL1g4xPNBaUf7PsPfdWI6X+0f8PSBXdsaj7YvwOD
e/sLjObuXtr4wX5/xKdu1f039n/YtuLCrdYP9hPA6i/tvxCZrHyn44P9AbD8
if0JfvY7V3bB+Dv2K7A1TnXu/mDPAAYL9sDkd0Dk7WH690D028PM74OYbw+z
fx/Efns099nD3N8Lcb+9SelCdoN7n2H+sVedVrhiivVnuPr/az4ekdr1CeYf
+9tNdhbl4Z9g/rE/oetygk/oE8w/9kpXfTQuvvgI84+9U8LTC0q3P8L8YwOT
h/pnP0w/1D/7YeZD/bMfZj/UP/vR3Lcf5n6of/ajxw+a/zD0o/lvP5r/9qP5
bz+a//aj+W8Pmv/s0fxnj+Y/ezT/YYQ/mv/sLys5zT61+gs8vi7daJjkq/cV
rj4145uX+fSv8Pj6fWbDpC3Pv8Ljy1Bs2fH5Ct/g8dXiut201+kbPL5e/F75
8ZLvN3h8weRh8QXTD4svmPmw+ILZD4svNPfth7m/F0f8AAAD/+uM
            "]]}}, 
         ControlType -> 
         None}, {{$CellContext`staticpolygons1718898201471941642981873$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGYC4iUFtlzXF/M4rJGJSrG+/9P+3l0Q4IbzJbzr
Nj4RR/CDdsi1vg7kgvN7VPdHfOrmhPOPTYrX+XmUA85nAAME3yp3wWU2K3Y4
v+SWw3LeEjY4f537wyqRdaxw/ostjX7SL1jgfCUwQPBj+w991YhhhvNj0Pjo
6tHNQ7cP3T3o7kX3D7p/0cMDPbzQwxM9vBejxQd6/AAAE++7vA==
            "]]}}, 
         ControlType -> 
         None}, {{$CellContext`staticpolygons1918898201471941642994612$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           
           Line[{{{3.5, 2.}, {2.5, 2.}, {2.5, 2.}, {3.5, 2.}, {3.5, 2.}}, {{
             2.5, 2.}, {2.085786437626905, 3.}, {2.085786437626905, 3.}, {2.5,
              2.}, {2.5, 2.}}, {{2.5, 3.414213562373095}, {2.085786437626905, 
             3.}, {2.085786437626905, 3.}, {2.5, 3.414213562373095}, {2.5, 
             3.414213562373095}}, {{3.5, 3.}, {2.5, 3.414213562373095}, {2.5, 
             3.414213562373095}, {3.5, 3.}, {3.5, 3.}}, {{3.5, 2.}, {3.5, 
             3.}, {3.5, 3.}, {3.5, 2.}, {3.5, 2.}}, {{3.500341421356237, 
             1.9996585786437628`}, {2.4998414213562374`, 
             1.9996585786437628`}, {2.085420752201956, 3.0001585786437626`}, {
             2.4998414213562374`, 3.414579247798044}, {3.500341421356237, 
             3.0001585786437626`}, {3.500341421356237, 
             1.9996585786437628`}}, {{3.500341421356237, 
             1.9996585786437628`}, {2.4998414213562374`, 
             1.9996585786437628`}, {2.085420752201956, 3.0001585786437626`}, {
             2.4998414213562374`, 3.414579247798044}, {3.500341421356237, 
             3.0001585786437626`}, {3.500341421356237, 
             1.9996585786437628`}}}]}}, ControlType -> 
         None}, {{$CellContext`staticpolygons2118898201471941643006643$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGZiQID+Q181Yvof7Yfx34HBPTh/f8SnbtX9N+D8
CWD1l+D8A2D5E2j8HXA+BCzYA2PtgMjbw/h7IPrh/D6I+XD+Poj9cD7UfXB+
L8T9cH4/Gh9d/X408yag2XcAzT0H0NwL9Y8Nmn/g/t2DFh59aOG1Dy080cO7
Fy0+YPEDAKxSgy8=
            "]]}}, ControlType -> 
         None}, {{$CellContext`staticpolygons2218898201471941643007768$$, {
           GrayLevel[0], 
           AbsoluteThickness[0.5], 
           Line[CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGYCYu12sZvnyoUc+g991Yjpf7Qfxn8HBvfg/P0R
n7pV99+A8yeA1V+C8w+A5U+g8XfA+QxgsGAPjL8DIm8P4++B6Ifz+yDmw/n7
IPbbo7kPzu+FuN8ezT841e9HM28Cmn0H0NxzAM29UP/YoPlnP5p/9qP5Zz+a
f3CGdy9afMDiBwCT4NoX
            "]]}}, ControlType -> None}}, 
      "Options" :> {
       TrackedSymbols -> Manipulate, Deployed -> False, 
        AutorunSequencing -> {1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 
         15, 16, 17, 18}, SynchronousInitialization -> False, 
        SynchronousUpdating -> False, 
        BaseStyle -> {DynamicEvaluationTimeout -> 100}}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{643., {428., 433.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>(($CellContext`raytracefunction118898201471941643017026 = 
       With[{$CellContext`compileoptionsetting$ = 
          If[$VersionNumber >= 8, {
            CompilationOptions -> {
              "ExpressionOptimization" -> False, "InlineCompiledFunctions" -> 
               False}, CompilationTarget -> "MVM", 
             RuntimeAttributes -> {Listable}, Parallelization -> False, 
             RuntimeOptions -> {}}, CompileOptimizations -> False]}, 
         Compile[{{$CellContext`LightAng$$, 
            Blank[Real]}, {$CellContext`lightX$$, 
            Blank[Real]}, {$CellContext`as2$$, 
            Blank[Real]}, {$CellContext`c11$$, 
            Blank[Real]}, {$CellContext`c12$$, 
            Blank[Real]}, {$CellContext`c21$$, 
            Blank[Real]}, {$CellContext`c22$$, 
            Blank[Real]}, {$CellContext`cs21$$, 
            Blank[Real]}, {$CellContext`cs22$$, 
            Blank[Real]}, {$CellContext`MirrorAngle$$, 
            Blank[Real]}, {$CellContext`t1$$, 
            Blank[Real]}, {$CellContext`t2$$, 
            Blank[Real]}, {$CellContext`ts2$$, 
            Blank[Real]}, {$CellContext`x2$$, 
            Blank[Real]}, {$CellContext`xs$$, 
            Blank[Real]}, {$CellContext`xs2$$, 
            Blank[Real]}, {$CellContext`y1$$, 
            Blank[Real]}}, 
          
          Module[{$CellContext`activeregion$, \
$CellContext`allcreatedamplitudes$, $CellContext`allcreatedrays$, \
$CellContext`allowzeroraylength$, $CellContext`alternateindex$, \
$CellContext`amplitude$, $CellContext`axismagnitude$, \
$CellContext`axismatrix$, $CellContext`clonedata$, \
$CellContext`clonegenerationnumber$, $CellContext`cloneinput$, \
$CellContext`clonenumber$, $CellContext`cloneposition$, \
$CellContext`clonereportedrays$, $CellContext`clonerotation$, \
$CellContext`clonescale$, $CellContext`clonescalevector$, \
$CellContext`clonesorthistogram$, $CellContext`clonetraceinput$, \
$CellContext`clonetraceoutput$, $CellContext`closestdistances$, \
$CellContext`closestposition$, $CellContext`closestpositions$, \
$CellContext`closestraylength$, $CellContext`completedray$, \
$CellContext`componentnumber$, $CellContext`cosangle$, \
$CellContext`crossmatrix$, $CellContext`deflecteddummyrayspresent$, \
$CellContext`deflectedlocalrays$, $CellContext`deflectedrays$, \
$CellContext`deflectedrayspresent$, $CellContext`dummymatrix$, \
$CellContext`dummymatrixlist$, $CellContext`dummyvector$, \
$CellContext`frontid$, $CellContext`generationlimit$, \
$CellContext`generationnumber$, $CellContext`holeintersections$, \
$CellContext`holeQ$, $CellContext`holeQlist$, $CellContext`hor$, \
$CellContext`index$, $CellContext`index1$, $CellContext`index2$, \
$CellContext`inrays$, $CellContext`intensity$, $CellContext`intensityscale$, \
$CellContext`intersectionnumber$, $CellContext`intersections$, \
$CellContext`intersectionslist$, $CellContext`intersectionspresent$, \
$CellContext`localdummyoutrayspresent$, $CellContext`localoutrays$, \
$CellContext`localoutrayspresent$, $CellContext`magnitude$, \
$CellContext`maxclonegenerationnumber$, $CellContext`maximumposition$, \
$CellContext`minimumraylength$, $CellContext`minresonateraylength$, \
$CellContext`n12$, $CellContext`newcomponentnumber$, \
$CellContext`newdeflectedrays$, $CellContext`newdistance$, \
$CellContext`newsurfaceid$, $CellContext`newsurfacenumber$, \
$CellContext`nonintersectingrays$, $CellContext`normalizedpolarization$, \
$CellContext`oldgenerationnumber$, $CellContext`opticallength$, \
$CellContext`originalray$, $CellContext`originalraytilt$, \
$CellContext`originalrotation$, $CellContext`originalsurfnorm$, \
$CellContext`outrays$, $CellContext`parallelamplitude$, $CellContext`PAxis$, \
$CellContext`perpendicularamplitude$, $CellContext`phaseshift$, \
$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$, \
$CellContext`previoustilt$, $CellContext`propagate$, \
$CellContext`propagatedrays$, $CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$, $CellContext`r4$, $CellContext`r5$, $CellContext`r6$, \
$CellContext`r7$, $CellContext`r8$, $CellContext`r9$, $CellContext`ray1$, \
$CellContext`ray2$, $CellContext`ray3$, $CellContext`LocRayL$, \
$CellContext`rayslot$, $CellContext`raysreported$, $CellContext`raytiltx$, \
$CellContext`raytiltz$, $CellContext`reporteddummyrayspresent$, \
$CellContext`reportedlocalrays$, $CellContext`reportedrays$, \
$CellContext`reportedrayspresent$, $CellContext`resonateintersections$, \
$CellContext`resonatenumber$, $CellContext`resonateraylength$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`rotationaxis$, $CellContext`rsx$, $CellContext`LocRSx$, \
$CellContext`rsy$, $CellContext`LocRSy$, $CellContext`rsz$, \
$CellContext`LocRSz$, 
            Optica`Optica`RTx$, $CellContext`LocRTy$, $CellContext`LocRTz$, \
$CellContext`rx$, $CellContext`rxhlp$, $CellContext`ry$, $CellContext`ryhlp$, \
$CellContext`rz$, $CellContext`rzhlp$, $CellContext`LocSCx$, \
$CellContext`LocSCy$, $CellContext`sid$, $CellContext`sinangle$, \
$CellContext`sno1$, $CellContext`sno2$, $CellContext`sno3$, \
$CellContext`sno4$, $CellContext`surfaceid$, $CellContext`surfacenumber$, \
$CellContext`surfacerotationmatrix$, $CellContext`surfacetranslationvector$, \
$CellContext`surfnorm$, $CellContext`symr1$, $CellContext`symr2$, \
$CellContext`symr3$, $CellContext`symr4$, $CellContext`symr5$, \
$CellContext`symr6$, $CellContext`symr7$, $CellContext`symr8$, \
$CellContext`symr9$, $CellContext`tempclonedata$, \
$CellContext`terminatedeflection$, $CellContext`thresholdintensity$, \
$CellContext`tiltmagnitude$, $CellContext`transmatrix$, $CellContext`LocTV1$, \
$CellContext`LocTV10$, $CellContext`LocTV2$, $CellContext`LocTV3$, \
$CellContext`LocTV4$, $CellContext`LocTV5$, $CellContext`LocTV6$, \
$CellContext`LocTV7$, $CellContext`LocTV8$, $CellContext`LocTV9$, \
$CellContext`u$, $CellContext`unfilteredintersections$, $CellContext`unit$, \
$CellContext`uu$, $CellContext`ver$, $CellContext`wavelength$, \
$CellContext`XAxis$, $CellContext`xunit$, $CellContext`YAxis$, \
$CellContext`yunit$, $CellContext`ZAxis$, $CellContext`zunit$}, \
$CellContext`rsx$ = 1.; $CellContext`rsy$ = 1.; $CellContext`rsz$ = 
            1.; $CellContext`rex$ = 1.; $CellContext`rey$ = 
            1.; $CellContext`rez$ = 1.; $CellContext`r1$ = 
            1.; $CellContext`r2$ = 1.; $CellContext`r3$ = 
            1.; $CellContext`r4$ = 1.; $CellContext`r5$ = 
            1.; $CellContext`r6$ = 1.; $CellContext`r7$ = 
            1.; $CellContext`r8$ = 1.; $CellContext`r9$ = 
            1.; $CellContext`symr1$ = 1.; $CellContext`symr2$ = 
            1.; $CellContext`symr3$ = 1.; $CellContext`symr4$ = 
            1.; $CellContext`symr5$ = 1.; $CellContext`symr6$ = 
            1.; $CellContext`symr7$ = 1.; $CellContext`symr8$ = 
            1.; $CellContext`symr9$ = 1.; $CellContext`rx$ = 
            1.; $CellContext`ry$ = 1.; $CellContext`rz$ = 
            1.; $CellContext`xunit$ = 1.; $CellContext`yunit$ = 
            1.; $CellContext`zunit$ = 1.; $CellContext`ray1$ = 
            1.; $CellContext`ray2$ = 1.; $CellContext`ray3$ = 
            1.; $CellContext`LocRSx$ = 1.; $CellContext`LocRSy$ = 
            1.; $CellContext`LocRSz$ = 1.; 
           Optica`Optica`RTx$ = 1.; $CellContext`LocRTy$ = 
            1.; $CellContext`LocRTz$ = 1.; $CellContext`LocRayL$ = 
            1.; $CellContext`LocSCx$ = 1.; $CellContext`LocSCy$ = 
            1.; $CellContext`opticallength$ = 1.; $CellContext`phaseshift$ = 
            0.; $CellContext`wavelength$ = 1.; $CellContext`intensity$ = 
            1.; $CellContext`intensityscale$ = 
            1.; $CellContext`componentnumber$ = -1.; \
$CellContext`surfacenumber$ = -1.; $CellContext`surfaceid$ = -1.; \
$CellContext`generationnumber$ = 1.; $CellContext`intersectionnumber$ = 
            1.; $CellContext`generationlimit$ = 
            200.; $CellContext`thresholdintensity$ = 
            1.; $CellContext`tiltmagnitude$ = 1.; $CellContext`pol1$ = 
            1.; $CellContext`pol2$ = 1.; $CellContext`pol3$ = 
            1.; $CellContext`sid$ = 1.; $CellContext`sno1$ = 
            1.; $CellContext`sno2$ = 1.; $CellContext`sno3$ = 
            1.; $CellContext`sno4$ = 1.; $CellContext`rayslot$ = 
            1.; $CellContext`index$ = 1.; $CellContext`activeregion$ = 
            1.; $CellContext`frontid$ = 1.; $CellContext`index1$ = 
            1.; $CellContext`index2$ = 1.; $CellContext`magnitude$ = 
            1.; $CellContext`LocTV1$ = 1.; $CellContext`LocTV2$ = 
            1.; $CellContext`LocTV3$ = 1.; $CellContext`LocTV4$ = 
            1.; $CellContext`LocTV5$ = 1.; $CellContext`LocTV6$ = 
            1.; $CellContext`LocTV7$ = 1.; $CellContext`LocTV8$ = 
            1.; $CellContext`LocTV9$ = 1.; $CellContext`LocTV10$ = 
            1.; $CellContext`cloneposition$ = {0., 0., 
             0.}; $CellContext`clonerotation$ = {{
             1.}}; $CellContext`clonedata$ = {{
             1.}}; $CellContext`clonenumber$ = 1; $CellContext`clonescale$ = 
            1.; $CellContext`newdistance$ = 
            1.; $CellContext`closestdistances$ = {
             1.}; $CellContext`closestposition$ = 
            0; $CellContext`closestraylength$ = 
            1.; $CellContext`maximumposition$ = 
            1; $CellContext`closestpositions$ = {
             0}; $CellContext`cloneinput$ = {
             1.}; $CellContext`clonetraceinput$ = {{
             1.}}; $CellContext`clonetraceoutput$ = {{
             1.}}; $CellContext`tempclonedata$ = {{
             1.}}; $CellContext`clonegenerationnumber$ = 
            1.; $CellContext`maxclonegenerationnumber$ = 
            1.; $CellContext`clonescalevector$ = {
             1.}; $CellContext`clonesorthistogram$ = {
             1}; $CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1.,
              0.}, {0., 0., 1.}}; $CellContext`surfacetranslationvector$ = {
             0., 0., 0.}; $CellContext`oldgenerationnumber$ = 
            1.; $CellContext`intersections$ = {{-1., 0., 
             0.}}; $CellContext`unfilteredintersections$ = {{-1., 0., 
             0.}}; $CellContext`intersectionslist$ = {{{-1., 0., 
             0.}}}; $CellContext`holeQlist$ = {
             0}; $CellContext`holeintersections$ = {{-1., 0., 
             0.}}; $CellContext`minimumraylength$ = 
            0.0001; $CellContext`originalray$ = {
             1.}; $CellContext`completedray$ = {
             1.}; $CellContext`reportedrayspresent$ = 
            False; $CellContext`propagate$ = 
            True; $CellContext`originalraytilt$ = {
             1.}; $CellContext`allowzeroraylength$ = 
            True; $CellContext`deflecteddummyrayspresent$ = 
            False; $CellContext`reporteddummyrayspresent$ = 
            False; $CellContext`localoutrayspresent$ = 
            False; $CellContext`localdummyoutrayspresent$ = 
            False; $CellContext`deflectedrayspresent$ = 
            False; $CellContext`intersectionspresent$ = 
            False; $CellContext`raysreported$ = 
            False; $CellContext`terminatedeflection$ = 
            False; $CellContext`allcreatedrays$ = {{
             1.}}; $CellContext`propagatedrays$ = {{
             1.}}; $CellContext`deflectedrays$ = {{
             1.}}; $CellContext`newdeflectedrays$ = {{
             1.}}; $CellContext`reportedrays$ = {{
             1.}}; $CellContext`clonereportedrays$ = {{
             1.}}; $CellContext`nonintersectingrays$ = {{
             1.}}; $CellContext`inrays$ = {{1.}}; $CellContext`outrays$ = {{
             1.}}; $CellContext`reportedlocalrays$ = {{
             1.}}; $CellContext`deflectedlocalrays$ = {{
             1.}}; $CellContext`localoutrays$ = {{
             1.}}; $CellContext`resonatenumber$ = 
            0; $CellContext`resonateraylength$ = 
            1.; $CellContext`minresonateraylength$ = 
            1.; $CellContext`resonateintersections$ = {{-1., 0., 
             0.}}; $CellContext`dummyvector$ = {
             1.}; $CellContext`dummymatrix$ = {{
             1.}}; $CellContext`dummymatrixlist$ = {{{
             1.}}}; $CellContext`newcomponentnumber$ = -1.; \
$CellContext`newsurfacenumber$ = -1.; $CellContext`newsurfaceid$ = -1.; \
$CellContext`holeQ$ = False; $CellContext`rxhlp$ = 1.; $CellContext`ryhlp$ = 
            1.; $CellContext`rzhlp$ = 
            1.; $CellContext`surfnorm$ = {{
             1.}}; $CellContext`originalsurfnorm$ = {{
             1.}}; $CellContext`XAxis$ = {1., 0., 0.}; $CellContext`YAxis$ = {
             1., 0., 0.}; $CellContext`ZAxis$ = {1., 0., 
             0.}; $CellContext`PAxis$ = {1., 0., 
             0.}; $CellContext`normalizedpolarization$ = {1., 
             1.}; $CellContext`amplitude$ = {
             1. + 0. I, 0. + 0. I, 0. + 
              0. I}; $CellContext`allcreatedamplitudes$ = {{
              0. + 0. I, 0. + 0. I, 0. + 
               0. I}}; $CellContext`perpendicularamplitude$ = 
            1. + 0. I; $CellContext`parallelamplitude$ = 
            1. + 0. I; $CellContext`raytiltz$ = 1.; $CellContext`raytiltx$ = 
            1.; $CellContext`n12$ = 1.; $CellContext`alternateindex$ = 
            1.; $CellContext`transmatrix$ = {{{1., 0., 0.}, {0., 1., 0.}, {0.,
              0., 1.}}}; $CellContext`u$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`uu$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`unit$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 
             0., 1.}}; $CellContext`originalrotation$ = {{1., 0., 0.}, {0., 
             1., 0.}, {0., 0., 1.}}; $CellContext`axismatrix$ = {{1., 0., 
             0.}, {0., 1., 0.}, {0., 0., 1.}}; $CellContext`crossmatrix$ = {{
             1., 0., 0.}, {0., 1., 0.}, {0., 0., 
             1.}}; $CellContext`axismagnitude$ = 1.; $CellContext`cosangle$ = 
            1.; $CellContext`sinangle$ = 
            1.; $CellContext`previoustilt$ = {1., 0., 0.}; $CellContext`hor$ = 
            1. + 0. I; $CellContext`ver$ = 
            0. + 0. I; $CellContext`propagatedrays$ = 
            Join[{$CellContext`symr1$, $CellContext`symr2$, \
$CellContext`symr3$, $CellContext`symr4$, $CellContext`symr5$, \
$CellContext`symr6$, $CellContext`symr7$, $CellContext`symr8$, \
$CellContext`symr9$} = Re[{
                  Cos[Degree $CellContext`LightAng$$], 
                  Sin[Degree $CellContext`LightAng$$], 0, -
                  Sin[Degree $CellContext`LightAng$$], 
                  Cos[Degree $CellContext`LightAng$$], 0, 0, 0, 1}]; 
              Map[({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {$CellContext`LocTV1$, $CellContext`LocTV2$, \
$CellContext`LocTV3$} = {$CellContext`lightX$$ + $CellContext`rsx$ \
$CellContext`symr1$ + $CellContext`rsy$ $CellContext`symr4$ + \
$CellContext`rsz$ $CellContext`symr7$, $CellContext`rsx$ $CellContext`symr2$ + \
$CellContext`rsy$ $CellContext`symr5$ + $CellContext`rsz$ \
$CellContext`symr8$, $CellContext`rsx$ $CellContext`symr3$ + \
$CellContext`rsy$ $CellContext`symr6$ + $CellContext`rsz$ \
$CellContext`symr9$}; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$} = {$CellContext`LocTV1$, $CellContext`LocTV2$, \
$CellContext`LocTV3$}; {$CellContext`LocTV1$, $CellContext`LocTV2$, \
$CellContext`LocTV3$} = {$CellContext`lightX$$ + $CellContext`rex$ \
$CellContext`symr1$ + $CellContext`rey$ $CellContext`symr4$ + \
$CellContext`rez$ $CellContext`symr7$, $CellContext`rex$ $CellContext`symr2$ + \
$CellContext`rey$ $CellContext`symr5$ + $CellContext`rez$ \
$CellContext`symr8$, $CellContext`rex$ $CellContext`symr3$ + \
$CellContext`rey$ $CellContext`symr6$ + $CellContext`rez$ \
$CellContext`symr9$}; {$CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$} = {$CellContext`LocTV1$, $CellContext`LocTV2$, \
$CellContext`LocTV3$}; {$CellContext`LocTV1$, $CellContext`LocTV2$, \
$CellContext`LocTV3$} = {$CellContext`r1$ $CellContext`symr1$ + \
$CellContext`r2$ $CellContext`symr4$ + $CellContext`r3$ $CellContext`symr7$, \
$CellContext`r1$ $CellContext`symr2$ + $CellContext`r2$ $CellContext`symr5$ + \
$CellContext`r3$ $CellContext`symr8$, $CellContext`r1$ $CellContext`symr3$ + \
$CellContext`r2$ $CellContext`symr6$ + $CellContext`r3$ $CellContext`symr9$}; \
{$CellContext`LocTV4$, $CellContext`LocTV5$, $CellContext`LocTV6$} = \
{$CellContext`r4$ $CellContext`symr1$ + $CellContext`r5$ $CellContext`symr4$ + \
$CellContext`r6$ $CellContext`symr7$, $CellContext`r4$ $CellContext`symr2$ + \
$CellContext`r5$ $CellContext`symr5$ + $CellContext`r6$ $CellContext`symr8$, \
$CellContext`r4$ $CellContext`symr3$ + $CellContext`r5$ $CellContext`symr6$ + \
$CellContext`r6$ $CellContext`symr9$}; {$CellContext`LocTV7$, \
$CellContext`LocTV8$, $CellContext`LocTV9$} = {$CellContext`r7$ \
$CellContext`symr1$ + $CellContext`r8$ $CellContext`symr4$ + $CellContext`r9$ \
$CellContext`symr7$, $CellContext`r7$ $CellContext`symr2$ + $CellContext`r8$ \
$CellContext`symr5$ + $CellContext`r9$ $CellContext`symr8$, $CellContext`r7$ \
$CellContext`symr3$ + $CellContext`r8$ $CellContext`symr6$ + $CellContext`r9$ \
$CellContext`symr9$}; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
{{$CellContext`LocTV1$, $CellContext`LocTV2$, $CellContext`LocTV3$}, \
{$CellContext`LocTV4$, $CellContext`LocTV5$, $CellContext`LocTV6$}, \
{$CellContext`LocTV7$, $CellContext`LocTV8$, $CellContext`LocTV9$}}; \
{$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$, $CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$, $CellContext`r4$, $CellContext`r5$, $CellContext`r6$, \
$CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , {{
                 0., -0.49, 0., 0., -0.49, 0., 1., 0., 0., 0., 1., 0., 0., 0.,
                   1., $CellContext`lam$$, 100., 0.125, 0., 
                  Sqrt[
                  1.0005281111748805` + 
                   2.830549017940716*^-12/$CellContext`lam$$^8 + 
                   3.7787839314048715`*^-10/$CellContext`lam$$^6 + 
                   2.6004099469477187`*^-8/$CellContext`lam$$^4 + 
                   2.9781670902982902`*^-6/$CellContext`lam$$^2 - 
                   2.364805676582992*^-10 $CellContext`lam$$^2], 0., 0., 1., 
                  0., 0., 0., 0., 800803., 800803., 1., 8., 1., 0., 1., 0., 
                  0., 0., 1., 0.}, {
                 0., -0.35, 0., 0., -0.35, 0., 1., 0., 0., 0., 1., 0., 0., 0.,
                   1., $CellContext`lam$$, 100., 0.125, 0., 
                  Sqrt[
                  1.0005281111748805` + 
                   2.830549017940716*^-12/$CellContext`lam$$^8 + 
                   3.7787839314048715`*^-10/$CellContext`lam$$^6 + 
                   2.6004099469477187`*^-8/$CellContext`lam$$^4 + 
                   2.9781670902982902`*^-6/$CellContext`lam$$^2 - 
                   2.364805676582992*^-10 $CellContext`lam$$^2], 0., 0., 1., 
                  0., 0., 0., 0., 800803., 800803., 2., 8., 2., 0., 1., 0., 
                  0., 0., 1., 0.}, {
                 0., -0.21000000000000002`, 0., 0., -0.21000000000000002`, 0.,
                   1., 0., 0., 0., 1., 0., 0., 0., 1., $CellContext`lam$$, 
                  100., 0.125, 0., 
                  Sqrt[
                  1.0005281111748805` + 
                   2.830549017940716*^-12/$CellContext`lam$$^8 + 
                   3.7787839314048715`*^-10/$CellContext`lam$$^6 + 
                   2.6004099469477187`*^-8/$CellContext`lam$$^4 + 
                   2.9781670902982902`*^-6/$CellContext`lam$$^2 - 
                   2.364805676582992*^-10 $CellContext`lam$$^2], 0., 0., 1., 
                  0., 0., 0., 0., 800803., 800803., 3., 8., 3., 0., 1., 0., 
                  0., 0., 1., 0.}, {
                 0., -0.07000000000000006, 0., 0., -0.07000000000000006, 0., 
                  1., 0., 0., 0., 1., 0., 0., 0., 1., $CellContext`lam$$, 
                  100., 0.125, 0., 
                  Sqrt[
                  1.0005281111748805` + 
                   2.830549017940716*^-12/$CellContext`lam$$^8 + 
                   3.7787839314048715`*^-10/$CellContext`lam$$^6 + 
                   2.6004099469477187`*^-8/$CellContext`lam$$^4 + 
                   2.9781670902982902`*^-6/$CellContext`lam$$^2 - 
                   2.364805676582992*^-10 $CellContext`lam$$^2], 0., 0., 1., 
                  0., 0., 0., 0., 800803., 800803., 4., 8., 4., 0., 1., 0., 
                  0., 0., 1., 0.}, {
                 0., 0.06999999999999995, 0., 0., 0.06999999999999995, 0., 1.,
                   0., 0., 0., 1., 0., 0., 0., 1., $CellContext`lam$$, 100., 
                  0.125, 0., 
                  Sqrt[
                  1.0005281111748805` + 
                   2.830549017940716*^-12/$CellContext`lam$$^8 + 
                   3.7787839314048715`*^-10/$CellContext`lam$$^6 + 
                   2.6004099469477187`*^-8/$CellContext`lam$$^4 + 
                   2.9781670902982902`*^-6/$CellContext`lam$$^2 - 
                   2.364805676582992*^-10 $CellContext`lam$$^2], 0., 0., 1., 
                  0., 0., 0., 0., 800803., 800803., 5., 8., 5., 0., 1., 0., 
                  0., 0., 1., 0.}, {
                 0., 0.20999999999999996`, 0., 0., 0.20999999999999996`, 0., 
                  1., 0., 0., 0., 1., 0., 0., 0., 1., $CellContext`lam$$, 
                  100., 0.125, 0., 
                  Sqrt[
                  1.0005281111748805` + 
                   2.830549017940716*^-12/$CellContext`lam$$^8 + 
                   3.7787839314048715`*^-10/$CellContext`lam$$^6 + 
                   2.6004099469477187`*^-8/$CellContext`lam$$^4 + 
                   2.9781670902982902`*^-6/$CellContext`lam$$^2 - 
                   2.364805676582992*^-10 $CellContext`lam$$^2], 0., 0., 1., 
                  0., 0., 0., 0., 800803., 800803., 6., 8., 6., 0., 1., 0., 
                  0., 0., 1., 0.}, {
                 0., 0.34999999999999987`, 0., 0., 0.34999999999999987`, 0., 
                  1., 0., 0., 0., 1., 0., 0., 0., 1., $CellContext`lam$$, 
                  100., 0.125, 0., 
                  Sqrt[
                  1.0005281111748805` + 
                   2.830549017940716*^-12/$CellContext`lam$$^8 + 
                   3.7787839314048715`*^-10/$CellContext`lam$$^6 + 
                   2.6004099469477187`*^-8/$CellContext`lam$$^4 + 
                   2.9781670902982902`*^-6/$CellContext`lam$$^2 - 
                   2.364805676582992*^-10 $CellContext`lam$$^2], 0., 0., 1., 
                  0., 0., 0., 0., 800803., 800803., 7., 8., 7., 0., 1., 0., 
                  0., 0., 1., 0.}, {
                 0., 0.4899999999999999, 0., 0., 0.4899999999999999, 0., 1., 
                  0., 0., 0., 1., 0., 0., 0., 1., $CellContext`lam$$, 100., 
                  0.125, 0., 
                  Sqrt[
                  1.0005281111748805` + 
                   2.830549017940716*^-12/$CellContext`lam$$^8 + 
                   3.7787839314048715`*^-10/$CellContext`lam$$^6 + 
                   2.6004099469477187`*^-8/$CellContext`lam$$^4 + 
                   2.9781670902982902`*^-6/$CellContext`lam$$^2 - 
                   2.364805676582992*^-10 $CellContext`lam$$^2], 0., 0., 1., 
                  0., 0., 0., 0., 800803., 800803., 8., 8., 8., 0., 1., 0., 
                  0., 0., 1., 0.}}]]; $CellContext`propagatedrays$ = 
            Map[({$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`componentnumber$ = 
               1.; $CellContext`frontid$ = 
               1.; {$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, \
$CellContext`rex$, $CellContext`rey$, $CellContext`rez$, $CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$, $CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$, $CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`propagatedrays$]; \
$CellContext`thresholdintensity$ = 1.; $CellContext`generationlimit$ = 
            200.; $CellContext`reportedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`generationnumber$ = 0.; (
            AddTo[$CellContext`generationnumber$, 
              1.]; $CellContext`reportedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, 
                0, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`deflectedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; ($CellContext`deflectedrayspresent$ = 
              False; $CellContext`reportedrayspresent$ = 
              False; $CellContext`deflecteddummyrayspresent$ = 
              False; $CellContext`reporteddummyrayspresent$ = 
              False; {$CellContext`deflectedlocalrays$, \
$CellContext`reportedlocalrays$} = Transpose[
                
                Map[(({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                   Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                   Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                   Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                   0.3 + $CellContext`rex$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                   Chop[$CellContext`rx$]; $CellContext`ry$ = 
                   Chop[$CellContext`ry$]; $CellContext`rz$ = 
                   Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                   False; $CellContext`intersections$ = {{-1., 0., 0.}}); 
                 If[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`deflectedrayspresent$ = 
                    True; ($CellContext`intersections$ = 
                    Block[{Compile`$19315}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., Part[#, 2]^2 + Part[#, 3]^2 <= 2.25], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$19315 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$19315), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$19315, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$19315}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 800842.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; $CellContext`intersections$ = Union[
                    Map[
                    If[Part[#, 2]^2 + Part[#, 3]^2 <= 
                    0.2025, $CellContext`holeQ$ = True; {-1., 0., 
                    0.}, #]& , $CellContext`unfilteredintersections$]]; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]); 
                   If[$CellContext`intersections$ != {{-1., 0., 
                    0.}}, $CellContext`intersectionspresent$ = 
                    True; ({$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {1., 1., 
                    800842.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {1., 1., 
                    800842.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
-0.3 + $CellContext`rxhlp$; $CellContext`rey$ = $CellContext`ryhlp$; \
$CellContext`rez$ = $CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}); ($CellContext`reportedrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {-0.3, 0, 
                    0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}})); {
                    
                    First[$CellContext`allcreatedrays$], \
$CellContext`completedray$}, $CellContext`reporteddummyrayspresent$ = 
                    True; {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, CompressedData["
1:eJxTTMoPSmVkYGBQZ4CBD/YDRzdEmOSfPUicerh79+Og6eZuAGaoMiY=
                   
                     "]}], $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`deflecteddummyrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmViYGAAYXUGGPhgP3B0Q4RJ/tmDxKmHu3c/DnoA/UFvemiGGwCy
wWJ9
                    "]])& , $CellContext`propagatedrays$]]; If[
               
               And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ]; 
               1., 1.]; If[
               
               And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
                Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
               1., 1.]); (
             If[$CellContext`reportedrayspresent$, $CellContext`reportedrays$ = 
                Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                  
                  "], $CellContext`reportedlocalrays$]; 1., 
               1.]; $CellContext`propagatedrays$ = \
$CellContext`deflectedlocalrays$); $CellContext`raysreported$ = \
$CellContext`reportedrayspresent$; 
            1.); ($CellContext`inrays$ = $CellContext`propagatedrays$; \
$CellContext`outrays$ = CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

              "]; $CellContext`deflectedrayspresent$ = 
             True; $CellContext`reportedrayspresent$ = 
             False; $CellContext`propagate$ = True; While[
              
              And[$CellContext`deflectedrayspresent$, \
$CellContext`propagate$], 
              AddTo[$CellContext`generationnumber$, 
                1.]; ($CellContext`deflecteddummyrayspresent$ = 
                False; $CellContext`deflectedrayspresent$ = 
                False; $CellContext`reportedrayspresent$ = 
                False; $CellContext`reporteddummyrayspresent$ = 
                True; $CellContext`localdummyoutrayspresent$ = 
                False; $CellContext`localoutrayspresent$ = 
                False; {$CellContext`deflectedlocalrays$, \
$CellContext`localoutrays$, $CellContext`reportedlocalrays$} = 
                Map[Flatten[#, 1]& , 
                  Transpose[
                   
                   Map[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; If[
                    
                    And[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`generationnumber$ < \
$CellContext`generationlimit$], ($CellContext`resonatenumber$ = 
                    0; $CellContext`resonateraylength$ = 
                    9.87654321*^8; $CellContext`resonateintersections$ = \
{{-1., 0., 0.}}; MapIndexed[If[
                    And[
                    Part[#, 1, 1] > -1., 
                    Part[#, 1, 
                    1] < $CellContext`resonateraylength$], \
$CellContext`resonateraylength$ = 
                    Part[#, 1, 
                    
                    1]; $CellContext`resonateintersections$ = #; \
$CellContext`resonatenumber$ = 
                    First[#2], $CellContext`resonatenumber$]& , \
$CellContext`intersectionslist$ = {{{-1., 0., 
                    0.}}}; $CellContext`holeQlist$ = {
                    0}; ({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$19465, Compile`$19517, Compile`$19518}, 
                    
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, 
                    Optica`Optica`TempVar3, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; 
                    Optica`Optica`TempVar1 = $CellContext`rx$^2 + \
$CellContext`ry$^2 + $CellContext`rz$^2; 
                    Optica`Optica`TempVar2 = $CellContext`rx$ \
$CellContext`xunit$ + $CellContext`ry$ $CellContext`yunit$ + $CellContext`rz$ \
$CellContext`zunit$ - 1.3147 $CellContext`xunit$; 
                    Optica`Optica`TempVar3 = -Optica`Optica`TempVar1 + 
                    Optica`Optica`TempVar2^2 + 2 $CellContext`rx$ 1.3147; 
                    Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; 
                    If[N[
                    Chop[Optica`Optica`TempVar3]] >= 0., 
                    Optica`Optica`TempVar3 = Sqrt[Optica`Optica`TempVar3]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = (
                    Compile`$19465 = Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3; {-Optica`Optica`TempVar2 - 
                    Optica`Optica`TempVar3, $CellContext`ry$ - 
                    Compile`$19465 $CellContext`yunit$, $CellContext`rz$ - 
                    Compile`$19465 $CellContext`zunit$}); If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    0.5625, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-1.3147 + $CellContext`rx$ + $CellContext`LocRayL$ \
$CellContext`xunit$ + 
                    Sqrt[1.72843609 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = (Compile`$19517 = -Optica`Optica`TempVar2; 
                    Compile`$19518 = Compile`$19517 + 
                    Optica`Optica`TempVar3; {
                    Compile`$19518, $CellContext`ry$ + 
                    Compile`$19518 $CellContext`yunit$, $CellContext`rz$ + 
                    Compile`$19518 $CellContext`zunit$}); If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    0.5625, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-1.3147 + $CellContext`rx$ + $CellContext`LocRayL$ \
$CellContext`xunit$ + 
                    Sqrt[1.72843609 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    If[Part[Optica`Optica`TempVar, 1] == 
                    Part[Optica`Optica`TempVar, 2], {
                    Part[Optica`Optica`TempVar, 1]}, 
                    Optica`Optica`TempVar], {{-1., 0., 0.}}]]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 800895.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -0.329 + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$19466, Compile`$19520, Compile`$19521}, 
                    
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, 
                    Optica`Optica`TempVar3, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; 
                    Optica`Optica`TempVar1 = $CellContext`rx$^2 + \
$CellContext`ry$^2 + $CellContext`rz$^2; 
                    Optica`Optica`TempVar2 = $CellContext`rx$ \
$CellContext`xunit$ + $CellContext`ry$ $CellContext`yunit$ + $CellContext`rz$ \
$CellContext`zunit$ - (-21.019) $CellContext`xunit$; 
                    Optica`Optica`TempVar3 = -Optica`Optica`TempVar1 + 
                    Optica`Optica`TempVar2^2 + 2 $CellContext`rx$ (-21.019); 
                    Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; 
                    If[N[
                    Chop[Optica`Optica`TempVar3]] >= 0., 
                    Optica`Optica`TempVar3 = Sqrt[Optica`Optica`TempVar3]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = (
                    Compile`$19466 = Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3; {-Optica`Optica`TempVar2 - 
                    Optica`Optica`TempVar3, $CellContext`ry$ - 
                    Compile`$19466 $CellContext`yunit$, $CellContext`rz$ - 
                    Compile`$19466 $CellContext`zunit$}); If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    0.5625, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[21.019 + $CellContext`rx$ + $CellContext`LocRayL$ \
$CellContext`xunit$ - 
                    Sqrt[441.79836099999994` - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = (Compile`$19520 = -Optica`Optica`TempVar2; 
                    Compile`$19521 = Compile`$19520 + 
                    Optica`Optica`TempVar3; {
                    Compile`$19521, $CellContext`ry$ + 
                    Compile`$19521 $CellContext`yunit$, $CellContext`rz$ + 
                    Compile`$19521 $CellContext`zunit$}); If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    0.5625, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[21.019 + $CellContext`rx$ + $CellContext`LocRayL$ \
$CellContext`xunit$ - 
                    Sqrt[441.79836099999994` - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    If[Part[Optica`Optica`TempVar, 1] == 
                    Part[Optica`Optica`TempVar, 2], {
                    Part[Optica`Optica`TempVar, 1]}, 
                    Optica`Optica`TempVar], {{-1., 0., 0.}}]]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 800896.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]); $CellContext`holeQlist$ = 
                    Drop[$CellContext`holeQlist$, 1]; 
                    Drop[$CellContext`intersectionslist$, 1]]); 
                    Which[$CellContext`resonatenumber$ == 
                    1, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 1., 
                    800895.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {2., 1., 
                    800895.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
$CellContext`rxhlp$; $CellContext`rey$ = $CellContext`ryhlp$; \
$CellContext`rez$ = $CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., -($CellContext`ray2$/(
                    1.72843609 - $CellContext`ray2$^2 - \
$CellContext`ray3$^2)^(2^(-1))), -($CellContext`ray3$/(
                    1.72843609 - $CellContext`ray2$^2 - \
$CellContext`ray3$^2)^(2^(-1)))}, {$CellContext`ray2$/(
                    1.72843609 - $CellContext`ray2$^2 - \
$CellContext`ray3$^2)^(2^(-1)), 1., 
                    0.}, {$CellContext`ray3$/(
                    1.72843609 - $CellContext`ray2$^2 - \
$CellContext`ray3$^2)^(2^(-1)), 0., 1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {0., 0., 
                    0.}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; If[$CellContext`intensity$ < 
                    0., $CellContext`intensity$ = 0., 
                    1.]; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[1 + (
                    1.291727649999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.006863581199999999) + (
                    0.2983927129999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.02287043119999998) + (
                    0.955518497 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    97.4779177)]; $CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1 + (
                    1.291727649999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.006863581199999999) + (
                    0.2983927129999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.02287043119999998) + (
                    0.955518497 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 97.4779177)]; 
                    If[
                    Abs[$CellContext`alternateindex$ - $CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1 + (
                    1.291727649999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.006863581199999999) + (
                    0.2983927129999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.02287043119999998) + (
                    0.955518497 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    97.4779177)]]]; $CellContext`n12$ = \
$CellContext`index1$/$CellContext`index2$; $CellContext`index$ = \
$CellContext`index2$; If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    N[0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    2, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -0.329 + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {2., 2., 
                    800896.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {2., 2., 
                    800896.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    0.329 + $CellContext`rxhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., -(-$CellContext`ray2$/(
                    441.79836099999994` - $CellContext`ray2$^2 - \
$CellContext`ray3$^2)^(2^(-1))), -(-$CellContext`ray3$/(
                    441.79836099999994` - $CellContext`ray2$^2 - \
$CellContext`ray3$^2)^(2^(-1)))}, {-$CellContext`ray2$/(
                    441.79836099999994` - $CellContext`ray2$^2 - \
$CellContext`ray3$^2)^(2^(-1)), 1., 
                    0.}, {-$CellContext`ray3$/(
                    441.79836099999994` - $CellContext`ray2$^2 - \
$CellContext`ray3$^2)^(2^(-1)), 0., 1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1, 0, 0}, {0, 1, 0}, {0, 0, 
                    1}}; $CellContext`surfacetranslationvector$ = {
                    0.329, 0, 
                    0}; $CellContext`activeregion$ = -1.; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; If[$CellContext`intensity$ < 
                    0., $CellContext`intensity$ = 0., 
                    1.]; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[1 + (
                    1.291727649999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.006863581199999999) + (
                    0.2983927129999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.02287043119999998) + (
                    0.955518497 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    97.4779177)]; $CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1 + (
                    1.291727649999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.006863581199999999) + (
                    0.2983927129999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.02287043119999998) + (
                    0.955518497 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 97.4779177)]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1 + (
                    1.291727649999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.006863581199999999) + (
                    0.2983927129999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.02287043119999998) + (
                    0.955518497 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    97.4779177)]]]; $CellContext`n12$ = \
$CellContext`index1$/$CellContext`index2$; $CellContext`index$ = \
$CellContext`index2$; If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    N[0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "], {$CellContext`completedray$}}, 
                    True, $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localoutrayspresent$ = 
                    True; {CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}], $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmVmYGAAYUYgVmeAgQ/2A0c3RJjknz1InHq4e/fjoAfQH/SmR8Nt
JIUbAPATktQ=
                    "]])& , $CellContext`inrays$]]]; If[
                 
                 And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                 Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ] 
                  1., 1.]; 
               If[$CellContext`localoutrayspresent$, 
                 If[$CellContext`localdummyoutrayspresent$, \
$CellContext`localoutrays$ = 
                    Select[$CellContext`localoutrays$, Part[#, 23] > 0.& ]; 
                   1., 1.]; $CellContext`outrays$ = 
                  Join[$CellContext`outrays$, $CellContext`localoutrays$]; 1.,
                  1.]; If[
                 
                 And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
                  Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
                 1., 1.]); 
              If[$CellContext`reportedrayspresent$, \
$CellContext`raysreported$ = True; $CellContext`reportedrays$ = 
                 Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                   
                   "], $CellContext`reportedlocalrays$]; 1., 
                1.]; $CellContext`inrays$ = $CellContext`deflectedlocalrays$; \
$CellContext`propagate$ = $CellContext`generationnumber$ < \
$CellContext`generationlimit$]; $CellContext`propagatedrays$ = 
             If[Length[$CellContext`outrays$] > 1, 
               Drop[$CellContext`outrays$, 1], $CellContext`outrays$]; If[
              
              And[$CellContext`generationnumber$ >= \
$CellContext`generationlimit$, $CellContext`deflectedrayspresent$], \
$CellContext`propagatedrays$ = 
               Join[$CellContext`propagatedrays$, \
$CellContext`deflectedlocalrays$]; 1., 
              1.]); ($CellContext`inrays$ = $CellContext`propagatedrays$; \
$CellContext`outrays$ = CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

              "]; $CellContext`deflectedrayspresent$ = 
             True; $CellContext`reportedrayspresent$ = 
             False; $CellContext`propagate$ = True; While[
              
              And[$CellContext`deflectedrayspresent$, \
$CellContext`propagate$], 
              AddTo[$CellContext`generationnumber$, 
                1.]; ($CellContext`deflecteddummyrayspresent$ = 
                False; $CellContext`deflectedrayspresent$ = 
                False; $CellContext`reportedrayspresent$ = 
                False; $CellContext`reporteddummyrayspresent$ = 
                True; $CellContext`localdummyoutrayspresent$ = 
                False; $CellContext`localoutrayspresent$ = 
                False; {$CellContext`deflectedlocalrays$, \
$CellContext`localoutrays$, $CellContext`reportedlocalrays$} = 
                Map[Flatten[#, 1]& , 
                  Transpose[
                   
                   Map[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; If[
                    
                    And[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`generationnumber$ < \
$CellContext`generationlimit$], ($CellContext`resonatenumber$ = 
                    0; $CellContext`resonateraylength$ = 
                    9.87654321*^8; $CellContext`resonateintersections$ = \
{{-1., 0., 0.}}; MapIndexed[If[
                    And[
                    Part[#, 1, 1] > -1., 
                    Part[#, 1, 
                    1] < $CellContext`resonateraylength$], \
$CellContext`resonateraylength$ = 
                    Part[#, 1, 
                    1]; $CellContext`resonateintersections$ = #; \
$CellContext`resonatenumber$ = 
                    First[#2], $CellContext`resonatenumber$]& , \
$CellContext`intersectionslist$ = {{{-1., 0., 
                    0.}}}; $CellContext`holeQlist$ = {
                    0}; ({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$ - 1. 
                    Re[$CellContext`xs2$$]; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, 
                    Optica`Optica`TempVar3, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; 
                    Optica`Optica`TempVar1 = $CellContext`rx$^2 + \
$CellContext`ry$^2 + $CellContext`rz$^2; 
                    Optica`Optica`TempVar2 = $CellContext`rx$ \
$CellContext`xunit$ + $CellContext`ry$ $CellContext`yunit$ + $CellContext`rz$ \
$CellContext`zunit$ - $CellContext`cs21$$ $CellContext`xunit$; 
                    Optica`Optica`TempVar3 = -Optica`Optica`TempVar1 + 
                    Optica`Optica`TempVar2^2 + 
                    2 $CellContext`rx$ $CellContext`cs21$$; 
                    Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; 
                    If[N[
                    Chop[Optica`Optica`TempVar3]] >= 0., 
                    Optica`Optica`TempVar3 = Sqrt[Optica`Optica`TempVar3]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = {-Optica`Optica`TempVar2 - 
                    Optica`Optica`TempVar3, $CellContext`ry$ - (
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ - (Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    0.25 Abs[$CellContext`as2$$]^2, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-$CellContext`cs21$$ + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    Sqrt[$CellContext`cs21$$^2 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`cs21$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = {-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3, $CellContext`ry$ + (-
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ + (-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    0.25 Abs[$CellContext`as2$$]^2, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-$CellContext`cs21$$ + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    Sqrt[$CellContext`cs21$$^2 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`cs21$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    If[Part[Optica`Optica`TempVar, 1] == 
                    Part[Optica`Optica`TempVar, 2], {
                    Part[Optica`Optica`TempVar, 1]}, 
                    Optica`Optica`TempVar], {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 800969.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$ - 1. 
                    Re[$CellContext`ts2$$ + $CellContext`xs2$$]; \
$CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = $CellContext`rez$; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, 
                    Optica`Optica`TempVar3, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; 
                    Optica`Optica`TempVar1 = $CellContext`rx$^2 + \
$CellContext`ry$^2 + $CellContext`rz$^2; 
                    Optica`Optica`TempVar2 = $CellContext`rx$ \
$CellContext`xunit$ + $CellContext`ry$ $CellContext`yunit$ + $CellContext`rz$ \
$CellContext`zunit$ - $CellContext`cs22$$ $CellContext`xunit$; 
                    Optica`Optica`TempVar3 = -Optica`Optica`TempVar1 + 
                    Optica`Optica`TempVar2^2 + 
                    2 $CellContext`rx$ $CellContext`cs22$$; 
                    Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; 
                    If[N[
                    Chop[Optica`Optica`TempVar3]] >= 0., 
                    Optica`Optica`TempVar3 = Sqrt[Optica`Optica`TempVar3]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = {-Optica`Optica`TempVar2 - 
                    Optica`Optica`TempVar3, $CellContext`ry$ - (
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ - (Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    0.25 Abs[$CellContext`as2$$]^2, 
                    
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-$CellContext`cs22$$ + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    Sqrt[$CellContext`cs22$$^2 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`cs22$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = {-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3, $CellContext`ry$ + (-
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ + (-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    0.25 Abs[$CellContext`as2$$]^2, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-$CellContext`cs22$$ + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    Sqrt[$CellContext`cs22$$^2 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`cs22$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    If[Part[Optica`Optica`TempVar, 1] == 
                    Part[Optica`Optica`TempVar, 2], {
                    Part[Optica`Optica`TempVar, 1]}, 
                    Optica`Optica`TempVar], {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 800970.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]); $CellContext`holeQlist$ = 
                    Drop[$CellContext`holeQlist$, 1]; 
                    Drop[$CellContext`intersectionslist$, 1]]); 
                    Which[$CellContext`resonatenumber$ == 
                    1, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$ - 1. 
                    Re[$CellContext`xs2$$]; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {3., 1., 
                    800969.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {3., 1., 
                    800969.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
$CellContext`rxhlp$ + 
                    Re[$CellContext`xs2$$]; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., -((
                    Sign[$CellContext`cs21$$] \
$CellContext`ray2$)/($CellContext`cs21$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5), -((
                    Sign[$CellContext`cs21$$] \
$CellContext`ray3$)/($CellContext`cs21$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5)}, {(
                    Sign[$CellContext`cs21$$] \
$CellContext`ray2$)/($CellContext`cs21$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5, 1., 
                    0.}, {(Sign[$CellContext`cs21$$] \
$CellContext`ray3$)/($CellContext`cs21$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5, 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    Re[$CellContext`xs2$$], 0., 
                    0.}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; If[$CellContext`intensity$ < 
                    0., $CellContext`intensity$ = 0., 
                    1.]; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[1 + (
                    1.34533359 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.0099774387) + (
                    0.209073176 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.04704507669999999) + (
                    0.9373571619999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    111.8867639999999)]; $CellContext`index1$ = \
$CellContext`index$; If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1 + (
                    1.34533359 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.0099774387) + (
                    0.209073176 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.04704507669999999) + (
                    0.9373571619999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 111.8867639999999)]; 
                    If[
                    Abs[$CellContext`alternateindex$ - $CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1 + (
                    1.34533359 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.0099774387) + (
                    0.209073176 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.04704507669999999) + (
                    0.9373571619999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    111.8867639999999)]]]; $CellContext`n12$ = \
$CellContext`index1$/$CellContext`index2$; $CellContext`index$ = \
$CellContext`index2$; If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    N[0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    2, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$ - 1. 
                    Re[$CellContext`ts2$$ + $CellContext`xs2$$]; \
$CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = $CellContext`rez$; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {3., 2., 
                    800970.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {3., 2., 
                    800970.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
$CellContext`rxhlp$ + 
                    Re[$CellContext`ts2$$ + $CellContext`xs2$$]; \
$CellContext`rey$ = $CellContext`ryhlp$; $CellContext`rez$ = \
$CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., -((
                    Sign[$CellContext`cs22$$] \
$CellContext`ray2$)/($CellContext`cs22$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5), -((
                    Sign[$CellContext`cs22$$] \
$CellContext`ray3$)/($CellContext`cs22$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5)}, {(
                    Sign[$CellContext`cs22$$] \
$CellContext`ray2$)/($CellContext`cs22$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5, 1., 
                    0.}, {(Sign[$CellContext`cs22$$] \
$CellContext`ray3$)/($CellContext`cs22$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5, 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    Re[$CellContext`ts2$$ + $CellContext`xs2$$], 0., 
                    0.}; $CellContext`activeregion$ = -1.; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; If[$CellContext`intensity$ < 
                    0., $CellContext`intensity$ = 0., 
                    1.]; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[1 + (
                    1.34533359 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.0099774387) + (
                    0.209073176 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.04704507669999999) + (
                    0.9373571619999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    111.8867639999999)]; $CellContext`index1$ = \
$CellContext`index$; If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1 + (
                    1.34533359 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.0099774387) + (
                    0.209073176 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.04704507669999999) + (
                    0.9373571619999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 111.8867639999999)]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1 + (
                    1.34533359 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.0099774387) + (
                    
                    0.209073176 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.04704507669999999) + (
                    0.9373571619999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    111.8867639999999)]]]; $CellContext`n12$ = \
$CellContext`index1$/$CellContext`index2$; $CellContext`index$ = \
$CellContext`index2$; If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    N[0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "], {$CellContext`completedray$}}, 
                    True, $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localoutrayspresent$ = 
                    True; {CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}], $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmVmYGAAYUYgVmeAgQ/2A0c3RJjknz1InHq4e/fjoAfQH/SmR8Nt
JIUbAPATktQ=
                    "]])& , $CellContext`inrays$]]]; If[
                 
                 And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                 Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ] 
                  1., 1.]; 
               If[$CellContext`localoutrayspresent$, 
                 If[$CellContext`localdummyoutrayspresent$, \
$CellContext`localoutrays$ = 
                    Select[$CellContext`localoutrays$, Part[#, 23] > 0.& ]; 
                   1., 1.]; $CellContext`outrays$ = 
                  Join[$CellContext`outrays$, $CellContext`localoutrays$]; 1.,
                  1.]; If[
                 
                 And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
                  Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
                 1., 1.]); 
              If[$CellContext`reportedrayspresent$, \
$CellContext`raysreported$ = True; $CellContext`reportedrays$ = 
                 Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                   
                   "], $CellContext`reportedlocalrays$]; 1., 
                1.]; $CellContext`inrays$ = $CellContext`deflectedlocalrays$; \
$CellContext`propagate$ = $CellContext`generationnumber$ < \
$CellContext`generationlimit$]; $CellContext`propagatedrays$ = 
             If[Length[$CellContext`outrays$] > 1, 
               Drop[$CellContext`outrays$, 1], $CellContext`outrays$]; If[
              
              And[$CellContext`generationnumber$ >= \
$CellContext`generationlimit$, $CellContext`deflectedrayspresent$], \
$CellContext`propagatedrays$ = 
               Join[$CellContext`propagatedrays$, \
$CellContext`deflectedlocalrays$]; 1., 1.]); (
            AddTo[$CellContext`generationnumber$, 
              1.]; $CellContext`reportedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, 
                0, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`deflectedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; ($CellContext`deflectedrayspresent$ = 
              False; $CellContext`reportedrayspresent$ = 
              False; $CellContext`deflecteddummyrayspresent$ = 
              False; $CellContext`reporteddummyrayspresent$ = 
              False; {$CellContext`deflectedlocalrays$, \
$CellContext`reportedlocalrays$} = Transpose[
                
                Map[(({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                   Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                   Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                   Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -0.827 + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                   Chop[$CellContext`rx$]; $CellContext`ry$ = 
                   Chop[$CellContext`ry$]; $CellContext`rz$ = 
                   Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                   False; $CellContext`intersections$ = {{-1., 0., 0.}}); 
                 If[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`deflectedrayspresent$ = 
                    True; ($CellContext`intersections$ = 
                    Block[{Compile`$19316}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., Part[#, 2]^2 + Part[#, 3]^2 <= 
                    0.3364], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$19316 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$19316), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$19316, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$19316}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 801030.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; $CellContext`intersections$ = Union[
                    Map[
                    If[Part[#, 2]^2 + Part[#, 3]^2 <= 
                    0.2025, $CellContext`holeQ$ = True; {-1., 0., 
                    0.}, #]& , $CellContext`unfilteredintersections$]]; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]); 
                   If[$CellContext`intersections$ != {{-1., 0., 
                    0.}}, $CellContext`intersectionspresent$ = 
                    True; ({$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {4., 1., 
                    801030.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {4., 1., 
                    801030.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    0.827 + $CellContext`rxhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}); ($CellContext`reportedrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    0.827, 0, 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`intensity$ = 
                    0.; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}})); {
                    
                    First[$CellContext`allcreatedrays$], \
$CellContext`completedray$}, $CellContext`reporteddummyrayspresent$ = 
                    True; {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, CompressedData["
1:eJxTTMoPSmVkYGBQZ4CBD/YDRzdEmOSfPUicerh79+Og6eZuAGaoMiY=
                   
                     "]}], $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`deflecteddummyrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmViYGAAYXUGGPhgP3B0Q4RJ/tmDxKmHu3c/DnoA/UFvemiGGwCy
wWJ9
                    "]])& , $CellContext`propagatedrays$]]; If[
               
               And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ]; 
               1., 1.]; If[
               
               And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
                Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
               1., 1.]); (
             If[$CellContext`reportedrayspresent$, $CellContext`reportedrays$ = 
                Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                  
                  "], $CellContext`reportedlocalrays$]; 1., 
               
               1.]; $CellContext`propagatedrays$ = \
$CellContext`deflectedlocalrays$); $CellContext`raysreported$ = \
$CellContext`reportedrayspresent$; 
            1.); ($CellContext`inrays$ = $CellContext`propagatedrays$; \
$CellContext`outrays$ = CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

              "]; $CellContext`deflectedrayspresent$ = 
             True; $CellContext`reportedrayspresent$ = 
             False; $CellContext`propagate$ = True; While[
              
              And[$CellContext`deflectedrayspresent$, \
$CellContext`propagate$], 
              AddTo[$CellContext`generationnumber$, 
                1.]; ($CellContext`deflecteddummyrayspresent$ = 
                False; $CellContext`deflectedrayspresent$ = 
                False; $CellContext`reportedrayspresent$ = 
                False; $CellContext`reporteddummyrayspresent$ = 
                True; $CellContext`localdummyoutrayspresent$ = 
                False; $CellContext`localoutrayspresent$ = 
                False; {$CellContext`deflectedlocalrays$, \
$CellContext`localoutrays$, $CellContext`reportedlocalrays$} = 
                Map[Flatten[#, 1]& , 
                  Transpose[
                   
                   Map[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; If[
                    
                    And[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`generationnumber$ < \
$CellContext`generationlimit$], ($CellContext`resonatenumber$ = 
                    0; $CellContext`resonateraylength$ = 
                    9.87654321*^8; $CellContext`resonateintersections$ = \
{{-1., 0., 0.}}; MapIndexed[If[
                    And[
                    Part[#, 1, 1] > -1., 
                    Part[#, 1, 
                    1] < $CellContext`resonateraylength$], \
$CellContext`resonateraylength$ = 
                    Part[#, 1, 
                    1]; $CellContext`resonateintersections$ = #; \
$CellContext`resonatenumber$ = 
                    First[#2], $CellContext`resonatenumber$]& , \
$CellContext`intersectionslist$ = {{{-1., 0., 
                    0.}}}; $CellContext`holeQlist$ = {
                    0}; ({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -1.034 + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$19472, Compile`$19618, Compile`$19619}, 
                    
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, 
                    Optica`Optica`TempVar3, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; 
                    Optica`Optica`TempVar1 = $CellContext`rx$^2 + \
$CellContext`ry$^2 + $CellContext`rz$^2; 
                    Optica`Optica`TempVar2 = $CellContext`rx$ \
$CellContext`xunit$ + $CellContext`ry$ $CellContext`yunit$ + $CellContext`rz$ \
$CellContext`zunit$ - (-31.8418) $CellContext`xunit$; 
                    Optica`Optica`TempVar3 = -Optica`Optica`TempVar1 + 
                    Optica`Optica`TempVar2^2 + 2 $CellContext`rx$ (-31.8418); 
                    Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; 
                    If[N[
                    Chop[Optica`Optica`TempVar3]] >= 0., 
                    Optica`Optica`TempVar3 = Sqrt[Optica`Optica`TempVar3]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = (
                    Compile`$19472 = Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3; {-Optica`Optica`TempVar2 - 
                    Optica`Optica`TempVar3, $CellContext`ry$ - 
                    Compile`$19472 $CellContext`yunit$, $CellContext`rz$ - 
                    Compile`$19472 $CellContext`zunit$}); If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    0.3364, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[31.8418 + $CellContext`rx$ + $CellContext`LocRayL$ \
$CellContext`xunit$ - 
                    Sqrt[1013.9002272399999` - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = (Compile`$19618 = -Optica`Optica`TempVar2; 
                    Compile`$19619 = Compile`$19618 + 
                    Optica`Optica`TempVar3; {
                    Compile`$19619, $CellContext`ry$ + 
                    Compile`$19619 $CellContext`yunit$, $CellContext`rz$ + 
                    Compile`$19619 $CellContext`zunit$}); If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    0.3364, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[31.8418 + $CellContext`rx$ + $CellContext`LocRayL$ \
$CellContext`xunit$ - 
                    Sqrt[1013.9002272399999` - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    If[Part[Optica`Optica`TempVar, 1] == 
                    Part[Optica`Optica`TempVar, 2], {
                    Part[Optica`Optica`TempVar, 1]}, 
                    Optica`Optica`TempVar], {{-1., 0., 0.}}]]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 801189.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -1.116 + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$19519, Compile`$19621, Compile`$19622}, 
                    
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, 
                    Optica`Optica`TempVar3, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; 
                    Optica`Optica`TempVar1 = $CellContext`rx$^2 + \
$CellContext`ry$^2 + $CellContext`rz$^2; 
                    Optica`Optica`TempVar2 = $CellContext`rx$ \
$CellContext`xunit$ + $CellContext`ry$ $CellContext`yunit$ + $CellContext`rz$ \
$CellContext`zunit$ - 1.4005 $CellContext`xunit$; 
                    Optica`Optica`TempVar3 = -Optica`Optica`TempVar1 + 
                    Optica`Optica`TempVar2^2 + 2 $CellContext`rx$ 1.4005; 
                    Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; 
                    If[N[
                    Chop[Optica`Optica`TempVar3]] >= 0., 
                    Optica`Optica`TempVar3 = Sqrt[Optica`Optica`TempVar3]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = (
                    Compile`$19519 = Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3; {-Optica`Optica`TempVar2 - 
                    Optica`Optica`TempVar3, $CellContext`ry$ - 
                    Compile`$19519 $CellContext`yunit$, $CellContext`rz$ - 
                    Compile`$19519 $CellContext`zunit$}); If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    0.3364, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-1.4005 + $CellContext`rx$ + $CellContext`LocRayL$ \
$CellContext`xunit$ + 
                    Sqrt[1.9614002500000003` - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = (Compile`$19621 = -Optica`Optica`TempVar2; 
                    Compile`$19622 = Compile`$19621 + 
                    Optica`Optica`TempVar3; {
                    Compile`$19622, $CellContext`ry$ + 
                    Compile`$19622 $CellContext`yunit$, $CellContext`rz$ + 
                    Compile`$19622 $CellContext`zunit$}); If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    0.3364, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-1.4005 + $CellContext`rx$ + $CellContext`LocRayL$ \
$CellContext`xunit$ + 
                    Sqrt[1.9614002500000003` - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    If[Part[Optica`Optica`TempVar, 1] == 
                    Part[Optica`Optica`TempVar, 2], {
                    Part[Optica`Optica`TempVar, 1]}, 
                    Optica`Optica`TempVar], {{-1., 0., 0.}}]]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 801190.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
-1.3940000000000001` + $CellContext`rex$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$19522, Compile`$19637, Compile`$19638}, 
                    
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, 
                    Optica`Optica`TempVar3, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; 
                    Optica`Optica`TempVar1 = $CellContext`rx$^2 + \
$CellContext`ry$^2 + $CellContext`rz$^2; 
                    Optica`Optica`TempVar2 = $CellContext`rx$ \
$CellContext`xunit$ + $CellContext`ry$ $CellContext`yunit$ + $CellContext`rz$ \
$CellContext`zunit$ - (-1.6991) $CellContext`xunit$; 
                    Optica`Optica`TempVar3 = -Optica`Optica`TempVar1 + 
                    Optica`Optica`TempVar2^2 + 2 $CellContext`rx$ (-1.6991); 
                    Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; 
                    If[N[
                    Chop[Optica`Optica`TempVar3]] >= 0., 
                    Optica`Optica`TempVar3 = Sqrt[Optica`Optica`TempVar3]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = (
                    Compile`$19522 = Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3; {-Optica`Optica`TempVar2 - 
                    Optica`Optica`TempVar3, $CellContext`ry$ - 
                    Compile`$19522 $CellContext`yunit$, $CellContext`rz$ - 
                    Compile`$19522 $CellContext`zunit$}); If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    0.3364, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[1.6991 + $CellContext`rx$ + $CellContext`LocRayL$ \
$CellContext`xunit$ - 
                    Sqrt[2.88694081 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = (Compile`$19637 = -Optica`Optica`TempVar2; 
                    Compile`$19638 = Compile`$19637 + 
                    Optica`Optica`TempVar3; {
                    Compile`$19638, $CellContext`ry$ + 
                    Compile`$19638 $CellContext`yunit$, $CellContext`rz$ + 
                    Compile`$19638 $CellContext`zunit$}); If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    0.3364, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[1.6991 + $CellContext`rx$ + $CellContext`LocRayL$ \
$CellContext`xunit$ - 
                    Sqrt[2.88694081 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    If[Part[Optica`Optica`TempVar, 1] == 
                    Part[Optica`Optica`TempVar, 2], {
                    Part[Optica`Optica`TempVar, 1]}, 
                    Optica`Optica`TempVar], {{-1., 0., 0.}}]]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 801191.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]); $CellContext`holeQlist$ = 
                    Drop[$CellContext`holeQlist$, 1]; 
                    Drop[$CellContext`intersectionslist$, 1]]); 
                    Which[$CellContext`resonatenumber$ == 
                    1, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -1.034 + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {5., 1., 
                    801189.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {5., 1., 
                    801189.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    1.034 + $CellContext`rxhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., -(-$CellContext`ray2$/(
                    1013.9002272399999` - $CellContext`ray2$^2 - \
$CellContext`ray3$^2)^(2^(-1))), -(-$CellContext`ray3$/(
                    1013.9002272399999` - $CellContext`ray2$^2 - \
$CellContext`ray3$^2)^(2^(-1)))}, {-$CellContext`ray2$/(
                    1013.9002272399999` - $CellContext`ray2$^2 - \
$CellContext`ray3$^2)^(2^(-1)), 1., 
                    0.}, {-$CellContext`ray3$/(
                    1013.9002272399999` - $CellContext`ray2$^2 - \
$CellContext`ray3$^2)^(2^(-1)), 0., 1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    1.034, 0, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; If[$CellContext`intensity$ < 
                    0., $CellContext`intensity$ = 0., 
                    1.]; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[1 + (
                    1.156870819999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.0080942425) + (
                    0.0642625444 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.0386051284) + (
                    0.8723761389999998 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    104.74773)]; $CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1 + (
                    1.156870819999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.0080942425) + (
                    0.0642625444 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.0386051284) + (
                    0.8723761389999998 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 104.74773)]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1 + (
                    1.156870819999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.0080942425) + (
                    0.0642625444 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.0386051284) + (
                    0.8723761389999998 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    104.74773)]]]; $CellContext`n12$ = \
$CellContext`index1$/$CellContext`index2$; $CellContext`index$ = \
$CellContext`index2$; If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    N[0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    2, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -1.116 + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {5., 2., 
                    801190.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {5., 2., 
                    801190.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    1.116 + $CellContext`rxhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., -($CellContext`ray2$/(
                    1.9614002500000003` - $CellContext`ray2$^2 - \
$CellContext`ray3$^2)^(2^(-1))), -($CellContext`ray3$/(
                    1.9614002500000003` - $CellContext`ray2$^2 - \
$CellContext`ray3$^2)^(2^(-1)))}, {$CellContext`ray2$/(
                    1.9614002500000003` - $CellContext`ray2$^2 - \
$CellContext`ray3$^2)^(2^(-1)), 1., 
                    0.}, {$CellContext`ray3$/(
                    1.9614002500000003` - $CellContext`ray2$^2 - \
$CellContext`ray3$^2)^(2^(-1)), 0., 1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    1.116, 0, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; If[$CellContext`intensity$ < 
                    0., $CellContext`intensity$ = 0., 
                    1.]; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[1 + (
                    1.291727649999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.006863581199999999) + (
                    0.2983927129999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.02287043119999998) + (
                    0.955518497 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    97.4779177)]; $CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1 + (
                    1.156870819999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.0080942425) + (
                    0.0642625444 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.0386051284) + (
                    0.8723761389999998 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 104.74773)]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1 + (
                    1.156870819999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.0080942425) + (
                    0.0642625444 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.0386051284) + (
                    0.8723761389999998 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    104.74773)]], $CellContext`index2$ = 
                    Sqrt[1 + (
                    1.156870819999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.0080942425) + (
                    0.0642625444 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.0386051284) + (
                    0.8723761389999998 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    104.74773)]; $CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1 + (
                    1.291727649999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.006863581199999999) + (
                    0.2983927129999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.02287043119999998) + (
                    0.955518497 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 97.4779177)]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1 + (
                    1.291727649999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.006863581199999999) + (
                    0.2983927129999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.02287043119999998) + (
                    0.955518497 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    97.4779177)]]]; $CellContext`n12$ = \
$CellContext`index1$/$CellContext`index2$; $CellContext`index$ = \
$CellContext`index2$; If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    N[0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    3, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
-1.3940000000000001` + $CellContext`rex$; $CellContext`ry$ = \
$CellContext`rey$; $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {5., 3., 
                    801191.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {5., 3., 
                    801191.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    1.3940000000000001` + $CellContext`rxhlp$; \
$CellContext`rey$ = $CellContext`ryhlp$; $CellContext`rez$ = \
$CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., -(-$CellContext`ray2$/(
                    2.88694081 - $CellContext`ray2$^2 - \
$CellContext`ray3$^2)^(2^(-1))), -(-$CellContext`ray3$/(
                    2.88694081 - $CellContext`ray2$^2 - \
$CellContext`ray3$^2)^(2^(-1)))}, {-$CellContext`ray2$/(
                    
                    2.88694081 - $CellContext`ray2$^2 - \
$CellContext`ray3$^2)^(2^(-1)), 1., 
                    0.}, {-$CellContext`ray3$/(
                    2.88694081 - $CellContext`ray2$^2 - \
$CellContext`ray3$^2)^(2^(-1)), 0., 1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    1.3940000000000001`, 0, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; If[$CellContext`intensity$ < 
                    0., $CellContext`intensity$ = 0., 
                    1.]; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[1 + (
                    1.291727649999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.006863581199999999) + (
                    0.2983927129999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.02287043119999998) + (
                    0.955518497 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    97.4779177)]; $CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1 + (
                    1.291727649999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.006863581199999999) + (
                    0.2983927129999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.02287043119999998) + (
                    0.955518497 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 97.4779177)]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1 + (
                    1.291727649999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.006863581199999999) + (
                    0.2983927129999999 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    0.02287043119999998) + (
                    0.955518497 \
$CellContext`wavelength$^2)/($CellContext`wavelength$^2 - 
                    97.4779177)]]]; $CellContext`n12$ = \
$CellContext`index1$/$CellContext`index2$; $CellContext`index$ = \
$CellContext`index2$; If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[
                    Chop[$CellContext`axismagnitude$] != 
                    N[0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "], {$CellContext`completedray$}}, 
                    True, $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localoutrayspresent$ = 
                    True; {CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}], $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmVmYGAAYUYgVmeAgQ/2A0c3RJjknz1InHq4e/fjoAfQH/SmR8Nt
JIUbAPATktQ=
                    "]])& , $CellContext`inrays$]]]; If[
                 
                 And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                 Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ] 
                  1., 1.]; 
               If[$CellContext`localoutrayspresent$, 
                 If[$CellContext`localdummyoutrayspresent$, \
$CellContext`localoutrays$ = 
                    Select[$CellContext`localoutrays$, Part[#, 23] > 0.& ]; 
                   1., 1.]; $CellContext`outrays$ = 
                  Join[$CellContext`outrays$, $CellContext`localoutrays$]; 1.,
                  1.]; If[
                 
                 And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
                  Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
                 1., 1.]); 
              If[$CellContext`reportedrayspresent$, \
$CellContext`raysreported$ = True; $CellContext`reportedrays$ = 
                 Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                   
                   "], $CellContext`reportedlocalrays$]; 1., 
                1.]; $CellContext`inrays$ = $CellContext`deflectedlocalrays$; \
$CellContext`propagate$ = $CellContext`generationnumber$ < \
$CellContext`generationlimit$]; $CellContext`propagatedrays$ = 
             If[Length[$CellContext`outrays$] > 1, 
               Drop[$CellContext`outrays$, 1], $CellContext`outrays$]; If[
              
              And[$CellContext`generationnumber$ >= \
$CellContext`generationlimit$, $CellContext`deflectedrayspresent$], \
$CellContext`propagatedrays$ = 
               Join[$CellContext`propagatedrays$, \
$CellContext`deflectedlocalrays$]; 1., 1.]); (
            AddTo[$CellContext`generationnumber$, 
              1.]; $CellContext`reportedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, 
                0, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`deflectedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; ($CellContext`deflectedrayspresent$ = 
              False; $CellContext`reportedrayspresent$ = 
              False; $CellContext`deflecteddummyrayspresent$ = 
              False; $CellContext`reporteddummyrayspresent$ = 
              False; {$CellContext`deflectedlocalrays$, \
$CellContext`reportedlocalrays$} = Transpose[
                
                Map[(({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$ 
                    Re[(-0.7071067811865475) 
                    Cos[0.017453292519943295` $CellContext`MirrorAngle$$] + 
                    0.7071067811865475 
                    Sin[0.017453292519943295` $CellContext`MirrorAngle$$]] + \
$CellContext`r1$ Re[0.7071067811865475 
                    Cos[0.017453292519943295` $CellContext`MirrorAngle$$] + 
                    0.7071067811865475 
                    Sin[0.017453292519943295` $CellContext`MirrorAngle$$]]; \
$CellContext`yunit$ = $CellContext`r1$ 
                    Re[0.7071067811865475 
                    Cos[0.017453292519943295` $CellContext`MirrorAngle$$] - 
                    0.7071067811865475 
                    Sin[0.017453292519943295` $CellContext`MirrorAngle$$]] + \
$CellContext`r2$ Re[0.7071067811865475 
                    Cos[0.017453292519943295` $CellContext`MirrorAngle$$] + 
                    0.7071067811865475 
                    Sin[0.017453292519943295` $CellContext`MirrorAngle$$]]; \
$CellContext`zunit$ = $CellContext`r3$ 
                    Re[Cos[0.017453292519943295` \
$CellContext`MirrorAngle$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`MirrorAngle$$]^2]; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                   Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                   
                   Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
($CellContext`rey$ - 1. 
                    Re[0.7071067811865475 (0.5 - 0.5 
                    Cos[0.017453292519943295` $CellContext`MirrorAngle$$]) - 
                    0.35355339059327373` 
                    Sin[0.017453292519943295` $CellContext`MirrorAngle$$]]) 
                    Re[(-0.7071067811865475) 
                    Cos[0.017453292519943295` $CellContext`MirrorAngle$$] + 
                    0.7071067811865475 
                    Sin[0.017453292519943295` $CellContext`MirrorAngle$$]] + \
(-3. + $CellContext`rex$ - 1. 
                    Re[0.7071067811865475 (0.5 - 0.5 
                    Cos[0.017453292519943295` $CellContext`MirrorAngle$$]) + 
                    0.35355339059327373` 
                    Sin[0.017453292519943295` $CellContext`MirrorAngle$$]]) 
                    Re[0.7071067811865475 
                    Cos[0.017453292519943295` $CellContext`MirrorAngle$$] + 
                    0.7071067811865475 
                    Sin[0.017453292519943295` $CellContext`MirrorAngle$$]]; \
$CellContext`ry$ = Re[
                    0.7071067811865475 
                    Cos[0.017453292519943295` $CellContext`MirrorAngle$$] - 
                    0.7071067811865475 
                    Sin[0.017453292519943295` $CellContext`MirrorAngle$$]] \
(-3. + $CellContext`rex$ - 1. 
                    Re[0.7071067811865475 (0.5 - 0.5 
                    Cos[0.017453292519943295` $CellContext`MirrorAngle$$]) + 
                    0.35355339059327373` 
                    Sin[0.017453292519943295` $CellContext`MirrorAngle$$]]) + \
($CellContext`rey$ - 1. 
                    Re[0.7071067811865475 (0.5 - 0.5 
                    Cos[0.017453292519943295` $CellContext`MirrorAngle$$]) - 
                    0.35355339059327373` 
                    Sin[0.017453292519943295` $CellContext`MirrorAngle$$]]) 
                    Re[0.7071067811865475 
                    Cos[0.017453292519943295` $CellContext`MirrorAngle$$] + 
                    0.7071067811865475 
                    Sin[0.017453292519943295` $CellContext`MirrorAngle$$]]; \
$CellContext`rz$ = $CellContext`rez$ 
                    Re[Cos[0.017453292519943295` \
$CellContext`MirrorAngle$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`MirrorAngle$$]^2]; \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                   Chop[$CellContext`ry$]; $CellContext`rz$ = 
                   Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                   False; $CellContext`intersections$ = {{-1., 0., 0.}}); 
                 If[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`deflectedrayspresent$ = 
                    True; ($CellContext`intersections$ = 
                    Block[{Compile`$19319}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., Part[#, 2]^2 + Part[#, 3]^2 <= 0.25], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$19319 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$19319), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$19319, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$19319}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 801219.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]); 
                   If[$CellContext`intersections$ != {{-1., 0., 
                    0.}}, $CellContext`intersectionspresent$ = 
                    True; ({$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {6., 1., 
                    801219.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {6., 1., 
                    801219.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    3. + $CellContext`ryhlp$ 
                    Re[0.7071067811865475 
                    Cos[0.017453292519943295` $CellContext`MirrorAngle$$] - 
                    0.7071067811865475 
                    Sin[0.017453292519943295` $CellContext`MirrorAngle$$]] + 
                    Re[0.7071067811865475 (0.5 - 0.5 
                    Cos[0.017453292519943295` $CellContext`MirrorAngle$$]) + 
                    0.35355339059327373` 
                    Sin[0.017453292519943295` $CellContext`MirrorAngle$$]] + \
$CellContext`rxhlp$ Re[0.7071067811865475 
                    Cos[0.017453292519943295` $CellContext`MirrorAngle$$] + 
                    0.7071067811865475 
                    Sin[0.017453292519943295` $CellContext`MirrorAngle$$]]; \
$CellContext`rey$ = Re[0.7071067811865475 (0.5 - 0.5 
                    Cos[0.017453292519943295` $CellContext`MirrorAngle$$]) - 
                    0.35355339059327373` 
                    Sin[0.017453292519943295` $CellContext`MirrorAngle$$]] + \
$CellContext`rxhlp$ Re[(-0.7071067811865475) 
                    Cos[0.017453292519943295` $CellContext`MirrorAngle$$] + 
                    0.7071067811865475 
                    Sin[0.017453292519943295` $CellContext`MirrorAngle$$]] + \
$CellContext`ryhlp$ Re[0.7071067811865475 
                    Cos[0.017453292519943295` $CellContext`MirrorAngle$$] + 
                    0.7071067811865475 
                    Sin[0.017453292519943295` $CellContext`MirrorAngle$$]]; \
$CellContext`rez$ = $CellContext`rzhlp$ 
                    Re[Cos[0.017453292519943295` \
$CellContext`MirrorAngle$$]^2 + 
                    Sin[0.017453292519943295` $CellContext`MirrorAngle$$]^2]; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}); ($CellContext`reportedrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{
                    Re[0.7071067811865475 
                    Cos[0.017453292519943295` $CellContext`MirrorAngle$$] + 
                    0.7071067811865475 
                    Sin[0.017453292519943295` $CellContext`MirrorAngle$$]]/(-
                    Re[0.7071067811865475 
                    Cos[0.017453292519943295` $CellContext`MirrorAngle$$] - 
                    0.7071067811865475 
                    Sin[0.017453292519943295` $CellContext`MirrorAngle$$]] 
                    Re[(-0.7071067811865475) 
                    Cos[0.017453292519943295` $CellContext`MirrorAngle$$] + 
                    0.7071067811865475 
                    Sin[0.017453292519943295` $CellContext`MirrorAngle$$]] + 
                    Re[0.7071067811865475 
                    Cos[0.017453292519943295` $CellContext`MirrorAngle$$] + 
                    0.7071067811865475 
                    Sin[0.017453292519943295` \
$CellContext`MirrorAngle$$]]^2), (-
                    Re[(-0.7071067811865475) 
                    Cos[0.017453292519943295` $CellContext`MirrorAngle$$] + 
                    0.7071067811865475 
                    Sin[0.017453292519943295` $CellContext`MirrorAngle$$]])/(-
                    Re[0.7071067811865475 
                    Cos[0.017453292519943295` $CellContext`MirrorAngle$$] - 
                    0.7071067811865475 
                    Sin[0.017453292519943295` $CellContext`MirrorAngle$$]] 
                    Re[(-0.7071067811865475) 
                    Cos[0.017453292519943295` $CellContext`MirrorAngle$$] + 
                    0.7071067811865475 
                    Sin[0.017453292519943295` $CellContext`MirrorAngle$$]] + 
                    Re[0.7071067811865475 
                    Cos[0.017453292519943295` $CellContext`MirrorAngle$$] + 
                    0.7071067811865475 
                    Sin[0.017453292519943295` $CellContext`MirrorAngle$$]]^2),
                     0.}, {(-Re[
                    0.7071067811865475 
                    Cos[0.017453292519943295` $CellContext`MirrorAngle$$] - 
                    0.7071067811865475 
                    Sin[0.017453292519943295` $CellContext`MirrorAngle$$]])/(-
                    Re[0.7071067811865475 
                    Cos[0.017453292519943295` $CellContext`MirrorAngle$$] - 
                    0.7071067811865475 
                    Sin[0.017453292519943295` $CellContext`MirrorAngle$$]] 
                    Re[(-0.7071067811865475) 
                    Cos[0.017453292519943295` $CellContext`MirrorAngle$$] + 
                    0.7071067811865475 
                    Sin[0.017453292519943295` $CellContext`MirrorAngle$$]] + 
                    Re[0.7071067811865475 
                    Cos[0.017453292519943295` $CellContext`MirrorAngle$$] + 
                    0.7071067811865475 
                    Sin[0.017453292519943295` $CellContext`MirrorAngle$$]]^2),
                     Re[0.7071067811865475 
                    Cos[0.017453292519943295` $CellContext`MirrorAngle$$] + 
                    0.7071067811865475 
                    Sin[0.017453292519943295` $CellContext`MirrorAngle$$]]/(-
                    Re[0.7071067811865475 
                    Cos[0.017453292519943295` $CellContext`MirrorAngle$$] - 
                    0.7071067811865475 
                    Sin[0.017453292519943295` $CellContext`MirrorAngle$$]] 
                    Re[(-0.7071067811865475) 
                    Cos[0.017453292519943295` $CellContext`MirrorAngle$$] + 
                    0.7071067811865475 
                    Sin[0.017453292519943295` $CellContext`MirrorAngle$$]] + 
                    Re[0.7071067811865475 
                    Cos[0.017453292519943295` $CellContext`MirrorAngle$$] + 
                    0.7071067811865475 
                    Sin[0.017453292519943295` $CellContext`MirrorAngle$$]]^2),
                     0.}, {0., 
                    0., (-Re[0.7071067811865475 
                    Cos[0.017453292519943295` $CellContext`MirrorAngle$$] - 
                    0.7071067811865475 
                    Sin[0.017453292519943295` $CellContext`MirrorAngle$$]] 
                    Re[(-0.7071067811865475) 
                    Cos[0.017453292519943295` $CellContext`MirrorAngle$$] + 
                    0.7071067811865475 
                    Sin[0.017453292519943295` $CellContext`MirrorAngle$$]] + 
                    Re[0.7071067811865475 
                    Cos[0.017453292519943295` $CellContext`MirrorAngle$$] + 
                    0.7071067811865475 
                    Sin[0.017453292519943295` \
$CellContext`MirrorAngle$$]]^2)/(-
                    Re[0.7071067811865475 
                    Cos[0.017453292519943295` $CellContext`MirrorAngle$$] - 
                    0.7071067811865475 
                    Sin[0.017453292519943295` $CellContext`MirrorAngle$$]] 
                    Re[(-0.7071067811865475) 
                    Cos[0.017453292519943295` $CellContext`MirrorAngle$$] + 
                    0.7071067811865475 
                    Sin[0.017453292519943295` $CellContext`MirrorAngle$$]] + 
                    Re[0.7071067811865475 
                    Cos[0.017453292519943295` $CellContext`MirrorAngle$$] + 
                    0.7071067811865475 
                    Sin[0.017453292519943295` \
$CellContext`MirrorAngle$$]]^2)}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{
                    Re[
                    0.7071067811865475 
                    Cos[0.017453292519943295` $CellContext`MirrorAngle$$] + 
                    0.7071067811865475 
                    Sin[0.017453292519943295` $CellContext`MirrorAngle$$]], 
                    
                    Re[(-0.7071067811865475) 
                    Cos[0.017453292519943295` $CellContext`MirrorAngle$$] + 
                    0.7071067811865475 
                    Sin[0.017453292519943295` $CellContext`MirrorAngle$$]], 
                    0.}, {
                    Re[
                    0.7071067811865475 
                    Cos[0.017453292519943295` $CellContext`MirrorAngle$$] - 
                    0.7071067811865475 
                    Sin[0.017453292519943295` $CellContext`MirrorAngle$$]], 
                    Re[
                    0.7071067811865475 
                    Cos[0.017453292519943295` $CellContext`MirrorAngle$$] + 
                    0.7071067811865475 
                    Sin[0.017453292519943295` $CellContext`MirrorAngle$$]], 
                    0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    3. + Re[
                    0.7071067811865475 (0.5 - 0.5 
                    Cos[0.017453292519943295` $CellContext`MirrorAngle$$]) + 
                    0.35355339059327373` 
                    Sin[0.017453292519943295` $CellContext`MirrorAngle$$]], 
                    Re[
                    0.7071067811865475 (0.5 - 0.5 
                    Cos[0.017453292519943295` $CellContext`MirrorAngle$$]) - 
                    0.35355339059327373` 
                    Sin[0.017453292519943295` $CellContext`MirrorAngle$$]], 
                    0.}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; 
                    If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; If[$CellContext`intensity$ < 
                    0., $CellContext`intensity$ = 0., 
                    1.]; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} - 2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`allcreatedrays$ = \
{{$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$, $CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$, $CellContext`r4$, $CellContext`r5$, $CellContext`r6$, \
$CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    N[0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$])); {
                    
                    First[$CellContext`allcreatedrays$], \
$CellContext`completedray$}, $CellContext`reporteddummyrayspresent$ = 
                    True; {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, CompressedData["
1:eJxTTMoPSmVkYGBQZ4CBD/YDRzdEmOSfPUicerh79+Og6eZuAGaoMiY=
                   
                     "]}], $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`deflecteddummyrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmViYGAAYXUGGPhgP3B0Q4RJ/tmDxKmHu3c/DnoA/UFvemiGGwCy
wWJ9
                    "]])& , $CellContext`propagatedrays$]]; If[
               
               And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ]; 
               1., 1.]; If[
               
               And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
                Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
               1., 1.]); (
             If[$CellContext`reportedrayspresent$, $CellContext`reportedrays$ = 
                Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                  
                  "], $CellContext`reportedlocalrays$]; 1., 
               1.]; $CellContext`propagatedrays$ = \
$CellContext`deflectedlocalrays$); $CellContext`raysreported$ = \
$CellContext`reportedrayspresent$; 1.); (
            AddTo[$CellContext`generationnumber$, 
              1.]; $CellContext`reportedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, 
                0, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`deflectedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; ($CellContext`deflectedrayspresent$ = 
              False; $CellContext`reportedrayspresent$ = 
              False; $CellContext`deflecteddummyrayspresent$ = 
              False; $CellContext`reporteddummyrayspresent$ = 
              False; {$CellContext`deflectedlocalrays$, \
$CellContext`reportedlocalrays$} = Transpose[
                
                Map[(({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                   Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                   Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -1.617 + \
$CellContext`rey$; $CellContext`ry$ = -(-3. + $CellContext`rex$); \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                   Chop[$CellContext`rx$]; $CellContext`ry$ = 
                   Chop[$CellContext`ry$]; $CellContext`rz$ = 
                   Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                   False; $CellContext`intersections$ = {{-1., 0., 0.}}); 
                 If[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`deflectedrayspresent$ = 
                    True; ($CellContext`intersections$ = 
                    Block[{Compile`$19320}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., Part[#, 2]^2 + Part[#, 3]^2 <= 
                    0.3364], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$19320 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$19320), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$19320, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$19320}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 801259.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]); 
                   If[$CellContext`intersections$ != {{-1., 0., 
                    0.}}, $CellContext`intersectionspresent$ = 
                    True; ({$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {7., 1., 
                    801259.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {7., 1., 
                    801259.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    3. - 1. $CellContext`ryhlp$; $CellContext`rey$ = 
                    1.617 + $CellContext`rxhlp$; $CellContext`rez$ = \
$CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}); ($CellContext`reportedrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    3., 1.617, 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}})); {
                    
                    First[$CellContext`allcreatedrays$], \
$CellContext`completedray$}, $CellContext`reporteddummyrayspresent$ = 
                    True; {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, CompressedData["
1:eJxTTMoPSmVkYGBQZ4CBD/YDRzdEmOSfPUicerh79+Og6eZuAGaoMiY=
                   
                     "]}], $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`deflecteddummyrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmViYGAAYXUGGPhgP3B0Q4RJ/tmDxKmHu3c/DnoA/UFvemiGGwCy
wWJ9
                    "]])& , $CellContext`propagatedrays$]]; If[
               
               And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ]; 
               1., 1.]; If[
               
               And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
                Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
               1., 1.]); (
             If[$CellContext`reportedrayspresent$, $CellContext`reportedrays$ = 
                Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                  
                  "], $CellContext`reportedlocalrays$]; 1., 
               1.]; $CellContext`propagatedrays$ = \
$CellContext`deflectedlocalrays$); $CellContext`raysreported$ = \
$CellContext`reportedrayspresent$; 
            1.); ($CellContext`inrays$ = $CellContext`propagatedrays$; \
$CellContext`outrays$ = CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

              "]; $CellContext`deflectedrayspresent$ = 
             True; $CellContext`reportedrayspresent$ = 
             False; $CellContext`propagate$ = True; While[
              
              And[$CellContext`deflectedrayspresent$, \
$CellContext`propagate$], 
              AddTo[$CellContext`generationnumber$, 
                1.]; ($CellContext`deflecteddummyrayspresent$ = 
                False; $CellContext`deflectedrayspresent$ = 
                False; $CellContext`reportedrayspresent$ = 
                False; $CellContext`reporteddummyrayspresent$ = 
                True; $CellContext`localdummyoutrayspresent$ = 
                False; $CellContext`localoutrayspresent$ = 
                False; {$CellContext`deflectedlocalrays$, \
$CellContext`localoutrays$, $CellContext`reportedlocalrays$} = 
                Map[Flatten[#, 1]& , 
                  Transpose[
                   
                   Map[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; If[
                    
                    And[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`generationnumber$ < \
$CellContext`generationlimit$], ($CellContext`resonatenumber$ = 
                    0; $CellContext`resonateraylength$ = 
                    9.87654321*^8; $CellContext`resonateintersections$ = \
{{-1., 0., 0.}}; MapIndexed[If[
                    And[
                    Part[#, 1, 1] > -1., 
                    Part[#, 1, 
                    1] < $CellContext`resonateraylength$], \
$CellContext`resonateraylength$ = 
                    Part[#, 1, 
                    1]; $CellContext`resonateintersections$ = #; \
$CellContext`resonatenumber$ = 
                    First[#2], $CellContext`resonatenumber$]& , \
$CellContext`intersectionslist$ = {{{-1., 0., 
                    0.}}}; $CellContext`holeQlist$ = {
                    0}; ({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rey$ - 1. 
                    Re[$CellContext`y1$$]; $CellContext`ry$ = -(-3. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, 
                    Optica`Optica`TempVar3, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; 
                    Optica`Optica`TempVar1 = $CellContext`rx$^2 + \
$CellContext`ry$^2 + $CellContext`rz$^2; 
                    Optica`Optica`TempVar2 = $CellContext`rx$ \
$CellContext`xunit$ + $CellContext`ry$ $CellContext`yunit$ + $CellContext`rz$ \
$CellContext`zunit$ - $CellContext`c11$$ $CellContext`xunit$; 
                    Optica`Optica`TempVar3 = -Optica`Optica`TempVar1 + 
                    Optica`Optica`TempVar2^2 + 
                    2 $CellContext`rx$ $CellContext`c11$$; 
                    Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; 
                    If[N[
                    Chop[Optica`Optica`TempVar3]] >= 0., 
                    Optica`Optica`TempVar3 = Sqrt[Optica`Optica`TempVar3]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = {-Optica`Optica`TempVar2 - 
                    Optica`Optica`TempVar3, $CellContext`ry$ - (
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ - (Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    0.3364, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-$CellContext`c11$$ + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    Sqrt[$CellContext`c11$$^2 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`c11$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = {-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3, $CellContext`ry$ + (-
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ + (-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    0.3364, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-$CellContext`c11$$ + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    Sqrt[$CellContext`c11$$^2 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`c11$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    If[Part[Optica`Optica`TempVar, 1] == 
                    Part[Optica`Optica`TempVar, 2], {
                    Part[Optica`Optica`TempVar, 1]}, 
                    Optica`Optica`TempVar], {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 801315.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rey$ - 1. 
                    Re[$CellContext`t1$$ + $CellContext`y1$$]; \
$CellContext`ry$ = -(-3. + $CellContext`rex$); $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, 
                    Optica`Optica`TempVar3, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; 
                    Optica`Optica`TempVar1 = $CellContext`rx$^2 + \
$CellContext`ry$^2 + $CellContext`rz$^2; 
                    Optica`Optica`TempVar2 = $CellContext`rx$ \
$CellContext`xunit$ + $CellContext`ry$ $CellContext`yunit$ + $CellContext`rz$ \
$CellContext`zunit$ - $CellContext`c12$$ $CellContext`xunit$; 
                    Optica`Optica`TempVar3 = -Optica`Optica`TempVar1 + 
                    Optica`Optica`TempVar2^2 + 
                    2 $CellContext`rx$ $CellContext`c12$$; 
                    Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; 
                    If[N[
                    Chop[Optica`Optica`TempVar3]] >= 0., 
                    Optica`Optica`TempVar3 = Sqrt[Optica`Optica`TempVar3]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = {-Optica`Optica`TempVar2 - 
                    Optica`Optica`TempVar3, $CellContext`ry$ - (
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ - (Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    0.3364, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-$CellContext`c12$$ + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    Sqrt[$CellContext`c12$$^2 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`c12$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = {-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3, $CellContext`ry$ + (-
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ + (-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    0.3364, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-$CellContext`c12$$ + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    Sqrt[$CellContext`c12$$^2 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`c12$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    If[Part[Optica`Optica`TempVar, 1] == 
                    Part[Optica`Optica`TempVar, 2], {
                    Part[Optica`Optica`TempVar, 1]}, 
                    Optica`Optica`TempVar], {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 801316.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]); $CellContext`holeQlist$ = 
                    Drop[$CellContext`holeQlist$, 1]; 
                    Drop[$CellContext`intersectionslist$, 1]]); 
                    Which[$CellContext`resonatenumber$ == 
                    1, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rey$ - 1. 
                    Re[$CellContext`y1$$]; $CellContext`ry$ = -(-3. + \
$CellContext`rex$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {8., 1., 
                    801315.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {8., 1., 
                    801315.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    3. - 1. $CellContext`ryhlp$; $CellContext`rey$ = \
$CellContext`rxhlp$ + 
                    Re[$CellContext`y1$$]; $CellContext`rez$ = \
$CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., -((
                    Sign[$CellContext`c11$$] \
$CellContext`ray2$)/($CellContext`c11$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5), -((
                    Sign[$CellContext`c11$$] \
$CellContext`ray3$)/($CellContext`c11$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5)}, {(
                    Sign[$CellContext`c11$$] \
$CellContext`ray2$)/($CellContext`c11$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5, 1., 
                    0.}, {(Sign[$CellContext`c11$$] \
$CellContext`ray3$)/($CellContext`c11$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5, 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {3., 
                    Re[$CellContext`y1$$], 0.}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[Abs[$CellContext`raytiltx$] < 
                    1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; If[$CellContext`intensity$ < 
                    0., $CellContext`intensity$ = 0., 
                    1.]; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    N[0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    2, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rey$ - 1. 
                    Re[$CellContext`t1$$ + $CellContext`y1$$]; \
$CellContext`ry$ = -(-3. + $CellContext`rex$); $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {8., 2., 
                    801316.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {8., 2., 
                    801316.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    3. - 
                    1. $CellContext`ryhlp$; $CellContext`rey$ = \
$CellContext`rxhlp$ + 
                    Re[$CellContext`t1$$ + $CellContext`y1$$]; \
$CellContext`rez$ = $CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., -((
                    Sign[$CellContext`c12$$] \
$CellContext`ray2$)/($CellContext`c12$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5), -((
                    Sign[$CellContext`c12$$] \
$CellContext`ray3$)/($CellContext`c12$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5)}, {(
                    Sign[$CellContext`c12$$] \
$CellContext`ray2$)/($CellContext`c12$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5, 1., 
                    0.}, {(Sign[$CellContext`c12$$] \
$CellContext`ray3$)/($CellContext`c12$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5, 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {3., 
                    Re[$CellContext`t1$$ + $CellContext`y1$$], 
                    0.}; $CellContext`activeregion$ = -1.; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; If[$CellContext`intensity$ < 
                    0., $CellContext`intensity$ = 0., 
                    1.]; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    N[
                    0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "], {$CellContext`completedray$}}, 
                    True, $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localoutrayspresent$ = 
                    True; {CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}], $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmVmYGAAYUYgVmeAgQ/2A0c3RJjknz1InHq4e/fjoAfQH/SmR8Nt
JIUbAPATktQ=
                    "]])& , $CellContext`inrays$]]]; If[
                 
                 And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                 Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ] 
                  1., 1.]; 
               If[$CellContext`localoutrayspresent$, 
                 If[$CellContext`localdummyoutrayspresent$, \
$CellContext`localoutrays$ = 
                    Select[$CellContext`localoutrays$, Part[#, 23] > 0.& ]; 
                   1., 1.]; $CellContext`outrays$ = 
                  Join[$CellContext`outrays$, $CellContext`localoutrays$]; 1.,
                  1.]; If[
                 
                 And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
                  Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
                 1., 1.]); 
              If[$CellContext`reportedrayspresent$, \
$CellContext`raysreported$ = True; $CellContext`reportedrays$ = 
                 Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                   
                   "], $CellContext`reportedlocalrays$]; 1., 
                1.]; $CellContext`inrays$ = $CellContext`deflectedlocalrays$; \
$CellContext`propagate$ = $CellContext`generationnumber$ < \
$CellContext`generationlimit$]; $CellContext`propagatedrays$ = 
             If[Length[$CellContext`outrays$] > 1, 
               Drop[$CellContext`outrays$, 1], $CellContext`outrays$]; If[
              
              And[$CellContext`generationnumber$ >= \
$CellContext`generationlimit$, $CellContext`deflectedrayspresent$], \
$CellContext`propagatedrays$ = 
               Join[$CellContext`propagatedrays$, \
$CellContext`deflectedlocalrays$]; 1., 
              1.]); ($CellContext`inrays$ = $CellContext`propagatedrays$; \
$CellContext`outrays$ = CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

              "]; $CellContext`deflectedrayspresent$ = 
             True; $CellContext`reportedrayspresent$ = 
             False; $CellContext`propagate$ = True; While[
              
              And[$CellContext`deflectedrayspresent$, \
$CellContext`propagate$], 
              AddTo[$CellContext`generationnumber$, 
                1.]; ($CellContext`deflecteddummyrayspresent$ = 
                False; $CellContext`deflectedrayspresent$ = 
                False; $CellContext`reportedrayspresent$ = 
                False; $CellContext`reporteddummyrayspresent$ = 
                True; $CellContext`localdummyoutrayspresent$ = 
                False; $CellContext`localoutrayspresent$ = 
                False; {$CellContext`deflectedlocalrays$, \
$CellContext`localoutrays$, $CellContext`reportedlocalrays$} = 
                Map[Flatten[#, 1]& , 
                  Transpose[
                   
                   Map[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; If[
                    
                    And[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`generationnumber$ < \
$CellContext`generationlimit$], ($CellContext`resonatenumber$ = 
                    0; $CellContext`resonateraylength$ = 
                    9.87654321*^8; $CellContext`resonateintersections$ = \
{{-1., 0., 0.}}; MapIndexed[If[
                    And[
                    Part[#, 1, 1] > -1., 
                    Part[#, 1, 
                    1] < $CellContext`resonateraylength$], \
$CellContext`resonateraylength$ = 
                    Part[#, 1, 
                    1]; $CellContext`resonateintersections$ = #; \
$CellContext`resonatenumber$ = 
                    First[#2], $CellContext`resonatenumber$]& , \
$CellContext`intersectionslist$ = {{{-1., 0., 
                    0.}}}; $CellContext`holeQlist$ = {
                    0}; ({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -2. + \
$CellContext`rey$; $CellContext`ry$ = -(-3. + $CellContext`rex$); \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$19321}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 0.50025, Part[#, 2] >= -0.50025, 
                    Part[#, 3] >= -0.50025, Part[#, 3] <= 0.50025]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$19321 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$19321), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$19321, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$19321}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 801366.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = 0.9238795325112867 $CellContext`r1$ + 
                    0.3826834323650898 $CellContext`r2$; $CellContext`yunit$ = \
(-0.3826834323650898) $CellContext`r1$ + 
                    0.9238795325112867 $CellContext`r2$; $CellContext`zunit$ = \
$CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    0.9238795325112867 (-2.2928932188134525` + \
$CellContext`rex$) + 
                    0.3826834323650898 (-2.5 + $CellContext`rey$); \
$CellContext`ry$ = (-0.3826834323650898) (-2.2928932188134525` + \
$CellContext`rex$) + 
                    0.9238795325112867 (-2.5 + $CellContext`rey$); \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$19322}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 0.54146669819627, 
                    Part[#, 2] >= -0.54146669819627, Part[#, 3] >= -0.50025, 
                    Part[#, 3] <= 0.50025]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$19322 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$19322), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$19322, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$19322}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 801395.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = (-0.7071067811865475) $CellContext`r1$ + 
                    0.7071067811865475 $CellContext`r2$; $CellContext`yunit$ = \
(-0.7071067811865475) $CellContext`r1$ - 
                    0.7071067811865475 $CellContext`r2$; $CellContext`zunit$ = \
$CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
(-0.7071067811865475) (-2.2928932188134525` + $CellContext`rex$) + 
                    0.7071067811865475 (-3.2071067811865475` + \
$CellContext`rey$); $CellContext`ry$ = (-0.7071067811865475) \
(-2.2928932188134525` + $CellContext`rex$) - 
                    0.7071067811865475 (-3.2071067811865475` + \
$CellContext`rey$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$19323}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 0.2930396654228591, 
                    Part[#, 2] >= -0.2930396654228591, Part[#, 3] >= -0.50025,
                     Part[#, 3] <= 0.50025]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$19323 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$19323), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$19323, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$19323}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 801451.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = 0.3826834323650898 $CellContext`r1$ + 
                    0.9238795325112867 $CellContext`r2$; $CellContext`yunit$ = \
(-0.9238795325112867) $CellContext`r1$ + 
                    0.3826834323650898 $CellContext`r2$; $CellContext`zunit$ = \
$CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    0.3826834323650898 (-3. + $CellContext`rex$) + 
                    0.9238795325112867 (-3.2071067811865475` + \
$CellContext`rey$); $CellContext`ry$ = (-0.9238795325112867) (-3. + \
$CellContext`rex$) + 
                    0.3826834323650898 (-3.2071067811865475` + \
$CellContext`rey$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$19357}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 0.54146669819627, 
                    Part[#, 2] >= -0.54146669819627, Part[#, 3] >= -0.50025, 
                    Part[#, 3] <= 0.50025]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$19357 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$19357), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$19357, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$19357}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 801482.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -3.5 + \
$CellContext`rex$; $CellContext`ry$ = -2.5 + $CellContext`rey$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$19358}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    And[
                    Part[#, 2] <= 0.50025, Part[#, 2] >= -0.50025, 
                    Part[#, 3] >= -0.50025, Part[#, 3] <= 0.50025]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$19358 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$19358), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$19358, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$19358}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 801537.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -0.5 + \
$CellContext`rez$; $CellContext`ry$ = -2. + $CellContext`rey$; \
$CellContext`rz$ = -(-3. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$19359}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    
                    Block[{$CellContext`lines, $CellContext`edges, \
$CellContext`polygonpoint, $CellContext`pointx, $CellContext`pointy}, \
$CellContext`lines = 0; $CellContext`edges = 1; $CellContext`polygonpoint = 
                    0; {$CellContext`pointx, $CellContext`pointy} = {
                    Part[#, 2], 
                    Part[#, 3]}; Map[If[
                    Or[
                    And[
                    Abs[Part[#, 1, 1] - $CellContext`pointx] < 
                    1.067533208062722*^-10, 
                    Abs[Part[#, 1, -1] - $CellContext`pointy] < 
                    1.067533208062722*^-10], 
                    And[
                    Abs[Part[#, 2, 1] - $CellContext`pointx] < 
                    1.067533208062722*^-10, 
                    Abs[Part[#, 2, -1] - $CellContext`pointy] < 
                    1.067533208062722*^-10]], $CellContext`polygonpoint = 
                    1, $CellContext`polygonpoint]& , \
{{{-0.0003414213562372703, -0.5003414213562373}, {-0.0003414213562372703, 
                    0.5001585786437627}}, {{-0.0003414213562372703, 
                    0.5001585786437627}, {1.0001585786437626`, 
                    0.9145792477980441}}, {{1.0001585786437626`, 
                    0.9145792477980441}, {1.4145792477980441`, 
                    0.5001585786437627}}, {{1.4145792477980441`, 
                    0.5001585786437627}, {
                    1.0001585786437626`, -0.5003414213562373}}, {{
                    1.0001585786437626`, -0.5003414213562373}, \
{-0.0003414213562372703, -0.5003414213562373}}}]; 
                    If[$CellContext`polygonpoint == 1, True, {
                    
                    Which[-0.0003414213562372703 < $CellContext`pointx, 0, 
                    Abs[0.5001585786437627 - $CellContext`pointy] < 
                    1.067533208062722*^-10, $CellContext`edges = -1, 
                    Abs[-0.5003414213562373 - $CellContext`pointy] < 
                    1.067533208062722*^-10, 
                    If[$CellContext`edges == -1, 
                    AddTo[$CellContext`lines, 1], 0], 
                    
                    Or[-0.5003414213562373 < $CellContext`pointy < 
                    0.5001585786437627, 
                    0.5001585786437627 < $CellContext`pointy < \
-0.5003414213562373], 
                    AddTo[$CellContext`lines, 1], True, 0], 
                    Which[
                    And[
                    Abs[-2.2079896238990218` + 
                    2.4142135623730954` $CellContext`pointy] < 
                    1.067533208062722*^-10, 
                    1.0001585786437626` >= $CellContext`pointx], \
$CellContext`edges = -1, 
                    And[
                    Abs[-1.2074896238990223` + 
                    2.4142135623730954` $CellContext`pointy] < 
                    1.067533208062722*^-10, -0.0003414213562372703 >= \
$CellContext`pointx], 
                    If[$CellContext`edges == -1, 
                    AddTo[$CellContext`lines, 1], 0], 
                    And[
                    0 <= -1.2068861808086184` + 
                    2.4130070588436743` $CellContext`pointy <= 
                    1, -1.2078310452552596` - $CellContext`pointx + 
                    2.4142135623730954` $CellContext`pointy > 0], 
                    AddTo[$CellContext`lines, 1], True, 0], 
                    Which[
                    And[
                    Abs[0.500158578643763 - 
                    1.0000000000000004` $CellContext`pointy] < 
                    1.067533208062722*^-10, 
                    1.4145792477980441` >= $CellContext`pointx], \
$CellContext`edges = 1, 
                    And[
                    Abs[0.9145792477980446 - 
                    1.0000000000000004` $CellContext`pointy] < 
                    1.067533208062722*^-10, 
                    1.0001585786437626` >= $CellContext`pointx], 
                    If[$CellContext`edges == 1, 
                    AddTo[$CellContext`lines, 1], 0], 
                    And[
                    0 <= 2.206886180808618 - 
                    2.4130070588436743` $CellContext`pointy <= 1, 
                    1.9147378264418071` - $CellContext`pointx - 
                    1.0000000000000004` $CellContext`pointy > 0], 
                    AddTo[$CellContext`lines, 1], True, 0], 
                    Which[
                    And[
                    Abs[0.20724820254278484` + 
                    0.414213562373095 $CellContext`pointy] < 
                    1.067533208062722*^-10, 
                    1.0001585786437626` >= $CellContext`pointx], \
$CellContext`edges = 1, 
                    And[
                    Abs[-0.20717246661149671` + 
                    0.414213562373095 $CellContext`pointy] < 
                    1.067533208062722*^-10, 
                    1.4145792477980441` >= $CellContext`pointx], 
                    If[$CellContext`edges == 1, 
                    AddTo[$CellContext`lines, 1], 0], 
                    And[
                    0 <= 0.4999086243315969 - 
                    0.9995002498750625 $CellContext`pointy <= 1, 
                    1.2074067811865474` - $CellContext`pointx + 
                    0.414213562373095 $CellContext`pointy > 0], 
                    AddTo[$CellContext`lines, 1], True, 0], 0}; And[
                    OddQ[$CellContext`lines], $CellContext`lines != 0]]]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$19359 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$19359), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$19359, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$19359}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 801605.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    0.5 + $CellContext`rez$; $CellContext`ry$ = -2. + \
$CellContext`rey$; $CellContext`rz$ = -(-3. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Compile`$19360}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., 
                    
                    Block[{$CellContext`lines, $CellContext`edges, \
$CellContext`polygonpoint, $CellContext`pointx, $CellContext`pointy}, \
$CellContext`lines = 0; $CellContext`edges = 1; $CellContext`polygonpoint = 
                    0; {$CellContext`pointx, $CellContext`pointy} = {
                    Part[#, 2], 
                    Part[#, 3]}; Map[If[
                    Or[
                    And[
                    Abs[Part[#, 1, 1] - $CellContext`pointx] < 
                    1.067533208062722*^-10, 
                    Abs[Part[#, 1, -1] - $CellContext`pointy] < 
                    1.067533208062722*^-10], 
                    And[
                    Abs[Part[#, 2, 1] - $CellContext`pointx] < 
                    1.067533208062722*^-10, 
                    Abs[Part[#, 2, -1] - $CellContext`pointy] < 
                    1.067533208062722*^-10]], $CellContext`polygonpoint = 
                    1, $CellContext`polygonpoint]& , \
{{{-0.0003414213562372703, -0.5003414213562373}, {-0.0003414213562372703, 
                    0.5001585786437627}}, {{-0.0003414213562372703, 
                    0.5001585786437627}, {1.0001585786437626`, 
                    0.9145792477980441}}, {{1.0001585786437626`, 
                    0.9145792477980441}, {1.4145792477980441`, 
                    0.5001585786437627}}, {{1.4145792477980441`, 
                    0.5001585786437627}, {
                    1.0001585786437626`, -0.5003414213562373}}, {{
                    1.0001585786437626`, -0.5003414213562373}, \
{-0.0003414213562372703, -0.5003414213562373}}}]; 
                    If[$CellContext`polygonpoint == 1, True, {
                    
                    Which[-0.0003414213562372703 < $CellContext`pointx, 0, 
                    Abs[0.5001585786437627 - $CellContext`pointy] < 
                    1.067533208062722*^-10, $CellContext`edges = -1, 
                    Abs[-0.5003414213562373 - $CellContext`pointy] < 
                    1.067533208062722*^-10, 
                    If[$CellContext`edges == -1, 
                    AddTo[$CellContext`lines, 1], 0], 
                    
                    Or[-0.5003414213562373 < $CellContext`pointy < 
                    0.5001585786437627, 
                    0.5001585786437627 < $CellContext`pointy < \
-0.5003414213562373], 
                    AddTo[$CellContext`lines, 1], True, 0], 
                    Which[
                    And[
                    Abs[-2.2079896238990218` + 
                    2.4142135623730954` $CellContext`pointy] < 
                    1.067533208062722*^-10, 
                    1.0001585786437626` >= $CellContext`pointx], \
$CellContext`edges = -1, 
                    And[
                    Abs[-1.2074896238990223` + 
                    2.4142135623730954` $CellContext`pointy] < 
                    1.067533208062722*^-10, -0.0003414213562372703 >= \
$CellContext`pointx], 
                    If[$CellContext`edges == -1, 
                    AddTo[$CellContext`lines, 1], 0], 
                    And[
                    0 <= -1.2068861808086184` + 
                    2.4130070588436743` $CellContext`pointy <= 
                    1, -1.2078310452552596` - $CellContext`pointx + 
                    2.4142135623730954` $CellContext`pointy > 0], 
                    AddTo[$CellContext`lines, 1], True, 0], 
                    Which[
                    And[
                    Abs[0.500158578643763 - 
                    1.0000000000000004` $CellContext`pointy] < 
                    1.067533208062722*^-10, 
                    1.4145792477980441` >= $CellContext`pointx], \
$CellContext`edges = 1, 
                    And[
                    Abs[0.9145792477980446 - 
                    1.0000000000000004` $CellContext`pointy] < 
                    1.067533208062722*^-10, 
                    1.0001585786437626` >= $CellContext`pointx], 
                    If[$CellContext`edges == 1, 
                    AddTo[$CellContext`lines, 1], 0], 
                    And[
                    0 <= 2.206886180808618 - 
                    2.4130070588436743` $CellContext`pointy <= 1, 
                    1.9147378264418071` - $CellContext`pointx - 
                    1.0000000000000004` $CellContext`pointy > 0], 
                    AddTo[$CellContext`lines, 1], True, 0], 
                    Which[
                    And[
                    Abs[0.20724820254278484` + 
                    0.414213562373095 $CellContext`pointy] < 
                    1.067533208062722*^-10, 
                    1.0001585786437626` >= $CellContext`pointx], \
$CellContext`edges = 1, 
                    And[
                    Abs[-0.20717246661149671` + 
                    0.414213562373095 $CellContext`pointy] < 
                    1.067533208062722*^-10, 
                    1.4145792477980441` >= $CellContext`pointx], 
                    If[$CellContext`edges == 1, 
                    AddTo[$CellContext`lines, 1], 0], 
                    And[
                    0 <= 0.4999086243315969 - 
                    0.9995002498750625 $CellContext`pointy <= 1, 
                    1.2074067811865474` - $CellContext`pointx + 
                    0.414213562373095 $CellContext`pointy > 0], 
                    AddTo[$CellContext`lines, 1], True, 0], 0}; And[
                    OddQ[$CellContext`lines], $CellContext`lines != 0]]]], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$19360 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$19360), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$19360, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$19360}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 801673.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]); $CellContext`holeQlist$ = 
                    Drop[$CellContext`holeQlist$, 1]; 
                    Drop[$CellContext`intersectionslist$, 1]]); 
                    Which[$CellContext`resonatenumber$ == 
                    1, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r2$; $CellContext`yunit$ = \
-$CellContext`r1$; $CellContext`zunit$ = $CellContext`r3$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -2. + \
$CellContext`rey$; $CellContext`ry$ = -(-3. + $CellContext`rex$); \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {9., 1., 
                    801366.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {9., 1., 
                    801366.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    3. - 1. $CellContext`ryhlp$; $CellContext`rey$ = 
                    2. + $CellContext`rxhlp$; $CellContext`rez$ = \
$CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., -1., 0.}, {1., 0., 0.}, {0., 0., 
                    
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 1., 0.}, {-1., 0., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    3., 2., 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; If[$CellContext`intensity$ < 
                    0., $CellContext`intensity$ = 0., 
                    1.]; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[
                    Abs[$CellContext`alternateindex$ - $CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    N[0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    2, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = 0.9238795325112867 $CellContext`r1$ + 
                    0.3826834323650898 $CellContext`r2$; $CellContext`yunit$ = \
(-0.3826834323650898) $CellContext`r1$ + 
                    0.9238795325112867 $CellContext`r2$; $CellContext`zunit$ = \
$CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    0.9238795325112867 (-2.2928932188134525` + \
$CellContext`rex$) + 
                    0.3826834323650898 (-2.5 + $CellContext`rey$); \
$CellContext`ry$ = (-0.3826834323650898) (-2.2928932188134525` + \
$CellContext`rex$) + 
                    0.9238795325112867 (-2.5 + $CellContext`rey$); \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {9., 2., 
                    801395.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {9., 2., 
                    801395.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    2.2928932188134525` + 
                    0.9238795325112867 $CellContext`rxhlp$ - 
                    0.3826834323650898 $CellContext`ryhlp$; $CellContext`rey$ = 
                    2.5 + 0.3826834323650898 $CellContext`rxhlp$ + 
                    0.9238795325112867 $CellContext`ryhlp$; $CellContext`rez$ = \
$CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0.9238795325112867, -0.3826834323650898, 0.}, {
                    0.3826834323650898, 0.9238795325112867, 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0.9238795325112867, 
                    0.3826834323650898, 0.}, {-0.3826834323650898, 
                    0.9238795325112867, 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    2.2928932188134525`, 2.5, 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; If[$CellContext`intensity$ < 
                    0., $CellContext`intensity$ = 0., 
                    1.]; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} - 2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`allcreatedrays$ = \
{{$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$, $CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$, $CellContext`r4$, $CellContext`r5$, $CellContext`r6$, \
$CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    N[0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    3, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = (-0.7071067811865475) $CellContext`r1$ + 
                    0.7071067811865475 $CellContext`r2$; $CellContext`yunit$ = \
(-0.7071067811865475) $CellContext`r1$ - 
                    0.7071067811865475 $CellContext`r2$; $CellContext`zunit$ = \
$CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
(-0.7071067811865475) (-2.2928932188134525` + $CellContext`rex$) + 
                    0.7071067811865475 (-3.2071067811865475` + \
$CellContext`rey$); $CellContext`ry$ = (-0.7071067811865475) \
(-2.2928932188134525` + $CellContext`rex$) - 
                    
                    0.7071067811865475 (-3.2071067811865475` + \
$CellContext`rey$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {9., 3., 
                    801451.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {9., 3., 
                    801451.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    2.2928932188134525` - 
                    0.7071067811865476 $CellContext`rxhlp$ - 
                    0.7071067811865476 $CellContext`ryhlp$; $CellContext`rey$ = 
                    3.2071067811865475` + 
                    0.7071067811865476 $CellContext`rxhlp$ - 
                    0.7071067811865476 $CellContext`ryhlp$; $CellContext`rez$ = \
$CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{-0.7071067811865475, -0.7071067811865475, 0.}, {
                    0.7071067811865475, -0.7071067811865475, 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{-0.7071067811865476, 
                    0.7071067811865476, 
                    0.}, {-0.7071067811865476, -0.7071067811865476, 0.}, {0., 
                    0., 1.}}; $CellContext`surfacetranslationvector$ = {
                    2.2928932188134525`, 3.2071067811865475`, 
                    0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; If[$CellContext`intensity$ < 
                    0., $CellContext`intensity$ = 0., 
                    1.]; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} - 2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`allcreatedrays$ = \
{{$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$, $CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$, $CellContext`r4$, $CellContext`r5$, $CellContext`r6$, \
$CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    N[0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    4, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = 0.3826834323650898 $CellContext`r1$ + 
                    0.9238795325112867 $CellContext`r2$; $CellContext`yunit$ = \
(-0.9238795325112867) $CellContext`r1$ + 
                    0.3826834323650898 $CellContext`r2$; $CellContext`zunit$ = \
$CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    0.3826834323650898 (-3. + $CellContext`rex$) + 
                    0.9238795325112867 (-3.2071067811865475` + \
$CellContext`rey$); $CellContext`ry$ = (-0.9238795325112867) (-3. + \
$CellContext`rex$) + 
                    0.3826834323650898 (-3.2071067811865475` + \
$CellContext`rey$); $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {9., 4., 
                    801482.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {9., 4., 
                    801482.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    3. + 0.3826834323650898 $CellContext`rxhlp$ - 
                    0.9238795325112867 $CellContext`ryhlp$; $CellContext`rey$ = 
                    3.2071067811865475` + 
                    0.9238795325112867 $CellContext`rxhlp$ + 
                    0.3826834323650898 $CellContext`ryhlp$; $CellContext`rez$ = \
$CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0.3826834323650898, -0.9238795325112867, 0.}, {
                    0.9238795325112867, 0.3826834323650898, 0.}, {0., 0., 
                    1.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0.3826834323650898, 
                    0.9238795325112867, 0.}, {-0.9238795325112867, 
                    0.3826834323650898, 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    3., 3.2071067811865475`, 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; If[$CellContext`intensity$ < 
                    0., $CellContext`intensity$ = 0., 
                    1.]; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} - 2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`allcreatedrays$ = \
{{$CellContext`rsx$, $CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, \
$CellContext`rey$, $CellContext`rez$, $CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$, $CellContext`r4$, $CellContext`r5$, $CellContext`r6$, \
$CellContext`r7$, $CellContext`r8$, $CellContext`r9$, \
$CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    N[0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    5, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -3.5 + \
$CellContext`rex$; $CellContext`ry$ = -2.5 + $CellContext`rey$; \
$CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {9., 5., 
                    801537.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {9., 5., 
                    801537.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    3.5 + $CellContext`rxhlp$; $CellContext`rey$ = 
                    2.5 + $CellContext`ryhlp$; $CellContext`rez$ = \
$CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    3.5, 2.5, 0}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; If[$CellContext`intensity$ < 
                    0., $CellContext`intensity$ = 0., 
                    1.]; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[
                    Chop[$CellContext`axismagnitude$] != 
                    N[0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    6, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -0.5 + \
$CellContext`rez$; $CellContext`ry$ = -2. + $CellContext`rey$; \
$CellContext`rz$ = -(-3. + $CellContext`rex$); $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {9., 6., 
                    801605.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {9., 6., 
                    801605.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    3. - 1. $CellContext`rzhlp$; $CellContext`rey$ = 
                    2. + $CellContext`ryhlp$; $CellContext`rez$ = 
                    0.5 + $CellContext`rxhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., 1., 0.}, {1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., 1.}, {0., 1., 0.}, {-1., 0., 
                    0.}}; $CellContext`surfacetranslationvector$ = {3., 2., 
                    0.5}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; If[$CellContext`intensity$ < 
                    0., $CellContext`intensity$ = 0., 
                    1.]; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    N[0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    7, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r3$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = -$CellContext`r1$; \
$CellContext`xunit$ = Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = 
                    0.5 + $CellContext`rez$; $CellContext`ry$ = -2. + \
$CellContext`rey$; $CellContext`rz$ = -(-3. + $CellContext`rex$); \
$CellContext`rx$ = Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {9., 7., 
                    801673.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {9., 7., 
                    801673.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    3. - 1. $CellContext`rzhlp$; $CellContext`rey$ = 
                    2. + $CellContext`ryhlp$; $CellContext`rez$ = -0.5 + \
$CellContext`rxhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[Dot[{{0., 0., -1.}, {0., 1., 0.}, {1., 0., 
                    0.}}, #]& , $CellContext`surfnorm$]; \
$CellContext`surfnorm$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{0., 0., 1.}, {0., 1., 0.}, {-1., 0., 
                    0.}}; $CellContext`surfacetranslationvector$ = {3., 
                    2., -0.5}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; If[$CellContext`intensity$ < 
                    0., $CellContext`intensity$ = 0., 
                    1.]; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    N[0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "], {$CellContext`completedray$}}, 
                    True, $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localoutrayspresent$ = 
                    True; {CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}], $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmVmYGAAYUYgVmeAgQ/2A0c3RJjknz1InHq4e/fjoAfQH/SmR8Nt
JIUbAPATktQ=
                    "]])& , $CellContext`inrays$]]]; If[
                 
                 And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                 Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ] 
                  1., 1.]; 
               If[$CellContext`localoutrayspresent$, 
                 If[$CellContext`localdummyoutrayspresent$, \
$CellContext`localoutrays$ = 
                    Select[$CellContext`localoutrays$, Part[#, 23] > 0.& ]; 
                   1., 1.]; $CellContext`outrays$ = 
                  Join[$CellContext`outrays$, $CellContext`localoutrays$]; 1.,
                  1.]; If[
                 
                 And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
                  Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
                 1., 1.]); 
              If[$CellContext`reportedrayspresent$, \
$CellContext`raysreported$ = True; $CellContext`reportedrays$ = 
                 Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                   
                   "], $CellContext`reportedlocalrays$]; 1., 
                1.]; $CellContext`inrays$ = $CellContext`deflectedlocalrays$; \
$CellContext`propagate$ = $CellContext`generationnumber$ < \
$CellContext`generationlimit$]; $CellContext`propagatedrays$ = 
             If[Length[$CellContext`outrays$] > 1, 
               Drop[$CellContext`outrays$, 1], $CellContext`outrays$]; If[
              
              And[$CellContext`generationnumber$ >= \
$CellContext`generationlimit$, $CellContext`deflectedrayspresent$], \
$CellContext`propagatedrays$ = 
               Join[$CellContext`propagatedrays$, \
$CellContext`deflectedlocalrays$]; 1., 
              1.]); ($CellContext`inrays$ = $CellContext`propagatedrays$; \
$CellContext`outrays$ = CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

              "]; $CellContext`deflectedrayspresent$ = 
             True; $CellContext`reportedrayspresent$ = 
             False; $CellContext`propagate$ = True; While[
              
              And[$CellContext`deflectedrayspresent$, \
$CellContext`propagate$], 
              AddTo[$CellContext`generationnumber$, 
                1.]; ($CellContext`deflecteddummyrayspresent$ = 
                False; $CellContext`deflectedrayspresent$ = 
                False; $CellContext`reportedrayspresent$ = 
                False; $CellContext`reporteddummyrayspresent$ = 
                True; $CellContext`localdummyoutrayspresent$ = 
                False; $CellContext`localoutrayspresent$ = 
                False; {$CellContext`deflectedlocalrays$, \
$CellContext`localoutrays$, $CellContext`reportedlocalrays$} = 
                Map[Flatten[#, 1]& , 
                  Transpose[
                   
                   Map[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; If[
                    
                    And[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`generationnumber$ < \
$CellContext`generationlimit$], ($CellContext`resonatenumber$ = 
                    0; $CellContext`resonateraylength$ = 
                    9.87654321*^8; $CellContext`resonateintersections$ = \
{{-1., 0., 0.}}; MapIndexed[If[
                    And[
                    Part[#, 1, 1] > -1., 
                    Part[#, 1, 
                    1] < $CellContext`resonateraylength$], \
$CellContext`resonateraylength$ = 
                    Part[#, 1, 
                    1]; $CellContext`resonateintersections$ = #; \
$CellContext`resonatenumber$ = 
                    First[#2], $CellContext`resonatenumber$]& , \
$CellContext`intersectionslist$ = {{{-1., 0., 
                    0.}}}; $CellContext`holeQlist$ = {
                    0}; ({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$ - 1. 
                    Re[$CellContext`x2$$]; $CellContext`ry$ = -2.5 + \
$CellContext`rey$; $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, 
                    Optica`Optica`TempVar3, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; 
                    Optica`Optica`TempVar1 = $CellContext`rx$^2 + \
$CellContext`ry$^2 + $CellContext`rz$^2; 
                    Optica`Optica`TempVar2 = $CellContext`rx$ \
$CellContext`xunit$ + $CellContext`ry$ $CellContext`yunit$ + $CellContext`rz$ \
$CellContext`zunit$ - $CellContext`c21$$ $CellContext`xunit$; 
                    Optica`Optica`TempVar3 = -Optica`Optica`TempVar1 + 
                    Optica`Optica`TempVar2^2 + 
                    2 $CellContext`rx$ $CellContext`c21$$; 
                    Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; 
                    If[N[
                    Chop[Optica`Optica`TempVar3]] >= 0., 
                    Optica`Optica`TempVar3 = Sqrt[Optica`Optica`TempVar3]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = {-Optica`Optica`TempVar2 - 
                    Optica`Optica`TempVar3, $CellContext`ry$ - (
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ - (Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    0.3364, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-$CellContext`c21$$ + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    Sqrt[$CellContext`c21$$^2 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`c21$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = {-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3, $CellContext`ry$ + (-
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ + (-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    0.3364, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-$CellContext`c21$$ + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    Sqrt[$CellContext`c21$$^2 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`c21$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    If[Part[Optica`Optica`TempVar, 1] == 
                    Part[Optica`Optica`TempVar, 2], {
                    Part[Optica`Optica`TempVar, 1]}, 
                    Optica`Optica`TempVar], {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 801752.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$ - 1. 
                    Re[$CellContext`t2$$ + $CellContext`x2$$]; \
$CellContext`ry$ = -2.5 + $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = 
                    Block[{Optica`Optica`TempVar, Optica`Optica`TempVar1, 
                    Optica`Optica`TempVar2, 
                    Optica`Optica`TempVar3, $CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$}, Optica`Optica`TempVar1 = 1.; 
                    Optica`Optica`TempVar2 = 1.; Optica`Optica`TempVar3 = 1.; 
                    Optica`Optica`TempVar = {{-1., 0., 
                    0.}}; $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; 
                    Optica`Optica`TempVar1 = $CellContext`rx$^2 + \
$CellContext`ry$^2 + $CellContext`rz$^2; 
                    Optica`Optica`TempVar2 = $CellContext`rx$ \
$CellContext`xunit$ + $CellContext`ry$ $CellContext`yunit$ + $CellContext`rz$ \
$CellContext`zunit$ - $CellContext`c22$$ $CellContext`xunit$; 
                    Optica`Optica`TempVar3 = -Optica`Optica`TempVar1 + 
                    Optica`Optica`TempVar2^2 + 
                    2 $CellContext`rx$ $CellContext`c22$$; 
                    Optica`Optica`TempVar3 = Re[Optica`Optica`TempVar3]; 
                    If[N[
                    Chop[Optica`Optica`TempVar3]] >= 0., 
                    Optica`Optica`TempVar3 = Sqrt[Optica`Optica`TempVar3]; 
                    Optica`Optica`TempVar = {{$CellContext`LocRayL$, \
$CellContext`LocSCx$, $CellContext`LocSCy$} = {-Optica`Optica`TempVar2 - 
                    Optica`Optica`TempVar3, $CellContext`ry$ - (
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ - (Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    0.3364, 
                    
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-$CellContext`c22$$ + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    Sqrt[$CellContext`c22$$^2 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`c22$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 
                    0.}], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} = {-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3, $CellContext`ry$ + (-
                    Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`yunit$, \
$CellContext`rz$ + (-Optica`Optica`TempVar2 + 
                    Optica`Optica`TempVar3) $CellContext`zunit$}; If[
                    And[N[
                    Chop[$CellContext`LocRayL$]] >= 
                    0., $CellContext`LocSCx$^2 + $CellContext`LocSCy$^2 <= 
                    0.3364, 
                    Abs[$CellContext`ry$ + $CellContext`LocRayL$ \
$CellContext`yunit$ - $CellContext`LocSCx$] + 
                    Abs[$CellContext`rz$ + $CellContext`LocRayL$ \
$CellContext`zunit$ - $CellContext`LocSCy$] + 
                    Abs[-$CellContext`c22$$ + $CellContext`rx$ + \
$CellContext`LocRayL$ $CellContext`xunit$ + 
                    Sqrt[$CellContext`c22$$^2 - $CellContext`LocSCx$^2 - \
$CellContext`LocSCy$^2] Sign[$CellContext`c22$$]] < 
                    1.*^-7], {$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, {-1., 0., 0.}]}; 
                    If[Part[Optica`Optica`TempVar, 1] == 
                    Part[Optica`Optica`TempVar, 2], {
                    Part[Optica`Optica`TempVar, 1]}, 
                    Optica`Optica`TempVar], {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 801753.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]; 
                    AppendTo[$CellContext`intersectionslist$, \
$CellContext`intersections$]; If[$CellContext`holeQ$, 
                    AppendTo[$CellContext`holeQlist$, 1], 
                    
                    AppendTo[$CellContext`holeQlist$, 
                    0]]); $CellContext`holeQlist$ = 
                    Drop[$CellContext`holeQlist$, 1]; 
                    Drop[$CellContext`intersectionslist$, 1]]); 
                    Which[$CellContext`resonatenumber$ == 
                    1, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$ - 1. 
                    Re[$CellContext`x2$$]; $CellContext`ry$ = -2.5 + \
$CellContext`rey$; $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {10., 1., 
                    801752.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {10., 1., 
                    801752.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
$CellContext`rxhlp$ + Re[$CellContext`x2$$]; $CellContext`rey$ = 
                    2.5 + $CellContext`ryhlp$; $CellContext`rez$ = \
$CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., -((
                    Sign[$CellContext`c21$$] \
$CellContext`ray2$)/($CellContext`c21$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5), -((
                    Sign[$CellContext`c21$$] \
$CellContext`ray3$)/($CellContext`c21$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5)}, {(
                    Sign[$CellContext`c21$$] \
$CellContext`ray2$)/($CellContext`c21$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5, 1., 
                    0.}, {(Sign[$CellContext`c21$$] \
$CellContext`ray3$)/($CellContext`c21$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5, 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    Re[$CellContext`x2$$], 2.5, 
                    0.}; $CellContext`activeregion$ = 
                    1.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; If[$CellContext`intensity$ < 
                    0., $CellContext`intensity$ = 0., 
                    1.]; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; If[
                    Chop[$CellContext`axismagnitude$] != 
                    N[0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {$CellContext`completedray$}}, \
$CellContext`resonatenumber$ == 
                    2, {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                    Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                    Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                    Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$ - 1. 
                    Re[$CellContext`t2$$ + $CellContext`x2$$]; \
$CellContext`ry$ = -2.5 + $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                    Chop[$CellContext`rx$]; $CellContext`ry$ = 
                    Chop[$CellContext`ry$]; $CellContext`rz$ = 
                    Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                    False; $CellContext`intersections$ = {{-1., 0., 
                    0.}}; $CellContext`intersections$ = \
$CellContext`resonateintersections$; $CellContext`holeQ$ = 
                    Part[$CellContext`holeQlist$, \
$CellContext`resonatenumber$] == 
                    1; {$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {10., 2., 
                    801753.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {10., 2., 
                    801753.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
$CellContext`rxhlp$ + 
                    Re[$CellContext`t2$$ + $CellContext`x2$$]; \
$CellContext`rey$ = 
                    2.5 + $CellContext`ryhlp$; $CellContext`rez$ = \
$CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`reportedrayspresent$ = 
                    True; $CellContext`intersectionspresent$ = 
                    True; $CellContext`deflectedrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., -((
                    Sign[$CellContext`c22$$] \
$CellContext`ray2$)/($CellContext`c22$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5), -((
                    Sign[$CellContext`c22$$] \
$CellContext`ray3$)/($CellContext`c22$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5)}, {(
                    Sign[$CellContext`c22$$] \
$CellContext`ray2$)/($CellContext`c22$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5, 1., 
                    0.}, {(Sign[$CellContext`c22$$] \
$CellContext`ray3$)/($CellContext`c22$$^2 - 1. $CellContext`ray2$^2 - 
                    1. $CellContext`ray3$^2)^0.5, 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    Re[$CellContext`t2$$ + $CellContext`x2$$], 2.5, 
                    0.}; $CellContext`activeregion$ = -1.; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`ZAxis$ = 
                    First[$CellContext`surfnorm$] Sign[
                    Dot[
                    
                    First[$CellContext`surfnorm$], {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]]; $CellContext`raytiltz$ = 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`raytiltx$ = 
                    1 - $CellContext`raytiltz$^2; 
                    If[$CellContext`raytiltx$ < 
                    2.220446049250313*^-16, $CellContext`raytiltx$ = 
                    0., $CellContext`raytiltx$ = 
                    Sqrt[$CellContext`raytiltx$]]; $CellContext`XAxis$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - $CellContext`ZAxis$ \
$CellContext`raytiltz$; If[
                    Abs[$CellContext`raytiltx$] < 1.*^-7, $CellContext`XAxis$ = 
                    Part[$CellContext`surfnorm$, 
                    2], $CellContext`XAxis$ = \
$CellContext`XAxis$/$CellContext`raytiltx$]; $CellContext`YAxis$ = {-(
                    Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 2]) + 
                    Part[$CellContext`ZAxis$, 2] Part[$CellContext`XAxis$, 3],
                     Part[$CellContext`ZAxis$, 3] 
                    Part[$CellContext`XAxis$, 1] - 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 3], -(
                    Part[$CellContext`ZAxis$, 2] 
                    Part[$CellContext`XAxis$, 1]) + 
                    Part[$CellContext`ZAxis$, 1] 
                    Part[$CellContext`XAxis$, 
                    2]}; $CellContext`YAxis$ = $CellContext`YAxis$/Sqrt[
                    
                    Dot[$CellContext`YAxis$, $CellContext`YAxis$]]; \
$CellContext`PAxis$ = $CellContext`ZAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`XAxis$] - $CellContext`XAxis$ 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, $CellContext`ZAxis$]; $CellContext`PAxis$ = \
$CellContext`PAxis$/Sqrt[
                    
                    Dot[$CellContext`PAxis$, $CellContext`PAxis$]]; \
$CellContext`normalizedpolarization$ = 
                    Part[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {1, 
                    2}]; $CellContext`normalizedpolarization$ = \
$CellContext`normalizedpolarization$/Sqrt[
                    
                    Dot[$CellContext`normalizedpolarization$, \
$CellContext`normalizedpolarization$]]; $CellContext`allcreatedamplitudes$ = \
{{0. I, 0. I, 0. I}}; If[$CellContext`intensity$ < 
                    0., $CellContext`intensity$ = 0., 
                    1.]; $CellContext`amplitude$ = 
                    Sqrt[$CellContext`intensity$] (
                    Part[$CellContext`normalizedpolarization$, 
                    1] {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$} + 
                    Part[$CellContext`normalizedpolarization$, 
                    2] {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$} 
                    Exp[I $CellContext`pol3$ 
                    0.017453292519943295`]); \
$CellContext`perpendicularamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`YAxis$]; \
$CellContext`parallelamplitude$ = 
                    Dot[$CellContext`amplitude$, $CellContext`PAxis$]; 
                    If[$CellContext`activeregion$ Part[
                    
                    Dot[$CellContext`surfacerotationmatrix$, \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}], 1] > 
                    0, $CellContext`index2$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]], \
$CellContext`index2$ = Sqrt[1.0005281111748805` - 
                    2.364805676582992*^-10 $CellContext`wavelength$^2 + 
                    2.9781670902982902`*^-6/$CellContext`wavelength$^2 + 
                    2.6004099469477187`*^-8/$CellContext`wavelength$^4 + 
                    3.7787839314048715`*^-10/$CellContext`wavelength$^6 + 
                    2.830549017940716*^-12/$CellContext`wavelength$^8]; \
$CellContext`index1$ = $CellContext`index$; 
                    If[Abs[$CellContext`index2$ - $CellContext`index1$] < 
                    0.01, $CellContext`alternateindex$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]; 
                    If[Abs[$CellContext`alternateindex$ - \
$CellContext`index1$] > 
                    Abs[$CellContext`index2$ - $CellContext`index1$], \
$CellContext`index1$ = $CellContext`index2$; $CellContext`index2$ = \
$CellContext`alternateindex$, $CellContext`index1$ = \
$CellContext`alternateindex$], $CellContext`index1$ = 
                    Sqrt[2.2718929 - 0.010108077 $CellContext`wavelength$^2 + 
                    0.010592509/$CellContext`wavelength$^2 + 
                    0.00020816965/$CellContext`wavelength$^4 - 
                    7.6472538*^-6/$CellContext`wavelength$^6 + 
                    4.9240991*^-7/$CellContext`wavelength$^8]]]; \
$CellContext`n12$ = $CellContext`index1$/$CellContext`index2$; \
$CellContext`index$ = $CellContext`index2$; 
                    If[1 - $CellContext`n12$^2 $CellContext`raytiltx$^2 >= 
                    0., $CellContext`dummyvector$ = $CellContext`n12$ \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} + $CellContext`ZAxis$ \
(-($CellContext`n12$ $CellContext`raytiltz$) + 
                    Sqrt[
                    1 - $CellContext`n12$^2 $CellContext`raytiltx$^2]); \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} = \
$CellContext`dummyvector$; 1., 
                    If[Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, 
                    Part[$CellContext`surfnorm$, 1]] > 
                    0, $CellContext`phaseshift$ = $CellContext`phaseshift$ + 
                    0.5, 1.]; $CellContext`index2$ = $CellContext`index1$; \
$CellContext`index$ = $CellContext`index1$; $CellContext`dummyvector$ = \
{$CellContext`r1$, $CellContext`r2$, $CellContext`r3$} - 
                    2 $CellContext`ZAxis$ 
                    Dot[$CellContext`ZAxis$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; {$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = \
{$CellContext`pol1$, $CellContext`pol2$, $CellContext`pol3$} + {0, 
                    0, -180}; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; 
                    1.]; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`originalrotation$ = Partition[
                    Take[$CellContext`originalray$, {7, 15}], 
                    3]; $CellContext`previoustilt$ = 
                    Part[$CellContext`originalrotation$, 
                    1]; $CellContext`transmatrix$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`rotationaxis$ = 
                    Cross[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; $CellContext`axismagnitude$ = Sqrt[
                    
                    Dot[$CellContext`rotationaxis$, \
$CellContext`rotationaxis$]]; 
                    If[Chop[$CellContext`axismagnitude$] != 
                    N[0], $CellContext`rotationaxis$ = \
$CellContext`rotationaxis$/$CellContext`axismagnitude$; \
$CellContext`axismatrix$ = 
                    Map[# $CellContext`rotationaxis$& , \
$CellContext`rotationaxis$]; $CellContext`crossmatrix$ = {{
                    0., -Part[$CellContext`rotationaxis$, 3], 
                    Part[$CellContext`rotationaxis$, 2]}, {
                    Part[$CellContext`rotationaxis$, 3], 0., -
                    Part[$CellContext`rotationaxis$, 1]}, {-
                    Part[$CellContext`rotationaxis$, 2], 
                    Part[$CellContext`rotationaxis$, 1], 
                    0.}}; $CellContext`cosangle$ = 
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]; 
                    If[1. - $CellContext`cosangle$ < 
                    2.220446049250313*^-16, $CellContext`cosangle$ = 
                    1., $CellContext`cosangle$ = $CellContext`cosangle$]; \
$CellContext`sinangle$ = 1 - $CellContext`cosangle$^2; 
                    If[$CellContext`sinangle$ < 
                    2.220446049250313*^-16, $CellContext`sinangle$ = 
                    0., $CellContext`sinangle$ = 
                    Sqrt[$CellContext`sinangle$]]; $CellContext`axismatrix$ + \
({{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}} - $CellContext`axismatrix$) $CellContext`cosangle$ + \
$CellContext`crossmatrix$ $CellContext`sinangle$, {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    If[Sign[
                    
                    Dot[$CellContext`previoustilt$, {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}]] === 1, {{1., 0., 0.}, {0., 1., 0.}, {0.,
                     0., 1.}}, {{-1., 0., 0.}, {0., -1., 0.}, {0., 
                    0., -1.}}]])& , $CellContext`allcreatedrays$]; \
$CellContext`allcreatedrays$ = 
                    MapIndexed[({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = 
                    Function[$CellContext`mm$, 
                    Map[
                    Dot[$CellContext`mm$, #]& , \
$CellContext`originalrotation$]][
                    Part[$CellContext`transmatrix$, 
                    First[#2]]]; $CellContext`tiltmagnitude$ = 
                    Dot[{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r1$, $CellContext`r2$, $CellContext`r3$}]; 
                    If[Abs[$CellContext`tiltmagnitude$ - 1.] > 
                    1.*^-6, $CellContext`dummyvector$ = {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}/
                    Sqrt[$CellContext`tiltmagnitude$]; {$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$} = $CellContext`dummyvector$; \
$CellContext`dummymatrix$ = Map[#/Sqrt[
                    
                    Dot[#, #]]& , {{$CellContext`r1$, $CellContext`r2$, \
$CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, $CellContext`r6$}, \
{$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}}]; {{$CellContext`r1$, \
$CellContext`r2$, $CellContext`r3$}, {$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, {$CellContext`r7$, $CellContext`r8$, $CellContext`r9$}} = \
$CellContext`dummymatrix$; 1., 1.]; 
                    If[$CellContext`allcreatedamplitudes$ != {{
                    I 0., I 0., I 0.}}, $CellContext`amplitude$ = 
                    Part[$CellContext`allcreatedamplitudes$, 
                    First[#2]]; $CellContext`hor$ = 
                    Dot[{$CellContext`r4$, $CellContext`r5$, \
$CellContext`r6$}, $CellContext`amplitude$]; $CellContext`ver$ = 
                    Dot[{$CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$}, $CellContext`amplitude$]; If[
                    Or[
                    Abs[$CellContext`hor$] > 0., Abs[$CellContext`ver$] > 
                    0.], {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = {
                    Abs[$CellContext`hor$], 
                    Abs[$CellContext`ver$], 
                    0.}; $CellContext`dummyvector$ = {$CellContext`pol1$, \
$CellContext`pol2$, $CellContext`pol3$}/Sqrt[
                    
                    Dot[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}]]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$; $CellContext`dummyvector$ = 
                    ReplacePart[{$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, (If[$CellContext`ver$ == 0., 0., 
                    Arg[$CellContext`ver$]] - 
                    If[$CellContext`hor$ == 0., 0., 
                    Arg[$CellContext`hor$]])/Degree, 
                    3]; {$CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = $CellContext`dummyvector$]; 1., 
                    1.]; {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$})& , $CellContext`allcreatedrays$]); \
{$CellContext`allcreatedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "], {$CellContext`completedray$}}, 
                    True, $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localoutrayspresent$ = 
                    True; {CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    
                    "], {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1Bhj4YD9wdEOESf7Zg8Sph7t3Pw6abu4GAG/YMig=

                    "]}], $CellContext`deflecteddummyrayspresent$ = 
                    True; $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`localdummyoutrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmVmYGAAYUYgVmeAgQ/2A0c3RJjknz1InHq4e/fjoAfQH/SmR8Nt
JIUbAPATktQ=
                    "]])& , $CellContext`inrays$]]]; If[
                 
                 And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                 Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ] 
                  1., 1.]; 
               If[$CellContext`localoutrayspresent$, 
                 If[$CellContext`localdummyoutrayspresent$, \
$CellContext`localoutrays$ = 
                    Select[$CellContext`localoutrays$, Part[#, 23] > 0.& ]; 
                   1., 1.]; $CellContext`outrays$ = 
                  Join[$CellContext`outrays$, $CellContext`localoutrays$]; 1.,
                  1.]; If[
                 
                 And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
                  Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
                 1., 1.]); 
              If[$CellContext`reportedrayspresent$, \
$CellContext`raysreported$ = True; $CellContext`reportedrays$ = 
                 Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                   
                   "], $CellContext`reportedlocalrays$]; 1., 
                1.]; $CellContext`inrays$ = $CellContext`deflectedlocalrays$; \
$CellContext`propagate$ = $CellContext`generationnumber$ < \
$CellContext`generationlimit$]; $CellContext`propagatedrays$ = 
             If[Length[$CellContext`outrays$] > 1, 
               Drop[$CellContext`outrays$, 1], $CellContext`outrays$]; If[
              
              And[$CellContext`generationnumber$ >= \
$CellContext`generationlimit$, $CellContext`deflectedrayspresent$], \
$CellContext`propagatedrays$ = 
               Join[$CellContext`propagatedrays$, \
$CellContext`deflectedlocalrays$]; 1., 1.]); (
            AddTo[$CellContext`generationnumber$, 
              1.]; $CellContext`reportedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, 
                0, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`deflectedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; ($CellContext`deflectedrayspresent$ = 
              False; $CellContext`reportedrayspresent$ = 
              False; $CellContext`deflecteddummyrayspresent$ = 
              False; $CellContext`reporteddummyrayspresent$ = 
              False; {$CellContext`deflectedlocalrays$, \
$CellContext`reportedlocalrays$} = Transpose[
                
                Map[(({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                   Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                   Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                   Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = \
$CellContext`rex$ - 1. 
                    Re[$CellContext`xs$$]; $CellContext`ry$ = -2.5 + \
$CellContext`rey$; $CellContext`rz$ = $CellContext`rez$; $CellContext`rx$ = 
                   Chop[$CellContext`rx$]; $CellContext`ry$ = 
                   Chop[$CellContext`ry$]; $CellContext`rz$ = 
                   Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                   False; $CellContext`intersections$ = {{-1., 0., 0.}}); 
                 If[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`deflectedrayspresent$ = 
                    True; ($CellContext`intersections$ = 
                    Block[{Compile`$19361}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., Part[#, 2]^2 + Part[#, 3]^2 <= 
                    0.3364], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$19361 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$19361), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$19361, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$19361}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 801804.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]); 
                   If[$CellContext`intersections$ != {{-1., 0., 
                    0.}}, $CellContext`intersectionspresent$ = 
                    True; ({$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {11., 1., 
                    801804.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {11., 1., 
                    801804.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = \
$CellContext`rxhlp$ + Re[$CellContext`xs$$]; $CellContext`rey$ = 
                    2.5 + $CellContext`ryhlp$; $CellContext`rez$ = \
$CellContext`rzhlp$; $CellContext`rex$ = 
                    Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}); ($CellContext`reportedrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    Re[$CellContext`xs$$], 2.5, 
                    0.}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}})); {
                    
                    First[$CellContext`allcreatedrays$], \
$CellContext`completedray$}, $CellContext`reporteddummyrayspresent$ = 
                    True; {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, CompressedData["
1:eJxTTMoPSmVkYGBQZ4CBD/YDRzdEmOSfPUicerh79+Og6eZuAGaoMiY=
                   
                     "]}], $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`deflecteddummyrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmViYGAAYXUGGPhgP3B0Q4RJ/tmDxKmHu3c/DnoA/UFvemiGGwCy
wWJ9
                    "]])& , $CellContext`propagatedrays$]]; If[
               
               And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ]; 
               1., 1.]; If[
               
               And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
                Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
               1., 1.]); (
             If[$CellContext`reportedrayspresent$, $CellContext`reportedrays$ = 
                Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                  
                  "], $CellContext`reportedlocalrays$]; 1., 
               1.]; $CellContext`propagatedrays$ = \
$CellContext`deflectedlocalrays$); $CellContext`raysreported$ = \
$CellContext`reportedrayspresent$; 1.); (
            AddTo[$CellContext`generationnumber$, 
              1.]; $CellContext`reportedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, 
                0, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; $CellContext`deflectedlocalrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}}; ($CellContext`deflectedrayspresent$ = 
              False; $CellContext`reportedrayspresent$ = 
              False; $CellContext`deflecteddummyrayspresent$ = 
              False; $CellContext`reporteddummyrayspresent$ = 
              False; {$CellContext`deflectedlocalrays$, \
$CellContext`reportedlocalrays$} = Transpose[
                
                Map[(({$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`oldgenerationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$} = #; $CellContext`index1$ = $CellContext`index$; \
$CellContext`xunit$ = $CellContext`r1$; $CellContext`yunit$ = \
$CellContext`r2$; $CellContext`zunit$ = $CellContext`r3$; $CellContext`xunit$ = 
                   Chop[$CellContext`xunit$]; $CellContext`yunit$ = 
                   Chop[$CellContext`yunit$]; $CellContext`zunit$ = 
                   Chop[$CellContext`zunit$]; $CellContext`magnitude$ = \
($CellContext`xunit$^2 + $CellContext`yunit$^2 + $CellContext`zunit$^2)^(
                    2^(-1)); $CellContext`xunit$ = \
$CellContext`xunit$/$CellContext`magnitude$; $CellContext`yunit$ = \
$CellContext`yunit$/$CellContext`magnitude$; $CellContext`zunit$ = \
$CellContext`zunit$/$CellContext`magnitude$; $CellContext`rx$ = -4.617 + \
$CellContext`rex$; $CellContext`ry$ = $CellContext`rey$; $CellContext`rz$ = \
$CellContext`rez$; $CellContext`rx$ = 
                   Chop[$CellContext`rx$]; $CellContext`ry$ = 
                   Chop[$CellContext`ry$]; $CellContext`rz$ = 
                   Chop[$CellContext`rz$]; $CellContext`terminatedeflection$ = 
                   False; $CellContext`intersections$ = {{-1., 0., 0.}}); 
                 If[$CellContext`intensity$ > \
$CellContext`thresholdintensity$, $CellContext`deflectedrayspresent$ = 
                    True; ($CellContext`intersections$ = 
                    Block[{Compile`$19364}, 
                    If[Chop[$CellContext`xunit$] != 0, {
                    (If[
                    And[N[
                    Chop[
                    Part[#, 1]]] >= 0., Part[#, 2]^2 + Part[#, 3]^2 <= 
                    0.3364], {
                    Part[#, 1], 
                    Part[#, 2], 
                    Part[#, 3]}, {-1., 0., 0.}]& )[
                    Compile`$19364 = $CellContext`xunit$^(-1); \
{-($CellContext`rx$ 
                    Compile`$19364), $CellContext`ry$ - ($CellContext`rx$ \
$CellContext`yunit$) 
                    Compile`$19364, $CellContext`rz$ - ($CellContext`rx$ \
$CellContext`zunit$) Compile`$19364}]}, {{-1., 0., 0.}}]]; 
                    AppendTo[$CellContext`intersections$, {-1., 0., 
                    0.}]; $CellContext`holeQ$ = False; If[
                    Or[
                    Not[
                    Or[Chop[$CellContext`surfaceid$ - 801837.] == 0., N[
                    Chop[$CellContext`ray1$]] < 
                    0.0001]], $CellContext`generationnumber$ == 
                    1.], $CellContext`minresonateraylength$ = 
                    0., $CellContext`minresonateraylength$ = 0.0001]; 
                    Block[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$}, $CellContext`LocRayL$ = 1.; $CellContext`LocSCx$ = 
                    1.; $CellContext`LocSCy$ = 1.; $CellContext`dummymatrix$ = 
                    Union[
                    
                    Select[$CellContext`intersections$, \
({$CellContext`LocRayL$, $CellContext`LocSCx$, $CellContext`LocSCy$} = #; 
                    Or[{$CellContext`LocRayL$, $CellContext`LocSCx$, \
$CellContext`LocSCy$} == {-1., 0., 0.}, N[
                    
                    Chop[$CellContext`LocRayL$]] >= \
$CellContext`minresonateraylength$])& ]]; $CellContext`intersections$ = \
$CellContext`dummymatrix$]; $CellContext`unfilteredintersections$ = \
$CellContext`intersections$; 
                    If[Length[$CellContext`intersections$] > 
                    1, $CellContext`dummymatrix$ = 
                    Take[$CellContext`intersections$, {
                    2}]; $CellContext`intersections$ = \
$CellContext`dummymatrix$; 1., 1.]); 
                   If[$CellContext`intersections$ != {{-1., 0., 
                    0.}}, $CellContext`intersectionspresent$ = 
                    True; ({$CellContext`newcomponentnumber$, \
$CellContext`newsurfacenumber$, $CellContext`newsurfaceid$} = {12., 1., 
                    801837.}; {$CellContext`componentnumber$, \
$CellContext`surfacenumber$, $CellContext`surfaceid$} = {12., 1., 
                    801837.}; {$CellContext`ray1$, $CellContext`ray2$, \
$CellContext`ray3$} = Part[$CellContext`intersections$, 
                    1]; $CellContext`rsx$ = $CellContext`rex$; \
$CellContext`rsy$ = $CellContext`rey$; $CellContext`rsz$ = $CellContext`rez$; \
$CellContext`rxhlp$ = $CellContext`rx$ + $CellContext`ray1$ \
$CellContext`xunit$; $CellContext`ryhlp$ = $CellContext`ry$ + \
$CellContext`ray1$ $CellContext`yunit$; $CellContext`rzhlp$ = \
$CellContext`rz$ + $CellContext`ray1$ $CellContext`zunit$; $CellContext`rex$ = 
                    4.617 + $CellContext`rxhlp$; $CellContext`rey$ = \
$CellContext`ryhlp$; $CellContext`rez$ = $CellContext`rzhlp$; \
$CellContext`rex$ = Chop[$CellContext`rex$]; $CellContext`rey$ = 
                    Chop[$CellContext`rey$]; $CellContext`rez$ = 
                    Chop[$CellContext`rez$]; $CellContext`intersectionnumber$ = \
$CellContext`intersectionnumber$ + 
                    1.; $CellContext`opticallength$ = \
$CellContext`opticallength$ + $CellContext`ray1$ $CellContext`index1$; \
$CellContext`completedray$ = {$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}); ($CellContext`reportedrayspresent$ = 
                    True; ($CellContext`surfnorm$ = 
                    1. Re[{{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}]; $CellContext`dummymatrix$ = 
                    Map[#& , $CellContext`surfnorm$]; $CellContext`surfnorm$ = 
                    Map[#/Sqrt[
                    
                    Dot[#, #]]& , $CellContext`dummymatrix$]; \
$CellContext`surfacerotationmatrix$ = {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 
                    1.}}; $CellContext`surfacetranslationvector$ = {
                    4.617, 0, 0}; $CellContext`activeregion$ = 
                    0.; $CellContext`completedray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`componentnumber$ = \
$CellContext`newcomponentnumber$; $CellContext`surfacenumber$ = \
$CellContext`newsurfacenumber$; $CellContext`surfaceid$ = \
$CellContext`newsurfaceid$; $CellContext`originalray$ = {$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}; $CellContext`allcreatedrays$ = {{$CellContext`rsx$, \
$CellContext`rsy$, $CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, \
$CellContext`rez$, $CellContext`r1$, $CellContext`r2$, $CellContext`r3$, \
$CellContext`r4$, $CellContext`r5$, $CellContext`r6$, $CellContext`r7$, \
$CellContext`r8$, $CellContext`r9$, $CellContext`wavelength$, \
$CellContext`intensity$, $CellContext`intensityscale$, $CellContext`ray1$, \
$CellContext`index$, $CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}})); {
                    
                    First[$CellContext`allcreatedrays$], \
$CellContext`completedray$}, $CellContext`reporteddummyrayspresent$ = 
                    True; {{$CellContext`rsx$, $CellContext`rsy$, \
$CellContext`rsz$, $CellContext`rex$, $CellContext`rey$, $CellContext`rez$, \
$CellContext`r1$, $CellContext`r2$, $CellContext`r3$, $CellContext`r4$, \
$CellContext`r5$, $CellContext`r6$, $CellContext`r7$, $CellContext`r8$, \
$CellContext`r9$, $CellContext`wavelength$, $CellContext`intensity$, \
$CellContext`intensityscale$, $CellContext`ray1$, $CellContext`index$, \
$CellContext`opticallength$, $CellContext`phaseshift$, \
$CellContext`componentnumber$, $CellContext`surfacenumber$, \
$CellContext`surfaceid$, $CellContext`ray2$, $CellContext`ray3$, \
$CellContext`sid$, $CellContext`frontid$, $CellContext`sno1$, \
$CellContext`sno2$, $CellContext`sno3$, $CellContext`sno4$, \
$CellContext`rayslot$, $CellContext`generationnumber$, \
$CellContext`intersectionnumber$, $CellContext`pol1$, $CellContext`pol2$, \
$CellContext`pol3$}, CompressedData["
1:eJxTTMoPSmVkYGBQZ4CBD/YDRzdEmOSfPUicerh79+Og6eZuAGaoMiY=
                   
                     "]}], $CellContext`reporteddummyrayspresent$ = 
                    True; $CellContext`deflecteddummyrayspresent$ = 
                    True; CompressedData["
1:eJxTTMoPSmViYGAAYXUGGPhgP3B0Q4RJ/tmDxKmHu3c/DnoA/UFvemiGGwCy
wWJ9
                    "]])& , $CellContext`propagatedrays$]]; If[
               
               And[$CellContext`deflectedrayspresent$, \
$CellContext`deflecteddummyrayspresent$], $CellContext`deflectedlocalrays$ = 
                Select[$CellContext`deflectedlocalrays$, Part[#, 23] > 0.& ]; 
               1., 1.]; If[
               
               And[$CellContext`reportedrayspresent$, \
$CellContext`reporteddummyrayspresent$], $CellContext`reportedlocalrays$ = 
                Select[$CellContext`reportedlocalrays$, Part[#, 23] > 0.& ]; 
               1., 1.]); (
             If[$CellContext`reportedrayspresent$, $CellContext`reportedrays$ = 
                Join[$CellContext`reportedrays$, CompressedData["
1:eJxTTMoPSmViYGBgBGJ1BhBoiDDJP3twlCaNBgAGqngz
                  
                  "], $CellContext`reportedlocalrays$]; 1., 
               1.]; $CellContext`propagatedrays$ = \
$CellContext`deflectedlocalrays$); $CellContext`raysreported$ = \
$CellContext`reportedrayspresent$; 1.); 
           If[Length[$CellContext`reportedrays$] > 
             2, $CellContext`reportedrays$ = 
             Drop[$CellContext`reportedrays$, 2], $CellContext`reportedrays$]; 
           Map[{
              Part[#, 1], 
              Part[#, 2], 
              Part[#, 3], 
              Part[#, 4], 
              Part[#, 5], 
              
              Part[#, 6]}& , $CellContext`reportedrays$]], \
$CellContext`compileoptionsetting$]]; \
$CellContext`polygons1318898201471941642964617 = 
       Compile[{$CellContext`as2, $CellContext`cs21, $CellContext`cs22, \
$CellContext`ts2}, {{$CellContext`cs21 - 1. 
           Sqrt[0. - 1. (0. - 0.5 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. - 
           0.5 $CellContext`as2}, {$CellContext`cs22 + $CellContext`ts2 - 1. 
           Sign[$CellContext`cs22] 
           Sqrt[$CellContext`cs22^2 - 
             1. (0.5 $CellContext`as2 + 
               1. Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[-$CellContext`as2, 0.]])^2 - 
             1. (0. + 1. Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[-$CellContext`as2, 0.]])^2], 
           0.5 $CellContext`as2 + 
           1. Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[-$CellContext`as2, 
                0.]]}, {$CellContext`cs22 + $CellContext`ts2 - 1. 
           Sign[$CellContext`cs22] 
           Sqrt[$CellContext`cs22^2 - 
             1. (0.5 $CellContext`as2 + 
               0.9166666666666666 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[-$CellContext`as2, 0.]])^2 - 
             1. (0. + 0.9166666666666666 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[-$CellContext`as2, 0.]])^2], 
           0.5 $CellContext`as2 + 
           0.9166666666666666 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[-$CellContext`as2, 0.]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.08333333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[1. $CellContext`as2, 0.]])^2 - 
             1. (0. + 0.08333333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[
                   1. $CellContext`as2, 0.]])^2], (-0.5) $CellContext`as2 + 
           0.08333333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[1. $CellContext`as2, 0.]]}, {$CellContext`cs21 - 1. 
           Sqrt[0. - 1. (0. - 0.5 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. - 
           0.5 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.08333333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[1. $CellContext`as2, 0.]])^2 - 
             1. (0. + 0.08333333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[
                   1. $CellContext`as2, 0.]])^2], (-0.5) $CellContext`as2 + 
           0.08333333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[
               1. $CellContext`as2, 
                0.]]}, {$CellContext`cs22 + $CellContext`ts2 - 1. 
           Sign[$CellContext`cs22] 
           Sqrt[$CellContext`cs22^2 - 
             1. (0.5 $CellContext`as2 + 
               0.9166666666666666 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[-$CellContext`as2, 0.]])^2 - 
             1. (0. + 0.9166666666666666 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[-$CellContext`as2, 0.]])^2], 
           0.5 $CellContext`as2 + 
           0.9166666666666666 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[-$CellContext`as2, 
                0.]]}, {$CellContext`cs22 + $CellContext`ts2 - 1. 
           Sign[$CellContext`cs22] 
           Sqrt[$CellContext`cs22^2 - 
             1. (0.5 $CellContext`as2 + 
               0.8333333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[-$CellContext`as2, 0.]])^2 - 
             1. (0. + 0.8333333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[-$CellContext`as2, 0.]])^2], 
           0.5 $CellContext`as2 + 
           0.8333333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[-$CellContext`as2, 0.]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.16666666666666666` Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[1. $CellContext`as2, 0.]])^2 - 
             1. (0. + 0.16666666666666666` Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[
                   1. $CellContext`as2, 0.]])^2], (-0.5) $CellContext`as2 + 
           0.16666666666666666` Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[1. $CellContext`as2, 0.]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.08333333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[1. $CellContext`as2, 0.]])^2 - 
             1. (0. + 0.08333333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[
                   1. $CellContext`as2, 0.]])^2], (-0.5) $CellContext`as2 + 
           0.08333333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[1. $CellContext`as2, 0.]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.16666666666666666` Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[1. $CellContext`as2, 0.]])^2 - 
             1. (0. + 0.16666666666666666` Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[
                   1. $CellContext`as2, 0.]])^2], (-0.5) $CellContext`as2 + 
           0.16666666666666666` Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[
               1. $CellContext`as2, 
                0.]]}, {$CellContext`cs22 + $CellContext`ts2 - 1. 
           Sign[$CellContext`cs22] 
           Sqrt[$CellContext`cs22^2 - 
             1. (0.5 $CellContext`as2 + 
               0.8333333333333334 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[-$CellContext`as2, 0.]])^2 - 
             1. (0. + 0.8333333333333334 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[-$CellContext`as2, 0.]])^2], 
           0.5 $CellContext`as2 + 
           0.8333333333333334 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[-$CellContext`as2, 
                0.]]}, {$CellContext`cs22 + $CellContext`ts2 - 1. 
           Sign[$CellContext`cs22] 
           Sqrt[$CellContext`cs22^2 - 
             1. (0.5 $CellContext`as2 + 
               0.75 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[-$CellContext`as2, 0.]])^2 - 
             1. (0. + 0.75 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[-$CellContext`as2, 0.]])^2], 
           0.5 $CellContext`as2 + 
           0.75 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[-$CellContext`as2, 0.]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.25 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[1. $CellContext`as2, 0.]])^2 - 
             1. (0. + 0.25 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[
                   1. $CellContext`as2, 0.]])^2], (-0.5) $CellContext`as2 + 
           0.25 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[1. $CellContext`as2, 0.]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.16666666666666666` Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[1. $CellContext`as2, 0.]])^2 - 
             1. (0. + 0.16666666666666666` Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[
                   1. $CellContext`as2, 0.]])^2], (-0.5) $CellContext`as2 + 
           0.16666666666666666` Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[1. $CellContext`as2, 0.]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.25 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[1. $CellContext`as2, 0.]])^2 - 
             1. (0. + 0.25 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[
                   1. $CellContext`as2, 0.]])^2], (-0.5) $CellContext`as2 + 
           0.25 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[
               1. $CellContext`as2, 
                0.]]}, {$CellContext`cs22 + $CellContext`ts2 - 1. 
           Sign[$CellContext`cs22] 
           Sqrt[$CellContext`cs22^2 - 
             1. (0.5 $CellContext`as2 + 
               0.75 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[-$CellContext`as2, 0.]])^2 - 
             1. (0. + 0.75 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[-$CellContext`as2, 0.]])^2], 
           0.5 $CellContext`as2 + 
           0.75 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[-$CellContext`as2, 
                0.]]}, {$CellContext`cs22 + $CellContext`ts2 - 1. 
           Sign[$CellContext`cs22] 
           Sqrt[$CellContext`cs22^2 - 
             1. (0.5 $CellContext`as2 + 
               0.6666666666666666 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[-$CellContext`as2, 0.]])^2 - 
             1. (0. + 0.6666666666666666 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[-$CellContext`as2, 0.]])^2], 
           0.5 $CellContext`as2 + 
           0.6666666666666666 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[-$CellContext`as2, 0.]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.3333333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[1. $CellContext`as2, 0.]])^2 - 
             1. (0. + 0.3333333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[
                   1. $CellContext`as2, 0.]])^2], (-0.5) $CellContext`as2 + 
           0.3333333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[1. $CellContext`as2, 0.]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.25 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[1. $CellContext`as2, 0.]])^2 - 
             1. (0. + 0.25 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[
                   1. $CellContext`as2, 0.]])^2], (-0.5) $CellContext`as2 + 
           0.25 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[1. $CellContext`as2, 0.]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.3333333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[1. $CellContext`as2, 0.]])^2 - 
             1. (0. + 0.3333333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[
                   1. $CellContext`as2, 0.]])^2], (-0.5) $CellContext`as2 + 
           0.3333333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[
               1. $CellContext`as2, 
                0.]]}, {$CellContext`cs22 + $CellContext`ts2 - 1. 
           Sign[$CellContext`cs22] 
           Sqrt[$CellContext`cs22^2 - 
             1. (0.5 $CellContext`as2 + 
               0.6666666666666667 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[-$CellContext`as2, 0.]])^2 - 
             1. (0. + 0.6666666666666667 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[-$CellContext`as2, 0.]])^2], 
           0.5 $CellContext`as2 + 
           0.6666666666666667 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[-$CellContext`as2, 
                0.]]}, {$CellContext`cs22 + $CellContext`ts2 - 1. 
           Sign[$CellContext`cs22] 
           Sqrt[$CellContext`cs22^2 - 
             1. (0.5 $CellContext`as2 + 
               0.5833333333333334 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[-$CellContext`as2, 0.]])^2 - 
             1. (0. + 0.5833333333333334 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[-$CellContext`as2, 0.]])^2], 
           0.5 $CellContext`as2 + 
           0.5833333333333334 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[-$CellContext`as2, 0.]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.41666666666666663` Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[1. $CellContext`as2, 0.]])^2 - 
             1. (0. + 0.41666666666666663` Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[
                   1. $CellContext`as2, 0.]])^2], (-0.5) $CellContext`as2 + 
           0.41666666666666663` Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[1. $CellContext`as2, 0.]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.3333333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[1. $CellContext`as2, 0.]])^2 - 
             1. (0. + 0.3333333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[
                   1. $CellContext`as2, 0.]])^2], (-0.5) $CellContext`as2 + 
           0.3333333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[1. $CellContext`as2, 0.]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.41666666666666663` Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[1. $CellContext`as2, 0.]])^2 - 
             1. (0. + 0.41666666666666663` Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[
                   1. $CellContext`as2, 0.]])^2], (-0.5) $CellContext`as2 + 
           0.41666666666666663` Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[
               1. $CellContext`as2, 
                0.]]}, {$CellContext`cs22 + $CellContext`ts2 - 1. 
           Sign[$CellContext`cs22] 
           Sqrt[$CellContext`cs22^2 - 
             1. (0.5 $CellContext`as2 + 
               0.5833333333333334 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[-$CellContext`as2, 0.]])^2 - 
             1. (0. + 0.5833333333333334 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[-$CellContext`as2, 0.]])^2], 
           0.5 $CellContext`as2 + 
           0.5833333333333334 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[-$CellContext`as2, 
                0.]]}, {$CellContext`cs22 + $CellContext`ts2 - 1. 
           Sign[$CellContext`cs22] 
           Sqrt[$CellContext`cs22^2 - 
             1. (0.5 $CellContext`as2 + 
               0.5 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[-$CellContext`as2, 0.]])^2 - 
             1. (0. + 0.5 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[-$CellContext`as2, 0.]])^2], 
           0.5 $CellContext`as2 + 
           0.5 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[-$CellContext`as2, 0.]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.49999999999999994` Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[1. $CellContext`as2, 0.]])^2 - 
             1. (0. + 0.49999999999999994` Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[
                   1. $CellContext`as2, 0.]])^2], (-0.5) $CellContext`as2 + 
           0.49999999999999994` Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[1. $CellContext`as2, 0.]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.41666666666666663` Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[1. $CellContext`as2, 0.]])^2 - 
             1. (0. + 0.41666666666666663` Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[
                   1. $CellContext`as2, 0.]])^2], (-0.5) $CellContext`as2 + 
           0.41666666666666663` Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[1. $CellContext`as2, 0.]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.5 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[1. $CellContext`as2, 0.]])^2 - 
             1. (0. + 0.5 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[
                   1. $CellContext`as2, 0.]])^2], (-0.5) $CellContext`as2 + 
           0.5 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[
               1. $CellContext`as2, 
                0.]]}, {$CellContext`cs22 + $CellContext`ts2 - 1. 
           Sign[$CellContext`cs22] 
           Sqrt[$CellContext`cs22^2 - 
             1. (0.5 $CellContext`as2 + 
               0.5 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[-$CellContext`as2, 0.]])^2 - 
             1. (0. + 0.5 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[-$CellContext`as2, 0.]])^2], 
           0.5 $CellContext`as2 + 
           0.5 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[-$CellContext`as2, 
                0.]]}, {$CellContext`cs22 + $CellContext`ts2 - 1. 
           Sign[$CellContext`cs22] 
           Sqrt[$CellContext`cs22^2 - 
             1. (0.5 $CellContext`as2 + 
               0.4166666666666667 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[-$CellContext`as2, 0.]])^2 - 
             1. (0. + 0.4166666666666667 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[-$CellContext`as2, 0.]])^2], 
           0.5 $CellContext`as2 + 
           0.4166666666666667 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[-$CellContext`as2, 0.]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.5833333333333334 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[1. $CellContext`as2, 0.]])^2 - 
             1. (0. + 0.5833333333333334 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[
                   1. $CellContext`as2, 0.]])^2], (-0.5) $CellContext`as2 + 
           0.5833333333333334 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[1. $CellContext`as2, 0.]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.5 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[1. $CellContext`as2, 0.]])^2 - 
             1. (0. + 0.5 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[
                   1. $CellContext`as2, 0.]])^2], (-0.5) $CellContext`as2 + 
           0.5 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[1. $CellContext`as2, 0.]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.5833333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[1. $CellContext`as2, 0.]])^2 - 
             1. (0. + 0.5833333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[
                   1. $CellContext`as2, 0.]])^2], (-0.5) $CellContext`as2 + 
           0.5833333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[
               1. $CellContext`as2, 
                0.]]}, {$CellContext`cs22 + $CellContext`ts2 - 1. 
           Sign[$CellContext`cs22] 
           Sqrt[$CellContext`cs22^2 - 
             1. (0.5 $CellContext`as2 + 
               0.41666666666666674` Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[-$CellContext`as2, 0.]])^2 - 
             1. (0. + 0.41666666666666674` Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[-$CellContext`as2, 0.]])^2], 
           0.5 $CellContext`as2 + 
           0.41666666666666674` Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[-$CellContext`as2, 
                0.]]}, {$CellContext`cs22 + $CellContext`ts2 - 1. 
           Sign[$CellContext`cs22] 
           Sqrt[$CellContext`cs22^2 - 
             1. (0.5 $CellContext`as2 + 
               0.3333333333333334 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[-$CellContext`as2, 0.]])^2 - 
             1. (0. + 0.3333333333333334 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[-$CellContext`as2, 0.]])^2], 
           0.5 $CellContext`as2 + 
           0.3333333333333334 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[-$CellContext`as2, 0.]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.6666666666666666 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[1. $CellContext`as2, 0.]])^2 - 
             1. (0. + 0.6666666666666666 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[
                   1. $CellContext`as2, 0.]])^2], (-0.5) $CellContext`as2 + 
           0.6666666666666666 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[1. $CellContext`as2, 0.]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.5833333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[1. $CellContext`as2, 0.]])^2 - 
             1. (0. + 0.5833333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[
                   1. $CellContext`as2, 0.]])^2], (-0.5) $CellContext`as2 + 
           0.5833333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[1. $CellContext`as2, 0.]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.6666666666666666 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[1. $CellContext`as2, 0.]])^2 - 
             1. (0. + 0.6666666666666666 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[
                   1. $CellContext`as2, 0.]])^2], (-0.5) $CellContext`as2 + 
           0.6666666666666666 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[
               1. $CellContext`as2, 
                0.]]}, {$CellContext`cs22 + $CellContext`ts2 - 1. 
           Sign[$CellContext`cs22] 
           Sqrt[$CellContext`cs22^2 - 
             1. (0.5 $CellContext`as2 + 
               0.33333333333333337` Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[-$CellContext`as2, 0.]])^2 - 
             1. (0. + 
               0.33333333333333337` Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[-$CellContext`as2, 0.]])^2], 
           0.5 $CellContext`as2 + 
           0.33333333333333337` Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[-$CellContext`as2, 
                0.]]}, {$CellContext`cs22 + $CellContext`ts2 - 1. 
           Sign[$CellContext`cs22] 
           Sqrt[$CellContext`cs22^2 - 
             1. (0.5 $CellContext`as2 + 
               0.25000000000000006` Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[-$CellContext`as2, 0.]])^2 - 
             1. (0. + 0.25000000000000006` Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[-$CellContext`as2, 0.]])^2], 
           0.5 $CellContext`as2 + 
           0.25000000000000006` Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[-$CellContext`as2, 0.]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.75 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[1. $CellContext`as2, 0.]])^2 - 
             1. (0. + 0.75 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[
                   1. $CellContext`as2, 0.]])^2], (-0.5) $CellContext`as2 + 
           0.75 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[1. $CellContext`as2, 0.]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.6666666666666666 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[1. $CellContext`as2, 0.]])^2 - 
             1. (0. + 0.6666666666666666 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[
                   1. $CellContext`as2, 0.]])^2], (-0.5) $CellContext`as2 + 
           0.6666666666666666 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[1. $CellContext`as2, 0.]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.75 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[1. $CellContext`as2, 0.]])^2 - 
             1. (0. + 0.75 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[
                   1. $CellContext`as2, 0.]])^2], (-0.5) $CellContext`as2 + 
           0.75 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[
               1. $CellContext`as2, 
                0.]]}, {$CellContext`cs22 + $CellContext`ts2 - 1. 
           Sign[$CellContext`cs22] 
           Sqrt[$CellContext`cs22^2 - 
             1. (0.5 $CellContext`as2 + 
               0.25 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[-$CellContext`as2, 0.]])^2 - 
             1. (0. + 0.25 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[-$CellContext`as2, 0.]])^2], 
           0.5 $CellContext`as2 + 
           0.25 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[-$CellContext`as2, 
                0.]]}, {$CellContext`cs22 + $CellContext`ts2 - 1. 
           Sign[$CellContext`cs22] 
           Sqrt[$CellContext`cs22^2 - 
             1. (0.5 $CellContext`as2 + 
               0.16666666666666669` Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[-$CellContext`as2, 0.]])^2 - 
             1. (0. + 0.16666666666666669` Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[-$CellContext`as2, 0.]])^2], 
           0.5 $CellContext`as2 + 
           0.16666666666666669` Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[-$CellContext`as2, 0.]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.8333333333333334 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[1. $CellContext`as2, 0.]])^2 - 
             1. (0. + 0.8333333333333334 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[
                   1. $CellContext`as2, 0.]])^2], (-0.5) $CellContext`as2 + 
           0.8333333333333334 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[1. $CellContext`as2, 0.]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.75 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[1. $CellContext`as2, 0.]])^2 - 
             1. (0. + 0.75 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[
                   1. $CellContext`as2, 0.]])^2], (-0.5) $CellContext`as2 + 
           0.75 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[1. $CellContext`as2, 0.]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.8333333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[1. $CellContext`as2, 0.]])^2 - 
             1. (0. + 
               0.8333333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[
                   1. $CellContext`as2, 0.]])^2], (-0.5) $CellContext`as2 + 
           0.8333333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[
               1. $CellContext`as2, 
                0.]]}, {$CellContext`cs22 + $CellContext`ts2 - 1. 
           Sign[$CellContext`cs22] 
           Sqrt[$CellContext`cs22^2 - 
             1. (0.5 $CellContext`as2 + 
               0.16666666666666674` Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[-$CellContext`as2, 0.]])^2 - 
             1. (0. + 0.16666666666666674` Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[-$CellContext`as2, 0.]])^2], 
           0.5 $CellContext`as2 + 
           0.16666666666666674` Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[-$CellContext`as2, 
                0.]]}, {$CellContext`cs22 + $CellContext`ts2 - 1. 
           Sign[$CellContext`cs22] 
           Sqrt[$CellContext`cs22^2 - 
             1. (0.5 $CellContext`as2 + 
               0.08333333333333341 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[-$CellContext`as2, 0.]])^2 - 
             1. (0. + 0.08333333333333341 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[-$CellContext`as2, 0.]])^2], 
           0.5 $CellContext`as2 + 
           0.08333333333333341 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[-$CellContext`as2, 0.]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.9166666666666666 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[1. $CellContext`as2, 0.]])^2 - 
             1. (0. + 0.9166666666666666 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[
                   1. $CellContext`as2, 0.]])^2], (-0.5) $CellContext`as2 + 
           0.9166666666666666 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[1. $CellContext`as2, 0.]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.8333333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[1. $CellContext`as2, 0.]])^2 - 
             1. (0. + 0.8333333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[
                   1. $CellContext`as2, 0.]])^2], (-0.5) $CellContext`as2 + 
           0.8333333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[1. $CellContext`as2, 0.]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.9166666666666666 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[1. $CellContext`as2, 0.]])^2 - 
             1. (0. + 0.9166666666666666 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[
                   1. $CellContext`as2, 0.]])^2], (-0.5) $CellContext`as2 + 
           0.9166666666666666 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[
               1. $CellContext`as2, 
                0.]]}, {$CellContext`cs22 + $CellContext`ts2 - 1. 
           Sign[$CellContext`cs22] 
           Sqrt[$CellContext`cs22^2 - 
             1. (0.5 $CellContext`as2 + 
               0.08333333333333337 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[-$CellContext`as2, 0.]])^2 - 
             1. (0. + 0.08333333333333337 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[-$CellContext`as2, 0.]])^2], 
           0.5 $CellContext`as2 + 
           0.08333333333333337 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[-$CellContext`as2, 
                0.]]}, {$CellContext`cs22 + $CellContext`ts2 - 1. 
           Sign[$CellContext`cs22] 
           Sqrt[$CellContext`cs22^2 - 
             1. (0.5 $CellContext`as2 + 
               4.163336342344337*^-17 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[-$CellContext`as2, 0.]])^2 - 
             1. (0. + 4.163336342344337*^-17 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[-$CellContext`as2, 0.]])^2], 
           0.5 $CellContext`as2 + 
           4.163336342344337*^-17 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[-$CellContext`as2, 0.]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. ((-0.5) $CellContext`as2 + 
               1. Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[1. $CellContext`as2, 0.]])^2 - 
             1. (0. + 1. Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[
                   1. $CellContext`as2, 0.]])^2], (-0.5) $CellContext`as2 + 
           1. Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[1. $CellContext`as2, 0.]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.9166666666666666 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[1. $CellContext`as2, 0.]])^2 - 
             1. (0. + 0.9166666666666666 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[
                   1. $CellContext`as2, 0.]])^2], (-0.5) $CellContext`as2 + 
           0.9166666666666666 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[1. $CellContext`as2, 0.]]}, {$CellContext`cs21 - 1. 
           Sqrt[0. - 1. (0. - 0.5 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 
           0.}, {$CellContext`cs22 + $CellContext`ts2 - 1. 
           Sign[$CellContext`cs22] 
           Sqrt[$CellContext`cs22^2 - 
             1. (0. + 1. Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., -$CellContext`as2]])^2 - 
             1. (0.5 $CellContext`as2 + 
               1. Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., -$CellContext`as2]])^2], 0. + 
           1. Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[
               0., -$CellContext`as2]]}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. Sign[$CellContext`cs22] 
           Sqrt[$CellContext`cs22^2 - 
             1. (0. + 0.9166666666666666 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., -$CellContext`as2]])^2 - 
             1. (0.5 $CellContext`as2 + 
               0.9166666666666666 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., -$CellContext`as2]])^2], 0. + 
           0.9166666666666666 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[0., -$CellContext`as2]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. (0. + 0.08333333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., 1. $CellContext`as2]])^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.08333333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., 1. $CellContext`as2]])^2], 0. + 
           0.08333333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[0., 1. $CellContext`as2]]}, {$CellContext`cs21 - 1. 
           Sqrt[0. - 1. (0. - 0.5 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0.}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. (0. + 
               0.08333333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., 1. $CellContext`as2]])^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.08333333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., 1. $CellContext`as2]])^2], 0. + 
           0.08333333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[
               0., 1. $CellContext`as2]]}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. Sign[$CellContext`cs22] 
           Sqrt[$CellContext`cs22^2 - 
             1. (0. + 0.9166666666666666 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., -$CellContext`as2]])^2 - 
             1. (0.5 $CellContext`as2 + 
               0.9166666666666666 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., -$CellContext`as2]])^2], 0. + 
           0.9166666666666666 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[
               0., -$CellContext`as2]]}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. Sign[$CellContext`cs22] 
           Sqrt[$CellContext`cs22^2 - 
             1. (0. + 0.8333333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., -$CellContext`as2]])^2 - 
             1. (0.5 $CellContext`as2 + 
               0.8333333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., -$CellContext`as2]])^2], 0. + 
           0.8333333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[0., -$CellContext`as2]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. (0. + 0.16666666666666666` Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., 1. $CellContext`as2]])^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.16666666666666666` Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., 1. $CellContext`as2]])^2], 0. + 
           0.16666666666666666` Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[0., 1. $CellContext`as2]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. (0. + 0.08333333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., 1. $CellContext`as2]])^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.08333333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., 1. $CellContext`as2]])^2], 0. + 
           0.08333333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[0., 1. $CellContext`as2]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. (0. + 0.16666666666666666` Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., 1. $CellContext`as2]])^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.16666666666666666` Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., 1. $CellContext`as2]])^2], 0. + 
           0.16666666666666666` Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[
               0., 1. $CellContext`as2]]}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. Sign[$CellContext`cs22] 
           Sqrt[$CellContext`cs22^2 - 
             1. (0. + 0.8333333333333334 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., -$CellContext`as2]])^2 - 
             1. (0.5 $CellContext`as2 + 
               0.8333333333333334 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., -$CellContext`as2]])^2], 0. + 
           0.8333333333333334 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[
               0., -$CellContext`as2]]}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. Sign[$CellContext`cs22] 
           Sqrt[$CellContext`cs22^2 - 
             1. (0. + 0.75 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., -$CellContext`as2]])^2 - 
             1. (0.5 $CellContext`as2 + 
               0.75 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., -$CellContext`as2]])^2], 0. + 
           0.75 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[0., -$CellContext`as2]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. (0. + 0.25 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., 1. $CellContext`as2]])^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.25 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., 1. $CellContext`as2]])^2], 0. + 
           0.25 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[0., 1. $CellContext`as2]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. (0. + 0.16666666666666666` Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., 1. $CellContext`as2]])^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.16666666666666666` Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., 1. $CellContext`as2]])^2], 0. + 
           0.16666666666666666` Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[0., 1. $CellContext`as2]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. (0. + 0.25 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., 1. $CellContext`as2]])^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.25 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., 1. $CellContext`as2]])^2], 0. + 
           0.25 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[
               0., 1. $CellContext`as2]]}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. Sign[$CellContext`cs22] 
           Sqrt[$CellContext`cs22^2 - 
             1. (0. + 0.75 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., -$CellContext`as2]])^2 - 
             1. (0.5 $CellContext`as2 + 
               0.75 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., -$CellContext`as2]])^2], 0. + 
           0.75 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[
               0., -$CellContext`as2]]}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. Sign[$CellContext`cs22] 
           Sqrt[$CellContext`cs22^2 - 
             1. (0. + 0.6666666666666666 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., -$CellContext`as2]])^2 - 
             1. (0.5 $CellContext`as2 + 
               0.6666666666666666 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., -$CellContext`as2]])^2], 0. + 
           0.6666666666666666 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[0., -$CellContext`as2]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. (0. + 0.3333333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., 1. $CellContext`as2]])^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.3333333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., 1. $CellContext`as2]])^2], 0. + 
           0.3333333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[0., 1. $CellContext`as2]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. (0. + 0.25 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., 1. $CellContext`as2]])^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.25 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., 1. $CellContext`as2]])^2], 0. + 
           0.25 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[0., 1. $CellContext`as2]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. (0. + 0.3333333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., 1. $CellContext`as2]])^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.3333333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., 1. $CellContext`as2]])^2], 0. + 
           0.3333333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[
               0., 1. $CellContext`as2]]}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. Sign[$CellContext`cs22] 
           Sqrt[$CellContext`cs22^2 - 
             1. (0. + 0.6666666666666667 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., -$CellContext`as2]])^2 - 
             1. (0.5 $CellContext`as2 + 
               0.6666666666666667 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., -$CellContext`as2]])^2], 0. + 
           0.6666666666666667 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[
               0., -$CellContext`as2]]}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. Sign[$CellContext`cs22] 
           Sqrt[$CellContext`cs22^2 - 
             1. (0. + 0.5833333333333334 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., -$CellContext`as2]])^2 - 
             1. (0.5 $CellContext`as2 + 
               0.5833333333333334 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., -$CellContext`as2]])^2], 0. + 
           0.5833333333333334 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[0., -$CellContext`as2]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. (0. + 0.41666666666666663` Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., 1. $CellContext`as2]])^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.41666666666666663` Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., 1. $CellContext`as2]])^2], 0. + 
           0.41666666666666663` Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[0., 1. $CellContext`as2]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. (0. + 0.3333333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., 1. $CellContext`as2]])^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.3333333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., 1. $CellContext`as2]])^2], 0. + 
           0.3333333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[0., 1. $CellContext`as2]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. (0. + 0.41666666666666663` Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., 1. $CellContext`as2]])^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.41666666666666663` Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., 1. $CellContext`as2]])^2], 0. + 
           0.41666666666666663` Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[
               0., 1. $CellContext`as2]]}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. Sign[$CellContext`cs22] 
           Sqrt[$CellContext`cs22^2 - 
             1. (0. + 0.5833333333333334 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., -$CellContext`as2]])^2 - 
             1. (0.5 $CellContext`as2 + 
               0.5833333333333334 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., -$CellContext`as2]])^2], 0. + 
           0.5833333333333334 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[
               0., -$CellContext`as2]]}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. Sign[$CellContext`cs22] 
           Sqrt[$CellContext`cs22^2 - 
             1. (0. + 0.5 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., -$CellContext`as2]])^2 - 
             1. (0.5 $CellContext`as2 + 
               0.5 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., -$CellContext`as2]])^2], 0. + 
           0.5 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[0., -$CellContext`as2]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. (0. + 0.49999999999999994` Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., 1. $CellContext`as2]])^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.49999999999999994` Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., 1. $CellContext`as2]])^2], 0. + 
           0.49999999999999994` Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[0., 1. $CellContext`as2]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. (0. + 0.41666666666666663` Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., 1. $CellContext`as2]])^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.41666666666666663` Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., 1. $CellContext`as2]])^2], 0. + 
           0.41666666666666663` Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[0., 1. $CellContext`as2]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. (0. + 0.5 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., 1. $CellContext`as2]])^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.5 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., 1. $CellContext`as2]])^2], 0. + 
           0.5 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[
               0., 1. $CellContext`as2]]}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. Sign[$CellContext`cs22] 
           Sqrt[$CellContext`cs22^2 - 
             1. (0. + 0.5 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., -$CellContext`as2]])^2 - 
             1. (0.5 $CellContext`as2 + 
               0.5 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., -$CellContext`as2]])^2], 0. + 
           0.5 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[
               0., -$CellContext`as2]]}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. Sign[$CellContext`cs22] 
           Sqrt[$CellContext`cs22^2 - 
             1. (0. + 0.4166666666666667 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., -$CellContext`as2]])^2 - 
             1. (0.5 $CellContext`as2 + 
               0.4166666666666667 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., -$CellContext`as2]])^2], 0. + 
           0.4166666666666667 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[0., -$CellContext`as2]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. (0. + 0.5833333333333334 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., 1. $CellContext`as2]])^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.5833333333333334 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., 1. $CellContext`as2]])^2], 0. + 
           0.5833333333333334 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[0., 1. $CellContext`as2]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. (0. + 0.5 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., 1. $CellContext`as2]])^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.5 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., 1. $CellContext`as2]])^2], 0. + 
           0.5 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[0., 1. $CellContext`as2]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. (0. + 0.5833333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., 1. $CellContext`as2]])^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.5833333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., 1. $CellContext`as2]])^2], 0. + 
           0.5833333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[
               0., 1. $CellContext`as2]]}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. Sign[$CellContext`cs22] 
           Sqrt[$CellContext`cs22^2 - 
             1. (0. + 0.41666666666666674` Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., -$CellContext`as2]])^2 - 
             1. (0.5 $CellContext`as2 + 
               0.41666666666666674` Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., -$CellContext`as2]])^2], 0. + 
           0.41666666666666674` Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[
               0., -$CellContext`as2]]}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. Sign[$CellContext`cs22] 
           Sqrt[$CellContext`cs22^2 - 
             1. (0. + 0.3333333333333334 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., -$CellContext`as2]])^2 - 
             1. (0.5 $CellContext`as2 + 
               0.3333333333333334 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., -$CellContext`as2]])^2], 0. + 
           0.3333333333333334 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[0., -$CellContext`as2]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. (0. + 0.6666666666666666 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., 1. $CellContext`as2]])^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.6666666666666666 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., 1. $CellContext`as2]])^2], 0. + 
           0.6666666666666666 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[0., 1. $CellContext`as2]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. (0. + 0.5833333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., 1. $CellContext`as2]])^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.5833333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., 1. $CellContext`as2]])^2], 0. + 
           0.5833333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[0., 1. $CellContext`as2]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. (0. + 0.6666666666666666 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., 1. $CellContext`as2]])^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.6666666666666666 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., 1. $CellContext`as2]])^2], 0. + 
           0.6666666666666666 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[
               0., 1. $CellContext`as2]]}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. Sign[$CellContext`cs22] 
           Sqrt[$CellContext`cs22^2 - 
             1. (0. + 0.33333333333333337` Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., -$CellContext`as2]])^2 - 
             1. (0.5 $CellContext`as2 + 
               0.33333333333333337` Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., -$CellContext`as2]])^2], 0. + 
           0.33333333333333337` Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[
               0., -$CellContext`as2]]}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. Sign[$CellContext`cs22] 
           Sqrt[$CellContext`cs22^2 - 
             1. (0. + 0.25000000000000006` Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., -$CellContext`as2]])^2 - 
             1. (0.5 $CellContext`as2 + 
               0.25000000000000006` Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., -$CellContext`as2]])^2], 0. + 
           0.25000000000000006` Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[0., -$CellContext`as2]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. (0. + 0.75 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., 1. $CellContext`as2]])^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.75 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., 1. $CellContext`as2]])^2], 0. + 
           0.75 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[0., 1. $CellContext`as2]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. (0. + 0.6666666666666666 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., 1. $CellContext`as2]])^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.6666666666666666 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., 1. $CellContext`as2]])^2], 0. + 
           0.6666666666666666 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[0., 1. $CellContext`as2]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. (0. + 0.75 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., 1. $CellContext`as2]])^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.75 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., 1. $CellContext`as2]])^2], 0. + 
           0.75 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[
               0., 1. $CellContext`as2]]}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. Sign[$CellContext`cs22] 
           Sqrt[$CellContext`cs22^2 - 
             1. (0. + 0.25 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., -$CellContext`as2]])^2 - 
             1. (0.5 $CellContext`as2 + 
               0.25 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., -$CellContext`as2]])^2], 0. + 
           0.25 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[
               0., -$CellContext`as2]]}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. Sign[$CellContext`cs22] 
           Sqrt[$CellContext`cs22^2 - 
             1. (0. + 0.16666666666666669` Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., -$CellContext`as2]])^2 - 
             1. (0.5 $CellContext`as2 + 
               0.16666666666666669` Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., -$CellContext`as2]])^2], 0. + 
           0.16666666666666669` Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[0., -$CellContext`as2]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. (0. + 0.8333333333333334 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., 1. $CellContext`as2]])^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.8333333333333334 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., 1. $CellContext`as2]])^2], 0. + 
           0.8333333333333334 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[0., 1. $CellContext`as2]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. (0. + 0.75 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., 1. $CellContext`as2]])^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.75 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., 1. $CellContext`as2]])^2], 0. + 
           0.75 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[0., 1. $CellContext`as2]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. (0. + 0.8333333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., 1. $CellContext`as2]])^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.8333333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., 1. $CellContext`as2]])^2], 0. + 
           0.8333333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[
               0., 1. $CellContext`as2]]}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. Sign[$CellContext`cs22] 
           Sqrt[$CellContext`cs22^2 - 
             1. (0. + 0.16666666666666674` Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., -$CellContext`as2]])^2 - 
             1. (0.5 $CellContext`as2 + 
               0.16666666666666674` Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., -$CellContext`as2]])^2], 0. + 
           0.16666666666666674` Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[
               0., -$CellContext`as2]]}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. Sign[$CellContext`cs22] 
           Sqrt[$CellContext`cs22^2 - 
             1. (0. + 0.08333333333333341 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., -$CellContext`as2]])^2 - 
             1. (0.5 $CellContext`as2 + 
               0.08333333333333341 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., -$CellContext`as2]])^2], 0. + 
           0.08333333333333341 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[0., -$CellContext`as2]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. (0. + 0.9166666666666666 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., 1. $CellContext`as2]])^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.9166666666666666 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., 1. $CellContext`as2]])^2], 0. + 
           0.9166666666666666 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[0., 1. $CellContext`as2]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. (0. + 0.8333333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., 1. $CellContext`as2]])^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.8333333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., 1. $CellContext`as2]])^2], 0. + 
           0.8333333333333333 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[0., 1. $CellContext`as2]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. (0. + 0.9166666666666666 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., 1. $CellContext`as2]])^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.9166666666666666 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., 1. $CellContext`as2]])^2], 0. + 
           0.9166666666666666 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[
               0., 1. $CellContext`as2]]}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. Sign[$CellContext`cs22] 
           Sqrt[$CellContext`cs22^2 - 
             1. (0. + 0.08333333333333337 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., -$CellContext`as2]])^2 - 
             1. (0.5 $CellContext`as2 + 
               0.08333333333333337 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., -$CellContext`as2]])^2], 0. + 
           0.08333333333333337 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[
               0., -$CellContext`as2]]}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. Sign[$CellContext`cs22] 
           Sqrt[$CellContext`cs22^2 - 
             1. (0. + 4.163336342344337*^-17 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., -$CellContext`as2]])^2 - 
             1. (0.5 $CellContext`as2 + 
               4.163336342344337*^-17 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., -$CellContext`as2]])^2], 0. + 
           4.163336342344337*^-17 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[0., -$CellContext`as2]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. (0. + 1. Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., 1. $CellContext`as2]])^2 - 
             1. ((-0.5) $CellContext`as2 + 
               1. Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., 1. $CellContext`as2]])^2], 0. + 
           1. Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[0., 1. $CellContext`as2]]}, {$CellContext`cs21 - 1. 
           Sign[$CellContext`cs21] 
           Sqrt[$CellContext`cs21^2 - 
             1. (0. + 0.9166666666666666 Sqrt[0. + 1. $CellContext`as2^2] 
                Cos[1. ArcTan[0., 1. $CellContext`as2]])^2 - 
             1. ((-0.5) $CellContext`as2 + 
               0.9166666666666666 Sqrt[0. + 1. $CellContext`as2^2] 
                Sin[1. ArcTan[0., 1. $CellContext`as2]])^2], 0. + 
           0.9166666666666666 Sqrt[0. + 1. $CellContext`as2^2] 
            Cos[1. ArcTan[
               0., 1. $CellContext`as2]]}}]; \
$CellContext`lines1318898201471941642965473 = 
       Compile[{$CellContext`as2, $CellContext`cs21, $CellContext`cs22, \
$CellContext`ts2}, {{$CellContext`cs21 - 1. 
           Sqrt[0. - 0.25 $CellContext`as2^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], (-0.5) $CellContext`as2}, \
{$CellContext`cs21 - 1. 
           Sqrt[0. - 0.25 $CellContext`as2^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0.}, {$CellContext`cs21 - 1. 
           Sqrt[0. - 1. (0. + 0.5 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. + 
           0.5 $CellContext`as2}, {$CellContext`cs22 + $CellContext`ts2 - 1. 
           Sqrt[0. - 1. (0. + 0.5 $CellContext`as2)^2 + $CellContext`cs22^2] 
           Sign[$CellContext`cs22], 0. + 
           0.5 $CellContext`as2}, {$CellContext`cs22 + $CellContext`ts2 - 1. 
           Sqrt[-(0. + 0.06526309611002579 $CellContext`as2)^2 - 
             1. (0. + 
               0.4957224306869052 $CellContext`as2)^2 + $CellContext`cs22^2] 
           Sign[$CellContext`cs22], 0. + 
           0.4957224306869052 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. + 0.06526309611002579 $CellContext`as2)^2 - 
             1. (0. + 
               0.4957224306869052 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. + 
           0.4957224306869052 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[0. - 1. (0. + 0.5 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. + 
           0.5 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. + 0.06526309611002579 $CellContext`as2)^2 - 
             1. (0. + 
               0.4957224306869052 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. + 
           0.4957224306869052 $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. + 0.06526309611002579 $CellContext`as2)^2 - 
             1. (0. + 
               0.4957224306869052 $CellContext`as2)^2 + $CellContext`cs22^2] 
           Sign[$CellContext`cs22], 0. + 
           0.4957224306869052 $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. + 0.12940952255126037` $CellContext`as2)^2 - 
             1. (0. + 
               0.48296291314453416` $CellContext`as2)^2 + $CellContext`cs22^2]
             Sign[$CellContext`cs22], 0. + 
           0.48296291314453416` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. + 0.12940952255126037` $CellContext`as2)^2 - 
             1. (0. + 
               0.48296291314453416` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. + 
           0.48296291314453416` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. + 0.06526309611002579 $CellContext`as2)^2 - 
             1. (0. + 
               0.4957224306869052 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. + 
           0.4957224306869052 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. + 0.12940952255126037` $CellContext`as2)^2 - 
             1. (0. + 
               0.48296291314453416` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. + 
           0.48296291314453416` $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. + 0.12940952255126037` $CellContext`as2)^2 - 
             1. (0. + 
               0.48296291314453416` $CellContext`as2)^2 + $CellContext`cs22^2]
             Sign[$CellContext`cs22], 0. + 
           0.48296291314453416` $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. + 0.1913417161825449 $CellContext`as2)^2 - 
             1. (0. + 
               0.46193976625564337` $CellContext`as2)^2 + $CellContext`cs22^2]
             Sign[$CellContext`cs22], 0. + 
           0.46193976625564337` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. + 0.1913417161825449 $CellContext`as2)^2 - 
             1. (0. + 
               0.46193976625564337` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. + 
           0.46193976625564337` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. + 0.12940952255126037` $CellContext`as2)^2 - 
             1. (0. + 
               0.48296291314453416` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. + 
           0.48296291314453416` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. + 0.1913417161825449 $CellContext`as2)^2 - 
             1. (0. + 
               0.46193976625564337` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. + 
           0.46193976625564337` $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. + 0.1913417161825449 $CellContext`as2)^2 - 
             1. (0. + 
               0.46193976625564337` $CellContext`as2)^2 + $CellContext`cs22^2]
             Sign[$CellContext`cs22], 0. + 
           0.46193976625564337` $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. + 0.24999999999999997` $CellContext`as2)^2 - 
             1. (0. + 
               0.43301270189221935` $CellContext`as2)^2 + $CellContext`cs22^2]
             Sign[$CellContext`cs22], 0. + 
           0.43301270189221935` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. + 0.24999999999999997` $CellContext`as2)^2 - 
             1. (0. + 
               0.43301270189221935` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. + 
           0.43301270189221935` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. + 0.1913417161825449 $CellContext`as2)^2 - 
             1. (0. + 
               0.46193976625564337` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. + 
           0.46193976625564337` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. + 0.24999999999999997` $CellContext`as2)^2 - 
             1. (0. + 
               0.43301270189221935` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. + 
           0.43301270189221935` $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. + 0.24999999999999997` $CellContext`as2)^2 - 
             1. (0. + 
               0.43301270189221935` $CellContext`as2)^2 + $CellContext`cs22^2]
             Sign[$CellContext`cs22], 0. + 
           0.43301270189221935` $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. + 0.3043807145043603 $CellContext`as2)^2 - 
             1. (0. + 
               0.39667667014561764` $CellContext`as2)^2 + $CellContext`cs22^2]
             Sign[$CellContext`cs22], 0. + 
           0.39667667014561764` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. + 0.3043807145043603 $CellContext`as2)^2 - 
             1. (0. + 
               0.39667667014561764` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. + 
           0.39667667014561764` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. + 0.24999999999999997` $CellContext`as2)^2 - 
             1. (0. + 
               0.43301270189221935` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. + 
           0.43301270189221935` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. + 0.3043807145043603 $CellContext`as2)^2 - 
             1. (0. + 
               0.39667667014561764` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. + 
           0.39667667014561764` $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. + 0.3043807145043603 $CellContext`as2)^2 - 
             1. (0. + 
               0.39667667014561764` $CellContext`as2)^2 + $CellContext`cs22^2]
             Sign[$CellContext`cs22], 0. + 
           0.39667667014561764` $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[(-2.) (0. + 
                0.35355339059327373` $CellContext`as2)^2 + \
$CellContext`cs22^2] Sign[$CellContext`cs22], 0. + 
           0.3535533905932738 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[(-2.) (0. + 
                0.35355339059327373` $CellContext`as2)^2 + \
$CellContext`cs21^2] Sign[$CellContext`cs21], 0. + 
           0.3535533905932738 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. + 0.3043807145043603 $CellContext`as2)^2 - 
             1. (0. + 
               0.39667667014561764` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. + 
           0.39667667014561764` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[(-2.) (0. + 
                0.35355339059327373` $CellContext`as2)^2 + \
$CellContext`cs21^2] Sign[$CellContext`cs21], 0. + 
           0.3535533905932738 $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[(-2.) (0. + 
                0.35355339059327373` $CellContext`as2)^2 + \
$CellContext`cs22^2] Sign[$CellContext`cs22], 0. + 
           0.3535533905932738 $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. + 0.30438071450436033` $CellContext`as2)^2 - 
             1. (0. + 
               0.3966766701456176 $CellContext`as2)^2 + $CellContext`cs22^2] 
           Sign[$CellContext`cs22], 0. + 
           0.30438071450436033` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. + 0.30438071450436033` $CellContext`as2)^2 - 
             1. (0. + 
               0.3966766701456176 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. + 
           0.30438071450436033` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[(-2.) (0. + 
                0.35355339059327373` $CellContext`as2)^2 + \
$CellContext`cs21^2] Sign[$CellContext`cs21], 0. + 
           0.3535533905932738 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. + 0.30438071450436033` $CellContext`as2)^2 - 
             1. (0. + 
               0.3966766701456176 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. + 
           0.30438071450436033` $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. + 0.30438071450436033` $CellContext`as2)^2 - 
             1. (0. + 
               0.3966766701456176 $CellContext`as2)^2 + $CellContext`cs22^2] 
           Sign[$CellContext`cs22], 0. + 
           0.30438071450436033` $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. + 0.25000000000000006` $CellContext`as2)^2 - 
             1. (0. + 
               0.4330127018922193 $CellContext`as2)^2 + $CellContext`cs22^2] 
           Sign[$CellContext`cs22], 0. + 
           0.25000000000000006` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. + 0.25000000000000006` $CellContext`as2)^2 - 
             1. (0. + 
               0.4330127018922193 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. + 
           0.25000000000000006` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. + 0.30438071450436033` $CellContext`as2)^2 - 
             1. (0. + 
               0.3966766701456176 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. + 
           0.30438071450436033` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. + 0.25000000000000006` $CellContext`as2)^2 - 
             1. (0. + 
               0.4330127018922193 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. + 
           0.25000000000000006` $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. + 0.25000000000000006` $CellContext`as2)^2 - 
             1. (0. + 
               0.4330127018922193 $CellContext`as2)^2 + $CellContext`cs22^2] 
           Sign[$CellContext`cs22], 0. + 
           0.25000000000000006` $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. + 0.19134171618254492` $CellContext`as2)^2 - 
             1. (0. + 
               0.46193976625564337` $CellContext`as2)^2 + $CellContext`cs22^2]
             Sign[$CellContext`cs22], 0. + 
           0.19134171618254492` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. + 0.19134171618254492` $CellContext`as2)^2 - 
             1. (0. + 
               0.46193976625564337` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. + 
           0.19134171618254492` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. + 0.25000000000000006` $CellContext`as2)^2 - 
             1. (0. + 
               0.4330127018922193 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. + 
           0.25000000000000006` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. + 0.19134171618254492` $CellContext`as2)^2 - 
             1. (0. + 
               0.46193976625564337` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. + 
           0.19134171618254492` $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. + 0.19134171618254492` $CellContext`as2)^2 - 
             1. (0. + 
               0.46193976625564337` $CellContext`as2)^2 + $CellContext`cs22^2]
             Sign[$CellContext`cs22], 0. + 
           0.19134171618254492` $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. + 0.12940952255126037` $CellContext`as2)^2 - 
             1. (0. + 
               0.48296291314453416` $CellContext`as2)^2 + $CellContext`cs22^2]
             Sign[$CellContext`cs22], 0. + 
           0.12940952255126037` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. + 0.12940952255126037` $CellContext`as2)^2 - 
             1. (0. + 
               0.48296291314453416` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. + 
           0.12940952255126037` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. + 0.19134171618254492` $CellContext`as2)^2 - 
             1. (0. + 
               0.46193976625564337` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. + 
           0.19134171618254492` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. + 0.12940952255126048` $CellContext`as2)^2 - 
             1. (0. + 
               0.4829629131445341 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. + 
           0.12940952255126048` $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. + 0.12940952255126048` $CellContext`as2)^2 - 
             1. (0. + 
               0.4829629131445341 $CellContext`as2)^2 + $CellContext`cs22^2] 
           Sign[$CellContext`cs22], 0. + 
           0.12940952255126048` $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. + 0.06526309611002586 $CellContext`as2)^2 - 
             1. (0. + 
               0.4957224306869052 $CellContext`as2)^2 + $CellContext`cs22^2] 
           Sign[$CellContext`cs22], 0. + 
           0.06526309611002586 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. + 0.06526309611002586 $CellContext`as2)^2 - 
             1. (0. + 
               0.4957224306869052 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. + 
           0.06526309611002586 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. + 0.12940952255126048` $CellContext`as2)^2 - 
             1. (0. + 
               0.4829629131445341 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. + 
           0.12940952255126048` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. + 0.06526309611002586 $CellContext`as2)^2 - 
             1. (0. + 
               0.4957224306869052 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. + 
           0.06526309611002586 $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. + 0.06526309611002586 $CellContext`as2)^2 - 
             1. (0. + 
               0.4957224306869052 $CellContext`as2)^2 + $CellContext`cs22^2] 
           Sign[$CellContext`cs22], 0. + 
           0.06526309611002586 $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. + 3.061616997868383*^-17 $CellContext`as2)^2 - 
             1. (0. + 0.5 $CellContext`as2)^2 + $CellContext`cs22^2] 
           Sign[$CellContext`cs22], 0. + 
           3.061616997868383*^-17 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. + 3.061616997868383*^-17 $CellContext`as2)^2 - 
             1. (0. + 0.5 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. + 
           3.061616997868383*^-17 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. + 0.06526309611002586 $CellContext`as2)^2 - 
             1. (0. + 
               0.4957224306869052 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. + 
           0.06526309611002586 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. + 3.061616997868383*^-17 $CellContext`as2)^2 - 
             1. (0. + 0.5 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. + 
           
           3.061616997868383*^-17 $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. + 3.061616997868383*^-17 $CellContext`as2)^2 - 
             1. (0. + 0.5 $CellContext`as2)^2 + $CellContext`cs22^2] 
           Sign[$CellContext`cs22], 0. + 
           3.061616997868383*^-17 $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.0652630961100258 $CellContext`as2)^2 - 
             1. (0. + 
               0.4957224306869052 $CellContext`as2)^2 + $CellContext`cs22^2] 
           Sign[$CellContext`cs22], 0. - 
           0.0652630961100258 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.0652630961100258 $CellContext`as2)^2 - 
             1. (0. + 
               0.4957224306869052 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. - 
           0.0652630961100258 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. + 3.061616997868383*^-17 $CellContext`as2)^2 - 
             1. (0. + 0.5 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. + 
           3.061616997868383*^-17 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.06526309611002569 $CellContext`as2)^2 - 
             1. (0. + 
               0.49572243068690525` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. - 
           0.06526309611002569 $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.06526309611002569 $CellContext`as2)^2 - 
             1. (0. + 
               0.49572243068690525` $CellContext`as2)^2 + $CellContext`cs22^2]
             Sign[$CellContext`cs22], 0. - 
           0.06526309611002569 $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.12940952255126031` $CellContext`as2)^2 - 
             1. (0. + 
               0.48296291314453416` $CellContext`as2)^2 + $CellContext`cs22^2]
             Sign[$CellContext`cs22], 0. - 
           0.12940952255126031` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.12940952255126031` $CellContext`as2)^2 - 
             1. (0. + 
               0.48296291314453416` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. - 
           0.12940952255126031` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.06526309611002569 $CellContext`as2)^2 - 
             1. (0. + 
               0.49572243068690525` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. - 
           0.06526309611002569 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.12940952255126031` $CellContext`as2)^2 - 
             1. (0. + 
               0.48296291314453416` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. - 
           0.12940952255126031` $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.12940952255126031` $CellContext`as2)^2 - 
             1. (0. + 
               0.48296291314453416` $CellContext`as2)^2 + $CellContext`cs22^2]
             Sign[$CellContext`cs22], 0. - 
           0.12940952255126031` $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.19134171618254486` $CellContext`as2)^2 - 
             1. (0. + 
               0.46193976625564337` $CellContext`as2)^2 + $CellContext`cs22^2]
             Sign[$CellContext`cs22], 0. - 
           0.19134171618254486` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.19134171618254486` $CellContext`as2)^2 - 
             1. (0. + 
               0.46193976625564337` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. - 
           0.19134171618254486` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.12940952255126031` $CellContext`as2)^2 - 
             1. (0. + 
               0.48296291314453416` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. - 
           0.12940952255126031` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.19134171618254475` $CellContext`as2)^2 - 
             1. (0. + 
               0.4619397662556434 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. - 
           0.19134171618254475` $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.19134171618254475` $CellContext`as2)^2 - 
             1. (0. + 
               0.4619397662556434 $CellContext`as2)^2 + $CellContext`cs22^2] 
           Sign[$CellContext`cs22], 0. - 
           0.19134171618254475` $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.2499999999999999 $CellContext`as2)^2 - 
             1. (0. + 
               0.43301270189221935` $CellContext`as2)^2 + $CellContext`cs22^2]
             Sign[$CellContext`cs22], 0. - 
           0.2499999999999999 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.2499999999999999 $CellContext`as2)^2 - 
             1. (0. + 
               0.43301270189221935` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. - 
           0.2499999999999999 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.19134171618254475` $CellContext`as2)^2 - 
             1. (0. + 
               0.4619397662556434 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. - 
           0.19134171618254475` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.2499999999999999 $CellContext`as2)^2 - 
             1. (0. + 
               0.43301270189221935` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. - 
           0.2499999999999999 $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.2499999999999999 $CellContext`as2)^2 - 
             1. (0. + 
               0.43301270189221935` $CellContext`as2)^2 + $CellContext`cs22^2]
             Sign[$CellContext`cs22], 0. - 
           0.2499999999999999 $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.30438071450436016` $CellContext`as2)^2 - 
             1. (0. + 
               0.3966766701456177 $CellContext`as2)^2 + $CellContext`cs22^2] 
           Sign[$CellContext`cs22], 0. - 
           0.30438071450436016` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.30438071450436016` $CellContext`as2)^2 - 
             1. (0. + 
               0.3966766701456177 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. - 
           0.30438071450436016` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.2499999999999999 $CellContext`as2)^2 - 
             1. (0. + 
               0.43301270189221935` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. - 
           0.2499999999999999 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.30438071450436016` $CellContext`as2)^2 - 
             1. (0. + 
               0.3966766701456177 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. - 
           0.30438071450436016` $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.30438071450436016` $CellContext`as2)^2 - 
             1. (0. + 
               0.3966766701456177 $CellContext`as2)^2 + $CellContext`cs22^2] 
           Sign[$CellContext`cs22], 0. - 
           0.30438071450436016` $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.35355339059327356` $CellContext`as2)^2 - 
             1. (0. + 
               0.35355339059327395` $CellContext`as2)^2 + $CellContext`cs22^2]
             Sign[$CellContext`cs22], 0. - 
           0.35355339059327356` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.35355339059327356` $CellContext`as2)^2 - 
             1. (0. + 
               0.35355339059327395` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. - 
           0.35355339059327356` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.30438071450436016` $CellContext`as2)^2 - 
             1. (0. + 
               0.3966766701456177 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. - 
           0.30438071450436016` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.35355339059327373` $CellContext`as2)^2 - 
             1. (0. + 
               0.3535533905932738 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. - 
           0.35355339059327373` $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.35355339059327373` $CellContext`as2)^2 - 
             1. (0. + 
               0.3535533905932738 $CellContext`as2)^2 + $CellContext`cs22^2] 
           Sign[$CellContext`cs22], 0. - 
           0.35355339059327373` $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.3966766701456175 $CellContext`as2)^2 - 
             1. (0. + 
               0.30438071450436044` $CellContext`as2)^2 + $CellContext`cs22^2]
             Sign[$CellContext`cs22], 0. - 
           0.3966766701456175 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.3966766701456175 $CellContext`as2)^2 - 
             1. (0. + 
               0.30438071450436044` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. - 
           0.3966766701456175 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.35355339059327373` $CellContext`as2)^2 - 
             1. (0. + 
               0.3535533905932738 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. - 
           0.35355339059327373` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.3966766701456175 $CellContext`as2)^2 - 
             1. (0. + 
               0.30438071450436044` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. - 
           0.3966766701456175 $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.3966766701456175 $CellContext`as2)^2 - 
             1. (0. + 
               0.30438071450436044` $CellContext`as2)^2 + $CellContext`cs22^2]
             Sign[$CellContext`cs22], 0. - 
           0.3966766701456175 $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.43301270189221924` $CellContext`as2)^2 - 
             1. (0. + 
               0.25000000000000017` $CellContext`as2)^2 + $CellContext`cs22^2]
             Sign[$CellContext`cs22], 0. - 
           0.43301270189221924` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.43301270189221924` $CellContext`as2)^2 - 
             1. (0. + 
               0.25000000000000017` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. - 
           0.43301270189221924` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.3966766701456175 $CellContext`as2)^2 - 
             1. (0. + 
               0.30438071450436044` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. - 
           0.3966766701456175 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.43301270189221924` $CellContext`as2)^2 - 
             1. (0. + 
               0.25000000000000017` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. - 
           0.43301270189221924` $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.43301270189221924` $CellContext`as2)^2 - 
             1. (0. + 
               0.25000000000000017` $CellContext`as2)^2 + $CellContext`cs22^2]
             Sign[$CellContext`cs22], 0. - 
           0.43301270189221924` $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.46193976625564326` $CellContext`as2)^2 - 
             1. (0. + 
               0.19134171618254514` $CellContext`as2)^2 + $CellContext`cs22^2]
             Sign[$CellContext`cs22], 0. - 
           0.46193976625564326` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.46193976625564326` $CellContext`as2)^2 - 
             1. (0. + 
               0.19134171618254514` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. - 
           0.46193976625564326` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.43301270189221924` $CellContext`as2)^2 - 
             1. (0. + 
               0.25000000000000017` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. - 
           0.43301270189221924` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.46193976625564337` $CellContext`as2)^2 - 
             1. (0. + 
               0.19134171618254495` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. - 
           0.46193976625564337` $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.46193976625564337` $CellContext`as2)^2 - 
             1. (0. + 
               0.19134171618254495` $CellContext`as2)^2 + $CellContext`cs22^2]
             Sign[$CellContext`cs22], 0. - 
           0.46193976625564337` $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.4829629131445341 $CellContext`as2)^2 - 
             1. (0. + 
               0.1294095225512605 $CellContext`as2)^2 + $CellContext`cs22^2] 
           Sign[$CellContext`cs22], 0. - 
           0.4829629131445341 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.4829629131445341 $CellContext`as2)^2 - 
             1. (0. + 
               0.1294095225512605 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. - 
           0.4829629131445341 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.46193976625564337` $CellContext`as2)^2 - 
             1. (0. + 
               0.19134171618254495` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. - 
           0.46193976625564337` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.4829629131445341 $CellContext`as2)^2 - 
             1. (0. + 
               0.1294095225512605 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. - 
           0.4829629131445341 $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.4829629131445341 $CellContext`as2)^2 - 
             1. (0. + 
               0.1294095225512605 $CellContext`as2)^2 + $CellContext`cs22^2] 
           Sign[$CellContext`cs22], 0. - 
           0.4829629131445341 $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.4957224306869052 $CellContext`as2)^2 - 
             1. (0. + 
               0.065263096110026 $CellContext`as2)^2 + $CellContext`cs22^2] 
           Sign[$CellContext`cs22], 0. - 
           0.4957224306869052 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.4957224306869052 $CellContext`as2)^2 - 
             1. (0. + 
               0.065263096110026 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. - 
           0.4957224306869052 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.4829629131445341 $CellContext`as2)^2 - 
             1. (0. + 
               0.1294095225512605 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. - 
           0.4829629131445341 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.4957224306869052 $CellContext`as2)^2 - 
             1. (0. + 
               0.065263096110026 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. - 
           0.4957224306869052 $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.4957224306869052 $CellContext`as2)^2 - 
             1. (0. + 
               0.065263096110026 $CellContext`as2)^2 + $CellContext`cs22^2] 
           Sign[$CellContext`cs22], 0. - 
           0.4957224306869052 $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.5 $CellContext`as2)^2 - 
             1. (0. + 
               2.83276944882399*^-16 $CellContext`as2)^2 + \
$CellContext`cs22^2] Sign[$CellContext`cs22], 0. - 
           0.5 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.5 $CellContext`as2)^2 - 
             1. (0. + 
               2.83276944882399*^-16 $CellContext`as2)^2 + \
$CellContext`cs21^2] Sign[$CellContext`cs21], 0. - 
           0.5 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.4957224306869052 $CellContext`as2)^2 - 
             1. (0. + 
               0.065263096110026 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. - 
           0.4957224306869052 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.5 $CellContext`as2)^2 - 
             1. (0. + 
               6.123233995736766*^-17 $CellContext`as2)^2 + \
$CellContext`cs21^2] Sign[$CellContext`cs21], 0. - 
           0.5 $CellContext`as2}, {$CellContext`cs22 + $CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.5 $CellContext`as2)^2 - 
             1. (0. + 
               6.123233995736766*^-17 $CellContext`as2)^2 + \
$CellContext`cs22^2] Sign[$CellContext`cs22], 0. - 
           0.5 $CellContext`as2}, {$CellContext`cs22 + $CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.49572243068690525` $CellContext`as2)^2 - 
             1. (0. - 
               0.06526309611002566 $CellContext`as2)^2 + $CellContext`cs22^2] 
           Sign[$CellContext`cs22], 0. - 
           0.49572243068690525` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.49572243068690525` $CellContext`as2)^2 - 
             1. (0. - 
               0.06526309611002566 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. - 
           0.49572243068690525` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.5 $CellContext`as2)^2 - 
             1. (0. + 
               6.123233995736766*^-17 $CellContext`as2)^2 + \
$CellContext`cs21^2] Sign[$CellContext`cs21], 0. - 
           0.5 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.49572243068690525` $CellContext`as2)^2 - 
             1. (0. - 
               0.06526309611002566 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. - 
           0.49572243068690525` $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.49572243068690525` $CellContext`as2)^2 - 
             1. (0. - 
               0.06526309611002566 $CellContext`as2)^2 + $CellContext`cs22^2] 
           Sign[$CellContext`cs22], 0. - 
           0.49572243068690525` $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.4829629131445342 $CellContext`as2)^2 - 
             1. (0. - 
               0.12940952255126018` $CellContext`as2)^2 + $CellContext`cs22^2]
             Sign[$CellContext`cs22], 0. - 
           0.4829629131445342 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.4829629131445342 $CellContext`as2)^2 - 
             1. (0. - 
               0.12940952255126018` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. - 
           0.4829629131445342 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.49572243068690525` $CellContext`as2)^2 - 
             1. (0. - 
               0.06526309611002566 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. - 
           0.49572243068690525` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.4829629131445342 $CellContext`as2)^2 - 
             1. (0. - 
               0.12940952255126018` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. - 
           0.4829629131445342 $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.4829629131445342 $CellContext`as2)^2 - 
             1. (0. - 
               0.12940952255126018` $CellContext`as2)^2 + $CellContext`cs22^2]
             Sign[$CellContext`cs22], 0. - 
           0.4829629131445342 $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.4619397662556435 $CellContext`as2)^2 - 
             1. (0. - 
               0.1913417161825446 $CellContext`as2)^2 + $CellContext`cs22^2] 
           Sign[$CellContext`cs22], 0. - 
           0.4619397662556435 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.4619397662556435 $CellContext`as2)^2 - 
             1. (0. - 
               0.1913417161825446 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. - 
           0.4619397662556435 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.4829629131445342 $CellContext`as2)^2 - 
             1. (0. - 
               0.12940952255126018` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. - 
           0.4829629131445342 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.4619397662556435 $CellContext`as2)^2 - 
             1. (0. - 
               0.1913417161825446 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. - 0.4619397662556435 $CellContext`as2},
           {$CellContext`cs22 + $CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.4619397662556435 $CellContext`as2)^2 - 
             1. (0. - 
               0.1913417161825446 $CellContext`as2)^2 + $CellContext`cs22^2] 
           Sign[$CellContext`cs22], 0. - 
           0.4619397662556435 $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.4330127018922195 $CellContext`as2)^2 - 
             1. (0. - 
               0.2499999999999997 $CellContext`as2)^2 + $CellContext`cs22^2] 
           Sign[$CellContext`cs22], 0. - 
           0.4330127018922195 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.4330127018922195 $CellContext`as2)^2 - 
             1. (0. - 
               0.2499999999999997 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. - 
           0.4330127018922195 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.4619397662556435 $CellContext`as2)^2 - 
             1. (0. - 
               0.1913417161825446 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. - 
           0.4619397662556435 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.4330127018922194 $CellContext`as2)^2 - 
             1. (0. - 
               0.24999999999999986` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. - 
           0.4330127018922194 $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.4330127018922194 $CellContext`as2)^2 - 
             1. (0. - 
               0.24999999999999986` $CellContext`as2)^2 + $CellContext`cs22^2]
             Sign[$CellContext`cs22], 0. - 
           0.4330127018922194 $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.3966766701456177 $CellContext`as2)^2 - 
             1. (0. - 
               0.30438071450436016` $CellContext`as2)^2 + $CellContext`cs22^2]
             Sign[$CellContext`cs22], 0. - 
           0.3966766701456177 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.3966766701456177 $CellContext`as2)^2 - 
             1. (0. - 
               0.30438071450436016` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. - 
           0.3966766701456177 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.4330127018922194 $CellContext`as2)^2 - 
             1. (0. - 
               0.24999999999999986` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. - 
           0.4330127018922194 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.3966766701456177 $CellContext`as2)^2 - 
             1. (0. - 
               0.30438071450436016` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. - 
           0.3966766701456177 $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.3966766701456177 $CellContext`as2)^2 - 
             1. (0. - 
               0.30438071450436016` $CellContext`as2)^2 + $CellContext`cs22^2]
             Sign[$CellContext`cs22], 0. - 
           0.3966766701456177 $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.35355339059327395` $CellContext`as2)^2 - 
             1. (0. - 
               0.35355339059327356` $CellContext`as2)^2 + $CellContext`cs22^2]
             Sign[$CellContext`cs22], 0. - 
           0.35355339059327395` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.35355339059327395` $CellContext`as2)^2 - 
             1. (0. - 
               0.35355339059327356` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. - 
           0.35355339059327395` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.3966766701456177 $CellContext`as2)^2 - 
             1. (0. - 
               0.30438071450436016` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. - 
           0.3966766701456177 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.35355339059327395` $CellContext`as2)^2 - 
             1. (0. - 
               0.35355339059327356` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. - 
           0.35355339059327395` $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.35355339059327395` $CellContext`as2)^2 - 
             1. (0. - 
               0.35355339059327356` $CellContext`as2)^2 + $CellContext`cs22^2]
             Sign[$CellContext`cs22], 0. - 
           0.35355339059327395` $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.39667667014561747` $CellContext`as2)^2 - 
             1. (0. - 
               0.30438071450436044` $CellContext`as2)^2 + $CellContext`cs22^2]
             Sign[$CellContext`cs22], 0. - 
           0.30438071450436044` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.39667667014561747` $CellContext`as2)^2 - 
             1. (0. - 
               0.30438071450436044` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. - 
           0.30438071450436044` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.35355339059327395` $CellContext`as2)^2 - 
             1. (0. - 
               0.35355339059327356` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. - 
           0.35355339059327395` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.39667667014561747` $CellContext`as2)^2 - 
             1. (0. - 
               0.30438071450436044` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. - 
           0.30438071450436044` $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.39667667014561747` $CellContext`as2)^2 - 
             1. (0. - 
               0.30438071450436044` $CellContext`as2)^2 + $CellContext`cs22^2]
             Sign[$CellContext`cs22], 0. - 
           0.30438071450436044` $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.4330127018922192 $CellContext`as2)^2 - 
             1. (0. - 
               0.2500000000000002 $CellContext`as2)^2 + $CellContext`cs22^2] 
           Sign[$CellContext`cs22], 0. - 
           0.2500000000000002 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.4330127018922192 $CellContext`as2)^2 - 
             1. (0. - 
               0.2500000000000002 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. - 
           0.2500000000000002 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.39667667014561747` $CellContext`as2)^2 - 
             1. (0. - 
               0.30438071450436044` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. - 
           0.30438071450436044` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.4330127018922192 $CellContext`as2)^2 - 
             1. (0. - 
               0.2500000000000002 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. - 
           0.2500000000000002 $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.4330127018922192 $CellContext`as2)^2 - 
             1. (0. - 
               0.2500000000000002 $CellContext`as2)^2 + $CellContext`cs22^2] 
           Sign[$CellContext`cs22], 0. - 
           0.2500000000000002 $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.46193976625564326` $CellContext`as2)^2 - 
             1. (0. - 
               0.19134171618254517` $CellContext`as2)^2 + $CellContext`cs22^2]
             Sign[$CellContext`cs22], 0. - 
           0.19134171618254517` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.46193976625564326` $CellContext`as2)^2 - 
             1. (0. - 
               0.19134171618254517` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. - 
           0.19134171618254517` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.4330127018922192 $CellContext`as2)^2 - 
             1. (0. - 
               0.2500000000000002 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. - 
           0.2500000000000002 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.46193976625564326` $CellContext`as2)^2 - 
             1. (0. - 
               0.19134171618254517` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. - 
           0.19134171618254517` $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.46193976625564326` $CellContext`as2)^2 - 
             1. (0. - 
               0.19134171618254517` $CellContext`as2)^2 + $CellContext`cs22^2]
             Sign[$CellContext`cs22], 0. - 
           0.19134171618254517` $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.48296291314453405` $CellContext`as2)^2 - 
             1. (0. - 
               0.12940952255126076` $CellContext`as2)^2 + $CellContext`cs22^2]
             Sign[$CellContext`cs22], 0. - 
           0.12940952255126076` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.48296291314453405` $CellContext`as2)^2 - 
             1. (0. - 
               0.12940952255126076` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. - 
           0.12940952255126076` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.46193976625564326` $CellContext`as2)^2 - 
             1. (0. - 
               0.19134171618254517` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. - 
           0.19134171618254517` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.48296291314453405` $CellContext`as2)^2 - 
             1. (0. - 
               0.12940952255126076` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. - 
           0.12940952255126076` $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.48296291314453405` $CellContext`as2)^2 - 
             1. (0. - 
               0.12940952255126076` $CellContext`as2)^2 + $CellContext`cs22^2]
             Sign[$CellContext`cs22], 0. - 
           0.12940952255126076` $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.49572243068690514` $CellContext`as2)^2 - 
             1. (0. - 
               0.06526309611002624 $CellContext`as2)^2 + $CellContext`cs22^2] 
           Sign[$CellContext`cs22], 0. - 
           0.06526309611002624 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.49572243068690514` $CellContext`as2)^2 - 
             1. (0. - 
               0.06526309611002624 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. - 
           0.06526309611002624 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.48296291314453405` $CellContext`as2)^2 - 
             1. (0. - 
               0.12940952255126076` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. - 
           0.12940952255126076` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.49572243068690514` $CellContext`as2)^2 - 
             1. (0. - 
               0.06526309611002624 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. - 
           0.06526309611002624 $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.49572243068690514` $CellContext`as2)^2 - 
             1. (0. - 
               0.06526309611002624 $CellContext`as2)^2 + $CellContext`cs22^2] 
           Sign[$CellContext`cs22], 0. - 
           0.06526309611002624 $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.5 $CellContext`as2)^2 - 
             1. (0. - 
               5.359377197861141*^-16 $CellContext`as2)^2 + \
$CellContext`cs22^2] Sign[$CellContext`cs22], 0. - 
           5.359377197861141*^-16 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.5 $CellContext`as2)^2 - 
             1. (0. - 
               5.359377197861141*^-16 $CellContext`as2)^2 + \
$CellContext`cs21^2] Sign[$CellContext`cs21], 0. - 
           5.359377197861141*^-16 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.49572243068690514` $CellContext`as2)^2 - 
             1. (0. - 
               0.06526309611002624 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. - 
           0.06526309611002624 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.5 $CellContext`as2)^2 - 
             1. (0. - 
               9.184850993605148*^-17 $CellContext`as2)^2 + \
$CellContext`cs21^2] Sign[$CellContext`cs21], 0. - 
           9.184850993605148*^-17 $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.5 $CellContext`as2)^2 - 
             1. (0. - 
               9.184850993605148*^-17 $CellContext`as2)^2 + \
$CellContext`cs22^2] Sign[$CellContext`cs22], 0. - 
           9.184850993605148*^-17 $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.49572243068690525` $CellContext`as2)^2 - 
             1. (0. + 
               0.06526309611002563 $CellContext`as2)^2 + $CellContext`cs22^2] 
           Sign[$CellContext`cs22], 0. + 
           0.06526309611002563 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.49572243068690525` $CellContext`as2)^2 - 
             1. (0. + 
               0.06526309611002563 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. + 
           0.06526309611002563 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.5 $CellContext`as2)^2 - 
             1. (0. - 
               9.184850993605148*^-17 $CellContext`as2)^2 + \
$CellContext`cs21^2] Sign[$CellContext`cs21], 0. - 
           9.184850993605148*^-17 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.49572243068690525` $CellContext`as2)^2 - 
             1. (0. + 
               0.06526309611002563 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. + 
           0.06526309611002563 $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.49572243068690525` $CellContext`as2)^2 - 
             1. (0. + 
               0.06526309611002563 $CellContext`as2)^2 + $CellContext`cs22^2] 
           Sign[$CellContext`cs22], 0. + 
           0.06526309611002563 $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.4829629131445342 $CellContext`as2)^2 - 
             1. (0. + 
               0.12940952255126015` $CellContext`as2)^2 + $CellContext`cs22^2]
             Sign[$CellContext`cs22], 0. + 
           0.12940952255126015` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.4829629131445342 $CellContext`as2)^2 - 
             1. (0. + 
               0.12940952255126015` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. + 
           0.12940952255126015` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.49572243068690525` $CellContext`as2)^2 - 
             1. (0. + 
               0.06526309611002563 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. + 
           0.06526309611002563 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.4829629131445342 $CellContext`as2)^2 - 
             1. (0. + 
               0.12940952255126015` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. + 
           0.12940952255126015` $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.4829629131445342 $CellContext`as2)^2 - 
             1. (0. + 
               0.12940952255126015` $CellContext`as2)^2 + $CellContext`cs22^2]
             Sign[$CellContext`cs22], 0. + 
           0.12940952255126015` $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.4619397662556435 $CellContext`as2)^2 - 
             1. (0. + 
               0.19134171618254459` $CellContext`as2)^2 + $CellContext`cs22^2]
             Sign[$CellContext`cs22], 0. + 
           0.19134171618254459` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.4619397662556435 $CellContext`as2)^2 - 
             1. (0. + 
               0.19134171618254459` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. + 
           0.19134171618254459` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.4829629131445342 $CellContext`as2)^2 - 
             1. (0. + 
               0.12940952255126015` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. + 
           0.12940952255126015` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.4619397662556435 $CellContext`as2)^2 - 
             1. (0. + 
               0.19134171618254459` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. + 
           0.19134171618254459` $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.4619397662556435 $CellContext`as2)^2 - 
             1. (0. + 
               0.19134171618254459` $CellContext`as2)^2 + $CellContext`cs22^2]
             Sign[$CellContext`cs22], 0. + 
           0.19134171618254459` $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.4330127018922195 $CellContext`as2)^2 - 
             1. (0. + 
               0.24999999999999967` $CellContext`as2)^2 + $CellContext`cs22^2]
             Sign[$CellContext`cs22], 0. + 
           0.24999999999999967` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.4330127018922195 $CellContext`as2)^2 - 
             1. (0. + 
               0.24999999999999967` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. + 
           0.24999999999999967` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.4619397662556435 $CellContext`as2)^2 - 
             1. (0. + 
               0.19134171618254459` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. + 
           0.19134171618254459` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.4330127018922195 $CellContext`as2)^2 - 
             1. (0. + 
               0.24999999999999967` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. + 
           0.24999999999999967` $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.4330127018922195 $CellContext`as2)^2 - 
             1. (0. + 
               0.24999999999999967` $CellContext`as2)^2 + $CellContext`cs22^2]
             Sign[$CellContext`cs22], 0. + 
           0.24999999999999967` $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.39667667014561786` $CellContext`as2)^2 - 
             1. (0. + 
               0.30438071450435994` $CellContext`as2)^2 + $CellContext`cs22^2]
             Sign[$CellContext`cs22], 0. + 
           0.30438071450435994` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.39667667014561786` $CellContext`as2)^2 - 
             1. (0. + 
               0.30438071450435994` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. + 
           0.30438071450435994` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.4330127018922195 $CellContext`as2)^2 - 
             1. (0. + 
               0.24999999999999967` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. + 
           0.24999999999999967` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.39667667014561786` $CellContext`as2)^2 - 
             1. (0. + 
               0.30438071450435994` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. + 
           0.30438071450435994` $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.39667667014561786` $CellContext`as2)^2 - 
             1. (0. + 
               0.30438071450435994` $CellContext`as2)^2 + $CellContext`cs22^2]
             Sign[$CellContext`cs22], 0. + 
           0.30438071450435994` $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.3535533905932742 $CellContext`as2)^2 - 
             1. (0. + 
               0.3535533905932734 $CellContext`as2)^2 + $CellContext`cs22^2] 
           Sign[$CellContext`cs22], 0. + 
           0.3535533905932734 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.3535533905932742 $CellContext`as2)^2 - 
             1. (0. + 
               0.3535533905932734 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. + 
           0.3535533905932734 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.39667667014561786` $CellContext`as2)^2 - 
             1. (0. + 
               0.30438071450435994` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. + 
           0.30438071450435994` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.35355339059327384` $CellContext`as2)^2 - 
             1. (0. + 
               0.3535533905932737 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. + 
           0.3535533905932737 $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.35355339059327384` $CellContext`as2)^2 - 
             1. (0. + 
               0.3535533905932737 $CellContext`as2)^2 + $CellContext`cs22^2] 
           Sign[$CellContext`cs22], 0. + 
           0.3535533905932737 $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.30438071450436044` $CellContext`as2)^2 - 
             1. (0. + 
               0.39667667014561747` $CellContext`as2)^2 + $CellContext`cs22^2]
             Sign[$CellContext`cs22], 0. + 
           0.39667667014561747` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.30438071450436044` $CellContext`as2)^2 - 
             1. (0. + 
               0.39667667014561747` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. + 
           0.39667667014561747` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.35355339059327384` $CellContext`as2)^2 - 
             1. (0. + 
               0.3535533905932737 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. + 
           0.3535533905932737 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.30438071450436044` $CellContext`as2)^2 - 
             1. (0. + 
               0.39667667014561747` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. + 
           0.39667667014561747` $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.30438071450436044` $CellContext`as2)^2 - 
             1. (0. + 
               0.39667667014561747` $CellContext`as2)^2 + $CellContext`cs22^2]
             Sign[$CellContext`cs22], 0. + 
           0.39667667014561747` $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.2500000000000002 $CellContext`as2)^2 - 
             1. (0. + 
               0.4330127018922192 $CellContext`as2)^2 + $CellContext`cs22^2] 
           Sign[$CellContext`cs22], 0. + 
           0.4330127018922192 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.2500000000000002 $CellContext`as2)^2 - 
             1. (0. + 
               0.4330127018922192 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. + 
           0.4330127018922192 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.30438071450436044` $CellContext`as2)^2 - 
             1. (0. + 
               0.39667667014561747` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. + 
           0.39667667014561747` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.2500000000000002 $CellContext`as2)^2 - 
             1. (0. + 
               0.4330127018922192 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. + 
           0.4330127018922192 $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.2500000000000002 $CellContext`as2)^2 - 
             1. (0. + 
               0.4330127018922192 $CellContext`as2)^2 + $CellContext`cs22^2] 
           Sign[$CellContext`cs22], 0. + 
           0.4330127018922192 $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.1913417161825452 $CellContext`as2)^2 - 
             1. (0. + 
               0.46193976625564326` $CellContext`as2)^2 + $CellContext`cs22^2]
             Sign[$CellContext`cs22], 0. + 
           0.46193976625564326` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.1913417161825452 $CellContext`as2)^2 - 
             1. (0. + 
               0.46193976625564326` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. + 
           0.46193976625564326` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.2500000000000002 $CellContext`as2)^2 - 
             1. (0. + 
               0.4330127018922192 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. + 
           0.4330127018922192 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.1913417161825452 $CellContext`as2)^2 - 
             1. (0. + 
               0.46193976625564326` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. + 
           0.46193976625564326` $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.1913417161825452 $CellContext`as2)^2 - 
             1. (0. + 
               0.46193976625564326` $CellContext`as2)^2 + $CellContext`cs22^2]
             Sign[$CellContext`cs22], 0. + 
           0.46193976625564326` $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.12940952255126079` $CellContext`as2)^2 - 
             1. (0. + 
               0.48296291314453405` $CellContext`as2)^2 + $CellContext`cs22^2]
             Sign[$CellContext`cs22], 0. + 
           0.48296291314453405` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.12940952255126079` $CellContext`as2)^2 - 
             1. (0. + 
               0.48296291314453405` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. + 
           0.48296291314453405` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.1913417161825452 $CellContext`as2)^2 - 
             1. (0. + 
               0.46193976625564326` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. + 
           0.46193976625564326` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.12940952255126079` $CellContext`as2)^2 - 
             1. (0. + 
               0.48296291314453405` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. + 
           0.48296291314453405` $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.12940952255126079` $CellContext`as2)^2 - 
             1. (0. + 
               0.48296291314453405` $CellContext`as2)^2 + $CellContext`cs22^2]
             Sign[$CellContext`cs22], 0. + 
           0.48296291314453405` $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.06526309611002629 $CellContext`as2)^2 - 
             1. (0. + 
               0.49572243068690514` $CellContext`as2)^2 + $CellContext`cs22^2]
             Sign[$CellContext`cs22], 0. + 
           0.49572243068690514` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.06526309611002629 $CellContext`as2)^2 - 
             1. (0. + 
               0.49572243068690514` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. + 
           0.49572243068690514` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.12940952255126079` $CellContext`as2)^2 - 
             1. (0. + 
               0.48296291314453405` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. + 
           0.48296291314453405` $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.06526309611002629 $CellContext`as2)^2 - 
             1. (0. + 
               0.49572243068690514` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. + 
           0.49572243068690514` $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 0.06526309611002629 $CellContext`as2)^2 - 
             1. (0. + 
               0.49572243068690514` $CellContext`as2)^2 + $CellContext`cs22^2]
             Sign[$CellContext`cs22], 0. + 
           0.49572243068690514` $CellContext`as2}, {$CellContext`cs22 + \
$CellContext`ts2 - 1. 
           Sqrt[-(0. - 5.66553889764798*^-16 $CellContext`as2)^2 - 
             1. (0. + 0.5 $CellContext`as2)^2 + $CellContext`cs22^2] 
           Sign[$CellContext`cs22], 0. + 
           0.5 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 5.66553889764798*^-16 $CellContext`as2)^2 - 
             1. (0. + 0.5 $CellContext`as2)^2 + $CellContext`cs21^2] 
           Sign[$CellContext`cs21], 0. + 
           0.5 $CellContext`as2}, {$CellContext`cs21 - 1. 
           Sqrt[-(0. - 0.06526309611002629 $CellContext`as2)^2 - 
             1. (0. + 
               0.49572243068690514` $CellContext`as2)^2 + $CellContext`cs21^2]
             Sign[$CellContext`cs21], 0. + 
           0.49572243068690514` $CellContext`as2}}]; \
$CellContext`lines1618898201471941642980591 = 
       Compile[{$CellContext`MirrorAngle}, {{
          0., (-0.5) Cos[0.017453292519943295` $CellContext`MirrorAngle]^2 - 
           0.5 Sin[0.017453292519943295` $CellContext`MirrorAngle]^2}, {
          0., (-0.4166666666666667) 
            Cos[0.017453292519943295` $CellContext`MirrorAngle]^2 - 
           0.4166666666666667 
           Sin[0.017453292519943295` $CellContext`MirrorAngle]^2}, {
          0., (-0.33333333333333337`) 
            Cos[0.017453292519943295` $CellContext`MirrorAngle]^2 - 
           0.33333333333333337` 
           Sin[0.017453292519943295` $CellContext`MirrorAngle]^2}, {
          0., (-0.25) Cos[0.017453292519943295` $CellContext`MirrorAngle]^2 - 
           0.25 Sin[0.017453292519943295` $CellContext`MirrorAngle]^2}, {
          0., (-0.16666666666666669`) 
            Cos[0.017453292519943295` $CellContext`MirrorAngle]^2 - 
           0.16666666666666669` 
           Sin[0.017453292519943295` $CellContext`MirrorAngle]^2}, {
          0., (-0.08333333333333337) 
            Cos[0.017453292519943295` $CellContext`MirrorAngle]^2 - 
           0.08333333333333337 
           Sin[0.017453292519943295` $CellContext`MirrorAngle]^2}, {0., 0.}, {
          0., 0.08333333333333326 
            Cos[0.017453292519943295` $CellContext`MirrorAngle]^2 + 
           0.08333333333333326 
            Sin[0.017453292519943295` $CellContext`MirrorAngle]^2}, {
          0., 0.16666666666666663` 
            Cos[0.017453292519943295` $CellContext`MirrorAngle]^2 + 
           0.16666666666666663` 
            Sin[0.017453292519943295` $CellContext`MirrorAngle]^2}, {
          0., 0.25 Cos[0.017453292519943295` $CellContext`MirrorAngle]^2 + 
           0.25 Sin[0.017453292519943295` $CellContext`MirrorAngle]^2}, {
          0., 0.33333333333333326` 
            Cos[0.017453292519943295` $CellContext`MirrorAngle]^2 + 
           0.33333333333333326` 
            Sin[0.017453292519943295` $CellContext`MirrorAngle]^2}, {
          0., 0.41666666666666663` 
            Cos[0.017453292519943295` $CellContext`MirrorAngle]^2 + 
           0.41666666666666663` 
            Sin[0.017453292519943295` $CellContext`MirrorAngle]^2}, {
          0., 0.5 Cos[0.017453292519943295` $CellContext`MirrorAngle]^2 + 
           0.5 Sin[0.017453292519943295` $CellContext`MirrorAngle]^2}, {
          0., 0.5 Cos[0.017453292519943295` $CellContext`MirrorAngle]^2 + 
           0.5 Sin[0.017453292519943295` $CellContext`MirrorAngle]^2}, {
          0., 0.4166666666666667 
            Cos[0.017453292519943295` $CellContext`MirrorAngle]^2 + 
           0.4166666666666667 
            Sin[0.017453292519943295` $CellContext`MirrorAngle]^2}, {
          0., 0.33333333333333337` 
            Cos[0.017453292519943295` $CellContext`MirrorAngle]^2 + 
           0.33333333333333337` 
            Sin[0.017453292519943295` $CellContext`MirrorAngle]^2}, {
          0., 0.25 Cos[0.017453292519943295` $CellContext`MirrorAngle]^2 + 
           0.25 Sin[0.017453292519943295` $CellContext`MirrorAngle]^2}, {
          0., 0.16666666666666669` 
            Cos[0.017453292519943295` $CellContext`MirrorAngle]^2 + 
           0.16666666666666669` 
            Sin[0.017453292519943295` $CellContext`MirrorAngle]^2}, {
          0., 0.08333333333333337 
            Cos[0.017453292519943295` $CellContext`MirrorAngle]^2 + 
           0.08333333333333337 
            Sin[0.017453292519943295` $CellContext`MirrorAngle]^2}, {0., 
          0.}, {0., (-0.08333333333333326) 
            Cos[0.017453292519943295` $CellContext`MirrorAngle]^2 - 
           0.08333333333333326 
           Sin[0.017453292519943295` $CellContext`MirrorAngle]^2}, {
          0., (-0.16666666666666663`) 
            Cos[0.017453292519943295` $CellContext`MirrorAngle]^2 - 
           0.16666666666666663` 
           Sin[0.017453292519943295` $CellContext`MirrorAngle]^2}, {
          0., (-0.25) Cos[0.017453292519943295` $CellContext`MirrorAngle]^2 - 
           0.25 Sin[0.017453292519943295` $CellContext`MirrorAngle]^2}, {
          0., (-0.33333333333333326`) 
            Cos[0.017453292519943295` $CellContext`MirrorAngle]^2 - 
           0.33333333333333326` 
           Sin[0.017453292519943295` $CellContext`MirrorAngle]^2}, {
          0., (-0.41666666666666663`) 
            Cos[0.017453292519943295` $CellContext`MirrorAngle]^2 - 
           0.41666666666666663` 
           Sin[0.017453292519943295` $CellContext`MirrorAngle]^2}, {
          0., (-0.5) Cos[0.017453292519943295` $CellContext`MirrorAngle]^2 - 
           0.5 Sin[0.017453292519943295` $CellContext`MirrorAngle]^2}, {
          0., (-0.5) Cos[0.017453292519943295` $CellContext`MirrorAngle]^2 - 
           0.5 Sin[0.017453292519943295` $CellContext`MirrorAngle]^2}}]; \
$CellContext`polygons1818898201471941642992831 = 
       Compile[{$CellContext`c11, $CellContext`c12, $CellContext`t1}, \
{{$CellContext`c11 - 1. Sqrt[-0.3364 + $CellContext`c11^2] 
           Sign[$CellContext`c11], -0.58}, {$CellContext`c11 - 1. 
           Sqrt[-0.23361111111111105` + $CellContext`c11^2] 
           Sign[$CellContext`c11], -0.4833333333333333}, {$CellContext`c11 - 
           1. Sqrt[-0.1495111111111111 + $CellContext`c11^2] 
           Sign[$CellContext`c11], -0.38666666666666666`}, {$CellContext`c11 - 
           1. Sqrt[-0.08410000000000002 + $CellContext`c11^2] 
           Sign[$CellContext`c11], -0.29000000000000004`}, {$CellContext`c11 - 
           1. Sqrt[-0.03737777777777779 + $CellContext`c11^2] 
           Sign[$CellContext`c11], -0.19333333333333336`}, {$CellContext`c11 - 
           1. Sqrt[-0.009344444444444447 + $CellContext`c11^2] 
           Sign[$CellContext`c11], -0.09666666666666668}, {$CellContext`c11 - 
           1. Sqrt[-1.232595164407831*^-32 + $CellContext`c11^2] 
           Sign[$CellContext`c11], -1.1102230246251565`*^-16}, \
{$CellContext`c11 - 1. Sqrt[-0.009344444444444426 + $CellContext`c11^2] 
           Sign[$CellContext`c11], 0.09666666666666657}, {$CellContext`c11 - 
           1. Sqrt[-0.037377777777777746` + $CellContext`c11^2] 
           Sign[$CellContext`c11], 0.19333333333333325`}, {$CellContext`c11 - 
           1. Sqrt[-0.08409999999999995 + $CellContext`c11^2] 
           Sign[$CellContext`c11], 0.2899999999999999}, {$CellContext`c11 - 
           1. Sqrt[-0.14951111111111107` + $CellContext`c11^2] 
           Sign[$CellContext`c11], 0.3866666666666666}, {$CellContext`c11 - 
           1. Sqrt[-0.23361111111111105` + $CellContext`c11^2] 
           Sign[$CellContext`c11], 0.4833333333333333}, {$CellContext`c11 - 
           1. Sqrt[-0.3363999999999997 + $CellContext`c11^2] 
           Sign[$CellContext`c11], 
           0.5799999999999997}, {$CellContext`c12 + $CellContext`t1 - 1. 
           Sqrt[-0.3364 + $CellContext`c12^2] Sign[$CellContext`c12], 
           0.58}, {$CellContext`c12 + $CellContext`t1 - 1. 
           Sqrt[-0.23361111111111105` + $CellContext`c12^2] 
           Sign[$CellContext`c12], 
           0.4833333333333333}, {$CellContext`c12 + $CellContext`t1 - 1. 
           Sqrt[-0.1495111111111111 + $CellContext`c12^2] 
           Sign[$CellContext`c12], 
           0.38666666666666666`}, {$CellContext`c12 + $CellContext`t1 - 1. 
           Sqrt[-0.08410000000000002 + $CellContext`c12^2] 
           Sign[$CellContext`c12], 
           0.29000000000000004`}, {$CellContext`c12 + $CellContext`t1 - 1. 
           Sqrt[-0.03737777777777779 + $CellContext`c12^2] 
           Sign[$CellContext`c12], 
           0.19333333333333336`}, {$CellContext`c12 + $CellContext`t1 - 1. 
           Sqrt[-0.009344444444444447 + $CellContext`c12^2] 
           Sign[$CellContext`c12], 
           0.09666666666666668}, {$CellContext`c12 + $CellContext`t1 - 1. 
           Sqrt[-1.232595164407831*^-32 + $CellContext`c12^2] 
           Sign[$CellContext`c12], 
           1.1102230246251565`*^-16}, {$CellContext`c12 + $CellContext`t1 - 
           1. Sqrt[-0.009344444444444426 + $CellContext`c12^2] 
           Sign[$CellContext`c12], -0.09666666666666657}, {$CellContext`c12 + \
$CellContext`t1 - 1. Sqrt[-0.037377777777777746` + $CellContext`c12^2] 
           Sign[$CellContext`c12], -0.19333333333333325`}, {$CellContext`c12 + \
$CellContext`t1 - 1. Sqrt[-0.08409999999999995 + $CellContext`c12^2] 
           Sign[$CellContext`c12], -0.2899999999999999}, {$CellContext`c12 + \
$CellContext`t1 - 1. Sqrt[-0.14951111111111107` + $CellContext`c12^2] 
           Sign[$CellContext`c12], -0.3866666666666666}, {$CellContext`c12 + \
$CellContext`t1 - 1. Sqrt[-0.23361111111111105` + $CellContext`c12^2] 
           Sign[$CellContext`c12], -0.4833333333333333}, {$CellContext`c12 + \
$CellContext`t1 - 1. Sqrt[-0.3363999999999997 + $CellContext`c12^2] 
           Sign[$CellContext`c12], -0.5799999999999997}, {$CellContext`c11 - 
           1. Sqrt[-0.3364 + $CellContext`c11^2] 
           Sign[$CellContext`c11], -0.58}}]; \
$CellContext`polygons2018898201471941643005225 = 
       Compile[{$CellContext`c21, $CellContext`c22, $CellContext`t2}, \
{{$CellContext`c21 - 1. Sqrt[-0.3364 + $CellContext`c21^2] 
           Sign[$CellContext`c21], -0.58}, {$CellContext`c21 - 1. 
           Sqrt[-0.23361111111111105` + $CellContext`c21^2] 
           Sign[$CellContext`c21], -0.4833333333333333}, {$CellContext`c21 - 
           1. Sqrt[-0.1495111111111111 + $CellContext`c21^2] 
           Sign[$CellContext`c21], -0.38666666666666666`}, {$CellContext`c21 - 
           1. Sqrt[-0.08410000000000002 + $CellContext`c21^2] 
           Sign[$CellContext`c21], -0.29000000000000004`}, {$CellContext`c21 - 
           1. Sqrt[-0.03737777777777779 + $CellContext`c21^2] 
           Sign[$CellContext`c21], -0.19333333333333336`}, {$CellContext`c21 - 
           1. Sqrt[-0.009344444444444447 + $CellContext`c21^2] 
           Sign[$CellContext`c21], -0.09666666666666668}, {$CellContext`c21 - 
           1. Sqrt[-1.232595164407831*^-32 + $CellContext`c21^2] 
           Sign[$CellContext`c21], -1.1102230246251565`*^-16}, \
{$CellContext`c21 - 1. Sqrt[-0.009344444444444426 + $CellContext`c21^2] 
           Sign[$CellContext`c21], 0.09666666666666657}, {$CellContext`c21 - 
           1. Sqrt[-0.037377777777777746` + $CellContext`c21^2] 
           Sign[$CellContext`c21], 0.19333333333333325`}, {$CellContext`c21 - 
           1. Sqrt[-0.08409999999999995 + $CellContext`c21^2] 
           Sign[$CellContext`c21], 0.2899999999999999}, {$CellContext`c21 - 
           1. Sqrt[-0.14951111111111107` + $CellContext`c21^2] 
           Sign[$CellContext`c21], 0.3866666666666666}, {$CellContext`c21 - 
           1. Sqrt[-0.23361111111111105` + $CellContext`c21^2] 
           Sign[$CellContext`c21], 0.4833333333333333}, {$CellContext`c21 - 
           1. Sqrt[-0.3363999999999997 + $CellContext`c21^2] 
           Sign[$CellContext`c21], 
           0.5799999999999997}, {$CellContext`c22 + $CellContext`t2 - 1. 
           Sqrt[-0.3364 + $CellContext`c22^2] Sign[$CellContext`c22], 
           0.58}, {$CellContext`c22 + $CellContext`t2 - 1. 
           Sqrt[-0.23361111111111105` + $CellContext`c22^2] 
           Sign[$CellContext`c22], 
           0.4833333333333333}, {$CellContext`c22 + $CellContext`t2 - 1. 
           Sqrt[-0.1495111111111111 + $CellContext`c22^2] 
           Sign[$CellContext`c22], 
           0.38666666666666666`}, {$CellContext`c22 + $CellContext`t2 - 1. 
           Sqrt[-0.08410000000000002 + $CellContext`c22^2] 
           Sign[$CellContext`c22], 
           0.29000000000000004`}, {$CellContext`c22 + $CellContext`t2 - 1. 
           Sqrt[-0.03737777777777779 + $CellContext`c22^2] 
           Sign[$CellContext`c22], 
           0.19333333333333336`}, {$CellContext`c22 + $CellContext`t2 - 1. 
           Sqrt[-0.009344444444444447 + $CellContext`c22^2] 
           Sign[$CellContext`c22], 
           0.09666666666666668}, {$CellContext`c22 + $CellContext`t2 - 1. 
           Sqrt[-1.232595164407831*^-32 + $CellContext`c22^2] 
           Sign[$CellContext`c22], 
           1.1102230246251565`*^-16}, {$CellContext`c22 + $CellContext`t2 - 
           1. Sqrt[-0.009344444444444426 + $CellContext`c22^2] 
           Sign[$CellContext`c22], -0.09666666666666657}, {$CellContext`c22 + \
$CellContext`t2 - 1. Sqrt[-0.037377777777777746` + $CellContext`c22^2] 
           Sign[$CellContext`c22], -0.19333333333333325`}, {$CellContext`c22 + \
$CellContext`t2 - 1. Sqrt[-0.08409999999999995 + $CellContext`c22^2] 
           Sign[$CellContext`c22], -0.2899999999999999}, {$CellContext`c22 + \
$CellContext`t2 - 1. Sqrt[-0.14951111111111107` + $CellContext`c22^2] 
           Sign[$CellContext`c22], -0.3866666666666666}, {$CellContext`c22 + \
$CellContext`t2 - 1. Sqrt[-0.23361111111111105` + $CellContext`c22^2] 
           
           Sign[$CellContext`c22], -0.4833333333333333}, {$CellContext`c22 + \
$CellContext`t2 - 1. Sqrt[-0.3363999999999997 + $CellContext`c22^2] 
           Sign[$CellContext`c22], -0.5799999999999997}, {$CellContext`c21 - 
           1. Sqrt[-0.3364 + $CellContext`c21^2] 
           Sign[$CellContext`c21], -0.58}}]); Typeset`initDone$$ = True),
    SynchronousInitialization->False,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False,
   DynamicEvaluationTimeout->100],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.554143537796097*^9, 3.6147502119682627`*^9}]
}, Open  ]]
},
WindowSize->{1123, 791},
WindowMargins->{{40, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> True}},
FrontEndVersion->"9.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (January 25, \
2013)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 1230, 26, 271, "Input"],
Cell[CellGroupData[{
Cell[1800, 50, 7825, 205, 380, "Input"],
Cell[9628, 257, 993124, 16952, 878, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
