(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    327811,      14220]*)
(*NotebookOutlinePosition[    330275,      14278]*)
(*  CellTagsIndexPosition[    330164,      14272]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Bulk Diffusion with MonteCarlo Random Walk", "Section",
  CellTags->"Bulk Diffusion with MonteCarlo Random Walk"],

Cell[CellGroupData[{

Cell["BulkDiffusion Genetic", "Subsubsection",
  CellTags->"Bulk Diffusion with MonteCarlo Random Walk"],

Cell["Clear[BulkDiffusion];", "Input",
  CellTags->"Bulk Diffusion with MonteCarlo Random Walk"],

Cell["\<\
BulkDiffusion[component_, scatterangle_, scatterlength_, \
attenuation_, options___] :=
Block[{scatterx, scattery, minscatterlength, maxscatterlength, \
attenuationfunction, scalefactor=100},
\tWhich[
\t\tNumberQ[scatterangle],
\t\tscatterx = {-scatterangle/2,scatterangle/2};
\t\tscattery = {0,0};
\t,
\t\tLength[scatterangle]==1&&Length[Flatten[{scatterangle}]]==1,
\t\tscatterx = Flatten[{-scatterangle/2,scatterangle/2}];
\t\tscattery = scatterx
\t,
\t\tLength[scatterangle]==1&&Length[Flatten[{scatterangle}]]==2,
\t\tscatterx = {scatterangle[[1,1]],scatterangle[[1,2]]};
\t\tscattery = scatterx
\t,
\t\tLength[scatterangle]==2 && Length[scatterangle[[1]]]==1,
\t\tscatterx = {-scatterangle[[1]],scatterangle[[1]]};
\t\tscattery = {-scatterangle[[2]],scatterangle[[2]]}
\t,
\t\tLength[scatterangle]==2 && Length[scatterangle[[1]]]==2,
\t\t{scatterx, scattery} = scatterangle
\t,
\t\tLength[scatterangle]==2,
\t\tscatterx = scatterangle;
\t\tscattery = {0,0}
\t,
\t\tLength[scatterangle]==4,
\t\t{scatterx, scattery} = {scatterangle[[{1,2}]],scatterangle[[{3,4}]]}
\t];
\tIf[Length[scatterlength]==2,
\t\t{minscatterlength, maxscatterlength} = N[scatterlength],
\t\t{minscatterlength, maxscatterlength} = \
N[{scatterlength/scalefactor,scatterlength}]
\t];
\tWhich[
\t\tattenuation==0,
\t\tattenuationfunction = 1.&
\t,
\t\tNumberQ[attenuation],
\t\tattenuationfunction = Exp[-#*attenuation]&
\t,
\t\tHead[attenuationfactor]===Function,
\t\tattenuationfunction = attenuation
\t];
\t
\tCustomDeflections[
\t\tcomponent
\t,
\t\tWith[
\t\t\t{scatterx=N[scatterx], scattery=N[scattery], \
minscatterlength=N[minscatterlength], 
\t\t\tdegree = N[Degree], maxscatterlength=N[maxscatterlength], \
attenuationfunction=attenuationfunction}
\t\t,
\t\t\t{
\t\t\tHold[anglex],
\t\t\tHold[anglex = 1.],
\t\t\tHold[
\t\t\t\tRayStart = RayEnd-RayLength*RayTilt;
\t\t\t\tanglex = 0.;
\t\t\t\tIf[RayLength<minscatterlength || RayLength>maxscatterlength,
\t\t\t\t\tIf[RayLength>minscatterlength,
\t\t\t\t\t\tRayLength = Random[Real,{minscatterlength, maxscatterlength}];
\t\t\t\t\t\tRayEnd = RayStart + RayLength*RayTilt;
\t\t\t\t\t\t1.
\t\t\t\t\t,
\t\t\t\t\t\t1.
\t\t\t\t\t];
\t\t\t\t\tanglex = Random[Real,scatterx]*degree;
\t\t\t\t\tRayTilt = (#/Sqrt[Dot[#,#]])&[
\t\t\t\t\t\t\tCos[anglex]*RotationMatrix[[1]]+Sin[anglex]*RotationMatrix[[2]]]\
;
\t\t\t\t\t1.
\t\t\t\t,
\t\t\t\t\tTerminateDeflection = True;
\t\t\t\t\t1.
\t\t\t\t];
\t\t\t\tIntensity = Intensity*attenuationfunction[RayLength];
\t\t\t\tAllCreatedRays = {Ray}
\t\t\t]
\t\t\t}
\t\t]
\t,
\t\tFlatten[{TakeFrom->{OriginalRay}, \
AddTo->{OriginalRay},MultipleScatteredRays->1,
\t\tWith[
\t\t\t{scatterx=N[scatterx], scattery=N[scattery], \
minscatterlength=N[minscatterlength], 
\t\t\tdegree = N[Degree], maxscatterlength=N[maxscatterlength], \
attenuationfunction=attenuationfunction}
\t\t,
\t\tPropagateSystemDeflection->Function[
\t\t\t\tModule[{raystart, rayend, raytilt, intensity, raylength, anglex, 
\t\t\t\t\trotationmatrix, cos, sin, ux, uy, uz, rx, ry, rz, terminate},
\t\t\t\t{rayend, raytilt, intensity, raylength, rotationmatrix} = 
\t\t\t\t\t{RayEnd, RayTilt, Intensity, RayLength, RotationMatrix}/.#;
\t\t\t\t
\t\t\t\traystart = rayend-raylength*raytilt;
\t\t\t\tanglex = 0.;
\t\t\t\tterminate = False;
\t\t\t\tIf[raylength<minscatterlength || raylength>maxscatterlength,

\t\t\t\t\tIf[raylength>minscatterlength,
\t\t\t\t\t\t\t\t
\t\t\t\t\t\traylength = Random[Real,{minscatterlength, maxscatterlength}];
\t\t\t\t\t\trayend = raystart + raylength*raytilt
\t\t\t\t\t];
\t\t\t\t\t
\t\t\t\t\tanglex = Random[Real,scatterx]*degree;
\t\t\t\t\traytilt = (#/Sqrt[Dot[#,#]])&[
\t\t\t\t\t\t\tCos[anglex]*rotationmatrix[[1]]+Sin[anglex]*rotationmatrix[[2]]]\

\t\t\t\t,
\t\t\t\t\tterminate = True;
\t\t\t\t];
\t\t\t\tintensity = intensity*attenuationfunction[raylength];
\t\t\t\tRay[
\t\t\t\t\tRayStart -> raystart,
\t\t\t\t\tRayEnd -> rayend,
\t\t\t\t\tRayTilt -> raytilt,
\t\t\t\t\tIntensity -> intensity,
\t\t\t\t\tRayLength -> raylength,
\t\t\t\t\tTerminateDeflection -> terminate
\t\t\t\t]
\t\t\t\t]
\t\t\t]],
\t\toptions}]
\t]
];\
\>", "Input",
  CellTags->"Bulk Diffusion with MonteCarlo Random Walk"]
}, Closed]],

Cell[CellGroupData[{

Cell["DiffuserBlock Component", "Subsubsection",
  CellTags->"Bulk Diffusion with MonteCarlo Random Walk"],

Cell["Clear[DiffuserBlock];", "Input",
  CellTags->"Bulk Diffusion with MonteCarlo Random Walk"],

Cell["\<\
DiffuserBlock[scatterangle_, scatterlength_, boundarydimensions_] \
:=
\tDiffuserBlock3[scatterangle, scatterlength, 0, boundarydimensions];\
\>", \
"Input",
  CellTags->"Bulk Diffusion with MonteCarlo Random Walk"],

Cell["\<\
DiffuserBlock[scatterangle_, scatterlength_, attenuation_, \
boundarydimensions_, options___] :=
Block[{opts, scalefactor=1000},
\topts = Flatten[{
\t\tComponentDescription -> 
\t\t\tComponentDescription[
\t\t\t\tDiffuserBlock[scatterangle, scatterlength, attenuation, \
boundarydimensions, options]
\t\t\t\t],
\t\toptions}];
\tResonate[
\t\t{\t
\t\t\tRefraction[
\t\t\t\tRemoveDeflection[
\t\t\t\t\tClearBoundary[boundarydimensions,opts]
\t\t\t\t]
\t\t\t,
\t\t\t\topts
\t\t\t]
\t\t,
\t\t\tMove[
\t\t\t\tBulkDiffusion[
\t\t\t\t\tRemoveDeflection[
\t\t\t\t\t\tClearBoundary[boundarydimensions-2*scatterlength/scalefactor, 
\t\t\t\t\t\t\tFlatten[{GraphicDesign->Off,opts}]]
\t\t\t\t\t]
\t\t\t\t,
\t\t\t\t\tscatterangle, scatterlength, attenuation, opts
\t\t\t\t]
\t\t\t,
\t\t\t\tscatterlength/scalefactor
\t\t\t]
\t\t}
\t,\t
\t\topts
\t]
];\
\>", "Input",
  CellTags->"Bulk Diffusion with MonteCarlo Random Walk"]
}, Closed]],

Cell[CellGroupData[{

Cell["Tests", "Subsubsection",
  CellTags->"Bulk Diffusion with MonteCarlo Random Walk"],

Cell[CellGroupData[{

Cell["diffusorblock = Move[DiffuserBlock[90, 1, 25],10]", "Input",
  CellTags->"Bulk Diffusion with MonteCarlo Random Walk"],

Cell[BoxData[
    TagBox[\(DiffuserBlock[90, 1, 0, 25]\),
      HoldForm]], "Output",
  CellTags->"Bulk Diffusion with MonteCarlo Random Walk"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
sys = TurboPlot[{SingleRay[], diffusorblock, Boundary[50]}, \
PlotType->TopView, RunningCommentary->TurboTrace];\
\>", "Input",
  CellTags->"Bulk Diffusion with MonteCarlo Random Walk"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0190476 0.5 0.0190476 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.69048 .7381 m
.69048 .2619 L
.69048 .2619 L
.69048 .7381 L
.69048 .7381 L
s
.69048 .2619 m
.21429 .2619 L
.21429 .2619 L
.69048 .2619 L
.69048 .2619 L
s
.21429 .2619 m
.21429 .7381 L
.21429 .7381 L
.21429 .2619 L
.21429 .2619 L
s
.21429 .7381 m
.69048 .7381 L
.69048 .7381 L
.21429 .7381 L
.21429 .7381 L
s
.69048 .2619 m
.69048 .7381 L
.21429 .7381 L
.21429 .2619 L
.69048 .2619 L
s
.69048 .7381 m
.69048 .2619 L
.21429 .2619 L
.21429 .7381 L
.69048 .7381 L
s
.97619 .97619 m
.97619 .02381 L
.97619 .02381 L
.97619 .97619 L
.97619 .97619 L
s
.97619 .02381 m
.02381 .02381 L
.02381 .02381 L
.97619 .02381 L
.97619 .02381 L
s
.02381 .02381 m
.02381 .97619 L
.02381 .97619 L
.02381 .02381 L
.02381 .02381 L
s
.02381 .97619 m
.97619 .97619 L
.97619 .97619 L
.02381 .97619 L
.02381 .97619 L
s
.97619 .02381 m
.97619 .97619 L
.02381 .97619 L
.02381 .02381 L
.97619 .02381 L
s
.97619 .97619 m
.97619 .02381 L
.02381 .02381 L
.02381 .97619 L
.97619 .97619 L
s
.039 .916 .04 r
.02381 .5 m
.21429 .5 L
s
0 0 0 r
2.5 Mabswid
.21429 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.21429 .5 m
.2143 .5 L
s
0 0 0 r
2.5 Mabswid
.2143 .5 Mdot
.039 .916 .04 r
.5 Mabswid
.2143 .5 m
.22373 .50253 L
s
0 0 0 r
2.5 Mabswid
.22373 .50253 Mdot
.039 .916 .04 r
.5 Mabswid
.22373 .50253 m
.23866 .50829 L
s
0 0 0 r
2.5 Mabswid
.23866 .50829 Mdot
.039 .916 .04 r
.5 Mabswid
.23866 .50829 m
.24222 .51507 L
s
0 0 0 r
2.5 Mabswid
.24222 .51507 Mdot
.039 .916 .04 r
.5 Mabswid
.24222 .51507 m
.24176 .51901 L
s
0 0 0 r
2.5 Mabswid
.24176 .51901 Mdot
.039 .916 .04 r
.5 Mabswid
.24176 .51901 m
.24931 .53277 L
s
0 0 0 r
2.5 Mabswid
.24931 .53277 Mdot
.039 .916 .04 r
.5 Mabswid
.24931 .53277 m
.25136 .53386 L
s
0 0 0 r
2.5 Mabswid
.25136 .53386 Mdot
.039 .916 .04 r
.5 Mabswid
.25136 .53386 m
.25438 .53827 L
s
0 0 0 r
2.5 Mabswid
.25438 .53827 Mdot
.039 .916 .04 r
.5 Mabswid
.25438 .53827 m
.26109 .54024 L
s
0 0 0 r
2.5 Mabswid
.26109 .54024 Mdot
.039 .916 .04 r
.5 Mabswid
.26109 .54024 m
.269 .54666 L
s
0 0 0 r
2.5 Mabswid
.269 .54666 Mdot
.039 .916 .04 r
.5 Mabswid
.269 .54666 m
.27276 .55372 L
s
0 0 0 r
2.5 Mabswid
.27276 .55372 Mdot
.039 .916 .04 r
.5 Mabswid
.27276 .55372 m
.27418 .56137 L
s
0 0 0 r
2.5 Mabswid
.27418 .56137 Mdot
.039 .916 .04 r
.5 Mabswid
.27418 .56137 m
.28162 .5668 L
s
0 0 0 r
2.5 Mabswid
.28162 .5668 Mdot
.039 .916 .04 r
.5 Mabswid
.28162 .5668 m
.29859 .56489 L
s
0 0 0 r
2.5 Mabswid
.29859 .56489 Mdot
.039 .916 .04 r
.5 Mabswid
.29859 .56489 m
.31062 .56259 L
s
0 0 0 r
2.5 Mabswid
.31062 .56259 Mdot
.039 .916 .04 r
.5 Mabswid
.31062 .56259 m
.31686 .55528 L
s
0 0 0 r
2.5 Mabswid
.31686 .55528 Mdot
.039 .916 .04 r
.5 Mabswid
.31686 .55528 m
.323 .54946 L
s
0 0 0 r
2.5 Mabswid
.323 .54946 Mdot
.039 .916 .04 r
.5 Mabswid
.323 .54946 m
.33596 .54909 L
s
0 0 0 r
2.5 Mabswid
.33596 .54909 Mdot
.039 .916 .04 r
.5 Mabswid
.33596 .54909 m
.34224 .54829 L
s
0 0 0 r
2.5 Mabswid
.34224 .54829 Mdot
.039 .916 .04 r
.5 Mabswid
.34224 .54829 m
.34838 .54348 L
s
0 0 0 r
2.5 Mabswid
.34838 .54348 Mdot
.039 .916 .04 r
.5 Mabswid
.34838 .54348 m
.36035 .52951 L
s
0 0 0 r
2.5 Mabswid
.36035 .52951 Mdot
.039 .916 .04 r
.5 Mabswid
.36035 .52951 m
.36917 .51538 L
s
0 0 0 r
2.5 Mabswid
.36917 .51538 Mdot
.039 .916 .04 r
.5 Mabswid
.36917 .51538 m
.37636 .50761 L
s
0 0 0 r
2.5 Mabswid
.37636 .50761 Mdot
.039 .916 .04 r
.5 Mabswid
.37636 .50761 m
.38434 .50329 L
s
0 0 0 r
2.5 Mabswid
.38434 .50329 Mdot
.039 .916 .04 r
.5 Mabswid
.38434 .50329 m
.38582 .50278 L
s
0 0 0 r
2.5 Mabswid
.38582 .50278 Mdot
.039 .916 .04 r
.5 Mabswid
.38582 .50278 m
.39685 .50223 L
s
0 0 0 r
2.5 Mabswid
.39685 .50223 Mdot
.039 .916 .04 r
.5 Mabswid
.39685 .50223 m
.40377 .49753 L
s
0 0 0 r
2.5 Mabswid
.40377 .49753 Mdot
.039 .916 .04 r
.5 Mabswid
.40377 .49753 m
.40525 .49686 L
s
0 0 0 r
2.5 Mabswid
.40525 .49686 Mdot
.039 .916 .04 r
.5 Mabswid
.40525 .49686 m
.42341 .49146 L
s
0 0 0 r
2.5 Mabswid
.42341 .49146 Mdot
.039 .916 .04 r
.5 Mabswid
.42341 .49146 m
.4311 .491 L
s
0 0 0 r
2.5 Mabswid
.4311 .491 Mdot
.039 .916 .04 r
.5 Mabswid
.4311 .491 m
.44156 .48361 L
s
0 0 0 r
2.5 Mabswid
.44156 .48361 Mdot
.039 .916 .04 r
.5 Mabswid
.44156 .48361 m
.45686 .47242 L
s
0 0 0 r
2.5 Mabswid
.45686 .47242 Mdot
.039 .916 .04 r
.5 Mabswid
.45686 .47242 m
.47003 .46969 L
s
0 0 0 r
2.5 Mabswid
.47003 .46969 Mdot
.039 .916 .04 r
.5 Mabswid
.47003 .46969 m
.47166 .46782 L
s
0 0 0 r
2.5 Mabswid
.47166 .46782 Mdot
.039 .916 .04 r
.5 Mabswid
.47166 .46782 m
.47217 .46481 L
s
0 0 0 r
2.5 Mabswid
.47217 .46481 Mdot
.039 .916 .04 r
.5 Mabswid
.47217 .46481 m
.47186 .45235 L
s
0 0 0 r
2.5 Mabswid
.47186 .45235 Mdot
.039 .916 .04 r
.5 Mabswid
.47186 .45235 m
.47195 .45067 L
s
0 0 0 r
2.5 Mabswid
.47195 .45067 Mdot
.039 .916 .04 r
.5 Mabswid
.47195 .45067 m
.47251 .44916 L
s
0 0 0 r
2.5 Mabswid
.47251 .44916 Mdot
.039 .916 .04 r
.5 Mabswid
.47251 .44916 m
.47493 .43704 L
s
0 0 0 r
2.5 Mabswid
.47493 .43704 Mdot
.039 .916 .04 r
.5 Mabswid
.47493 .43704 m
.46654 .41995 L
s
0 0 0 r
2.5 Mabswid
.46654 .41995 Mdot
.039 .916 .04 r
.5 Mabswid
.46654 .41995 m
.46698 .4075 L
s
0 0 0 r
2.5 Mabswid
.46698 .4075 Mdot
.039 .916 .04 r
.5 Mabswid
.46698 .4075 m
.46626 .396 L
s
0 0 0 r
2.5 Mabswid
.46626 .396 Mdot
.039 .916 .04 r
.5 Mabswid
.46626 .396 m
.46996 .37766 L
s
0 0 0 r
2.5 Mabswid
.46996 .37766 Mdot
.039 .916 .04 r
.5 Mabswid
.46996 .37766 m
.47908 .37047 L
s
0 0 0 r
2.5 Mabswid
.47908 .37047 Mdot
.039 .916 .04 r
.5 Mabswid
.47908 .37047 m
.48452 .37021 L
s
0 0 0 r
2.5 Mabswid
.48452 .37021 Mdot
.039 .916 .04 r
.5 Mabswid
.48452 .37021 m
.4926 .37485 L
s
0 0 0 r
2.5 Mabswid
.4926 .37485 Mdot
.039 .916 .04 r
.5 Mabswid
.4926 .37485 m
.4942 .37687 L
s
0 0 0 r
2.5 Mabswid
.4942 .37687 Mdot
.039 .916 .04 r
.5 Mabswid
.4942 .37687 m
.50432 .38914 L
s
0 0 0 r
2.5 Mabswid
.50432 .38914 Mdot
.039 .916 .04 r
.5 Mabswid
.50432 .38914 m
.50533 .38956 L
s
0 0 0 r
2.5 Mabswid
.50533 .38956 Mdot
.039 .916 .04 r
.5 Mabswid
.50533 .38956 m
.51481 .4005 L
s
0 0 0 r
2.5 Mabswid
.51481 .4005 Mdot
.039 .916 .04 r
.5 Mabswid
.51481 .4005 m
.51673 .40805 L
s
0 0 0 r
2.5 Mabswid
.51673 .40805 Mdot
.039 .916 .04 r
.5 Mabswid
.51673 .40805 m
.51563 .42249 L
s
0 0 0 r
2.5 Mabswid
.51563 .42249 Mdot
.039 .916 .04 r
.5 Mabswid
.51563 .42249 m
.50497 .43212 L
s
0 0 0 r
2.5 Mabswid
.50497 .43212 Mdot
.039 .916 .04 r
.5 Mabswid
.50497 .43212 m
.50353 .43493 L
s
0 0 0 r
2.5 Mabswid
.50353 .43493 Mdot
.039 .916 .04 r
.5 Mabswid
.50353 .43493 m
.50082 .44939 L
s
0 0 0 r
2.5 Mabswid
.50082 .44939 Mdot
.039 .916 .04 r
.5 Mabswid
.50082 .44939 m
.50184 .45993 L
s
0 0 0 r
2.5 Mabswid
.50184 .45993 Mdot
.039 .916 .04 r
.5 Mabswid
.50184 .45993 m
.50388 .46917 L
s
0 0 0 r
2.5 Mabswid
.50388 .46917 Mdot
.039 .916 .04 r
.5 Mabswid
.50388 .46917 m
.50429 .47057 L
s
0 0 0 r
2.5 Mabswid
.50429 .47057 Mdot
.039 .916 .04 r
.5 Mabswid
.50429 .47057 m
.50429 .47764 L
s
0 0 0 r
2.5 Mabswid
.50429 .47764 Mdot
.039 .916 .04 r
.5 Mabswid
.50429 .47764 m
.50119 .48104 L
s
0 0 0 r
2.5 Mabswid
.50119 .48104 Mdot
.039 .916 .04 r
.5 Mabswid
.50119 .48104 m
.49713 .48568 L
s
0 0 0 r
2.5 Mabswid
.49713 .48568 Mdot
.039 .916 .04 r
.5 Mabswid
.49713 .48568 m
.49515 .49464 L
s
0 0 0 r
2.5 Mabswid
.49515 .49464 Mdot
.039 .916 .04 r
.5 Mabswid
.49515 .49464 m
.48655 .5098 L
s
0 0 0 r
2.5 Mabswid
.48655 .5098 Mdot
.039 .916 .04 r
.5 Mabswid
.48655 .5098 m
.48025 .52201 L
s
0 0 0 r
2.5 Mabswid
.48025 .52201 Mdot
.039 .916 .04 r
.5 Mabswid
.48025 .52201 m
.47793 .52427 L
s
0 0 0 r
2.5 Mabswid
.47793 .52427 Mdot
.039 .916 .04 r
.5 Mabswid
.47793 .52427 m
.47435 .53443 L
s
0 0 0 r
2.5 Mabswid
.47435 .53443 Mdot
.039 .916 .04 r
.5 Mabswid
.47435 .53443 m
.47313 .54191 L
s
0 0 0 r
2.5 Mabswid
.47313 .54191 Mdot
.039 .916 .04 r
.5 Mabswid
.47313 .54191 m
.47287 .54218 L
s
0 0 0 r
2.5 Mabswid
.47287 .54218 Mdot
.039 .916 .04 r
.5 Mabswid
.47287 .54218 m
.45574 .54342 L
s
0 0 0 r
2.5 Mabswid
.45574 .54342 Mdot
.039 .916 .04 r
.5 Mabswid
.45574 .54342 m
.43808 .54669 L
s
0 0 0 r
2.5 Mabswid
.43808 .54669 Mdot
.039 .916 .04 r
.5 Mabswid
.43808 .54669 m
.42916 .55183 L
s
0 0 0 r
2.5 Mabswid
.42916 .55183 Mdot
.039 .916 .04 r
.5 Mabswid
.42916 .55183 m
.4179 .55936 L
s
0 0 0 r
2.5 Mabswid
.4179 .55936 Mdot
.039 .916 .04 r
.5 Mabswid
.4179 .55936 m
.41361 .55988 L
s
0 0 0 r
2.5 Mabswid
.41361 .55988 Mdot
.039 .916 .04 r
.5 Mabswid
.41361 .55988 m
.40956 .56196 L
s
0 0 0 r
2.5 Mabswid
.40956 .56196 Mdot
.039 .916 .04 r
.5 Mabswid
.40956 .56196 m
.4068 .56722 L
s
0 0 0 r
2.5 Mabswid
.4068 .56722 Mdot
.039 .916 .04 r
.5 Mabswid
.4068 .56722 m
.39875 .57292 L
s
0 0 0 r
2.5 Mabswid
.39875 .57292 Mdot
.039 .916 .04 r
.5 Mabswid
.39875 .57292 m
.39667 .57493 L
s
0 0 0 r
2.5 Mabswid
.39667 .57493 Mdot
.039 .916 .04 r
.5 Mabswid
.39667 .57493 m
.3819 .58546 L
s
0 0 0 r
2.5 Mabswid
.3819 .58546 Mdot
.039 .916 .04 r
.5 Mabswid
.3819 .58546 m
.37921 .59957 L
s
0 0 0 r
2.5 Mabswid
.37921 .59957 Mdot
.039 .916 .04 r
.5 Mabswid
.37921 .59957 m
.37035 .61518 L
s
0 0 0 r
2.5 Mabswid
.37035 .61518 Mdot
.039 .916 .04 r
.5 Mabswid
.37035 .61518 m
.37342 .63112 L
s
0 0 0 r
2.5 Mabswid
.37342 .63112 Mdot
.039 .916 .04 r
.5 Mabswid
.37342 .63112 m
.38317 .64748 L
s
0 0 0 r
2.5 Mabswid
.38317 .64748 Mdot
.039 .916 .04 r
.5 Mabswid
.38317 .64748 m
.3839 .65357 L
s
0 0 0 r
2.5 Mabswid
.3839 .65357 Mdot
.039 .916 .04 r
.5 Mabswid
.3839 .65357 m
.38176 .65884 L
s
0 0 0 r
2.5 Mabswid
.38176 .65884 Mdot
.039 .916 .04 r
.5 Mabswid
.38176 .65884 m
.37995 .65971 L
s
0 0 0 r
2.5 Mabswid
.37995 .65971 Mdot
.039 .916 .04 r
.5 Mabswid
.37995 .65971 m
.37872 .66019 L
s
0 0 0 r
2.5 Mabswid
.37872 .66019 Mdot
.039 .916 .04 r
.5 Mabswid
.37872 .66019 m
.36389 .65737 L
s
0 0 0 r
2.5 Mabswid
.36389 .65737 Mdot
.039 .916 .04 r
.5 Mabswid
.36389 .65737 m
.35506 .65168 L
s
0 0 0 r
2.5 Mabswid
.35506 .65168 Mdot
.039 .916 .04 r
.5 Mabswid
.35506 .65168 m
.3442 .64568 L
s
0 0 0 r
2.5 Mabswid
.3442 .64568 Mdot
.039 .916 .04 r
.5 Mabswid
.3442 .64568 m
.3328 .64618 L
s
0 0 0 r
2.5 Mabswid
.3328 .64618 Mdot
.039 .916 .04 r
.5 Mabswid
.3328 .64618 m
.31586 .64849 L
s
0 0 0 r
2.5 Mabswid
.31586 .64849 Mdot
.039 .916 .04 r
.5 Mabswid
.31586 .64849 m
.30367 .65129 L
s
0 0 0 r
2.5 Mabswid
.30367 .65129 Mdot
.039 .916 .04 r
.5 Mabswid
.30367 .65129 m
.3027 .6517 L
s
0 0 0 r
2.5 Mabswid
.3027 .6517 Mdot
.039 .916 .04 r
.5 Mabswid
.3027 .6517 m
.29517 .6617 L
s
0 0 0 r
2.5 Mabswid
.29517 .6617 Mdot
.039 .916 .04 r
.5 Mabswid
.29517 .6617 m
.28475 .67099 L
s
0 0 0 r
2.5 Mabswid
.28475 .67099 Mdot
.039 .916 .04 r
.5 Mabswid
.28475 .67099 m
.28082 .67682 L
s
0 0 0 r
2.5 Mabswid
.28082 .67682 Mdot
.039 .916 .04 r
.5 Mabswid
.28082 .67682 m
.27177 .68492 L
s
0 0 0 r
2.5 Mabswid
.27177 .68492 Mdot
.039 .916 .04 r
.5 Mabswid
.27177 .68492 m
.26608 .68647 L
s
0 0 0 r
2.5 Mabswid
.26608 .68647 Mdot
.039 .916 .04 r
.5 Mabswid
.26608 .68647 m
.25032 .68325 L
s
0 0 0 r
2.5 Mabswid
.25032 .68325 Mdot
.039 .916 .04 r
.5 Mabswid
.25032 .68325 m
.23768 .69024 L
s
0 0 0 r
2.5 Mabswid
.23768 .69024 Mdot
.039 .916 .04 r
.5 Mabswid
.23768 .69024 m
.23486 .6929 L
s
0 0 0 r
2.5 Mabswid
.23486 .6929 Mdot
.039 .916 .04 r
.5 Mabswid
.23486 .6929 m
.23167 .6933 L
s
0 0 0 r
2.5 Mabswid
.23167 .6933 Mdot
.039 .916 .04 r
.5 Mabswid
.23167 .6933 m
.22656 .69051 L
s
0 0 0 r
2.5 Mabswid
.22656 .69051 Mdot
.039 .916 .04 r
.5 Mabswid
.22656 .69051 m
.2143 .68483 L
s
0 0 0 r
2.5 Mabswid
.2143 .68483 Mdot
.039 .916 .04 r
.5 Mabswid
.2143 .68483 m
.21429 .68483 L
s
0 0 0 r
2.5 Mabswid
.21429 .68483 Mdot
.039 .916 .04 r
.5 Mabswid
.21429 .68483 m
.02381 .52692 L
s
0 0 0 r
2.5 Mabswid
.02381 .52692 Mdot
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`001P3ooooo000001@000001`3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oo
oa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo03@0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo03@0ooooRP00001A0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0QP3oool00`000000
oooo0?ooo`1?0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03@0oooo
00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?oo
o`1?0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool0QP3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo03@0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`1?0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3o
ool0QP3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0QP3o
ool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo03@0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0QP3oool00`00
0000oooo0?ooo`1?0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03@0
oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0QP3oool00`000000oooo
0?ooo`1?0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0QP3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`1?
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03@0oooo00<000000?oo
o`3oool0QP3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo03@0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`1?0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0
QP3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo03@0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`1?0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0QP3oool0
0`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
03@0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0QP3oool00`000000
oooo0?ooo`1?0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03@0oooo
00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?oo
o`1?0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool0QP3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo03@0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`1?0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3o
ool0QP3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0QP3o
ool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo03@0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0BP3oool20000
03X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`0d0?ooo`030000003oool0oooo04P0oooo00<0000000WZ2P0000000P09jPXi0?ooo`03
0000003oool0oooo04l0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
=03oool00`000000oooo0?ooo`170?ooo`0300WZ2P00000000000080oooo0`00000g0?ooo`030000
003oool0oooo04l0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`160?ooo`0300WZ2P000000oooo00<0oooo00<0000000WZ2P000000=`3o
ool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo03@0oooo00<000000?ooo`3oool0AP3oool2000000H0oooo00<02NX:0?ooo`3oool0=@3oool0
0`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
03@0oooo00<000000?ooo`3oool0AP3oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0oooo
03@0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`0d0?ooo`030000003oool0oooo04D0oooo00<02NX:0?ooo`3oool01`3oool200000003
00WZ2P3oool0oooo0380oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`050?ooo`00
1P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo04D0oooo00<02NX:0?ooo`3oool0
1`3oool20000000300WZ2P3oool0oooo0380oooo00<000000?ooo`3oool0C`3oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo04D0oooo00<0
2NX:0000003oool02P3oool00`09jPX0oooo0?ooo`0a0?ooo`030000003oool0oooo04l0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`15
0?ooo`800000303oool00`09jPX000000?ooo`0`0?ooo`030000003oool0oooo04l0oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`160?oo
o`0300WZ2P3oool0oooo00X0oooo00<02NX:0000003oool0<03oool00`000000oooo0?ooo`1?0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3o
ool0A@3oool00`0000002NX:0?ooo`0;0?ooo`800000<@3oool00`000000oooo0?ooo`1?0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0
A@3oool2000000`0oooo00<0000000WZ2P3oool0<03oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0AP3o
ool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo02l0oooo00<000000?ooo`3oool0C`3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo04D0oooo00<02NX:0?ooo`3oool0303oool00`09jPX0oooo0?ooo`0_0?ooo`030000003oool0
oooo04l0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0=03oool00`00
0000oooo0?ooo`150?ooo`0300WZ2P000000oooo00/0oooo00<02NX:0?ooo`3oool0<03oool00`00
0000oooo0?ooo`1?0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03@0
oooo00<000000?ooo`3oool0A@3oool2000000`0oooo00<02NX:0000003oool0<03oool00`000000
oooo0?ooo`1?0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03@0oooo
00<000000?ooo`3oool0AP3oool00`09jPX0oooo0?ooo`090?ooo`0300WZ2P00000000000340oooo
00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo04L0oooo00<02NX:0?ooo`3oool01P3oool2000003@0oooo00<0
00000?ooo`3oool0C`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0d
0?ooo`030000003oool0oooo04L0oooo00<02NX:0?ooo`3oool01@3oool00`0000002NX:0000000d
0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0=03oool00`000000oooo0?ooo`170?ooo`0300000009jPX0oooo00D0oooo00<0000000WZ
2P3oool0=03oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00D0oooo00060?ooo`03
0000003oool0oooo03@0oooo00<000000?ooo`3oool0A`3oool2000000L0oooo00<02NX:0?ooo`3o
ool0<`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0A`3oool00`09jPX0oooo0?ooo`050?ooo`0300WZ
2P3oool0oooo03@0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`050?ooo`001P3o
ool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo04H0oooo00<0000000WZ2P3oool01@3o
ool00`0000002NX:0?ooo`0e0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`160?ooo`8000001P3oool0
0`0000002NX:0?ooo`0e0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`160?ooo`800000203oool00`09
jPX0oooo0?ooo`0c0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`170?ooo`0300WZ2P3oool0oooo00D0
oooo00<0000000WZ2P3oool0=03oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00D0
oooo00060?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0A`3oool00`09jPX0oooo
0?ooo`050?ooo`0300000009jPX0oooo03@0oooo00<000000?ooo`3oool0C`3oool00`000000oooo
0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo04H0oooo00<0
000000WZ2P3oool01`3oool00`09jPX0oooo0?ooo`0c0?ooo`030000003oool0oooo04l0oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`15
0?ooo`0300WZ2P000000000000L0oooo0P00000e0?ooo`030000003oool0oooo04l0oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`120?oo
o`0400000009jPX02NX:0?ooo`8000001`3oool00`0000002NX:0?ooo`0d0?ooo`030000003oool0
oooo04l0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0=03oool00`00
0000oooo0?ooo`100?ooo`802NX:0P00000;0?ooo`800000=@3oool00`000000oooo0?ooo`1?0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3o
ool0?`3oool00`09jPX0oooo0?ooo`0=0?ooo`800000=@3oool00`000000oooo0?ooo`1?0?ooo`03
0000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0
?@3oool00`0000002NX:0?ooo`0?0?ooo`0300WZ2P000000oooo03@0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo03`0oooo00<02NX:0000000000003P3oool00`0000002NX:0?ooo`0f0?ooo`030000003o
ool0oooo04l0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0=03oool0
0`000000oooo0?ooo`0h0?ooo`<0000000<02NX:0?ooo`3oool03`3oool00`0000002NX:0?ooo`0f
0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?oo
o`3oool0=03oool00`000000oooo0?ooo`0g0?ooo`0300WZ2P0000002NX:008000004@3oool00`00
00002NX:0?ooo`0f0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool01@3oool000H0
oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0c0?ooo`0400000009jPX02NX:00WZ
2QH0oooo00<0000000WZ2P3oool0=P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo
00D0oooo00060?ooocH02NX:00<0000000WZ2P09jPX00P00000`0?ooo`0400000009jPX000000000
01P0oooo00<02NX:0?ooo`3oool0=P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo03<0oooo0P0000000`3oool0000000WZ2P0200WZ2RX0
oooo00<0000000WZ2P09jPX00P09jPX00`000000oooo0?ooo`0G0?ooo`0300WZ2P3oool0oooo03L0
oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo
0?ooo`0d0?ooo`030000003oool0oooo00<0oooo00<0000000WZ2P3oool09@3oool0100000002NX:
00000000000M0?ooo`0300WZ2P3oool0oooo03L0oooo00<000000?ooo`3oool0C`3oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00<0oooo
00<0000000WZ2P3oool0903oool00`09jPX000000000000M0?ooo`0300000009jPX0oooo03T0oooo
00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo00@0oooo00<0000000WZ2P3oool08P3oool00`09jPX000000?oo
o`0N0?ooo`0300000009jPX0oooo03T0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00@0oooo00<00000
00WZ2P3oool08P3oool2000001l0oooo00<02NX:0?ooo`3oool0>@3oool00`000000oooo0?ooo`1?
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03@0oooo00<000000?oo
o`3oool0103oool00`0000002NX:0?ooo`0Q0?ooo`0300WZ2P3oool0oooo01h0oooo00<02NX:0000
003oool0>P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00D0oooo00060?ooo`80
0000=@3oool00`000000oooo0?ooo`060?ooo`0300WZ2P3oool0oooo01l0oooo00<02NX:0?ooo`3o
ool07@3oool00`0000002NX:0000000k0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3o
ool01@3oool000H0oooo0P00000e0?ooo`030000003oool0oooo00H0oooo00<02NX:0?ooo`3oool0
7@3oool00`0000002NX:0?ooo`0O0?ooo`0300000009jPX0oooo03/0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo00WZ2P0d0?ooo`030000003o
ool0oooo00H0oooo0`00000M0?ooo`800000803oool00`09jPX0oooo0?ooo`0k0?ooo`030000003o
ool0oooo04l0oooo00<000000?ooo`3oool01@3oool000H0oooo00@000000?ooo`3oool02NX:<`3o
ool00`000000oooo0?ooo`060?ooo`80000000<02NX:0?ooo`3oool06P3oool00`09jPX0oooo0?oo
o`0O0?ooo`0300000009jPX0oooo03`0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?oo
o`050?ooo`001P3oool01@000000oooo0?ooo`3oool02NX:0380oooo00<000000?ooo`3oool0203o
ool0100000002NX:00000000000H0?ooo`0300WZ2P3oool0oooo0200oooo00<0000000WZ2P3oool0
?03oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0080oooo0P09jPX`0?ooo`030000003oool0oooo00P0oooo0P00000300WZ2QH0oooo00<0
2NX:0000003oool06P3oool300WZ2P0300000009jPX02NX:00802NX:00<000000?ooo`3oool0>`3o
ool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo00@0oooo00<02NX:0?ooo`3oool0;@3oool00`000000oooo0?ooo`0<0?ooo`0300000009jPX0
oooo01@0oooo0P00000G0?ooo`0400000009jPX02NX:00WZ2P80oooo0P0000020?ooo`<00000?@3o
ool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo00D0oooo00<02NX:0?ooo`3oool0;03oool00`000000oooo0?ooo`0<0?ooo`0300000009jPX0
oooo00`0oooo00P0000000WZ2P09jPX02NX:00000009jPX0000000WZ2QT0oooo00<02NX:0000003o
ool0A`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo00H0oooo00<02NX:0?ooo`3oool0:`3oool00`000000oooo0?ooo`0=0?ooo`030000
0009jPX0oooo00/0oooo0P0000020?ooo`@000005`3oool200WZ2TX0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`070?ooo`0300WZ2P3o
ool0oooo02X0oooo00<000000?ooo`3oool03@3oool00`0000002NX:0?ooo`0:0?ooo`0300WZ2P00
0000oooo01/0oooo0P09jPX2000004X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`080?ooo`802NX::P3oool00`000000oooo0?ooo`0=
0?ooo`8000002`3oool2000001T0oooo00@0000000WZ2P09jPX00000C@3oool00`000000oooo0?oo
o`1?0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo00X0oooo00<02NX:
0?ooo`3oool09`3oool00`000000oooo0?ooo`0=0?ooo`0300000009jPX02NX:00@0oooo0P000000
103oool02NX:00000009jPXJ0?ooo`0300000009jPX0000000800000C@3oool00`000000oooo0?oo
o`1?0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo00/0oooo00<02NX:
0?ooo`3oool09P3oool00`000000oooo0?ooo`0@0?ooo`@02NX:00@0000000WZ2P09jPX0oooo0P00
000J0?ooo`0300WZ2P000000oooo04l0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?oo
o`050?ooo`001P3oool00`000000oooo0?ooo`0<0?ooo`0300WZ2P3oool0oooo02D0oooo00<00000
0?ooo`3oool0403oool200000240oooo00<02NX:000000000000D03oool00`000000oooo0?ooo`1?
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo00d0oooo0P09jPXU0?oo
o`030000003oool0oooo0340oooo0P00001C0?ooo`030000003oool0oooo04l0oooo00<000000?oo
o`3oool01@3oool000H0oooo00<000000?ooo`3oool03`3oool00`09jPX0oooo0?ooo`0R0?ooo`03
0000003oool0oooo0300oooo0P09jPX00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo04l0
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0403oool00`09jPX0oooo
0?ooo`0Q0?ooo`030000003oool0oooo02l0oooo00<02NX:0?ooo`3oool0E03oool00`000000oooo
0?ooo`1?0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0140oooo00<0
2NX:0?ooo`3oool0803oool00`000000oooo0?ooo`0/0?ooo`80000000<02NX:0?ooo`3oool0E@3o
ool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo0180oooo00<02NX:0?ooo`3oool07`3oool00`000000oooo0?ooo`0/0?ooo`0300000009jPX0
oooo05L0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`0C0?ooo`802NX:7`3oool00`000000oooo0?ooo`0]0?ooo`0300WZ2P3oool0oooo
05H0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`0E0?ooo`0300WZ2P3oool0oooo01`0oooo00<000000?ooo`3oool0;@3oool00`09jPX0
oooo0?ooo`1F0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool05P3oool00`09jPX0oooo0?ooo`0K0?ooo`030000003oool0oooo02`0oooo
0P00001H0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool01@3oool000H0oooo00<0
00000?ooo`3oool05`3oool00`09jPX0oooo0?ooo`0J0?ooo`030000003oool0oooo02`0oooo00<0
2NX:0000003oool0E`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo01P0oooo0P09jPXJ0?ooo`030000003oool0oooo02`0oooo00<02NX:
0?ooo`3oool0E`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo01X0oooo00<02NX:0?ooo`3oool05`3oool00`000000oooo0?ooo`0[0?oo
o`0300WZ2P3oool0oooo05P0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`0K0?ooo`0300WZ2P3oool0oooo01H0oooo00<000000?ooo`3o
ool0:`3oool00`09jPX0oooo0?ooo`1H0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0703oool00`09jPX0oooo0?ooo`0E0?ooo`030000
003oool0oooo02T0oooo00<0000000WZ2P3oool0FP3oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo01d0oooo00<02NX:0?ooo`3oool0503o
ool00`000000oooo0?ooo`0Y0?ooo`0300000009jPX0oooo05X0oooo00<000000?ooo`3oool0C`3o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0N0?ooo`802NX:503oool0
0`000000oooo0?ooo`0Z0?ooo`0300WZ2P3oool0oooo05T0oooo00<000000?ooo`3oool0C`3oool0
0`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0P0?ooo`0300WZ2P3oool0oooo
0140oooo00<000000?ooo`3oool0:`3oool00`09jPX0oooo0?ooo`1H0?ooo`030000003oool0oooo
04l0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool08@3oool00`09jPX0
oooo0?ooo`0@0?ooo`030000003oool0oooo02X0oooo0P00001J0?ooo`030000003oool0oooo04l0
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool08P3oool00`09jPX0oooo
0?ooo`0?0?ooo`030000003oool0oooo02X0oooo00<0000000WZ2P3oool0F@3oool00`000000oooo
0?ooo`1?0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo02<0oooo0P09
jPX?0?ooo`030000003oool0oooo02/0oooo00<02NX:0?ooo`3oool0F03oool00`000000oooo0?oo
o`1?0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo02D0oooo00<02NX:
0?ooo`3oool0303oool00`000000oooo0?ooo`0/0?ooo`0300WZ2P3oool0oooo05L0oooo00<00000
0?ooo`3oool0C`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0V0?oo
o`0300WZ2P3oool0oooo00/0oooo00<000000?ooo`3oool0;03oool00`09jPX0oooo0?ooo`1G0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool09`3oool00`09jPX0oooo0?ooo`0:0?ooo`030000003oool0oooo01T0oooo0P0000020?ooo`H0
2NX:00<000000?ooo`3oool01`3oool00`09jPX000000?ooo`1F0?ooo`030000003oool0oooo04l0
oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0:03oool00`09jPX0oooo
0?ooo`090?ooo`030000003oool0oooo01H0oooo0P00000500WZ2P030?ooo`00000000000080oooo
0P0000000`09jPX00000000000060?ooo`0300WZ2P000000oooo05H0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0Y0?ooo`802NX:2@3o
ool00`000000oooo0?ooo`0F0?ooo`0300WZ2P000000oooo00`0oooo00<02NX:00000009jPX01@3o
ool00`0000002NX:0?ooo`1F0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool01@3o
ool000H0oooo00<000000?ooo`3oool0:`3oool00`09jPX0oooo0?ooo`060?ooo`030000003oool0
oooo01D0oooo00<02NX:0?ooo`3oool03`3oool01@0000002NX:00WZ2P09jPX0oooo0080000000<0
2NX:0?ooo`3oool0E@3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo02`0oooo00<02NX:0?ooo`3oool01@3oool00`000000oooo0?ooo`0C
0?ooo`0300000009jPX0oooo0140oooo0P0000020?ooo`<02NX:F03oool00`000000oooo0?ooo`1?
0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo02d0oooo00<02NX:0?oo
o`3oool0103oool00`000000oooo0?ooo`0C0?ooo`0300WZ2P000000oooo01D0oooo0`00001H0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0;P3oool200WZ2P@0oooo00<000000?ooo`3oool04P3oool00`09jPX0oooo0?ooo`1a0?ooo`03
0000003oool0oooo04l0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
<03oool01@09jPX0oooo0?ooo`3oool000000180oooo00<0000000WZ2P3oool0L`3oool00`000000
oooo0?ooo`1?0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0340oooo
00@02NX:0?ooo`3oool000004@3oool20000000300WZ2P3oool0oooo0780oooo00<000000?ooo`3o
ool0C`3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`0b0?ooo`0300WZ
2P3oool000000140oooo00<0000000WZ2P3oool0M03oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03<0oooo00<02NX:0000003oool0203o
ool2000000H0oooo00<02NX:0?ooo`3oool0M03oool00`000000oooo0?ooo`1?0?ooo`030000003o
ool0oooo00D0oooo00060?ooo`030000003oool0oooo03<0oooo00<0000000WZ2P09jPX01`3oool2
00WZ2P0300000009jPX02NX:008000000P09jPYg0?ooo`030000003oool0oooo04l0oooo00<00000
0?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0<`3oool2000000050?ooo`09jPX02NX:
0000003oool00P0000000`09jPX0oooo0?ooo`030?ooo`802NX:0P00001g0?ooo`030000003oool0
oooo04l0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0=03oool01000
0000oooo0?ooo`00000400WZ2X40oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`05
0?ooo`001P3oool00`000000oooo0?ooo`0d0?ooo`040000003oool0oooo0?ooo`<00000PP3oool0
0`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo
03@0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo
00D0oooo00060?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0QP3oool00`000000
oooo0?ooo`1?0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03@0oooo
00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?oo
o`1?0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool0QP3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00D0oooo00060?oo
o`030000003oool0oooo03@0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`1?0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3o
ool0QP3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0QP3o
ool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo03@0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0QP3oool00`00
0000oooo0?ooo`1?0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo03@0
ooooRP00001A0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo
403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o
0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo
403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o
0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo
403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o
0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo
403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o
0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?oo
o`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000
oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool0
1@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo0006
0?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool00`00
0000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo
403oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<0
00000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0
oooo00D0oooo00060?ooo`030000003oool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?oo
o`001P3oool00`000000oooo0?ooo`3o0?oooa00oooo00<000000?ooo`3oool01@3oool000H0oooo
00<000000?ooo`3oool0o`3oool@0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003o
ool0oooo0?l0oooo403oool00`000000oooo0?ooo`050?ooo`001P3oool200000?l0oooo4@3oool0
0`000000oooo0?ooo`050?ooo`001P3ooooo000001@000001`3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.25026, -26.2503, 0.182929, \
0.182929}},
  CellTags->"Bulk Diffusion with MonteCarlo Random Walk"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
TurboPlot[LineOfRays[10,NumberOfRays->20],sys,PlotType->TopView];\
\
\>", "Input",
  CellTags->"Bulk Diffusion with MonteCarlo Random Walk"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0190476 0.5 0.0190476 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.69048 .7381 m
.69048 .2619 L
.69048 .2619 L
.69048 .7381 L
.69048 .7381 L
s
.69048 .2619 m
.21429 .2619 L
.21429 .2619 L
.69048 .2619 L
.69048 .2619 L
s
.21429 .2619 m
.21429 .7381 L
.21429 .7381 L
.21429 .2619 L
.21429 .2619 L
s
.21429 .7381 m
.69048 .7381 L
.69048 .7381 L
.21429 .7381 L
.21429 .7381 L
s
.69048 .2619 m
.69048 .7381 L
.21429 .7381 L
.21429 .2619 L
.69048 .2619 L
s
.69048 .7381 m
.69048 .2619 L
.21429 .2619 L
.21429 .7381 L
.69048 .7381 L
s
.97619 .97619 m
.97619 .02381 L
.97619 .02381 L
.97619 .97619 L
.97619 .97619 L
s
.97619 .02381 m
.02381 .02381 L
.02381 .02381 L
.97619 .02381 L
.97619 .02381 L
s
.02381 .02381 m
.02381 .97619 L
.02381 .97619 L
.02381 .02381 L
.02381 .02381 L
s
.02381 .97619 m
.97619 .97619 L
.97619 .97619 L
.02381 .97619 L
.02381 .97619 L
s
.97619 .02381 m
.97619 .97619 L
.02381 .97619 L
.02381 .02381 L
.97619 .02381 L
s
.97619 .97619 m
.97619 .02381 L
.02381 .02381 L
.02381 .97619 L
.97619 .97619 L
s
.039 .916 .04 r
.02381 .40476 m
.21429 .40476 L
s
0 0 0 r
2.5 Mabswid
.21429 .40476 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .41479 m
.21429 .41479 L
s
0 0 0 r
2.5 Mabswid
.21429 .41479 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .42481 m
.21429 .42481 L
s
0 0 0 r
2.5 Mabswid
.21429 .42481 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .43484 m
.21429 .43484 L
s
0 0 0 r
2.5 Mabswid
.21429 .43484 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .44486 m
.21429 .44486 L
s
0 0 0 r
2.5 Mabswid
.21429 .44486 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .45489 m
.21429 .45489 L
s
0 0 0 r
2.5 Mabswid
.21429 .45489 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .46491 m
.21429 .46491 L
s
0 0 0 r
2.5 Mabswid
.21429 .46491 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .47494 m
.21429 .47494 L
s
0 0 0 r
2.5 Mabswid
.21429 .47494 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .48496 m
.21429 .48496 L
s
0 0 0 r
2.5 Mabswid
.21429 .48496 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .49499 m
.21429 .49499 L
s
0 0 0 r
2.5 Mabswid
.21429 .49499 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .50501 m
.21429 .50501 L
s
0 0 0 r
2.5 Mabswid
.21429 .50501 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .51504 m
.21429 .51504 L
s
0 0 0 r
2.5 Mabswid
.21429 .51504 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .52506 m
.21429 .52506 L
s
0 0 0 r
2.5 Mabswid
.21429 .52506 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .53509 m
.21429 .53509 L
s
0 0 0 r
2.5 Mabswid
.21429 .53509 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .54511 m
.21429 .54511 L
s
0 0 0 r
2.5 Mabswid
.21429 .54511 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .55514 m
.21429 .55514 L
s
0 0 0 r
2.5 Mabswid
.21429 .55514 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .56516 m
.21429 .56516 L
s
0 0 0 r
2.5 Mabswid
.21429 .56516 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .57519 m
.21429 .57519 L
s
0 0 0 r
2.5 Mabswid
.21429 .57519 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .58521 m
.21429 .58521 L
s
0 0 0 r
2.5 Mabswid
.21429 .58521 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .59524 m
.21429 .59524 L
s
0 0 0 r
2.5 Mabswid
.21429 .59524 Mdot
.039 .916 .04 r
.5 Mabswid
.21429 .40476 m
.2143 .40476 L
s
0 0 0 r
2.5 Mabswid
.2143 .40476 Mdot
.039 .916 .04 r
.5 Mabswid
.21429 .41479 m
.2143 .41479 L
s
0 0 0 r
2.5 Mabswid
.2143 .41479 Mdot
.039 .916 .04 r
.5 Mabswid
.21429 .42481 m
.2143 .42481 L
s
0 0 0 r
2.5 Mabswid
.2143 .42481 Mdot
.039 .916 .04 r
.5 Mabswid
.21429 .43484 m
.2143 .43484 L
s
0 0 0 r
2.5 Mabswid
.2143 .43484 Mdot
.039 .916 .04 r
.5 Mabswid
.21429 .44486 m
.2143 .44486 L
s
0 0 0 r
2.5 Mabswid
.2143 .44486 Mdot
.039 .916 .04 r
.5 Mabswid
.21429 .45489 m
.2143 .45489 L
s
0 0 0 r
2.5 Mabswid
.2143 .45489 Mdot
.039 .916 .04 r
.5 Mabswid
.21429 .46491 m
.2143 .46491 L
s
0 0 0 r
2.5 Mabswid
.2143 .46491 Mdot
.039 .916 .04 r
.5 Mabswid
.21429 .47494 m
.2143 .47494 L
s
0 0 0 r
2.5 Mabswid
.2143 .47494 Mdot
.039 .916 .04 r
.5 Mabswid
.21429 .48496 m
.2143 .48496 L
s
0 0 0 r
2.5 Mabswid
.2143 .48496 Mdot
.039 .916 .04 r
.5 Mabswid
.21429 .49499 m
.2143 .49499 L
s
0 0 0 r
2.5 Mabswid
.2143 .49499 Mdot
.039 .916 .04 r
.5 Mabswid
.21429 .50501 m
.2143 .50501 L
s
0 0 0 r
2.5 Mabswid
.2143 .50501 Mdot
.039 .916 .04 r
.5 Mabswid
.21429 .51504 m
.2143 .51504 L
s
0 0 0 r
2.5 Mabswid
.2143 .51504 Mdot
.039 .916 .04 r
.5 Mabswid
.21429 .52506 m
.2143 .52506 L
s
0 0 0 r
2.5 Mabswid
.2143 .52506 Mdot
.039 .916 .04 r
.5 Mabswid
.21429 .53509 m
.2143 .53509 L
s
0 0 0 r
2.5 Mabswid
.2143 .53509 Mdot
.039 .916 .04 r
.5 Mabswid
.21429 .54511 m
.2143 .54511 L
s
0 0 0 r
2.5 Mabswid
.2143 .54511 Mdot
.039 .916 .04 r
.5 Mabswid
.21429 .55514 m
.2143 .55514 L
s
0 0 0 r
2.5 Mabswid
.2143 .55514 Mdot
.039 .916 .04 r
.5 Mabswid
.21429 .56516 m
.2143 .56516 L
s
0 0 0 r
2.5 Mabswid
.2143 .56516 Mdot
.039 .916 .04 r
.5 Mabswid
.21429 .57519 m
.2143 .57519 L
s
0 0 0 r
2.5 Mabswid
.2143 .57519 Mdot
.039 .916 .04 r
.5 Mabswid
.21429 .58521 m
.2143 .58521 L
s
0 0 0 r
2.5 Mabswid
.2143 .58521 Mdot
.039 .916 .04 r
.5 Mabswid
.21429 .59524 m
.2143 .59524 L
s
0 0 0 r
2.5 Mabswid
.2143 .59524 Mdot
.039 .916 .04 r
.5 Mabswid
.2143 .40476 m
.2196 .40594 L
s
0 0 0 r
2.5 Mabswid
.2196 .40594 Mdot
.039 .916 .04 r
.5 Mabswid
.2143 .41479 m
.23193 .41125 L
s
0 0 0 r
2.5 Mabswid
.23193 .41125 Mdot
.039 .916 .04 r
.5 Mabswid
.2143 .42481 m
.22387 .42423 L
s
0 0 0 r
2.5 Mabswid
.22387 .42423 Mdot
.039 .916 .04 r
.5 Mabswid
.2143 .43484 m
.22412 .43296 L
s
0 0 0 r
2.5 Mabswid
.22412 .43296 Mdot
.039 .916 .04 r
.5 Mabswid
.2143 .44486 m
.2197 .44363 L
s
0 0 0 r
2.5 Mabswid
.2197 .44363 Mdot
.039 .916 .04 r
.5 Mabswid
.2143 .45489 m
.22824 .4536 L
s
0 0 0 r
2.5 Mabswid
.22824 .4536 Mdot
.039 .916 .04 r
.5 Mabswid
.2143 .46491 m
.21472 .46501 L
s
0 0 0 r
2.5 Mabswid
.21472 .46501 Mdot
.039 .916 .04 r
.5 Mabswid
.2143 .47494 m
.2268 .47732 L
s
0 0 0 r
2.5 Mabswid
.2268 .47732 Mdot
.039 .916 .04 r
.5 Mabswid
.2143 .48496 m
.21789 .48431 L
s
0 0 0 r
2.5 Mabswid
.21789 .48431 Mdot
.039 .916 .04 r
.5 Mabswid
.2143 .49499 m
.21498 .49476 L
s
0 0 0 r
2.5 Mabswid
.21498 .49476 Mdot
.039 .916 .04 r
.5 Mabswid
.2143 .50501 m
.21804 .50369 L
s
0 0 0 r
2.5 Mabswid
.21804 .50369 Mdot
.039 .916 .04 r
.5 Mabswid
.2143 .51504 m
.22842 .5129 L
s
0 0 0 r
2.5 Mabswid
.22842 .5129 Mdot
.039 .916 .04 r
.5 Mabswid
.2143 .52506 m
.2313 .52956 L
s
0 0 0 r
2.5 Mabswid
.2313 .52956 Mdot
.039 .916 .04 r
.5 Mabswid
.2143 .53509 m
.22948 .5328 L
s
0 0 0 r
2.5 Mabswid
.22948 .5328 Mdot
.039 .916 .04 r
.5 Mabswid
.2143 .54511 m
.22245 .54599 L
s
0 0 0 r
2.5 Mabswid
.22245 .54599 Mdot
.039 .916 .04 r
.5 Mabswid
.2143 .55514 m
.21984 .555 L
s
0 0 0 r
2.5 Mabswid
.21984 .555 Mdot
.039 .916 .04 r
.5 Mabswid
.2143 .56516 m
.21695 .56622 L
s
0 0 0 r
2.5 Mabswid
.21695 .56622 Mdot
.039 .916 .04 r
.5 Mabswid
.2143 .57519 m
.22466 .57741 L
s
0 0 0 r
2.5 Mabswid
.22466 .57741 Mdot
.039 .916 .04 r
.5 Mabswid
.2143 .58521 m
.21687 .58477 L
s
0 0 0 r
2.5 Mabswid
.21687 .58477 Mdot
.039 .916 .04 r
.5 Mabswid
.2143 .59524 m
.23091 .59844 L
s
0 0 0 r
2.5 Mabswid
.23091 .59844 Mdot
.039 .916 .04 r
.5 Mabswid
.2196 .40594 m
.23492 .41542 L
s
0 0 0 r
2.5 Mabswid
.23492 .41542 Mdot
.039 .916 .04 r
.5 Mabswid
.23193 .41125 m
.24826 .41272 L
s
0 0 0 r
2.5 Mabswid
.24826 .41272 Mdot
.039 .916 .04 r
.5 Mabswid
.22387 .42423 m
.23807 .42536 L
s
0 0 0 r
2.5 Mabswid
.23807 .42536 Mdot
.039 .916 .04 r
.5 Mabswid
.22412 .43296 m
.22642 .43271 L
s
0 0 0 r
2.5 Mabswid
.22642 .43271 Mdot
.039 .916 .04 r
.5 Mabswid
.2197 .44363 m
.23426 .43774 L
s
0 0 0 r
2.5 Mabswid
.23426 .43774 Mdot
.039 .916 .04 r
.5 Mabswid
.22824 .4536 m
.23414 .45477 L
s
0 0 0 r
2.5 Mabswid
.23414 .45477 Mdot
.039 .916 .04 r
.5 Mabswid
.21472 .46501 m
.22242 .46496 L
s
0 0 0 r
2.5 Mabswid
.22242 .46496 Mdot
.039 .916 .04 r
.5 Mabswid
.2268 .47732 m
.22746 .47748 L
s
0 0 0 r
2.5 Mabswid
.22746 .47748 Mdot
.039 .916 .04 r
.5 Mabswid
.21789 .48431 m
.2229 .48497 L
s
0 0 0 r
2.5 Mabswid
.2229 .48497 Mdot
.039 .916 .04 r
.5 Mabswid
.21498 .49476 m
.22229 .48929 L
s
0 0 0 r
2.5 Mabswid
.22229 .48929 Mdot
.039 .916 .04 r
.5 Mabswid
.21804 .50369 m
.22017 .50213 L
s
0 0 0 r
2.5 Mabswid
.22017 .50213 Mdot
.039 .916 .04 r
.5 Mabswid
.22842 .5129 m
.23927 .50991 L
s
0 0 0 r
2.5 Mabswid
.23927 .50991 Mdot
.039 .916 .04 r
.5 Mabswid
.2313 .52956 m
.23497 .52965 L
s
0 0 0 r
2.5 Mabswid
.23497 .52965 Mdot
.039 .916 .04 r
.5 Mabswid
.22948 .5328 m
.2432 .53053 L
s
0 0 0 r
2.5 Mabswid
.2432 .53053 Mdot
.039 .916 .04 r
.5 Mabswid
.22245 .54599 m
.23086 .54704 L
s
0 0 0 r
2.5 Mabswid
.23086 .54704 Mdot
.039 .916 .04 r
.5 Mabswid
.21984 .555 m
.23121 .55812 L
s
0 0 0 r
2.5 Mabswid
.23121 .55812 Mdot
.039 .916 .04 r
.5 Mabswid
.21695 .56622 m
.22861 .56815 L
s
0 0 0 r
2.5 Mabswid
.22861 .56815 Mdot
.039 .916 .04 r
.5 Mabswid
.22466 .57741 m
.23053 .57637 L
s
0 0 0 r
2.5 Mabswid
.23053 .57637 Mdot
.039 .916 .04 r
.5 Mabswid
.21687 .58477 m
.22055 .58253 L
s
0 0 0 r
2.5 Mabswid
.22055 .58253 Mdot
.039 .916 .04 r
.5 Mabswid
.23091 .59844 m
.23633 .59927 L
s
0 0 0 r
2.5 Mabswid
.23633 .59927 Mdot
.039 .916 .04 r
.5 Mabswid
.23492 .41542 m
.2526 .42015 L
s
0 0 0 r
2.5 Mabswid
.2526 .42015 Mdot
.039 .916 .04 r
.5 Mabswid
.24826 .41272 m
.26365 .41238 L
s
0 0 0 r
2.5 Mabswid
.26365 .41238 Mdot
.039 .916 .04 r
.5 Mabswid
.23807 .42536 m
.25316 .4205 L
s
0 0 0 r
2.5 Mabswid
.25316 .4205 Mdot
.039 .916 .04 r
.5 Mabswid
.22642 .43271 m
.23024 .43068 L
s
0 0 0 r
2.5 Mabswid
.23024 .43068 Mdot
.039 .916 .04 r
.5 Mabswid
.23426 .43774 m
.2465 .43592 L
s
0 0 0 r
2.5 Mabswid
.2465 .43592 Mdot
.039 .916 .04 r
.5 Mabswid
.23414 .45477 m
.24338 .45681 L
s
0 0 0 r
2.5 Mabswid
.24338 .45681 Mdot
.039 .916 .04 r
.5 Mabswid
.22242 .46496 m
.22645 .46423 L
s
0 0 0 r
2.5 Mabswid
.22645 .46423 Mdot
.039 .916 .04 r
.5 Mabswid
.22746 .47748 m
.24313 .48329 L
s
0 0 0 r
2.5 Mabswid
.24313 .48329 Mdot
.039 .916 .04 r
.5 Mabswid
.2229 .48497 m
.23395 .4825 L
s
0 0 0 r
2.5 Mabswid
.23395 .4825 Mdot
.039 .916 .04 r
.5 Mabswid
.22229 .48929 m
.23175 .48379 L
s
0 0 0 r
2.5 Mabswid
.23175 .48379 Mdot
.039 .916 .04 r
.5 Mabswid
.22017 .50213 m
.22405 .49606 L
s
0 0 0 r
2.5 Mabswid
.22405 .49606 Mdot
.039 .916 .04 r
.5 Mabswid
.23927 .50991 m
.24421 .50717 L
s
0 0 0 r
2.5 Mabswid
.24421 .50717 Mdot
.039 .916 .04 r
.5 Mabswid
.23497 .52965 m
.24247 .53231 L
s
0 0 0 r
2.5 Mabswid
.24247 .53231 Mdot
.039 .916 .04 r
.5 Mabswid
.2432 .53053 m
.25245 .53148 L
s
0 0 0 r
2.5 Mabswid
.25245 .53148 Mdot
.039 .916 .04 r
.5 Mabswid
.23086 .54704 m
.24094 .55181 L
s
0 0 0 r
2.5 Mabswid
.24094 .55181 Mdot
.039 .916 .04 r
.5 Mabswid
.23121 .55812 m
.23566 .56072 L
s
0 0 0 r
2.5 Mabswid
.23566 .56072 Mdot
.039 .916 .04 r
.5 Mabswid
.22861 .56815 m
.24623 .5655 L
s
0 0 0 r
2.5 Mabswid
.24623 .5655 Mdot
.039 .916 .04 r
.5 Mabswid
.23053 .57637 m
.24448 .57158 L
s
0 0 0 r
2.5 Mabswid
.24448 .57158 Mdot
.039 .916 .04 r
.5 Mabswid
.22055 .58253 m
.23387 .57847 L
s
0 0 0 r
2.5 Mabswid
.23387 .57847 Mdot
.039 .916 .04 r
.5 Mabswid
.23633 .59927 m
.2528 .60379 L
s
0 0 0 r
2.5 Mabswid
.2528 .60379 Mdot
.039 .916 .04 r
.5 Mabswid
.2526 .42015 m
.25509 .42142 L
s
0 0 0 r
2.5 Mabswid
.25509 .42142 Mdot
.039 .916 .04 r
.5 Mabswid
.26365 .41238 m
.26946 .40984 L
s
0 0 0 r
2.5 Mabswid
.26946 .40984 Mdot
.039 .916 .04 r
.5 Mabswid
.25316 .4205 m
.26767 .41863 L
s
0 0 0 r
2.5 Mabswid
.26767 .41863 Mdot
.039 .916 .04 r
.5 Mabswid
.23024 .43068 m
.23109 .43046 L
s
0 0 0 r
2.5 Mabswid
.23109 .43046 Mdot
.039 .916 .04 r
.5 Mabswid
.2465 .43592 m
.25333 .43668 L
s
0 0 0 r
2.5 Mabswid
.25333 .43668 Mdot
.039 .916 .04 r
.5 Mabswid
.24338 .45681 m
.25224 .46268 L
s
0 0 0 r
2.5 Mabswid
.25224 .46268 Mdot
.039 .916 .04 r
.5 Mabswid
.22645 .46423 m
.24103 .46653 L
s
0 0 0 r
2.5 Mabswid
.24103 .46653 Mdot
.039 .916 .04 r
.5 Mabswid
.24313 .48329 m
.24878 .48368 L
s
0 0 0 r
2.5 Mabswid
.24878 .48368 Mdot
.039 .916 .04 r
.5 Mabswid
.23395 .4825 m
.24992 .48306 L
s
0 0 0 r
2.5 Mabswid
.24992 .48306 Mdot
.039 .916 .04 r
.5 Mabswid
.23175 .48379 m
.24136 .48118 L
s
0 0 0 r
2.5 Mabswid
.24136 .48118 Mdot
.039 .916 .04 r
.5 Mabswid
.22405 .49606 m
.22445 .49385 L
s
0 0 0 r
2.5 Mabswid
.22445 .49385 Mdot
.039 .916 .04 r
.5 Mabswid
.24421 .50717 m
.2529 .49899 L
s
0 0 0 r
2.5 Mabswid
.2529 .49899 Mdot
.039 .916 .04 r
.5 Mabswid
.24247 .53231 m
.26081 .53479 L
s
0 0 0 r
2.5 Mabswid
.26081 .53479 Mdot
.039 .916 .04 r
.5 Mabswid
.25245 .53148 m
.25818 .53063 L
s
0 0 0 r
2.5 Mabswid
.25818 .53063 Mdot
.039 .916 .04 r
.5 Mabswid
.24094 .55181 m
.24461 .55355 L
s
0 0 0 r
2.5 Mabswid
.24461 .55355 Mdot
.039 .916 .04 r
.5 Mabswid
.23566 .56072 m
.24031 .56284 L
s
0 0 0 r
2.5 Mabswid
.24031 .56284 Mdot
.039 .916 .04 r
.5 Mabswid
.24623 .5655 m
.26247 .56529 L
s
0 0 0 r
2.5 Mabswid
.26247 .56529 Mdot
.039 .916 .04 r
.5 Mabswid
.24448 .57158 m
.25692 .56627 L
s
0 0 0 r
2.5 Mabswid
.25692 .56627 Mdot
.039 .916 .04 r
.5 Mabswid
.23387 .57847 m
.23553 .5783 L
s
0 0 0 r
2.5 Mabswid
.23553 .5783 Mdot
.039 .916 .04 r
.5 Mabswid
.2528 .60379 m
.26083 .6045 L
s
0 0 0 r
2.5 Mabswid
.26083 .6045 Mdot
.039 .916 .04 r
.5 Mabswid
.25509 .42142 m
.25838 .42482 L
s
0 0 0 r
2.5 Mabswid
.25838 .42482 Mdot
.039 .916 .04 r
.5 Mabswid
.26946 .40984 m
.28481 .40223 L
s
0 0 0 r
2.5 Mabswid
.28481 .40223 Mdot
.039 .916 .04 r
.5 Mabswid
.26767 .41863 m
.27029 .41917 L
s
0 0 0 r
2.5 Mabswid
.27029 .41917 Mdot
.039 .916 .04 r
.5 Mabswid
.23109 .43046 m
.23596 .42815 L
s
0 0 0 r
2.5 Mabswid
.23596 .42815 Mdot
.039 .916 .04 r
.5 Mabswid
.25333 .43668 m
.25644 .43749 L
s
0 0 0 r
2.5 Mabswid
.25644 .43749 Mdot
.039 .916 .04 r
.5 Mabswid
.25224 .46268 m
.27031 .46729 L
s
0 0 0 r
2.5 Mabswid
.27031 .46729 Mdot
.039 .916 .04 r
.5 Mabswid
.24103 .46653 m
.25916 .46478 L
s
0 0 0 r
2.5 Mabswid
.25916 .46478 Mdot
.039 .916 .04 r
.5 Mabswid
.24878 .48368 m
.26216 .48676 L
s
0 0 0 r
2.5 Mabswid
.26216 .48676 Mdot
.039 .916 .04 r
.5 Mabswid
.24992 .48306 m
.25208 .48314 L
s
0 0 0 r
2.5 Mabswid
.25208 .48314 Mdot
.039 .916 .04 r
.5 Mabswid
.24136 .48118 m
.24172 .48101 L
s
0 0 0 r
2.5 Mabswid
.24172 .48101 Mdot
.039 .916 .04 r
.5 Mabswid
.22445 .49385 m
.22471 .49321 L
s
0 0 0 r
2.5 Mabswid
.22471 .49321 Mdot
.039 .916 .04 r
.5 Mabswid
.2529 .49899 m
.25774 .48868 L
s
0 0 0 r
2.5 Mabswid
.25774 .48868 Mdot
.039 .916 .04 r
.5 Mabswid
.26081 .53479 m
.27463 .5406 L
s
0 0 0 r
2.5 Mabswid
.27463 .5406 Mdot
.039 .916 .04 r
.5 Mabswid
.25818 .53063 m
.27144 .52952 L
s
0 0 0 r
2.5 Mabswid
.27144 .52952 Mdot
.039 .916 .04 r
.5 Mabswid
.24461 .55355 m
.25359 .56226 L
s
0 0 0 r
2.5 Mabswid
.25359 .56226 Mdot
.039 .916 .04 r
.5 Mabswid
.24031 .56284 m
.24807 .56519 L
s
0 0 0 r
2.5 Mabswid
.24807 .56519 Mdot
.039 .916 .04 r
.5 Mabswid
.26247 .56529 m
.27172 .56321 L
s
0 0 0 r
2.5 Mabswid
.27172 .56321 Mdot
.039 .916 .04 r
.5 Mabswid
.25692 .56627 m
.26395 .56149 L
s
0 0 0 r
2.5 Mabswid
.26395 .56149 Mdot
.039 .916 .04 r
.5 Mabswid
.23553 .5783 m
.24483 .57381 L
s
0 0 0 r
2.5 Mabswid
.24483 .57381 Mdot
.039 .916 .04 r
.5 Mabswid
.26083 .6045 m
.27453 .60628 L
s
0 0 0 r
2.5 Mabswid
.27453 .60628 Mdot
.039 .916 .04 r
.5 Mabswid
.25838 .42482 m
.26394 .43105 L
s
0 0 0 r
2.5 Mabswid
.26394 .43105 Mdot
.039 .916 .04 r
.5 Mabswid
.28481 .40223 m
.29564 .39399 L
s
0 0 0 r
2.5 Mabswid
.29564 .39399 Mdot
.039 .916 .04 r
.5 Mabswid
.27029 .41917 m
.27744 .42245 L
s
0 0 0 r
2.5 Mabswid
.27744 .42245 Mdot
.039 .916 .04 r
.5 Mabswid
.23596 .42815 m
.23788 .4267 L
s
0 0 0 r
2.5 Mabswid
.23788 .4267 Mdot
.039 .916 .04 r
.5 Mabswid
.25644 .43749 m
.26618 .44435 L
s
0 0 0 r
2.5 Mabswid
.26618 .44435 Mdot
.039 .916 .04 r
.5 Mabswid
.27031 .46729 m
.27791 .47026 L
s
0 0 0 r
2.5 Mabswid
.27791 .47026 Mdot
.039 .916 .04 r
.5 Mabswid
.25916 .46478 m
.27572 .45666 L
s
0 0 0 r
2.5 Mabswid
.27572 .45666 Mdot
.039 .916 .04 r
.5 Mabswid
.26216 .48676 m
.2624 .48678 L
s
0 0 0 r
2.5 Mabswid
.2624 .48678 Mdot
.039 .916 .04 r
.5 Mabswid
.25208 .48314 m
.26087 .48568 L
s
0 0 0 r
2.5 Mabswid
.26087 .48568 Mdot
.039 .916 .04 r
.5 Mabswid
.24172 .48101 m
.24953 .47357 L
s
0 0 0 r
2.5 Mabswid
.24953 .47357 Mdot
.039 .916 .04 r
.5 Mabswid
.22471 .49321 m
.23452 .47827 L
s
0 0 0 r
2.5 Mabswid
.23452 .47827 Mdot
.039 .916 .04 r
.5 Mabswid
.25774 .48868 m
.26482 .47431 L
s
0 0 0 r
2.5 Mabswid
.26482 .47431 Mdot
.039 .916 .04 r
.5 Mabswid
.27463 .5406 m
.28421 .54218 L
s
0 0 0 r
2.5 Mabswid
.28421 .54218 Mdot
.039 .916 .04 r
.5 Mabswid
.27144 .52952 m
.27394 .52883 L
s
0 0 0 r
2.5 Mabswid
.27394 .52883 Mdot
.039 .916 .04 r
.5 Mabswid
.25359 .56226 m
.25515 .56357 L
s
0 0 0 r
2.5 Mabswid
.25515 .56357 Mdot
.039 .916 .04 r
.5 Mabswid
.24807 .56519 m
.24844 .56516 L
s
0 0 0 r
2.5 Mabswid
.24844 .56516 Mdot
.039 .916 .04 r
.5 Mabswid
.27172 .56321 m
.28059 .56086 L
s
0 0 0 r
2.5 Mabswid
.28059 .56086 Mdot
.039 .916 .04 r
.5 Mabswid
.26395 .56149 m
.27259 .55426 L
s
0 0 0 r
2.5 Mabswid
.27259 .55426 Mdot
.039 .916 .04 r
.5 Mabswid
.24483 .57381 m
.2533 .56895 L
s
0 0 0 r
2.5 Mabswid
.2533 .56895 Mdot
.039 .916 .04 r
.5 Mabswid
.27453 .60628 m
.28546 .60375 L
s
0 0 0 r
2.5 Mabswid
.28546 .60375 Mdot
.039 .916 .04 r
.5 Mabswid
.26394 .43105 m
.26443 .43169 L
s
0 0 0 r
2.5 Mabswid
.26443 .43169 Mdot
.039 .916 .04 r
.5 Mabswid
.29564 .39399 m
.29624 .39382 L
s
0 0 0 r
2.5 Mabswid
.29624 .39382 Mdot
.039 .916 .04 r
.5 Mabswid
.27744 .42245 m
.27894 .42373 L
s
0 0 0 r
2.5 Mabswid
.27894 .42373 Mdot
.039 .916 .04 r
.5 Mabswid
.23788 .4267 m
.2407 .42437 L
s
0 0 0 r
2.5 Mabswid
.2407 .42437 Mdot
.039 .916 .04 r
.5 Mabswid
.26618 .44435 m
.27462 .45188 L
s
0 0 0 r
2.5 Mabswid
.27462 .45188 Mdot
.039 .916 .04 r
.5 Mabswid
.27791 .47026 m
.27915 .47041 L
s
0 0 0 r
2.5 Mabswid
.27915 .47041 Mdot
.039 .916 .04 r
.5 Mabswid
.27572 .45666 m
.28318 .45083 L
s
0 0 0 r
2.5 Mabswid
.28318 .45083 Mdot
.039 .916 .04 r
.5 Mabswid
.2624 .48678 m
.26345 .48659 L
s
0 0 0 r
2.5 Mabswid
.26345 .48659 Mdot
.039 .916 .04 r
.5 Mabswid
.26087 .48568 m
.2613 .48592 L
s
0 0 0 r
2.5 Mabswid
.2613 .48592 Mdot
.039 .916 .04 r
.5 Mabswid
.24953 .47357 m
.25711 .469 L
s
0 0 0 r
2.5 Mabswid
.25711 .469 Mdot
.039 .916 .04 r
.5 Mabswid
.23452 .47827 m
.23904 .46961 L
s
0 0 0 r
2.5 Mabswid
.23904 .46961 Mdot
.039 .916 .04 r
.5 Mabswid
.26482 .47431 m
.2748 .46094 L
s
0 0 0 r
2.5 Mabswid
.2748 .46094 Mdot
.039 .916 .04 r
.5 Mabswid
.28421 .54218 m
.29272 .54556 L
s
0 0 0 r
2.5 Mabswid
.29272 .54556 Mdot
.039 .916 .04 r
.5 Mabswid
.27394 .52883 m
.29015 .52782 L
s
0 0 0 r
2.5 Mabswid
.29015 .52782 Mdot
.039 .916 .04 r
.5 Mabswid
.25515 .56357 m
.25893 .56989 L
s
0 0 0 r
2.5 Mabswid
.25893 .56989 Mdot
.039 .916 .04 r
.5 Mabswid
.24844 .56516 m
.2609 .56234 L
s
0 0 0 r
2.5 Mabswid
.2609 .56234 Mdot
.039 .916 .04 r
.5 Mabswid
.28059 .56086 m
.29429 .55449 L
s
0 0 0 r
2.5 Mabswid
.29429 .55449 Mdot
.039 .916 .04 r
.5 Mabswid
.27259 .55426 m
.27907 .5445 L
s
0 0 0 r
2.5 Mabswid
.27907 .5445 Mdot
.039 .916 .04 r
.5 Mabswid
.2533 .56895 m
.257 .56445 L
s
0 0 0 r
2.5 Mabswid
.257 .56445 Mdot
.039 .916 .04 r
.5 Mabswid
.28546 .60375 m
.29618 .60538 L
s
0 0 0 r
2.5 Mabswid
.29618 .60538 Mdot
.039 .916 .04 r
.5 Mabswid
.26443 .43169 m
.26855 .43539 L
s
0 0 0 r
2.5 Mabswid
.26855 .43539 Mdot
.039 .916 .04 r
.5 Mabswid
.29624 .39382 m
.29814 .39275 L
s
0 0 0 r
2.5 Mabswid
.29814 .39275 Mdot
.039 .916 .04 r
.5 Mabswid
.27894 .42373 m
.28688 .43625 L
s
0 0 0 r
2.5 Mabswid
.28688 .43625 Mdot
.039 .916 .04 r
.5 Mabswid
.2407 .42437 m
.24414 .42139 L
s
0 0 0 r
2.5 Mabswid
.24414 .42139 Mdot
.039 .916 .04 r
.5 Mabswid
.27462 .45188 m
.27996 .45429 L
s
0 0 0 r
2.5 Mabswid
.27996 .45429 Mdot
.039 .916 .04 r
.5 Mabswid
.27915 .47041 m
.2862 .47247 L
s
0 0 0 r
2.5 Mabswid
.2862 .47247 Mdot
.039 .916 .04 r
.5 Mabswid
.28318 .45083 m
.29398 .43702 L
s
0 0 0 r
2.5 Mabswid
.29398 .43702 Mdot
.039 .916 .04 r
.5 Mabswid
.26345 .48659 m
.27659 .48302 L
s
0 0 0 r
2.5 Mabswid
.27659 .48302 Mdot
.039 .916 .04 r
.5 Mabswid
.2613 .48592 m
.26307 .48785 L
s
0 0 0 r
2.5 Mabswid
.26307 .48785 Mdot
.039 .916 .04 r
.5 Mabswid
.25711 .469 m
.25866 .4676 L
s
0 0 0 r
2.5 Mabswid
.25866 .4676 Mdot
.039 .916 .04 r
.5 Mabswid
.23904 .46961 m
.25012 .4583 L
s
0 0 0 r
2.5 Mabswid
.25012 .4583 Mdot
.039 .916 .04 r
.5 Mabswid
.2748 .46094 m
.27943 .45175 L
s
0 0 0 r
2.5 Mabswid
.27943 .45175 Mdot
.039 .916 .04 r
.5 Mabswid
.29272 .54556 m
.30208 .55031 L
s
0 0 0 r
2.5 Mabswid
.30208 .55031 Mdot
.039 .916 .04 r
.5 Mabswid
.29015 .52782 m
.29782 .52463 L
s
0 0 0 r
2.5 Mabswid
.29782 .52463 Mdot
.039 .916 .04 r
.5 Mabswid
.25893 .56989 m
.26405 .5837 L
s
0 0 0 r
2.5 Mabswid
.26405 .5837 Mdot
.039 .916 .04 r
.5 Mabswid
.2609 .56234 m
.26482 .56179 L
s
0 0 0 r
2.5 Mabswid
.26482 .56179 Mdot
.039 .916 .04 r
.5 Mabswid
.29429 .55449 m
.30283 .55149 L
s
0 0 0 r
2.5 Mabswid
.30283 .55149 Mdot
.039 .916 .04 r
.5 Mabswid
.27907 .5445 m
.29132 .53476 L
s
0 0 0 r
2.5 Mabswid
.29132 .53476 Mdot
.039 .916 .04 r
.5 Mabswid
.257 .56445 m
.26329 .55595 L
s
0 0 0 r
2.5 Mabswid
.26329 .55595 Mdot
.039 .916 .04 r
.5 Mabswid
.29618 .60538 m
.29837 .60572 L
s
0 0 0 r
2.5 Mabswid
.29837 .60572 Mdot
.039 .916 .04 r
.5 Mabswid
.26855 .43539 m
.27452 .44092 L
s
0 0 0 r
2.5 Mabswid
.27452 .44092 Mdot
.039 .916 .04 r
.5 Mabswid
.29814 .39275 m
.29838 .39254 L
s
0 0 0 r
2.5 Mabswid
.29838 .39254 Mdot
.039 .916 .04 r
.5 Mabswid
.28688 .43625 m
.2918 .44647 L
s
0 0 0 r
2.5 Mabswid
.2918 .44647 Mdot
.039 .916 .04 r
.5 Mabswid
.24414 .42139 m
.25267 .4183 L
s
0 0 0 r
2.5 Mabswid
.25267 .4183 Mdot
.039 .916 .04 r
.5 Mabswid
.27996 .45429 m
.28101 .45434 L
s
0 0 0 r
2.5 Mabswid
.28101 .45434 Mdot
.039 .916 .04 r
.5 Mabswid
.2862 .47247 m
.287 .473 L
s
0 0 0 r
2.5 Mabswid
.287 .473 Mdot
.039 .916 .04 r
.5 Mabswid
.29398 .43702 m
.29657 .4323 L
s
0 0 0 r
2.5 Mabswid
.29657 .4323 Mdot
.039 .916 .04 r
.5 Mabswid
.27659 .48302 m
.29114 .47625 L
s
0 0 0 r
2.5 Mabswid
.29114 .47625 Mdot
.039 .916 .04 r
.5 Mabswid
.26307 .48785 m
.27186 .50046 L
s
0 0 0 r
2.5 Mabswid
.27186 .50046 Mdot
.039 .916 .04 r
.5 Mabswid
.25866 .4676 m
.25906 .46717 L
s
0 0 0 r
2.5 Mabswid
.25906 .46717 Mdot
.039 .916 .04 r
.5 Mabswid
.25012 .4583 m
.2528 .45409 L
s
0 0 0 r
2.5 Mabswid
.2528 .45409 Mdot
.039 .916 .04 r
.5 Mabswid
.27943 .45175 m
.2915 .43919 L
s
0 0 0 r
2.5 Mabswid
.2915 .43919 Mdot
.039 .916 .04 r
.5 Mabswid
.30208 .55031 m
.31485 .55977 L
s
0 0 0 r
2.5 Mabswid
.31485 .55977 Mdot
.039 .916 .04 r
.5 Mabswid
.29782 .52463 m
.31439 .5197 L
s
0 0 0 r
2.5 Mabswid
.31439 .5197 Mdot
.039 .916 .04 r
.5 Mabswid
.26405 .5837 m
.26709 .58733 L
s
0 0 0 r
2.5 Mabswid
.26709 .58733 Mdot
.039 .916 .04 r
.5 Mabswid
.26482 .56179 m
.27322 .56173 L
s
0 0 0 r
2.5 Mabswid
.27322 .56173 Mdot
.039 .916 .04 r
.5 Mabswid
.30283 .55149 m
.30579 .54899 L
s
0 0 0 r
2.5 Mabswid
.30579 .54899 Mdot
.039 .916 .04 r
.5 Mabswid
.29132 .53476 m
.2982 .53141 L
s
0 0 0 r
2.5 Mabswid
.2982 .53141 Mdot
.039 .916 .04 r
.5 Mabswid
.26329 .55595 m
.27621 .54408 L
s
0 0 0 r
2.5 Mabswid
.27621 .54408 Mdot
.039 .916 .04 r
.5 Mabswid
.29837 .60572 m
.30889 .60731 L
s
0 0 0 r
2.5 Mabswid
.30889 .60731 Mdot
.039 .916 .04 r
.5 Mabswid
.27452 .44092 m
.27669 .44187 L
s
0 0 0 r
2.5 Mabswid
.27669 .44187 Mdot
.039 .916 .04 r
.5 Mabswid
.29838 .39254 m
.30373 .38381 L
s
0 0 0 r
2.5 Mabswid
.30373 .38381 Mdot
.039 .916 .04 r
.5 Mabswid
.2918 .44647 m
.29481 .46262 L
s
0 0 0 r
2.5 Mabswid
.29481 .46262 Mdot
.039 .916 .04 r
.5 Mabswid
.25267 .4183 m
.26272 .41199 L
s
0 0 0 r
2.5 Mabswid
.26272 .41199 Mdot
.039 .916 .04 r
.5 Mabswid
.28101 .45434 m
.28171 .45417 L
s
0 0 0 r
2.5 Mabswid
.28171 .45417 Mdot
.039 .916 .04 r
.5 Mabswid
.287 .473 m
.29771 .48142 L
s
0 0 0 r
2.5 Mabswid
.29771 .48142 Mdot
.039 .916 .04 r
.5 Mabswid
.29657 .4323 m
.29889 .41746 L
s
0 0 0 r
2.5 Mabswid
.29889 .41746 Mdot
.039 .916 .04 r
.5 Mabswid
.29114 .47625 m
.29653 .47571 L
s
0 0 0 r
2.5 Mabswid
.29653 .47571 Mdot
.039 .916 .04 r
.5 Mabswid
.27186 .50046 m
.28129 .50674 L
s
0 0 0 r
2.5 Mabswid
.28129 .50674 Mdot
.039 .916 .04 r
.5 Mabswid
.25906 .46717 m
.26672 .4522 L
s
0 0 0 r
2.5 Mabswid
.26672 .4522 Mdot
.039 .916 .04 r
.5 Mabswid
.2528 .45409 m
.25774 .44224 L
s
0 0 0 r
2.5 Mabswid
.25774 .44224 Mdot
.039 .916 .04 r
.5 Mabswid
.2915 .43919 m
.29643 .43517 L
s
0 0 0 r
2.5 Mabswid
.29643 .43517 Mdot
.039 .916 .04 r
.5 Mabswid
.31485 .55977 m
.32464 .564 L
s
0 0 0 r
2.5 Mabswid
.32464 .564 Mdot
.039 .916 .04 r
.5 Mabswid
.31439 .5197 m
.32908 .5159 L
s
0 0 0 r
2.5 Mabswid
.32908 .5159 Mdot
.039 .916 .04 r
.5 Mabswid
.26709 .58733 m
.27659 .59661 L
s
0 0 0 r
2.5 Mabswid
.27659 .59661 Mdot
.039 .916 .04 r
.5 Mabswid
.27322 .56173 m
.27668 .56121 L
s
0 0 0 r
2.5 Mabswid
.27668 .56121 Mdot
.039 .916 .04 r
.5 Mabswid
.30579 .54899 m
.31371 .53899 L
s
0 0 0 r
2.5 Mabswid
.31371 .53899 Mdot
.039 .916 .04 r
.5 Mabswid
.2982 .53141 m
.30676 .52895 L
s
0 0 0 r
2.5 Mabswid
.30676 .52895 Mdot
.039 .916 .04 r
.5 Mabswid
.27621 .54408 m
.28544 .53007 L
s
0 0 0 r
2.5 Mabswid
.28544 .53007 Mdot
.039 .916 .04 r
.5 Mabswid
.30889 .60731 m
.31232 .60869 L
s
0 0 0 r
2.5 Mabswid
.31232 .60869 Mdot
.039 .916 .04 r
.5 Mabswid
.27669 .44187 m
.28226 .4427 L
s
0 0 0 r
2.5 Mabswid
.28226 .4427 Mdot
.039 .916 .04 r
.5 Mabswid
.30373 .38381 m
.30739 .37914 L
s
0 0 0 r
2.5 Mabswid
.30739 .37914 Mdot
.039 .916 .04 r
.5 Mabswid
.29481 .46262 m
.29342 .47438 L
s
0 0 0 r
2.5 Mabswid
.29342 .47438 Mdot
.039 .916 .04 r
.5 Mabswid
.26272 .41199 m
.28106 .40877 L
s
0 0 0 r
2.5 Mabswid
.28106 .40877 Mdot
.039 .916 .04 r
.5 Mabswid
.28171 .45417 m
.28307 .45403 L
s
0 0 0 r
2.5 Mabswid
.28307 .45403 Mdot
.039 .916 .04 r
.5 Mabswid
.29771 .48142 m
.30067 .48355 L
s
0 0 0 r
2.5 Mabswid
.30067 .48355 Mdot
.039 .916 .04 r
.5 Mabswid
.29889 .41746 m
.2989 .41032 L
s
0 0 0 r
2.5 Mabswid
.2989 .41032 Mdot
.039 .916 .04 r
.5 Mabswid
.29653 .47571 m
.29684 .47558 L
s
0 0 0 r
2.5 Mabswid
.29684 .47558 Mdot
.039 .916 .04 r
.5 Mabswid
.28129 .50674 m
.29434 .50993 L
s
0 0 0 r
2.5 Mabswid
.29434 .50993 Mdot
.039 .916 .04 r
.5 Mabswid
.26672 .4522 m
.27083 .44256 L
s
0 0 0 r
2.5 Mabswid
.27083 .44256 Mdot
.039 .916 .04 r
.5 Mabswid
.25774 .44224 m
.26767 .43008 L
s
0 0 0 r
2.5 Mabswid
.26767 .43008 Mdot
.039 .916 .04 r
.5 Mabswid
.29643 .43517 m
.30221 .43127 L
s
0 0 0 r
2.5 Mabswid
.30221 .43127 Mdot
.039 .916 .04 r
.5 Mabswid
.32464 .564 m
.33328 .56953 L
s
0 0 0 r
2.5 Mabswid
.33328 .56953 Mdot
.039 .916 .04 r
.5 Mabswid
.32908 .5159 m
.3303 .51604 L
s
0 0 0 r
2.5 Mabswid
.3303 .51604 Mdot
.039 .916 .04 r
.5 Mabswid
.27659 .59661 m
.28565 .61156 L
s
0 0 0 r
2.5 Mabswid
.28565 .61156 Mdot
.039 .916 .04 r
.5 Mabswid
.27668 .56121 m
.27829 .56157 L
s
0 0 0 r
2.5 Mabswid
.27829 .56157 Mdot
.039 .916 .04 r
.5 Mabswid
.31371 .53899 m
.31993 .52392 L
s
0 0 0 r
2.5 Mabswid
.31993 .52392 Mdot
.039 .916 .04 r
.5 Mabswid
.30676 .52895 m
.32327 .52463 L
s
0 0 0 r
2.5 Mabswid
.32327 .52463 Mdot
.039 .916 .04 r
.5 Mabswid
.28544 .53007 m
.29247 .5239 L
s
0 0 0 r
2.5 Mabswid
.29247 .5239 Mdot
.039 .916 .04 r
.5 Mabswid
.31232 .60869 m
.32847 .61371 L
s
0 0 0 r
2.5 Mabswid
.32847 .61371 Mdot
.039 .916 .04 r
.5 Mabswid
.28226 .4427 m
.29621 .44814 L
s
0 0 0 r
2.5 Mabswid
.29621 .44814 Mdot
.039 .916 .04 r
.5 Mabswid
.30739 .37914 m
.31313 .37583 L
s
0 0 0 r
2.5 Mabswid
.31313 .37583 Mdot
.039 .916 .04 r
.5 Mabswid
.29342 .47438 m
.28557 .49093 L
s
0 0 0 r
2.5 Mabswid
.28557 .49093 Mdot
.039 .916 .04 r
.5 Mabswid
.28106 .40877 m
.29907 .40371 L
s
0 0 0 r
2.5 Mabswid
.29907 .40371 Mdot
.039 .916 .04 r
.5 Mabswid
.28307 .45403 m
.29086 .45135 L
s
0 0 0 r
2.5 Mabswid
.29086 .45135 Mdot
.039 .916 .04 r
.5 Mabswid
.30067 .48355 m
.31575 .49275 L
s
0 0 0 r
2.5 Mabswid
.31575 .49275 Mdot
.039 .916 .04 r
.5 Mabswid
.2989 .41032 m
.29806 .40055 L
s
0 0 0 r
2.5 Mabswid
.29806 .40055 Mdot
.039 .916 .04 r
.5 Mabswid
.29684 .47558 m
.31144 .46856 L
s
0 0 0 r
2.5 Mabswid
.31144 .46856 Mdot
.039 .916 .04 r
.5 Mabswid
.29434 .50993 m
.30689 .51041 L
s
0 0 0 r
2.5 Mabswid
.30689 .51041 Mdot
.039 .916 .04 r
.5 Mabswid
.27083 .44256 m
.28274 .42882 L
s
0 0 0 r
2.5 Mabswid
.28274 .42882 Mdot
.039 .916 .04 r
.5 Mabswid
.26767 .43008 m
.26961 .42729 L
s
0 0 0 r
2.5 Mabswid
.26961 .42729 Mdot
.039 .916 .04 r
.5 Mabswid
.30221 .43127 m
.30342 .43045 L
s
0 0 0 r
2.5 Mabswid
.30342 .43045 Mdot
.039 .916 .04 r
.5 Mabswid
.33328 .56953 m
.33918 .57412 L
s
0 0 0 r
2.5 Mabswid
.33918 .57412 Mdot
.039 .916 .04 r
.5 Mabswid
.3303 .51604 m
.34408 .51774 L
s
0 0 0 r
2.5 Mabswid
.34408 .51774 Mdot
.039 .916 .04 r
.5 Mabswid
.28565 .61156 m
.28873 .61915 L
s
0 0 0 r
2.5 Mabswid
.28873 .61915 Mdot
.039 .916 .04 r
.5 Mabswid
.27829 .56157 m
.2925 .5607 L
s
0 0 0 r
2.5 Mabswid
.2925 .5607 Mdot
.039 .916 .04 r
.5 Mabswid
.31993 .52392 m
.32708 .50632 L
s
0 0 0 r
2.5 Mabswid
.32708 .50632 Mdot
.039 .916 .04 r
.5 Mabswid
.32327 .52463 m
.33884 .52351 L
s
0 0 0 r
2.5 Mabswid
.33884 .52351 Mdot
.039 .916 .04 r
.5 Mabswid
.29247 .5239 m
.29729 .51585 L
s
0 0 0 r
2.5 Mabswid
.29729 .51585 Mdot
.039 .916 .04 r
.5 Mabswid
.32847 .61371 m
.34672 .6165 L
s
0 0 0 r
2.5 Mabswid
.34672 .6165 Mdot
.039 .916 .04 r
.5 Mabswid
.29621 .44814 m
.30879 .45781 L
s
0 0 0 r
2.5 Mabswid
.30879 .45781 Mdot
.039 .916 .04 r
.5 Mabswid
.31313 .37583 m
.31352 .37557 L
s
0 0 0 r
2.5 Mabswid
.31352 .37557 Mdot
.039 .916 .04 r
.5 Mabswid
.28557 .49093 m
.2805 .50253 L
s
0 0 0 r
2.5 Mabswid
.2805 .50253 Mdot
.039 .916 .04 r
.5 Mabswid
.29907 .40371 m
.31709 .40465 L
s
0 0 0 r
2.5 Mabswid
.31709 .40465 Mdot
.039 .916 .04 r
.5 Mabswid
.29086 .45135 m
.29624 .45101 L
s
0 0 0 r
2.5 Mabswid
.29624 .45101 Mdot
.039 .916 .04 r
.5 Mabswid
.31575 .49275 m
.31962 .49473 L
s
0 0 0 r
2.5 Mabswid
.31962 .49473 Mdot
.039 .916 .04 r
.5 Mabswid
.29806 .40055 m
.29222 .38539 L
s
0 0 0 r
2.5 Mabswid
.29222 .38539 Mdot
.039 .916 .04 r
.5 Mabswid
.31144 .46856 m
.31884 .46315 L
s
0 0 0 r
2.5 Mabswid
.31884 .46315 Mdot
.039 .916 .04 r
.5 Mabswid
.30689 .51041 m
.32299 .51291 L
s
0 0 0 r
2.5 Mabswid
.32299 .51291 Mdot
.039 .916 .04 r
.5 Mabswid
.28274 .42882 m
.29122 .4195 L
s
0 0 0 r
2.5 Mabswid
.29122 .4195 Mdot
.039 .916 .04 r
.5 Mabswid
.26961 .42729 m
.27387 .4216 L
s
0 0 0 r
2.5 Mabswid
.27387 .4216 Mdot
.039 .916 .04 r
.5 Mabswid
.30342 .43045 m
.31248 .42087 L
s
0 0 0 r
2.5 Mabswid
.31248 .42087 Mdot
.039 .916 .04 r
.5 Mabswid
.33918 .57412 m
.34631 .58154 L
s
0 0 0 r
2.5 Mabswid
.34631 .58154 Mdot
.039 .916 .04 r
.5 Mabswid
.34408 .51774 m
.35613 .52235 L
s
0 0 0 r
2.5 Mabswid
.35613 .52235 Mdot
.039 .916 .04 r
.5 Mabswid
.28873 .61915 m
.2982 .63288 L
s
0 0 0 r
2.5 Mabswid
.2982 .63288 Mdot
.039 .916 .04 r
.5 Mabswid
.2925 .5607 m
.30598 .56412 L
s
0 0 0 r
2.5 Mabswid
.30598 .56412 Mdot
.039 .916 .04 r
.5 Mabswid
.32708 .50632 m
.33038 .49533 L
s
0 0 0 r
2.5 Mabswid
.33038 .49533 Mdot
.039 .916 .04 r
.5 Mabswid
.33884 .52351 m
.34856 .52273 L
s
0 0 0 r
2.5 Mabswid
.34856 .52273 Mdot
.039 .916 .04 r
.5 Mabswid
.29729 .51585 m
.30197 .50237 L
s
0 0 0 r
2.5 Mabswid
.30197 .50237 Mdot
.039 .916 .04 r
.5 Mabswid
.34672 .6165 m
.34749 .61645 L
s
0 0 0 r
2.5 Mabswid
.34749 .61645 Mdot
.039 .916 .04 r
.5 Mabswid
.30879 .45781 m
.32152 .46911 L
s
0 0 0 r
2.5 Mabswid
.32152 .46911 Mdot
.039 .916 .04 r
.5 Mabswid
.31352 .37557 m
.32006 .37249 L
s
0 0 0 r
2.5 Mabswid
.32006 .37249 Mdot
.039 .916 .04 r
.5 Mabswid
.2805 .50253 m
.27994 .51262 L
s
0 0 0 r
2.5 Mabswid
.27994 .51262 Mdot
.039 .916 .04 r
.5 Mabswid
.31709 .40465 m
.33018 .40501 L
s
0 0 0 r
2.5 Mabswid
.33018 .40501 Mdot
.039 .916 .04 r
.5 Mabswid
.29624 .45101 m
.31483 .44782 L
s
0 0 0 r
2.5 Mabswid
.31483 .44782 Mdot
.039 .916 .04 r
.5 Mabswid
.31962 .49473 m
.31993 .49494 L
s
0 0 0 r
2.5 Mabswid
.31993 .49494 Mdot
.039 .916 .04 r
.5 Mabswid
.29222 .38539 m
.29078 .3835 L
s
0 0 0 r
2.5 Mabswid
.29078 .3835 Mdot
.039 .916 .04 r
.5 Mabswid
.31884 .46315 m
.32388 .46089 L
s
0 0 0 r
2.5 Mabswid
.32388 .46089 Mdot
.039 .916 .04 r
.5 Mabswid
.32299 .51291 m
.3323 .5164 L
s
0 0 0 r
2.5 Mabswid
.3323 .5164 Mdot
.039 .916 .04 r
.5 Mabswid
.29122 .4195 m
.29913 .40697 L
s
0 0 0 r
2.5 Mabswid
.29913 .40697 Mdot
.039 .916 .04 r
.5 Mabswid
.27387 .4216 m
.28287 .40996 L
s
0 0 0 r
2.5 Mabswid
.28287 .40996 Mdot
.039 .916 .04 r
.5 Mabswid
.31248 .42087 m
.31812 .40779 L
s
0 0 0 r
2.5 Mabswid
.31812 .40779 Mdot
.039 .916 .04 r
.5 Mabswid
.34631 .58154 m
.35325 .59676 L
s
0 0 0 r
2.5 Mabswid
.35325 .59676 Mdot
.039 .916 .04 r
.5 Mabswid
.35613 .52235 m
.3631 .52419 L
s
0 0 0 r
2.5 Mabswid
.3631 .52419 Mdot
.039 .916 .04 r
.5 Mabswid
.2982 .63288 m
.30023 .63939 L
s
0 0 0 r
2.5 Mabswid
.30023 .63939 Mdot
.039 .916 .04 r
.5 Mabswid
.30598 .56412 m
.31714 .57108 L
s
0 0 0 r
2.5 Mabswid
.31714 .57108 Mdot
.039 .916 .04 r
.5 Mabswid
.33038 .49533 m
.33251 .48865 L
s
0 0 0 r
2.5 Mabswid
.33251 .48865 Mdot
.039 .916 .04 r
.5 Mabswid
.34856 .52273 m
.36099 .51903 L
s
0 0 0 r
2.5 Mabswid
.36099 .51903 Mdot
.039 .916 .04 r
.5 Mabswid
.30197 .50237 m
.30313 .49768 L
s
0 0 0 r
2.5 Mabswid
.30313 .49768 Mdot
.039 .916 .04 r
.5 Mabswid
.34749 .61645 m
.3551 .61575 L
s
0 0 0 r
2.5 Mabswid
.3551 .61575 Mdot
.039 .916 .04 r
.5 Mabswid
.32152 .46911 m
.331 .47933 L
s
0 0 0 r
2.5 Mabswid
.331 .47933 Mdot
.039 .916 .04 r
.5 Mabswid
.32006 .37249 m
.32925 .36499 L
s
0 0 0 r
2.5 Mabswid
.32925 .36499 Mdot
.039 .916 .04 r
.5 Mabswid
.27994 .51262 m
.28461 .53029 L
s
0 0 0 r
2.5 Mabswid
.28461 .53029 Mdot
.039 .916 .04 r
.5 Mabswid
.33018 .40501 m
.3463 .40075 L
s
0 0 0 r
2.5 Mabswid
.3463 .40075 Mdot
.039 .916 .04 r
.5 Mabswid
.31483 .44782 m
.31641 .4471 L
s
0 0 0 r
2.5 Mabswid
.31641 .4471 Mdot
.039 .916 .04 r
.5 Mabswid
.31993 .49494 m
.32657 .50196 L
s
0 0 0 r
2.5 Mabswid
.32657 .50196 Mdot
.039 .916 .04 r
.5 Mabswid
.29078 .3835 m
.28058 .37397 L
s
0 0 0 r
2.5 Mabswid
.28058 .37397 Mdot
.039 .916 .04 r
.5 Mabswid
.32388 .46089 m
.3393 .45897 L
s
0 0 0 r
2.5 Mabswid
.3393 .45897 Mdot
.039 .916 .04 r
.5 Mabswid
.3323 .5164 m
.33833 .52023 L
s
0 0 0 r
2.5 Mabswid
.33833 .52023 Mdot
.039 .916 .04 r
.5 Mabswid
.29913 .40697 m
.30087 .40482 L
s
0 0 0 r
2.5 Mabswid
.30087 .40482 Mdot
.039 .916 .04 r
.5 Mabswid
.28287 .40996 m
.28421 .40785 L
s
0 0 0 r
2.5 Mabswid
.28421 .40785 Mdot
.039 .916 .04 r
.5 Mabswid
.31812 .40779 m
.32032 .39379 L
s
0 0 0 r
2.5 Mabswid
.32032 .39379 Mdot
.039 .916 .04 r
.5 Mabswid
.35325 .59676 m
.35494 .60419 L
s
0 0 0 r
2.5 Mabswid
.35494 .60419 Mdot
.039 .916 .04 r
.5 Mabswid
.3631 .52419 m
.3651 .52569 L
s
0 0 0 r
2.5 Mabswid
.3651 .52569 Mdot
.039 .916 .04 r
.5 Mabswid
.30023 .63939 m
.30171 .64765 L
s
0 0 0 r
2.5 Mabswid
.30171 .64765 Mdot
.039 .916 .04 r
.5 Mabswid
.31714 .57108 m
.32042 .5747 L
s
0 0 0 r
2.5 Mabswid
.32042 .5747 Mdot
.039 .916 .04 r
.5 Mabswid
.33251 .48865 m
.33453 .48211 L
s
0 0 0 r
2.5 Mabswid
.33453 .48211 Mdot
.039 .916 .04 r
.5 Mabswid
.36099 .51903 m
.37262 .51075 L
s
0 0 0 r
2.5 Mabswid
.37262 .51075 Mdot
.039 .916 .04 r
.5 Mabswid
.30313 .49768 m
.30323 .48575 L
s
0 0 0 r
2.5 Mabswid
.30323 .48575 Mdot
.039 .916 .04 r
.5 Mabswid
.3551 .61575 m
.37193 .61004 L
s
0 0 0 r
2.5 Mabswid
.37193 .61004 Mdot
.039 .916 .04 r
.5 Mabswid
.331 .47933 m
.33456 .4828 L
s
0 0 0 r
2.5 Mabswid
.33456 .4828 Mdot
.039 .916 .04 r
.5 Mabswid
.32925 .36499 m
.34142 .35588 L
s
0 0 0 r
2.5 Mabswid
.34142 .35588 Mdot
.039 .916 .04 r
.5 Mabswid
.28461 .53029 m
.28613 .53248 L
s
0 0 0 r
2.5 Mabswid
.28613 .53248 Mdot
.039 .916 .04 r
.5 Mabswid
.3463 .40075 m
.34744 .40033 L
s
0 0 0 r
2.5 Mabswid
.34744 .40033 Mdot
.039 .916 .04 r
.5 Mabswid
.31641 .4471 m
.32814 .4393 L
s
0 0 0 r
2.5 Mabswid
.32814 .4393 Mdot
.039 .916 .04 r
.5 Mabswid
.32657 .50196 m
.33989 .5137 L
s
0 0 0 r
2.5 Mabswid
.33989 .5137 Mdot
.039 .916 .04 r
.5 Mabswid
.28058 .37397 m
.27674 .3695 L
s
0 0 0 r
2.5 Mabswid
.27674 .3695 Mdot
.039 .916 .04 r
.5 Mabswid
.3393 .45897 m
.3523 .45765 L
s
0 0 0 r
2.5 Mabswid
.3523 .45765 Mdot
.039 .916 .04 r
.5 Mabswid
.33833 .52023 m
.35566 .52545 L
s
0 0 0 r
2.5 Mabswid
.35566 .52545 Mdot
.039 .916 .04 r
.5 Mabswid
.30087 .40482 m
.3115 .39049 L
s
0 0 0 r
2.5 Mabswid
.3115 .39049 Mdot
.039 .916 .04 r
.5 Mabswid
.28421 .40785 m
.28926 .404 L
s
0 0 0 r
2.5 Mabswid
.28926 .404 Mdot
.039 .916 .04 r
.5 Mabswid
.32032 .39379 m
.32031 .39354 L
s
0 0 0 r
2.5 Mabswid
.32031 .39354 Mdot
.039 .916 .04 r
.5 Mabswid
.35494 .60419 m
.35527 .60572 L
s
0 0 0 r
2.5 Mabswid
.35527 .60572 Mdot
.039 .916 .04 r
.5 Mabswid
.3651 .52569 m
.36797 .52861 L
s
0 0 0 r
2.5 Mabswid
.36797 .52861 Mdot
.039 .916 .04 r
.5 Mabswid
.30171 .64765 m
.30551 .66519 L
s
0 0 0 r
2.5 Mabswid
.30551 .66519 Mdot
.039 .916 .04 r
.5 Mabswid
.32042 .5747 m
.32277 .57667 L
s
0 0 0 r
2.5 Mabswid
.32277 .57667 Mdot
.039 .916 .04 r
.5 Mabswid
.33453 .48211 m
.33464 .47806 L
s
0 0 0 r
2.5 Mabswid
.33464 .47806 Mdot
.039 .916 .04 r
.5 Mabswid
.37262 .51075 m
.37681 .50957 L
s
0 0 0 r
2.5 Mabswid
.37681 .50957 Mdot
.039 .916 .04 r
.5 Mabswid
.30323 .48575 m
.30357 .46854 L
s
0 0 0 r
2.5 Mabswid
.30357 .46854 Mdot
.039 .916 .04 r
.5 Mabswid
.37193 .61004 m
.38145 .60602 L
s
0 0 0 r
2.5 Mabswid
.38145 .60602 Mdot
.039 .916 .04 r
.5 Mabswid
.33456 .4828 m
.34884 .49403 L
s
0 0 0 r
2.5 Mabswid
.34884 .49403 Mdot
.039 .916 .04 r
.5 Mabswid
.34142 .35588 m
.35251 .35267 L
s
0 0 0 r
2.5 Mabswid
.35251 .35267 Mdot
.039 .916 .04 r
.5 Mabswid
.28613 .53248 m
.29363 .54185 L
s
0 0 0 r
2.5 Mabswid
.29363 .54185 Mdot
.039 .916 .04 r
.5 Mabswid
.34744 .40033 m
.35871 .39813 L
s
0 0 0 r
2.5 Mabswid
.35871 .39813 Mdot
.039 .916 .04 r
.5 Mabswid
.32814 .4393 m
.33837 .43644 L
s
0 0 0 r
2.5 Mabswid
.33837 .43644 Mdot
.039 .916 .04 r
.5 Mabswid
.33989 .5137 m
.34704 .51624 L
s
0 0 0 r
2.5 Mabswid
.34704 .51624 Mdot
.039 .916 .04 r
.5 Mabswid
.27674 .3695 m
.26875 .36093 L
s
0 0 0 r
2.5 Mabswid
.26875 .36093 Mdot
.039 .916 .04 r
.5 Mabswid
.3523 .45765 m
.357 .4579 L
s
0 0 0 r
2.5 Mabswid
.357 .4579 Mdot
.039 .916 .04 r
.5 Mabswid
.35566 .52545 m
.36345 .52646 L
s
0 0 0 r
2.5 Mabswid
.36345 .52646 Mdot
.039 .916 .04 r
.5 Mabswid
.3115 .39049 m
.31191 .39013 L
s
0 0 0 r
2.5 Mabswid
.31191 .39013 Mdot
.039 .916 .04 r
.5 Mabswid
.28926 .404 m
.29805 .39991 L
s
0 0 0 r
2.5 Mabswid
.29805 .39991 Mdot
.039 .916 .04 r
.5 Mabswid
.32031 .39354 m
.31883 .3844 L
s
0 0 0 r
2.5 Mabswid
.31883 .3844 Mdot
.039 .916 .04 r
.5 Mabswid
.35527 .60572 m
.35822 .61588 L
s
0 0 0 r
2.5 Mabswid
.35822 .61588 Mdot
.039 .916 .04 r
.5 Mabswid
.36797 .52861 m
.38069 .53952 L
s
0 0 0 r
2.5 Mabswid
.38069 .53952 Mdot
.039 .916 .04 r
.5 Mabswid
.30551 .66519 m
.31552 .67969 L
s
0 0 0 r
2.5 Mabswid
.31552 .67969 Mdot
.039 .916 .04 r
.5 Mabswid
.32277 .57667 m
.32644 .58072 L
s
0 0 0 r
2.5 Mabswid
.32644 .58072 Mdot
.039 .916 .04 r
.5 Mabswid
.33464 .47806 m
.33263 .47117 L
s
0 0 0 r
2.5 Mabswid
.33263 .47117 Mdot
.039 .916 .04 r
.5 Mabswid
.37681 .50957 m
.39356 .50709 L
s
0 0 0 r
2.5 Mabswid
.39356 .50709 Mdot
.039 .916 .04 r
.5 Mabswid
.30357 .46854 m
.30562 .45418 L
s
0 0 0 r
2.5 Mabswid
.30562 .45418 Mdot
.039 .916 .04 r
.5 Mabswid
.38145 .60602 m
.39386 .60564 L
s
0 0 0 r
2.5 Mabswid
.39386 .60564 Mdot
.039 .916 .04 r
.5 Mabswid
.34884 .49403 m
.35464 .49766 L
s
0 0 0 r
2.5 Mabswid
.35464 .49766 Mdot
.039 .916 .04 r
.5 Mabswid
.35251 .35267 m
.36306 .34682 L
s
0 0 0 r
2.5 Mabswid
.36306 .34682 Mdot
.039 .916 .04 r
.5 Mabswid
.29363 .54185 m
.30285 .55517 L
s
0 0 0 r
2.5 Mabswid
.30285 .55517 Mdot
.039 .916 .04 r
.5 Mabswid
.35871 .39813 m
.36169 .39842 L
s
0 0 0 r
2.5 Mabswid
.36169 .39842 Mdot
.039 .916 .04 r
.5 Mabswid
.33837 .43644 m
.34339 .43351 L
s
0 0 0 r
2.5 Mabswid
.34339 .43351 Mdot
.039 .916 .04 r
.5 Mabswid
.34704 .51624 m
.35204 .51792 L
s
0 0 0 r
2.5 Mabswid
.35204 .51792 Mdot
.039 .916 .04 r
.5 Mabswid
.26875 .36093 m
.26261 .35707 L
s
0 0 0 r
2.5 Mabswid
.26261 .35707 Mdot
.039 .916 .04 r
.5 Mabswid
.357 .4579 m
.3751 .46322 L
s
0 0 0 r
2.5 Mabswid
.3751 .46322 Mdot
.039 .916 .04 r
.5 Mabswid
.36345 .52646 m
.3637 .5264 L
s
0 0 0 r
2.5 Mabswid
.3637 .5264 Mdot
.039 .916 .04 r
.5 Mabswid
.31191 .39013 m
.31302 .38833 L
s
0 0 0 r
2.5 Mabswid
.31302 .38833 Mdot
.039 .916 .04 r
.5 Mabswid
.29805 .39991 m
.30227 .3976 L
s
0 0 0 r
2.5 Mabswid
.30227 .3976 Mdot
.039 .916 .04 r
.5 Mabswid
.31883 .3844 m
.31522 .37643 L
s
0 0 0 r
2.5 Mabswid
.31522 .37643 Mdot
.039 .916 .04 r
.5 Mabswid
.35822 .61588 m
.36832 .62957 L
s
0 0 0 r
2.5 Mabswid
.36832 .62957 Mdot
.039 .916 .04 r
.5 Mabswid
.38069 .53952 m
.38836 .55327 L
s
0 0 0 r
2.5 Mabswid
.38836 .55327 Mdot
.039 .916 .04 r
.5 Mabswid
.31552 .67969 m
.31612 .6805 L
s
0 0 0 r
2.5 Mabswid
.31612 .6805 Mdot
.039 .916 .04 r
.5 Mabswid
.32644 .58072 m
.33774 .58703 L
s
0 0 0 r
2.5 Mabswid
.33774 .58703 Mdot
.039 .916 .04 r
.5 Mabswid
.33263 .47117 m
.32642 .45835 L
s
0 0 0 r
2.5 Mabswid
.32642 .45835 Mdot
.039 .916 .04 r
.5 Mabswid
.39356 .50709 m
.4014 .50661 L
s
0 0 0 r
2.5 Mabswid
.4014 .50661 Mdot
.039 .916 .04 r
.5 Mabswid
.30562 .45418 m
.30447 .44709 L
s
0 0 0 r
2.5 Mabswid
.30447 .44709 Mdot
.039 .916 .04 r
.5 Mabswid
.39386 .60564 m
.40173 .60734 L
s
0 0 0 r
2.5 Mabswid
.40173 .60734 Mdot
.039 .916 .04 r
.5 Mabswid
.35464 .49766 m
.36161 .49909 L
s
0 0 0 r
2.5 Mabswid
.36161 .49909 Mdot
.039 .916 .04 r
.5 Mabswid
.36306 .34682 m
.36876 .34461 L
s
0 0 0 r
2.5 Mabswid
.36876 .34461 Mdot
.039 .916 .04 r
.5 Mabswid
.30285 .55517 m
.30405 .55736 L
s
0 0 0 r
2.5 Mabswid
.30405 .55736 Mdot
.039 .916 .04 r
.5 Mabswid
.36169 .39842 m
.37801 .40011 L
s
0 0 0 r
2.5 Mabswid
.37801 .40011 Mdot
.039 .916 .04 r
.5 Mabswid
.34339 .43351 m
.34744 .43147 L
s
0 0 0 r
2.5 Mabswid
.34744 .43147 Mdot
.039 .916 .04 r
.5 Mabswid
.35204 .51792 m
.35284 .51823 L
s
0 0 0 r
2.5 Mabswid
.35284 .51823 Mdot
.039 .916 .04 r
.5 Mabswid
.26261 .35707 m
.25903 .35611 L
s
0 0 0 r
2.5 Mabswid
.25903 .35611 Mdot
.039 .916 .04 r
.5 Mabswid
.3751 .46322 m
.38182 .46505 L
s
0 0 0 r
2.5 Mabswid
.38182 .46505 Mdot
.039 .916 .04 r
.5 Mabswid
.3637 .5264 m
.37221 .52683 L
s
0 0 0 r
2.5 Mabswid
.37221 .52683 Mdot
.039 .916 .04 r
.5 Mabswid
.31302 .38833 m
.32656 .37623 L
s
0 0 0 r
2.5 Mabswid
.32656 .37623 Mdot
.039 .916 .04 r
.5 Mabswid
.30227 .3976 m
.30371 .39711 L
s
0 0 0 r
2.5 Mabswid
.30371 .39711 Mdot
.039 .916 .04 r
.5 Mabswid
.31522 .37643 m
.30805 .36904 L
s
0 0 0 r
2.5 Mabswid
.30805 .36904 Mdot
.039 .916 .04 r
.5 Mabswid
.36832 .62957 m
.3748 .64136 L
s
0 0 0 r
2.5 Mabswid
.3748 .64136 Mdot
.039 .916 .04 r
.5 Mabswid
.38836 .55327 m
.39082 .55689 L
s
0 0 0 r
2.5 Mabswid
.39082 .55689 Mdot
.039 .916 .04 r
.5 Mabswid
.31612 .6805 m
.32547 .68656 L
s
0 0 0 r
2.5 Mabswid
.32547 .68656 Mdot
.039 .916 .04 r
.5 Mabswid
.33774 .58703 m
.34261 .59207 L
s
0 0 0 r
2.5 Mabswid
.34261 .59207 Mdot
.039 .916 .04 r
.5 Mabswid
.32642 .45835 m
.32327 .45233 L
s
0 0 0 r
2.5 Mabswid
.32327 .45233 Mdot
.039 .916 .04 r
.5 Mabswid
.4014 .50661 m
.4076 .5053 L
s
0 0 0 r
2.5 Mabswid
.4076 .5053 Mdot
.039 .916 .04 r
.5 Mabswid
.30447 .44709 m
.30356 .44394 L
s
0 0 0 r
2.5 Mabswid
.30356 .44394 Mdot
.039 .916 .04 r
.5 Mabswid
.40173 .60734 m
.41808 .61583 L
s
0 0 0 r
2.5 Mabswid
.41808 .61583 Mdot
.039 .916 .04 r
.5 Mabswid
.36161 .49909 m
.37511 .502 L
s
0 0 0 r
2.5 Mabswid
.37511 .502 Mdot
.039 .916 .04 r
.5 Mabswid
.36876 .34461 m
.36922 .34461 L
s
0 0 0 r
2.5 Mabswid
.36922 .34461 Mdot
.039 .916 .04 r
.5 Mabswid
.30405 .55736 m
.30736 .56938 L
s
0 0 0 r
2.5 Mabswid
.30736 .56938 Mdot
.039 .916 .04 r
.5 Mabswid
.37801 .40011 m
.38639 .40391 L
s
0 0 0 r
2.5 Mabswid
.38639 .40391 Mdot
.039 .916 .04 r
.5 Mabswid
.34744 .43147 m
.36058 .41906 L
s
0 0 0 r
2.5 Mabswid
.36058 .41906 Mdot
.039 .916 .04 r
.5 Mabswid
.35284 .51823 m
.35748 .52014 L
s
0 0 0 r
2.5 Mabswid
.35748 .52014 Mdot
.039 .916 .04 r
.5 Mabswid
.25903 .35611 m
.25193 .35654 L
s
0 0 0 r
2.5 Mabswid
.25193 .35654 Mdot
.039 .916 .04 r
.5 Mabswid
.38182 .46505 m
.39762 .47148 L
s
0 0 0 r
2.5 Mabswid
.39762 .47148 Mdot
.039 .916 .04 r
.5 Mabswid
.37221 .52683 m
.37271 .52691 L
s
0 0 0 r
2.5 Mabswid
.37271 .52691 Mdot
.039 .916 .04 r
.5 Mabswid
.32656 .37623 m
.33371 .368 L
s
0 0 0 r
2.5 Mabswid
.33371 .368 Mdot
.039 .916 .04 r
.5 Mabswid
.30371 .39711 m
.31799 .38929 L
s
0 0 0 r
2.5 Mabswid
.31799 .38929 Mdot
.039 .916 .04 r
.5 Mabswid
.30805 .36904 m
.30001 .36077 L
s
0 0 0 r
2.5 Mabswid
.30001 .36077 Mdot
.039 .916 .04 r
.5 Mabswid
.3748 .64136 m
.37555 .64391 L
s
0 0 0 r
2.5 Mabswid
.37555 .64391 Mdot
.039 .916 .04 r
.5 Mabswid
.39082 .55689 m
.39697 .56633 L
s
0 0 0 r
2.5 Mabswid
.39697 .56633 Mdot
.039 .916 .04 r
.5 Mabswid
.32547 .68656 m
.33087 .69406 L
s
0 0 0 r
2.5 Mabswid
.33087 .69406 Mdot
.039 .916 .04 r
.5 Mabswid
.34261 .59207 m
.34402 .59383 L
s
0 0 0 r
2.5 Mabswid
.34402 .59383 Mdot
.039 .916 .04 r
.5 Mabswid
.32327 .45233 m
.32112 .44234 L
s
0 0 0 r
2.5 Mabswid
.32112 .44234 Mdot
.039 .916 .04 r
.5 Mabswid
.4076 .5053 m
.42165 .49707 L
s
0 0 0 r
2.5 Mabswid
.42165 .49707 Mdot
.039 .916 .04 r
.5 Mabswid
.30356 .44394 m
.30328 .44066 L
s
0 0 0 r
2.5 Mabswid
.30328 .44066 Mdot
.039 .916 .04 r
.5 Mabswid
.41808 .61583 m
.43469 .62344 L
s
0 0 0 r
2.5 Mabswid
.43469 .62344 Mdot
.039 .916 .04 r
.5 Mabswid
.37511 .502 m
.37807 .50176 L
s
0 0 0 r
2.5 Mabswid
.37807 .50176 Mdot
.039 .916 .04 r
.5 Mabswid
.36922 .34461 m
.3764 .34228 L
s
0 0 0 r
2.5 Mabswid
.3764 .34228 Mdot
.039 .916 .04 r
.5 Mabswid
.30736 .56938 m
.30738 .57513 L
s
0 0 0 r
2.5 Mabswid
.30738 .57513 Mdot
.039 .916 .04 r
.5 Mabswid
.38639 .40391 m
.39958 .4112 L
s
0 0 0 r
2.5 Mabswid
.39958 .4112 Mdot
.039 .916 .04 r
.5 Mabswid
.36058 .41906 m
.36207 .41614 L
s
0 0 0 r
2.5 Mabswid
.36207 .41614 Mdot
.039 .916 .04 r
.5 Mabswid
.35748 .52014 m
.36147 .52036 L
s
0 0 0 r
2.5 Mabswid
.36147 .52036 Mdot
.039 .916 .04 r
.5 Mabswid
.25193 .35654 m
.23978 .36141 L
s
0 0 0 r
2.5 Mabswid
.23978 .36141 Mdot
.039 .916 .04 r
.5 Mabswid
.39762 .47148 m
.39942 .47214 L
s
0 0 0 r
2.5 Mabswid
.39942 .47214 Mdot
.039 .916 .04 r
.5 Mabswid
.37271 .52691 m
.37577 .52676 L
s
0 0 0 r
2.5 Mabswid
.37577 .52676 Mdot
.039 .916 .04 r
.5 Mabswid
.33371 .368 m
.33639 .36415 L
s
0 0 0 r
2.5 Mabswid
.33639 .36415 Mdot
.039 .916 .04 r
.5 Mabswid
.31799 .38929 m
.33444 .38015 L
s
0 0 0 r
2.5 Mabswid
.33444 .38015 Mdot
.039 .916 .04 r
.5 Mabswid
.30001 .36077 m
.2977 .35581 L
s
0 0 0 r
2.5 Mabswid
.2977 .35581 Mdot
.039 .916 .04 r
.5 Mabswid
.37555 .64391 m
.38169 .65873 L
s
0 0 0 r
2.5 Mabswid
.38169 .65873 Mdot
.039 .916 .04 r
.5 Mabswid
.39697 .56633 m
.4023 .58243 L
s
0 0 0 r
2.5 Mabswid
.4023 .58243 Mdot
.039 .916 .04 r
.5 Mabswid
.33087 .69406 m
.3368 .7027 L
s
0 0 0 r
2.5 Mabswid
.3368 .7027 Mdot
.039 .916 .04 r
.5 Mabswid
.34402 .59383 m
.34564 .59514 L
s
0 0 0 r
2.5 Mabswid
.34564 .59514 Mdot
.039 .916 .04 r
.5 Mabswid
.32112 .44234 m
.31936 .43516 L
s
0 0 0 r
2.5 Mabswid
.31936 .43516 Mdot
.039 .916 .04 r
.5 Mabswid
.42165 .49707 m
.43358 .48477 L
s
0 0 0 r
2.5 Mabswid
.43358 .48477 Mdot
.039 .916 .04 r
.5 Mabswid
.30328 .44066 m
.30084 .42753 L
s
0 0 0 r
2.5 Mabswid
.30084 .42753 Mdot
.039 .916 .04 r
.5 Mabswid
.43469 .62344 m
.44751 .63198 L
s
0 0 0 r
2.5 Mabswid
.44751 .63198 Mdot
.039 .916 .04 r
.5 Mabswid
.37807 .50176 m
.38782 .49791 L
s
0 0 0 r
2.5 Mabswid
.38782 .49791 Mdot
.039 .916 .04 r
.5 Mabswid
.3764 .34228 m
.38626 .33761 L
s
0 0 0 r
2.5 Mabswid
.38626 .33761 Mdot
.039 .916 .04 r
.5 Mabswid
.30738 .57513 m
.30628 .58578 L
s
0 0 0 r
2.5 Mabswid
.30628 .58578 Mdot
.039 .916 .04 r
.5 Mabswid
.39958 .4112 m
.40468 .41357 L
s
0 0 0 r
2.5 Mabswid
.40468 .41357 Mdot
.039 .916 .04 r
.5 Mabswid
.36207 .41614 m
.36599 .403 L
s
0 0 0 r
2.5 Mabswid
.36599 .403 Mdot
.039 .916 .04 r
.5 Mabswid
.36147 .52036 m
.36913 .52129 L
s
0 0 0 r
2.5 Mabswid
.36913 .52129 Mdot
.039 .916 .04 r
.5 Mabswid
.23978 .36141 m
.23641 .36207 L
s
0 0 0 r
2.5 Mabswid
.23641 .36207 Mdot
.039 .916 .04 r
.5 Mabswid
.39942 .47214 m
.40509 .47351 L
s
0 0 0 r
2.5 Mabswid
.40509 .47351 Mdot
.039 .916 .04 r
.5 Mabswid
.37577 .52676 m
.39048 .52343 L
s
0 0 0 r
2.5 Mabswid
.39048 .52343 Mdot
.039 .916 .04 r
.5 Mabswid
.33639 .36415 m
.33921 .35694 L
s
0 0 0 r
2.5 Mabswid
.33921 .35694 Mdot
.039 .916 .04 r
.5 Mabswid
.33444 .38015 m
.33632 .37979 L
s
0 0 0 r
2.5 Mabswid
.33632 .37979 Mdot
.039 .916 .04 r
.5 Mabswid
.2977 .35581 m
.29289 .3455 L
s
0 0 0 r
2.5 Mabswid
.29289 .3455 Mdot
.039 .916 .04 r
.5 Mabswid
.38169 .65873 m
.3835 .66906 L
s
0 0 0 r
2.5 Mabswid
.3835 .66906 Mdot
.039 .916 .04 r
.5 Mabswid
.4023 .58243 m
.40267 .58299 L
s
0 0 0 r
2.5 Mabswid
.40267 .58299 Mdot
.039 .916 .04 r
.5 Mabswid
.3368 .7027 m
.35132 .71468 L
s
0 0 0 r
2.5 Mabswid
.35132 .71468 Mdot
.039 .916 .04 r
.5 Mabswid
.34564 .59514 m
.35462 .60599 L
s
0 0 0 r
2.5 Mabswid
.35462 .60599 Mdot
.039 .916 .04 r
.5 Mabswid
.31936 .43516 m
.31965 .42986 L
s
0 0 0 r
2.5 Mabswid
.31965 .42986 Mdot
.039 .916 .04 r
.5 Mabswid
.43358 .48477 m
.43679 .47904 L
s
0 0 0 r
2.5 Mabswid
.43679 .47904 Mdot
.039 .916 .04 r
.5 Mabswid
.30084 .42753 m
.29991 .42569 L
s
0 0 0 r
2.5 Mabswid
.29991 .42569 Mdot
.039 .916 .04 r
.5 Mabswid
.44751 .63198 m
.44813 .63266 L
s
0 0 0 r
2.5 Mabswid
.44813 .63266 Mdot
.039 .916 .04 r
.5 Mabswid
.38782 .49791 m
.39382 .49735 L
s
0 0 0 r
2.5 Mabswid
.39382 .49735 Mdot
.039 .916 .04 r
.5 Mabswid
.38626 .33761 m
.39773 .33337 L
s
0 0 0 r
2.5 Mabswid
.39773 .33337 Mdot
.039 .916 .04 r
.5 Mabswid
.30628 .58578 m
.30438 .58963 L
s
0 0 0 r
2.5 Mabswid
.30438 .58963 Mdot
.039 .916 .04 r
.5 Mabswid
.40468 .41357 m
.40572 .41371 L
s
0 0 0 r
2.5 Mabswid
.40572 .41371 Mdot
.039 .916 .04 r
.5 Mabswid
.36599 .403 m
.36644 .39015 L
s
0 0 0 r
2.5 Mabswid
.36644 .39015 Mdot
.039 .916 .04 r
.5 Mabswid
.36913 .52129 m
.36963 .52155 L
s
0 0 0 r
2.5 Mabswid
.36963 .52155 Mdot
.039 .916 .04 r
.5 Mabswid
.23641 .36207 m
.22535 .36903 L
s
0 0 0 r
2.5 Mabswid
.22535 .36903 Mdot
.039 .916 .04 r
.5 Mabswid
.40509 .47351 m
.41062 .47352 L
s
0 0 0 r
2.5 Mabswid
.41062 .47352 Mdot
.039 .916 .04 r
.5 Mabswid
.39048 .52343 m
.39749 .51967 L
s
0 0 0 r
2.5 Mabswid
.39749 .51967 Mdot
.039 .916 .04 r
.5 Mabswid
.33921 .35694 m
.33926 .33892 L
s
0 0 0 r
2.5 Mabswid
.33926 .33892 Mdot
.039 .916 .04 r
.5 Mabswid
.33632 .37979 m
.34146 .37652 L
s
0 0 0 r
2.5 Mabswid
.34146 .37652 Mdot
.039 .916 .04 r
.5 Mabswid
.29289 .3455 m
.28229 .33185 L
s
0 0 0 r
2.5 Mabswid
.28229 .33185 Mdot
.039 .916 .04 r
.5 Mabswid
.3835 .66906 m
.38361 .66928 L
s
0 0 0 r
2.5 Mabswid
.38361 .66928 Mdot
.039 .916 .04 r
.5 Mabswid
.40267 .58299 m
.40519 .58758 L
s
0 0 0 r
2.5 Mabswid
.40519 .58758 Mdot
.039 .916 .04 r
.5 Mabswid
.35132 .71468 m
.36476 .72133 L
s
0 0 0 r
2.5 Mabswid
.36476 .72133 Mdot
.039 .916 .04 r
.5 Mabswid
.35462 .60599 m
.35745 .60934 L
s
0 0 0 r
2.5 Mabswid
.35745 .60934 Mdot
.039 .916 .04 r
.5 Mabswid
.31965 .42986 m
.31893 .42765 L
s
0 0 0 r
2.5 Mabswid
.31893 .42765 Mdot
.039 .916 .04 r
.5 Mabswid
.43679 .47904 m
.43885 .47561 L
s
0 0 0 r
2.5 Mabswid
.43885 .47561 Mdot
.039 .916 .04 r
.5 Mabswid
.29991 .42569 m
.2936 .42029 L
s
0 0 0 r
2.5 Mabswid
.2936 .42029 Mdot
.039 .916 .04 r
.5 Mabswid
.44813 .63266 m
.46143 .64406 L
s
0 0 0 r
2.5 Mabswid
.46143 .64406 Mdot
.039 .916 .04 r
.5 Mabswid
.39382 .49735 m
.39435 .49744 L
s
0 0 0 r
2.5 Mabswid
.39435 .49744 Mdot
.039 .916 .04 r
.5 Mabswid
.39773 .33337 m
.414 .32445 L
s
0 0 0 r
2.5 Mabswid
.414 .32445 Mdot
.039 .916 .04 r
.5 Mabswid
.30438 .58963 m
.29553 .59983 L
s
0 0 0 r
2.5 Mabswid
.29553 .59983 Mdot
.039 .916 .04 r
.5 Mabswid
.40572 .41371 m
.40715 .41344 L
s
0 0 0 r
2.5 Mabswid
.40715 .41344 Mdot
.039 .916 .04 r
.5 Mabswid
.36644 .39015 m
.36864 .37689 L
s
0 0 0 r
2.5 Mabswid
.36864 .37689 Mdot
.039 .916 .04 r
.5 Mabswid
.36963 .52155 m
.38325 .52845 L
s
0 0 0 r
2.5 Mabswid
.38325 .52845 Mdot
.039 .916 .04 r
.5 Mabswid
.22535 .36903 m
.2143 .37649 L
s
0 0 0 r
2.5 Mabswid
.2143 .37649 Mdot
.039 .916 .04 r
.5 Mabswid
.41062 .47352 m
.42681 .46688 L
s
0 0 0 r
2.5 Mabswid
.42681 .46688 Mdot
.039 .916 .04 r
.5 Mabswid
.39749 .51967 m
.40693 .51386 L
s
0 0 0 r
2.5 Mabswid
.40693 .51386 Mdot
.039 .916 .04 r
.5 Mabswid
.33926 .33892 m
.33889 .32357 L
s
0 0 0 r
2.5 Mabswid
.33889 .32357 Mdot
.039 .916 .04 r
.5 Mabswid
.34146 .37652 m
.34735 .37227 L
s
0 0 0 r
2.5 Mabswid
.34735 .37227 Mdot
.039 .916 .04 r
.5 Mabswid
.28229 .33185 m
.27637 .32766 L
s
0 0 0 r
2.5 Mabswid
.27637 .32766 Mdot
.039 .916 .04 r
.5 Mabswid
.38361 .66928 m
.38684 .67746 L
s
0 0 0 r
2.5 Mabswid
.38684 .67746 Mdot
.039 .916 .04 r
.5 Mabswid
.40519 .58758 m
.40696 .59425 L
s
0 0 0 r
2.5 Mabswid
.40696 .59425 Mdot
.039 .916 .04 r
.5 Mabswid
.36476 .72133 m
.37209 .72703 L
s
0 0 0 r
2.5 Mabswid
.37209 .72703 Mdot
.039 .916 .04 r
.5 Mabswid
.35745 .60934 m
.36374 .62008 L
s
0 0 0 r
2.5 Mabswid
.36374 .62008 Mdot
.039 .916 .04 r
.5 Mabswid
.31893 .42765 m
.31418 .42119 L
s
0 0 0 r
2.5 Mabswid
.31418 .42119 Mdot
.039 .916 .04 r
.5 Mabswid
.43885 .47561 m
.4446 .4585 L
s
0 0 0 r
2.5 Mabswid
.4446 .4585 Mdot
.039 .916 .04 r
.5 Mabswid
.2936 .42029 m
.2855 .41171 L
s
0 0 0 r
2.5 Mabswid
.2855 .41171 Mdot
.039 .916 .04 r
.5 Mabswid
.46143 .64406 m
.46209 .64441 L
s
0 0 0 r
2.5 Mabswid
.46209 .64441 Mdot
.039 .916 .04 r
.5 Mabswid
.39435 .49744 m
.39526 .49739 L
s
0 0 0 r
2.5 Mabswid
.39526 .49739 Mdot
.039 .916 .04 r
.5 Mabswid
.414 .32445 m
.41823 .32313 L
s
0 0 0 r
2.5 Mabswid
.41823 .32313 Mdot
.039 .916 .04 r
.5 Mabswid
.29553 .59983 m
.2853 .60735 L
s
0 0 0 r
2.5 Mabswid
.2853 .60735 Mdot
.039 .916 .04 r
.5 Mabswid
.40715 .41344 m
.42332 .41206 L
s
0 0 0 r
2.5 Mabswid
.42332 .41206 Mdot
.039 .916 .04 r
.5 Mabswid
.36864 .37689 m
.36835 .37281 L
s
0 0 0 r
2.5 Mabswid
.36835 .37281 Mdot
.039 .916 .04 r
.5 Mabswid
.38325 .52845 m
.39043 .53471 L
s
0 0 0 r
2.5 Mabswid
.39043 .53471 Mdot
.039 .916 .04 r
.5 Mabswid
.2143 .37649 m
.21429 .37651 L
s
0 0 0 r
2.5 Mabswid
.21429 .37651 Mdot
.039 .916 .04 r
.5 Mabswid
.42681 .46688 m
.43939 .46108 L
s
0 0 0 r
2.5 Mabswid
.43939 .46108 Mdot
.039 .916 .04 r
.5 Mabswid
.40693 .51386 m
.41736 .50159 L
s
0 0 0 r
2.5 Mabswid
.41736 .50159 Mdot
.039 .916 .04 r
.5 Mabswid
.33889 .32357 m
.33805 .3176 L
s
0 0 0 r
2.5 Mabswid
.33805 .3176 Mdot
.039 .916 .04 r
.5 Mabswid
.34735 .37227 m
.36353 .36673 L
s
0 0 0 r
2.5 Mabswid
.36353 .36673 Mdot
.039 .916 .04 r
.5 Mabswid
.27637 .32766 m
.267 .31826 L
s
0 0 0 r
2.5 Mabswid
.267 .31826 Mdot
.039 .916 .04 r
.5 Mabswid
.38684 .67746 m
.39099 .69348 L
s
0 0 0 r
2.5 Mabswid
.39099 .69348 Mdot
.039 .916 .04 r
.5 Mabswid
.40696 .59425 m
.41007 .60641 L
s
0 0 0 r
2.5 Mabswid
.41007 .60641 Mdot
.039 .916 .04 r
.5 Mabswid
.37209 .72703 m
.37954 .73808 L
s
0 0 0 r
2.5 Mabswid
.37954 .73808 Mdot
.039 .916 .04 r
.5 Mabswid
.36374 .62008 m
.36798 .63164 L
s
0 0 0 r
2.5 Mabswid
.36798 .63164 Mdot
.039 .916 .04 r
.5 Mabswid
.31418 .42119 m
.30048 .40816 L
s
0 0 0 r
2.5 Mabswid
.30048 .40816 Mdot
.039 .916 .04 r
.5 Mabswid
.4446 .4585 m
.44971 .44426 L
s
0 0 0 r
2.5 Mabswid
.44971 .44426 Mdot
.039 .916 .04 r
.5 Mabswid
.2855 .41171 m
.27486 .40114 L
s
0 0 0 r
2.5 Mabswid
.27486 .40114 Mdot
.039 .916 .04 r
.5 Mabswid
.46209 .64441 m
.46782 .64534 L
s
0 0 0 r
2.5 Mabswid
.46782 .64534 Mdot
.039 .916 .04 r
.5 Mabswid
.39526 .49739 m
.39659 .49718 L
s
0 0 0 r
2.5 Mabswid
.39659 .49718 Mdot
.039 .916 .04 r
.5 Mabswid
.41823 .32313 m
.4269 .32207 L
s
0 0 0 r
2.5 Mabswid
.4269 .32207 Mdot
.039 .916 .04 r
.5 Mabswid
.2853 .60735 m
.27383 .616 L
s
0 0 0 r
2.5 Mabswid
.27383 .616 Mdot
.039 .916 .04 r
.5 Mabswid
.42332 .41206 m
.43286 .40724 L
s
0 0 0 r
2.5 Mabswid
.43286 .40724 Mdot
.039 .916 .04 r
.5 Mabswid
.36835 .37281 m
.36859 .37154 L
s
0 0 0 r
2.5 Mabswid
.36859 .37154 Mdot
.039 .916 .04 r
.5 Mabswid
.39043 .53471 m
.40034 .54339 L
s
0 0 0 r
2.5 Mabswid
.40034 .54339 Mdot
.039 .916 .04 r
.5 Mabswid
.43939 .46108 m
.44713 .46032 L
s
0 0 0 r
2.5 Mabswid
.44713 .46032 Mdot
.039 .916 .04 r
.5 Mabswid
.41736 .50159 m
.4182 .50095 L
s
0 0 0 r
2.5 Mabswid
.4182 .50095 Mdot
.039 .916 .04 r
.5 Mabswid
.33805 .3176 m
.33787 .30968 L
s
0 0 0 r
2.5 Mabswid
.33787 .30968 Mdot
.039 .916 .04 r
.5 Mabswid
.36353 .36673 m
.36783 .36423 L
s
0 0 0 r
2.5 Mabswid
.36783 .36423 Mdot
.039 .916 .04 r
.5 Mabswid
.267 .31826 m
.25677 .31205 L
s
0 0 0 r
2.5 Mabswid
.25677 .31205 Mdot
.039 .916 .04 r
.5 Mabswid
.39099 .69348 m
.39997 .70933 L
s
0 0 0 r
2.5 Mabswid
.39997 .70933 Mdot
.039 .916 .04 r
.5 Mabswid
.41007 .60641 m
.40997 .61723 L
s
0 0 0 r
2.5 Mabswid
.40997 .61723 Mdot
.039 .916 .04 r
.5 Mabswid
.37954 .73808 m
.37955 .7381 L
s
0 0 0 r
2.5 Mabswid
.37955 .7381 Mdot
.039 .916 .04 r
.5 Mabswid
.36798 .63164 m
.37176 .64055 L
s
0 0 0 r
2.5 Mabswid
.37176 .64055 Mdot
.039 .916 .04 r
.5 Mabswid
.30048 .40816 m
.28804 .39893 L
s
0 0 0 r
2.5 Mabswid
.28804 .39893 Mdot
.039 .916 .04 r
.5 Mabswid
.44971 .44426 m
.45477 .42694 L
s
0 0 0 r
2.5 Mabswid
.45477 .42694 Mdot
.039 .916 .04 r
.5 Mabswid
.27486 .40114 m
.26477 .39087 L
s
0 0 0 r
2.5 Mabswid
.26477 .39087 Mdot
.039 .916 .04 r
.5 Mabswid
.46782 .64534 m
.47228 .64772 L
s
0 0 0 r
2.5 Mabswid
.47228 .64772 Mdot
.039 .916 .04 r
.5 Mabswid
.39659 .49718 m
.40336 .49656 L
s
0 0 0 r
2.5 Mabswid
.40336 .49656 Mdot
.039 .916 .04 r
.5 Mabswid
.4269 .32207 m
.43076 .32043 L
s
0 0 0 r
2.5 Mabswid
.43076 .32043 Mdot
.039 .916 .04 r
.5 Mabswid
.27383 .616 m
.25671 .62132 L
s
0 0 0 r
2.5 Mabswid
.25671 .62132 Mdot
.039 .916 .04 r
.5 Mabswid
.43286 .40724 m
.45089 .40436 L
s
0 0 0 r
2.5 Mabswid
.45089 .40436 Mdot
.039 .916 .04 r
.5 Mabswid
.36859 .37154 m
.37088 .36584 L
s
0 0 0 r
2.5 Mabswid
.37088 .36584 Mdot
.039 .916 .04 r
.5 Mabswid
.40034 .54339 m
.40048 .54357 L
s
0 0 0 r
2.5 Mabswid
.40048 .54357 Mdot
.039 .916 .04 r
.5 Mabswid
.44713 .46032 m
.46113 .46358 L
s
0 0 0 r
2.5 Mabswid
.46113 .46358 Mdot
.039 .916 .04 r
.5 Mabswid
.4182 .50095 m
.42481 .49397 L
s
0 0 0 r
2.5 Mabswid
.42481 .49397 Mdot
.039 .916 .04 r
.5 Mabswid
.33787 .30968 m
.3385 .29176 L
s
0 0 0 r
2.5 Mabswid
.3385 .29176 Mdot
.039 .916 .04 r
.5 Mabswid
.36783 .36423 m
.37815 .36174 L
s
0 0 0 r
2.5 Mabswid
.37815 .36174 Mdot
.039 .916 .04 r
.5 Mabswid
.25677 .31205 m
.25312 .31133 L
s
0 0 0 r
2.5 Mabswid
.25312 .31133 Mdot
.039 .916 .04 r
.5 Mabswid
.39997 .70933 m
.40089 .715 L
s
0 0 0 r
2.5 Mabswid
.40089 .715 Mdot
.039 .916 .04 r
.5 Mabswid
.40997 .61723 m
.41024 .63319 L
s
0 0 0 r
2.5 Mabswid
.41024 .63319 Mdot
.039 .916 .04 r
.5 Mabswid
.37176 .64055 m
.37204 .64226 L
s
0 0 0 r
2.5 Mabswid
.37204 .64226 Mdot
.039 .916 .04 r
.5 Mabswid
.28804 .39893 m
.27455 .38844 L
s
0 0 0 r
2.5 Mabswid
.27455 .38844 Mdot
.039 .916 .04 r
.5 Mabswid
.45477 .42694 m
.45621 .42487 L
s
0 0 0 r
2.5 Mabswid
.45621 .42487 Mdot
.039 .916 .04 r
.5 Mabswid
.26477 .39087 m
.2589 .3814 L
s
0 0 0 r
2.5 Mabswid
.2589 .3814 Mdot
.039 .916 .04 r
.5 Mabswid
.47228 .64772 m
.47469 .64831 L
s
0 0 0 r
2.5 Mabswid
.47469 .64831 Mdot
.039 .916 .04 r
.5 Mabswid
.40336 .49656 m
.41887 .49965 L
s
0 0 0 r
2.5 Mabswid
.41887 .49965 Mdot
.039 .916 .04 r
.5 Mabswid
.43076 .32043 m
.44263 .31932 L
s
0 0 0 r
2.5 Mabswid
.44263 .31932 Mdot
.039 .916 .04 r
.5 Mabswid
.25671 .62132 m
.24156 .62889 L
s
0 0 0 r
2.5 Mabswid
.24156 .62889 Mdot
.039 .916 .04 r
.5 Mabswid
.45089 .40436 m
.45218 .4036 L
s
0 0 0 r
2.5 Mabswid
.45218 .4036 Mdot
.039 .916 .04 r
.5 Mabswid
.37088 .36584 m
.37322 .35264 L
s
0 0 0 r
2.5 Mabswid
.37322 .35264 Mdot
.039 .916 .04 r
.5 Mabswid
.40048 .54357 m
.413 .55146 L
s
0 0 0 r
2.5 Mabswid
.413 .55146 Mdot
.039 .916 .04 r
.5 Mabswid
.46113 .46358 m
.47604 .47062 L
s
0 0 0 r
2.5 Mabswid
.47604 .47062 Mdot
.039 .916 .04 r
.5 Mabswid
.42481 .49397 m
.43199 .48284 L
s
0 0 0 r
2.5 Mabswid
.43199 .48284 Mdot
.039 .916 .04 r
.5 Mabswid
.3385 .29176 m
.3354 .27358 L
s
0 0 0 r
2.5 Mabswid
.3354 .27358 Mdot
.039 .916 .04 r
.5 Mabswid
.37815 .36174 m
.38839 .35796 L
s
0 0 0 r
2.5 Mabswid
.38839 .35796 Mdot
.039 .916 .04 r
.5 Mabswid
.25312 .31133 m
.24572 .3101 L
s
0 0 0 r
2.5 Mabswid
.24572 .3101 Mdot
.039 .916 .04 r
.5 Mabswid
.40089 .715 m
.40444 .72287 L
s
0 0 0 r
2.5 Mabswid
.40444 .72287 Mdot
.039 .916 .04 r
.5 Mabswid
.41024 .63319 m
.40964 .64391 L
s
0 0 0 r
2.5 Mabswid
.40964 .64391 Mdot
.039 .916 .04 r
.5 Mabswid
.37204 .64226 m
.37726 .65714 L
s
0 0 0 r
2.5 Mabswid
.37726 .65714 Mdot
.039 .916 .04 r
.5 Mabswid
.27455 .38844 m
.26328 .38225 L
s
0 0 0 r
2.5 Mabswid
.26328 .38225 Mdot
.039 .916 .04 r
.5 Mabswid
.45621 .42487 m
.46202 .41163 L
s
0 0 0 r
2.5 Mabswid
.46202 .41163 Mdot
.039 .916 .04 r
.5 Mabswid
.2589 .3814 m
.24441 .36991 L
s
0 0 0 r
2.5 Mabswid
.24441 .36991 Mdot
.039 .916 .04 r
.5 Mabswid
.47469 .64831 m
.4934 .64814 L
s
0 0 0 r
2.5 Mabswid
.4934 .64814 Mdot
.039 .916 .04 r
.5 Mabswid
.41887 .49965 m
.42106 .49971 L
s
0 0 0 r
2.5 Mabswid
.42106 .49971 Mdot
.039 .916 .04 r
.5 Mabswid
.44263 .31932 m
.44813 .32063 L
s
0 0 0 r
2.5 Mabswid
.44813 .32063 Mdot
.039 .916 .04 r
.5 Mabswid
.24156 .62889 m
.23965 .63093 L
s
0 0 0 r
2.5 Mabswid
.23965 .63093 Mdot
.039 .916 .04 r
.5 Mabswid
.45218 .4036 m
.46439 .3972 L
s
0 0 0 r
2.5 Mabswid
.46439 .3972 Mdot
.039 .916 .04 r
.5 Mabswid
.37322 .35264 m
.37672 .33873 L
s
0 0 0 r
2.5 Mabswid
.37672 .33873 Mdot
.039 .916 .04 r
.5 Mabswid
.413 .55146 m
.41773 .55394 L
s
0 0 0 r
2.5 Mabswid
.41773 .55394 Mdot
.039 .916 .04 r
.5 Mabswid
.47604 .47062 m
.47859 .47343 L
s
0 0 0 r
2.5 Mabswid
.47859 .47343 Mdot
.039 .916 .04 r
.5 Mabswid
.43199 .48284 m
.43434 .47455 L
s
0 0 0 r
2.5 Mabswid
.43434 .47455 Mdot
.039 .916 .04 r
.5 Mabswid
.3354 .27358 m
.33527 .26192 L
s
0 0 0 r
2.5 Mabswid
.33527 .26192 Mdot
.039 .916 .04 r
.5 Mabswid
.38839 .35796 m
.39836 .35734 L
s
0 0 0 r
2.5 Mabswid
.39836 .35734 Mdot
.039 .916 .04 r
.5 Mabswid
.24572 .3101 m
.23301 .30652 L
s
0 0 0 r
2.5 Mabswid
.23301 .30652 Mdot
.039 .916 .04 r
.5 Mabswid
.40444 .72287 m
.40872 .73808 L
s
0 0 0 r
2.5 Mabswid
.40872 .73808 Mdot
.039 .916 .04 r
.5 Mabswid
.40964 .64391 m
.41029 .65443 L
s
0 0 0 r
2.5 Mabswid
.41029 .65443 Mdot
.039 .916 .04 r
.5 Mabswid
.37726 .65714 m
.37892 .67058 L
s
0 0 0 r
2.5 Mabswid
.37892 .67058 Mdot
.039 .916 .04 r
.5 Mabswid
.26328 .38225 m
.25525 .37935 L
s
0 0 0 r
2.5 Mabswid
.25525 .37935 Mdot
.039 .916 .04 r
.5 Mabswid
.46202 .41163 m
.46351 .40369 L
s
0 0 0 r
2.5 Mabswid
.46351 .40369 Mdot
.039 .916 .04 r
.5 Mabswid
.24441 .36991 m
.24044 .3655 L
s
0 0 0 r
2.5 Mabswid
.24044 .3655 Mdot
.039 .916 .04 r
.5 Mabswid
.4934 .64814 m
.50637 .65126 L
s
0 0 0 r
2.5 Mabswid
.50637 .65126 Mdot
.039 .916 .04 r
.5 Mabswid
.42106 .49971 m
.43149 .50182 L
s
0 0 0 r
2.5 Mabswid
.43149 .50182 Mdot
.039 .916 .04 r
.5 Mabswid
.44813 .32063 m
.45573 .32368 L
s
0 0 0 r
2.5 Mabswid
.45573 .32368 Mdot
.039 .916 .04 r
.5 Mabswid
.23965 .63093 m
.2371 .63748 L
s
0 0 0 r
2.5 Mabswid
.2371 .63748 Mdot
.039 .916 .04 r
.5 Mabswid
.46439 .3972 m
.48251 .39294 L
s
0 0 0 r
2.5 Mabswid
.48251 .39294 Mdot
.039 .916 .04 r
.5 Mabswid
.37672 .33873 m
.37906 .32281 L
s
0 0 0 r
2.5 Mabswid
.37906 .32281 Mdot
.039 .916 .04 r
.5 Mabswid
.41773 .55394 m
.42324 .55501 L
s
0 0 0 r
2.5 Mabswid
.42324 .55501 Mdot
.039 .916 .04 r
.5 Mabswid
.47859 .47343 m
.48375 .47596 L
s
0 0 0 r
2.5 Mabswid
.48375 .47596 Mdot
.039 .916 .04 r
.5 Mabswid
.43434 .47455 m
.43618 .46358 L
s
0 0 0 r
2.5 Mabswid
.43618 .46358 Mdot
.039 .916 .04 r
.5 Mabswid
.33527 .26192 m
.33527 .2619 L
s
0 0 0 r
2.5 Mabswid
.33527 .2619 Mdot
.039 .916 .04 r
.5 Mabswid
.39836 .35734 m
.41452 .35909 L
s
0 0 0 r
2.5 Mabswid
.41452 .35909 Mdot
.039 .916 .04 r
.5 Mabswid
.23301 .30652 m
.2143 .30651 L
s
0 0 0 r
2.5 Mabswid
.2143 .30651 Mdot
.039 .916 .04 r
.5 Mabswid
.40872 .73808 m
.40873 .7381 L
s
0 0 0 r
2.5 Mabswid
.40873 .7381 Mdot
.039 .916 .04 r
.5 Mabswid
.41029 .65443 m
.41169 .65734 L
s
0 0 0 r
2.5 Mabswid
.41169 .65734 Mdot
.039 .916 .04 r
.5 Mabswid
.37892 .67058 m
.38152 .68077 L
s
0 0 0 r
2.5 Mabswid
.38152 .68077 Mdot
.039 .916 .04 r
.5 Mabswid
.25525 .37935 m
.24647 .37771 L
s
0 0 0 r
2.5 Mabswid
.24647 .37771 Mdot
.039 .916 .04 r
.5 Mabswid
.46351 .40369 m
.46915 .38562 L
s
0 0 0 r
2.5 Mabswid
.46915 .38562 Mdot
.039 .916 .04 r
.5 Mabswid
.24044 .3655 m
.23971 .36493 L
s
0 0 0 r
2.5 Mabswid
.23971 .36493 Mdot
.039 .916 .04 r
.5 Mabswid
.50637 .65126 m
.51701 .65698 L
s
0 0 0 r
2.5 Mabswid
.51701 .65698 Mdot
.039 .916 .04 r
.5 Mabswid
.43149 .50182 m
.43267 .50249 L
s
0 0 0 r
2.5 Mabswid
.43267 .50249 Mdot
.039 .916 .04 r
.5 Mabswid
.45573 .32368 m
.46866 .33136 L
s
0 0 0 r
2.5 Mabswid
.46866 .33136 Mdot
.039 .916 .04 r
.5 Mabswid
.2371 .63748 m
.22786 .64904 L
s
0 0 0 r
2.5 Mabswid
.22786 .64904 Mdot
.039 .916 .04 r
.5 Mabswid
.48251 .39294 m
.49139 .3896 L
s
0 0 0 r
2.5 Mabswid
.49139 .3896 Mdot
.039 .916 .04 r
.5 Mabswid
.37906 .32281 m
.37861 .31896 L
s
0 0 0 r
2.5 Mabswid
.37861 .31896 Mdot
.039 .916 .04 r
.5 Mabswid
.42324 .55501 m
.4355 .55433 L
s
0 0 0 r
2.5 Mabswid
.4355 .55433 Mdot
.039 .916 .04 r
.5 Mabswid
.48375 .47596 m
.48457 .47612 L
s
0 0 0 r
2.5 Mabswid
.48457 .47612 Mdot
.039 .916 .04 r
.5 Mabswid
.43618 .46358 m
.43701 .46181 L
s
0 0 0 r
2.5 Mabswid
.43701 .46181 Mdot
.039 .916 .04 r
.5 Mabswid
.41452 .35909 m
.42461 .36335 L
s
0 0 0 r
2.5 Mabswid
.42461 .36335 Mdot
.039 .916 .04 r
.5 Mabswid
.2143 .30651 m
.21429 .30651 L
s
0 0 0 r
2.5 Mabswid
.21429 .30651 Mdot
.039 .916 .04 r
.5 Mabswid
.41169 .65734 m
.41301 .65895 L
s
0 0 0 r
2.5 Mabswid
.41301 .65895 Mdot
.039 .916 .04 r
.5 Mabswid
.38152 .68077 m
.38333 .69081 L
s
0 0 0 r
2.5 Mabswid
.38333 .69081 Mdot
.039 .916 .04 r
.5 Mabswid
.24647 .37771 m
.23745 .37699 L
s
0 0 0 r
2.5 Mabswid
.23745 .37699 Mdot
.039 .916 .04 r
.5 Mabswid
.46915 .38562 m
.47304 .37747 L
s
0 0 0 r
2.5 Mabswid
.47304 .37747 Mdot
.039 .916 .04 r
.5 Mabswid
.23971 .36493 m
.23061 .35557 L
s
0 0 0 r
2.5 Mabswid
.23061 .35557 Mdot
.039 .916 .04 r
.5 Mabswid
.51701 .65698 m
.52695 .66579 L
s
0 0 0 r
2.5 Mabswid
.52695 .66579 Mdot
.039 .916 .04 r
.5 Mabswid
.43267 .50249 m
.43614 .50393 L
s
0 0 0 r
2.5 Mabswid
.43614 .50393 Mdot
.039 .916 .04 r
.5 Mabswid
.46866 .33136 m
.47639 .33706 L
s
0 0 0 r
2.5 Mabswid
.47639 .33706 Mdot
.039 .916 .04 r
.5 Mabswid
.22786 .64904 m
.22374 .65872 L
s
0 0 0 r
2.5 Mabswid
.22374 .65872 Mdot
.039 .916 .04 r
.5 Mabswid
.49139 .3896 m
.49968 .3862 L
s
0 0 0 r
2.5 Mabswid
.49968 .3862 Mdot
.039 .916 .04 r
.5 Mabswid
.37861 .31896 m
.37633 .31051 L
s
0 0 0 r
2.5 Mabswid
.37633 .31051 Mdot
.039 .916 .04 r
.5 Mabswid
.4355 .55433 m
.45256 .55464 L
s
0 0 0 r
2.5 Mabswid
.45256 .55464 Mdot
.039 .916 .04 r
.5 Mabswid
.48457 .47612 m
.49139 .47535 L
s
0 0 0 r
2.5 Mabswid
.49139 .47535 Mdot
.039 .916 .04 r
.5 Mabswid
.43701 .46181 m
.43734 .45477 L
s
0 0 0 r
2.5 Mabswid
.43734 .45477 Mdot
.039 .916 .04 r
.5 Mabswid
.42461 .36335 m
.4386 .37277 L
s
0 0 0 r
2.5 Mabswid
.4386 .37277 Mdot
.039 .916 .04 r
.5 Mabswid
.41301 .65895 m
.42558 .67048 L
s
0 0 0 r
2.5 Mabswid
.42558 .67048 Mdot
.039 .916 .04 r
.5 Mabswid
.38333 .69081 m
.3853 .6943 L
s
0 0 0 r
2.5 Mabswid
.3853 .6943 Mdot
.039 .916 .04 r
.5 Mabswid
.23745 .37699 m
.2335 .37659 L
s
0 0 0 r
2.5 Mabswid
.2335 .37659 Mdot
.039 .916 .04 r
.5 Mabswid
.47304 .37747 m
.4733 .37711 L
s
0 0 0 r
2.5 Mabswid
.4733 .37711 Mdot
.039 .916 .04 r
.5 Mabswid
.23061 .35557 m
.22469 .34353 L
s
0 0 0 r
2.5 Mabswid
.22469 .34353 Mdot
.039 .916 .04 r
.5 Mabswid
.52695 .66579 m
.53326 .67216 L
s
0 0 0 r
2.5 Mabswid
.53326 .67216 Mdot
.039 .916 .04 r
.5 Mabswid
.43614 .50393 m
.44052 .50548 L
s
0 0 0 r
2.5 Mabswid
.44052 .50548 Mdot
.039 .916 .04 r
.5 Mabswid
.47639 .33706 m
.47674 .33723 L
s
0 0 0 r
2.5 Mabswid
.47674 .33723 Mdot
.039 .916 .04 r
.5 Mabswid
.22374 .65872 m
.2143 .67059 L
s
0 0 0 r
2.5 Mabswid
.2143 .67059 Mdot
.039 .916 .04 r
.5 Mabswid
.49968 .3862 m
.50494 .38216 L
s
0 0 0 r
2.5 Mabswid
.50494 .38216 Mdot
.039 .916 .04 r
.5 Mabswid
.37633 .31051 m
.37635 .29793 L
s
0 0 0 r
2.5 Mabswid
.37635 .29793 Mdot
.039 .916 .04 r
.5 Mabswid
.45256 .55464 m
.47117 .55372 L
s
0 0 0 r
2.5 Mabswid
.47117 .55372 Mdot
.039 .916 .04 r
.5 Mabswid
.49139 .47535 m
.50607 .47389 L
s
0 0 0 r
2.5 Mabswid
.50607 .47389 Mdot
.039 .916 .04 r
.5 Mabswid
.43734 .45477 m
.43721 .45301 L
s
0 0 0 r
2.5 Mabswid
.43721 .45301 Mdot
.039 .916 .04 r
.5 Mabswid
.4386 .37277 m
.44472 .38183 L
s
0 0 0 r
2.5 Mabswid
.44472 .38183 Mdot
.039 .916 .04 r
.5 Mabswid
.42558 .67048 m
.43704 .68284 L
s
0 0 0 r
2.5 Mabswid
.43704 .68284 Mdot
.039 .916 .04 r
.5 Mabswid
.3853 .6943 m
.39322 .70146 L
s
0 0 0 r
2.5 Mabswid
.39322 .70146 Mdot
.039 .916 .04 r
.5 Mabswid
.2335 .37659 m
.23002 .37758 L
s
0 0 0 r
2.5 Mabswid
.23002 .37758 Mdot
.039 .916 .04 r
.5 Mabswid
.4733 .37711 m
.4746 .37572 L
s
0 0 0 r
2.5 Mabswid
.4746 .37572 Mdot
.039 .916 .04 r
.5 Mabswid
.22469 .34353 m
.21999 .32614 L
s
0 0 0 r
2.5 Mabswid
.21999 .32614 Mdot
.039 .916 .04 r
.5 Mabswid
.53326 .67216 m
.53413 .67362 L
s
0 0 0 r
2.5 Mabswid
.53413 .67362 Mdot
.039 .916 .04 r
.5 Mabswid
.44052 .50548 m
.45114 .51008 L
s
0 0 0 r
2.5 Mabswid
.45114 .51008 Mdot
.039 .916 .04 r
.5 Mabswid
.47674 .33723 m
.48228 .34325 L
s
0 0 0 r
2.5 Mabswid
.48228 .34325 Mdot
.039 .916 .04 r
.5 Mabswid
.2143 .67059 m
.21429 .67061 L
s
0 0 0 r
2.5 Mabswid
.21429 .67061 Mdot
.039 .916 .04 r
.5 Mabswid
.50494 .38216 m
.51226 .37267 L
s
0 0 0 r
2.5 Mabswid
.51226 .37267 Mdot
.039 .916 .04 r
.5 Mabswid
.37635 .29793 m
.37593 .28546 L
s
0 0 0 r
2.5 Mabswid
.37593 .28546 Mdot
.039 .916 .04 r
.5 Mabswid
.47117 .55372 m
.48134 .5559 L
s
0 0 0 r
2.5 Mabswid
.48134 .5559 Mdot
.039 .916 .04 r
.5 Mabswid
.50607 .47389 m
.50779 .47367 L
s
0 0 0 r
2.5 Mabswid
.50779 .47367 Mdot
.039 .916 .04 r
.5 Mabswid
.43721 .45301 m
.43358 .44094 L
s
0 0 0 r
2.5 Mabswid
.43358 .44094 Mdot
.039 .916 .04 r
.5 Mabswid
.44472 .38183 m
.45116 .38961 L
s
0 0 0 r
2.5 Mabswid
.45116 .38961 Mdot
.039 .916 .04 r
.5 Mabswid
.43704 .68284 m
.44464 .68798 L
s
0 0 0 r
2.5 Mabswid
.44464 .68798 Mdot
.039 .916 .04 r
.5 Mabswid
.39322 .70146 m
.39837 .70808 L
s
0 0 0 r
2.5 Mabswid
.39837 .70808 Mdot
.039 .916 .04 r
.5 Mabswid
.23002 .37758 m
.2143 .38252 L
s
0 0 0 r
2.5 Mabswid
.2143 .38252 Mdot
.039 .916 .04 r
.5 Mabswid
.4746 .37572 m
.48358 .37087 L
s
0 0 0 r
2.5 Mabswid
.48358 .37087 Mdot
.039 .916 .04 r
.5 Mabswid
.21999 .32614 m
.22021 .31927 L
s
0 0 0 r
2.5 Mabswid
.22021 .31927 Mdot
.039 .916 .04 r
.5 Mabswid
.53413 .67362 m
.53747 .69099 L
s
0 0 0 r
2.5 Mabswid
.53747 .69099 Mdot
.039 .916 .04 r
.5 Mabswid
.45114 .51008 m
.46606 .51968 L
s
0 0 0 r
2.5 Mabswid
.46606 .51968 Mdot
.039 .916 .04 r
.5 Mabswid
.48228 .34325 m
.48631 .34756 L
s
0 0 0 r
2.5 Mabswid
.48631 .34756 Mdot
.039 .916 .04 r
.5 Mabswid
.21429 .67061 m
.2143 .67064 L
s
0 0 0 r
2.5 Mabswid
.2143 .67064 Mdot
.039 .916 .04 r
.5 Mabswid
.51226 .37267 m
.52099 .36646 L
s
0 0 0 r
2.5 Mabswid
.52099 .36646 Mdot
.039 .916 .04 r
.5 Mabswid
.37593 .28546 m
.36937 .27032 L
s
0 0 0 r
2.5 Mabswid
.36937 .27032 Mdot
.039 .916 .04 r
.5 Mabswid
.48134 .5559 m
.4978 .56148 L
s
0 0 0 r
2.5 Mabswid
.4978 .56148 Mdot
.039 .916 .04 r
.5 Mabswid
.50779 .47367 m
.516 .47358 L
s
0 0 0 r
2.5 Mabswid
.516 .47358 Mdot
.039 .916 .04 r
.5 Mabswid
.43358 .44094 m
.42731 .4232 L
s
0 0 0 r
2.5 Mabswid
.42731 .4232 Mdot
.039 .916 .04 r
.5 Mabswid
.45116 .38961 m
.4542 .39772 L
s
0 0 0 r
2.5 Mabswid
.4542 .39772 Mdot
.039 .916 .04 r
.5 Mabswid
.44464 .68798 m
.45518 .70331 L
s
0 0 0 r
2.5 Mabswid
.45518 .70331 Mdot
.039 .916 .04 r
.5 Mabswid
.39837 .70808 m
.40427 .71151 L
s
0 0 0 r
2.5 Mabswid
.40427 .71151 Mdot
.039 .916 .04 r
.5 Mabswid
.2143 .38252 m
.21429 .38253 L
s
0 0 0 r
2.5 Mabswid
.21429 .38253 Mdot
.039 .916 .04 r
.5 Mabswid
.48358 .37087 m
.4955 .35832 L
s
0 0 0 r
2.5 Mabswid
.4955 .35832 Mdot
.039 .916 .04 r
.5 Mabswid
.22021 .31927 m
.2147 .30178 L
s
0 0 0 r
2.5 Mabswid
.2147 .30178 Mdot
.039 .916 .04 r
.5 Mabswid
.53747 .69099 m
.5392 .6971 L
s
0 0 0 r
2.5 Mabswid
.5392 .6971 Mdot
.039 .916 .04 r
.5 Mabswid
.46606 .51968 m
.47303 .52482 L
s
0 0 0 r
2.5 Mabswid
.47303 .52482 Mdot
.039 .916 .04 r
.5 Mabswid
.48631 .34756 m
.49623 .35837 L
s
0 0 0 r
2.5 Mabswid
.49623 .35837 Mdot
.039 .916 .04 r
.5 Mabswid
.2143 .67064 m
.22269 .67808 L
s
0 0 0 r
2.5 Mabswid
.22269 .67808 Mdot
.039 .916 .04 r
.5 Mabswid
.52099 .36646 m
.53597 .35989 L
s
0 0 0 r
2.5 Mabswid
.53597 .35989 Mdot
.039 .916 .04 r
.5 Mabswid
.36937 .27032 m
.36302 .26192 L
s
0 0 0 r
2.5 Mabswid
.36302 .26192 Mdot
.039 .916 .04 r
.5 Mabswid
.4978 .56148 m
.50099 .56153 L
s
0 0 0 r
2.5 Mabswid
.50099 .56153 Mdot
.039 .916 .04 r
.5 Mabswid
.516 .47358 m
.53246 .47562 L
s
0 0 0 r
2.5 Mabswid
.53246 .47562 Mdot
.039 .916 .04 r
.5 Mabswid
.42731 .4232 m
.42408 .41002 L
s
0 0 0 r
2.5 Mabswid
.42408 .41002 Mdot
.039 .916 .04 r
.5 Mabswid
.4542 .39772 m
.46332 .4121 L
s
0 0 0 r
2.5 Mabswid
.46332 .4121 Mdot
.039 .916 .04 r
.5 Mabswid
.45518 .70331 m
.4607 .70751 L
s
0 0 0 r
2.5 Mabswid
.4607 .70751 Mdot
.039 .916 .04 r
.5 Mabswid
.40427 .71151 m
.41699 .72531 L
s
0 0 0 r
2.5 Mabswid
.41699 .72531 Mdot
.039 .916 .04 r
.5 Mabswid
.4955 .35832 m
.49915 .3516 L
s
0 0 0 r
2.5 Mabswid
.49915 .3516 Mdot
.039 .916 .04 r
.5 Mabswid
.2147 .30178 m
.21532 .28919 L
s
0 0 0 r
2.5 Mabswid
.21532 .28919 Mdot
.039 .916 .04 r
.5 Mabswid
.5392 .6971 m
.53902 .71513 L
s
0 0 0 r
2.5 Mabswid
.53902 .71513 Mdot
.039 .916 .04 r
.5 Mabswid
.47303 .52482 m
.48521 .53665 L
s
0 0 0 r
2.5 Mabswid
.48521 .53665 Mdot
.039 .916 .04 r
.5 Mabswid
.49623 .35837 m
.50232 .36183 L
s
0 0 0 r
2.5 Mabswid
.50232 .36183 Mdot
.039 .916 .04 r
.5 Mabswid
.22269 .67808 m
.22332 .67861 L
s
0 0 0 r
2.5 Mabswid
.22332 .67861 Mdot
.039 .916 .04 r
.5 Mabswid
.53597 .35989 m
.53874 .357 L
s
0 0 0 r
2.5 Mabswid
.53874 .357 Mdot
.039 .916 .04 r
.5 Mabswid
.36302 .26192 m
.36301 .2619 L
s
0 0 0 r
2.5 Mabswid
.36301 .2619 Mdot
.039 .916 .04 r
.5 Mabswid
.50099 .56153 m
.50417 .56236 L
s
0 0 0 r
2.5 Mabswid
.50417 .56236 Mdot
.039 .916 .04 r
.5 Mabswid
.53246 .47562 m
.54194 .47586 L
s
0 0 0 r
2.5 Mabswid
.54194 .47586 Mdot
.039 .916 .04 r
.5 Mabswid
.42408 .41002 m
.42309 .40481 L
s
0 0 0 r
2.5 Mabswid
.42309 .40481 Mdot
.039 .916 .04 r
.5 Mabswid
.46332 .4121 m
.46516 .41412 L
s
0 0 0 r
2.5 Mabswid
.46516 .41412 Mdot
.039 .916 .04 r
.5 Mabswid
.4607 .70751 m
.46461 .7115 L
s
0 0 0 r
2.5 Mabswid
.46461 .7115 Mdot
.039 .916 .04 r
.5 Mabswid
.41699 .72531 m
.42924 .73236 L
s
0 0 0 r
2.5 Mabswid
.42924 .73236 Mdot
.039 .916 .04 r
.5 Mabswid
.49915 .3516 m
.50674 .34226 L
s
0 0 0 r
2.5 Mabswid
.50674 .34226 Mdot
.039 .916 .04 r
.5 Mabswid
.21532 .28919 m
.2143 .28241 L
s
0 0 0 r
2.5 Mabswid
.2143 .28241 Mdot
.039 .916 .04 r
.5 Mabswid
.53902 .71513 m
.54398 .72944 L
s
0 0 0 r
2.5 Mabswid
.54398 .72944 Mdot
.039 .916 .04 r
.5 Mabswid
.48521 .53665 m
.49764 .54331 L
s
0 0 0 r
2.5 Mabswid
.49764 .54331 Mdot
.039 .916 .04 r
.5 Mabswid
.50232 .36183 m
.50927 .36643 L
s
0 0 0 r
2.5 Mabswid
.50927 .36643 Mdot
.039 .916 .04 r
.5 Mabswid
.22332 .67861 m
.23558 .68418 L
s
0 0 0 r
2.5 Mabswid
.23558 .68418 Mdot
.039 .916 .04 r
.5 Mabswid
.53874 .357 m
.54251 .35451 L
s
0 0 0 r
2.5 Mabswid
.54251 .35451 Mdot
.039 .916 .04 r
.5 Mabswid
.50417 .56236 m
.51344 .56702 L
s
0 0 0 r
2.5 Mabswid
.51344 .56702 Mdot
.039 .916 .04 r
.5 Mabswid
.54194 .47586 m
.55573 .47305 L
s
0 0 0 r
2.5 Mabswid
.55573 .47305 Mdot
.039 .916 .04 r
.5 Mabswid
.42309 .40481 m
.42207 .39964 L
s
0 0 0 r
2.5 Mabswid
.42207 .39964 Mdot
.039 .916 .04 r
.5 Mabswid
.46516 .41412 m
.47275 .42281 L
s
0 0 0 r
2.5 Mabswid
.47275 .42281 Mdot
.039 .916 .04 r
.5 Mabswid
.46461 .7115 m
.47894 .72355 L
s
0 0 0 r
2.5 Mabswid
.47894 .72355 Mdot
.039 .916 .04 r
.5 Mabswid
.42924 .73236 m
.43537 .73808 L
s
0 0 0 r
2.5 Mabswid
.43537 .73808 Mdot
.039 .916 .04 r
.5 Mabswid
.50674 .34226 m
.51299 .32705 L
s
0 0 0 r
2.5 Mabswid
.51299 .32705 Mdot
.039 .916 .04 r
.5 Mabswid
.2143 .28241 m
.21429 .28228 L
s
0 0 0 r
2.5 Mabswid
.21429 .28228 Mdot
.039 .916 .04 r
.5 Mabswid
.54398 .72944 m
.54532 .73808 L
s
0 0 0 r
2.5 Mabswid
.54532 .73808 Mdot
.039 .916 .04 r
.5 Mabswid
.49764 .54331 m
.50207 .54858 L
s
0 0 0 r
2.5 Mabswid
.50207 .54858 Mdot
.039 .916 .04 r
.5 Mabswid
.50927 .36643 m
.51069 .36688 L
s
0 0 0 r
2.5 Mabswid
.51069 .36688 Mdot
.039 .916 .04 r
.5 Mabswid
.23558 .68418 m
.24469 .69175 L
s
0 0 0 r
2.5 Mabswid
.24469 .69175 Mdot
.039 .916 .04 r
.5 Mabswid
.54251 .35451 m
.55191 .34672 L
s
0 0 0 r
2.5 Mabswid
.55191 .34672 Mdot
.039 .916 .04 r
.5 Mabswid
.51344 .56702 m
.53072 .56925 L
s
0 0 0 r
2.5 Mabswid
.53072 .56925 Mdot
.039 .916 .04 r
.5 Mabswid
.55573 .47305 m
.56275 .46944 L
s
0 0 0 r
2.5 Mabswid
.56275 .46944 Mdot
.039 .916 .04 r
.5 Mabswid
.42207 .39964 m
.42113 .39247 L
s
0 0 0 r
2.5 Mabswid
.42113 .39247 Mdot
.039 .916 .04 r
.5 Mabswid
.47275 .42281 m
.48022 .43328 L
s
0 0 0 r
2.5 Mabswid
.48022 .43328 Mdot
.039 .916 .04 r
.5 Mabswid
.47894 .72355 m
.48087 .72453 L
s
0 0 0 r
2.5 Mabswid
.48087 .72453 Mdot
.039 .916 .04 r
.5 Mabswid
.43537 .73808 m
.43539 .7381 L
s
0 0 0 r
2.5 Mabswid
.43539 .7381 Mdot
.039 .916 .04 r
.5 Mabswid
.51299 .32705 m
.51391 .32584 L
s
0 0 0 r
2.5 Mabswid
.51391 .32584 Mdot
.039 .916 .04 r
.5 Mabswid
.21429 .28228 m
.2143 .28215 L
s
0 0 0 r
2.5 Mabswid
.2143 .28215 Mdot
.039 .916 .04 r
.5 Mabswid
.54532 .73808 m
.54532 .7381 L
s
0 0 0 r
2.5 Mabswid
.54532 .7381 Mdot
.039 .916 .04 r
.5 Mabswid
.50207 .54858 m
.50863 .55252 L
s
0 0 0 r
2.5 Mabswid
.50863 .55252 Mdot
.039 .916 .04 r
.5 Mabswid
.51069 .36688 m
.52953 .36674 L
s
0 0 0 r
2.5 Mabswid
.52953 .36674 Mdot
.039 .916 .04 r
.5 Mabswid
.24469 .69175 m
.25041 .69401 L
s
0 0 0 r
2.5 Mabswid
.25041 .69401 Mdot
.039 .916 .04 r
.5 Mabswid
.55191 .34672 m
.56789 .34121 L
s
0 0 0 r
2.5 Mabswid
.56789 .34121 Mdot
.039 .916 .04 r
.5 Mabswid
.53072 .56925 m
.53505 .56898 L
s
0 0 0 r
2.5 Mabswid
.53505 .56898 Mdot
.039 .916 .04 r
.5 Mabswid
.56275 .46944 m
.57904 .46255 L
s
0 0 0 r
2.5 Mabswid
.57904 .46255 Mdot
.039 .916 .04 r
.5 Mabswid
.42113 .39247 m
.41435 .3754 L
s
0 0 0 r
2.5 Mabswid
.41435 .3754 Mdot
.039 .916 .04 r
.5 Mabswid
.48022 .43328 m
.4842 .43837 L
s
0 0 0 r
2.5 Mabswid
.4842 .43837 Mdot
.039 .916 .04 r
.5 Mabswid
.48087 .72453 m
.49355 .73229 L
s
0 0 0 r
2.5 Mabswid
.49355 .73229 Mdot
.039 .916 .04 r
.5 Mabswid
.43539 .7381 m
.43541 .73808 L
s
0 0 0 r
2.5 Mabswid
.43541 .73808 Mdot
.039 .916 .04 r
.5 Mabswid
.51391 .32584 m
.52527 .31688 L
s
0 0 0 r
2.5 Mabswid
.52527 .31688 Mdot
.039 .916 .04 r
.5 Mabswid
.2143 .28215 m
.21429 .28203 L
s
0 0 0 r
2.5 Mabswid
.21429 .28203 Mdot
.039 .916 .04 r
.5 Mabswid
.50863 .55252 m
.5151 .55461 L
s
0 0 0 r
2.5 Mabswid
.5151 .55461 Mdot
.039 .916 .04 r
.5 Mabswid
.52953 .36674 m
.54146 .36917 L
s
0 0 0 r
2.5 Mabswid
.54146 .36917 Mdot
.039 .916 .04 r
.5 Mabswid
.25041 .69401 m
.25327 .69428 L
s
0 0 0 r
2.5 Mabswid
.25327 .69428 Mdot
.039 .916 .04 r
.5 Mabswid
.56789 .34121 m
.58151 .33172 L
s
0 0 0 r
2.5 Mabswid
.58151 .33172 Mdot
.039 .916 .04 r
.5 Mabswid
.53505 .56898 m
.53529 .56897 L
s
0 0 0 r
2.5 Mabswid
.53529 .56897 Mdot
.039 .916 .04 r
.5 Mabswid
.57904 .46255 m
.59038 .45464 L
s
0 0 0 r
2.5 Mabswid
.59038 .45464 Mdot
.039 .916 .04 r
.5 Mabswid
.41435 .3754 m
.40816 .36802 L
s
0 0 0 r
2.5 Mabswid
.40816 .36802 Mdot
.039 .916 .04 r
.5 Mabswid
.4842 .43837 m
.48768 .44711 L
s
0 0 0 r
2.5 Mabswid
.48768 .44711 Mdot
.039 .916 .04 r
.5 Mabswid
.49355 .73229 m
.50447 .73808 L
s
0 0 0 r
2.5 Mabswid
.50447 .73808 Mdot
.039 .916 .04 r
.5 Mabswid
.43541 .73808 m
.44252 .73467 L
s
0 0 0 r
2.5 Mabswid
.44252 .73467 Mdot
.039 .916 .04 r
.5 Mabswid
.52527 .31688 m
.53253 .3073 L
s
0 0 0 r
2.5 Mabswid
.53253 .3073 Mdot
.039 .916 .04 r
.5 Mabswid
.21429 .28203 m
.2143 .2819 L
s
0 0 0 r
2.5 Mabswid
.2143 .2819 Mdot
.039 .916 .04 r
.5 Mabswid
.5151 .55461 m
.51611 .55458 L
s
0 0 0 r
2.5 Mabswid
.51611 .55458 Mdot
.039 .916 .04 r
.5 Mabswid
.54146 .36917 m
.54724 .37176 L
s
0 0 0 r
2.5 Mabswid
.54724 .37176 Mdot
.039 .916 .04 r
.5 Mabswid
.25327 .69428 m
.27136 .68986 L
s
0 0 0 r
2.5 Mabswid
.27136 .68986 Mdot
.039 .916 .04 r
.5 Mabswid
.58151 .33172 m
.58993 .32549 L
s
0 0 0 r
2.5 Mabswid
.58993 .32549 Mdot
.039 .916 .04 r
.5 Mabswid
.53529 .56897 m
.55167 .56383 L
s
0 0 0 r
2.5 Mabswid
.55167 .56383 Mdot
.039 .916 .04 r
.5 Mabswid
.59038 .45464 m
.59157 .45339 L
s
0 0 0 r
2.5 Mabswid
.59157 .45339 Mdot
.039 .916 .04 r
.5 Mabswid
.40816 .36802 m
.39767 .35941 L
s
0 0 0 r
2.5 Mabswid
.39767 .35941 Mdot
.039 .916 .04 r
.5 Mabswid
.48768 .44711 m
.49608 .46072 L
s
0 0 0 r
2.5 Mabswid
.49608 .46072 Mdot
.039 .916 .04 r
.5 Mabswid
.50447 .73808 m
.5045 .7381 L
s
0 0 0 r
2.5 Mabswid
.5045 .7381 Mdot
.039 .916 .04 r
.5 Mabswid
.44252 .73467 m
.45107 .73373 L
s
0 0 0 r
2.5 Mabswid
.45107 .73373 Mdot
.039 .916 .04 r
.5 Mabswid
.53253 .3073 m
.53901 .29876 L
s
0 0 0 r
2.5 Mabswid
.53901 .29876 Mdot
.039 .916 .04 r
.5 Mabswid
.2143 .2819 m
.21933 .27336 L
s
0 0 0 r
2.5 Mabswid
.21933 .27336 Mdot
.039 .916 .04 r
.5 Mabswid
.51611 .55458 m
.51733 .5549 L
s
0 0 0 r
2.5 Mabswid
.51733 .5549 Mdot
.039 .916 .04 r
.5 Mabswid
.54724 .37176 m
.55509 .37634 L
s
0 0 0 r
2.5 Mabswid
.55509 .37634 Mdot
.039 .916 .04 r
.5 Mabswid
.27136 .68986 m
.28397 .68382 L
s
0 0 0 r
2.5 Mabswid
.28397 .68382 Mdot
.039 .916 .04 r
.5 Mabswid
.58993 .32549 m
.59756 .3198 L
s
0 0 0 r
2.5 Mabswid
.59756 .3198 Mdot
.039 .916 .04 r
.5 Mabswid
.55167 .56383 m
.55506 .56235 L
s
0 0 0 r
2.5 Mabswid
.55506 .56235 Mdot
.039 .916 .04 r
.5 Mabswid
.59157 .45339 m
.59937 .44509 L
s
0 0 0 r
2.5 Mabswid
.59937 .44509 Mdot
.039 .916 .04 r
.5 Mabswid
.39767 .35941 m
.39616 .35787 L
s
0 0 0 r
2.5 Mabswid
.39616 .35787 Mdot
.039 .916 .04 r
.5 Mabswid
.49608 .46072 m
.49888 .47736 L
s
0 0 0 r
2.5 Mabswid
.49888 .47736 Mdot
.039 .916 .04 r
.5 Mabswid
.5045 .7381 m
.50454 .73808 L
s
0 0 0 r
2.5 Mabswid
.50454 .73808 Mdot
.039 .916 .04 r
.5 Mabswid
.45107 .73373 m
.46841 .7268 L
s
0 0 0 r
2.5 Mabswid
.46841 .7268 Mdot
.039 .916 .04 r
.5 Mabswid
.53901 .29876 m
.54234 .29493 L
s
0 0 0 r
2.5 Mabswid
.54234 .29493 Mdot
.039 .916 .04 r
.5 Mabswid
.21933 .27336 m
.22638 .26192 L
s
0 0 0 r
2.5 Mabswid
.22638 .26192 Mdot
.039 .916 .04 r
.5 Mabswid
.51733 .5549 m
.52457 .55744 L
s
0 0 0 r
2.5 Mabswid
.52457 .55744 Mdot
.039 .916 .04 r
.5 Mabswid
.55509 .37634 m
.56623 .38483 L
s
0 0 0 r
2.5 Mabswid
.56623 .38483 Mdot
.039 .916 .04 r
.5 Mabswid
.28397 .68382 m
.29921 .68249 L
s
0 0 0 r
2.5 Mabswid
.29921 .68249 Mdot
.039 .916 .04 r
.5 Mabswid
.59756 .3198 m
.59882 .31873 L
s
0 0 0 r
2.5 Mabswid
.59882 .31873 Mdot
.039 .916 .04 r
.5 Mabswid
.55506 .56235 m
.56962 .55552 L
s
0 0 0 r
2.5 Mabswid
.56962 .55552 Mdot
.039 .916 .04 r
.5 Mabswid
.59937 .44509 m
.60433 .43352 L
s
0 0 0 r
2.5 Mabswid
.60433 .43352 Mdot
.039 .916 .04 r
.5 Mabswid
.39616 .35787 m
.39329 .35111 L
s
0 0 0 r
2.5 Mabswid
.39329 .35111 Mdot
.039 .916 .04 r
.5 Mabswid
.49888 .47736 m
.50158 .48859 L
s
0 0 0 r
2.5 Mabswid
.50158 .48859 Mdot
.039 .916 .04 r
.5 Mabswid
.50454 .73808 m
.51071 .73317 L
s
0 0 0 r
2.5 Mabswid
.51071 .73317 Mdot
.039 .916 .04 r
.5 Mabswid
.46841 .7268 m
.47183 .72523 L
s
0 0 0 r
2.5 Mabswid
.47183 .72523 Mdot
.039 .916 .04 r
.5 Mabswid
.54234 .29493 m
.5487 .28966 L
s
0 0 0 r
2.5 Mabswid
.5487 .28966 Mdot
.039 .916 .04 r
.5 Mabswid
.22638 .26192 m
.22639 .2619 L
s
0 0 0 r
2.5 Mabswid
.22639 .2619 Mdot
.039 .916 .04 r
.5 Mabswid
.52457 .55744 m
.53848 .56846 L
s
0 0 0 r
2.5 Mabswid
.53848 .56846 Mdot
.039 .916 .04 r
.5 Mabswid
.56623 .38483 m
.56679 .38537 L
s
0 0 0 r
2.5 Mabswid
.56679 .38537 Mdot
.039 .916 .04 r
.5 Mabswid
.29921 .68249 m
.3031 .682 L
s
0 0 0 r
2.5 Mabswid
.3031 .682 Mdot
.039 .916 .04 r
.5 Mabswid
.59882 .31873 m
.60303 .31708 L
s
0 0 0 r
2.5 Mabswid
.60303 .31708 Mdot
.039 .916 .04 r
.5 Mabswid
.56962 .55552 m
.57207 .55532 L
s
0 0 0 r
2.5 Mabswid
.57207 .55532 Mdot
.039 .916 .04 r
.5 Mabswid
.60433 .43352 m
.60849 .42728 L
s
0 0 0 r
2.5 Mabswid
.60849 .42728 Mdot
.039 .916 .04 r
.5 Mabswid
.39329 .35111 m
.38893 .34332 L
s
0 0 0 r
2.5 Mabswid
.38893 .34332 Mdot
.039 .916 .04 r
.5 Mabswid
.50158 .48859 m
.50162 .48894 L
s
0 0 0 r
2.5 Mabswid
.50162 .48894 Mdot
.039 .916 .04 r
.5 Mabswid
.51071 .73317 m
.5234 .72274 L
s
0 0 0 r
2.5 Mabswid
.5234 .72274 Mdot
.039 .916 .04 r
.5 Mabswid
.47183 .72523 m
.48173 .71935 L
s
0 0 0 r
2.5 Mabswid
.48173 .71935 Mdot
.039 .916 .04 r
.5 Mabswid
.5487 .28966 m
.55504 .27848 L
s
0 0 0 r
2.5 Mabswid
.55504 .27848 Mdot
.039 .916 .04 r
.5 Mabswid
.53848 .56846 m
.54089 .5709 L
s
0 0 0 r
2.5 Mabswid
.54089 .5709 Mdot
.039 .916 .04 r
.5 Mabswid
.56679 .38537 m
.57943 .39175 L
s
0 0 0 r
2.5 Mabswid
.57943 .39175 Mdot
.039 .916 .04 r
.5 Mabswid
.3031 .682 m
.30558 .6806 L
s
0 0 0 r
2.5 Mabswid
.30558 .6806 Mdot
.039 .916 .04 r
.5 Mabswid
.60303 .31708 m
.61315 .31455 L
s
0 0 0 r
2.5 Mabswid
.61315 .31455 Mdot
.039 .916 .04 r
.5 Mabswid
.57207 .55532 m
.58802 .54845 L
s
0 0 0 r
2.5 Mabswid
.58802 .54845 Mdot
.039 .916 .04 r
.5 Mabswid
.60849 .42728 m
.61406 .42133 L
s
0 0 0 r
2.5 Mabswid
.61406 .42133 Mdot
.039 .916 .04 r
.5 Mabswid
.38893 .34332 m
.38303 .33518 L
s
0 0 0 r
2.5 Mabswid
.38303 .33518 Mdot
.039 .916 .04 r
.5 Mabswid
.50162 .48894 m
.50623 .50661 L
s
0 0 0 r
2.5 Mabswid
.50623 .50661 Mdot
.039 .916 .04 r
.5 Mabswid
.5234 .72274 m
.53201 .71786 L
s
0 0 0 r
2.5 Mabswid
.53201 .71786 Mdot
.039 .916 .04 r
.5 Mabswid
.48173 .71935 m
.4837 .71886 L
s
0 0 0 r
2.5 Mabswid
.4837 .71886 Mdot
.039 .916 .04 r
.5 Mabswid
.55504 .27848 m
.56211 .26192 L
s
0 0 0 r
2.5 Mabswid
.56211 .26192 Mdot
.039 .916 .04 r
.5 Mabswid
.54089 .5709 m
.54956 .58603 L
s
0 0 0 r
2.5 Mabswid
.54956 .58603 Mdot
.039 .916 .04 r
.5 Mabswid
.57943 .39175 m
.5861 .39657 L
s
0 0 0 r
2.5 Mabswid
.5861 .39657 Mdot
.039 .916 .04 r
.5 Mabswid
.30558 .6806 m
.31892 .67577 L
s
0 0 0 r
2.5 Mabswid
.31892 .67577 Mdot
.039 .916 .04 r
.5 Mabswid
.61315 .31455 m
.62621 .31338 L
s
0 0 0 r
2.5 Mabswid
.62621 .31338 Mdot
.039 .916 .04 r
.5 Mabswid
.58802 .54845 m
.59637 .5405 L
s
0 0 0 r
2.5 Mabswid
.59637 .5405 Mdot
.039 .916 .04 r
.5 Mabswid
.61406 .42133 m
.6162 .41941 L
s
0 0 0 r
2.5 Mabswid
.6162 .41941 Mdot
.039 .916 .04 r
.5 Mabswid
.38303 .33518 m
.374 .32553 L
s
0 0 0 r
2.5 Mabswid
.374 .32553 Mdot
.039 .916 .04 r
.5 Mabswid
.50623 .50661 m
.51211 .51907 L
s
0 0 0 r
2.5 Mabswid
.51211 .51907 Mdot
.039 .916 .04 r
.5 Mabswid
.53201 .71786 m
.53533 .71744 L
s
0 0 0 r
2.5 Mabswid
.53533 .71744 Mdot
.039 .916 .04 r
.5 Mabswid
.4837 .71886 m
.49792 .71577 L
s
0 0 0 r
2.5 Mabswid
.49792 .71577 Mdot
.039 .916 .04 r
.5 Mabswid
.56211 .26192 m
.56212 .2619 L
s
0 0 0 r
2.5 Mabswid
.56212 .2619 Mdot
.039 .916 .04 r
.5 Mabswid
.54956 .58603 m
.55864 .59462 L
s
0 0 0 r
2.5 Mabswid
.55864 .59462 Mdot
.039 .916 .04 r
.5 Mabswid
.5861 .39657 m
.59791 .40127 L
s
0 0 0 r
2.5 Mabswid
.59791 .40127 Mdot
.039 .916 .04 r
.5 Mabswid
.31892 .67577 m
.33127 .66893 L
s
0 0 0 r
2.5 Mabswid
.33127 .66893 Mdot
.039 .916 .04 r
.5 Mabswid
.62621 .31338 m
.63087 .3129 L
s
0 0 0 r
2.5 Mabswid
.63087 .3129 Mdot
.039 .916 .04 r
.5 Mabswid
.59637 .5405 m
.61095 .52835 L
s
0 0 0 r
2.5 Mabswid
.61095 .52835 Mdot
.039 .916 .04 r
.5 Mabswid
.6162 .41941 m
.6255 .41427 L
s
0 0 0 r
2.5 Mabswid
.6255 .41427 Mdot
.039 .916 .04 r
.5 Mabswid
.374 .32553 m
.36893 .31982 L
s
0 0 0 r
2.5 Mabswid
.36893 .31982 Mdot
.039 .916 .04 r
.5 Mabswid
.51211 .51907 m
.51721 .52515 L
s
0 0 0 r
2.5 Mabswid
.51721 .52515 Mdot
.039 .916 .04 r
.5 Mabswid
.53533 .71744 m
.54791 .71261 L
s
0 0 0 r
2.5 Mabswid
.54791 .71261 Mdot
.039 .916 .04 r
.5 Mabswid
.49792 .71577 m
.51105 .7172 L
s
0 0 0 r
2.5 Mabswid
.51105 .7172 Mdot
.039 .916 .04 r
.5 Mabswid
.55864 .59462 m
.56758 .59975 L
s
0 0 0 r
2.5 Mabswid
.56758 .59975 Mdot
.039 .916 .04 r
.5 Mabswid
.59791 .40127 m
.61494 .40609 L
s
0 0 0 r
2.5 Mabswid
.61494 .40609 Mdot
.039 .916 .04 r
.5 Mabswid
.33127 .66893 m
.34249 .65635 L
s
0 0 0 r
2.5 Mabswid
.34249 .65635 Mdot
.039 .916 .04 r
.5 Mabswid
.63087 .3129 m
.63572 .31112 L
s
0 0 0 r
2.5 Mabswid
.63572 .31112 Mdot
.039 .916 .04 r
.5 Mabswid
.61095 .52835 m
.61355 .527 L
s
0 0 0 r
2.5 Mabswid
.61355 .527 Mdot
.039 .916 .04 r
.5 Mabswid
.6255 .41427 m
.62613 .41404 L
s
0 0 0 r
2.5 Mabswid
.62613 .41404 Mdot
.039 .916 .04 r
.5 Mabswid
.36893 .31982 m
.36646 .31812 L
s
0 0 0 r
2.5 Mabswid
.36646 .31812 Mdot
.039 .916 .04 r
.5 Mabswid
.51721 .52515 m
.52052 .53363 L
s
0 0 0 r
2.5 Mabswid
.52052 .53363 Mdot
.039 .916 .04 r
.5 Mabswid
.54791 .71261 m
.5619 .70912 L
s
0 0 0 r
2.5 Mabswid
.5619 .70912 Mdot
.039 .916 .04 r
.5 Mabswid
.51105 .7172 m
.51235 .7176 L
s
0 0 0 r
2.5 Mabswid
.51235 .7176 Mdot
.039 .916 .04 r
.5 Mabswid
.56758 .59975 m
.56859 .60029 L
s
0 0 0 r
2.5 Mabswid
.56859 .60029 Mdot
.039 .916 .04 r
.5 Mabswid
.61494 .40609 m
.62114 .40975 L
s
0 0 0 r
2.5 Mabswid
.62114 .40975 Mdot
.039 .916 .04 r
.5 Mabswid
.34249 .65635 m
.34759 .64789 L
s
0 0 0 r
2.5 Mabswid
.34759 .64789 Mdot
.039 .916 .04 r
.5 Mabswid
.63572 .31112 m
.64366 .30794 L
s
0 0 0 r
2.5 Mabswid
.64366 .30794 Mdot
.039 .916 .04 r
.5 Mabswid
.61355 .527 m
.6226 .51901 L
s
0 0 0 r
2.5 Mabswid
.6226 .51901 Mdot
.039 .916 .04 r
.5 Mabswid
.62613 .41404 m
.62923 .41226 L
s
0 0 0 r
2.5 Mabswid
.62923 .41226 Mdot
.039 .916 .04 r
.5 Mabswid
.36646 .31812 m
.35844 .31335 L
s
0 0 0 r
2.5 Mabswid
.35844 .31335 Mdot
.039 .916 .04 r
.5 Mabswid
.52052 .53363 m
.52147 .53657 L
s
0 0 0 r
2.5 Mabswid
.52147 .53657 Mdot
.039 .916 .04 r
.5 Mabswid
.5619 .70912 m
.56773 .70623 L
s
0 0 0 r
2.5 Mabswid
.56773 .70623 Mdot
.039 .916 .04 r
.5 Mabswid
.51235 .7176 m
.52422 .723 L
s
0 0 0 r
2.5 Mabswid
.52422 .723 Mdot
.039 .916 .04 r
.5 Mabswid
.56859 .60029 m
.57811 .60607 L
s
0 0 0 r
2.5 Mabswid
.57811 .60607 Mdot
.039 .916 .04 r
.5 Mabswid
.62114 .40975 m
.62882 .41881 L
s
0 0 0 r
2.5 Mabswid
.62882 .41881 Mdot
.039 .916 .04 r
.5 Mabswid
.34759 .64789 m
.34996 .63798 L
s
0 0 0 r
2.5 Mabswid
.34996 .63798 Mdot
.039 .916 .04 r
.5 Mabswid
.64366 .30794 m
.64738 .3048 L
s
0 0 0 r
2.5 Mabswid
.64738 .3048 Mdot
.039 .916 .04 r
.5 Mabswid
.6226 .51901 m
.62305 .51879 L
s
0 0 0 r
2.5 Mabswid
.62305 .51879 Mdot
.039 .916 .04 r
.5 Mabswid
.62923 .41226 m
.64327 .40602 L
s
0 0 0 r
2.5 Mabswid
.64327 .40602 Mdot
.039 .916 .04 r
.5 Mabswid
.35844 .31335 m
.35253 .30876 L
s
0 0 0 r
2.5 Mabswid
.35253 .30876 Mdot
.039 .916 .04 r
.5 Mabswid
.52147 .53657 m
.52641 .54748 L
s
0 0 0 r
2.5 Mabswid
.52641 .54748 Mdot
.039 .916 .04 r
.5 Mabswid
.56773 .70623 m
.58129 .69563 L
s
0 0 0 r
2.5 Mabswid
.58129 .69563 Mdot
.039 .916 .04 r
.5 Mabswid
.52422 .723 m
.53146 .72844 L
s
0 0 0 r
2.5 Mabswid
.53146 .72844 Mdot
.039 .916 .04 r
.5 Mabswid
.57811 .60607 m
.58885 .60787 L
s
0 0 0 r
2.5 Mabswid
.58885 .60787 Mdot
.039 .916 .04 r
.5 Mabswid
.62882 .41881 m
.64155 .42686 L
s
0 0 0 r
2.5 Mabswid
.64155 .42686 Mdot
.039 .916 .04 r
.5 Mabswid
.34996 .63798 m
.35356 .61953 L
s
0 0 0 r
2.5 Mabswid
.35356 .61953 Mdot
.039 .916 .04 r
.5 Mabswid
.64738 .3048 m
.64936 .30207 L
s
0 0 0 r
2.5 Mabswid
.64936 .30207 Mdot
.039 .916 .04 r
.5 Mabswid
.62305 .51879 m
.63042 .51399 L
s
0 0 0 r
2.5 Mabswid
.63042 .51399 Mdot
.039 .916 .04 r
.5 Mabswid
.64327 .40602 m
.65628 .39423 L
s
0 0 0 r
2.5 Mabswid
.65628 .39423 Mdot
.039 .916 .04 r
.5 Mabswid
.35253 .30876 m
.34578 .30362 L
s
0 0 0 r
2.5 Mabswid
.34578 .30362 Mdot
.039 .916 .04 r
.5 Mabswid
.52641 .54748 m
.52746 .54962 L
s
0 0 0 r
2.5 Mabswid
.52746 .54962 Mdot
.039 .916 .04 r
.5 Mabswid
.58129 .69563 m
.58238 .69517 L
s
0 0 0 r
2.5 Mabswid
.58238 .69517 Mdot
.039 .916 .04 r
.5 Mabswid
.53146 .72844 m
.54041 .73156 L
s
0 0 0 r
2.5 Mabswid
.54041 .73156 Mdot
.039 .916 .04 r
.5 Mabswid
.58885 .60787 m
.59179 .60858 L
s
0 0 0 r
2.5 Mabswid
.59179 .60858 Mdot
.039 .916 .04 r
.5 Mabswid
.64155 .42686 m
.6421 .42711 L
s
0 0 0 r
2.5 Mabswid
.6421 .42711 Mdot
.039 .916 .04 r
.5 Mabswid
.35356 .61953 m
.35634 .6087 L
s
0 0 0 r
2.5 Mabswid
.35634 .6087 Mdot
.039 .916 .04 r
.5 Mabswid
.64936 .30207 m
.65115 .29785 L
s
0 0 0 r
2.5 Mabswid
.65115 .29785 Mdot
.039 .916 .04 r
.5 Mabswid
.63042 .51399 m
.63779 .50525 L
s
0 0 0 r
2.5 Mabswid
.63779 .50525 Mdot
.039 .916 .04 r
.5 Mabswid
.65628 .39423 m
.6569 .39298 L
s
0 0 0 r
2.5 Mabswid
.6569 .39298 Mdot
.039 .916 .04 r
.5 Mabswid
.34578 .30362 m
.34398 .30144 L
s
0 0 0 r
2.5 Mabswid
.34398 .30144 Mdot
.039 .916 .04 r
.5 Mabswid
.52746 .54962 m
.5278 .55249 L
s
0 0 0 r
2.5 Mabswid
.5278 .55249 Mdot
.039 .916 .04 r
.5 Mabswid
.58238 .69517 m
.59374 .68807 L
s
0 0 0 r
2.5 Mabswid
.59374 .68807 Mdot
.039 .916 .04 r
.5 Mabswid
.54041 .73156 m
.54106 .73177 L
s
0 0 0 r
2.5 Mabswid
.54106 .73177 Mdot
.039 .916 .04 r
.5 Mabswid
.59179 .60858 m
.60391 .61119 L
s
0 0 0 r
2.5 Mabswid
.60391 .61119 Mdot
.039 .916 .04 r
.5 Mabswid
.6421 .42711 m
.65184 .43035 L
s
0 0 0 r
2.5 Mabswid
.65184 .43035 Mdot
.039 .916 .04 r
.5 Mabswid
.35634 .6087 m
.36131 .60053 L
s
0 0 0 r
2.5 Mabswid
.36131 .60053 Mdot
.039 .916 .04 r
.5 Mabswid
.65115 .29785 m
.65152 .288 L
s
0 0 0 r
2.5 Mabswid
.65152 .288 Mdot
.039 .916 .04 r
.5 Mabswid
.63779 .50525 m
.64682 .49035 L
s
0 0 0 r
2.5 Mabswid
.64682 .49035 Mdot
.039 .916 .04 r
.5 Mabswid
.6569 .39298 m
.66048 .38885 L
s
0 0 0 r
2.5 Mabswid
.66048 .38885 Mdot
.039 .916 .04 r
.5 Mabswid
.34398 .30144 m
.33897 .29783 L
s
0 0 0 r
2.5 Mabswid
.33897 .29783 Mdot
.039 .916 .04 r
.5 Mabswid
.5278 .55249 m
.52731 .55672 L
s
0 0 0 r
2.5 Mabswid
.52731 .55672 Mdot
.039 .916 .04 r
.5 Mabswid
.59374 .68807 m
.59656 .68592 L
s
0 0 0 r
2.5 Mabswid
.59656 .68592 Mdot
.039 .916 .04 r
.5 Mabswid
.54106 .73177 m
.55032 .73808 L
s
0 0 0 r
2.5 Mabswid
.55032 .73808 Mdot
.039 .916 .04 r
.5 Mabswid
.60391 .61119 m
.60545 .61101 L
s
0 0 0 r
2.5 Mabswid
.60545 .61101 Mdot
.039 .916 .04 r
.5 Mabswid
.65184 .43035 m
.66079 .43254 L
s
0 0 0 r
2.5 Mabswid
.66079 .43254 Mdot
.039 .916 .04 r
.5 Mabswid
.36131 .60053 m
.36194 .59968 L
s
0 0 0 r
2.5 Mabswid
.36194 .59968 Mdot
.039 .916 .04 r
.5 Mabswid
.65152 .288 m
.6464 .27298 L
s
0 0 0 r
2.5 Mabswid
.6464 .27298 Mdot
.039 .916 .04 r
.5 Mabswid
.64682 .49035 m
.6534 .48303 L
s
0 0 0 r
2.5 Mabswid
.6534 .48303 Mdot
.039 .916 .04 r
.5 Mabswid
.66048 .38885 m
.66629 .38593 L
s
0 0 0 r
2.5 Mabswid
.66629 .38593 Mdot
.039 .916 .04 r
.5 Mabswid
.33897 .29783 m
.32299 .28749 L
s
0 0 0 r
2.5 Mabswid
.32299 .28749 Mdot
.039 .916 .04 r
.5 Mabswid
.52731 .55672 m
.52843 .56477 L
s
0 0 0 r
2.5 Mabswid
.52843 .56477 Mdot
.039 .916 .04 r
.5 Mabswid
.59656 .68592 m
.60578 .67572 L
s
0 0 0 r
2.5 Mabswid
.60578 .67572 Mdot
.039 .916 .04 r
.5 Mabswid
.55032 .73808 m
.55035 .7381 L
s
0 0 0 r
2.5 Mabswid
.55035 .7381 Mdot
.039 .916 .04 r
.5 Mabswid
.60545 .61101 m
.60754 .61056 L
s
0 0 0 r
2.5 Mabswid
.60754 .61056 Mdot
.039 .916 .04 r
.5 Mabswid
.66079 .43254 m
.6691 .43752 L
s
0 0 0 r
2.5 Mabswid
.6691 .43752 Mdot
.039 .916 .04 r
.5 Mabswid
.36194 .59968 m
.37258 .58563 L
s
0 0 0 r
2.5 Mabswid
.37258 .58563 Mdot
.039 .916 .04 r
.5 Mabswid
.6464 .27298 m
.64536 .26192 L
s
0 0 0 r
2.5 Mabswid
.64536 .26192 Mdot
.039 .916 .04 r
.5 Mabswid
.6534 .48303 m
.65688 .47548 L
s
0 0 0 r
2.5 Mabswid
.65688 .47548 Mdot
.039 .916 .04 r
.5 Mabswid
.66629 .38593 m
.6728 .3803 L
s
0 0 0 r
2.5 Mabswid
.6728 .3803 Mdot
.039 .916 .04 r
.5 Mabswid
.32299 .28749 m
.31577 .28567 L
s
0 0 0 r
2.5 Mabswid
.31577 .28567 Mdot
.039 .916 .04 r
.5 Mabswid
.52843 .56477 m
.53054 .57637 L
s
0 0 0 r
2.5 Mabswid
.53054 .57637 Mdot
.039 .916 .04 r
.5 Mabswid
.60578 .67572 m
.61239 .66043 L
s
0 0 0 r
2.5 Mabswid
.61239 .66043 Mdot
.039 .916 .04 r
.5 Mabswid
.55035 .7381 m
.55038 .73808 L
s
0 0 0 r
2.5 Mabswid
.55038 .73808 Mdot
.039 .916 .04 r
.5 Mabswid
.60754 .61056 m
.62146 .60115 L
s
0 0 0 r
2.5 Mabswid
.62146 .60115 Mdot
.039 .916 .04 r
.5 Mabswid
.6691 .43752 m
.67919 .44925 L
s
0 0 0 r
2.5 Mabswid
.67919 .44925 Mdot
.039 .916 .04 r
.5 Mabswid
.37258 .58563 m
.37884 .58005 L
s
0 0 0 r
2.5 Mabswid
.37884 .58005 Mdot
.039 .916 .04 r
.5 Mabswid
.64536 .26192 m
.64536 .2619 L
s
0 0 0 r
2.5 Mabswid
.64536 .2619 Mdot
.039 .916 .04 r
.5 Mabswid
.65688 .47548 m
.66295 .463 L
s
0 0 0 r
2.5 Mabswid
.66295 .463 Mdot
.039 .916 .04 r
.5 Mabswid
.6728 .3803 m
.68027 .37691 L
s
0 0 0 r
2.5 Mabswid
.68027 .37691 Mdot
.039 .916 .04 r
.5 Mabswid
.31577 .28567 m
.3003 .28779 L
s
0 0 0 r
2.5 Mabswid
.3003 .28779 Mdot
.039 .916 .04 r
.5 Mabswid
.53054 .57637 m
.53702 .58763 L
s
0 0 0 r
2.5 Mabswid
.53702 .58763 Mdot
.039 .916 .04 r
.5 Mabswid
.61239 .66043 m
.61613 .65616 L
s
0 0 0 r
2.5 Mabswid
.61613 .65616 Mdot
.039 .916 .04 r
.5 Mabswid
.55038 .73808 m
.56153 .72726 L
s
0 0 0 r
2.5 Mabswid
.56153 .72726 Mdot
.039 .916 .04 r
.5 Mabswid
.62146 .60115 m
.62666 .59953 L
s
0 0 0 r
2.5 Mabswid
.62666 .59953 Mdot
.039 .916 .04 r
.5 Mabswid
.67919 .44925 m
.68513 .46226 L
s
0 0 0 r
2.5 Mabswid
.68513 .46226 Mdot
.039 .916 .04 r
.5 Mabswid
.37884 .58005 m
.38286 .57378 L
s
0 0 0 r
2.5 Mabswid
.38286 .57378 Mdot
.039 .916 .04 r
.5 Mabswid
.66295 .463 m
.67302 .44988 L
s
0 0 0 r
2.5 Mabswid
.67302 .44988 Mdot
.039 .916 .04 r
.5 Mabswid
.68027 .37691 m
.69046 .37367 L
s
0 0 0 r
2.5 Mabswid
.69046 .37367 Mdot
.039 .916 .04 r
.5 Mabswid
.3003 .28779 m
.28937 .28642 L
s
0 0 0 r
2.5 Mabswid
.28937 .28642 Mdot
.039 .916 .04 r
.5 Mabswid
.53702 .58763 m
.54265 .59379 L
s
0 0 0 r
2.5 Mabswid
.54265 .59379 Mdot
.039 .916 .04 r
.5 Mabswid
.61613 .65616 m
.62565 .64306 L
s
0 0 0 r
2.5 Mabswid
.62565 .64306 Mdot
.039 .916 .04 r
.5 Mabswid
.56153 .72726 m
.56182 .7271 L
s
0 0 0 r
2.5 Mabswid
.56182 .7271 Mdot
.039 .916 .04 r
.5 Mabswid
.62666 .59953 m
.62742 .59946 L
s
0 0 0 r
2.5 Mabswid
.62742 .59946 Mdot
.039 .916 .04 r
.5 Mabswid
.68513 .46226 m
.68554 .46864 L
s
0 0 0 r
2.5 Mabswid
.68554 .46864 Mdot
.039 .916 .04 r
.5 Mabswid
.38286 .57378 m
.3904 .56183 L
s
0 0 0 r
2.5 Mabswid
.3904 .56183 Mdot
.039 .916 .04 r
.5 Mabswid
.67302 .44988 m
.67624 .44052 L
s
0 0 0 r
2.5 Mabswid
.67624 .44052 Mdot
.039 .916 .04 r
.5 Mabswid
.69046 .37367 m
.69048 .37366 L
s
0 0 0 r
2.5 Mabswid
.69048 .37366 Mdot
.039 .916 .04 r
.5 Mabswid
.28937 .28642 m
.28073 .28442 L
s
0 0 0 r
2.5 Mabswid
.28073 .28442 Mdot
.039 .916 .04 r
.5 Mabswid
.54265 .59379 m
.54836 .60728 L
s
0 0 0 r
2.5 Mabswid
.54836 .60728 Mdot
.039 .916 .04 r
.5 Mabswid
.62565 .64306 m
.62694 .64209 L
s
0 0 0 r
2.5 Mabswid
.62694 .64209 Mdot
.039 .916 .04 r
.5 Mabswid
.56182 .7271 m
.57518 .71633 L
s
0 0 0 r
2.5 Mabswid
.57518 .71633 Mdot
.039 .916 .04 r
.5 Mabswid
.62742 .59946 m
.63612 .59527 L
s
0 0 0 r
2.5 Mabswid
.63612 .59527 Mdot
.039 .916 .04 r
.5 Mabswid
.68554 .46864 m
.69046 .47997 L
s
0 0 0 r
2.5 Mabswid
.69046 .47997 Mdot
.039 .916 .04 r
.5 Mabswid
.3904 .56183 m
.39609 .55485 L
s
0 0 0 r
2.5 Mabswid
.39609 .55485 Mdot
.039 .916 .04 r
.5 Mabswid
.67624 .44052 m
.67768 .42809 L
s
0 0 0 r
2.5 Mabswid
.67768 .42809 Mdot
.039 .916 .04 r
.5 Mabswid
.28073 .28442 m
.27308 .27995 L
s
0 0 0 r
2.5 Mabswid
.27308 .27995 Mdot
.039 .916 .04 r
.5 Mabswid
.54836 .60728 m
.55498 .61722 L
s
0 0 0 r
2.5 Mabswid
.55498 .61722 Mdot
.039 .916 .04 r
.5 Mabswid
.62694 .64209 m
.62892 .64031 L
s
0 0 0 r
2.5 Mabswid
.62892 .64031 Mdot
.039 .916 .04 r
.5 Mabswid
.57518 .71633 m
.58521 .70278 L
s
0 0 0 r
2.5 Mabswid
.58521 .70278 Mdot
.039 .916 .04 r
.5 Mabswid
.63612 .59527 m
.64758 .59243 L
s
0 0 0 r
2.5 Mabswid
.64758 .59243 Mdot
.039 .916 .04 r
.5 Mabswid
.69046 .47997 m
.69048 .48001 L
s
0 0 0 r
2.5 Mabswid
.69048 .48001 Mdot
.039 .916 .04 r
.5 Mabswid
.39609 .55485 m
.39988 .5476 L
s
0 0 0 r
2.5 Mabswid
.39988 .5476 Mdot
.039 .916 .04 r
.5 Mabswid
.67768 .42809 m
.68433 .41331 L
s
0 0 0 r
2.5 Mabswid
.68433 .41331 Mdot
.039 .916 .04 r
.5 Mabswid
.27308 .27995 m
.26882 .27471 L
s
0 0 0 r
2.5 Mabswid
.26882 .27471 Mdot
.039 .916 .04 r
.5 Mabswid
.55498 .61722 m
.56052 .63445 L
s
0 0 0 r
2.5 Mabswid
.56052 .63445 Mdot
.039 .916 .04 r
.5 Mabswid
.62892 .64031 m
.64366 .63373 L
s
0 0 0 r
2.5 Mabswid
.64366 .63373 Mdot
.039 .916 .04 r
.5 Mabswid
.58521 .70278 m
.58882 .69423 L
s
0 0 0 r
2.5 Mabswid
.58882 .69423 Mdot
.039 .916 .04 r
.5 Mabswid
.64758 .59243 m
.65138 .59203 L
s
0 0 0 r
2.5 Mabswid
.65138 .59203 Mdot
.039 .916 .04 r
.5 Mabswid
.69048 .48001 m
.69046 .48006 L
s
0 0 0 r
2.5 Mabswid
.69046 .48006 Mdot
.039 .916 .04 r
.5 Mabswid
.39988 .5476 m
.40015 .54682 L
s
0 0 0 r
2.5 Mabswid
.40015 .54682 Mdot
.039 .916 .04 r
.5 Mabswid
.68433 .41331 m
.69046 .39665 L
s
0 0 0 r
2.5 Mabswid
.69046 .39665 Mdot
.039 .916 .04 r
.5 Mabswid
.26882 .27471 m
.26413 .26192 L
s
0 0 0 r
2.5 Mabswid
.26413 .26192 Mdot
.039 .916 .04 r
.5 Mabswid
.56052 .63445 m
.56448 .64139 L
s
0 0 0 r
2.5 Mabswid
.56448 .64139 Mdot
.039 .916 .04 r
.5 Mabswid
.64366 .63373 m
.64577 .63198 L
s
0 0 0 r
2.5 Mabswid
.64577 .63198 Mdot
.039 .916 .04 r
.5 Mabswid
.58882 .69423 m
.59185 .6912 L
s
0 0 0 r
2.5 Mabswid
.59185 .6912 Mdot
.039 .916 .04 r
.5 Mabswid
.65138 .59203 m
.65991 .58947 L
s
0 0 0 r
2.5 Mabswid
.65991 .58947 Mdot
.039 .916 .04 r
.5 Mabswid
.69046 .48006 m
.68987 .49729 L
s
0 0 0 r
2.5 Mabswid
.68987 .49729 Mdot
.039 .916 .04 r
.5 Mabswid
.40015 .54682 m
.40059 .54575 L
s
0 0 0 r
2.5 Mabswid
.40059 .54575 Mdot
.039 .916 .04 r
.5 Mabswid
.69046 .39665 m
.69048 .3966 L
s
0 0 0 r
2.5 Mabswid
.69048 .3966 Mdot
.039 .916 .04 r
.5 Mabswid
.26413 .26192 m
.26412 .2619 L
s
0 0 0 r
2.5 Mabswid
.26412 .2619 Mdot
.039 .916 .04 r
.5 Mabswid
.56448 .64139 m
.56843 .65974 L
s
0 0 0 r
2.5 Mabswid
.56843 .65974 Mdot
.039 .916 .04 r
.5 Mabswid
.64577 .63198 m
.6591 .62391 L
s
0 0 0 r
2.5 Mabswid
.6591 .62391 Mdot
.039 .916 .04 r
.5 Mabswid
.59185 .6912 m
.60092 .67822 L
s
0 0 0 r
2.5 Mabswid
.60092 .67822 Mdot
.039 .916 .04 r
.5 Mabswid
.65991 .58947 m
.67384 .58225 L
s
0 0 0 r
2.5 Mabswid
.67384 .58225 Mdot
.039 .916 .04 r
.5 Mabswid
.68987 .49729 m
.69013 .50815 L
s
0 0 0 r
2.5 Mabswid
.69013 .50815 Mdot
.039 .916 .04 r
.5 Mabswid
.40059 .54575 m
.41044 .53437 L
s
0 0 0 r
2.5 Mabswid
.41044 .53437 Mdot
.039 .916 .04 r
.5 Mabswid
.69048 .3966 m
.69046 .39654 L
s
0 0 0 r
2.5 Mabswid
.69046 .39654 Mdot
.039 .916 .04 r
.5 Mabswid
.56843 .65974 m
.56882 .6614 L
s
0 0 0 r
2.5 Mabswid
.56882 .6614 Mdot
.039 .916 .04 r
.5 Mabswid
.6591 .62391 m
.66663 .61472 L
s
0 0 0 r
2.5 Mabswid
.66663 .61472 Mdot
.039 .916 .04 r
.5 Mabswid
.60092 .67822 m
.61384 .66988 L
s
0 0 0 r
2.5 Mabswid
.61384 .66988 Mdot
.039 .916 .04 r
.5 Mabswid
.67384 .58225 m
.69046 .57917 L
s
0 0 0 r
2.5 Mabswid
.69046 .57917 Mdot
.039 .916 .04 r
.5 Mabswid
.69013 .50815 m
.68778 .51468 L
s
0 0 0 r
2.5 Mabswid
.68778 .51468 Mdot
.039 .916 .04 r
.5 Mabswid
.41044 .53437 m
.41436 .52814 L
s
0 0 0 r
2.5 Mabswid
.41436 .52814 Mdot
.039 .916 .04 r
.5 Mabswid
.69046 .39654 m
.68544 .3896 L
s
0 0 0 r
2.5 Mabswid
.68544 .3896 Mdot
.039 .916 .04 r
.5 Mabswid
.56882 .6614 m
.57072 .67853 L
s
0 0 0 r
2.5 Mabswid
.57072 .67853 Mdot
.039 .916 .04 r
.5 Mabswid
.66663 .61472 m
.67287 .61096 L
s
0 0 0 r
2.5 Mabswid
.67287 .61096 Mdot
.039 .916 .04 r
.5 Mabswid
.61384 .66988 m
.62574 .65725 L
s
0 0 0 r
2.5 Mabswid
.62574 .65725 Mdot
.039 .916 .04 r
.5 Mabswid
.69046 .57917 m
.69048 .57916 L
s
0 0 0 r
2.5 Mabswid
.69048 .57916 Mdot
.039 .916 .04 r
.5 Mabswid
.68778 .51468 m
.68799 .52432 L
s
0 0 0 r
2.5 Mabswid
.68799 .52432 Mdot
.039 .916 .04 r
.5 Mabswid
.41436 .52814 m
.41928 .51094 L
s
0 0 0 r
2.5 Mabswid
.41928 .51094 Mdot
.039 .916 .04 r
.5 Mabswid
.68544 .3896 m
.68222 .38745 L
s
0 0 0 r
2.5 Mabswid
.68222 .38745 Mdot
.039 .916 .04 r
.5 Mabswid
.57072 .67853 m
.57474 .6944 L
s
0 0 0 r
2.5 Mabswid
.57474 .6944 Mdot
.039 .916 .04 r
.5 Mabswid
.67287 .61096 m
.68083 .60332 L
s
0 0 0 r
2.5 Mabswid
.68083 .60332 Mdot
.039 .916 .04 r
.5 Mabswid
.62574 .65725 m
.62656 .65638 L
s
0 0 0 r
2.5 Mabswid
.62656 .65638 Mdot
.039 .916 .04 r
.5 Mabswid
.68799 .52432 m
.68758 .52858 L
s
0 0 0 r
2.5 Mabswid
.68758 .52858 Mdot
.039 .916 .04 r
.5 Mabswid
.41928 .51094 m
.42484 .49933 L
s
0 0 0 r
2.5 Mabswid
.42484 .49933 Mdot
.039 .916 .04 r
.5 Mabswid
.68222 .38745 m
.66992 .37928 L
s
0 0 0 r
2.5 Mabswid
.66992 .37928 Mdot
.039 .916 .04 r
.5 Mabswid
.57474 .6944 m
.58296 .70658 L
s
0 0 0 r
2.5 Mabswid
.58296 .70658 Mdot
.039 .916 .04 r
.5 Mabswid
.68083 .60332 m
.69046 .59493 L
s
0 0 0 r
2.5 Mabswid
.69046 .59493 Mdot
.039 .916 .04 r
.5 Mabswid
.62656 .65638 m
.6332 .65255 L
s
0 0 0 r
2.5 Mabswid
.6332 .65255 Mdot
.039 .916 .04 r
.5 Mabswid
.68758 .52858 m
.68563 .54486 L
s
0 0 0 r
2.5 Mabswid
.68563 .54486 Mdot
.039 .916 .04 r
.5 Mabswid
.42484 .49933 m
.43486 .48549 L
s
0 0 0 r
2.5 Mabswid
.43486 .48549 Mdot
.039 .916 .04 r
.5 Mabswid
.66992 .37928 m
.65519 .36973 L
s
0 0 0 r
2.5 Mabswid
.65519 .36973 Mdot
.039 .916 .04 r
.5 Mabswid
.58296 .70658 m
.59126 .71709 L
s
0 0 0 r
2.5 Mabswid
.59126 .71709 Mdot
.039 .916 .04 r
.5 Mabswid
.69046 .59493 m
.69048 .59491 L
s
0 0 0 r
2.5 Mabswid
.69048 .59491 Mdot
.039 .916 .04 r
.5 Mabswid
.6332 .65255 m
.63424 .65166 L
s
0 0 0 r
2.5 Mabswid
.63424 .65166 Mdot
.039 .916 .04 r
.5 Mabswid
.68563 .54486 m
.68455 .54717 L
s
0 0 0 r
2.5 Mabswid
.68455 .54717 Mdot
.039 .916 .04 r
.5 Mabswid
.43486 .48549 m
.4351 .48521 L
s
0 0 0 r
2.5 Mabswid
.4351 .48521 Mdot
.039 .916 .04 r
.5 Mabswid
.65519 .36973 m
.63882 .36412 L
s
0 0 0 r
2.5 Mabswid
.63882 .36412 Mdot
.039 .916 .04 r
.5 Mabswid
.59126 .71709 m
.59664 .72081 L
s
0 0 0 r
2.5 Mabswid
.59664 .72081 Mdot
.039 .916 .04 r
.5 Mabswid
.63424 .65166 m
.63573 .64937 L
s
0 0 0 r
2.5 Mabswid
.63573 .64937 Mdot
.039 .916 .04 r
.5 Mabswid
.68455 .54717 m
.67949 .55681 L
s
0 0 0 r
2.5 Mabswid
.67949 .55681 Mdot
.039 .916 .04 r
.5 Mabswid
.4351 .48521 m
.44225 .47305 L
s
0 0 0 r
2.5 Mabswid
.44225 .47305 Mdot
.039 .916 .04 r
.5 Mabswid
.63882 .36412 m
.62528 .36465 L
s
0 0 0 r
2.5 Mabswid
.62528 .36465 Mdot
.039 .916 .04 r
.5 Mabswid
.59664 .72081 m
.60963 .73028 L
s
0 0 0 r
2.5 Mabswid
.60963 .73028 Mdot
.039 .916 .04 r
.5 Mabswid
.63573 .64937 m
.64433 .63702 L
s
0 0 0 r
2.5 Mabswid
.64433 .63702 Mdot
.039 .916 .04 r
.5 Mabswid
.67949 .55681 m
.67895 .55963 L
s
0 0 0 r
2.5 Mabswid
.67895 .55963 Mdot
.039 .916 .04 r
.5 Mabswid
.44225 .47305 m
.44706 .46004 L
s
0 0 0 r
2.5 Mabswid
.44706 .46004 Mdot
.039 .916 .04 r
.5 Mabswid
.62528 .36465 m
.62479 .36477 L
s
0 0 0 r
2.5 Mabswid
.62479 .36477 Mdot
.039 .916 .04 r
.5 Mabswid
.60963 .73028 m
.61798 .73808 L
s
0 0 0 r
2.5 Mabswid
.61798 .73808 Mdot
.039 .916 .04 r
.5 Mabswid
.64433 .63702 m
.64763 .62374 L
s
0 0 0 r
2.5 Mabswid
.64763 .62374 Mdot
.039 .916 .04 r
.5 Mabswid
.67895 .55963 m
.67847 .56182 L
s
0 0 0 r
2.5 Mabswid
.67847 .56182 Mdot
.039 .916 .04 r
.5 Mabswid
.44706 .46004 m
.45164 .4543 L
s
0 0 0 r
2.5 Mabswid
.45164 .4543 Mdot
.039 .916 .04 r
.5 Mabswid
.62479 .36477 m
.60635 .36266 L
s
0 0 0 r
2.5 Mabswid
.60635 .36266 Mdot
.039 .916 .04 r
.5 Mabswid
.61798 .73808 m
.618 .7381 L
s
0 0 0 r
2.5 Mabswid
.618 .7381 Mdot
.039 .916 .04 r
.5 Mabswid
.64763 .62374 m
.65309 .60923 L
s
0 0 0 r
2.5 Mabswid
.65309 .60923 Mdot
.039 .916 .04 r
.5 Mabswid
.67847 .56182 m
.676 .56575 L
s
0 0 0 r
2.5 Mabswid
.676 .56575 Mdot
.039 .916 .04 r
.5 Mabswid
.45164 .4543 m
.45242 .45231 L
s
0 0 0 r
2.5 Mabswid
.45242 .45231 Mdot
.039 .916 .04 r
.5 Mabswid
.60635 .36266 m
.59874 .36241 L
s
0 0 0 r
2.5 Mabswid
.59874 .36241 Mdot
.039 .916 .04 r
.5 Mabswid
.618 .7381 m
.61802 .73808 L
s
0 0 0 r
2.5 Mabswid
.61802 .73808 Mdot
.039 .916 .04 r
.5 Mabswid
.65309 .60923 m
.6626 .59894 L
s
0 0 0 r
2.5 Mabswid
.6626 .59894 Mdot
.039 .916 .04 r
.5 Mabswid
.676 .56575 m
.67133 .58297 L
s
0 0 0 r
2.5 Mabswid
.67133 .58297 Mdot
.039 .916 .04 r
.5 Mabswid
.45242 .45231 m
.46113 .43915 L
s
0 0 0 r
2.5 Mabswid
.46113 .43915 Mdot
.039 .916 .04 r
.5 Mabswid
.59874 .36241 m
.58036 .36227 L
s
0 0 0 r
2.5 Mabswid
.58036 .36227 Mdot
.039 .916 .04 r
.5 Mabswid
.61802 .73808 m
.62024 .7353 L
s
0 0 0 r
2.5 Mabswid
.62024 .7353 Mdot
.039 .916 .04 r
.5 Mabswid
.6626 .59894 m
.66293 .59841 L
s
0 0 0 r
2.5 Mabswid
.66293 .59841 Mdot
.039 .916 .04 r
.5 Mabswid
.67133 .58297 m
.67089 .58422 L
s
0 0 0 r
2.5 Mabswid
.67089 .58422 Mdot
.039 .916 .04 r
.5 Mabswid
.46113 .43915 m
.46553 .428 L
s
0 0 0 r
2.5 Mabswid
.46553 .428 Mdot
.039 .916 .04 r
.5 Mabswid
.58036 .36227 m
.57894 .36182 L
s
0 0 0 r
2.5 Mabswid
.57894 .36182 Mdot
.039 .916 .04 r
.5 Mabswid
.62024 .7353 m
.62384 .72632 L
s
0 0 0 r
2.5 Mabswid
.62384 .72632 Mdot
.039 .916 .04 r
.5 Mabswid
.66293 .59841 m
.66598 .59341 L
s
0 0 0 r
2.5 Mabswid
.66598 .59341 Mdot
.039 .916 .04 r
.5 Mabswid
.67089 .58422 m
.67084 .58508 L
s
0 0 0 r
2.5 Mabswid
.67084 .58508 Mdot
.039 .916 .04 r
.5 Mabswid
.46553 .428 m
.47094 .41856 L
s
0 0 0 r
2.5 Mabswid
.47094 .41856 Mdot
.039 .916 .04 r
.5 Mabswid
.57894 .36182 m
.57726 .36061 L
s
0 0 0 r
2.5 Mabswid
.57726 .36061 Mdot
.039 .916 .04 r
.5 Mabswid
.62384 .72632 m
.62991 .71353 L
s
0 0 0 r
2.5 Mabswid
.62991 .71353 Mdot
.039 .916 .04 r
.5 Mabswid
.66598 .59341 m
.66745 .59109 L
s
0 0 0 r
2.5 Mabswid
.66745 .59109 Mdot
.039 .916 .04 r
.5 Mabswid
.67084 .58508 m
.67216 .5958 L
s
0 0 0 r
2.5 Mabswid
.67216 .5958 Mdot
.039 .916 .04 r
.5 Mabswid
.47094 .41856 m
.47171 .41637 L
s
0 0 0 r
2.5 Mabswid
.47171 .41637 Mdot
.039 .916 .04 r
.5 Mabswid
.57726 .36061 m
.5703 .35392 L
s
0 0 0 r
2.5 Mabswid
.5703 .35392 Mdot
.039 .916 .04 r
.5 Mabswid
.62991 .71353 m
.63065 .70418 L
s
0 0 0 r
2.5 Mabswid
.63065 .70418 Mdot
.039 .916 .04 r
.5 Mabswid
.66745 .59109 m
.67344 .58526 L
s
0 0 0 r
2.5 Mabswid
.67344 .58526 Mdot
.039 .916 .04 r
.5 Mabswid
.67216 .5958 m
.66846 .61417 L
s
0 0 0 r
2.5 Mabswid
.66846 .61417 Mdot
.039 .916 .04 r
.5 Mabswid
.47171 .41637 m
.47221 .41373 L
s
0 0 0 r
2.5 Mabswid
.47221 .41373 Mdot
.039 .916 .04 r
.5 Mabswid
.5703 .35392 m
.56005 .33904 L
s
0 0 0 r
2.5 Mabswid
.56005 .33904 Mdot
.039 .916 .04 r
.5 Mabswid
.63065 .70418 m
.63253 .69349 L
s
0 0 0 r
2.5 Mabswid
.63253 .69349 Mdot
.039 .916 .04 r
.5 Mabswid
.67344 .58526 m
.68763 .57747 L
s
0 0 0 r
2.5 Mabswid
.68763 .57747 Mdot
.039 .916 .04 r
.5 Mabswid
.66846 .61417 m
.671 .62971 L
s
0 0 0 r
2.5 Mabswid
.671 .62971 Mdot
.039 .916 .04 r
.5 Mabswid
.47221 .41373 m
.47283 .40011 L
s
0 0 0 r
2.5 Mabswid
.47283 .40011 Mdot
.039 .916 .04 r
.5 Mabswid
.56005 .33904 m
.55812 .33428 L
s
0 0 0 r
2.5 Mabswid
.55812 .33428 Mdot
.039 .916 .04 r
.5 Mabswid
.63253 .69349 m
.63048 .68217 L
s
0 0 0 r
2.5 Mabswid
.63048 .68217 Mdot
.039 .916 .04 r
.5 Mabswid
.68763 .57747 m
.69046 .57448 L
s
0 0 0 r
2.5 Mabswid
.69046 .57448 Mdot
.039 .916 .04 r
.5 Mabswid
.671 .62971 m
.6785 .64215 L
s
0 0 0 r
2.5 Mabswid
.6785 .64215 Mdot
.039 .916 .04 r
.5 Mabswid
.47283 .40011 m
.47257 .3978 L
s
0 0 0 r
2.5 Mabswid
.47257 .3978 Mdot
.039 .916 .04 r
.5 Mabswid
.55812 .33428 m
.55404 .32939 L
s
0 0 0 r
2.5 Mabswid
.55404 .32939 Mdot
.039 .916 .04 r
.5 Mabswid
.63048 .68217 m
.63103 .6796 L
s
0 0 0 r
2.5 Mabswid
.63103 .6796 Mdot
.039 .916 .04 r
.5 Mabswid
.69046 .57448 m
.69048 .57446 L
s
0 0 0 r
2.5 Mabswid
.69048 .57446 Mdot
.039 .916 .04 r
.5 Mabswid
.6785 .64215 m
.68087 .6452 L
s
0 0 0 r
2.5 Mabswid
.68087 .6452 Mdot
.039 .916 .04 r
.5 Mabswid
.47257 .3978 m
.47184 .39428 L
s
0 0 0 r
2.5 Mabswid
.47184 .39428 Mdot
.039 .916 .04 r
.5 Mabswid
.55404 .32939 m
.54634 .3201 L
s
0 0 0 r
2.5 Mabswid
.54634 .3201 Mdot
.039 .916 .04 r
.5 Mabswid
.63103 .6796 m
.63157 .67316 L
s
0 0 0 r
2.5 Mabswid
.63157 .67316 Mdot
.039 .916 .04 r
.5 Mabswid
.69048 .57446 m
.69046 .57444 L
s
0 0 0 r
2.5 Mabswid
.69046 .57444 Mdot
.039 .916 .04 r
.5 Mabswid
.68087 .6452 m
.69046 .65265 L
s
0 0 0 r
2.5 Mabswid
.69046 .65265 Mdot
.039 .916 .04 r
.5 Mabswid
.47184 .39428 m
.47146 .39189 L
s
0 0 0 r
2.5 Mabswid
.47146 .39189 Mdot
.039 .916 .04 r
.5 Mabswid
.54634 .3201 m
.54378 .31838 L
s
0 0 0 r
2.5 Mabswid
.54378 .31838 Mdot
.039 .916 .04 r
.5 Mabswid
.63157 .67316 m
.6316 .67273 L
s
0 0 0 r
2.5 Mabswid
.6316 .67273 Mdot
.039 .916 .04 r
.5 Mabswid
.69046 .57444 m
.68891 .57173 L
s
0 0 0 r
2.5 Mabswid
.68891 .57173 Mdot
.039 .916 .04 r
.5 Mabswid
.69046 .65265 m
.69048 .65266 L
s
0 0 0 r
2.5 Mabswid
.69048 .65266 Mdot
.039 .916 .04 r
.5 Mabswid
.47146 .39189 m
.47063 .37918 L
s
0 0 0 r
2.5 Mabswid
.47063 .37918 Mdot
.039 .916 .04 r
.5 Mabswid
.54378 .31838 m
.53172 .30969 L
s
0 0 0 r
2.5 Mabswid
.53172 .30969 Mdot
.039 .916 .04 r
.5 Mabswid
.6316 .67273 m
.63056 .66969 L
s
0 0 0 r
2.5 Mabswid
.63056 .66969 Mdot
.039 .916 .04 r
.5 Mabswid
.68891 .57173 m
.68643 .56358 L
s
0 0 0 r
2.5 Mabswid
.68643 .56358 Mdot
.039 .916 .04 r
.5 Mabswid
.47063 .37918 m
.47531 .36118 L
s
0 0 0 r
2.5 Mabswid
.47531 .36118 Mdot
.039 .916 .04 r
.5 Mabswid
.53172 .30969 m
.51775 .30034 L
s
0 0 0 r
2.5 Mabswid
.51775 .30034 Mdot
.039 .916 .04 r
.5 Mabswid
.63056 .66969 m
.6288 .65371 L
s
0 0 0 r
2.5 Mabswid
.6288 .65371 Mdot
.039 .916 .04 r
.5 Mabswid
.68643 .56358 m
.68262 .55633 L
s
0 0 0 r
2.5 Mabswid
.68262 .55633 Mdot
.039 .916 .04 r
.5 Mabswid
.47531 .36118 m
.47979 .34808 L
s
0 0 0 r
2.5 Mabswid
.47979 .34808 Mdot
.039 .916 .04 r
.5 Mabswid
.51775 .30034 m
.51367 .29696 L
s
0 0 0 r
2.5 Mabswid
.51367 .29696 Mdot
.039 .916 .04 r
.5 Mabswid
.6288 .65371 m
.62485 .64069 L
s
0 0 0 r
2.5 Mabswid
.62485 .64069 Mdot
.039 .916 .04 r
.5 Mabswid
.68262 .55633 m
.68208 .55403 L
s
0 0 0 r
2.5 Mabswid
.68208 .55403 Mdot
.039 .916 .04 r
.5 Mabswid
.47979 .34808 m
.48025 .34712 L
s
0 0 0 r
2.5 Mabswid
.48025 .34712 Mdot
.039 .916 .04 r
.5 Mabswid
.51367 .29696 m
.50799 .2937 L
s
0 0 0 r
2.5 Mabswid
.50799 .2937 Mdot
.039 .916 .04 r
.5 Mabswid
.62485 .64069 m
.62154 .62412 L
s
0 0 0 r
2.5 Mabswid
.62154 .62412 Mdot
.039 .916 .04 r
.5 Mabswid
.68208 .55403 m
.67823 .53738 L
s
0 0 0 r
2.5 Mabswid
.67823 .53738 Mdot
.039 .916 .04 r
.5 Mabswid
.48025 .34712 m
.49026 .33296 L
s
0 0 0 r
2.5 Mabswid
.49026 .33296 Mdot
.039 .916 .04 r
.5 Mabswid
.50799 .2937 m
.50753 .29362 L
s
0 0 0 r
2.5 Mabswid
.50753 .29362 Mdot
.039 .916 .04 r
.5 Mabswid
.62154 .62412 m
.62176 .62268 L
s
0 0 0 r
2.5 Mabswid
.62176 .62268 Mdot
.039 .916 .04 r
.5 Mabswid
.67823 .53738 m
.67819 .52607 L
s
0 0 0 r
2.5 Mabswid
.67819 .52607 Mdot
.039 .916 .04 r
.5 Mabswid
.49026 .33296 m
.49341 .32709 L
s
0 0 0 r
2.5 Mabswid
.49341 .32709 Mdot
.039 .916 .04 r
.5 Mabswid
.50753 .29362 m
.50136 .29428 L
s
0 0 0 r
2.5 Mabswid
.50136 .29428 Mdot
.039 .916 .04 r
.5 Mabswid
.62176 .62268 m
.61962 .61078 L
s
0 0 0 r
2.5 Mabswid
.61962 .61078 Mdot
.039 .916 .04 r
.5 Mabswid
.67819 .52607 m
.67764 .52207 L
s
0 0 0 r
2.5 Mabswid
.67764 .52207 Mdot
.039 .916 .04 r
.5 Mabswid
.49341 .32709 m
.49825 .31696 L
s
0 0 0 r
2.5 Mabswid
.49825 .31696 Mdot
.039 .916 .04 r
.5 Mabswid
.50136 .29428 m
.48656 .30165 L
s
0 0 0 r
2.5 Mabswid
.48656 .30165 Mdot
.039 .916 .04 r
.5 Mabswid
.61962 .61078 m
.62051 .59742 L
s
0 0 0 r
2.5 Mabswid
.62051 .59742 Mdot
.039 .916 .04 r
.5 Mabswid
.67764 .52207 m
.67577 .50367 L
s
0 0 0 r
2.5 Mabswid
.67577 .50367 Mdot
.039 .916 .04 r
.5 Mabswid
.49825 .31696 m
.50013 .30199 L
s
0 0 0 r
2.5 Mabswid
.50013 .30199 Mdot
.039 .916 .04 r
.5 Mabswid
.48656 .30165 m
.47024 .30977 L
s
0 0 0 r
2.5 Mabswid
.47024 .30977 Mdot
.039 .916 .04 r
.5 Mabswid
.62051 .59742 m
.61768 .5839 L
s
0 0 0 r
2.5 Mabswid
.61768 .5839 Mdot
.039 .916 .04 r
.5 Mabswid
.67577 .50367 m
.67625 .49658 L
s
0 0 0 r
2.5 Mabswid
.67625 .49658 Mdot
.039 .916 .04 r
.5 Mabswid
.50013 .30199 m
.50276 .29512 L
s
0 0 0 r
2.5 Mabswid
.50276 .29512 Mdot
.039 .916 .04 r
.5 Mabswid
.47024 .30977 m
.46925 .31021 L
s
0 0 0 r
2.5 Mabswid
.46925 .31021 Mdot
.039 .916 .04 r
.5 Mabswid
.61768 .5839 m
.61723 .5696 L
s
0 0 0 r
2.5 Mabswid
.61723 .5696 Mdot
.039 .916 .04 r
.5 Mabswid
.67625 .49658 m
.67392 .48066 L
s
0 0 0 r
2.5 Mabswid
.67392 .48066 Mdot
.039 .916 .04 r
.5 Mabswid
.50276 .29512 m
.5034 .29192 L
s
0 0 0 r
2.5 Mabswid
.5034 .29192 Mdot
.039 .916 .04 r
.5 Mabswid
.46925 .31021 m
.45461 .32169 L
s
0 0 0 r
2.5 Mabswid
.45461 .32169 Mdot
.039 .916 .04 r
.5 Mabswid
.61723 .5696 m
.61677 .56069 L
s
0 0 0 r
2.5 Mabswid
.61677 .56069 Mdot
.039 .916 .04 r
.5 Mabswid
.67392 .48066 m
.67391 .48036 L
s
0 0 0 r
2.5 Mabswid
.67391 .48036 Mdot
.039 .916 .04 r
.5 Mabswid
.5034 .29192 m
.50474 .2791 L
s
0 0 0 r
2.5 Mabswid
.50474 .2791 Mdot
.039 .916 .04 r
.5 Mabswid
.45461 .32169 m
.45396 .3226 L
s
0 0 0 r
2.5 Mabswid
.45396 .3226 Mdot
.039 .916 .04 r
.5 Mabswid
.61677 .56069 m
.61205 .5432 L
s
0 0 0 r
2.5 Mabswid
.61205 .5432 Mdot
.039 .916 .04 r
.5 Mabswid
.67391 .48036 m
.67261 .46736 L
s
0 0 0 r
2.5 Mabswid
.67261 .46736 Mdot
.039 .916 .04 r
.5 Mabswid
.50474 .2791 m
.5055 .26192 L
s
0 0 0 r
2.5 Mabswid
.5055 .26192 Mdot
.039 .916 .04 r
.5 Mabswid
.45396 .3226 m
.44534 .32936 L
s
0 0 0 r
2.5 Mabswid
.44534 .32936 Mdot
.039 .916 .04 r
.5 Mabswid
.61205 .5432 m
.61076 .53109 L
s
0 0 0 r
2.5 Mabswid
.61076 .53109 Mdot
.039 .916 .04 r
.5 Mabswid
.67261 .46736 m
.67271 .45166 L
s
0 0 0 r
2.5 Mabswid
.67271 .45166 Mdot
.039 .916 .04 r
.5 Mabswid
.5055 .26192 m
.5055 .2619 L
s
0 0 0 r
2.5 Mabswid
.5055 .2619 Mdot
.039 .916 .04 r
.5 Mabswid
.44534 .32936 m
.43409 .33948 L
s
0 0 0 r
2.5 Mabswid
.43409 .33948 Mdot
.039 .916 .04 r
.5 Mabswid
.61076 .53109 m
.60895 .51859 L
s
0 0 0 r
2.5 Mabswid
.60895 .51859 Mdot
.039 .916 .04 r
.5 Mabswid
.67271 .45166 m
.67807 .43704 L
s
0 0 0 r
2.5 Mabswid
.67807 .43704 Mdot
.039 .916 .04 r
.5 Mabswid
.43409 .33948 m
.43065 .3413 L
s
0 0 0 r
2.5 Mabswid
.43065 .3413 Mdot
.039 .916 .04 r
.5 Mabswid
.60895 .51859 m
.60744 .50321 L
s
0 0 0 r
2.5 Mabswid
.60744 .50321 Mdot
.039 .916 .04 r
.5 Mabswid
.67807 .43704 m
.68282 .42819 L
s
0 0 0 r
2.5 Mabswid
.68282 .42819 Mdot
.039 .916 .04 r
.5 Mabswid
.43065 .3413 m
.41882 .34973 L
s
0 0 0 r
2.5 Mabswid
.41882 .34973 Mdot
.039 .916 .04 r
.5 Mabswid
.60744 .50321 m
.60432 .49268 L
s
0 0 0 r
2.5 Mabswid
.60432 .49268 Mdot
.039 .916 .04 r
.5 Mabswid
.68282 .42819 m
.69046 .42092 L
s
0 0 0 r
2.5 Mabswid
.69046 .42092 Mdot
.039 .916 .04 r
.5 Mabswid
.41882 .34973 m
.41756 .35079 L
s
0 0 0 r
2.5 Mabswid
.41756 .35079 Mdot
.039 .916 .04 r
.5 Mabswid
.60432 .49268 m
.60421 .4925 L
s
0 0 0 r
2.5 Mabswid
.60421 .4925 Mdot
.039 .916 .04 r
.5 Mabswid
.69046 .42092 m
.69048 .4209 L
s
0 0 0 r
2.5 Mabswid
.69048 .4209 Mdot
.039 .916 .04 r
.5 Mabswid
.41756 .35079 m
.41007 .35487 L
s
0 0 0 r
2.5 Mabswid
.41007 .35487 Mdot
.039 .916 .04 r
.5 Mabswid
.60421 .4925 m
.60318 .48908 L
s
0 0 0 r
2.5 Mabswid
.60318 .48908 Mdot
.039 .916 .04 r
.5 Mabswid
.69048 .4209 m
.69046 .42088 L
s
0 0 0 r
2.5 Mabswid
.69046 .42088 Mdot
.039 .916 .04 r
.5 Mabswid
.41007 .35487 m
.40253 .36061 L
s
0 0 0 r
2.5 Mabswid
.40253 .36061 Mdot
.039 .916 .04 r
.5 Mabswid
.60318 .48908 m
.60308 .48341 L
s
0 0 0 r
2.5 Mabswid
.60308 .48341 Mdot
.039 .916 .04 r
.5 Mabswid
.69046 .42088 m
.68054 .40893 L
s
0 0 0 r
2.5 Mabswid
.68054 .40893 Mdot
.039 .916 .04 r
.5 Mabswid
.40253 .36061 m
.38777 .37147 L
s
0 0 0 r
2.5 Mabswid
.38777 .37147 Mdot
.039 .916 .04 r
.5 Mabswid
.60308 .48341 m
.60566 .47305 L
s
0 0 0 r
2.5 Mabswid
.60566 .47305 Mdot
.039 .916 .04 r
.5 Mabswid
.68054 .40893 m
.67961 .40808 L
s
0 0 0 r
2.5 Mabswid
.67961 .40808 Mdot
.039 .916 .04 r
.5 Mabswid
.38777 .37147 m
.38603 .37423 L
s
0 0 0 r
2.5 Mabswid
.38603 .37423 Mdot
.039 .916 .04 r
.5 Mabswid
.60566 .47305 m
.61318 .45863 L
s
0 0 0 r
2.5 Mabswid
.61318 .45863 Mdot
.039 .916 .04 r
.5 Mabswid
.67961 .40808 m
.67299 .40398 L
s
0 0 0 r
2.5 Mabswid
.67299 .40398 Mdot
.039 .916 .04 r
.5 Mabswid
.38603 .37423 m
.38557 .37551 L
s
0 0 0 r
2.5 Mabswid
.38557 .37551 Mdot
.039 .916 .04 r
.5 Mabswid
.61318 .45863 m
.61364 .45668 L
s
0 0 0 r
2.5 Mabswid
.61364 .45668 Mdot
.039 .916 .04 r
.5 Mabswid
.67299 .40398 m
.66903 .40258 L
s
0 0 0 r
2.5 Mabswid
.66903 .40258 Mdot
.039 .916 .04 r
.5 Mabswid
.38557 .37551 m
.3796 .38542 L
s
0 0 0 r
2.5 Mabswid
.3796 .38542 Mdot
.039 .916 .04 r
.5 Mabswid
.61364 .45668 m
.61153 .43924 L
s
0 0 0 r
2.5 Mabswid
.61153 .43924 Mdot
.039 .916 .04 r
.5 Mabswid
.66903 .40258 m
.65394 .40226 L
s
0 0 0 r
2.5 Mabswid
.65394 .40226 Mdot
.039 .916 .04 r
.5 Mabswid
.3796 .38542 m
.36982 .40088 L
s
0 0 0 r
2.5 Mabswid
.36982 .40088 Mdot
.039 .916 .04 r
.5 Mabswid
.61153 .43924 m
.61013 .43486 L
s
0 0 0 r
2.5 Mabswid
.61013 .43486 Mdot
.039 .916 .04 r
.5 Mabswid
.65394 .40226 m
.63709 .40585 L
s
0 0 0 r
2.5 Mabswid
.63709 .40585 Mdot
.039 .916 .04 r
.5 Mabswid
.36982 .40088 m
.36929 .40232 L
s
0 0 0 r
2.5 Mabswid
.36929 .40232 Mdot
.039 .916 .04 r
.5 Mabswid
.61013 .43486 m
.6097 .43379 L
s
0 0 0 r
2.5 Mabswid
.6097 .43379 Mdot
.039 .916 .04 r
.5 Mabswid
.63709 .40585 m
.62448 .40381 L
s
0 0 0 r
2.5 Mabswid
.62448 .40381 Mdot
.039 .916 .04 r
.5 Mabswid
.36929 .40232 m
.36737 .42106 L
s
0 0 0 r
2.5 Mabswid
.36737 .42106 Mdot
.039 .916 .04 r
.5 Mabswid
.6097 .43379 m
.60795 .42295 L
s
0 0 0 r
2.5 Mabswid
.60795 .42295 Mdot
.039 .916 .04 r
.5 Mabswid
.62448 .40381 m
.61155 .39652 L
s
0 0 0 r
2.5 Mabswid
.61155 .39652 Mdot
.039 .916 .04 r
.5 Mabswid
.36737 .42106 m
.37209 .4389 L
s
0 0 0 r
2.5 Mabswid
.37209 .4389 Mdot
.039 .916 .04 r
.5 Mabswid
.60795 .42295 m
.61047 .40684 L
s
0 0 0 r
2.5 Mabswid
.61047 .40684 Mdot
.039 .916 .04 r
.5 Mabswid
.61155 .39652 m
.60924 .39382 L
s
0 0 0 r
2.5 Mabswid
.60924 .39382 Mdot
.039 .916 .04 r
.5 Mabswid
.37209 .4389 m
.37809 .45488 L
s
0 0 0 r
2.5 Mabswid
.37809 .45488 Mdot
.039 .916 .04 r
.5 Mabswid
.61047 .40684 m
.61582 .38964 L
s
0 0 0 r
2.5 Mabswid
.61582 .38964 Mdot
.039 .916 .04 r
.5 Mabswid
.60924 .39382 m
.59367 .38313 L
s
0 0 0 r
2.5 Mabswid
.59367 .38313 Mdot
.039 .916 .04 r
.5 Mabswid
.37809 .45488 m
.38455 .47024 L
s
0 0 0 r
2.5 Mabswid
.38455 .47024 Mdot
.039 .916 .04 r
.5 Mabswid
.61582 .38964 m
.62451 .37397 L
s
0 0 0 r
2.5 Mabswid
.62451 .37397 Mdot
.039 .916 .04 r
.5 Mabswid
.59367 .38313 m
.59028 .38088 L
s
0 0 0 r
2.5 Mabswid
.59028 .38088 Mdot
.039 .916 .04 r
.5 Mabswid
.38455 .47024 m
.39044 .48739 L
s
0 0 0 r
2.5 Mabswid
.39044 .48739 Mdot
.039 .916 .04 r
.5 Mabswid
.62451 .37397 m
.63195 .36437 L
s
0 0 0 r
2.5 Mabswid
.63195 .36437 Mdot
.039 .916 .04 r
.5 Mabswid
.59028 .38088 m
.58759 .37865 L
s
0 0 0 r
2.5 Mabswid
.58759 .37865 Mdot
.039 .916 .04 r
.5 Mabswid
.39044 .48739 m
.3931 .49985 L
s
0 0 0 r
2.5 Mabswid
.3931 .49985 Mdot
.039 .916 .04 r
.5 Mabswid
.63195 .36437 m
.6366 .36024 L
s
0 0 0 r
2.5 Mabswid
.6366 .36024 Mdot
.039 .916 .04 r
.5 Mabswid
.58759 .37865 m
.58144 .37158 L
s
0 0 0 r
2.5 Mabswid
.58144 .37158 Mdot
.039 .916 .04 r
.5 Mabswid
.3931 .49985 m
.39566 .50763 L
s
0 0 0 r
2.5 Mabswid
.39566 .50763 Mdot
.039 .916 .04 r
.5 Mabswid
.6366 .36024 m
.64129 .35094 L
s
0 0 0 r
2.5 Mabswid
.64129 .35094 Mdot
.039 .916 .04 r
.5 Mabswid
.58144 .37158 m
.57462 .36674 L
s
0 0 0 r
2.5 Mabswid
.57462 .36674 Mdot
.039 .916 .04 r
.5 Mabswid
.39566 .50763 m
.39898 .51999 L
s
0 0 0 r
2.5 Mabswid
.39898 .51999 Mdot
.039 .916 .04 r
.5 Mabswid
.64129 .35094 m
.64513 .34226 L
s
0 0 0 r
2.5 Mabswid
.64513 .34226 Mdot
.039 .916 .04 r
.5 Mabswid
.57462 .36674 m
.5661 .36414 L
s
0 0 0 r
2.5 Mabswid
.5661 .36414 Mdot
.039 .916 .04 r
.5 Mabswid
.39898 .51999 m
.39885 .5304 L
s
0 0 0 r
2.5 Mabswid
.39885 .5304 Mdot
.039 .916 .04 r
.5 Mabswid
.64513 .34226 m
.65036 .32734 L
s
0 0 0 r
2.5 Mabswid
.65036 .32734 Mdot
.039 .916 .04 r
.5 Mabswid
.5661 .36414 m
.55901 .36364 L
s
0 0 0 r
2.5 Mabswid
.55901 .36364 Mdot
.039 .916 .04 r
.5 Mabswid
.39885 .5304 m
.39819 .53359 L
s
0 0 0 r
2.5 Mabswid
.39819 .53359 Mdot
.039 .916 .04 r
.5 Mabswid
.65036 .32734 m
.6507 .32631 L
s
0 0 0 r
2.5 Mabswid
.6507 .32631 Mdot
.039 .916 .04 r
.5 Mabswid
.55901 .36364 m
.54662 .36736 L
s
0 0 0 r
2.5 Mabswid
.54662 .36736 Mdot
.039 .916 .04 r
.5 Mabswid
.39819 .53359 m
.39936 .54547 L
s
0 0 0 r
2.5 Mabswid
.39936 .54547 Mdot
.039 .916 .04 r
.5 Mabswid
.6507 .32631 m
.65054 .32361 L
s
0 0 0 r
2.5 Mabswid
.65054 .32361 Mdot
.039 .916 .04 r
.5 Mabswid
.54662 .36736 m
.54286 .36723 L
s
0 0 0 r
2.5 Mabswid
.54286 .36723 Mdot
.039 .916 .04 r
.5 Mabswid
.39936 .54547 m
.40062 .55433 L
s
0 0 0 r
2.5 Mabswid
.40062 .55433 Mdot
.039 .916 .04 r
.5 Mabswid
.65054 .32361 m
.64955 .31032 L
s
0 0 0 r
2.5 Mabswid
.64955 .31032 Mdot
.039 .916 .04 r
.5 Mabswid
.54286 .36723 m
.54262 .36724 L
s
0 0 0 r
2.5 Mabswid
.54262 .36724 Mdot
.039 .916 .04 r
.5 Mabswid
.40062 .55433 m
.40073 .55745 L
s
0 0 0 r
2.5 Mabswid
.40073 .55745 Mdot
.039 .916 .04 r
.5 Mabswid
.64955 .31032 m
.65052 .30698 L
s
0 0 0 r
2.5 Mabswid
.65052 .30698 Mdot
.039 .916 .04 r
.5 Mabswid
.54262 .36724 m
.52772 .36937 L
s
0 0 0 r
2.5 Mabswid
.52772 .36937 Mdot
.039 .916 .04 r
.5 Mabswid
.40073 .55745 m
.40084 .55784 L
s
0 0 0 r
2.5 Mabswid
.40084 .55784 Mdot
.039 .916 .04 r
.5 Mabswid
.65052 .30698 m
.65887 .29555 L
s
0 0 0 r
2.5 Mabswid
.65887 .29555 Mdot
.039 .916 .04 r
.5 Mabswid
.52772 .36937 m
.52171 .37191 L
s
0 0 0 r
2.5 Mabswid
.52171 .37191 Mdot
.039 .916 .04 r
.5 Mabswid
.40084 .55784 m
.40086 .56025 L
s
0 0 0 r
2.5 Mabswid
.40086 .56025 Mdot
.039 .916 .04 r
.5 Mabswid
.65887 .29555 m
.66029 .2918 L
s
0 0 0 r
2.5 Mabswid
.66029 .2918 Mdot
.039 .916 .04 r
.5 Mabswid
.52171 .37191 m
.50408 .37326 L
s
0 0 0 r
2.5 Mabswid
.50408 .37326 Mdot
.039 .916 .04 r
.5 Mabswid
.40086 .56025 m
.39861 .57417 L
s
0 0 0 r
2.5 Mabswid
.39861 .57417 Mdot
.039 .916 .04 r
.5 Mabswid
.66029 .2918 m
.66165 .28747 L
s
0 0 0 r
2.5 Mabswid
.66165 .28747 Mdot
.039 .916 .04 r
.5 Mabswid
.50408 .37326 m
.49026 .3759 L
s
0 0 0 r
2.5 Mabswid
.49026 .3759 Mdot
.039 .916 .04 r
.5 Mabswid
.39861 .57417 m
.398 .57566 L
s
0 0 0 r
2.5 Mabswid
.398 .57566 Mdot
.039 .916 .04 r
.5 Mabswid
.66165 .28747 m
.66408 .27696 L
s
0 0 0 r
2.5 Mabswid
.66408 .27696 Mdot
.039 .916 .04 r
.5 Mabswid
.49026 .3759 m
.48489 .37749 L
s
0 0 0 r
2.5 Mabswid
.48489 .37749 Mdot
.039 .916 .04 r
.5 Mabswid
.398 .57566 m
.39644 .58611 L
s
0 0 0 r
2.5 Mabswid
.39644 .58611 Mdot
.039 .916 .04 r
.5 Mabswid
.66408 .27696 m
.66672 .26192 L
s
0 0 0 r
2.5 Mabswid
.66672 .26192 Mdot
.039 .916 .04 r
.5 Mabswid
.48489 .37749 m
.47663 .38397 L
s
0 0 0 r
2.5 Mabswid
.47663 .38397 Mdot
.039 .916 .04 r
.5 Mabswid
.39644 .58611 m
.39547 .59024 L
s
0 0 0 r
2.5 Mabswid
.39547 .59024 Mdot
.039 .916 .04 r
.5 Mabswid
.66672 .26192 m
.66672 .2619 L
s
0 0 0 r
2.5 Mabswid
.66672 .2619 Mdot
.039 .916 .04 r
.5 Mabswid
.47663 .38397 m
.46894 .38705 L
s
0 0 0 r
2.5 Mabswid
.46894 .38705 Mdot
.039 .916 .04 r
.5 Mabswid
.39547 .59024 m
.39532 .59062 L
s
0 0 0 r
2.5 Mabswid
.39532 .59062 Mdot
.039 .916 .04 r
.5 Mabswid
.46894 .38705 m
.4613 .39294 L
s
0 0 0 r
2.5 Mabswid
.4613 .39294 Mdot
.039 .916 .04 r
.5 Mabswid
.39532 .59062 m
.39425 .59587 L
s
0 0 0 r
2.5 Mabswid
.39425 .59587 Mdot
.039 .916 .04 r
.5 Mabswid
.4613 .39294 m
.45648 .39512 L
s
0 0 0 r
2.5 Mabswid
.45648 .39512 Mdot
.039 .916 .04 r
.5 Mabswid
.39425 .59587 m
.3924 .60605 L
s
0 0 0 r
2.5 Mabswid
.3924 .60605 Mdot
.039 .916 .04 r
.5 Mabswid
.45648 .39512 m
.45311 .39702 L
s
0 0 0 r
2.5 Mabswid
.45311 .39702 Mdot
.039 .916 .04 r
.5 Mabswid
.3924 .60605 m
.39489 .62449 L
s
0 0 0 r
2.5 Mabswid
.39489 .62449 Mdot
.039 .916 .04 r
.5 Mabswid
.45311 .39702 m
.44045 .40883 L
s
0 0 0 r
2.5 Mabswid
.44045 .40883 Mdot
.039 .916 .04 r
.5 Mabswid
.39489 .62449 m
.39491 .63273 L
s
0 0 0 r
2.5 Mabswid
.39491 .63273 Mdot
.039 .916 .04 r
.5 Mabswid
.44045 .40883 m
.43668 .41473 L
s
0 0 0 r
2.5 Mabswid
.43668 .41473 Mdot
.039 .916 .04 r
.5 Mabswid
.39491 .63273 m
.39632 .63668 L
s
0 0 0 r
2.5 Mabswid
.39632 .63668 Mdot
.039 .916 .04 r
.5 Mabswid
.43668 .41473 m
.42936 .43092 L
s
0 0 0 r
2.5 Mabswid
.42936 .43092 Mdot
.039 .916 .04 r
.5 Mabswid
.39632 .63668 m
.39803 .64026 L
s
0 0 0 r
2.5 Mabswid
.39803 .64026 Mdot
.039 .916 .04 r
.5 Mabswid
.42936 .43092 m
.42801 .43912 L
s
0 0 0 r
2.5 Mabswid
.42801 .43912 Mdot
.039 .916 .04 r
.5 Mabswid
.39803 .64026 m
.41016 .65309 L
s
0 0 0 r
2.5 Mabswid
.41016 .65309 Mdot
.039 .916 .04 r
.5 Mabswid
.42801 .43912 m
.4278 .44233 L
s
0 0 0 r
2.5 Mabswid
.4278 .44233 Mdot
.039 .916 .04 r
.5 Mabswid
.41016 .65309 m
.41474 .65904 L
s
0 0 0 r
2.5 Mabswid
.41474 .65904 Mdot
.039 .916 .04 r
.5 Mabswid
.4278 .44233 m
.41988 .45893 L
s
0 0 0 r
2.5 Mabswid
.41988 .45893 Mdot
.039 .916 .04 r
.5 Mabswid
.41474 .65904 m
.41944 .66544 L
s
0 0 0 r
2.5 Mabswid
.41944 .66544 Mdot
.039 .916 .04 r
.5 Mabswid
.41988 .45893 m
.41909 .45993 L
s
0 0 0 r
2.5 Mabswid
.41909 .45993 Mdot
.039 .916 .04 r
.5 Mabswid
.41944 .66544 m
.4259 .68305 L
s
0 0 0 r
2.5 Mabswid
.4259 .68305 Mdot
.039 .916 .04 r
.5 Mabswid
.41909 .45993 m
.40996 .46962 L
s
0 0 0 r
2.5 Mabswid
.40996 .46962 Mdot
.039 .916 .04 r
.5 Mabswid
.4259 .68305 m
.42766 .69769 L
s
0 0 0 r
2.5 Mabswid
.42766 .69769 Mdot
.039 .916 .04 r
.5 Mabswid
.40996 .46962 m
.40183 .48174 L
s
0 0 0 r
2.5 Mabswid
.40183 .48174 Mdot
.039 .916 .04 r
.5 Mabswid
.42766 .69769 m
.42962 .70848 L
s
0 0 0 r
2.5 Mabswid
.42962 .70848 Mdot
.039 .916 .04 r
.5 Mabswid
.40183 .48174 m
.39994 .48794 L
s
0 0 0 r
2.5 Mabswid
.39994 .48794 Mdot
.039 .916 .04 r
.5 Mabswid
.42962 .70848 m
.43349 .72022 L
s
0 0 0 r
2.5 Mabswid
.43349 .72022 Mdot
.039 .916 .04 r
.5 Mabswid
.39994 .48794 m
.39831 .49098 L
s
0 0 0 r
2.5 Mabswid
.39831 .49098 Mdot
.039 .916 .04 r
.5 Mabswid
.43349 .72022 m
.43651 .73808 L
s
0 0 0 r
2.5 Mabswid
.43651 .73808 Mdot
.039 .916 .04 r
.5 Mabswid
.39831 .49098 m
.39507 .49483 L
s
0 0 0 r
2.5 Mabswid
.39507 .49483 Mdot
.039 .916 .04 r
.5 Mabswid
.43651 .73808 m
.43652 .7381 L
s
0 0 0 r
2.5 Mabswid
.43652 .7381 Mdot
.039 .916 .04 r
.5 Mabswid
.39507 .49483 m
.39333 .49855 L
s
0 0 0 r
2.5 Mabswid
.39333 .49855 Mdot
.039 .916 .04 r
.5 Mabswid
.39333 .49855 m
.38162 .50967 L
s
0 0 0 r
2.5 Mabswid
.38162 .50967 Mdot
.039 .916 .04 r
.5 Mabswid
.38162 .50967 m
.37977 .51206 L
s
0 0 0 r
2.5 Mabswid
.37977 .51206 Mdot
.039 .916 .04 r
.5 Mabswid
.37977 .51206 m
.37109 .52603 L
s
0 0 0 r
2.5 Mabswid
.37109 .52603 Mdot
.039 .916 .04 r
.5 Mabswid
.37109 .52603 m
.36641 .53342 L
s
0 0 0 r
2.5 Mabswid
.36641 .53342 Mdot
.039 .916 .04 r
.5 Mabswid
.36641 .53342 m
.36597 .53526 L
s
0 0 0 r
2.5 Mabswid
.36597 .53526 Mdot
.039 .916 .04 r
.5 Mabswid
.36597 .53526 m
.36719 .5484 L
s
0 0 0 r
2.5 Mabswid
.36719 .5484 Mdot
.039 .916 .04 r
.5 Mabswid
.36719 .5484 m
.36457 .55801 L
s
0 0 0 r
2.5 Mabswid
.36457 .55801 Mdot
.039 .916 .04 r
.5 Mabswid
.36457 .55801 m
.36142 .56417 L
s
0 0 0 r
2.5 Mabswid
.36142 .56417 Mdot
.039 .916 .04 r
.5 Mabswid
.36142 .56417 m
.35744 .58034 L
s
0 0 0 r
2.5 Mabswid
.35744 .58034 Mdot
.039 .916 .04 r
.5 Mabswid
.35744 .58034 m
.35779 .58399 L
s
0 0 0 r
2.5 Mabswid
.35779 .58399 Mdot
.039 .916 .04 r
.5 Mabswid
.35779 .58399 m
.35946 .59567 L
s
0 0 0 r
2.5 Mabswid
.35946 .59567 Mdot
.039 .916 .04 r
.5 Mabswid
.35946 .59567 m
.35619 .61398 L
s
0 0 0 r
2.5 Mabswid
.35619 .61398 Mdot
.039 .916 .04 r
.5 Mabswid
.35619 .61398 m
.35402 .62852 L
s
0 0 0 r
2.5 Mabswid
.35402 .62852 Mdot
.039 .916 .04 r
.5 Mabswid
.35402 .62852 m
.35047 .64389 L
s
0 0 0 r
2.5 Mabswid
.35047 .64389 Mdot
.039 .916 .04 r
.5 Mabswid
.35047 .64389 m
.35207 .66112 L
s
0 0 0 r
2.5 Mabswid
.35207 .66112 Mdot
.039 .916 .04 r
.5 Mabswid
.35207 .66112 m
.35497 .66772 L
s
0 0 0 r
2.5 Mabswid
.35497 .66772 Mdot
.039 .916 .04 r
.5 Mabswid
.35497 .66772 m
.36611 .67865 L
s
0 0 0 r
2.5 Mabswid
.36611 .67865 Mdot
.039 .916 .04 r
.5 Mabswid
.36611 .67865 m
.3782 .68357 L
s
0 0 0 r
2.5 Mabswid
.3782 .68357 Mdot
.039 .916 .04 r
.5 Mabswid
.3782 .68357 m
.38404 .68381 L
s
0 0 0 r
2.5 Mabswid
.38404 .68381 Mdot
.039 .916 .04 r
.5 Mabswid
.38404 .68381 m
.39028 .68278 L
s
0 0 0 r
2.5 Mabswid
.39028 .68278 Mdot
.039 .916 .04 r
.5 Mabswid
.39028 .68278 m
.39846 .68373 L
s
0 0 0 r
2.5 Mabswid
.39846 .68373 Mdot
.039 .916 .04 r
.5 Mabswid
.39846 .68373 m
.40129 .68332 L
s
0 0 0 r
2.5 Mabswid
.40129 .68332 Mdot
.039 .916 .04 r
.5 Mabswid
.40129 .68332 m
.41643 .68006 L
s
0 0 0 r
2.5 Mabswid
.41643 .68006 Mdot
.039 .916 .04 r
.5 Mabswid
.41643 .68006 m
.41947 .67878 L
s
0 0 0 r
2.5 Mabswid
.41947 .67878 Mdot
.039 .916 .04 r
.5 Mabswid
.41947 .67878 m
.42044 .67874 L
s
0 0 0 r
2.5 Mabswid
.42044 .67874 Mdot
.039 .916 .04 r
.5 Mabswid
.42044 .67874 m
.427 .67929 L
s
0 0 0 r
2.5 Mabswid
.427 .67929 Mdot
.039 .916 .04 r
.5 Mabswid
.427 .67929 m
.42954 .68026 L
s
0 0 0 r
2.5 Mabswid
.42954 .68026 Mdot
.039 .916 .04 r
.5 Mabswid
.42954 .68026 m
.44634 .68779 L
s
0 0 0 r
2.5 Mabswid
.44634 .68779 Mdot
.039 .916 .04 r
.5 Mabswid
.44634 .68779 m
.45109 .69171 L
s
0 0 0 r
2.5 Mabswid
.45109 .69171 Mdot
.039 .916 .04 r
.5 Mabswid
.45109 .69171 m
.45517 .69547 L
s
0 0 0 r
2.5 Mabswid
.45517 .69547 Mdot
.039 .916 .04 r
.5 Mabswid
.45517 .69547 m
.45546 .69589 L
s
0 0 0 r
2.5 Mabswid
.45546 .69589 Mdot
.039 .916 .04 r
.5 Mabswid
.45546 .69589 m
.4678 .70936 L
s
0 0 0 r
2.5 Mabswid
.4678 .70936 Mdot
.039 .916 .04 r
.5 Mabswid
.4678 .70936 m
.47225 .71977 L
s
0 0 0 r
2.5 Mabswid
.47225 .71977 Mdot
.039 .916 .04 r
.5 Mabswid
.47225 .71977 m
.48199 .73195 L
s
0 0 0 r
2.5 Mabswid
.48199 .73195 Mdot
.039 .916 .04 r
.5 Mabswid
.48199 .73195 m
.48676 .73808 L
s
0 0 0 r
2.5 Mabswid
.48676 .73808 Mdot
.039 .916 .04 r
.5 Mabswid
.48676 .73808 m
.48678 .7381 L
s
0 0 0 r
2.5 Mabswid
.48678 .7381 Mdot
.039 .916 .04 r
.5 Mabswid
.21429 .37651 m
.02381 .68502 L
s
0 0 0 r
2.5 Mabswid
.02381 .68502 Mdot
.039 .916 .04 r
.5 Mabswid
.37955 .7381 m
.76238 .97619 L
s
0 0 0 r
2.5 Mabswid
.76238 .97619 Mdot
.039 .916 .04 r
.5 Mabswid
.33527 .2619 m
.33129 .02381 L
s
0 0 0 r
2.5 Mabswid
.33129 .02381 Mdot
.039 .916 .04 r
.5 Mabswid
.40873 .7381 m
.5165 .97619 L
s
0 0 0 r
2.5 Mabswid
.5165 .97619 Mdot
.039 .916 .04 r
.5 Mabswid
.21429 .30651 m
.02381 .30632 L
s
0 0 0 r
2.5 Mabswid
.02381 .30632 Mdot
.039 .916 .04 r
.5 Mabswid
.21429 .38253 m
.02381 .48013 L
s
0 0 0 r
2.5 Mabswid
.02381 .48013 Mdot
.039 .916 .04 r
.5 Mabswid
.36301 .2619 m
.02381 .11294 L
s
0 0 0 r
2.5 Mabswid
.02381 .11294 Mdot
.039 .916 .04 r
.5 Mabswid
.54532 .7381 m
.60218 .97619 L
s
0 0 0 r
2.5 Mabswid
.60218 .97619 Mdot
.039 .916 .04 r
.5 Mabswid
.22639 .2619 m
.54085 .02381 L
s
0 0 0 r
2.5 Mabswid
.54085 .02381 Mdot
.039 .916 .04 r
.5 Mabswid
.56212 .2619 m
.73916 .02381 L
s
0 0 0 r
2.5 Mabswid
.73916 .02381 Mdot
.039 .916 .04 r
.5 Mabswid
.64536 .2619 m
.61121 .02381 L
s
0 0 0 r
2.5 Mabswid
.61121 .02381 Mdot
.039 .916 .04 r
.5 Mabswid
.69048 .37366 m
.97619 .22574 L
s
0 0 0 r
2.5 Mabswid
.97619 .22574 Mdot
.039 .916 .04 r
.5 Mabswid
.26412 .2619 m
.11767 .02381 L
s
0 0 0 r
2.5 Mabswid
.11767 .02381 Mdot
.039 .916 .04 r
.5 Mabswid
.69048 .57916 m
.97619 .49669 L
s
0 0 0 r
2.5 Mabswid
.97619 .49669 Mdot
.039 .916 .04 r
.5 Mabswid
.69048 .59491 m
.72624 .02381 L
s
0 0 0 r
2.5 Mabswid
.72624 .02381 Mdot
.039 .916 .04 r
.5 Mabswid
.69048 .65266 m
.81627 .97619 L
s
0 0 0 r
2.5 Mabswid
.81627 .97619 Mdot
.039 .916 .04 r
.5 Mabswid
.5055 .2619 m
.52165 .02381 L
s
0 0 0 r
2.5 Mabswid
.52165 .02381 Mdot
.039 .916 .04 r
.5 Mabswid
.66672 .2619 m
.73151 .02381 L
s
0 0 0 r
2.5 Mabswid
.73151 .02381 Mdot
.039 .916 .04 r
.5 Mabswid
.43652 .7381 m
.49882 .97619 L
s
0 0 0 r
2.5 Mabswid
.49882 .97619 Mdot
.039 .916 .04 r
.5 Mabswid
.48678 .7381 m
.97619 .92626 L
s
0 0 0 r
2.5 Mabswid
.97619 .92626 Mdot
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{433, 433},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006a0001/B000`400?l00000o`00003oo`3ooonb
0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3ooonb
0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3ooonb0?ooo`00o`3ooonb
0?ooo`002P3ooooo000009d000002`3oool000X0oooo00<000000?ooo`3oool09@3oool2000005X0
oooo0P00001@0?ooo`8000001@3oool00`09jPX000000000000M0?ooo`800000;`3oool200000004
0?ooo`00000000000?ooo`800000I@3oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000
oooo0?ooo`0V0?ooo`0300WZ2P3oool0oooo05T0oooo00<02NX:0?ooo`3oool0C`3oool00`09jPX0
oooo0?ooo`020?ooo`0300WZ2P3oool0oooo01l0oooo00<02NX:0?ooo`3oool0;P3oool01P09jPX0
oooo0?ooo`09jPX0oooo00WZ2VH0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?oo
o`3oool09`3oool00`09jPX0oooo0?ooo`1H0?ooo`0300WZ2P3oool0oooo04l0oooo00<02NX:0?oo
o`3oool00P09jPXR0?ooo`0300WZ2P3oool0oooo02h0oooo00D02NX:0?ooo`09jPX0oooo00WZ2P1W
0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo02L0oooo00<02NX:0?oo
o`3oool0F03oool00`09jPX0oooo0?ooo`1?0?ooo`0300WZ2P3oool02NX:02@0oooo00<02NX:0?oo
o`3oool0;P3oool01009jPX0oooo00WZ2P09jPYX0?ooo`030000003oool0oooo00T0oooo000:0?oo
o`030000003oool0oooo02P0oooo00<02NX:0?ooo`3oool0E`3oool00`09jPX0oooo0?ooo`1?0?oo
o`802NX:9P3oool00`09jPX0oooo0?ooo`0]0?ooo`0400WZ2P3oool02NX:00WZ2VP0oooo00<00000
0?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0:03oool00`09jPX0oooo0?ooo`1G0?oo
o`0300WZ2P3oool0oooo04h0oooo0P09jPXW0?ooo`0300WZ2P3oool0oooo02d0oooo00<02NX:0?oo
o`09jPX0J@3oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`0Y0?ooo`03
00WZ2P3oool0oooo05H0oooo00<02NX:0?ooo`3oool0C@3oool00`09jPX0oooo00WZ2P0W0?ooo`03
00WZ2P3oool0oooo02d0oooo0P09jPYZ0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000
003oool0oooo02X0oooo00<02NX:0?ooo`3oool0E@3oool00`09jPX0oooo0?ooo`1<0?ooo`0300WZ
2P3oool02NX:02P0oooo00<02NX:0?ooo`3oool0;@3oool200WZ2VX0oooo00<000000?ooo`3oool0
2@3oool000X0oooo00<000000?ooo`3oool0:P3oool00`09jPX0oooo0?ooo`1E0?ooo`0300WZ2P3o
ool0oooo04X0oooo0P09jPX20?ooo`0300WZ2P3oool0oooo02H0oooo00<02NX:0?ooo`3oool0;03o
ool300WZ2VX0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0:`3oool0
0`09jPX0oooo0?ooo`1D0?ooo`0300WZ2P3oool0oooo04T0oooo00<02NX:0?ooo`3oool00P3oool0
0`09jPX0oooo0?ooo`0V0?ooo`0300WZ2P3oool0oooo02`0oooo0P09jPY[0?ooo`030000003oool0
oooo00T0oooo000:0?ooo`030000003oool0oooo02`0oooo00<02NX:0?ooo`3oool0D`3oool00`09
jPX0oooo0?ooo`180?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool09P3oool00`09
jPX0oooo0?ooo`0[0?ooo`<02NX:J`3oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000
oooo0?ooo`0/0?ooo`0300WZ2P3oool0oooo05<0oooo00<02NX:0?ooo`3oool0AP3oool200WZ2PH0
oooo00<02NX:0?ooo`3oool09`3oool00`09jPX0oooo0?ooo`0Y0?ooo`0400WZ2P3oool02NX:00WZ
2V/0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0;@3oool00`09jPX0
oooo0?ooo`1B0?ooo`0300WZ2P3oool0oooo04D0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0
oooo0?ooo`0W0?ooo`0300WZ2P3oool0oooo02T0oooo00@02NX:0?ooo`09jPX02NX:J`3oool00`00
0000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`0]0?ooo`0300WZ2P3oool0oooo0580
oooo00<02NX:0?ooo`3oool0A03oool00`09jPX0oooo0?ooo`070?ooo`0300WZ2P3oool0oooo02L0
oooo00<02NX:0?ooo`3oool0:03oool01009jPX0oooo0?ooo`09jPY/0?ooo`030000003oool0oooo
00T0oooo000:0?ooo`030000003oool0oooo02h0oooo00<02NX:0?ooo`3oool0D@3oool00`09jPX0
oooo0?ooo`130?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool09`3oool00`09jPX0
oooo0?ooo`0W0?ooo`0500WZ2P3oool0oooo0?ooo`09jPX0K03oool00`000000oooo0?ooo`090?oo
o`002P3oool00`000000oooo0?ooo`0_0?ooo`0300WZ2P3oool0oooo0500oooo00<02NX:0?ooo`3o
ool0@@3oool200WZ2P/0oooo00<02NX:0?ooo`3oool09`3oool00`09jPX0oooo0?ooo`0V0?ooo`03
00WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool0JP3oool00`000000oooo0?ooo`090?ooo`00
2P3oool00`000000oooo0?ooo`0_0?ooo`0300WZ2P3oool0oooo0500oooo00<02NX:0?ooo`3oool0
@03oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo02L0oooo00<02NX:0?ooo`3oool0
9P3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo06X0oooo00<000000?ooo`3oool0
2@3oool000X0oooo00<000000?ooo`3oool0<03oool00`09jPX0oooo0?ooo`1?0?ooo`0300WZ2P3o
ool0oooo03l0oooo00<02NX:0?ooo`3oool0303oool00`09jPX0oooo0?ooo`0W0?ooo`0300WZ2P3o
ool0oooo02D0oooo00<02NX:0?ooo`3oool00P3oool200WZ2V`0oooo00<000000?ooo`3oool02@3o
ool000X0oooo00<000000?ooo`3oool0<03oool00`09jPX0oooo0?ooo`1?0?ooo`0300WZ2P3oool0
oooo03d0oooo0P09jPX?0?ooo`0300WZ2P3oool0oooo02P0oooo00<02NX:0?ooo`3oool08`3oool0
0`09jPX0oooo0?ooo`030?ooo`802NX:K03oool00`000000oooo0?ooo`090?ooo`002P3oool00`00
0000oooo0?ooo`0a0?ooo`0300WZ2P3oool0oooo04h0oooo00<02NX:0?ooo`3oool0?03oool00`09
jPX0oooo0?ooo`0?0?ooo`0300WZ2P3oool0oooo02P0oooo00<02NX:0?ooo`3oool08P3oool00`09
jPX0oooo0?ooo`040?ooo`802NX:K03oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000
oooo0?ooo`0b0?ooo`0300WZ2P3oool0oooo04d0oooo00<02NX:0?ooo`3oool0>`3oool00`09jPX0
oooo0?ooo`0@0?ooo`0300WZ2P3oool0oooo02P0oooo00<02NX:0?ooo`3oool08P3oool00`09jPX0
oooo0?ooo`030?ooo`0300WZ2P3oool02NX:06`0oooo00<000000?ooo`3oool02@3oool000X0oooo
00<000000?ooo`3oool0<P3oool00`09jPX0oooo0?ooo`1=0?ooo`0300WZ2P3oool0oooo03T0oooo
0P09jPXC0?ooo`0300WZ2P3oool0oooo02P0oooo00<02NX:0?ooo`3oool08@3oool00`09jPX0oooo
0?ooo`040?ooo`0300WZ2P3oool02NX:06`0oooo00<000000?ooo`3oool02@3oool000X0oooo00<0
00000?ooo`3oool0<`3oool00`09jPX0oooo0?ooo`1<0?ooo`0300WZ2P3oool0oooo03P0oooo00<0
2NX:0?ooo`3oool04P3oool00`09jPX0oooo0?ooo`0Y0?ooo`0300WZ2P3oool0oooo0200oooo00<0
2NX:0?ooo`3oool01@3oool00`09jPX0oooo00WZ2P1/0?ooo`030000003oool0oooo00T0oooo000:
0?ooo`030000003oool0oooo03@0oooo00<02NX:0?ooo`3oool0B`3oool00`09jPX0oooo0?ooo`0g
0?ooo`0300WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool0:@3oool00`09jPX0oooo0?ooo`0O
0?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`09jPX0K03oool00`000000oooo0?ooo`09
0?ooo`002P3oool00`000000oooo0?ooo`0d0?ooo`0300WZ2P3oool0oooo04/0oooo00<02NX:0?oo
o`3oool0=@3oool200WZ2QH0oooo00<02NX:0?ooo`3oool0:@3oool00`09jPX0oooo0?ooo`0O0?oo
o`0300WZ2P3oool0oooo00D0oooo00@02NX:0?ooo`3oool02NX:K03oool00`000000oooo0?ooo`09
0?ooo`002P3oool00`000000oooo0?ooo`0e0?ooo`0300WZ2P3oool0oooo04X0oooo00<02NX:0?oo
o`3oool0=03oool00`09jPX0oooo0?ooo`0F0?ooo`0300WZ2P3oool0oooo02T0oooo00<02NX:0?oo
o`3oool07P3oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3oool02NX:06d0oooo00<000000?oo
o`3oool02@3oool000X0oooo00<000000?ooo`3oool0=@3oool00`09jPX0oooo0?ooo`1:0?ooo`03
00WZ2P3oool0oooo03<0oooo00<02NX:0?ooo`3oool05`3oool00`09jPX0oooo0?ooo`0Z0?ooo`03
00WZ2P3oool0oooo01`0oooo00<02NX:0?ooo`3oool01`3oool00`09jPX0oooo00WZ2P1]0?ooo`03
0000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo03H0oooo00<02NX:0?ooo`3oool0
B@3oool00`09jPX0oooo0?ooo`0a0?ooo`802NX:6P3oool00`09jPX0oooo0?ooo`0Z0?ooo`0300WZ
2P3oool0oooo01/0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo00WZ2P1]0?ooo`030000
003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo03L0oooo00<02NX:0?ooo`3oool0B03o
ool00`09jPX0oooo0?ooo`0`0?ooo`0300WZ2P3oool0oooo01X0oooo00<02NX:0?ooo`3oool0:P3o
ool00`09jPX0oooo0?ooo`0K0?ooo`0300WZ2P3oool0oooo00L0oooo00@02NX:0?ooo`3oool02NX:
K@3oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`0g0?ooo`0300WZ2P3o
ool0oooo04P0oooo00<02NX:0?ooo`3oool0;`3oool00`09jPX0oooo0?ooo`0K0?ooo`0300WZ2P3o
ool0oooo02X0oooo00<02NX:0?ooo`3oool06P3oool00`09jPX0oooo0?ooo`080?ooo`0400WZ2P3o
ool0oooo00WZ2Vd0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0>03o
ool00`09jPX0oooo0?ooo`170?ooo`0300WZ2P3oool0oooo02d0oooo0P09jPXN0?ooo`0300WZ2P3o
ool0oooo02X0oooo00<02NX:0?ooo`3oool06@3oool00`09jPX0oooo0?ooo`090?ooo`0400WZ2P3o
ool0oooo00WZ2Vd0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0>@3o
ool00`09jPX0oooo0?ooo`160?ooo`0300WZ2P3oool0oooo02`0oooo00<02NX:0?ooo`3oool07P3o
ool00`09jPX0oooo0?ooo`0Z0?ooo`0300WZ2P3oool0oooo01P0oooo00<02NX:0?ooo`3oool02@3o
ool01@09jPX0oooo0?ooo`3oool02NX:06d0oooo00<000000?ooo`3oool02@3oool000X0oooo00<0
00000?ooo`3oool0>@3oool00`09jPX0oooo0?ooo`160?ooo`0300WZ2P3oool0oooo02/0oooo00<0
2NX:0?ooo`3oool07`3oool00`09jPX0oooo0?ooo`0Z0?ooo`0300WZ2P3oool0oooo01P0oooo00<0
2NX:0?ooo`3oool02@3oool01@09jPX0oooo0?ooo`3oool02NX:06d0oooo00<000000?ooo`3oool0
2@3oool000X0oooo00<000000?ooo`3oool0>P3oool00`09jPX0oooo0?ooo`150?ooo`0300WZ2P3o
ool0oooo02T0oooo0P09jPXR0?ooo`0300WZ2P3oool0oooo02/0oooo00<02NX:0?ooo`3oool05P3o
ool00`09jPX0oooo0?ooo`0:0?ooo`0500WZ2P3oool0oooo0?ooo`09jPX0K@3oool00`000000oooo
0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`0j0?ooo`0300WZ2P3oool0oooo04D0oooo00<0
2NX:0?ooo`3oool0:03oool00`09jPX0oooo0?ooo`0R0?ooo`0300WZ2P3oool0oooo02/0oooo00<0
2NX:0?ooo`3oool05@3oool00`09jPX0oooo0?ooo`0;0?ooo`0500WZ2P3oool0oooo0?ooo`09jPX0
K@3oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`0k0?ooo`0300WZ2P3o
ool0oooo04@0oooo00<02NX:0?ooo`3oool09`3oool00`09jPX0oooo0?ooo`0S0?ooo`0300WZ2P3o
ool0oooo02/0oooo00<02NX:0?ooo`3oool0503oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3o
ool0oooo0080oooo00<02NX:0?ooo`3oool0J`3oool00`000000oooo0?ooo`090?ooo`002P3oool0
0`000000oooo0?ooo`0l0?ooo`0300WZ2P3oool0oooo04<0oooo00<02NX:0?ooo`3oool09@3oool2
00WZ2RH0oooo00<02NX:0?ooo`3oool0:`3oool00`09jPX0oooo0?ooo`0D0?ooo`0300WZ2P3oool0
oooo00/0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`1[0?ooo`030000003oool0
oooo00T0oooo00090?ooo`80000000<02NX:0?ooo`3oool0>`3oool00`09jPX0oooo0?ooo`130?oo
o`0300WZ2P3oool0oooo02@0oooo00<02NX:0?ooo`3oool09@3oool00`09jPX0oooo0?ooo`0/0?oo
o`0300WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool0303oool00`09jPX0oooo0?ooo`020?oo
o`0300WZ2P3oool0oooo06/0oooo00<000000?ooo`3oool02@3oool000T0oooo0P0000000`3oool0
2NX:00WZ2P0l0?ooo`0300WZ2P3oool0oooo0480oooo00<02NX:0?ooo`3oool08`3oool00`09jPX0
oooo0?ooo`0V0?ooo`0300WZ2P3oool0oooo02`0oooo00<02NX:0?ooo`3oool04P3oool00`09jPX0
oooo0?ooo`0=0?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool0J`3oool00`000000
oooo0?ooo`090?ooo`002P3oool010000000oooo0?ooo`3oool300WZ2SX0oooo00<02NX:0?ooo`3o
ool0@@3oool00`09jPX0oooo0?ooo`0R0?ooo`0300WZ2P3oool0oooo02L0oooo00<02NX:0?ooo`3o
ool0;03oool00`09jPX0oooo0?ooo`0A0?ooo`0300WZ2P3oool0oooo00d0oooo00<02NX:0?ooo`3o
ool00`3oool00`09jPX0oooo0?ooo`1[0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000
003oool0oooo00@0oooo0P09jPXh0?ooo`0300WZ2P3oool0oooo0440oooo00<02NX:0?ooo`3oool0
803oool200WZ2RX0oooo00<02NX:0?ooo`3oool0;@3oool00`09jPX0oooo0?ooo`0@0?ooo`0300WZ
2P3oool0oooo00d0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`1[0?ooo`030000
003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo00H0oooo0P09jPXg0?ooo`0300WZ2P3o
ool0oooo0400oooo00<02NX:0?ooo`3oool07`3oool00`09jPX0oooo0?ooo`0Z0?ooo`0300WZ2P3o
ool0oooo02d0oooo00<02NX:0?ooo`3oool03`3oool00`09jPX0oooo0?ooo`0>0?ooo`0300WZ2P3o
ool0oooo0080oooo00<02NX:0?ooo`3oool0K03oool00`000000oooo0?ooo`090?ooo`002P3oool0
0`000000oooo0?ooo`080?ooo`802NX:=@3oool00`09jPX0oooo0?ooo`100?ooo`0300WZ2P3oool0
oooo01h0oooo00<02NX:0?ooo`3oool0:`3oool00`09jPX0oooo0?ooo`0]0?ooo`0300WZ2P3oool0
oooo00h0oooo00<02NX:0?ooo`3oool03P3oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0
oooo06`0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool02P3oool300WZ
2S<0oooo00<02NX:0?ooo`3oool0?`3oool00`09jPX0oooo0?ooo`0L0?ooo`802NX:;P3oool00`09
jPX0oooo0?ooo`0]0?ooo`0300WZ2P3oool0oooo00d0oooo00<02NX:0?ooo`3oool03`3oool00`09
jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo06`0oooo00<000000?ooo`3oool02@3oool000X0
oooo00<000000?ooo`3oool03@3oool200WZ2S80oooo00<02NX:0?ooo`3oool0?P3oool00`09jPX0
oooo0?ooo`0K0?ooo`0300WZ2P3oool0oooo02h0oooo00<02NX:0?ooo`3oool0;@3oool00`09jPX0
oooo0?ooo`0=0?ooo`0300WZ2P3oool0oooo00l0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0
oooo0?ooo`1/0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo00l0oooo
0P09jPX`0?ooo`0300WZ2P3oool0oooo03h0oooo00<02NX:0?ooo`3oool06P3oool00`09jPX0oooo
0?ooo`0_0?ooo`0300WZ2P3oool0oooo02d0oooo00<02NX:0?ooo`3oool0303oool00`09jPX0oooo
0?ooo`0@0?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0K03oool00`000000oooo
0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`0A0?ooo`802NX:;`3oool00`09jPX0oooo0?oo
o`0m0?ooo`0300WZ2P3oool0oooo01P0oooo0P09jPXb0?ooo`0300WZ2P3oool0oooo02d0oooo00<0
2NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0@0?ooo`0300WZ2P3oool0oooo00@0oooo00<0
2NX:0?ooo`3oool0K03oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`0C
0?ooo`<02NX:;@3oool00`09jPX0oooo0?ooo`0l0?ooo`0300WZ2P3oool0oooo01L0oooo00<02NX:
0?ooo`3oool0<P3oool00`09jPX0oooo0?ooo`0]0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:
0?ooo`3oool04@3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo06`0oooo00<00000
0?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool05P3oool200WZ2R/0oooo00<02NX:0?oo
o`3oool0?03oool00`09jPX0oooo0?ooo`0F0?ooo`0300WZ2P3oool0oooo03<0oooo00<02NX:0?oo
o`3oool0;P3oool00`09jPX0oooo0?ooo`090?ooo`0300WZ2P3oool0oooo0140oooo00<02NX:0?oo
o`3oool0103oool00`09jPX0oooo0?ooo`1/0?ooo`030000003oool0oooo00T0oooo000:0?ooo`03
0000003oool0oooo01P0oooo0P09jPXZ0?ooo`0300WZ2P3oool0oooo03/0oooo00<02NX:0?ooo`3o
ool0503oool200WZ2SH0oooo00<02NX:0?ooo`3oool0;P3oool00`09jPX0oooo0?ooo`080?ooo`03
00WZ2P3oool0oooo0180oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`1/0?ooo`03
0000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo01X0oooo0P09jPXX0?ooo`0300WZ
2P3oool0oooo03/0oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`0f0?ooo`0300WZ
2P3oool0oooo02h0oooo00<02NX:0?ooo`3oool01`3oool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ
2P3oool0oooo00D0oooo00<02NX:0?ooo`3oool0K03oool00`000000oooo0?ooo`090?ooo`002P3o
ool00`000000oooo0?ooo`0L0?ooo`<02NX:9P3oool00`09jPX0oooo0?ooo`0k0?ooo`0300WZ2P3o
ool0oooo0140oooo00<02NX:0?ooo`3oool0=P3oool00`09jPX0oooo0?ooo`0_0?ooo`0300WZ2P3o
ool0oooo00H0oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`050?ooo`0300WZ2P3o
ool0oooo06`0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool07`3oool2
00WZ2RD0oooo00<02NX:0?ooo`3oool0>P3oool00`09jPX0oooo0?ooo`0?0?ooo`802NX:>@3oool0
0`09jPX0oooo0?ooo`0_0?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool04`3oool0
0`09jPX0oooo0?ooo`050?ooo`0300WZ2P3oool0oooo06`0oooo00<000000?ooo`3oool02@3oool0
00X0oooo00<000000?ooo`3oool08@3oool200WZ2R<0oooo00<02NX:0?ooo`3oool0>P3oool00`09
jPX0oooo0?ooo`0>0?ooo`0300WZ2P3oool0oooo03T0oooo00<02NX:0?ooo`3oool0;`3oool00`09
jPX0oooo0?ooo`050?ooo`0300WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool01P3oool00`09
jPX0oooo0?ooo`1/0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo02<0
oooo0P09jPXR0?ooo`0300WZ2P3oool0oooo03T0oooo00<02NX:0?ooo`3oool03@3oool00`09jPX0
oooo0?ooo`0j0?ooo`0300WZ2P3oool0oooo02l0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0
oooo0?ooo`0D0?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool0K03oool00`000000
oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`0U0?ooo`<02NX:7`3oool00`09jPX0oooo
0?ooo`0i0?ooo`0300WZ2P3oool0oooo00/0oooo0P09jPXm0?ooo`0300WZ2P3oool0oooo0300oooo
00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`0D0?ooo`0300WZ2P3oool0oooo00H0oooo
00<02NX:0?ooo`3oool0K03oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?oo
o`0X0?ooo`802NX:7P3oool00`09jPX0oooo0?ooo`0h0?ooo`0300WZ2P3oool0oooo00X0oooo00<0
2NX:0?ooo`3oool0?@3oool00`09jPX0oooo0?ooo`0`0?ooo`0300WZ2P3oool0oooo0080oooo00<0
2NX:0?ooo`3oool05@3oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0oooo06`0oooo00<0
00000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0:P3oool200WZ2Qd0oooo00<02NX:
0?ooo`3oool0=`3oool00`09jPX0oooo0?ooo`090?ooo`0300WZ2P3oool0oooo03h0oooo00<02NX:
0?ooo`3oool0<03oool01@09jPX0oooo0?ooo`3oool02NX:01L0oooo00<02NX:0?ooo`3oool01P3o
ool00`09jPX0oooo0?ooo`1]0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0
oooo02`0oooo0P09jPXK0?ooo`0300WZ2P3oool0oooo03L0oooo00<02NX:0?ooo`3oool01`3oool2
00WZ2T40oooo00<02NX:0?ooo`3oool0<03oool01009jPX0oooo0?ooo`09jPXH0?ooo`0300WZ2P3o
ool0oooo00H0oooo00<02NX:0?ooo`3oool0K@3oool00`000000oooo0?ooo`090?ooo`002P3oool0
0`000000oooo0?ooo`0^0?ooo`<02NX:6@3oool00`09jPX0oooo0?ooo`0f0?ooo`0300WZ2P3oool0
oooo00H0oooo00<02NX:0?ooo`3oool0@@3oool00`09jPX0oooo0?ooo`0`0?ooo`0400WZ2P3oool0
oooo00WZ2QP0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`1]0?ooo`030000003o
ool0oooo00T0oooo000:0?ooo`030000003oool0oooo0340oooo0P09jPXH0?ooo`0300WZ2P3oool0
oooo03D0oooo00<02NX:0?ooo`3oool01@3oool00`09jPX0oooo0?ooo`120?ooo`0300WZ2P3oool0
oooo0300oooo00<02NX:0?ooo`09jPX06@3oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0
oooo06d0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0<`3oool200WZ
2QH0oooo00<02NX:0?ooo`3oool0=@3oool00`09jPX0oooo0?ooo`030?ooo`802NX:A@3oool00`09
jPX0oooo0?ooo`0`0?ooo`802NX:6@3oool00`09jPX0oooo0?ooo`070?ooo`0300WZ2P3oool0oooo
06d0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0=@3oool200WZ2QD0
oooo00<02NX:0?ooo`3oool0=03oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo04D0
oooo00<02NX:0?ooo`3oool0<03oool00`09jPX0oooo0?ooo`0H0?ooo`0300WZ2P3oool0oooo00L0
oooo00<02NX:0?ooo`3oool0K@3oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo
0?ooo`0g0?ooo`<02NX:4P3oool00`09jPX0oooo0?ooo`0d0?ooo`0500WZ2P3oool0oooo0?ooo`09
jPX0B03oool00`09jPX0oooo0?ooo`0`0?ooo`802NX:6@3oool00`09jPX0oooo0?ooo`070?ooo`03
00WZ2P3oool0oooo06d0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0
>P3oool200WZ2Q40oooo00<02NX:0?ooo`3oool0<`3oool01009jPX0oooo0?ooo`09jPY90?ooo`03
00WZ2P3oool0oooo02l0oooo00<02NX:0?ooo`09jPX0603oool00`09jPX0oooo0?ooo`080?ooo`03
00WZ2P3oool0oooo06d0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0
?03oool200WZ2Q00oooo00<02NX:0?ooo`3oool0<P3oool300WZ2TX0oooo00<02NX:0?ooo`3oool0
;P3oool01009jPX0oooo0?ooo`09jPXH0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3o
ool0K@3oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`0n0?ooo`802NX:
3P3oool00`09jPX0oooo0?ooo`0b0?ooo`0300WZ2P3oool0oooo04T0oooo00<02NX:0?ooo`3oool0
;P3oool01@09jPX0oooo0?ooo`3oool02NX:01P0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0
oooo0?ooo`1]0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo0400oooo
0`09jPX<0?ooo`0300WZ2P3oool0oooo0300oooo0P09jPY;0?ooo`0300WZ2P3oool0oooo02h0oooo
00D02NX:0?ooo`3oool0oooo00WZ2P0H0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3o
ool0K@3oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`130?ooo`802NX:
2`3oool00`09jPX0oooo0?ooo`0]0?ooo`802NX:00<0oooo00WZ2P3oool0BP3oool00`09jPX0oooo
0?ooo`0]0?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool05@3oool00`09jPX0oooo
0?ooo`090?ooo`0300WZ2P3oool0oooo06d0oooo00<000000?ooo`3oool02@3oool000X0oooo00<0
00000?ooo`3oool0A@3oool200WZ2PT0oooo00<02NX:0?ooo`3oool0;03oool01@09jPX0oooo0?oo
o`3oool02NX:04/0oooo00<02NX:0?ooo`3oool0;03oool00`09jPX0oooo0?ooo`030?ooo`0300WZ
2P3oool0oooo01D0oooo00<02NX:0?ooo`3oool02@3oool00`09jPX0oooo0?ooo`1]0?ooo`030000
003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo04L0oooo0P09jPX80?ooo`0300WZ2P3o
ool0oooo02X0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`190?ooo`0300WZ2P3o
ool0oooo02/0oooo00<02NX:0?ooo`3oool01@3oool00`09jPX0oooo0?ooo`0D0?ooo`0300WZ2P3o
ool0oooo00T0oooo00<02NX:0?ooo`3oool0K@3oool00`000000oooo0?ooo`090?ooo`002P3oool0
0`000000oooo0?ooo`190?ooo`802NX:1P3oool00`09jPX0oooo0?ooo`0X0?ooo`802NX:1@3oool0
0`09jPX0oooo0?ooo`190?ooo`0300WZ2P3oool0oooo02/0oooo00<02NX:0?ooo`3oool01@3oool0
0`09jPX0oooo0?ooo`0D0?ooo`0300WZ2P3oool0oooo00T0oooo00<02NX:0?ooo`3oool0K@3oool0
0`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`1;0?ooo`<02NX:103oool00`09
jPX0oooo0?ooo`0V0?ooo`0300WZ2P3oool0oooo00D0oooo00<02NX:0?ooo`3oool0B@3oool00`09
jPX0oooo0?ooo`0Z0?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool04`3oool00`09
jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo06d0oooo00<000000?ooo`3oool02@3oool000X0
oooo00<000000?ooo`3oool0CP3oool200WZ2P<0oooo00<02NX:0?ooo`3oool0903oool00`09jPX0
oooo0?ooo`060?ooo`0300WZ2P3oool0oooo04T0oooo00<02NX:0?ooo`3oool0:@3oool00`09jPX0
oooo0?ooo`070?ooo`0300WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0
oooo0?ooo`1]0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo0500oooo
0P09jPX00`3oool02NX:0?ooo`0S0?ooo`802NX:2@3oool00`09jPX0oooo0?ooo`190?ooo`0300WZ
2P3oool0oooo02P0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ
2P3oool0oooo00T0oooo00<02NX:0?ooo`3oool0KP3oool00`000000oooo0?ooo`090?ooo`002P3o
ool00`000000oooo0?ooo`1B0?ooo`<02NX:8P3oool00`09jPX0oooo0?ooo`090?ooo`0300WZ2P3o
ool0oooo04T0oooo00<02NX:0?ooo`3oool0:03oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3o
ool0oooo0180oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`1^0?ooo`030000003o
ool0oooo00T0oooo000:0?ooo`030000003oool0oooo05@0oooo0`09jPXO0?ooo`0300WZ2P3oool0
oooo00X0oooo00<02NX:0?ooo`3oool0B@3oool00`09jPX0oooo0?ooo`0W0?ooo`0300WZ2P3oool0
oooo00T0oooo00<02NX:0?ooo`3oool04P3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0
oooo06h0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0E@3oool01009
jPX0oooo00WZ2P09jPXK0?ooo`802NX:3@3oool00`09jPX0oooo0?ooo`190?ooo`0300WZ2P3oool0
oooo02H0oooo00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0A0?ooo`0300WZ2P3oool0
oooo00X0oooo00<02NX:0?ooo`3oool0KP3oool00`000000oooo0?ooo`090?ooo`002P3oool00`00
0000oooo0?ooo`1F0?ooo`0300WZ2P3oool0oooo00802NX:603oool00`09jPX0oooo0?ooo`0=0?oo
o`0300WZ2P3oool0oooo04T0oooo00<02NX:0?ooo`3oool09@3oool00`09jPX0oooo0?ooo`0<0?oo
o`0300WZ2P3oool0oooo0140oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`1^0?oo
o`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo05H0oooo00<02NX:0?ooo`3o
ool00P3oool200WZ2QD0oooo00<02NX:0?ooo`3oool03P3oool00`09jPX0oooo0?ooo`190?ooo`03
00WZ2P3oool0oooo02D0oooo00<02NX:0?ooo`3oool0303oool00`09jPX0oooo0?ooo`0@0?ooo`03
00WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool0KP3oool00`000000oooo0?ooo`090?ooo`00
2P3oool00`000000oooo0?ooo`1G0?ooo`0300WZ2P3oool0oooo00<0oooo0`09jPX@0?ooo`802NX:
4@3oool00`09jPX0oooo0?ooo`190?ooo`0300WZ2P3oool0oooo02@0oooo00<02NX:0?ooo`3oool0
3@3oool00`09jPX0oooo0?ooo`0@0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool0
KP3oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`1H0?ooo`0300WZ2P3o
ool0oooo00D0oooo0P09jPX=0?ooo`0300WZ2P3oool0oooo0140oooo00<02NX:0?ooo`3oool0B03o
ool00`09jPX0oooo0?ooo`0T0?ooo`0300WZ2P3oool0oooo00h0oooo00<02NX:0?ooo`3oool0403o
ool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo06h0oooo00<000000?ooo`3oool02@3o
ool000X0oooo00<000000?ooo`3oool0F03oool00`09jPX0oooo0?ooo`070?ooo`802NX:2P3oool0
0`09jPX0oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo04P0oooo00<02NX:0?ooo`3oool08`3oool0
0`09jPX0oooo0?ooo`0?0?ooo`0300WZ2P3oool0oooo0100oooo00<02NX:0?ooo`3oool02`3oool0
0`09jPX0oooo0?ooo`1^0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo
05T0oooo00<02NX:0?ooo`3oool0203oool200WZ2PH0oooo0P09jPXE0?ooo`0300WZ2P3oool0oooo
04P0oooo00<02NX:0?ooo`3oool08`3oool00`09jPX0oooo0?ooo`0?0?ooo`0300WZ2P3oool0oooo
00l0oooo00<02NX:0?ooo`3oool0303oool00`09jPX0oooo0?ooo`1^0?ooo`030000003oool0oooo
00T0oooo000:0?ooo`030000003oool0oooo05X0oooo00<02NX:0?ooo`3oool02@3oool300WZ2P80
oooo00<02NX:0?ooo`3oool05@3oool00`09jPX0oooo0?ooo`180?ooo`0300WZ2P3oool0oooo0280
oooo00<02NX:0?ooo`3oool0403oool00`09jPX0oooo0?ooo`0?0?ooo`0300WZ2P3oool0oooo00`0
oooo00<02NX:0?ooo`3oool0KP3oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo
0?ooo`1J0?ooo`0300WZ2P3oool0oooo00`0oooo0P09jPXH0?ooo`0300WZ2P3oool0oooo04P0oooo
00<02NX:0?ooo`3oool08@3oool00`09jPX0oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo00h0oooo
00<02NX:0?ooo`3oool0303oool00`09jPX0oooo0?ooo`1^0?ooo`030000003oool0oooo00T0oooo
000:0?ooo`030000003oool0oooo05/0oooo00<02NX:0?ooo`3oool02P3oool200WZ2P030?ooo`09
jPX02NX:01H0oooo00<02NX:0?ooo`3oool0B03oool00`09jPX0oooo0?ooo`0P0?ooo`0300WZ2P3o
ool0oooo01<0oooo00<02NX:0?ooo`3oool03@3oool00`09jPX0oooo0?ooo`0=0?ooo`0300WZ2P3o
ool0oooo06d0oooo0P00000;0?ooo`002P3oool00`000000oooo0?ooo`1K0?ooo`0300WZ2P3oool0
oooo00T0oooo00<02NX:0?ooo`3oool00`3oool200WZ2Q@0oooo00<02NX:0?ooo`3oool0B03oool0
0`09jPX0oooo0?ooo`0P0?ooo`0300WZ2P3oool0oooo01<0oooo00<02NX:0?ooo`3oool03@3oool0
0`09jPX0oooo0?ooo`0=0?ooo`0300WZ2P3oool0oooo06/0oooo0P09jPX2000000/0oooo000:0?oo
o`030000003oool0oooo05`0oooo00<02NX:0?ooo`3oool01`3oool00`09jPX0oooo0?ooo`060?oo
o`<02NX:4@3oool00`09jPX0oooo0?ooo`180?ooo`0300WZ2P3oool0oooo01l0oooo00<02NX:0?oo
o`3oool0503oool00`09jPX0oooo0?ooo`0=0?ooo`0300WZ2P3oool0oooo00d0oooo00<02NX:0?oo
o`3oool0J@3oool200WZ2P<0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3o
ool0G@3oool00`09jPX0oooo0?ooo`050?ooo`0300WZ2P3oool0oooo00X0oooo0P09jPX?0?ooo`03
00WZ2P3oool0oooo04P0oooo00<02NX:0?ooo`3oool07P3oool00`09jPX0oooo0?ooo`0E0?ooo`03
00WZ2P3oool0oooo00d0oooo00<02NX:0?ooo`3oool03@3oool00`09jPX0oooo0?ooo`1W0?ooo`80
2NX:1@3oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`1M0?ooo`0300WZ
2P3oool0oooo00<0oooo0P09jPX?0?ooo`802NX:3@3oool00`09jPX0oooo0?ooo`180?ooo`0300WZ
2P3oool0oooo01d0oooo00<02NX:0?ooo`3oool05P3oool00`09jPX0oooo0?ooo`0<0?ooo`0300WZ
2P3oool0oooo00d0oooo00<02NX:0?ooo`3oool0IP3oool200WZ2PL0oooo00<000000?ooo`3oool0
2@3oool000X0oooo00<000000?ooo`3oool0GP3oool01@09jPX0oooo0?ooo`3oool02NX:01<0oooo
0P09jPX;0?ooo`0300WZ2P3oool0oooo04P0oooo00<02NX:0?ooo`3oool07@3oool00`09jPX0oooo
0?ooo`0F0?ooo`0300WZ2P3oool0oooo00`0oooo00<02NX:0?ooo`3oool03@3oool00`09jPX0oooo
0?ooo`1T0?ooo`802NX:2@3oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?oo
o`1N0?ooo`0400WZ2P3oool0oooo00WZ2QH0oooo0`09jPX80?ooo`0300WZ2P3oool0oooo04P0oooo
00<02NX:0?ooo`3oool0703oool00`09jPX0oooo0?ooo`0H0?ooo`0300WZ2P3oool0oooo00/0oooo
00<02NX:0?ooo`3oool03@3oool00`09jPX0oooo0?ooo`1S0?ooo`0300WZ2P3oool0oooo00T0oooo
00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0G`3oool200WZ2QX0oooo0P09
jPX60?ooo`0300WZ2P3oool0oooo04P0oooo00<02NX:0?ooo`3oool06`3oool00`09jPX0oooo0?oo
o`0I0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool03@3oool00`09jPX0oooo0?oo
o`1Q0?ooo`802NX:303oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`1N
0?ooo`0300WZ2P3oool02NX:01`0oooo0P09jPX40?ooo`0300WZ2P3oool0oooo04P0oooo00<02NX:
0?ooo`3oool06P3oool00`09jPX0oooo0?ooo`0J0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:
0?ooo`3oool03P3oool00`09jPX0oooo0?ooo`1O0?ooo`802NX:3P3oool00`000000oooo0?ooo`09
0?ooo`002P3oool00`000000oooo0?ooo`1M0?ooo`0400WZ2P3oool0oooo00WZ2Qh0oooo0P09jPX2
0?ooo`0300WZ2P3oool0oooo04P0oooo00<02NX:0?ooo`3oool06P3oool00`09jPX0oooo0?ooo`0J
0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool03P3oool00`09jPX0oooo0?ooo`1M
0?ooo`802NX:403oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`1K0?oo
o`802NX:103oool00`09jPX0oooo0?ooo`0M0?ooo`<02NX:B@3oool00`09jPX0oooo0?ooo`0J0?oo
o`0300WZ2P3oool0oooo01/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0>0?oo
o`0300WZ2P3oool0oooo05/0oooo0P09jPXB0?ooo`030000003oool0oooo00T0oooo000:0?ooo`03
0000003oool0oooo05X0oooo00<02NX:0?ooo`3oool01@3oool00`09jPX0oooo0?ooo`0N0?ooo`<0
2NX:A`3oool00`09jPX0oooo0?ooo`0I0?ooo`0300WZ2P3oool0oooo01`0oooo00<02NX:0?ooo`3o
ool02@3oool00`09jPX0oooo0?ooo`0?0?ooo`0300WZ2P3oool0oooo05T0oooo0P09jPXD0?ooo`03
0000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo05T0oooo00<02NX:0?ooo`3oool0
1P3oool00`09jPX0oooo0?ooo`0N0?ooo`0300WZ2P3oool0oooo00802NX:A@3oool00`09jPX0oooo
0?ooo`0H0?ooo`0300WZ2P3oool0oooo01d0oooo00<02NX:0?ooo`3oool02@3oool00`09jPX0oooo
0?ooo`0?0?ooo`0300WZ2P3oool0oooo05L0oooo0P09jPXF0?ooo`030000003oool0oooo00T0oooo
000:0?ooo`030000003oool0oooo05L0oooo0P09jPX:0?ooo`0300WZ2P3oool0oooo01d0oooo00<0
2NX:0?ooo`3oool00P3oool200WZ2T<0oooo00<02NX:0?ooo`3oool0603oool00`09jPX0oooo0?oo
o`0N0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool03`3oool00`09jPX0oooo0?oo
o`1E0?ooo`802NX:603oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`1F
0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool07@3oool00`09jPX0oooo0?ooo`04
0?ooo`<02NX:@03oool00`09jPX0oooo0?ooo`0G0?ooo`0300WZ2P3oool0oooo01l0oooo00<02NX:
0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0?0?ooo`0300WZ2P3oool0oooo05<0oooo0P09jPXJ
0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo04l0oooo00<000000?oo
o`3oool00P3oool00`0000002NX:0?ooo`0=0?ooo`0300WZ2P000000oooo01`0oooo00<02NX:0000
003oool01`3oool200WZ2P800000>`3oool00`0000002NX:0?ooo`0F0?ooo`0300000009jPX0oooo
0240oooo00<02NX:0000003oool01P3oool00`0000002NX:0?ooo`080?ooo`030000003oool0oooo
00H0oooo00<02NX:0?ooo`3oool0D@3oool200WZ2Q`0oooo00<000000?ooo`3oool02@3oool000X0
oooo00<000000?ooo`3oool0C`3oool50000000300WZ2P000000000000h0000000<02NX:00000000
00006`0000000`09jPX00000000000090000000300WZ2P000000000003/0000000<02NX:00000000
00005@0000000`09jPX000000000000Q0000000300WZ2P000000000000L0000000<02NX:00000000
0000200000080?ooo`0300WZ2P3oool0oooo04l0oooo0P09jPXN0?ooo`030000003oool0oooo00T0
oooo000:0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool00P3oool00`09jPX0oooo
0?ooo`0>0?ooo`0300WZ2P3oool0oooo01/0oooo00<02NX:0?ooo`3oool02P3oool00`09jPX0oooo
0?ooo`0j0?ooo`0300WZ2P3oool0oooo01D0oooo00<02NX:0?ooo`3oool08@3oool00`09jPX0oooo
0?ooo`070?ooo`0300WZ2P3oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`09jPX0oooo
0?ooo`1=0?ooo`802NX:803oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?oo
o`1?0?ooo`050000003oool0oooo0?ooo`09jPX04P3oool00`09jPX0oooo0?ooo`0J0?ooo`0300WZ
2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool0>@3oool00`09jPX0oooo0?ooo`0D0?ooo`0300WZ
2P3oool0oooo0280oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo0?ooo`080?ooo`030000
003oool0oooo00H0oooo00<02NX:0?ooo`3oool0B`3oool200WZ2R80oooo00<000000?ooo`3oool0
2@3oool000X0oooo00<000000?ooo`3oool0C`3oool010000000oooo0?ooo`09jPXC0?ooo`0300WZ
2P3oool0oooo01X0oooo00<02NX:0?ooo`3oool02`3oool00`0000002NX:0?ooo`0i0?ooo`0300WZ
2P3oool0oooo01@0oooo00<02NX:0?ooo`3oool08`3oool00`09jPX0oooo0?ooo`050?ooo`0300WZ
2P3oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`09jPX0oooo0?ooo`1:0?ooo`0300WZ
2P3oool0oooo0280oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0C`3o
ool010000000oooo00000009jPXC0?ooo`0300WZ2P3oool0oooo01X0oooo00<02NX:0000003oool0
2`3oool2000003X0oooo00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`0S0?ooo`030000
0009jPX0oooo00H0oooo00<02NX:0?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`0300WZ
2P3oool0oooo04P0oooo0P09jPXU0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000003o
ool0oooo04l0oooo00@000000?ooo`09jPX000004`3oool00`0000002NX:0?ooo`0J0?ooo`0300WZ
2P000000oooo00d0oooo00<02NX:0?ooo`3oool0=`3oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ
2P3oool0oooo02<0oooo0P0000060?ooo`0300WZ2P3oool0oooo00T0oooo00<000000?ooo`3oool0
1@3oool00`09jPX0oooo0?ooo`170?ooo`802NX:9`3oool00`000000oooo0?ooo`090?ooo`002P3o
ool00`000000oooo0?ooo`1?0?ooo`030000003oool02NX:01@0oooo0P00000K0?ooo`0300WZ2P3o
ool0oooo00d0oooo00<02NX:0?ooo`3oool0=`3oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3o
ool0oooo02@0oooo00<02NX:0?ooo`3oool0103oool00`09jPX000000?ooo`090?ooo`030000003o
ool0oooo00D0oooo00<02NX:0?ooo`3oool0A@3oool200WZ2RT0oooo00<000000?ooo`3oool02@3o
ool000X0oooo00<000000?ooo`3oool0C`3oool00`0000002NX:0?ooo`0F0?ooo`0300WZ2P000000
oooo01P0oooo00<02NX:0?ooo`3oool03P3oool00`09jPX0oooo0?ooo`0e0?ooo`0300000009jPX0
oooo01<0oooo00<02NX:0000003oool09P3oool00`09jPX0oooo0?ooo`030?ooo`8000002P3oool0
0`000000oooo0?ooo`050?ooo`0300WZ2P3oool0oooo04<0oooo0P09jPX[0?ooo`030000003oool0
oooo00T0oooo000:0?ooo`030000003oool0oooo04h0oooo00<0000000WZ2P3oool05`3oool20000
00802NX:603oool00`09jPX0oooo0?ooo`0=0?ooo`0300WZ2P3oool0oooo03D0oooo0P00000D0?oo
o`8000009`3oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00T0oooo00<000000?oo
o`3oool01@3oool00`09jPX0oooo0?ooo`110?ooo`802NX:;@3oool00`000000oooo0?ooo`090?oo
o`002P3oool00`000000oooo0?ooo`1>0?ooo`8000006`3oool0100000002NX:00WZ2P09jPXE0?oo
o`0300WZ2P3oool0oooo00d0oooo00<02NX:0?ooo`3oool0=P3oool00`09jPX0oooo0?ooo`0A0?oo
o`0300WZ2P3oool0oooo02L0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`0:0?oo
o`030000003oool0oooo00D0oooo00<02NX:0?ooo`3oool0?`3oool200WZ2Rl0oooo00<000000?oo
o`3oool02@3oool000X0oooo00<000000?ooo`3oool0C`3oool00`09jPX0oooo0?ooo`0I0?ooo`80
00000P3oool400WZ2PD0oooo1P09jPX00`000000oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00d0
oooo00<0000000WZ2P3oool0=P3oool00`09jPX0oooo0?ooo`0A0?ooo`0300WZ2P3oool0oooo02P0
oooo00H02NX:0?ooo`3oool0oooo00WZ2P00000;0?ooo`030000003oool0oooo00D0oooo00<02NX:
0?ooo`3oool0?@3oool200WZ2S40oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?oo
o`3oool0C`3oool00`0000002NX:0?ooo`0M0?ooo`8000000P3oool500WZ2P80oooo0P000000103o
ool0000000WZ2P09jPX40?ooo`0300WZ2P3oool0oooo00d0oooo0P00000f0?ooo`0300WZ2P3oool0
oooo0100oooo0P0000000`09jPX0oooo0?ooo`0W0?ooo`0300000009jPX0oooo0080oooo00<02NX:
0000003oool02P3oool00`000000oooo0?ooo`050?ooo`0300WZ2P3oool0oooo03/0oooo0P09jPXc
0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo04l0oooo0P00000R0?oo
o`8000002`3oool200WZ2P80oooo00<0000000WZ2P3oool03P3oool00`09jPX0oooo0?ooo`0c0?oo
o`0300000009jPX0oooo0140oooo00<0000000WZ2P3oool0:@3oool200000080oooo00<0000000WZ
2P3oool02`3oool00`000000oooo0?ooo`050?ooo`0300WZ2P3oool0oooo03T0oooo0P09jPXe0?oo
o`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo04l0oooo00<0000000WZ2P3o
ool0<03oool01009jPX0oooo00000009jPX?0?ooo`0300WZ2P3oool0oooo0380oooo0P00000300WZ
2Pl0oooo00<02NX:0?ooo`3oool0:`3oool01@09jPX0oooo0?ooo`0000002NX:00`0oooo00<00000
0?ooo`3oool01@3oool00`09jPX0oooo0?ooo`0g0?ooo`802NX:=`3oool00`000000oooo0?ooo`09
0?ooo`002P3oool00`000000oooo0?ooo`1?0?ooo`0300000009jPX0oooo0340oooo0`09jPX?0?oo
o`0300WZ2P3oool0oooo0380oooo00<02NX:00000009jPX00P0000000`09jPX0oooo0?ooo`0:0?oo
o`0300000009jPX0oooo02d0oooo00@02NX:0?ooo`0000002NX:3@3oool00`000000oooo0?ooo`05
0?ooo`0300WZ2P3oool0oooo03D0oooo0P09jPXi0?ooo`030000003oool0oooo00T0oooo000:0?oo
o`030000003oool0oooo04l0oooo00<02NX:0?ooo`3oool0<P3oool00`0000002NX:0?ooo`0=0?oo
o`0300000009jPX0oooo0340oooo0P09jPX00`3oool00000000000030?ooo`0300WZ2P000000oooo
00P0oooo0`00000]0?ooo`0300000009jPX0oooo008000003@3oool00`000000oooo0?ooo`050?oo
o`0300WZ2P3oool0oooo03<0oooo0P09jPXk0?ooo`030000003oool0oooo00T0oooo000:0?ooo`03
0000003oool0oooo04l0oooo00<02NX:0?ooo`3oool0<P3oool20000000300WZ2P000000oooo00/0
oooo0P00000`0?ooo`802NX:0`3oool00`09jPX0oooo0?ooo`020?ooo`8000000P09jPX70?ooo`03
00WZ2P000000oooo02d0oooo0P0000000`3oool02NX:0?ooo`0=0?ooo`030000003oool0oooo00D0
oooo00<02NX:0?ooo`3oool0<P3oool00`09jPX0oooo0?ooo`0k0?ooo`030000003oool0oooo00T0
oooo000:0?ooo`030000003oool0oooo04l0oooo00<02NX:0000003oool0<P3oool01@09jPX0oooo
00000009jPX0000000`0oooo00<02NX:0?ooo`3oool0;03oool200WZ2P@0oooo00<0000000WZ2P3o
ool0103oool2000000030?ooo`09jPX0oooo00D0oooo00<02NX:0?ooo`3oool0;03oool010000000
2NX:0?ooo`09jPX?0?ooo`030000003oool0oooo00D0oooo00<02NX:0?ooo`3oool0<03oool200WZ
2Sh0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0C`3oool2000003<0
oooo00@02NX:0?ooo`3oool000000P09jPX;0?ooo`0300WZ2P3oool0oooo02T0oooo0`09jPX20000
00@0oooo0P0000090?ooo`802NX:0`3oool00`09jPX0oooo0?ooo`0/0?ooo`<0000000<0oooo00WZ
2P3oool03P3oool00`000000oooo0?ooo`050?ooo`0300WZ2P3oool0oooo02h0oooo0P09jPY00?oo
o`030000003oool0oooo00T0oooo00090?ooo`800000G@09jPXY0?ooo`0300WZ2P3oool0oooo00<0
oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0W0?ooo`802NX:2P3oool00`09jPX0
oooo0?ooo`090?ooo`0300WZ2P0000002NX:02h0oooo100000000`09jPX0oooo0?ooo`0>0?ooo`03
0000003oool0oooo00D0oooo00<02NX:0?ooo`3oool0;03oool200WZ2T80oooo00<000000?ooo`3o
ool02@3oool000T0oooo0P00001@0?ooo`80000000<02NX:0?ooo`3oool00`3oool2000000<0oooo
1@09jPXT0?ooo`0300WZ2P000000oooo00<0oooo00<0000000WZ2P3oool01`3oool00`0000002NX:
0?ooo`0U0?ooo`80000000<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`090?ooo`030000
0009jPX02NX:02d0oooo00<02NX:00000009jPX00`00000@0?ooo`030000003oool0oooo00D0oooo
00<02NX:0?ooo`3oool0:P3oool200WZ2T@0oooo00<000000?ooo`3oool02@3oool000X0oooo00<0
00000?ooo`3oool0C`3oool00`000000oooo00WZ2P0:0?ooo`80000000D0oooo00000009jPX02NX:
0000000Q0?ooo`800000103oool20000000300WZ2P3oool0oooo00D0oooo00<0000000WZ2P3oool0
9@3oool200WZ2P030000003oool0oooo00T0oooo00<02NX:0?ooo`3oool02P3oool2000000030?oo
o`09jPX0oooo02H0oooo0`00000200WZ2P<0oooo00<0000000WZ2P3oool0403oool00`000000oooo
0?ooo`040?ooo`0300WZ2P3oool0oooo02T0oooo0P09jPY60?ooo`030000003oool0oooo00T0oooo
000:0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`09jPX03@3oool4000000802NX:7`3o
ool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P000000oooo00D0oooo00<02NX:0?ooo`3oool08`3o
ool00`09jPX0oooo0?ooo`0<0?ooo`0300WZ2P3oool0oooo00T0oooo00<02NX:0?ooo`3oool00P3o
ool00`09jPX0oooo0?ooo`0K0?ooo`L02NX:00@0000000WZ2P0000002NX:0P0000050?ooo`0300WZ
2P3oool0oooo00l0oooo00<000000?ooo`3oool0103oool00`09jPX0oooo0?ooo`0W0?ooo`802NX:
B03oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`1?0?ooo`030000003o
ool02NX:01<0oooo00<02NX:0?ooo`3oool0703oool00`0000002NX:0?ooo`060?ooo`8000000P09
jPX50?ooo`0300WZ2P3oool0oooo0200oooo0P09jPX>0?ooo`0300000009jPX0oooo00T0oooo00<0
2NX:0000003oool0103oool00`09jPX0oooo0?ooo`0G0?ooo`0300000009jPX02NX:0080oooo0P00
00030?ooo`8000002@3oool00`09jPX0oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00<0
2NX:0?ooo`3oool09@3oool200WZ2TX0oooo00<000000?ooo`3oool02@3oool000X0oooo00<00000
0?ooo`3oool0C`3oool010000000oooo00000009jPXB0?ooo`0300000009jPX0oooo01`0oooo00<0
000000WZ2P3oool02@3oool00`0000002NX:000000020?ooo`0300000009jPX0oooo01P0oooo00@0
2NX:00000009jPX02NX:103oool00`09jPX0oooo0?ooo`0>0?ooo`8000002@3oool00`09jPX00000
000000060?ooo`0300WZ2P000000oooo01@0oooo00@0000000WZ2P0000000000503oool00`09jPX0
oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00<02NX:0?ooo`3oool08`3oool200WZ2T`0
oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0C`3oool010000000oooo
00000000000B0?ooo`80000000<02NX:0?ooo`3oool06`3oool00`09jPX0oooo0?ooo`080?ooo`80
000000<02NX:0?ooo`3oool00P00000C0?ooo`<000000`09jPX0103oool0000000000000000200WZ
2P0300000009jPX0oooo0100oooo00<02NX:0?ooo`3oool01`3oool00`09jPX0oooo0?ooo`070?oo
o`80000000<02NX:0?ooo`3oool04P3oool2000001H0oooo00<02NX:0?ooo`3oool03P3oool00`00
0000oooo0?ooo`040?ooo`0300WZ2P3oool0oooo0240oooo0P09jPY>0?ooo`030000003oool0oooo
00T0oooo000:0?ooo`030000003oool0oooo04l0oooo00@000000?ooo`3oool02NX:5@3oool00`09
jPX0oooo0?ooo`0I0?ooo`0300000009jPX0oooo00`0oooo00D02NX:0?ooo`3oool02NX:0000000=
0?ooo`8000000`09jPX0100000002NX:0000000000050?ooo`80000000@0oooo00WZ2P09jPX02NX:
403oool00`09jPX0oooo0?ooo`060?ooo`0300WZ2P3oool0oooo00T0oooo0P00000B0?ooo`802NX:
5`3oool00`0000002NX:0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00<02NX:0?ooo`3oool0
7`3oool200WZ2U00oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0C`3o
ool010000000oooo00000009jPXF0?ooo`0300WZ2P3oool0oooo01P0oooo0P00000=0?ooo`030000
0009jPX0oooo00800000303oool200WZ2P8000003@3oool01@09jPX000000000000000002NX:00l0
oooo00<02NX:0?ooo`3oool0103oool00`0000002NX:0?ooo`0=0?ooo`0300WZ2P3oool0oooo00h0
oooo00<02NX:0000003oool05`3oool200000100oooo00<000000?ooo`3oool0103oool00`09jPX0
oooo0?ooo`0M0?ooo`802NX:DP3oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo
0?ooo`1?0?ooo`040000003oool00000000001H0oooo00<0000000WZ2P3oool06@3oool00`09jPX0
oooo0?ooo`0;0?ooo`8000000P09jPX;0?ooo`802NX:403oool00`09jPX0oooo0?ooo`030?ooo`80
2NX:2`3oool00`0000002NX:0?ooo`050?ooo`<000003`3oool00`09jPX0oooo0?ooo`0<0?ooo`03
00WZ2P000000000001P0oooo0P00000@0?ooo`030000003oool0oooo00@0oooo00<02NX:0?ooo`3o
ool06`3oool200WZ2U@0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0
C`3oool010000000oooo0?ooo`09jPXF0?ooo`80000000<02NX:0?ooo`3oool05`3oool00`09jPX0
oooo0?ooo`0>0?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool03P3oool200WZ2PP0
oooo0P0000090?ooo`8000001P3oool200000100oooo00<0000000WZ2P3oool02`3oool00`09jPX0
oooo0?ooo`0I0?ooo`800000403oool00`000000oooo0?ooo`040?ooo`0300WZ2P3oool0oooo01X0
oooo00<02NX:0?ooo`3oool0E03oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo
0?ooo`1?0?ooo`050000003oool0oooo0?ooo`09jPX0603oool00`09jPX000000?ooo`0F0?ooo`03
00WZ2P3oool0oooo00d0oooo00<02NX:0?ooo`09jPX01P3oool00`0000002NX:00WZ2P0@0?ooo`03
00WZ2P000000000000P0oooo00<0000000WZ2P09jPX01`3oool00`09jPX000000?ooo`060?ooo`03
00WZ2P3oool0oooo00l0oooo0P0000000`09jPX0oooo0?ooo`070?ooo`0300000009jPX0oooo01X0
oooo00<02NX:0?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`0300WZ2P3oool0oooo01P0
oooo0P09jPYG0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo04l0oooo
00D000000?ooo`3oool0oooo00WZ2P0H0?ooo`8000005`3oool00`09jPX0oooo0?ooo`0=0?ooo`04
00WZ2P3oool0000000WZ2P<0oooo0`09jPX00`000000oooo0?ooo`0>0?ooo`0300WZ2P3oool0oooo
00`0oooo00<02NX:0?ooo`3oool0103oool2000000L0oooo00<02NX:0?ooo`3oool04@3oool00`00
00002NX:0?ooo`060?ooo`0300WZ2P000000000001/0oooo00<02NX:0?ooo`3oool0403oool00`00
0000oooo0?ooo`040?ooo`0300WZ2P3oool0oooo01H0oooo0P09jPYI0?ooo`030000003oool0oooo
00T0oooo000:0?ooo`030000003oool0oooo04l0oooo00D000000?ooo`3oool0oooo00WZ2P0I0?oo
o`0300WZ2P3oool0oooo01D0oooo00<02NX:0?ooo`3oool03@3oool01009jPX0oooo000000000003
00WZ2Q<0oooo00<02NX:0?ooo`3oool03P3oool00`09jPX000000?ooo`020?ooo`0300WZ2P3oool0
oooo00H0oooo00<02NX:0?ooo`3oool04P3oool2000000D0oooo0P09jPXN0?ooo`0300WZ2P3oool0
oooo0100oooo00<000000?ooo`3oool0103oool00`09jPX0oooo0?ooo`0D0?ooo`802NX:F`3oool0
0`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`1?0?ooo`050000003oool0oooo
0?ooo`09jPX06P3oool00`09jPX0oooo0?ooo`0C0?ooo`0300000009jPX0oooo00d0oooo00L00000
00WZ2P09jPX02NX:0?ooo`09jPX000000180oooo00<0000000WZ2P3oool0403oool01@0000002NX:
0?ooo`3oool02NX:00T0oooo00<02NX:0?ooo`3oool04`3oool00`09jPX000000?ooo`020?ooo`03
00WZ2P3oool0oooo01d0oooo00<02NX:0?ooo`3oool04@3oool00`000000oooo0?ooo`040?ooo`03
00WZ2P3oool0oooo0180oooo0P09jPYM0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000
003oool0oooo04l0oooo00<000000?ooo`3oool00P3oool00`09jPX0oooo0?ooo`0H0?ooo`0300WZ
2P3oool0oooo0180oooo0P00000>0?ooo`800000103oool00`09jPX0oooo0?ooo`0?0?ooo`802NX:
00<000000?ooo`3oool04@3oool00`09jPX0oooo00WZ2P080?ooo`0300WZ2P000000oooo01@0oooo
0P0000000`09jPX0000000WZ2P0O0?ooo`0300000009jPX0oooo0180oooo00<000000?ooo`3oool0
103oool00`09jPX0oooo0?ooo`0@0?ooo`802NX:G`3oool00`000000oooo0?ooo`090?ooo`002P3o
ool00`000000oooo0?ooo`1?0?ooo`060000003oool0oooo0?ooo`0000002NX:6`3oool00`09jPX0
oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo00T0oooo00D0000000WZ2P09jPX0000000WZ2P040?oo
o`0300000009jPX0oooo00h0oooo00<02NX:000000000000503oool00`0000002NX:0?ooo`080?oo
o`800000503oool300WZ2P030?ooo`000000000001l0oooo0P00000C0?ooo`030000003oool0oooo
00@0oooo00<02NX:0?ooo`3oool03P3oool200WZ2V40oooo00<000000?ooo`3oool02@3oool000X0
oooo00<000000?ooo`3oool0C`3oool010000000oooo0?ooo`3oool2000001/0oooo00<0000000WZ
2P3oool04P3oool00`09jPX0oooo0?ooo`060?ooo`<02NX:0P0000020?ooo`0300WZ2P3oool0oooo
0080oooo0P00000=0?ooo`802NX:5P3oool00`0000002NX:00000002000000H0oooo00<02NX:0?oo
o`3oool04@3oool00`0000002NX:00WZ2P030?ooo`0300WZ2P3oool0oooo0200oooo00<02NX:0?oo
o`3oool04@3oool00`000000oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00`0oooo0P09jPYS0?oo
o`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3o
ool00`3oool00`09jPX0oooo0?ooo`0H0?ooo`8000004`3oool00`09jPX0oooo0?ooo`050?ooo`04
00WZ2P3oool00000000000<0oooo00<02NX:0?ooo`3oool01@3oool00`09jPX0oooo0?ooo`080?oo
o`800000603oool2000000030?ooo`0000002NX:00D0oooo00<02NX:0?ooo`3oool04P3oool20000
00D0oooo00<02NX:0?ooo`3oool07P3oool00`09jPX0oooo0?ooo`0B0?ooo`030000003oool0oooo
00<0oooo00<02NX:0?ooo`3oool02`3oool200WZ2VD0oooo00<000000?ooo`3oool02@3oool000X0
oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`030?ooo`0300WZ2P3oool0oooo01X0
oooo00<02NX:0?ooo`3oool0403oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00D0
oooo00<02NX:0?ooo`3oool01@3oool00`09jPX000000?ooo`070?ooo`802NX:00<000000?ooo`3o
ool05P3oool2000000<0oooo00D02NX:0?ooo`3oool0000000WZ2P0D0?ooo`0300WZ2P3oool0oooo
00H0oooo00<02NX:0?ooo`3oool0703oool00`0000002NX:0?ooo`0C0?ooo`030000003oool0oooo
00<0oooo00<02NX:0?ooo`3oool02@3oool200WZ2VL0oooo00<000000?ooo`3oool02@3oool000X0
oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`030?ooo`0300WZ2P3oool0oooo01X0
oooo00<02NX:0?ooo`3oool0403oool01`09jPX0oooo0?ooo`3oool02NX:00000009jPX01`3oool0
0`0000002NX:0?ooo`060?ooo`8000001`3oool00`09jPX000000000000I0?ooo`0300WZ2P3oool0
oooo00<0oooo00@02NX:0?ooo`00000000004@3oool20000000300WZ2P3oool0oooo00L0oooo00<0
000000WZ2P3oool0703oool2000001@0oooo00<000000?ooo`3oool00`3oool00`09jPX0oooo0?oo
o`070?ooo`802NX:J@3oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`1?
0?ooo`030000003oool0oooo00<0oooo00<0000000WZ2P3oool01`3oool2000000802NX:00<00000
0?ooo`3oool0303oool00`0000002NX:0?ooo`0?0?ooo`0300000009jPX02NX:00802NX:00<0oooo
0000000000001`3oool2000000P0oooo00<02NX:0?ooo`3oool00`3oool200WZ2Q`0oooo00<02NX:
0?ooo`3oool0103oool200WZ2Q00oooo0`0000000`09jPX0oooo0?ooo`080?ooo`80000000<02NX:
0?ooo`3oool06P3oool00`09jPX0oooo0?ooo`0C0?ooo`030000003oool0oooo00<0oooo00<02NX:
0?ooo`3oool01@3oool200WZ2V/0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?oo
o`3oool0C`3oool00`000000oooo0?ooo`030?ooo`80000000<02NX:0?ooo`3oool0103oool200WZ
2P040000003oool00000000000<02NX:2`3oool200000100oooo00<0000000WZ2P0000003@3oool0
0`09jPX0oooo0?ooo`020?ooo`@02NX:00<0000000WZ2P09jPX00`09jPX4000001X0oooo00<02NX:
0?ooo`3oool0103oool00`0000002NX:00WZ2P0?0?ooo`0300000009jPX0oooo00h0oooo00<02NX:
0?ooo`3oool06@3oool00`09jPX0oooo0?ooo`0C0?ooo`030000003oool0oooo00<0oooo00<02NX:
0?ooo`3oool00`3oool200WZ2Vd0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?oo
o`3oool0C`3oool00`000000oooo0?ooo`060?ooo`0300WZ2P000000000000<02NX:1@3oool20000
00030?ooo`0000002NX:00/0oooo00<0000000WZ2P3oool03@3oool00`09jPX0oooo00WZ2P0>0?oo
o`0300WZ2P3oool0oooo00802NX:00@0oooo000000000000oooo0P00000200WZ2P050000003oool0
oooo00WZ2P0000000`09jPXF0?ooo`0300000009jPX0oooo00H0oooo0P0000000`3oool02NX:0?oo
o`0<0?ooo`0300000009jPX0oooo00l0oooo00<0000000WZ2P3oool05`3oool00`0000002NX:0?oo
o`0E0?ooo`030000003oool0oooo00<0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?oo
o`1]0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo04l0oooo00<00000
0?ooo`3oool01P3oool300WZ2P/0oooo0P00000;0?ooo`80000000<02NX:0?ooo`3oool02P3oool0
0`09jPX0oooo00WZ2P0>0?ooo`802NX:00<0000000WZ2P3oool01P3oool01009jPX0000000000000
00070?ooo`0300000009jPX02NX:01<0oooo00<0000000WZ2P3oool01@3oool01@09jPX0oooo0?oo
o`3oool0000000802NX:2@3oool200WZ2P800000203oool2000000H0oooo0P00000<00WZ2P040000
0009jPX02NX:00WZ2PP0oooo0P00000F0?ooo`030000003oool0oooo00<0oooo00<02NX:0?ooo`3o
ool00P09jPY`0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo04l0oooo
00<000000?ooo`3oool0103oool200WZ2P80000000<02NX:0000003oool02`3oool00`09jPX0oooo
0?ooo`0;0?ooo`0300WZ2P3oool0oooo00L0oooo00D0000000WZ2P3oool0000000WZ2P0<0?ooo`<0
2NX:00<0oooo0000000000001P3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00@0
oooo0P0000000`3oool02NX:0?ooo`0B0?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3o
ool00P3oool2000000030?ooo`09jPX0oooo00D0oooo0P09jPX;0?ooo`P02NX:0P3oool2000000H0
oooo0P0000020?ooo`8000000`3oool400WZ2P0300000009jPX0000000<02NX:00<0000000WZ2P3o
ool04`3oool00`000000oooo0?ooo`030?ooo`<02NX:LP3oool00`000000oooo0?ooo`090?ooo`00
2P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00<0oooo00@02NX:0?ooo`3oool0
oooo0`00000=0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool01@3oool00`09jPX0
000000000003000000T0oooo00<02NX:00000009jPX00P0000000`09jPX0oooo0?ooo`060?ooo`03
00WZ2P3oool0oooo00<0oooo00<0000000WZ2P3oool0203oool00`09jPX0oooo0?ooo`0@0?ooo`03
00WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool01P3oool00`0000002NX:00WZ2P0A00WZ2P@0
oooo0P0000020?ooo`<02NX:4`3oool2000000040?ooo`00000000000?ooo`80000000<0oooo00WZ
2P09jPX00P09jPX@0?ooo`030000003oool0oooo0080oooo0P09jPYd0?ooo`030000003oool0oooo
00T0oooo000:0?ooo`030000003oool0oooo04l0oooo00@000000?ooo`3oool0oooo0P09jPX60?oo
o`0300000009jPX02NX:00/0oooo00<0000000WZ2P3oool02`3oool00`0000002NX:0?ooo`040?oo
o`0400WZ2P3oool0oooo0?ooo`8000001`3oool300WZ2P030?ooo`00000000000080oooo00<02NX:
0?ooo`3oool01@3oool00`09jPX0oooo0?ooo`040?ooo`8000002P3oool00`09jPX0oooo0?ooo`0>
0?ooo`0600WZ2P3oool0oooo0?ooo`0000002NX:2@3oool2000000030?ooo`09jPX02NX:00800000
0P09jPX01@0000002NX:00WZ2P3oool02NX:00@000002P3oool2000000030?ooo`09jPX0oooo01<0
oooo00<02NX:0?ooo`3oool0203oool300WZ2Pd0oooo00<000000?ooo`3oool00P09jPX00`3oool0
2NX:0?ooo`1c0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo04l0oooo
00@000000?ooo`09jPX02NX:0P0000060?ooo`80000000<0oooo00WZ2P3oool02@3oool200000003
00WZ2P3oool0oooo00T0oooo0P0000001@09jPX0oooo0?ooo`0000002NX:00@0oooo00<02NX:0?oo
o`3oool00`3oool00`0000002NX:00WZ2P060?ooo`0300000009jPX0oooo00D0oooo00<0000000WZ
2P3oool0203oool00`09jPX0oooo0?ooo`080?ooo`8000003P3oool00`09jPX0oooo0?ooo`0200WZ
2P030000003oool0oooo00D0oooo0P0000000`3oool0000000WZ2P0400WZ2P030?ooo`0000000000
00@0oooo0`00000200WZ2P`0oooo00<0000000WZ2P3oool04@3oool00`09jPX0oooo0?ooo`090?oo
o`80000000<0oooo00WZ2P3oool02`3oool00`0000002NX:00WZ2P030?ooo`0300WZ2P3oool0oooo
0780oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0C`3oool00`000000
2NX:0?ooo`0=0?ooo`0300WZ2P3oool0oooo00T0oooo00<0000000WZ2P3oool02`3oool00`000000
2NX:00WZ2P02000000<0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX00000000000070?ooo`80
00001@3oool3000000X0oooo00<02NX:0000003oool01`3oool00`0000002NX:0?ooo`0=0?ooo`03
00WZ2P3oool02NX:00L0oooo1009jPX0100000002NX:00WZ2P0000020?ooo`8000002@3oool20000
00030?ooo`09jPX0oooo00X0oooo0P00000A0?ooo`0300WZ2P000000oooo00h0oooo0P09jPX80?oo
o`0300WZ2P0000002NX:00D0oooo00<02NX:0?ooo`3oool0LP3oool00`000000oooo0?ooo`090?oo
o`002P3oool00`000000oooo0?ooo`1>0?ooo`0300000009jPX0oooo00@0oooo0P0000000`09jPX0
000000WZ2P0200WZ2P8000000P3oool00`09jPX0oooo0?ooo`080?ooo`80000000<02NX:0?ooo`3o
ool02@3oool20000000600WZ2P3oool0oooo0?ooo`0000002NX:103oool00`0000002NX:0?ooo`09
0?ooo`0300000009jPX0oooo00@0oooo00<0000000WZ2P0000002P3oool00`0000002NX:0?ooo`09
0?ooo`0300WZ2P3oool0oooo00X0oooo00<02NX:00000009jPX00P3oool2000000802NX:00<00000
00WZ2P3oool01@3oool00`09jPX0oooo0?ooo`0@0?ooo`802NX:2`3oool00`09jPX0oooo0?ooo`0>
0?ooo`8000004@3oool01009jPX0oooo0?ooo`3oool400WZ2P030?ooo`000000000000D0oooo00<0
2NX:0?ooo`3oool0LP3oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`1>
0?ooo`0300000009jPX0oooo00<0oooo0`09jPX300000080oooo1`09jPX;0?ooo`0300WZ2P3oool0
oooo00H0oooo0P09jPX300000080oooo00@02NX:000000000000oooo1@00000:0?ooo`8000001P3o
ool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00T0oooo00<02NX:0?ooo`3oool0203o
ool0100000002NX:0000000000020?ooo`802NX:00<0oooo0000000000001P3oool00`09jPX0oooo
0?ooo`0A0?ooo`80000000<02NX:0?ooo`3oool02@3oool00`09jPX000000?ooo`0<0?ooo`0300WZ
2P3oool0oooo0140oooo00D0000000WZ2P09jPX02NX:0?ooo`02000000<0oooo00<000000?ooo`3o
ool00`3oool00`09jPX0oooo0?ooo`1b0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000
003oool0oooo04h0oooo00<02NX:0000003oool00`09jPX<0?ooo`8000000P09jPX00`000000oooo
0?ooo`080?ooo`0300WZ2P3oool0oooo00D0oooo0P0000020?ooo`0300WZ2P3oool02NX:00@0oooo
0P0000000`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0
2`3oool00`09jPX0oooo0?ooo`090?ooo`0300000009jPX0oooo00P0oooo0P0000001009jPX0oooo
00WZ2P09jPX90?ooo`80000000<02NX:0?ooo`3oool0503oool00`09jPX0oooo0?ooo`080?ooo`80
000000<02NX:0?ooo`3oool02P3oool00`09jPX0oooo0?ooo`0A0?ooo`8000000P09jPX60?ooo`03
0000003oool0oooo00<0oooo00<02NX:0?ooo`3oool0LP3oool00`000000oooo0?ooo`090?ooo`00
2P3oool00`000000oooo0?ooo`1=0?ooo`@02NX:4@3oool2000000802NX:2@3oool00`0000002NX:
0?ooo`030?ooo`0300000009jPX0oooo00<0oooo00<0000000WZ2P3oool00P3oool200WZ2Q00oooo
00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`0=0?ooo`0300WZ2P3oool0oooo00P0oooo
00<0000000WZ2P3oool02@3oool300WZ2P030000003oool0oooo00P0oooo00<0000000WZ2P3oool0
5`3oool2000000T0oooo0P00000200WZ2PT0oooo00<02NX:0?ooo`3oool04P3oool01@09jPX00000
0000003oool02NX:00D0oooo00<000000?ooo`3oool00`3oool00`09jPX0oooo0?ooo`1b0?ooo`03
0000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo04`0oooo0P09jPX2000001<0oooo
00<02NX:0?ooo`3oool00`09jPX60?ooo`80000000@02NX:0?ooo`3oool0oooo0P0000040?ooo`80
2NX:0P3oool00`09jPX0oooo0?ooo`0?0?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0000003o
ool03P3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00D0oooo0P0000001009jPX0
oooo0000000000070?ooo`<02NX:6P3oool00`0000002NX:00WZ2P090?ooo`80000000<0oooo00WZ
2P3oool01`3oool00`09jPX0oooo0?ooo`0@0?ooo`802NX:00<000000?ooo`3oool00P3oool00`09
jPX0oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<02NX:0?ooo`3oool0LP3oool00`00
0000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`1:0?ooo`<02NX:0P3oool00`000000
oooo0?ooo`0B0?ooo`0500WZ2P3oool0oooo0?ooo`0000000P09jPX50?ooo`8000000`3oool01P09
jPX0oooo0?ooo`3oool0000000WZ2P8000000P09jPXB0?ooo`0300WZ2P3oool0oooo0080oooo00<0
2NX:0000003oool03P3oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo00D0oooo0`09
jPX90?ooo`0400WZ2P3oool00000000001/0oooo0P00000200WZ2P/0oooo0P09jPX60?ooo`0300WZ
2P3oool0oooo00h0oooo00<0000000WZ2P3oool00P0000040?ooo`0300000009jPX02NX:0080oooo
00<000000?ooo`3oool00P3oool00`09jPX0oooo0?ooo`1c0?ooo`030000003oool0oooo00T0oooo
000:0?ooo`030000003oool0oooo04P0oooo0P09jPX20?ooo`0400WZ2P3oool0oooo000001@0oooo
00@0000000WZ2P3oool0oooo0P0000000`3oool02NX:0?ooo`040?ooo`0400WZ2P3oool0oooo00WZ
2P<0oooo100000000`09jPX0oooo0?ooo`0A0?ooo`0300000009jPX0oooo0080oooo00<02NX:0?oo
o`3oool0403oool00`09jPX0oooo0?ooo`0:0?ooo`0300WZ2P000000oooo00<0oooo00@02NX:0?oo
o`09jPX02NX:1P3oool00`09jPX0000000WZ2P0S0?ooo`0300WZ2P000000000000X0oooo00H02NX:
0?ooo`3oool0oooo00000009jPXA0?ooo`8000001`3oool30000000300WZ2P3oool0000000@0oooo
00<02NX:0?ooo`3oool0L`3oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?oo
o`160?ooo`802NX:0`3oool01@09jPX0oooo0?ooo`3oool0000001@0oooo0P0000060?ooo`0300WZ
2P3oool0oooo0080oooo00@0000000WZ2P09jPX000000`3oool01P0000002NX:00WZ2P3oool00000
00WZ2Q80oooo0P0000030?ooo`0300WZ2P3oool0oooo0100oooo00<02NX:0000003oool02P3oool0
1009jPX000000?ooo`3oool200WZ2P040?ooo`09jPX0000000WZ2P80oooo00D02NX:00000009jPX0
2NX:0?ooo`02000002@0oooo00<0000000WZ2P09jPX02P3oool00`09jPX000000?ooo`0200000100
oooo00<02NX:0000003oool02@3oool2000000030?ooo`000000oooo00<0oooo00<02NX:0?ooo`3o
ool0L`3oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`140?ooo`802NX:
103oool00`09jPX0oooo0?ooo`020?ooo`030000003oool0oooo01@0oooo00<02NX:0?ooo`3oool0
103oool01P09jPX0oooo0?ooo`3oool0000000WZ2P8000000P3oool200WZ2P<0oooo00<0000000WZ
2P3oool04P3oool01009jPX0oooo0?ooo`09jPXC0?ooo`800000303oool300WZ2P80000000<0oooo
00WZ2P0000000P0000001009jPX0oooo00000000000[0?ooo`0300WZ2P3oool0oooo00L0oooo00@0
000000WZ2P3oool02NX:403oool3000000`0oooo00<02NX:0000003oool00`3oool00`09jPX0oooo
0?ooo`1c0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo0480oooo0P09
jPX60?ooo`0300WZ2P3oool0oooo0080oooo00<000000?ooo`3oool05@3oool00`09jPX0oooo0?oo
o`040?ooo`0600WZ2P3oool02NX:0?ooo`09jPX0oooo0P00000200WZ2PD0oooo00<02NX:0?ooo`3o
ool02`3oool300WZ2P80000000@0oooo00WZ2P3oool02NX:5@3oool00`09jPX0oooo0?ooo`090?oo
o`0600000009jPX000000000003oool000000P09jPX00`3oool000000000000_0?ooo`0300000009
jPX02NX:00P0oooo00<0000000WZ2P09jPX03`3oool00`09jPX000000000000=0?ooo`0300000009
jPX0oooo00<0oooo00<02NX:0?ooo`3oool0L`3oool00`000000oooo0?ooo`090?ooo`002P3oool0
0`000000oooo0?ooo`100?ooo`802NX:1`3oool00`09jPX0oooo0?ooo`030?ooo`030000003oool0
oooo01H0oooo00<02NX:0?ooo`3oool00`3oool0100000002NX:00WZ2P3oool200WZ2P<000001P3o
ool00`09jPX0oooo0?ooo`070?ooo`8000000P09jPX20?ooo`8000000`09jPX20000000400WZ2P00
00002NX:00WZ2Q00oooo00<0000000WZ2P3oool02P3oool00`09jPX0000000WZ2P0200WZ2P800000
00@02NX:0?ooo`0000000000;`3oool2000000040?ooo`09jPX02NX:00WZ2PD0oooo00<0000000WZ
2P3oool00P09jPX<0?ooo`0300WZ2P3oool0oooo00h0oooo0P0000040?ooo`0300WZ2P3oool0oooo
07<0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0?P3oool200WZ2PT0
oooo00<02NX:0?ooo`3oool00`3oool00`000000oooo0?ooo`0F0?ooo`0300000009jPX02NX:0080
oooo0`00000200WZ2P040?ooo`000000000000WZ2PL0oooo00<02NX:0?ooo`3oool01@3oool200WZ
2P<000001P3oool20000000300WZ2P000000oooo0080000000<0oooo00WZ2P3oool03P3oool20000
00X0oooo00<02NX:0?ooo`3oool00P09jPX20?ooo`0300WZ2P3oool0oooo00800000=03oool01000
00002NX:00WZ2P09jPX30?ooo`0500WZ2P3oool0oooo0?ooo`09jPX02P3oool;00WZ2PL0oooo00<0
2NX:0000003oool00`3oool00`09jPX0oooo0?ooo`1c0?ooo`030000003oool0oooo00T0oooo000:
0?oooe402NX:00<0000000WZ2P09jPX05`3oool2000000030?ooo`09jPX02NX:0080000000<02NX:
0000003oool00`09jPX00`0000002NX:00WZ2P0800WZ2P0300000009jPX02NX:00802NX:2`3oool2
0000000300WZ2P3oool0oooo00@0oooo0P09jPX>0?ooo`0300WZ2P000000oooo00D0oooo1009jPX0
1`0000002NX:0?ooo`09jPX0oooo00000009jPX00`3oool00`09jPX0oooo0?ooo`0b0?ooo`800000
0P3oool400WZ2P@0oooo00@02NX:00000009jPX02NX:103oool300WZ2P030?ooo`000000000000D0
oooo0P00000200WZ2PD0oooo00<02NX:0000003oool00`3oool00`09jPX0oooo0?ooo`1c0?ooo`03
0000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo03X0oooo0P09jPX;0?ooo`0300WZ
2P3oool0oooo00@0oooo0P0000000`3oool02NX:00WZ2P0G0?ooo`0500WZ2P3oool02NX:00000009
jPX00P0000000`09jPX0oooo00WZ2P02000000D0oooo00<0000000WZ2P3oool00P3oool2000000l0
oooo0P09jPX60?ooo`8000000P09jPX<0?ooo`80000000<0oooo00WZ2P09jPX00`09jPX0103oool0
2NX:0?ooo`3oool200000080oooo00<02NX:0000000000000`3oool00`09jPX0oooo0?ooo`0g0?oo
o`0300000009jPX0000000802NX:0P3oool200000080oooo1@09jPX00`000000oooo0?ooo`080?oo
o`80000000<0oooo00WZ2P3oool00P3oool00`09jPX0oooo000000040?ooo`0300WZ2P3oool0oooo
07<0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0>@3oool00`09jPX0
oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00D0oooo00@000000?ooo`00000000000P09jPXA0?oo
o`8000000`09jPX20000000300WZ2P000000oooo00<0oooo00<0000000WZ2P0000001@3oool00`00
00002NX:0?ooo`0B0?ooo`0300WZ2P3oool02NX:00X0oooo0P09jPX:0?ooo`0400000009jPX02NX:
0?ooo`80000000<0oooo00000009jPX0203oool01@09jPX0oooo0?ooo`3oool02NX:03X0oooo1000
00000`3oool00000000000050?ooo`80000000<0oooo0000000000003@3oool01`0000002NX:0000
003oool02NX:0?ooo`000000103oool00`09jPX0oooo0?ooo`1c0?ooo`030000003oool0oooo00T0
oooo000:0?ooo`030000003oool0oooo03L0oooo0P09jPX=0?ooo`0300WZ2P3oool0oooo00H0oooo
00<000000?ooo`3oool00`3oool00`09jPX0000000WZ2P0400WZ2PL0oooo00<0000000WZ2P09jPX0
0P09jPX30?ooo`<0000000<02NX:0?ooo`3oool00P3oool01009jPX0000000000009jPX50?ooo`03
00WZ2P3oool0oooo0140oooo00<02NX:0?ooo`09jPX02`3oool00`0000002NX:00WZ2P080?ooo`03
00000009jPX0oooo00@0oooo00<0000000WZ2P3oool01P3oool300000080oooo00<02NX:0?ooo`3o
ool0>@3oool01P09jPX0oooo0?ooo`3oool0000000WZ2P80oooo00<0000000WZ2P09jPX04P3oool3
000000040?ooo`09jPX0oooo000000@0oooo00<02NX:0?ooo`3oool0L`3oool00`000000oooo0?oo
o`090?ooo`002P3oool00`000000oooo0?ooo`0e0?ooo`802NX:3P3oool00`09jPX0oooo0?ooo`06
0?ooo`80000000<0oooo00WZ2P09jPX00P09jPX00`3oool02NX:00WZ2P040?ooo`0300WZ2P000000
2NX:00@02NX:0P0000000`09jPX0oooo0?ooo`050?ooo`8000000`3oool00`09jPX0000000000002
0?ooo`0500WZ2P3oool0oooo0?ooo`09jPX0503oool200WZ2P`0oooo0P0000000`3oool0000000WZ
2P0800WZ2P<0oooo0P0000000`09jPX0oooo0?ooo`060?ooo`80000000D02NX:0000003oool02NX:
0000000j0?ooo`0300WZ2P3oool0oooo00<0oooo0`09jPX00`000000oooo0?ooo`0C0?ooo`050000
0009jPX0oooo0?ooo`000000103oool00`09jPX0oooo0?ooo`1c0?ooo`030000003oool0oooo00T0
oooo000:0?oooe402NX:00<0000000WZ2P09jPX01P3oool0100000002NX:00WZ2P09jPX20?ooo`80
00000P3oool00`09jPX0oooo0?ooo`080?ooo`0400WZ2P3oool0oooo00WZ2P80oooo00<02NX:0?oo
o`09jPX00`3oool00`09jPX0oooo00WZ2P0C0?ooo`0400000009jPX0oooo00WZ2Pl0oooo0`000006
0?ooo`0600WZ2P3oool0oooo0?ooo`0000002NX:2@3oool01@09jPX0oooo00000009jPX0oooo0080
0000>@3oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P0000002NX:01L0oooo0P0000000`09jPX0
oooo000000040?ooo`0300WZ2P3oool0oooo07<0oooo00<000000?ooo`3oool02@3oool000X0oooo
00<000000?ooo`3oool0<@3oool200WZ2Q40oooo00<02NX:0?ooo`3oool0203oool00`000000oooo
0?ooo`050?ooo`8000000P3oool400WZ2P0400000009jPX0oooo0?ooo`802NX:00@0000000WZ2P00
000000000P3oool00`09jPX0oooo0?ooo`020?ooo`802NX:00<0oooo00000009jPX0103oool200WZ
2Q<0oooo0P0000000`3oool02NX:0?ooo`0H0?ooo`0500WZ2P3oool0oooo0?ooo`09jPX02@3oool0
1009jPX0oooo0?ooo`3oool3000003T0oooo00<02NX:0?ooo`3oool00P0000001009jPX0oooo0?oo
o`00000200WZ2QD0oooo00D02NX:0?ooo`3oool02NX:000000040?ooo`0300WZ2P3oool0oooo07<0
oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0;`3oool200WZ2Q<0oooo
00<02NX:0?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`8000000P09jPX2000000802NX:
0P3oool20000000400WZ2P000000000000WZ2PD0oooo0P09jPX3000000@0oooo00<0000000WZ2P3o
ool04P3oool01009jPX0000000000009jPXI0?ooo`0400WZ2P3oool0oooo00WZ2PX0oooo00@02NX:
0?ooo`3oool0oooo0P00000j0?ooo`0500WZ2P3oool0000000000009jPX00`3oool2000000030?oo
o`09jPX0oooo01<0oooo00D02NX:0?ooo`3oool0000000WZ2P040?ooo`0300WZ2P3oool0oooo07<0
oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0;@3oool200WZ2Q@0oooo
00<02NX:0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`0400000009jPX02NX:0?ooo`80
000000<02NX:0?ooo`3oool0103oool0100000002NX:0000000000040?ooo`0300WZ2P0000000000
00802NX:103oool200000180oooo00D02NX:0?ooo`3oool0000000WZ2P0H0?ooo`0500000009jPX0
oooo0?ooo`09jPX02@3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P0000002NX:03P0oooo00D0
000000WZ2P3oool0000000WZ2P080?ooo`802NX:4@3oool01009jPX0oooo0?ooo`09jPX2000000@0
oooo00<02NX:0?ooo`3oool0L`3oool00`000000oooo0?ooo`090?ooo`002P3ooomA00WZ2P050000
0009jPX02NX:00WZ2P0000002009jPX00`000000oooo0?ooo`030?ooo`0300000009jPX0oooo00@0
oooo00@02NX:0?ooo`0000002NX:0`3oool01P09jPX0oooo0?ooo`3oool0000000WZ2P<0oooo00@0
2NX:0?ooo`3oool02NX:403oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo01H0oooo
0P0000000`3oool02NX:0?ooo`080?ooo`0300000009jPX0oooo00<0oooo00<02NX:00000009jPX0
>03oool20000000300WZ2P3oool0oooo00X0oooo00<02NX:0?ooo`3oool03P3oool00`09jPX0oooo
00WZ2P020?ooo`050000003oool0oooo0?ooo`09jPX0MP3oool00`000000oooo0?ooo`090?ooo`00
2P3oool00`000000oooo0?ooo`0Y0?ooo`802NX:5`3oool00`09jPX0oooo0?ooo`090?ooo`800000
0P3oool2000000<0oooo0`09jPX2000000D0oooo0P0000001@09jPX0oooo0?ooo`0000002NX:00<0
oooo00@02NX:0000000000002NX:103oool3000000030?ooo`09jPX0oooo00<0oooo00<02NX:0000
003oool0303oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo01L0oooo0P09jPX80?oo
o`<000000P3oool00`0000002NX:0?ooo`020?ooo`0300WZ2P3oool0oooo03H0oooo00<02NX:0000
003oool02`3oool0100000002NX:00WZ2P09jPX<0?ooo`0400WZ2P0000002NX:00000080oooo00D0
00000?ooo`3oool0oooo00WZ2P1f0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000003o
ool0oooo02L0oooo0P09jPXH0?ooo`0300WZ2P3oool0oooo00/0oooo00<000000?ooo`3oool00`3o
ool00`0000002NX:00000003000000T0oooo100000040?ooo`0300000009jPX0oooo00@0oooo00@0
2NX:0000000000002NX:1@3oool2000000`0oooo00<02NX:0?ooo`3oool01@3oool00`09jPX0oooo
0?ooo`0F0?ooo`80000000<02NX:0?ooo`3oool01P3oool2000000<0oooo0P0000040?ooo`0300WZ
2P3oool0oooo03D0oooo00<0000000WZ2P3oool02`3oool200000080oooo00@0000000WZ2P09jPX0
2NX:203oool400000080oooo00D000000?ooo`3oool0oooo00WZ2P1f0?ooo`030000003oool0oooo
00T0oooo000:0?ooo`030000003oool0oooo02D0oooo0P09jPXJ0?ooo`0300WZ2P3oool0oooo00/0
oooo00H000000?ooo`3oool0oooo00000009jPX3000000`0oooo0`0000060?ooo`0300WZ2P3oool0
oooo0080oooo00D0000000WZ2P0000002NX:000000050?ooo`8000002P3oool00`0000002NX:0?oo
o`070?ooo`0300WZ2P3oool0oooo01H0oooo00<0000000WZ2P3oool02@3oool01@09jPX0oooo0?oo
o`3oool02NX:00D0oooo0P00000e0?ooo`0300WZ2P3oool02NX:0100oooo0P0000020?ooo`030000
0009jPX02NX:00D0oooo0P09jPX40?ooo`050000003oool0oooo0?ooo`09jPX0MP3oool00`000000
oooo0?ooo`090?ooo`002P3ooomA00WZ2P0300000009jPX02NX:00<02NX:0P00000>0?ooo`040000
0009jPX00000000000@0oooo0P09jPX40?ooo`0400000009jPX0000000WZ2PH0oooo00<02NX:0000
003oool01`3oool0100000002NX:0000000000080?ooo`0300WZ2P3oool0oooo01L0oooo0P09jPX8
0?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool00`3oool00`0000002NX:0?ooo`0c
0?ooo`0400000009jPX0000000WZ2Q@0oooo0P0000000`3oool02NX:0?ooo`030?ooo`802NX:103o
ool01@000000oooo0?ooo`3oool02NX:07H0oooo00<000000?ooo`3oool02@3oool000X0oooo00<0
00000?ooo`3oool08@3oool200WZ2Q`0oooo00<02NX:0?ooo`3oool0303oool2000000L0oooo0P00
00020?ooo`0500WZ2P0000002NX:00WZ2P0000000`09jPX01@3oool02NX:0?ooo`0000002NX:00<0
oooo00L02NX:0?ooo`3oool02NX:0000003oool02NX:0080000000<0oooo00WZ2P3oool01@3oool2
000000D0oooo00<02NX:00000009jPX00P00000;0?ooo`0300WZ2P3oool0oooo01D0oooo00<02NX:
0?ooo`09jPX0203oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00D0oooo00<02NX:
0?ooo`3oool0<@3oool4000001P0oooo0P0000020?ooo`0300WZ2P000000oooo00<0oooo00D00000
0?ooo`3oool0oooo00WZ2P1f0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0
oooo01l0oooo0P09jPXN0?ooo`0300WZ2P3oool0oooo00d0oooo00<000000?ooo`3oool0103oool0
0`09jPX0000000WZ2P0200WZ2P040?ooo`00000000000?ooo`@000000P09jPX30?ooo`0300WZ2P3o
ool02NX:00<0oooo00<02NX:00000009jPX00P0000030?ooo`0300WZ2P3oool0oooo00<0oooo00<0
2NX:0?ooo`3oool01009jPX00`3oool000000000000<0?ooo`0300000009jPX0oooo01H0oooo00<0
2NX:00000009jPX0203oool01@09jPX0oooo0?ooo`0000002NX:00P0oooo00<0000000WZ2P3oool0
<@3oool01@09jPX0oooo0?ooo`0000002NX:01L0oooo00@0000000WZ2P3oool0oooo0P0000040?oo
o`050000003oool0oooo0?ooo`09jPX0MP3oool00`000000oooo0?ooo`090?ooo`002P3oool00`00
0000oooo0?ooo`0M0?ooo`802NX:7`3oool00`09jPX0oooo0?ooo`0>0?ooo`040000003oool0oooo
0?ooo`<02NX:2`3oool2000000802NX:0P3oool2000000<02NX:0P000000103oool02NX:00000000
00030?ooo`0300000009jPX0oooo00@0oooo00@0000000WZ2P09jPX0oooo0P00000@0?ooo`030000
0009jPX0oooo01H0oooo0`0000000`09jPX0oooo0?ooo`040?ooo`0400WZ2P3oool0oooo0?ooo`80
0000203oool00`0000002NX:0?ooo`0`0?ooo`0400WZ2P3oool0oooo0?ooo`800000603oool01009
jPX0oooo00000009jPX50?ooo`050000003oool0oooo0?ooo`09jPX0MP3oool00`000000oooo0?oo
o`090?ooo`002P3oool00`000000oooo0?ooo`0K0?ooo`802NX:803oool00`09jPX0oooo0?ooo`0>
0?ooo`8000000`09jPX>0?ooo`0500000009jPX0oooo0?ooo`09jPX00P0000001009jPX000000000
003oool500WZ2P@0oooo0P0000050?ooo`0300000009jPX0oooo01D0oooo00<02NX:0?ooo`3oool0
503oool01009jPX000000000000000050?ooo`0300000009jPX0oooo0080oooo00<02NX:0?ooo`3o
ool0203oool00`09jPX0oooo0?ooo`0_0?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3o
ool05`3oool200WZ2P030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo00WZ2P1f0?oo
o`030000003oool0oooo00T0oooo000:0?oooe402NX:00<0000000WZ2P3oool00P00000?0?ooo`07
00WZ2P3oool0oooo00000009jPX0oooo00WZ2P050?ooo`@02NX:0`3oool2000000<0oooo0P000002
00WZ2QH0oooo00<02NX:0?ooo`3oool0503oool01009jPX0oooo0?ooo`09jPX50?ooo`8000000P3o
ool00`09jPX0oooo0?ooo`090?ooo`800000;`3oool00`09jPX000000?ooo`030?ooo`0300WZ2P3o
ool0oooo01P0oooo00<02NX:0?ooo`3oool0103oool01@000000oooo0?ooo`3oool02NX:07H0oooo
00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool05`3oool200WZ2R<0oooo00<0
2NX:0?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`0300WZ2P3oool0oooo00<0oooo00<0
2NX:0?ooo`3oool00`3oool200WZ2P030?ooo`0000002NX:00802NX:00<0oooo00000009jPX00`09
jPX0100000002NX:0?ooo`09jPXG0?ooo`0300WZ2P3oool0oooo0180oooo00<02NX:0?ooo`3oool0
0P3oool00`09jPX0oooo0?ooo`030?ooo`0400WZ2P3oool0oooo00WZ2P/0oooo00<0000000WZ2P3o
ool0;@3oool00`09jPX00000000000040?ooo`0300WZ2P3oool0oooo01P0oooo00<02NX:00000000
0000103oool01@000000oooo0?ooo`3oool02NX:07H0oooo00<000000?ooo`3oool02@3oool000X0
oooo00<000000?ooo`3oool05@3oool200WZ2RD0oooo00<02NX:0?ooo`3oool0403oool00`000000
oooo0?ooo`0?0?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0000000000000P00000200WZ2P03
0?ooo`0000002NX:00H02NX:0`3oool200000080oooo00<02NX:0?ooo`3oool0503oool00`09jPX0
oooo0?ooo`0B0?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool00P3oool01009jPX0
oooo0?ooo`09jPX=0?ooo`0300WZ2P3oool0oooo02/0oooo00<02NX:0?ooo`3oool01P3oool00`09
jPX0oooo0?ooo`0E0?ooo`0500000009jPX0oooo00000009jPX0103oool01@000000oooo0?ooo`3o
ool02NX:07H0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool04`3oool2
00WZ2RH0oooo00<02NX:0?ooo`3oool04@3oool00`000000oooo0?ooo`0200WZ2P0400000009jPX0
2NX:00WZ2PL0oooo0P0000002@09jPX0oooo0?ooo`3oool0000000WZ2P3oool0000000WZ2P040000
000400WZ2P000000000000WZ2P80000000@0oooo00WZ2P0000002NX:1@3oool00`0000002NX:0?oo
o`0E0?ooo`0300WZ2P3oool0oooo0140oooo00<02NX:0?ooo`3oool00`3oool00`09jPX000000?oo
o`020?ooo`0300WZ2P0000002NX:00l0oooo00<02NX:0?ooo`3oool0:03oool00`0000002NX:0?oo
o`080?ooo`0300WZ2P3oool0oooo01D0oooo00D0000000WZ2P3oool0oooo00WZ2P040?ooo`050000
003oool0oooo0?ooo`09jPX0MP3oool00`000000oooo0?ooo`090?ooo`002P3ooomA00WZ2P040000
0009jPX02NX:00WZ2P80oooo0P0000000`3oool0000000WZ2P0200WZ2P@0oooo00<0000000WZ2P3o
ool00`3oool2000000@0oooo0P0000000`09jPX0oooo0?ooo`020?ooo`0600WZ2P3oool0oooo0?oo
o`0000002NX:1@3oool2000001H0oooo00<0000000WZ2P3oool04@3oool00`09jPX0oooo0?ooo`03
0?ooo`8000000`3oool00`09jPX000000000000@0?ooo`0300WZ2P3oool0oooo02L0oooo0P000009
0?ooo`0300WZ2P3oool0oooo01D0oooo0P09jPX30?ooo`0500WZ2P3oool0oooo0?ooo`0000000`3o
ool00`09jPX0oooo0?ooo`1d0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0
oooo0100oooo00<02NX:0?ooo`3oool09`3oool00`09jPX0oooo0?ooo`0A0?ooo`8000001`3oool2
00000080oooo00D0000000WZ2P09jPX0000000WZ2P050?ooo`0600WZ2P3oool0oooo0?ooo`000000
2NX:0P0000050?ooo`0300WZ2P3oool0oooo0080oooo0P09jPX60?ooo`0300WZ2P000000oooo00H0
oooo0P09jPX00`0000002NX:0000000200WZ2PH0oooo00<0000000WZ2P3oool04@3oool00`09jPX0
oooo0?ooo`030?ooo`80000000@0oooo00000009jPX0oooo0P00000@0?ooo`0300WZ2P3oool0oooo
02D0oooo0P09jPX2000000P0oooo00<0000000WZ2P3oool05@3oool00`09jPX0oooo00WZ2P030?oo
o`0500WZ2P3oool0oooo0?ooo`0000000`3oool00`09jPX0oooo0?ooo`1d0?ooo`030000003oool0
oooo00T0oooo000:0?ooo`030000003oool0oooo00h0oooo0P09jPXY0?ooo`0300WZ2P3oool0oooo
01<0oooo00<000000?ooo`3oool02@3oool2000000030?ooo`000000000000@0oooo00@02NX:0?oo
o`09jPX02NX:0P0000000`09jPX0oooo0?ooo`050?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:
00000009jPX0103oool20000000500WZ2P3oool02NX:00WZ2P0000000`09jPX20?ooo`@0000000@0
oooo00WZ2P09jPX02NX:1@3oool00`09jPX0oooo0?ooo`0=0?ooo`0300000009jPX0oooo00D0oooo
00D02NX:0000000000002NX:0000000300WZ2Q40oooo0P00000T0?ooo`0300WZ2P3oool0oooo00X0
oooo0P00000F0?ooo`0300WZ2P3oool02NX:00<0oooo00D02NX:0?ooo`3oool0oooo000000030?oo
o`0300WZ2P3oool0oooo07@0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3o
ool0303oool200WZ2RX0oooo00<02NX:0?ooo`3oool0503oool00`000000oooo0?ooo`0;0?ooo`03
00WZ2P3oool02NX:00802NX:00@0oooo00WZ2P09jPX02NX:0P3oool00`0000002NX:0?ooo`060?oo
o`0300000009jPX0oooo00<0oooo00@02NX:0?ooo`3oool02NX:0P00000500WZ2P80oooo0P00000<
0?ooo`802NX:0P0000000`3oool02NX:0?ooo`0>0?ooo`0300WZ2P000000oooo00D0oooo00@02NX:
00000009jPX0oooo0P0000020?ooo`<02NX:3P3oool00`0000002NX:0?ooo`0Q0?ooo`0300000009
jPX0oooo00`0oooo00<02NX:0?ooo`3oool04P3oool20000000400WZ2P3oool0oooo00WZ2P@0oooo
00@02NX:0000003oool000000`3oool00`09jPX0oooo0?ooo`1d0?ooo`030000003oool0oooo00T0
oooo000:0?oooe402NX:00D0000000WZ2P09jPX02NX:0000000600WZ2P<0oooo00<02NX:0?ooo`3o
ool01`09jPX30?ooo`0300WZ2P3oool0oooo00D0oooo00<0000000WZ2P3oool00P3oool00`09jPX0
oooo0?ooo`020?ooo`802NX:103oool00`09jPX0oooo0?ooo`0@0?ooo`0300000009jPX02NX:0080
2NX:3@3oool00`09jPX0oooo0?ooo`030?ooo`802NX:0`0000000`3oool02NX:00WZ2P050?ooo`03
00000009jPX02NX:00d0oooo00<02NX:0?ooo`3oool07@3oool300WZ2P800000303oool00`09jPX0
oooo0?ooo`0C0?ooo`0300000009jPX0oooo0080oooo00<02NX:0?ooo`3oool00P3oool01009jPX0
00000?ooo`0000020?ooo`0300WZ2P3oool0oooo07D0oooo00<000000?ooo`3oool02@3oool000X0
oooo00<000000?ooo`3oool0203oool200WZ2Rd0oooo00<02NX:0?ooo`3oool0503oool300000003
0?ooo`0000000000008000000`3oool00`09jPX0000000WZ2P0300WZ2P80oooo00<0000000WZ2P00
00000P3oool300WZ2PT0oooo00D02NX:0?ooo`3oool0oooo00WZ2P030?ooo`0300WZ2P3oool02NX:
00@0oooo00<02NX:0?ooo`3oool04`3oool00`0000002NX:00WZ2P0200WZ2PT0oooo00<02NX:0?oo
o`3oool00P3oool0100000002NX:0?ooo`3oool200000080oooo0P09jPX50?ooo`80000000<0oooo
00WZ2P09jPX02`3oool00`09jPX0oooo0?ooo`0K0?ooo`802NX:4@3oool00`09jPX0oooo0?ooo`0D
0?ooo`0500WZ2P3oool0oooo00000009jPX01@3oool00`09jPX0oooo000000020?ooo`0300WZ2P3o
ool0oooo07D0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool01P3oool2
00WZ2Rl0oooo00<02NX:0?ooo`3oool05@3oool00`000000oooo0?ooo`070?ooo`0300000009jPX0
000000D0oooo0`0000030?ooo`0300WZ2P0000002NX:008000001@3oool02@09jPX0oooo0?ooo`3o
ool0000000WZ2P3oool0000000WZ2P030?ooo`0500WZ2P000000oooo0?ooo`09jPX05P3oool20000
0080oooo0P09jPX50?ooo`0400000009jPX0oooo0?ooo`<02NX:0P0000030?ooo`0500WZ2P3oool0
2NX:0?ooo`09jPX02P3oool200WZ2PT0oooo00<02NX:0?ooo`3oool06@3oool00`0000002NX:0?oo
o`0A0?ooo`0300WZ2P3oool0oooo01@0oooo00@02NX:0?ooo`3oool0oooo0P0000040?ooo`040000
0009jPX0oooo00000080oooo00<02NX:0?ooo`3oool0M@3oool00`000000oooo0?ooo`090?ooo`00
2P3oool00`000000oooo0?ooo`040?ooo`802NX:<03oool00`09jPX0oooo0?ooo`0F0?ooo`030000
003oool0oooo00L0oooo0P0000040?ooo`802NX:0P0000030?ooo`0500WZ2P3oool0oooo0?ooo`00
00000P09jPX200000080oooo00@02NX:0?ooo`3oool0oooo0P0000000`09jPX00000000000030?oo
o`0600WZ2P000000oooo0?ooo`0000002NX:5@3oool00`0000002NX:0?ooo`030?ooo`0600000009
jPX02NX:00WZ2P3oool000000`09jPX70?ooo`0300WZ2P3oool0oooo00802NX:303oool00`000000
2NX:0?ooo`080?ooo`0300WZ2P3oool0oooo01L0oooo00<02NX:0000000000004P3oool00`09jPX0
oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool00P3oool010000000
2NX:0?ooo`0000020?ooo`0300WZ2P3oool0oooo07D0oooo00<000000?ooo`3oool02@3oool000X0
oooo00<000000?ooo`3oool00P3oool200WZ2S40oooo00<02NX:0?ooo`3oool05P3oool2000000T0
oooo00<02NX:0?ooo`3oool00P3oool00`09jPX000000?ooo`030?ooo`0300000009jPX0oooo00H0
oooo00L0000000WZ2P09jPX0oooo00WZ2P000000oooo00<02NX:1`3oool00`09jPX0oooo0?ooo`02
000001H0oooo00<02NX:0?ooo`3oool00P3oool2000000030?ooo`0000002NX:00802NX:203oool0
1P0000002NX:0?ooo`3oool0000000WZ2P`0oooo0P00000200WZ2PL0oooo0P09jPX2000000P02NX:
2P3oool200WZ2P0300000009jPX0oooo0180oooo00<0000000WZ2P3oool05@3oool00`09jPX0oooo
0?ooo`030?ooo`0300WZ2P3oool0oooo00@0oooo00D02NX:0000003oool0oooo00WZ2P1g0?ooo`03
0000003oool0oooo00T0oooo000:0?oooe402NX:00<0000000WZ2P09jPX00P09jPX00`3oool00000
000000030?ooo`0500WZ2P3oool0oooo0?ooo`09jPX00P0000040?ooo`800000203oool01P000000
2NX:00WZ2P09jPX0000000WZ2P80oooo00<02NX:0?ooo`3oool01P3oool01@09jPX0oooo0?ooo`3o
ool02NX:01D0oooo00<02NX:0?ooo`3oool01@3oool0100000002NX:0000000000080?ooo`040000
0009jPX0000000WZ2P8000003P3oool3000000802NX:00<0000000WZ2P09jPX00P000000103oool0
00000000000000020?ooo`8000000`3oool200WZ2P0500000009jPX02NX:00WZ2P0000000`09jPX2
0?ooo`8000004`3oool2000001D0oooo00<02NX:0000003oool01@3oool00`09jPX0oooo0?ooo`03
0?ooo`0500WZ2P000000oooo0?ooo`09jPX0M`3oool00`000000oooo0?ooo`090?ooo`002P3oool0
0`0000002NX:00WZ2P0d0?ooo`0300WZ2P3oool0oooo01P0oooo00H000000?ooo`3oool0oooo00WZ
2P00000200WZ2P0300000009jPX0oooo0080oooo00<02NX:0?ooo`3oool01@3oool00`09jPX0oooo
0?ooo`060?ooo`802NX:00<0oooo00WZ2P0000000P0000000`3oool02NX:0?ooo`090?ooo`0400WZ
2P000000000000WZ2QH0oooo00<02NX:0?ooo`3oool01@3oool00`09jPX0oooo0?ooo`090?ooo`04
00WZ2P000000000000WZ2Q40oooo0P0000001P3oool000000000003oool0000000WZ2Pd0oooo0P00
00020?ooo`8000006P3oool00`09jPX0oooo0?ooo`0C0?ooo`8000001P3oool00`09jPX0oooo0?oo
o`030?ooo`0500WZ2P000000oooo0?ooo`09jPX0M`3oool00`000000oooo0?ooo`090?ooo`002@3o
ool2000003H0oooo00<02NX:0?ooo`3oool0603oool00`000000oooo0?ooo`020?ooo`80000000H0
oooo0000000000002NX:00000009jPX80?ooo`0300WZ2P3oool0oooo00@0oooo0P09jPX30?ooo`06
00WZ2P3oool0000000WZ2P3oool02NX:2`3oool00`09jPX000000000000F0?ooo`0300WZ2P3oool0
oooo0080oooo0P0000000`09jPX0oooo0?ooo`090?ooo`0400WZ2P000000000000WZ2QT0oooo00<0
2NX:0?ooo`3oool0:P3oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P3oool0oooo00D0oooo00<0
000000WZ2P3oool0103oool01@0000002NX:0?ooo`3oool02NX:07L0oooo00<000000?ooo`3oool0
2@3oool000T0oooo0P00000e0?ooo`0300WZ2P3oool0oooo01T0oooo0`0000040?ooo`0400000009
jPX02NX:00WZ2P8000001P09jPX00`3oool02NX:0?ooo`040?ooo`0300000009jPX0oooo00@0oooo
00@02NX:0?ooo`00000000000P09jPX<0?ooo`0300000009jPX02NX:01D0oooo00<02NX:0?ooo`3o
ool00P3oool00`0000002NX:0?ooo`0:0?ooo`0400000009jPX02NX:00WZ2QX0oooo00<02NX:0?oo
o`3oool0:@3oool00`0000002NX:0?ooo`0C0?ooo`0300000009jPX0oooo00H0oooo0P0000050?oo
o`0500000009jPX0oooo0?ooo`09jPX0M`3oool00`000000oooo0?ooo`090?ooo`002P3ooomA00WZ
2P0500000009jPX0000000WZ2P0000000`09jPX00`0000002NX:000000020?ooo`H0000000<02NX:
00000009jPX00P00000300WZ2P800000103oool00`09jPX0oooo0?ooo`020?ooo`0400000009jPX0
000000WZ2PX0oooo0P0000000`3oool02NX:0?ooo`0D0?ooo`0300WZ2P3oool0oooo0080oooo00<0
2NX:0?ooo`3oool02@3oool20000000300WZ2P000000oooo01X0oooo00<02NX:0?ooo`3oool0:03o
ool2000001@0oooo0P0000080?ooo`0300WZ2P3oool0oooo00@0oooo00@02NX:0?ooo`3oool02NX:
M`3oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`0b0?ooo`0300WZ2P3o
ool0oooo01T0oooo0P0000020?ooo`80000000<02NX:0?ooo`09jPX02P3oool3000000802NX:2@3o
ool00`09jPX0oooo0?ooo`030?ooo`80000000<0oooo00WZ2P3oool01`3oool00`0000002NX:0?oo
o`020?ooo`0300WZ2P3oool0oooo0140oooo00<0000000WZ2P3oool00P3oool00`09jPX000000?oo
o`0:0?ooo`0400WZ2P0000000000000001X0oooo0P00000[0?ooo`0300WZ2P3oool0oooo0140oooo
00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`040?ooo`0400WZ2P3oool0oooo00WZ2WL0
oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0<@3oool00`09jPX0oooo
0?ooo`0K0?ooo`070000003oool0oooo00000009jPX0oooo00WZ2P0;0?ooo`0400000009jPX00000
00WZ2PP0oooo0P0000000`09jPX0oooo0?ooo`030?ooo`0400WZ2P3oool0oooo0?ooo`802NX:1P3o
ool00`0000002NX:0?ooo`030?ooo`0300WZ2P3oool0oooo0100oooo00@0000000WZ2P3oool0oooo
0`00000:0?ooo`<02NX:703oool00`0000002NX:0?ooo`0Y0?ooo`0300000009jPX0oooo0100oooo
00<0000000WZ2P3oool02`3oool00`09jPX0oooo0?ooo`030?ooo`0400WZ2P3oool0oooo00WZ2WL0
oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0<03oool00`09jPX0oooo
0?ooo`0L0?ooo`0300000009jPX02NX:00<0000000<02NX:0?ooo`3oool02P3oool01009jPX0oooo
0?ooo`09jPX70?ooo`0300000009jPX0oooo00D0oooo00<02NX:0?ooo`3oool00P3oool00`000000
2NX:00WZ2P050?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0403oool00`09jPX0
oooo0?ooo`0200WZ2P/0oooo0P09jPXN0?ooo`0300WZ2P3oool0oooo02P0oooo0P0000000`09jPX0
oooo0?ooo`0>0?ooo`800000303oool00`09jPX0oooo0?ooo`030?ooo`0400WZ2P3oool0oooo00WZ
2WL0oooo00<000000?ooo`3oool02@3oool000X0ooooD@09jPX00`0000002NX:000000020?ooo`03
00000009jPX0oooo00/0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`050?ooo`03
00WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00P3oool30000000500WZ2P3oool0oooo0000
0009jPX01P3oool0100000002NX:00WZ2P09jPX@0?ooo`0300000009jPX0oooo00X0oooo00@00000
00WZ2P3oool02NX:7P3oool00`09jPX0oooo0?ooo`0Y0?ooo`800000403oool00`09jPX0oooo0?oo
o`0;0?ooo`0300WZ2P3oool0oooo00<0oooo00@02NX:0?ooo`3oool02NX:M`3oool00`000000oooo
0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`0_0?ooo`0300WZ2P3oool0oooo01`0oooo0`00
00020?ooo`800000303oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo00@0oooo00<0
2NX:0?ooo`3oool01@3oool00`09jPX000000?ooo`040?ooo`80000000@02NX:0?ooo`0000000000
1P3oool2000000030?ooo`0000002NX:00802NX:2P3oool2000000030?ooo`0000002NX:00802NX:
00<0000000WZ2P09jPX00P09jPX30?ooo`<0000000<02NX:0?ooo`3oool07P3oool00`09jPX0oooo
0?ooo`0Y0?ooo`0300WZ2P3oool0oooo00h0oooo00<02NX:0?ooo`3oool02P3oool00`0000002NX:
0?ooo`030?ooo`0500000009jPX0oooo0?ooo`09jPX0M@3oool00`09jPX000000000000;0?ooo`00
2P3oool00`000000oooo0?ooo`0_0?ooo`0300WZ2P3oool0oooo01d0oooo00@000000?ooo`3oool0
oooo0P00000:0?ooo`0300000009jPX0oooo00D0oooo0P0000040?ooo`0300WZ2P3oool0oooo00D0
oooo0P0000080?ooo`0300WZ2P3oool02NX:00T0oooo0P0000000`3oool0000000WZ2P0300WZ2PD0
oooo00<02NX:00000009jPX00P09jPX2000000030?ooo`000000000000<0oooo1009jPX00`000000
2NX:00WZ2P0P0?ooo`0300WZ2P3oool0oooo02X0oooo00<02NX:0?ooo`3oool0303oool00`09jPX0
oooo0?ooo`0;0?ooo`800000103oool01@0000002NX:0?ooo`3oool02NX:0780oooo0`09jPX00`3o
ool000000000000;0?ooo`002P3oool00`000000oooo0?ooo`0^0?ooo`0300WZ2P3oool0oooo01h0
oooo00@000000?ooo`0000002NX:303oool2000000H0oooo00@0000000WZ2P09jPX0oooo0P000000
0`09jPX0oooo0?ooo`040?ooo`0300000009jPX0oooo00P0oooo00<0000000WZ2P3oool0303oool2
000000<0oooo00<02NX:0000000000000P09jPX30?ooo`0300WZ2P000000000000L0oooo00<02NX:
0000000000000`000000103oool0000000000000000M0?ooo`0300WZ2P3oool0oooo02X0oooo00<0
2NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`0<0?ooo`0300WZ2P3oool0oooo00@0oooo00<0
2NX:0?ooo`09jPX0K`3oool400WZ2PD0oooo00<000000?ooo`3oool02@3oool000X0oooo00<00000
0?ooo`3oool0;@3oool00`09jPX0oooo0?ooo`0N0?ooo`D000002`3oool00`09jPX0oooo0?ooo`09
0?ooo`0300WZ2P0000002NX:00L0oooo00<0000000WZ2P3oool0203oool20000000300WZ2P3oool0
oooo0100oooo0`0000030?ooo`0300WZ2P3oool02NX:00L0oooo00H02NX:0?ooo`00000000000?oo
o`09jPX20?ooo`0300000009jPX0000000802NX:703oool00`09jPX0oooo0?ooo`0X0?ooo`030000
0009jPX0oooo00`0oooo00<02NX:0?ooo`3oool0303oool00`09jPX000000?ooo`040?ooo`0300WZ
2P3oool02NX:06`0oooo0`09jPX90?ooo`030000003oool0oooo00T0oooo000:0?oooe402NX:00@0
000000WZ2P00000000002@3oool20000000300WZ2P3oool0oooo00/0oooo00@0000000WZ2P09jPX0
2NX:1P3oool00`09jPX0oooo0?ooo`070?ooo`0400000009jPX0oooo00WZ2QH0oooo00L02NX:0?oo
o`3oool0000000WZ2P3oool0000000802NX:00@0000000WZ2P3oool02NX:0`3oool00`09jPX0oooo
0?ooo`020?ooo`<000000P09jPXI0?ooo`0300000009jPX0oooo02T0oooo0P00000;0?ooo`030000
0009jPX0oooo00h0oooo0P0000050?ooo`0300WZ2P3oool02NX:06T0oooo0`09jPX<0?ooo`030000
003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo02`0oooo00<02NX:0?ooo`3oool0803o
ool00`000000oooo0?ooo`090?ooo`0300000009jPX0oooo00d0oooo00@0000000WZ2P3oool0oooo
0`09jPX20?ooo`0300WZ2P3oool0oooo00P0oooo0P0000020?ooo`0300WZ2P3oool0oooo00l0oooo
1000000300WZ2P0300000009jPX000000080000000@0oooo0000000000002NX:103oool00`09jPX0
oooo0?ooo`040?ooo`80000000<0oooo00WZ2P09jPX05`3oool00`0000002NX:0?ooo`0Z0?ooo`03
00WZ2P3oool0oooo00T0oooo0P00000?0?ooo`0300WZ2P3oool0oooo00<0oooo00@0000000WZ2P3o
ool02NX:I@3oool400WZ2Pl0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3o
ool0;03oool00`09jPX0oooo0?ooo`0P0?ooo`030000003oool0oooo00H0oooo00<02NX:00000009
jPX0403oool00`09jPX0oooo0?ooo`030?ooo`0300000009jPX02NX:00802NX:00<0000000WZ2P09
jPX00`09jPX30?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool02`3oool400WZ2P<0
0000103oool00`09jPX000000?ooo`030?ooo`0600WZ2P3oool0oooo0?ooo`0000002NX:303oool2
00WZ2QL0oooo00<02NX:0?ooo`3oool0:03oool00`09jPX0oooo0?ooo`090?ooo`0300WZ2P3oool0
oooo00h0oooo00<02NX:0?ooo`3oool00`3oool0100000002NX:0?ooo`09jPYR0?ooo`<02NX:4`3o
ool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`0[0?ooo`0300WZ2P3oool0
oooo0240oooo00<000000?ooo`3oool00P09jPX01@0000002NX:00WZ2P09jPX0oooo00800000403o
ool00`09jPX000000?ooo`030?ooo`80000000<0oooo00WZ2P3oool00P0000040?ooo`0400WZ2P00
00002NX:00WZ2PD0oooo0P09jPX:0?ooo`0700WZ2P3oool000000000003oool0000000WZ2P060?oo
o`0300WZ2P3oool0oooo00802NX:00@000000?ooo`3oool0oooo0P00000<0?ooo`8000000P09jPXE
0?ooo`0300WZ2P3oool0oooo02T0oooo00<02NX:0?ooo`3oool01@3oool20000000300WZ2P3oool0
oooo00l0oooo00<02NX:0?ooo`3oool00`3oool01009jPX000000?ooo`09jPYN0?ooo`@02NX:5P3o
ool00`000000oooo0?ooo`090?ooo`002P3ooomA00WZ2P0400000009jPX02NX:00WZ2P80oooo0P00
000E0?ooo`0300WZ2P000000oooo00@0oooo00<0000000WZ2P3oool0203oool2000000802NX:0P00
000200WZ2P80000000<02NX:0000000000001P3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3o
ool0oooo00@0oooo00@02NX:0?ooo`09jPX0oooo0P0000040?ooo`0300WZ2P3oool0oooo00h0oooo
00<02NX:0?ooo`3oool04`3oool00`09jPX0oooo0?ooo`0X0?ooo`0300WZ2P3oool0oooo00D0oooo
00<0000000WZ2P3oool04P3oool02@09jPX0oooo0?ooo`3oool0000000WZ2P000000oooo00WZ2P1K
0?ooo`<02NX:6P3oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`0Z0?oo
o`0300WZ2P3oool0oooo0240oooo0P00000K0?ooo`0300WZ2P3oool0oooo00@0oooo0P0000080?oo
o`<02NX:00<0oooo0000000000001009jPX01@0000002NX:00WZ2P09jPX0000000802NX:00<0oooo
00000009jPX01P3oool00`09jPX0oooo0?ooo`050?ooo`802NX:1`3oool00`09jPX0oooo0?ooo`0@
0?ooo`802NX:4`3oool2000002P0oooo00<0000000WZ2P3oool00`3oool20000000300WZ2P3oool0
oooo01<0oooo00T02NX:0?ooo`3oool0oooo00000009jPX000000?ooo`09jPX0F03oool300WZ2Qd0
oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0:@3oool00`09jPX0oooo
0?ooo`0S0?ooo`030000003oool0oooo01X0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo
0?ooo`030?ooo`@02NX:0P3oool00`09jPX0oooo0?ooo`030?ooo`0600000009jPX02NX:00WZ2P3o
ool02NX:0`0000001009jPX0000000WZ2P09jPX200000080oooo00<02NX:0?ooo`3oool01@3oool2
0000000300WZ2P3oool0oooo00D0oooo00<02NX:0?ooo`3oool04@3oool00`0000002NX:00WZ2P0A
0?ooo`0300000009jPX0oooo02L0oooo00<0000000WZ2P3oool00`3oool00`0000002NX:0?ooo`0E
0?ooo`0300WZ2P3oool0oooo0080oooo00@02NX:0000003oool02NX:E03oool400WZ2R00oooo00<0
00000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0:03oool00`09jPX0oooo0?ooo`0T
0?ooo`030000003oool0oooo01X0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`03
00WZ2P80oooo0P0000020?ooo`0300WZ2P3oool0oooo00<0oooo0P0000000`3oool02NX:00WZ2P03
00WZ2P@0000000H0oooo00000009jPX02NX:0?ooo`09jPX40?ooo`80000000@02NX:000000000000
2NX:1`3oool00`09jPX0oooo0?ooo`0A0?ooo`80000000<0oooo00WZ2P3oool04@3oool00`09jPX0
oooo0?ooo`0V0?ooo`0500WZ2P3oool0oooo0?ooo`09jPX05`3oool00`0000002NX:0?ooo`030?oo
o`0400WZ2P000000oooo00WZ2U40oooo0`09jPXT0?ooo`030000003oool0oooo00T0oooo000:0?oo
oe402NX:00@0000000WZ2P09jPX02NX:6P3oool01`09jPX0oooo0?ooo`3oool0000000WZ2P000000
0P09jPX70?ooo`P02NX:00@0000000WZ2P09jPX0oooo0P0000000`3oool0000000WZ2P0200WZ2PD0
00000P09jPX20?ooo`802NX:00<0000000WZ2P3oool00P3oool00`09jPX0oooo0?ooo`050?ooo`03
00WZ2P3oool0oooo01@0oooo00<0000000WZ2P3oool0403oool00`0000002NX:0?ooo`0V0?ooo`04
00WZ2P3oool0oooo00WZ2QP0oooo0P0000030?ooo`0500000009jPX000000?ooo`09jPX0C@3oool4
00WZ2RL0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool09`3oool00`09
jPX0oooo0?ooo`0T0?ooo`8000000P3oool300WZ2QL0oooo00@02NX:0?ooo`3oool02NX:10000005
0?ooo`<02NX:0`00000<0?ooo`8000000P3oool01P0000002NX:00WZ2P0000002NX:000000<02NX:
1`3oool00`09jPX0oooo0?ooo`030?ooo`0300000009jPX0oooo01H0oooo0P0000000`09jPX0oooo
0?ooo`0>0?ooo`0300000009jPX0oooo02H0oooo00<02NX:00000009jPX06P3oool02@09jPX00000
0?ooo`3oool0000000WZ2P000000oooo00WZ2P1:0?ooo`<02NX::`3oool00`000000oooo0?ooo`09
0?ooo`002P3oool00`000000oooo0?ooo`0W0?ooo`0300WZ2P3oool0oooo02D0oooo00<000000?oo
o`3oool00`3oool200WZ2P0400000009jPX02NX:00WZ2P800000103oool200000080oooo0P09jPX2
000000@02NX:0`0000000`09jPX0oooo0?ooo`020?ooo`0400WZ2P0000002NX:00WZ2P<0oooo00<0
2NX:0?ooo`3oool0403oool2000000<02NX:0P000000103oool0000000WZ2P09jPX40?ooo`800000
1@3oool00`0000002NX:0?ooo`0I0?ooo`0300WZ2P3oool0oooo00h0oooo00<02NX:0?ooo`3oool0
903oool200WZ2P8000006P3oool200000080oooo00D0000000WZ2P000000oooo00WZ2P160?ooo`@0
2NX:;P3oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`0V0?ooo`0300WZ
2P3oool0oooo02H0oooo00<000000?ooo`3oool00`3oool4000000H02NX:00<0000000WZ2P000000
0`09jPX20?ooo`<000000`3oool2000000<0oooo0`09jPX00`3oool00000000000040?ooo`0300WZ
2P3oool0oooo0180oooo00<0000000WZ2P09jPX00`3oool2000000030?ooo`09jPX0oooo0080oooo
00<0000000WZ2P3oool0103oool00`09jPX0oooo0?ooo`0J0?ooo`0300WZ2P3oool0oooo00h0oooo
00<02NX:0?ooo`3oool08P3oool01009jPX0oooo00WZ2P00000K0?ooo`0900WZ2P3oool0oooo0?oo
o`0000002NX:0000003oool02NX:04<0oooo0`09jPXb0?ooo`030000003oool0oooo00T0oooo000:
0?ooo`030000003oool0oooo02D0oooo00<02NX:0?ooo`3oool09P3oool2000000<0oooo0P09jPX0
100000002NX:00WZ2P09jPX20?ooo`80000000<0oooo00WZ2P09jPX00P09jPX2000000T0oooo00H0
000000WZ2P3oool0000000WZ2P3oool2000000H0oooo00<02NX:0?ooo`3oool04P3oool200000080
oooo00<02NX:0?ooo`3oool00`3oool01P0000002NX:0?ooo`3oool0000000WZ2P<0oooo00<00000
00WZ2P3oool07@3oool00`09jPX0oooo0?ooo`0=0?ooo`0300WZ2P000000oooo0240oooo00<02NX:
0?ooo`3oool00P00000K0?ooo`0300WZ2P3oool0oooo0080oooo00@02NX:0000003oool02NX:@03o
ool300WZ2SD0oooo00<000000?ooo`3oool02@3oool000X0ooooD@09jPX00`0000002NX:00WZ2P02
00WZ2Pl0oooo00@0000000WZ2P09jPX02NX:1`3oool400WZ2P030000003oool0oooo00L0oooo00<0
2NX:0?ooo`3oool04P3oool00`0000002NX:0?ooo`020?ooo`0300WZ2P3oool0oooo0080oooo0P00
00001009jPX0oooo00000009jPX30?ooo`8000007P3oool00`0000002NX:00WZ2P0=0?ooo`030000
0009jPX0oooo0200oooo00D02NX:0?ooo`3oool0oooo00WZ2P0L0?ooo`0300WZ2P000000oooo0080
oooo00@02NX:0000003oool02NX:?03oool400WZ2SP0oooo00<000000?ooo`3oool02@3oool000X0
oooo00<000000?ooo`3oool0903oool00`09jPX0oooo0?ooo`0X0?ooo`030000003oool0oooo01@0
oooo0`09jPX30?ooo`0400WZ2P3oool02NX:00WZ2PT0oooo00<0000000WZ2P3oool05@3oool00`09
jPX0oooo0?ooo`020?ooo`8000001@3oool00`09jPX0oooo00WZ2P030?ooo`0300WZ2P3oool0oooo
01d0oooo0P0000000`3oool02NX:00WZ2P0;0?ooo`0300000009jPX0oooo01l0oooo00<02NX:0?oo
o`3oool00`3oool00`09jPX0oooo0?ooo`0I0?ooo`0800WZ2P000000oooo0?ooo`09jPX0oooo0000
0009jPXj0?ooo`<02NX:?03oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?oo
o`0T0?ooo`0300WZ2P3oool0oooo02P0oooo00<000000?ooo`3oool05P3oool02@0000002NX:00WZ
2P09jPX0oooo00WZ2P000000oooo00WZ2P02000000H0oooo0P00000F0?ooo`0300WZ2P3oool0oooo
0080oooo00<0000000WZ2P3oool01@3oool200WZ2P80oooo00<02NX:0?ooo`3oool08`3oool00`09
jPX0oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo01/0oooo00<0000000WZ2P3oool01@3oool00`09
jPX0oooo0?ooo`0I0?ooo`0800WZ2P3oool0oooo0?ooo`09jPX0oooo00000009jPXf0?ooo`@02NX:
?`3oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`0S0?ooo`0300WZ2P3o
ool0oooo02T0oooo00<000000?ooo`3oool05P3oool3000000D02NX:00<0oooo00WZ2P0000001P3o
ool00`09jPX0oooo0?ooo`0E0?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool01@3o
ool300WZ2RL0oooo00<02NX:0000003oool02@3oool00`09jPX0oooo0?ooo`0K0?ooo`8000001@3o
ool00`0000002NX:0?ooo`0J0?ooo`0800WZ2P3oool0oooo0?ooo`09jPX0oooo00000009jPXc0?oo
o`<02NX:@`3oool00`000000oooo0?ooo`090?ooo`002P3ooomA00WZ2P0500000009jPX02NX:00WZ
2P0000000`09jPXC0?ooo`0300000009jPX02NX:00@0oooo00<0000000WZ2P09jPX01@3oool00`09
jPX0oooo0?ooo`0F0?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool00`3oool01@00
00002NX:00WZ2P3oool02NX:02H0oooo00<0000000WZ2P3oool02@3oool00`09jPX0oooo0?ooo`0J
0?ooo`0300WZ2P3oool0oooo00D0oooo0P00000L0?ooo`0700WZ2P3oool0000000WZ2P3oool00000
00WZ2P0`0?ooo`<02NX:AP3oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?oo
o`0R0?ooo`0300WZ2P3oool0oooo02T0oooo0P0000020?ooo`80000000@0oooo00000009jPX02NX:
403oool01009jPX0oooo0?ooo`09jPX40?ooo`8000000`09jPX0103oool0000000000009jPXG0?oo
o`0300000009jPX0oooo00D0oooo00<02NX:0?ooo`3oool00`3oool00`0000002NX:000000020?oo
o`0300WZ2P3oool0oooo02D0oooo0P09jPX80?ooo`0300000009jPX0oooo01P0oooo00<0000000WZ
2P3oool0203oool00`09jPX0oooo0?ooo`0J0?ooo`0700WZ2P0000002NX:0000003oool0000000WZ
2P0/0?ooo`@02NX:B@3oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`0Q
0?ooo`0300WZ2P3oool0oooo02/0oooo00<000000?ooo`3oool00`3oool2000000040?ooo`09jPX0
2NX:00WZ2P`0oooo00@02NX:0?ooo`3oool02NX:203oool01@09jPX0000000WZ2P0000002NX:01P0
oooo00<0000000WZ2P3oool01P3oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P000000oooo0080
oooo0P00000U0?ooo`80000000<02NX:0?ooo`3oool01@3oool00`0000002NX:0000000E0?ooo`<0
2NX:0P00000:0?ooo`0300WZ2P3oool0oooo01T0oooo00<02NX:00000009jPX00P3oool00`000000
2NX:0?ooo`0X0?ooo`<02NX:C@3oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo
0?ooo`0P0?ooo`0300WZ2P3oool0oooo02`0oooo00<000000?ooo`3oool0203oool3000000T0oooo
00@02NX:0?ooo`3oool02NX:2P3oool200WZ2P0300000009jPX0oooo01P0oooo00<02NX:0?ooo`3o
ool01@3oool00`09jPX00000000000020?ooo`0300WZ2P3oool02NX:00<0oooo00<0000000WZ2P09
jPX05P3oool2000000h0oooo00@0000000WZ2P09jPX02NX:1@3oool00`0000002NX:0?ooo`0B0?oo
o`802NX:3`3oool00`09jPX0oooo0?ooo`0J0?ooo`0600WZ2P3oool0oooo0?ooo`0000002NX:9@3o
ool400WZ2U00oooo00<000000?ooo`3oool02@3oool000X0ooooD@09jPX00`0000002NX:00WZ2P02
00WZ2PL0oooo0P00000200WZ2PD0oooo0P0000001@09jPX0oooo0?ooo`09jPX0000000L0oooo00L0
000000WZ2P09jPX0oooo00WZ2P000000oooo00802NX:5P3oool00`09jPX0oooo0?ooo`070?ooo`07
00WZ2P000000oooo00000009jPX0000000WZ2P050?ooo`0300000009jPX02NX:00D02NX:00<00000
00WZ2P09jPX01009jPX00`0000002NX:00WZ2P0500WZ2P0500000009jPX02NX:00WZ2P3oool00P00
00090?ooo`80000000<0oooo0000000000000`09jPX00`3oool0000000WZ2P0@0?ooo`80000000<0
2NX:0?ooo`3oool03`3oool00`09jPX0oooo0?ooo`0I0?ooo`0300000009jPX0oooo0080oooo00<0
000000WZ2P3oool08@3oool300WZ2U@0oooo00<000000?ooo`3oool02@3oool000X0oooo00<00000
0?ooo`3oool07`3oool00`09jPX0oooo0?ooo`0/0?ooo`80000000<0oooo0000000000000`09jPX2
000000H0oooo00<02NX:0?ooo`3oool00P3oool01@0000002NX:0?ooo`3oool02NX:008000001@3o
ool200WZ2P8000000P3oool00`0000002NX:0?ooo`020?ooo`0300WZ2P3oool0oooo0180oooo0P00
000:0?ooo`0300WZ2P00000000000080000000<02NX:0?ooo`3oool00`3oool2000000030?ooo`00
0000000000<0oooo0P0000050?ooo`8000002P3oool400WZ2P/0oooo0`0000001@3oool0000000WZ
2P09jPX0000000d0oooo0`09jPX300000140oooo00<02NX:0?ooo`3oool0603oool400000080oooo
00<0000000WZ2P3oool07@3oool400WZ2UL0oooo00<000000?ooo`3oool02@3oool000X0oooo00<0
00000?ooo`3oool07`3oool00`09jPX0oooo0?ooo`0]0?ooo`030000003oool0oooo00@0oooo0P09
jPX2000000D0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo00WZ2P060?ooo`802NX:00<0
oooo0000000000000`3oool00`0000002NX:0?ooo`020?ooo`0300000009jPX02NX:0180oooo00<0
000000WZ2P3oool02@3oool200WZ2P80oooo0P00000T0?ooo`@02NX:2`3oool20000000300WZ2P00
0000oooo00X0oooo0P09jPXG0?ooo`0300000009jPX0oooo01P0oooo00@0000000WZ2P0000000000
0P3oool00`0000002NX:0?ooo`0J0?ooo`<02NX:F`3oool00`000000oooo0?ooo`090?ooo`002P3o
ool00`000000oooo0?ooo`0N0?ooo`0300WZ2P3oool0oooo02h0oooo00<000000?ooo`3oool01P3o
ool200WZ2P8000000`3oool01P0000002NX:0?ooo`0000002NX:000000<02NX:0`00000500WZ2P03
00000009jPX02NX:00802NX:00<0oooo00WZ2P3oool00P3oool2000000030?ooo`09jPX02NX:0140
oooo00<02NX:0?ooo`3oool01`3oool00`0000002NX:00WZ2P020?ooo`0300000009jPX0oooo02L0
oooo0P00000300WZ2PT0oooo0P09jPX90?ooo`0300WZ2P000000oooo01L0oooo00<0000000WZ2P3o
ool0603oool0100000002NX:0?ooo`09jPX20?ooo`0300000009jPX0oooo01L0oooo0`09jPYN0?oo
o`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo01d0oooo00<02NX:0?ooo`3o
ool0;P3oool2000000X0oooo0`09jPX2000000802NX:00<0000000WZ2P0000000P0000000`09jPX0
000000000004000000P0oooo00@02NX:00000009jPX02NX:1@3oool00`0000002NX:0?ooo`0=0?oo
o`0300000009jPX0oooo00T0oooo0P0000001@3oool02NX:0?ooo`3oool02NX:02P0oooo1@000002
00WZ2PH0oooo00@0000000WZ2P3oool02NX:1@3oool00`09jPX0000000WZ2P02000001T0oooo00<0
2NX:0?ooo`3oool05`3oool0200000002NX:0?ooo`0000002NX:0?ooo`0000002NX:503oool400WZ
2V40oooo00<000000?ooo`3oool02@3oool000X0ooooD@09jPX2000000@02NX:1@3oool300WZ2P80
00000P09jPX4000000802NX:00<0oooo0000000000003@3oool00`0000002NX:0?ooo`0200WZ2P<0
oooo0P0000000`09jPX0oooo0?ooo`0;0?ooo`0300000009jPX0oooo00T0oooo00L02NX:0?ooo`3o
ool0000000WZ2P3oool02NX:02l0oooo1@09jPX00`3oool0000000WZ2P020?ooo`0300WZ2P3oool0
2NX:00802NX:00<0oooo0000000000006`3oool00`09jPX0oooo0?ooo`0F0?ooo`0400000009jPX0
oooo0?ooo`80000000<0oooo00000009jPX04@3oool300WZ2VD0oooo00<000000?ooo`3oool02@3o
ool000X0oooo00<000000?ooo`3oool0703oool00`09jPX0oooo0?ooo`0`0?ooo`8000000`3oool5
00WZ2P<0oooo00D0000000WZ2P09jPX0000000WZ2P03000001<0oooo00D02NX:0000003oool0oooo
00WZ2P050?ooo`0300WZ2P000000000000/0oooo00<02NX:0?ooo`3oool01`3oool02009jPX0oooo
0?ooo`3oool0000000WZ2P3oool02NX:;`3oool2000000<0oooo1009jPX20000000300WZ2P3oool0
oooo01h0oooo00<0000000WZ2P3oool05`3oool00`0000002NX:0?ooo`030?ooo`0300WZ2P000000
2NX:00d0oooo1009jPYX0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo
01`0oooo00<02NX:0?ooo`3oool0<03oool00`000000oooo0?ooo`030?ooo`800000103oool01000
00002NX:00WZ2P09jPX2000000030?ooo`09jPX0000001<0oooo00H02NX:0000003oool0oooo0000
0009jPX50?ooo`802NX:2P3oool00`09jPX0oooo0?ooo`080?ooo`0300WZ2P3oool0oooo0080oooo
0P09jPXg0?ooo`0300000009jPX000000080000000<02NX:0?ooo`3oool07@3oool00`0000002NX:
0?ooo`0H0?ooo`0800WZ2P3oool0oooo0?ooo`0000002NX:00000009jPX:0?ooo`<02NX:K03oool0
0`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`0K0?ooo`0300WZ2P3oool0oooo
0340oooo00<000000?ooo`3oool01P3oool500WZ2P030000003oool0oooo0080oooo00<02NX:0?oo
o`3oool04P3oool01P09jPX0oooo0?ooo`3oool0000000WZ2PL0oooo0P0000080?ooo`0300WZ2P3o
ool0oooo00H0oooo00<0000000WZ2P3oool0103oool2000003P0oooo00D02NX:0?ooo`3oool00000
00WZ2P0P0?ooo`0300WZ2P3oool0oooo01H0oooo00<02NX:0?ooo`3oool00P3oool30000000300WZ
2P3oool0oooo00D0oooo0`09jPY_0?ooo`030000003oool0oooo00T0oooo000:0?oooe402NX:00<0
000000WZ2P09jPX00P09jPX20?ooo`0400000009jPX02NX:0?ooo`802NX:00<0oooo000000000000
1@3oool00`09jPX0oooo0?ooo`0A0?ooo`0300WZ2P000000oooo0080oooo0`0000050?ooo`030000
0009jPX0oooo00L0oooo00<02NX:0?ooo`3oool01P3oool2000000D0oooo00<02NX:0000003oool0
=P3oool00`0000002NX:0?ooo`030?ooo`0300WZ2P3oool0oooo01d0oooo00<02NX:0?ooo`3oool0
5P3oool00`09jPX0oooo0?ooo`030?ooo`0300000009jPX02NX:00<0oooo1009jPYb0?ooo`030000
003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo01X0oooo00<02NX:0?ooo`3oool0<@3o
ool2000000<0oooo00<0000000WZ2P0000000P0000000`09jPX000000?ooo`080?ooo`0300WZ2P3o
ool0oooo0140oooo00<02NX:0000003oool00P3oool2000000802NX:1P3oool00`09jPX0oooo0?oo
o`040?ooo`0300WZ2P3oool0oooo00L0oooo00<02NX:0?ooo`3oool0103oool00`09jPX000000?oo
o`0f0?ooo`0300000009jPX0oooo00<0oooo00<02NX:0?ooo`3oool07@3oool00`09jPX0oooo0?oo
o`0F0?ooo`0300WZ2P3oool0oooo0080oooo00@0000000WZ2P09jPX0oooo0`09jPYf0?ooo`030000
003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo01T0oooo00<02NX:0?ooo`3oool0<`3o
ool01@000000oooo0?ooo`3oool0000000<02NX:0`00000:0?ooo`0300WZ2P3oool0oooo0100oooo
00<02NX:0?ooo`3oool01@3oool00`0000002NX:00WZ2P050?ooo`8000000`3oool00`0000002NX:
0?ooo`060?ooo`0300000009jPX0oooo00H0oooo00<02NX:0?ooo`09jPX0>03oool00`09jPX0oooo
0?ooo`020?ooo`0300WZ2P3oool0oooo01`0oooo00<02NX:0?ooo`3oool05@3oool00`09jPX0oooo
0?ooo`0300WZ2P8000000P09jPYi0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000003o
ool0oooo01P0oooo00<02NX:0?ooo`3oool0=03oool00`000000oooo0000000200WZ2Q00oooo0P00
000A0?ooo`0300WZ2P3oool0oooo00D0oooo0P0000000`3oool02NX:0?ooo`030?ooo`0300000009
jPX0oooo0080oooo00<0000000WZ2P3oool01@3oool00`09jPX00000000000070?ooo`0400WZ2P3o
ool02NX:000003L0oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`0K0?ooo`0300WZ
2P000000oooo01@0oooo00<0000000WZ2P09jPX00`09jPX30?ooo`0300WZ2P3oool0oooo07P0oooo
00<000000?ooo`3oool02@3oool000X0ooooD@09jPX20000000300WZ2P00000000000140oooo00<0
000000WZ2P3oool03`3oool2000000/0oooo00<02NX:0?ooo`3oool00P3oool01P09jPX0oooo0?oo
o`3oool0000000WZ2PD0oooo00<02NX:0000003oool01`3oool2000000030?ooo`0000002NX:03L0
oooo00<02NX:0?ooo`3oool00`3oool2000001`0oooo00<02NX:0000003oool04`3oool300WZ2P03
0000003oool0oooo00@0oooo00<02NX:0?ooo`3oool0N03oool00`000000oooo0?ooo`090?ooo`00
2P3oool00`000000oooo0?ooo`0G0?ooo`0300WZ2P3oool0oooo03@0oooo0`00000D0?ooo`030000
0009jPX0oooo00h0oooo00<0000000WZ2P3oool02`3oool200WZ2P<0oooo00D02NX:0?ooo`3oool0
000000WZ2P050?ooo`800000203oool01P0000002NX:0?ooo`3oool0000000WZ2SL0oooo00<02NX:
0000003oool00P3oool00`0000002NX:00WZ2P0K0?ooo`0300WZ2P3oool0oooo0140oooo0P09jPX0
103oool02NX:0000000000060?ooo`0300WZ2P3oool0oooo07P0oooo00<000000?ooo`3oool02@3o
ool000X0oooo00<000000?ooo`3oool05`3oool00`09jPX0oooo0?ooo`0e0?ooo`030000003oool0
oooo01<0oooo0P0000000`09jPX0oooo0?ooo`0;0?ooo`0300000009jPX0oooo00`0oooo0P000000
1009jPX0oooo0?ooo`09jPX30?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool0203o
ool200000080oooo00<0000000WZ2P3oool0=P3oool00`0000002NX:0?ooo`050?ooo`0300WZ2P3o
ool0oooo01T0oooo00<02NX:0?ooo`3oool03@3oool00`09jPX0000000WZ2P030?ooo`0300WZ2P3o
ool0oooo00H0oooo00<02NX:0?ooo`3oool0N03oool00`000000oooo0?ooo`090?ooo`002P3oool0
0`000000oooo0?ooo`0F0?ooo`0300WZ2P3oool0oooo03H0oooo00<000000?ooo`3oool05P3oool0
0`09jPX0oooo0?ooo`0:0?ooo`0300000009jPX0oooo00h0oooo00D0000000WZ2P3oool0oooo00WZ
2P030?ooo`0500WZ2P3oool0oooo0?ooo`09jPX02P3oool00`09jPX000000?ooo`020?ooo`0300WZ
2P3oool0oooo03L0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`0H0?ooo`0300WZ
2P3oool0oooo00P0oooo0P09jPX0100000002NX:00WZ2P3oool2000000050?ooo`0000002NX:0?oo
o`09jPX01`3oool00`09jPX0oooo0?ooo`1h0?ooo`030000003oool0oooo00T0oooo000:0?ooo`03
0000003oool0oooo01D0oooo00<02NX:0?ooo`3oool0=P3oool2000001T0oooo00<02NX:0?ooo`3o
ool02@3oool00`09jPX0oooo0?ooo`0>0?ooo`<0000000<0oooo00WZ2P3oool00P3oool01009jPX0
oooo0?ooo`09jPX;0?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0000003oool0=`3oool00`00
00002NX:0?ooo`040?ooo`0300000009jPX02NX:01P0oooo00<02NX:0?ooo`3oool0103oool01@00
00002NX:00WZ2P09jPX0oooo00<00000103oool3000000030?ooo`09jPX0oooo00D0oooo00<00000
00WZ2P3oool0N@3oool00`000000oooo0?ooo`090?ooo`002P3ooomA00WZ2P0300000009jPX02NX:
00<02NX:5@3oool00`0000002NX:0?ooo`080?ooo`0300WZ2P3oool0oooo00l0oooo0P0000002@09
jPX0oooo00000009jPX0oooo00000009jPX0oooo00WZ2P0;0?ooo`0300000009jPX0oooo00<0oooo
00<02NX:0000003oool0=`3oool00`0000002NX:0?ooo`040?ooo`80000000<0oooo00WZ2P3oool0
5P3oool00`0000002NX:0?ooo`030?ooo`802NX:00<000000?ooo`3oool0203oool2000000030?oo
o`0000002NX:00H0oooo0P00001j0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000003o
ool0oooo01@0oooo00<02NX:0?ooo`3oool0>03oool00`000000oooo0?ooo`020?ooo`@02NX:00@0
000000WZ2P09jPX02NX:3@3oool00`0000002NX:0?ooo`050?ooo`80000000<02NX:0?ooo`3oool0
4`3oool02009jPX0000000WZ2P3oool0000000WZ2P0000002NX:2`3oool00`0000002NX:0?ooo`04
0?ooo`0300WZ2P3oool0oooo03P0oooo00<02NX:0?ooo`3oool01P3oool2000001D0oooo00@00000
00WZ2P00000000000P09jPX<0?ooo`0600000009jPX0oooo0?ooo`0000002NX:1@3oool00`09jPX0
oooo0000001j0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo01@0oooo
00<02NX:0?ooo`3oool0>03oool00`000000oooo0?ooo`040?ooo`@000000P3oool300WZ2P`0oooo
00<02NX:0?ooo`3oool00`3oool200WZ2QL0oooo0P09jPX20?ooo`802NX:3@3oool00`09jPX0oooo
0?ooo`030?ooo`0300WZ2P3oool0oooo03P0oooo00<02NX:0?ooo`3oool01P3oool00`0000002NX:
00WZ2P0D0?ooo`0300000009jPX00000008000003@3oool2000000<0oooo00<02NX:0?ooo`3oool0
0P3oool01009jPX0oooo0?ooo`00001j0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000
003oool0oooo01<0oooo00<02NX:0?ooo`3oool0>@3oool00`000000oooo0?ooo`0=0?ooo`030000
0009jPX02NX:008000001`3oool200WZ2P0400000009jPX02NX:00WZ2QX0oooo00<02NX:00000009
jPX00P00000<0?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0>03oool00`09jPX0
oooo0?ooo`060?ooo`80000000<0oooo00WZ2P09jPX04@3oool00`09jPX0000000WZ2P0@0?ooo`05
00WZ2P3oool0oooo0?ooo`09jPX00`3oool00`0000002NX:0?ooo`020?ooo`030000003oool0oooo
07P0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool04P3oool00`09jPX0
oooo0?ooo`0j0?ooo`030000003oool0oooo00d0oooo0P0000000`3oool0000000WZ2P0400WZ2P03
00000009jPX02NX:00802NX:0P0000000`09jPX0oooo00WZ2P0500WZ2Q@0oooo00<0000000WZ2P09
jPX0203oool500WZ2P0300000009jPX02NX:00802NX:0`3oool00`0000002NX:0?ooo`0i0?ooo`03
00WZ2P3oool0oooo00T0oooo00<0000000WZ2P09jPX00P09jPX;0?ooo`802NX:00<0oooo00WZ2P3o
ool03`3oool00`09jPX0oooo0?ooo`020?ooo`0400WZ2P3oool0oooo00WZ2P8000000`3oool00`00
0000oooo0?ooo`1h0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo0180
oooo00<02NX:0?ooo`3oool0>P3oool00`000000oooo0?ooo`0F0?ooo`8000000`3oool200WZ2P<0
oooo0`0000020?ooo`0400000009jPX02NX:00WZ2Q00oooo00<0000000WZ2P09jPX01P3oool200WZ
2P030?ooo`00000000000080oooo00D0000000WZ2P000000oooo0000000200WZ2P030?ooo`000000
2NX:03X0oooo00<02NX:0000003oool02@3oool2000000<0oooo0P00000200WZ2PH0oooo00D02NX:
0?ooo`3oool0oooo00WZ2P0=0?ooo`80000000<02NX:0?ooo`3oool00`3oool00`09jPX0oooo00WZ
2P060?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool02@3oool000X0oooo00<00000
0?ooo`3oool04@3oool00`09jPX0oooo0?ooo`0k0?ooo`030000003oool0oooo01X0oooo00<02NX:
000000000000203oool4000000<02NX:3P3oool00`0000002NX:0?ooo`030?ooo`0300000009jPX0
oooo00L0oooo00<02NX:0?ooo`3oool00P000000103oool02NX:00WZ2P09jPXj0?ooo`0300WZ2P00
0000oooo00h0oooo0`000000103oool02NX:00WZ2P09jPX20000000600WZ2P3oool0oooo0?ooo`00
00002NX:3@3oool00`0000002NX:0?ooo`050?ooo`802NX:1`3oool00`000000oooo0?ooo`1h0?oo
o`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo0100oooo00<02NX:0?ooo`3o
ool0?03oool00`000000oooo0?ooo`0I0?ooo`0400WZ2P3oool0000000WZ2Pl0oooo0P09jPX20000
00X0oooo0P000000103oool02NX:00WZ2P09jPX2000000P0oooo00<02NX:0?ooo`3oool01@3oool0
0`09jPX0oooo0?ooo`0i0?ooo`0300WZ2P3oool0oooo01@0oooo0`0000030?ooo`8000003P3oool0
0`09jPX0oooo0?ooo`030?ooo`0300WZ2P000000000000L0oooo00<000000?ooo`3oool0N03oool0
0`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`0@0?ooo`0300WZ2P3oool0oooo
03`0oooo00<000000?ooo`3oool05P3oool20000000500WZ2P3oool0oooo0?ooo`09jPX04@3oool5
00WZ2PH0oooo0P09jPX00`0000002NX:0?ooo`0<0?ooo`0300WZ2P3oool0oooo00D0oooo0P09jPX2
000003T0oooo00<02NX:0?ooo`3oool06P3oool00`09jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0
oooo00<0oooo0P09jPX00`000000oooo0?ooo`060?ooo`030000003oool0oooo07P0oooo00<00000
0?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool03`3oool00`09jPX0oooo0?ooo`0m0?oo
o`030000003oool0oooo01D0oooo0`09jPX50?ooo`0300WZ2P3oool0oooo01<0oooo0`09jPX00`00
00002NX:00WZ2P0300WZ2P0300000009jPX0oooo00`0oooo00<02NX:0?ooo`3oool00`3oool01000
00002NX:0?ooo`00000200WZ2ST0oooo00<02NX:0000003oool06P3oool00`09jPX0oooo0?ooo`0:
0?ooo`0300WZ2P3oool0oooo00<0oooo00<0000000WZ2P000000203oool00`000000oooo0?ooo`1h
0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo00l0oooo00<02NX:0?oo
o`3oool0?@3oool00`000000oooo0?ooo`0A0?ooo`@02NX:1`3oool00`0000002NX:0?ooo`0G0?oo
o`<000000P09jPX0103oool02NX:00000009jPX<0?ooo`0300WZ2P3oool0oooo00<0oooo00<00000
00WZ2P3oool00`3oool300WZ2SH0oooo00<02NX:0000003oool06P3oool00`09jPX0oooo0?ooo`09
0?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`09jPX02@3oool00`000000oooo0?ooo`1h
0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo00h0oooo00<02NX:0?oo
o`3oool0?P3oool00`000000oooo0?ooo`0>0?ooo`802NX:00<000000?ooo`3oool02@3oool00`00
00002NX:0?ooo`0I0?ooo`80000000D02NX:0?ooo`3oool0000000WZ2P0<0?ooo`0300WZ2P3oool0
oooo00@0oooo00<02NX:0?ooo`3oool01@3oool200WZ2SD0oooo00<02NX:0?ooo`3oool0603oool0
0`0000002NX:0?ooo`0:0?ooo`0300WZ2P3oool0oooo0080oooo00@02NX:0?ooo`3oool02NX:2@3o
ool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0
oooo00d0oooo00<02NX:0?ooo`3oool0?`3oool00`000000oooo0?ooo`0<0?ooo`802NX:00<0oooo
0000000000003@3oool00`09jPX0oooo0?ooo`0H0?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:
0?ooo`3oool02@3oool00`0000002NX:0?ooo`050?ooo`0300WZ2P3oool0oooo00L0oooo0P09jPXc
0?ooo`0300WZ2P3oool0oooo01P0oooo0P00000:0?ooo`0600WZ2P000000oooo0?ooo`0000002NX:
103oool00`09jPX0oooo0?ooo`060?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0
2@3oool000X0oooo00<000000?ooo`3oool03@3oool00`09jPX0oooo0?ooo`0o0?ooo`030000003o
ool0oooo00X0oooo0P09jPXC0?ooo`0300WZ2P3oool0oooo01L0oooo00<02NX:0?ooo`3oool00`3o
ool00`09jPX0oooo0?ooo`080?ooo`0300000009jPX0oooo00D0oooo00<02NX:0?ooo`3oool01`3o
ool20000000300WZ2P3oool0oooo0300oooo00<02NX:0?ooo`3oool0603oool2000000X0oooo0P00
0000103oool02NX:0000000000040?ooo`0300WZ2P3oool0oooo00H0oooo00<000000?ooo`3oool0
N03oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`0<0?ooo`0300WZ2P3o
ool0oooo0400oooo00<000000?ooo`3oool0203oool00`0000002NX:0?ooo`0D0?ooo`0300WZ2P3o
ool0oooo01L0oooo00<02NX:0000003oool00`3oool200WZ2PX0oooo00<02NX:0?ooo`3oool0103o
ool00`09jPX0oooo0?ooo`0:0?ooo`802NX:<@3oool00`09jPX0oooo0?ooo`0H0?ooo`0300WZ2P3o
ool0oooo00P0oooo0`09jPX70?ooo`8000001`3oool00`000000oooo0?ooo`1h0?ooo`030000003o
ool0oooo00T0oooo000:0?ooo`030000003oool0oooo00/0oooo00<02NX:0?ooo`3oool0@@3oool0
0`000000oooo0?ooo`070?ooo`0300000009jPX0000001H0oooo00<02NX:0?ooo`3oool05@3oool2
00WZ2P030000003oool0oooo0080oooo00<02NX:0000003oool02@3oool00`09jPX0oooo0?ooo`04
0?ooo`0300WZ2P3oool0oooo00`0oooo0P00000_0?ooo`0300WZ2P3oool0oooo01P0oooo00<02NX:
0?ooo`3oool01`3oool00`0000002NX:0?ooo`080?ooo`0300WZ2P000000oooo00H0oooo00<00000
0?ooo`3oool0N03oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`0;0?oo
o`0300WZ2P3oool0oooo0440oooo00<000000?ooo`3oool01`3oool00`0000002NX:0?ooo`0G0?oo
o`0300WZ2P000000oooo01@0oooo0P09jPX50?ooo`0300WZ2P0000002NX:00P0oooo00<0000000WZ
2P3oool0103oool00`0000002NX:0?ooo`0=0?ooo`0300000009jPX02NX:02h0oooo0P00000J0?oo
o`0300WZ2P3oool0oooo00D0oooo00<0000000WZ2P0000002@3oool00`09jPX0oooo0?ooo`060?oo
o`030000003oool0oooo07P0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3o
ool02P3oool00`09jPX0oooo0?ooo`120?ooo`030000003oool0oooo00L0oooo00<02NX:0?ooo`3o
ool05`3oool00`09jPX000000?ooo`0D0?ooo`802NX:1P3oool200WZ2PP0oooo0`0000040?ooo`03
00000009jPX0oooo00d0oooo0P0000000`3oool02NX:0?ooo`0/0?ooo`0300000009jPX0oooo01T0
oooo00<02NX:0?ooo`3oool00P3oool300WZ2P0300000009jPX0oooo00X0oooo00<02NX:0?ooo`3o
ool01@3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000
003oool0oooo00X0oooo00<02NX:0?ooo`3oool0@P3oool00`000000oooo0?ooo`060?ooo`030000
0009jPX0oooo01P0oooo0P00000D0?ooo`0300000009jPX0oooo00H0oooo0P09jPX90?ooo`030000
0009jPX0oooo00@0oooo00<02NX:0?ooo`3oool0403oool00`09jPX0oooo0?ooo`0[0?ooo`0300WZ
2P3oool0oooo01P0oooo00<02NX:0?ooo`3oool00P09jPX30?ooo`0300000009jPX0oooo00/0oooo
00<02NX:0?ooo`3oool0103oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo00T0oooo
000:0?ooo`030000003oool0oooo00T0oooo00<02NX:0?ooo`3oool0@`3oool00`000000oooo0?oo
o`060?ooo`0300000009jPX0oooo01P0oooo00<0000000WZ2P3oool04`3oool00`0000002NX:0?oo
o`060?ooo`0400000009jPX00000000000P0oooo00<02NX:0000003oool00P3oool00`09jPX0oooo
0?ooo`0B0?ooo`0300WZ2P3oool0oooo02/0oooo0P00000H0?ooo`0300WZ2P0000002NX:00H0oooo
00<02NX:0?ooo`3oool02`3oool00`09jPX0oooo0?ooo`030?ooo`030000003oool0oooo07P0oooo
00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0203oool00`09jPX0oooo0?oo
o`140?ooo`030000003oool0oooo00H0oooo00<02NX:0?ooo`3oool06@3oool00`09jPX0oooo0?oo
o`0B0?ooo`8000001`3oool0100000002NX:0000000000080?ooo`0300000009jPX0oooo0080oooo
0P00000D0?ooo`800000:`3oool00`09jPX000000?ooo`0G0?ooo`<000001@3oool00`09jPX0oooo
0?ooo`0<0?ooo`0300000009jPX0oooo00<0oooo00<000000?ooo`3oool0N03oool00`000000oooo
0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`080?ooo`0300WZ2P3oool0oooo04@0oooo00<0
00000?ooo`3oool01@3oool00`09jPX0oooo0?ooo`0K0?ooo`0300WZ2P3oool0oooo0140oooo00<0
000000WZ2P3oool01P3oool0100000002NX:00000009jPX:0?ooo`0500WZ2P3oool0oooo00WZ2P00
0000503oool0100000002NX:00WZ2P00000200WZ2RL0oooo00<02NX:0?ooo`3oool05`3oool00`00
00002NX:000000040?ooo`0300WZ2P3oool0oooo00d0oooo0P00000200WZ2P80oooo00<000000?oo
o`3oool0N03oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`070?ooo`03
00WZ2P3oool0oooo04D0oooo00<000000?ooo`3oool0103oool00`09jPX0oooo0?ooo`0K0?ooo`03
00000009jPX0oooo0140oooo00<0000000WZ2P09jPX02@3oool200WZ2P/0oooo00<02NX:0?ooo`09
jPX05@3oool2000000030?ooo`000000000000<000000`3oool300WZ2P0300000009jPX02NX:01`0
oooo00<02NX:0?ooo`3oool05`3oool200WZ2P@0oooo00<02NX:0?ooo`3oool03`3oool200000004
0?ooo`09jPX0oooo000007X0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3o
ool01`3oool00`09jPX0oooo0?ooo`150?ooo`030000003oool0oooo0080oooo00<0000000WZ2P3o
ool07@3oool00`0000002NX:0?ooo`0A0?ooo`80000000<02NX:0?ooo`3oool01`3oool00`09jPX0
oooo00WZ2P0;0?ooo`802NX:6P3oool2000000@02NX:0`3oool2000000040?ooo`09jPX02NX:00WZ
2QX0oooo00<02NX:0?ooo`3oool05@3oool00`09jPX0oooo00WZ2P020?ooo`0300000009jPX0oooo
01D0oooo00<02NX:0000003oool0N@3oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000
oooo0?ooo`060?ooo`0300WZ2P3oool0oooo04H0oooo00<000000?ooo`3oool00P3oool00`000000
2NX:0?ooo`0N0?ooo`0300WZ2P3oool0oooo0100oooo00<02NX:0?ooo`09jPX02@3oool00`09jPX0
oooo00WZ2P0<0?ooo`800000:03oool200WZ2QP0oooo00<02NX:0?ooo`3oool05@3oool01009jPX0
oooo0?ooo`09jPX3000001H0oooo00<0000000WZ2P3oool0N@3oool00`000000oooo0?ooo`090?oo
o`002P3oool00`000000oooo0?ooo`050?ooo`0300WZ2P3oool0oooo04L0oooo00<000000?ooo`3o
ool00P3oool00`09jPX0oooo0?ooo`0N0?ooo`0300WZ2P3oool0oooo00l0oooo00D02NX:0?ooo`3o
ool0oooo00WZ2P090?ooo`802NX:303oool00`0000002NX:0?ooo`0W0?ooo`8000000`09jPXE0?oo
o`0300WZ2P3oool0oooo01@0oooo00D02NX:0?ooo`3oool0000000WZ2P03000001H0oooo00<00000
00WZ2P3oool0N@3oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`050?oo
o`0300WZ2P3oool0oooo04L0oooo00<000000?ooo`3oool00P3oool00`09jPX0oooo0?ooo`0N0?oo
o`0300WZ2P3oool0oooo00h0oooo00<02NX:0000003oool00P3oool00`09jPX0oooo0?ooo`070?oo
o`0300WZ2P0000002NX:00/0oooo00<0000000WZ2P09jPX0:`3oool00`0000002NX:0?ooo`0C0?oo
o`0300WZ2P3oool0oooo0180oooo00@0000000WZ2P3oool0oooo0`00000J0?ooo`0300000009jPX0
oooo07P0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0103oool00`09
jPX0oooo0?ooo`180?ooo`050000003oool0oooo00000009jPX08P3oool00`09jPX0oooo0?ooo`0=
0?ooo`8000000`3oool00`09jPX0oooo0?ooo`070?ooo`0400WZ2P0000002NX:000000/0oooo0P00
00000`09jPX0oooo0?ooo`0X0?ooo`80000000<02NX:0?ooo`3oool04@3oool2000001<0oooo0P00
00020?ooo`80000000<02NX:0?ooo`3oool0603oool00`0000002NX:0?ooo`1h0?ooo`030000003o
ool0oooo00T0oooo000:0?ooo`030000003oool0oooo00<0oooo00<02NX:0?ooo`3oool0B@3oool0
1@000000oooo0?ooo`0000002NX:0280oooo00<02NX:0?ooo`3oool0303oool00`09jPX0oooo0?oo
o`020?ooo`0300000009jPX0oooo00P0oooo00@02NX:0?ooo`09jPX000002`3oool20000000300WZ
2P3oool0oooo02/0oooo00<02NX:0?ooo`3oool0403oool00`0000002NX:0?ooo`0@0?ooo`030000
0009jPX0oooo00<0oooo00<02NX:0?ooo`09jPX06P3oool00`0000002NX:0?ooo`1h0?ooo`030000
003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo00<0oooo00<02NX:0?ooo`3oool0B@3o
ool010000000oooo0?ooo`09jPXS0?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool0
0`3oool00`0000002NX:0?ooo`080?ooo`0300WZ2P3oool02NX:00l0oooo00<02NX:0?ooo`3oool0
:`3oool00`09jPX0oooo0?ooo`0?0?ooo`0300000009jPX0oooo0100oooo0P0000030?ooo`0500WZ
2P3oool0oooo0?ooo`09jPX06@3oool00`000000oooo00WZ2P1h0?ooo`030000003oool0oooo00T0
oooo000:0?ooo`030000003oool0oooo0080oooo00<02NX:0?ooo`3oool0BP3oool00`000000oooo
00WZ2P0T0?ooo`0300WZ2P000000oooo00X0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0oooo
0?ooo`070?ooo`0300WZ2P3oool02NX:00h0oooo00<0000000WZ2P3oool0:`3oool00`0000002NX:
0?ooo`0@0?ooo`0300WZ2P3oool0oooo00l0oooo00D02NX:0?ooo`3oool0oooo00WZ2P040?ooo`03
00WZ2P3oool0oooo01L0oooo00<000000?ooo`09jPX0N03oool00`000000oooo0?ooo`090?ooo`00
2P3oool00`000000oooo0?ooo`020?ooo`0300WZ2P3oool0oooo04X0oooo00<0000000WZ2P3oool0
903oool00`09jPX000000?ooo`080?ooo`0300000009jPX0oooo00L0oooo00<0000000WZ2P3oool0
203oool00`09jPX000000000000>0?ooo`0300000009jPX02NX:02/0oooo0P0000000`09jPX0oooo
0?ooo`0>0?ooo`0300WZ2P3oool0oooo00l0oooo00@02NX:0?ooo`3oool02NX:1@3oool00`09jPX0
oooo0?ooo`0G0?ooo`040000003oool0oooo00WZ2WL0oooo00<000000?ooo`3oool02@3oool000X0
oooo00D000000?ooo`3oool0oooo00WZ2P1<0?ooo`0300000009jPX02NX:02H0oooo00<02NX:0?oo
o`3oool01@3oool200WZ2P800000203oool20000000300WZ2P3oool0oooo00D0oooo00@0000000WZ
2P0000002NX:3`3oool01009jPX0oooo00WZ2P00000/0?ooo`0300WZ2P3oool0oooo00d0oooo00<0
2NX:0?ooo`3oool03P3oool01009jPX0oooo00000009jPX50?ooo`0300000009jPX0oooo01P0oooo
00@000000?ooo`3oool02NX:M`3oool00`000000oooo0?ooo`090?ooo`002P3oool010000000oooo
0?ooo`09jPY=0?ooo`80000000<0oooo00WZ2P3oool09@3oool00`09jPX0oooo0?ooo`020?ooo`80
2NX:3`3oool00`09jPX0oooo0?ooo`040?ooo`0400000009jPX0oooo00WZ2Q00oooo00<02NX:0000
0009jPX0;03oool2000000l0oooo00<02NX:0?ooo`3oool03@3oool200WZ2P8000001@3oool30000
01P0oooo00@000000?ooo`3oool02NX:M`3oool00`000000oooo0?ooo`090?ooo`002P3oool01000
0000oooo0?ooo`09jPY>0?ooo`040000003oool0oooo00WZ2RH0oooo00D02NX:0?ooo`09jPX02NX:
0000000A0?ooo`0300WZ2P3oool0oooo00@0oooo00@02NX:0?ooo`3oool02NX:3`3oool01009jPX0
oooo0?ooo`09jPX[0?ooo`0300000009jPX0oooo00h0oooo00<02NX:0?ooo`3oool02`3oool200WZ
2PX0oooo0P00000H0?ooo`050000003oool0oooo0?ooo`09jPX0MP3oool00`000000oooo0?ooo`09
0?ooo`002P3oool00`000000oooo00WZ2P1?0?ooo`030000003oool0oooo008000009@3oool200WZ
2P030?ooo`00000000000180oooo0P0000050?ooo`0400WZ2P3oool0000000WZ2P`0oooo0P000000
1@09jPX0oooo0?ooo`3oool02NX:02/0oooo00<02NX:0?ooo`3oool0303oool2000000/0oooo00@0
000000WZ2P00000000002P3oool00`09jPX0oooo0?ooo`0G0?ooo`050000003oool0oooo0?ooo`09
jPX0MP3oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo00WZ2P1?0?ooo`040000
003oool0oooo000000802NX:8@3oool20000000300WZ2P3oool0000000802NX:4`3oool00`000000
2NX:00WZ2P040?ooo`<0000000<02NX:0?ooo`3oool0203oool200WZ2P0300000009jPX02NX:0080
00000`09jPXZ0?ooo`0300WZ2P3oool0oooo00`0oooo00<0000000WZ2P3oool02P3oool200000003
00WZ2P3oool0oooo00P0oooo00<0000000WZ2P3oool0603oool01@000000oooo0?ooo`3oool02NX:
07H0oooo00<000000?ooo`3oool02@3oool000X0oooo00<0000000WZ2P3oool0C`3oool00`000000
oooo0?ooo`030?ooo`<02NX:6@3oool200WZ2P0500000009jPX02NX:00000009jPX00P3oool20000
00030?ooo`09jPX0oooo01@0oooo0`09jPX01@3oool02NX:0000003oool0000000<02NX:00@0oooo
000000000000oooo0`09jPX00`3oool00000000000020?ooo`<0000000@0oooo00WZ2P09jPX02NX:
:@3oool00`09jPX0oooo0?ooo`0<0?ooo`0300WZ2P3oool0oooo00T0oooo0P09jPX;0?ooo`800000
6@3oool00`000000oooo0?ooo`020?ooo`0300WZ2P3oool0oooo07<0oooo00<000000?ooo`3oool0
2@3oool000T0oooo0P00001A0?ooo`030000003oool0oooo00H0oooo0P09jPXB0?ooo`0300000009
jPX02NX:00802NX:0P3oool4000000L0oooo00<02NX:0?ooo`3oool0503oool00`0000002NX:00WZ
2P0200WZ2P8000000P3oool2000000802NX:203oool00`09jPX000000?ooo`020?ooo`0300000009
jPX02NX:02P0oooo00<02NX:0?ooo`3oool03@3oool00`09jPX0oooo0?ooo`070?ooo`802NX:303o
ool2000001T0oooo00<000000?ooo`3oool00P3oool00`09jPX0oooo0?ooo`1c0?ooo`030000003o
ool0oooo00T0oooo00090?ooo`800000D@3oool00`000000oooo0?ooo`060?ooo`80000000<02NX:
0?ooo`3oool03@3oool200WZ2P800000403oool00`0000002NX:0?ooo`0D0?ooo`80000000D02NX:
000000000000oooo00WZ2P020?ooo`8000002P3oool00`09jPX0oooo0?ooo`040?ooo`802NX:0P00
000U0?ooo`0300WZ2P3oool0oooo00d0oooo00<02NX:0?ooo`3oool01@3oool20000000300WZ2P3o
ool0oooo00`0oooo00<02NX:0?ooo`3oool05`3oool00`000000oooo0?ooo`030?ooo`0300WZ2P3o
ool0oooo0780oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0C`3oool0
0`000000oooo0?ooo`090?ooo`0300WZ2P3oool0oooo00T0oooo0P0000000`09jPX0oooo0?ooo`0B
0?ooo`0300000009jPX0oooo01L0oooo00@02NX:0?ooo`3oool02NX:3P3oool00`09jPX0oooo0?oo
o`050?ooo`0300000009jPX02NX:02H0oooo00<02NX:0?ooo`3oool0303oool00`09jPX0oooo0?oo
o`050?ooo`0300000009jPX0000000l0oooo00<02NX:0?ooo`3oool05P3oool00`000000oooo0?oo
o`030?ooo`0300WZ2P3oool0oooo0780oooo00<000000?ooo`3oool02@3oool000X0oooo00<00000
0?ooo`3oool0C`3oool00`000000oooo0?ooo`090?ooo`0400000009jPX02NX:00WZ2PD0oooo0`09
jPX00`0000002NX:0?ooo`0F0?ooo`0300WZ2P3oool0oooo01@0oooo00D0000000WZ2P3oool0oooo
00WZ2P0>0?ooo`0300WZ2P3oool0oooo00H0oooo00@02NX:0?ooo`09jPX000008`3oool00`000000
2NX:0?ooo`0>0?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:00000009jPX04@3oool00`09jPX0
oooo0?ooo`0F0?ooo`030000003oool0oooo00<0oooo00<02NX:0?ooo`3oool0LP3oool00`000000
oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00T0oooo
0P0000000`3oool000000000000400WZ2Qd0oooo00<02NX:0000003oool04`3oool20000000400WZ
2P3oool02NX:000000h0oooo00<02NX:0?ooo`3oool01P3oool00`09jPX0000000WZ2P0S0?ooo`03
00000009jPX0oooo00d0oooo00<0000000WZ2P3oool00P3oool01009jPX0000000000000000@0?oo
o`0300000009jPX0oooo01L0oooo00<000000?ooo`3oool0103oool00`09jPX0oooo0?ooo`1a0?oo
o`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3o
ool0303oool300000200oooo00<02NX:0000003oool0503oool01@0000002NX:0?ooo`09jPX00000
00h0oooo00<02NX:0?ooo`3oool01`3oool01009jPX0000000WZ2P00000R0?ooo`8000003@3oool0
1P0000002NX:0?ooo`0000002NX:0?ooo`8000004@3oool2000001P0oooo00<000000?ooo`3oool0
103oool00`09jPX0oooo0?ooo`1a0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000003o
ool0oooo04l0oooo00<000000?ooo`3oool0<03oool00`09jPX0oooo0?ooo`0E0?ooo`0300WZ2P3o
ool02NX:00h0oooo00<02NX:0000003oool01`3oool01009jPX0000000000009jPXR0?ooo`0300WZ
2P000000oooo00h0oooo00D02NX:000000000000oooo00WZ2P0C0?ooo`0300WZ2P3oool0oooo01H0
oooo00<000000?ooo`3oool01@3oool00`09jPX0oooo0?ooo`1`0?ooo`030000003oool0oooo00T0
oooo000:0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0<@3oool00`09jPX0oooo
0?ooo`0E0?ooo`0300WZ2P000000000000d0oooo00<02NX:0000003oool0203oool01009jPX0oooo
0?ooo`09jPXQ0?ooo`0300WZ2P3oool0oooo00d0oooo0P09jPX30?ooo`0300WZ2P3oool0oooo0100
oooo00<02NX:0?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`0300WZ2P3oool0oooo0700
oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo
0?ooo`0a0?ooo`0300000009jPX02NX:01H0oooo0P09jPX=0?ooo`0300WZ2P3oool0oooo00P0oooo
00D0000000WZ2P09jPX0oooo00WZ2P0P0?ooo`0300WZ2P3oool0oooo00`0oooo00L02NX:0?ooo`3o
ool02NX:0?ooo`09jPX000000140oooo00<0000000WZ2P3oool0603oool00`000000oooo0?ooo`05
0?ooo`0300WZ2P3oool0oooo0700oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?oo
o`3oool0C`3oool00`000000oooo0?ooo`0a0?ooo`80000000<0oooo00WZ2P3oool05P3oool00`09
jPX0oooo0?ooo`0;0?ooo`0300WZ2P3oool0oooo00L0oooo0P000000103oool02NX:0?ooo`09jPXO
0?ooo`0300WZ2P3oool0oooo00T0oooo0P0000001@09jPX0oooo0?ooo`3oool02NX:00<000004@3o
ool00`0000002NX:0?ooo`0H0?ooo`030000003oool0oooo00H0oooo00<02NX:0?ooo`3oool0K`3o
ool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0
oooo03D0oooo00<02NX:0?ooo`3oool0503oool00`0000002NX:0?ooo`0:0?ooo`800000303oool0
100000002NX:0?ooo`09jPXN0?ooo`0300WZ2P3oool0oooo00T0oooo00<0000000WZ2P3oool0103o
ool00`09jPX000000?ooo`0B0?ooo`0300WZ2P3oool0oooo01L0oooo00<000000?ooo`3oool01P3o
ool00`09jPX0oooo0?ooo`1_0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0
oooo04l0oooo00<000000?ooo`3oool0=P3oool00`09jPX0oooo0?ooo`0C0?ooo`80000000<02NX:
0?ooo`3oool0203oool00`0000002NX:0?ooo`0;0?ooo`0500000009jPX0oooo00000009jPX07@3o
ool00`09jPX0oooo0?ooo`040?ooo`802NX:00<0000000WZ2P09jPX01P3oool00`09jPX0oooo00WZ
2P0C0?ooo`0300WZ2P3oool0oooo01L0oooo00<000000?ooo`3oool01P3oool00`09jPX0oooo0?oo
o`1_0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo04l0oooo00<00000
0?ooo`3oool0=`3oool00`09jPX0oooo0?ooo`0C0?ooo`0300WZ2P0000002NX:00X0oooo00<02NX:
0?ooo`3oool02`3oool0100000002NX:00000009jPXM0?ooo`0400WZ2P3oool0oooo000000<02NX:
0P3oool2000000L0oooo00@02NX:0?ooo`3oool02NX:4@3oool00`0000002NX:0?ooo`0H0?ooo`03
0000003oool0oooo00L0oooo00<02NX:0?ooo`3oool0KP3oool00`000000oooo0?ooo`090?ooo`00
2P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo03P0oooo0P09jPXC0?ooo`<00000
00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0:0?ooo`80000000<0oooo00WZ2P09jPX0
2P3oool200000100oooo0`09jPX2000000`0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo
0?ooo`0>0?ooo`0300000009jPX0oooo01P0oooo00<000000?ooo`3oool01`3oool00`09jPX0oooo
0?ooo`1^0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo04l0oooo00<0
00000?ooo`3oool0>03oool2000000802NX:4@3oool01@0000002NX:0?ooo`3oool02NX:00T0oooo
00<02NX:0?ooo`3oool03P3oool00`09jPX0oooo0?ooo`060?ooo`802NX:00<0000000WZ2P09jPX0
0`09jPX2000000L0oooo0P00000200WZ2P030000003oool0oooo00/0oooo00<0000000WZ2P3oool0
103oool00`0000002NX:0?ooo`0?0?ooo`0300WZ2P3oool0oooo01L0oooo00<000000?ooo`3oool0
203oool00`09jPX0oooo0?ooo`1]0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000003o
ool0oooo04l0oooo00<000000?ooo`3oool0?03oool200WZ2Q00oooo00D02NX:0?ooo`3oool0oooo
00WZ2P080?ooo`8000003`3oool01@0000002NX:0?ooo`3oool0000000@02NX:203oool00`000000
2NX:00WZ2P050?ooo`802NX:0P0000000`3oool02NX:0?ooo`0;0?ooo`0300WZ2P000000000000D0
oooo0P0000000`09jPX0oooo0?ooo`0<0?ooo`0300WZ2P3oool0oooo01P0oooo00<000000?ooo`3o
ool0203oool00`09jPX0oooo0?ooo`1]0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000
003oool0oooo04l0oooo00<000000?ooo`3oool0?@3oool00`0000002NX:0?ooo`0?0?ooo`0500WZ
2P3oool0oooo0?ooo`09jPX01`3oool00`0000002NX:0?ooo`0>0?ooo`0400000009jPX02NX:00WZ
2P<000003@3oool300WZ2P0300000009jPX0oooo00@0oooo00<02NX:0?ooo`3oool02@3oool00`09
jPX0oooo0?ooo`090?ooo`802NX:2`3oool00`09jPX0oooo0?ooo`0I0?ooo`030000003oool0oooo
00P0oooo00<02NX:0?ooo`3oool0K@3oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000
oooo0?ooo`1?0?ooo`030000003oool0oooo03d0oooo0P0000000`09jPX0oooo0?ooo`0<0?ooo`03
00000009jPX0oooo00<0oooo00<02NX:0?ooo`3oool01@3oool00`09jPX0oooo0?ooo`0>0?ooo`80
2NX:00<0000000WZ2P09jPX0403oool00`0000002NX:00WZ2P060?ooo`0300WZ2P3oool0oooo00L0
oooo00<02NX:0?ooo`3oool02P3oool20000000300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3o
ool06@3oool00`000000oooo0?ooo`090?ooo`0300WZ2P3oool0oooo06`0oooo00<000000?ooo`3o
ool02@3oool000X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`100?ooo`800000
303oool00`0000002NX:0?ooo`030?ooo`0300000009jPX02NX:00D0oooo00<02NX:0?ooo`3oool0
2`3oool02@0000002NX:00WZ2P000000oooo00WZ2P000000oooo00WZ2P0>0?ooo`0500WZ2P000000
00000?ooo`09jPX01@3oool00`09jPX0oooo0?ooo`040?ooo`80000000<02NX:0?ooo`3oool03P3o
ool200WZ2PH0oooo00<0000000WZ2P3oool06`3oool00`000000oooo0?ooo`090?ooo`0300WZ2P3o
ool0oooo06`0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0C`3oool0
0`000000oooo0?ooo`100?ooo`0300000009jPX0oooo00d0oooo00@02NX:0?ooo`3oool0oooo0P00
00000`3oool02NX:00WZ2P030?ooo`0300WZ2P3oool0oooo00P0oooo0`09jPX4000000030?ooo`09
jPX0oooo0080oooo0P09jPX:0?ooo`802NX:103oool00`0000002NX:00WZ2P030?ooo`8000001@3o
ool00`0000002NX:0?ooo`0B0?ooo`0300WZ2P3oool0oooo00<0oooo0P00000L0?ooo`030000003o
ool0oooo00X0oooo00<02NX:0?ooo`3oool0J`3oool00`000000oooo0?ooo`090?ooo`002P3oool0
0`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0440oooo00<02NX:0?ooo`3oool0303oool0
0`09jPX0oooo0?ooo`060?ooo`0500WZ2P3oool0oooo0?ooo`09jPX01P3oool300WZ2PT0oooo0P00
00030?ooo`0300WZ2P3oool0oooo00H0oooo00<02NX:0?ooo`3oool0103oool2000000030?ooo`09
jPX000000080000000<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`0C0?ooo`0300000009
jPX0oooo00<0oooo00<02NX:0?ooo`3oool06`3oool00`000000oooo0?ooo`0:0?ooo`0300WZ2P3o
ool0oooo06/0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0C`3oool0
0`000000oooo0?ooo`120?ooo`0300WZ2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool01P3oool0
1@0000002NX:00WZ2P3oool02NX:00@0oooo0P09jPX00`000000oooo0?ooo`090?ooo`0300000009
jPX0oooo0080oooo00<0000000WZ2P09jPX0103oool00`0000002NX:0?ooo`0:0?ooo`0400000009
jPX02NX:00WZ2P<0oooo00<02NX:0?ooo`3oool0503oool20000000500WZ2P3oool0oooo0?ooo`09
jPX07@3oool00`000000oooo0?ooo`0:0?ooo`0300WZ2P3oool0oooo06/0oooo00<000000?ooo`3o
ool02@3oool000X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`130?ooo`0300WZ
2P3oool0oooo00/0oooo00<02NX:0?ooo`3oool01@3oool2000000050?ooo`09jPX02NX:0?ooo`00
00000P09jPX00`3oool000000000000=0?ooo`0300WZ2P3oool0oooo0080000000D0oooo00WZ2P09
jPX0oooo00WZ2P02000000h0oooo0P09jPX00`3oool02NX:0?ooo`0I0?ooo`0400WZ2P3oool02NX:
000001d0oooo00<000000?ooo`3oool02`3oool00`09jPX0oooo0?ooo`1Z0?ooo`030000003oool0
oooo00T0oooo000:0?ooo`030000003oool0oooo04l0ooooA`00000200WZ2P/0000000<02NX:0000
000000002@00000200WZ2Q@000000P09jPX50000000300WZ2P000000000000l0000000<02NX:0000
0009jPX0700000000`09jPX000000000000N000000d0oooo00<02NX:0?ooo`3oool0JP3oool00`00
0000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`2F0?ooo`80000000<02NX:0?ooo`3o
ool01`3oool00`0000002NX:0?ooo`090?ooo`0300000009jPX0oooo01<0oooo0P000000103oool0
2NX:00WZ2P09jPX20?ooo`8000003`3oool00`0000002NX:00000002000001/0oooo0P00000/0?oo
o`0300WZ2P3oool0oooo06X0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3o
ool0V@3oool200WZ2PT0oooo00<02NX:0?ooo`3oool0203oool00`09jPX0oooo0?ooo`0H0?ooo`80
2NX:4P3oool00`09jPX0oooo0?ooo`1;0?ooo`0300WZ2P3oool0oooo06T0oooo00<000000?ooo`3o
ool02@3oool000X0oooo00<000000?ooo`3oool0V`3oool200WZ2PL0oooo00<02NX:0?ooo`3oool0
2@3oool00`09jPX0oooo0?ooo`0I0?ooo`<02NX:403oool00`09jPX0oooo0?ooo`1:0?ooo`0300WZ
2P3oool0oooo06T0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0W@3o
ool00`09jPX0oooo0?ooo`050?ooo`0300WZ2P3oool0oooo00P0oooo00<02NX:0?ooo`3oool0703o
ool300WZ2Pd0oooo00<02NX:0?ooo`3oool0B`3oool00`09jPX0oooo0?ooo`1X0?ooo`030000003o
ool0oooo00T0oooo000:0?ooo`030000003oool0oooo09h0oooo0P09jPX50?ooo`0300WZ2P3oool0
oooo00P0oooo00<02NX:0?ooo`3oool07`3oool200WZ2P/0oooo00<02NX:0?ooo`3oool0B`3oool0
0`09jPX0oooo0?ooo`1X0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo
0:00oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`070?ooo`0300WZ2P3oool0oooo
0240oooo0`09jPX80?ooo`0300WZ2P3oool0oooo04/0oooo00<02NX:0?ooo`3oool0J03oool00`00
0000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`2Q0?ooo`802NX:0`3oool00`09jPX0
oooo0?ooo`080?ooo`0300WZ2P3oool0oooo02<0oooo0P09jPX70?ooo`0300WZ2P3oool0oooo04/0
oooo00<02NX:0?ooo`3oool0I`3oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo
0?ooo`2S0?ooo`802NX:00<0oooo00WZ2P3oool02@3oool00`09jPX0oooo0?ooo`0U0?ooo`<02NX:
103oool00`09jPX0oooo0?ooo`1;0?ooo`0300WZ2P3oool0oooo06L0oooo00<000000?ooo`3oool0
2@3oool000X0oooo00<000000?ooo`3oool0Y@3oool00`09jPX0oooo00WZ2P090?ooo`0300WZ2P3o
ool0oooo02P0oooo0P09jPX20?ooo`0300WZ2P3oool0oooo04`0oooo00<02NX:0?ooo`3oool0IP3o
ool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`2V0?ooo`802NX:2@3oool0
0`09jPX0oooo0?ooo`0Z0?ooo`<02NX:CP3oool00`09jPX0oooo0?ooo`1V0?ooo`030000003oool0
oooo00T0oooo000:0?ooo`030000003oool0oooo0:P0oooo0P09jPX80?ooo`0300WZ2P3oool0oooo
02`0oooo0`09jPY;0?ooo`0300WZ2P3oool0oooo06H0oooo00<000000?ooo`3oool02@3oool000X0
oooo00<000000?ooo`3oool0Z03oool00`09jPX0oooo00WZ2P070?ooo`0300WZ2P3oool0oooo02`0
oooo00<02NX:0?ooo`3oool00P09jPY:0?ooo`0300WZ2P3oool0oooo06D0oooo00<000000?ooo`3o
ool02@3oool000X0oooo00<000000?ooo`3oool0Z@3oool01009jPX0oooo00WZ2P09jPX50?ooo`03
00WZ2P3oool0oooo02`0oooo00<02NX:0?ooo`3oool00P3oool300WZ2TL0oooo00<02NX:0?ooo`3o
ool0I@3oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`2Y0?ooo`0500WZ
2P3oool0oooo0?ooo`09jPX01@3oool00`09jPX0oooo0?ooo`0[0?ooo`0300WZ2P3oool0oooo00D0
oooo0P09jPY50?ooo`0300WZ2P3oool0oooo06D0oooo00<000000?ooo`3oool02@3oool000X0oooo
00<000000?ooo`3oool0ZP3oool01009jPX0oooo0?ooo`3oool200WZ2P<0oooo00<02NX:0?ooo`3o
ool0;03oool00`09jPX0oooo0?ooo`060?ooo`<02NX:@`3oool00`09jPX0oooo0?ooo`1T0?ooo`03
0000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo0:X0oooo00<02NX:0?ooo`3oool0
0`3oool200WZ2P030?ooo`09jPX0oooo02d0oooo00<02NX:0?ooo`3oool02@3oool200WZ2T40oooo
00<02NX:0?ooo`3oool0I03oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?oo
o`2[0?ooo`0300WZ2P3oool0oooo00@0oooo0P09jPX^0?ooo`0300WZ2P3oool0oooo00/0oooo0`09
jPXo0?ooo`0300WZ2P3oool0oooo06<0oooo00<000000?ooo`3oool02@3oool000X0oooo00<00000
0?ooo`3oool0Z`3oool00`09jPX0oooo0?ooo`050?ooo`802NX:;@3oool00`09jPX0oooo0?ooo`0>
0?ooo`<02NX:?03oool00`09jPX0oooo0?ooo`1S0?ooo`030000003oool0oooo00T0oooo000:0?oo
o`030000003oool0oooo0:/0oooo00<02NX:0?ooo`3oool01P3oool200WZ2R`0oooo00<02NX:0?oo
o`3oool04@3oool200WZ2SX0oooo00<02NX:0?ooo`3oool0H`3oool00`000000oooo0?ooo`090?oo
o`002P3oool00`000000oooo0?ooo`2/0?ooo`0300WZ2P3oool0oooo00D0oooo00@02NX:0?ooo`09
jPX02NX::`3oool00`09jPX0oooo0?ooo`0B0?ooo`<02NX:>03oool00`09jPX0oooo0?ooo`1R0?oo
o`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo0:`0oooo00<02NX:0?ooo`3o
ool01@3oool01009jPX0oooo0?ooo`3oool200WZ2RT0oooo00<02NX:0?ooo`3oool05@3oool200WZ
2SH0oooo00<02NX:0?ooo`3oool0HP3oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000
oooo0?ooo`2]0?ooo`0300WZ2P3oool0oooo00D0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0
oooo0?ooo`0V0?ooo`0300WZ2P3oool0oooo01L0oooo0`09jPXd0?ooo`0300WZ2P3oool0oooo0640
oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0[@3oool00`09jPX0oooo
0?ooo`050?ooo`0300WZ2P3oool0oooo00<0oooo0P09jPXV0?ooo`0300WZ2P3oool0oooo01X0oooo
0P09jPXb0?ooo`0300WZ2P3oool0oooo0640oooo00<000000?ooo`3oool02@3oool000X0oooo00<0
00000?ooo`3oool0[P3oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo00D0oooo00<0
2NX:0?ooo`3oool0903oool00`09jPX0oooo0?ooo`0K0?ooo`<02NX:;`3oool00`09jPX0oooo0?oo
o`1Q0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo0:h0oooo00<02NX:
0?ooo`3oool0103oool00`09jPX0oooo0?ooo`060?ooo`802NX:903oool00`09jPX0oooo0?ooo`0N
0?ooo`<02NX:;@3oool00`09jPX0oooo0?ooo`1P0?ooo`030000003oool0oooo00T0oooo000:0?oo
o`030000003oool0oooo0:l0oooo00<02NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`070?oo
o`802NX:8P3oool00`09jPX0oooo0?ooo`0Q0?ooo`802NX::`3oool00`09jPX0oooo0?ooo`1P0?oo
o`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo0:l0oooo00<02NX:0?ooo`3o
ool0103oool00`09jPX0oooo0?ooo`090?ooo`0300WZ2P3oool0oooo01l0oooo00<02NX:0?ooo`3o
ool08`3oool300WZ2RP0oooo00<02NX:0?ooo`3oool0H03oool00`000000oooo0?ooo`090?ooo`00
2P3oool00`000000oooo0?ooo`2`0?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0
2P3oool200WZ2R00oooo00<02NX:0?ooo`3oool09@3oool200WZ2RL0oooo00<02NX:0?ooo`3oool0
G`3oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`2`0?ooo`0300WZ2P3o
ool0oooo00<0oooo00<02NX:0?ooo`3oool0303oool200WZ2Qh0oooo00<02NX:0?ooo`3oool09`3o
ool300WZ2R@0oooo00<02NX:0?ooo`3oool0G`3oool00`000000oooo0?ooo`090?ooo`002P3oool0
0`000000oooo0?ooo`2`0?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool03@3oool0
0`09jPX0oooo0?ooo`0K0?ooo`0300WZ2P3oool0oooo02X0oooo0P09jPXS0?ooo`0300WZ2P3oool0
oooo05h0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0/@3oool00`09
jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo00h0oooo0P09jPXK0?ooo`0300WZ2P3oool0oooo
02`0oooo0`09jPXP0?ooo`0300WZ2P3oool0oooo05h0oooo00<000000?ooo`3oool02@3oool000X0
oooo00<000000?ooo`3oool0/@3oool00`09jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo0100
oooo00<02NX:0?ooo`3oool06@3oool00`09jPX0oooo0?ooo`0^0?ooo`<02NX:7@3oool00`09jPX0
oooo0?ooo`1N0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo0;80oooo
00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?ooo`0@0?ooo`802NX:6@3oool00`09jPX0oooo
0?ooo`0a0?ooo`802NX:703oool00`09jPX0oooo0?ooo`1M0?ooo`030000003oool0oooo00T0oooo
000:0?ooo`030000003oool0oooo0;80oooo00<02NX:0?ooo`3oool00`3oool00`09jPX0oooo0?oo
o`0B0?ooo`802NX:5`3oool00`09jPX0oooo0?ooo`0c0?ooo`<02NX:6@3oool00`09jPX0oooo0?oo
o`1M0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo0;<0oooo00<02NX:
0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`0D0?ooo`0300WZ2P3oool0oooo01@0oooo00<02NX:
0?ooo`3oool0=P3oool200WZ2QP0oooo00<02NX:0?ooo`3oool0G03oool00`000000oooo0?ooo`09
0?ooo`002P3oool00`000000oooo0?ooo`2c0?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?oo
o`3oool05@3oool200WZ2QD0oooo00<02NX:0?ooo`3oool0=`3oool300WZ2QD0oooo00<02NX:0?oo
o`3oool0G03oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`2d0?ooo`03
00WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool05P3oool00`09jPX0oooo0?ooo`0B0?ooo`03
00WZ2P3oool0oooo03X0oooo0P09jPXC0?ooo`0300WZ2P3oool0oooo05`0oooo00<000000?ooo`3o
ool02@3oool000X0oooo00<000000?ooo`3oool0]03oool00`09jPX0oooo0?ooo`020?ooo`0300WZ
2P3oool0oooo01L0oooo0P09jPXB0?ooo`0300WZ2P3oool0oooo03`0oooo0`09jPXA0?ooo`0300WZ
2P3oool0oooo05/0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0]@3o
ool01@09jPX0oooo0?ooo`3oool02NX:01/0oooo0P09jPX@0?ooo`0300WZ2P3oool0oooo03l0oooo
0`09jPX>0?ooo`0300WZ2P3oool0oooo05/0oooo00<000000?ooo`3oool02@3oool000X0oooo00<0
00000?ooo`3oool0]@3oool01@09jPX0oooo0?ooo`3oool02NX:01d0oooo00<02NX:0?ooo`3oool0
3P3oool00`09jPX0oooo0?ooo`110?ooo`802NX:3@3oool00`09jPX0oooo0?ooo`1J0?ooo`030000
003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo0;D0oooo00<02NX:0?ooo`3oool00P3o
ool00`09jPX0oooo0?ooo`0K0?ooo`802NX:3P3oool00`09jPX0oooo0?ooo`130?ooo`<02NX:2P3o
ool00`09jPX0oooo0?ooo`1J0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0
oooo0;H0oooo00D02NX:0?ooo`3oool0oooo00WZ2P0O0?ooo`0300WZ2P3oool0oooo00/0oooo00<0
2NX:0?ooo`3oool0AP3oool200WZ2PP0oooo00<02NX:0?ooo`3oool0FP3oool00`000000oooo0?oo
o`090?ooo`002P3oool00`000000oooo0?ooo`2f0?ooo`0500WZ2P3oool0oooo0?ooo`09jPX0803o
ool200WZ2P/0oooo00<02NX:0?ooo`3oool0B03oool300WZ2PH0oooo00<02NX:0?ooo`3oool0F@3o
ool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`2g0?ooo`0400WZ2P3oool0
oooo00WZ2R80oooo0P09jPX:0?ooo`0300WZ2P3oool0oooo04X0oooo0`09jPX30?ooo`0300WZ2P3o
ool0oooo05T0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0]`3oool0
1@09jPX0oooo0?ooo`3oool02NX:02<0oooo00<02NX:0?ooo`3oool01`3oool00`09jPX0oooo0?oo
o`1=0?ooo`802NX:00<0oooo00WZ2P3oool0FP3oool00`000000oooo0?ooo`090?ooo`002P3oool0
0`000000oooo0?ooo`2h0?ooo`0400WZ2P3oool0oooo00WZ2R@0oooo0P09jPX70?ooo`0300WZ2P3o
ool0oooo04l0oooo0`09jPYJ0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0
oooo0;P0oooo00@02NX:0?ooo`3oool02NX:9P3oool200WZ2PD0oooo00<02NX:0?ooo`3oool0D@3o
ool300WZ2UP0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0^@3oool0
0`09jPX0oooo00WZ2P0X0?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0D@3oool0
0`09jPX0oooo00WZ2P0200WZ2UD0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?oo
o`3oool0^@3oool01009jPX0oooo0?ooo`09jPXX0?ooo`802NX:0`3oool00`09jPX0oooo0?ooo`1A
0?ooo`0300WZ2P3oool0oooo0080oooo0P09jPYC0?ooo`030000003oool0oooo00T0oooo000:0?oo
o`030000003oool0oooo0;X0oooo00<02NX:0?ooo`09jPX0:P3oool01009jPX0oooo0?ooo`09jPYC
0?ooo`0300WZ2P3oool0oooo00@0oooo0`09jPY@0?ooo`030000003oool0oooo00T0oooo000:0?oo
o`030000003oool0oooo0;X0oooo00<02NX:0?ooo`09jPX0:`3oool300WZ2U@0oooo00<02NX:0?oo
o`3oool01P3oool300WZ2Td0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3o
ool0^`3oool00`09jPX0oooo00WZ2P0/0?ooo`802NX:D`3oool00`09jPX0oooo0?ooo`090?ooo`80
2NX:B`3oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`2k0?ooo`0300WZ
2P3oool02NX:02d0oooo0P09jPYC0?ooo`0300WZ2P3oool0oooo00X0oooo0`09jPY80?ooo`030000
003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo0;/0oooo00<02NX:0?ooo`09jPX0;@3o
ool01009jPX0oooo00WZ2P09jPYA0?ooo`0300WZ2P3oool0oooo00d0oooo0P09jPY60?ooo`030000
003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo0;`0oooo0P09jPX]0?ooo`0500WZ2P3o
ool0oooo0?ooo`09jPX0D03oool00`09jPX0oooo0?ooo`0?0?ooo`<02NX:@`3oool00`000000oooo
0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`2l0?ooo`0300WZ2P3oool02NX:02`0oooo00<0
2NX:0?ooo`3oool00P3oool200WZ2Tl0oooo00<02NX:0?ooo`3oool04@3oool200WZ2T40oooo00<0
00000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0_@3oool200WZ2Rd0oooo00<02NX:
0?ooo`3oool00`3oool200WZ2Td0oooo00<02NX:0?ooo`3oool04`3oool300WZ2Sh0oooo00<00000
0?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0_@3oool200WZ2Rd0oooo00<02NX:0?oo
o`3oool01@3oool00`09jPX0oooo0?ooo`1:0?ooo`0300WZ2P3oool0oooo01H0oooo0`09jPXk0?oo
o`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo0;h0oooo00<02NX:0?ooo`3o
ool0:`3oool00`09jPX0oooo0?ooo`060?ooo`802NX:B`3oool00`09jPX0oooo0?ooo`0H0?ooo`80
2NX:>@3oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`2n0?ooo`802NX:
;03oool00`09jPX0oooo0?ooo`080?ooo`802NX:B@3oool00`09jPX0oooo0?ooo`0J0?ooo`<02NX:
=P3oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`2o0?ooo`0300WZ2P3o
ool0oooo02/0oooo00<02NX:0?ooo`3oool02@3oool00`09jPX0oooo0?ooo`170?ooo`0300WZ2P3o
ool0oooo01`0oooo0P09jPXd0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0
oooo0;l0oooo00<02NX:0?ooo`3oool0:`3oool00`09jPX0oooo0?ooo`0:0?ooo`802NX:A`3oool0
0`09jPX0oooo0?ooo`0N0?ooo`<02NX:<@3oool00`000000oooo0?ooo`090?ooo`002P3oool00`00
0000oooo0?ooo`2o0?ooo`802NX:;03oool00`09jPX0oooo0?ooo`0<0?ooo`0300WZ2P3oool0oooo
04@0oooo00<02NX:0?ooo`3oool08@3oool200WZ2Rl0oooo00<000000?ooo`3oool02@3oool000X0
oooo00<000000?ooo`3oool0`03oool00`09jPX0oooo0?ooo`0Z0?ooo`0300WZ2P3oool0oooo00d0
oooo0P09jPY50?ooo`0300WZ2P3oool0oooo0280oooo0`09jPX/0?ooo`030000003oool0oooo00T0
oooo000:0?ooo`030000003oool0oooo0<00oooo00<02NX:0?ooo`3oool0:`3oool00`09jPX0oooo
0?ooo`0>0?ooo`802NX:@`3oool00`09jPX0oooo0?ooo`0U0?ooo`<02NX::@3oool00`000000oooo
0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`300?ooo`802NX:;03oool00`09jPX0oooo0?oo
o`0@0?ooo`0300WZ2P3oool0oooo0440oooo00<02NX:0?ooo`3oool09`3oool200WZ2RL0oooo00<0
00000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0`03oool200WZ2R`0oooo00<02NX:
0?ooo`3oool04@3oool200WZ2T40oooo00<02NX:0?ooo`3oool0:@3oool300WZ2R@0oooo00<00000
0?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0`@3oool200WZ2R/0oooo00<02NX:0?oo
o`3oool04`3oool00`09jPX0oooo0?ooo`0n0?ooo`0300WZ2P3oool0oooo02`0oooo0P09jPXR0?oo
o`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo0<40oooo0P09jPX/0?ooo`03
00WZ2P3oool0oooo01<0oooo0P09jPXo0?ooo`0300WZ2P3oool0oooo02d0oooo0`09jPXO0?ooo`03
0000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo0<40oooo00<02NX:0?ooo`09jPX0
:`3oool00`09jPX0oooo0?ooo`0E0?ooo`802NX:?@3oool00`09jPX0oooo0?ooo`0`0?ooo`802NX:
7@3oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`310?ooo`0300WZ2P3o
ool02NX:02/0oooo00<02NX:0?ooo`3oool05`3oool00`09jPX0oooo0?ooo`0j0?ooo`0300WZ2P3o
ool0oooo0380oooo0`09jPXJ0?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0
oooo0<80oooo00<02NX:0?ooo`09jPX0:P3oool00`09jPX0oooo0?ooo`0H0?ooo`802NX:>`3oool0
0`09jPX0oooo0?ooo`0d0?ooo`<02NX:5`3oool00`000000oooo0?ooo`090?ooo`002P3oool00`00
0000oooo0?ooo`320?ooo`0300WZ2P3oool02NX:02/0oooo00<02NX:0?ooo`3oool06@3oool00`09
jPX0oooo0?ooo`0h0?ooo`0300WZ2P3oool0oooo03L0oooo0P09jPXE0?ooo`030000003oool0oooo
00T0oooo000:0?ooo`030000003oool0oooo0<80oooo00@02NX:0?ooo`3oool02NX::P3oool00`09
jPX0oooo0?ooo`0J0?ooo`802NX:>@3oool00`09jPX0oooo0?ooo`0h0?ooo`<02NX:4P3oool00`00
0000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`330?ooo`0300WZ2P3oool02NX:02X0
oooo00<02NX:0?ooo`3oool0703oool200WZ2SL0oooo00<02NX:0?ooo`3oool0>`3oool200WZ2Q00
oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0``3oool00`09jPX0oooo
00WZ2P0Z0?ooo`0300WZ2P3oool0oooo01h0oooo00<02NX:0?ooo`3oool0=03oool00`09jPX0oooo
0?ooo`0m0?ooo`<02NX:3@3oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?oo
o`330?ooo`0400WZ2P3oool0oooo00WZ2RX0oooo00<02NX:0?ooo`3oool07P3oool200WZ2SD0oooo
00<02NX:0?ooo`3oool0?`3oool200WZ2P/0oooo00<000000?ooo`3oool02@3oool000X0oooo00<0
00000?ooo`3oool0``3oool01009jPX0oooo0?ooo`09jPXZ0?ooo`0300WZ2P3oool0oooo0200oooo
0P09jPXc0?ooo`0300WZ2P3oool0oooo0440oooo0`09jPX80?ooo`030000003oool0oooo00T0oooo
000:0?ooo`030000003oool0oooo0<@0oooo00@02NX:0?ooo`3oool02NX::@3oool00`09jPX0oooo
0?ooo`0R0?ooo`0300WZ2P3oool0oooo0340oooo00<02NX:0?ooo`3oool0@`3oool300WZ2PD0oooo
00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0a03oool01009jPX0oooo0?oo
o`09jPXY0?ooo`0300WZ2P3oool0oooo02<0oooo0P09jPXa0?ooo`0300WZ2P3oool0oooo04H0oooo
0P09jPX30?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo0<@0oooo00D0
2NX:0?ooo`3oool0oooo00WZ2P0Y0?ooo`0300WZ2P3oool0oooo02@0oooo00<02NX:0?ooo`3oool0
;P3oool00`09jPX0oooo0?ooo`180?ooo`802NX:0P00000;0?ooo`002P3oool00`000000oooo0?oo
o`340?ooo`0500WZ2P3oool0oooo0?ooo`09jPX0:@3oool00`09jPX0oooo0?ooo`0U0?ooo`802NX:
;`3oool00`09jPX0oooo0?ooo`190?ooo`8000002`3oool000X0oooo00<000000?ooo`3oool0a@3o
ool01@09jPX0oooo0?ooo`3oool02NX:02P0oooo00<02NX:0?ooo`3oool09`3oool200WZ2Rd0oooo
00<02NX:0?ooo`3oool0BP3oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?oo
o`350?ooo`0500WZ2P3oool0oooo0?ooo`09jPX0:03oool00`09jPX0oooo0?ooo`0Y0?ooo`0300WZ
2P3oool0oooo02X0oooo00<02NX:0?ooo`3oool0BP3oool00`000000oooo0?ooo`090?ooo`002P3o
ool00`000000oooo0?ooo`350?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3oool09P3o
ool00`09jPX0oooo0?ooo`0Y0?ooo`802NX::`3oool00`09jPX0oooo0?ooo`190?ooo`030000003o
ool0oooo00T0oooo000:0?ooo`030000003oool0oooo0<D0oooo00<02NX:0?ooo`3oool00P3oool0
0`09jPX0oooo0?ooo`0V0?ooo`0300WZ2P3oool0oooo02/0oooo00<02NX:0?ooo`3oool0:03oool0
0`09jPX0oooo0?ooo`190?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo
0<H0oooo00D02NX:0?ooo`3oool0oooo00WZ2P0X0?ooo`0300WZ2P3oool0oooo02`0oooo0P09jPXY
0?ooo`0300WZ2P3oool0oooo04P0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?oo
o`3oool0aP3oool00`09jPX0oooo0?ooo`020?ooo`0300WZ2P3oool0oooo02D0oooo00<02NX:0?oo
o`3oool0;P3oool200WZ2RL0oooo00<02NX:0?ooo`3oool0B03oool00`000000oooo0?ooo`090?oo
o`002P3oool00`000000oooo0?ooo`360?ooo`0300WZ2P3oool0oooo0080oooo00<02NX:0?ooo`3o
ool09@3oool00`09jPX0oooo0?ooo`0`0?ooo`0300WZ2P3oool0oooo02@0oooo00<02NX:0?ooo`3o
ool0B03oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`360?ooo`0300WZ
2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool09@3oool00`09jPX0oooo0?ooo`0`0?ooo`802NX:
9@3oool00`09jPX0oooo0?ooo`170?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000003o
ool0oooo0<L0oooo00<02NX:0?ooo`3oool00P3oool00`09jPX0oooo0?ooo`0U0?ooo`0300WZ2P3o
ool0oooo0380oooo00<02NX:0?ooo`3oool08P3oool00`09jPX0oooo0?ooo`170?ooo`030000003o
ool0oooo00T0oooo000:0?ooo`030000003oool0oooo0<L0oooo00<02NX:0?ooo`3oool00`3oool0
0`09jPX0oooo0?ooo`0T0?ooo`0300WZ2P3oool0oooo03<0oooo0P09jPXS0?ooo`0300WZ2P3oool0
oooo04H0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0a`3oool00`09
jPX0oooo0?ooo`030?ooo`0300WZ2P3oool0oooo02@0oooo00<02NX:0?ooo`3oool0=@3oool200WZ
2R40oooo00<02NX:0?ooo`3oool0AP3oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000
oooo0?ooo`380?ooo`0300WZ2P3oool0oooo00<0oooo00<02NX:0?ooo`3oool0903oool00`09jPX0
oooo0?ooo`0f0?ooo`0300WZ2P3oool0oooo01h0oooo00<02NX:0?ooo`3oool0AP3oool00`000000
oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`380?ooo`0300WZ2P3oool0oooo00<0oooo
00<02NX:0?ooo`3oool0903oool00`09jPX0oooo0?ooo`0g0?ooo`802NX:7`3oool00`09jPX0oooo
0?ooo`150?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo0<P0oooo00<0
2NX:0?ooo`3oool0103oool00`09jPX0oooo0?ooo`0S0?ooo`0300WZ2P3oool0oooo03T0oooo0P09
jPXM0?ooo`0300WZ2P3oool0oooo04D0oooo00<000000?ooo`3oool02@3oool000X0oooo00<00000
0?ooo`3oool0b03oool00`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo02<0oooo00<02NX:
0?ooo`3oool0>`3oool00`09jPX0oooo0?ooo`0J0?ooo`0300WZ2P3oool0oooo04D0oooo00<00000
0?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0b@3oool00`09jPX0oooo0?ooo`030?oo
o`0300WZ2P3oool0oooo02@0oooo00<02NX:0?ooo`3oool0>`3oool200WZ2Q/0oooo00<02NX:0?oo
o`3oool0A03oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`390?ooo`03
00WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool08`3oool00`09jPX0oooo0?ooo`0m0?ooo`03
00WZ2P3oool0oooo01P0oooo00<02NX:0?ooo`3oool0A03oool00`000000oooo0?ooo`090?ooo`00
2P3oool00`000000oooo0?ooo`390?ooo`0300WZ2P3oool0oooo00@0oooo00<02NX:0?ooo`3oool0
8`3oool00`09jPX0oooo0?ooo`0n0?ooo`802NX:6@3oool00`09jPX0oooo0?ooo`130?ooo`030000
003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo0<T0oooo00<02NX:0?ooo`3oool01@3o
ool00`09jPX0oooo0?ooo`0R0?ooo`0300WZ2P3oool0oooo0400oooo0P09jPXG0?ooo`0300WZ2P3o
ool0oooo04<0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0bP3oool0
0`09jPX0oooo0?ooo`040?ooo`0300WZ2P3oool0oooo02<0oooo00<02NX:0?ooo`3oool0@@3oool0
0`09jPX0oooo0?ooo`0D0?ooo`0300WZ2P3oool0oooo04<0oooo00<000000?ooo`3oool02@3oool0
00X0ooooo`00002M000000/0oooo003F0?ooo`8000001P3oool2000002<0oooo0P0000130?ooo`80
00005@3oool200000500oooo003o0?oook80oooo003o0?oook80oooo003o0?oook80oooo003o0?oo
ok80oooo003o0?oook80oooo003o0?oook80oooo003o0?oook80oooo003o0?oook80oooo003o0?oo
ok80oooo0000\
\>"],
  ImageRangeCache->{{{0, 432}, {432, 0}} -> {-1.25026, -26.2503, 0.121529, \
0.121529}},
  CellTags->"Bulk Diffusion with MonteCarlo Random Walk"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 694}},
WindowSize->{816, 663},
WindowMargins->{{9, Automatic}, {Automatic, 21}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Bulk Diffusion with MonteCarlo Random Walk"->{
    Cell[1776, 53, 119, 1, 56, "Section",
      CellTags->"Bulk Diffusion with MonteCarlo Random Walk"],
    Cell[1920, 58, 104, 1, 42, "Subsubsection",
      CellTags->"Bulk Diffusion with MonteCarlo Random Walk"],
    Cell[2027, 61, 96, 1, 39, "Input",
      CellTags->"Bulk Diffusion with MonteCarlo Random Walk"],
    Cell[2126, 64, 4173, 133, 1869, "Input",
      CellTags->"Bulk Diffusion with MonteCarlo Random Walk"],
    Cell[6336, 202, 106, 1, 28, "Subsubsection",
      CellTags->"Bulk Diffusion with MonteCarlo Random Walk"],
    Cell[6445, 205, 96, 1, 27, "Input",
      CellTags->"Bulk Diffusion with MonteCarlo Random Walk"],
    Cell[6544, 208, 225, 6, 42, "Input",
      CellTags->"Bulk Diffusion with MonteCarlo Random Walk"],
    Cell[6772, 216, 921, 39, 567, "Input",
      CellTags->"Bulk Diffusion with MonteCarlo Random Walk"],
    Cell[7730, 260, 88, 1, 28, "Subsubsection",
      CellTags->"Bulk Diffusion with MonteCarlo Random Walk"],
    Cell[7843, 265, 124, 1, 27, "Input",
      CellTags->"Bulk Diffusion with MonteCarlo Random Walk"],
    Cell[7970, 268, 143, 3, 27, "Output",
      CellTags->"Bulk Diffusion with MonteCarlo Random Walk"],
    Cell[8150, 276, 195, 4, 42, "Input",
      CellTags->"Bulk Diffusion with MonteCarlo Random Walk"],
    Cell[8348, 282, 44009, 1364, 296, 12134, 966, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Bulk Diffusion with MonteCarlo Random Walk"],
    Cell[52394, 1651, 150, 4, 27, "Input",
      CellTags->"Bulk Diffusion with MonteCarlo Random Walk"],
    Cell[52547, 1657, 275224, 12558, 441, 134387, 10814, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"Bulk Diffusion with MonteCarlo Random Walk"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Bulk Diffusion with MonteCarlo Random Walk", 328430, 14235}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 119, 1, 56, "Section",
  CellTags->"Bulk Diffusion with MonteCarlo Random Walk"],

Cell[CellGroupData[{
Cell[1920, 58, 104, 1, 42, "Subsubsection",
  CellTags->"Bulk Diffusion with MonteCarlo Random Walk"],
Cell[2027, 61, 96, 1, 39, "Input",
  CellTags->"Bulk Diffusion with MonteCarlo Random Walk"],
Cell[2126, 64, 4173, 133, 1869, "Input",
  CellTags->"Bulk Diffusion with MonteCarlo Random Walk"]
}, Closed]],

Cell[CellGroupData[{
Cell[6336, 202, 106, 1, 28, "Subsubsection",
  CellTags->"Bulk Diffusion with MonteCarlo Random Walk"],
Cell[6445, 205, 96, 1, 27, "Input",
  CellTags->"Bulk Diffusion with MonteCarlo Random Walk"],
Cell[6544, 208, 225, 6, 42, "Input",
  CellTags->"Bulk Diffusion with MonteCarlo Random Walk"],
Cell[6772, 216, 921, 39, 567, "Input",
  CellTags->"Bulk Diffusion with MonteCarlo Random Walk"]
}, Closed]],

Cell[CellGroupData[{
Cell[7730, 260, 88, 1, 28, "Subsubsection",
  CellTags->"Bulk Diffusion with MonteCarlo Random Walk"],

Cell[CellGroupData[{
Cell[7843, 265, 124, 1, 27, "Input",
  CellTags->"Bulk Diffusion with MonteCarlo Random Walk"],
Cell[7970, 268, 143, 3, 27, "Output",
  CellTags->"Bulk Diffusion with MonteCarlo Random Walk"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8150, 276, 195, 4, 42, "Input",
  CellTags->"Bulk Diffusion with MonteCarlo Random Walk"],
Cell[8348, 282, 44009, 1364, 296, 12134, 966, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"Bulk Diffusion with MonteCarlo Random Walk"]
}, Open  ]],

Cell[CellGroupData[{
Cell[52394, 1651, 150, 4, 27, "Input",
  CellTags->"Bulk Diffusion with MonteCarlo Random Walk"],
Cell[52547, 1657, 275224, 12558, 441, 134387, 10814, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"Bulk Diffusion with MonteCarlo Random Walk"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

