(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1789157,      57654]*)
(*NotebookOutlinePosition[   1793158,      57762]*)
(*  CellTagsIndexPosition[   1792938,      57753]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["ZemaxToData, DataToRayica, and CompoundLens Example", "Section",
  CellTags->"CompoundLens"],

Cell[TextData[{
  "This example demonstrates the combined use of ",
  StyleBox["ZemaxToData", "Input"],
  ", ",
  StyleBox["DataToRayica", "Input"],
  ", and ",
  StyleBox["ComponentLens", "Input"],
  ". We start with some data about a compound lens in the Zemax data file \
format. "
}], "Text",
  CellTags->"CompoundLens"],

Cell[TextData[{
  "We first use the ",
  StyleBox["ZemaxToData", "Input"],
  " function to convert from Zemax data format into ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  "'s database information format."
}], "Text",
  CellTags->"CompoundLens"],

Cell[CellGroupData[{

Cell["?ZemaxToData", "Input",
  CellTags->"CompoundLens"],

Cell[BoxData[
    \("ZemaxToData[stringdata, options] is used to import Zemax lens data \
into Rayica's database format. \n\nZemaxToData requires that the stringdata \
for import be given in a single ascii string. Usually, this operation is \
accomplished either by opening the Zemax data file inside Mathematica or by \
manually copying and pasting the relevant data into an existing Mathematica \
notebook and, as a final last step, creating a string object by manually \
placing double-quotation marks on either side of the data. ZemaxToData then \
converts this string information into a rule-based, list format that is \
recognized by Mathematica. The translation process can be further modified by \
giving additional options to ZemaxToData (that get passed internally to \
StringReplace and EditData). Once converted, the new information can be \
edited further with EditData, saved to disk with SaveData, and converted to \
optical component models with DataToRayica. ZemaxToData is presently \
restricted to lens data that describe centered, refractive, spherical, \
multiple lens-surfaces with field stops. Zemax is a Trademark of Focus \
Software, Inc., Tucson, AZ. See also: ZemaxToRayica, DataToRayica, \
ExcelToData, ExcelToRayica, KDPToData, KDPToRayica, CodeVToData, and \
CodeVToRayica."\)], "Print",
  CellTags->"Info3311933938-1376534"]
}, Open  ]],

Cell[TextData[{
  "In addition to the ",
  StyleBox["ZemaxToData", "Input"],
  " function, ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " also supports file importing from Code V, and KDP (",
  StyleBox["CodeVToData", "Input"],
  " and ",
  StyleBox["KDPToData", "Input"],
  "). Please be aware that these functions are primarily intended for lens \
surface models and may not operate correctly for more complicated optical \
arrangements."
}], "Text",
  CellTags->"CompoundLens"],

Cell[CellGroupData[{

Cell["Define Zemax Lens Data", "Subsection"],

Cell["\<\
lensdata = 
\"REM * This ZEMAX lens prescription file was generated by LensVIEW (TM).
REM * ZEMAX is a Trademark of Focus Software, Inc., Tucson, AZ.
REM * LensVIEW is a Trademark of Optical Data Solutions, Inc.
REM
VERS 4.500
NAME U.S.Patent 2671380; Example 1 of 1
UNIT MM
ENPD 28.571420
RAIM
FTYP 0
XFLD 0 0 0
YFLD 0 15.750000 22.500000
FWGT 1 1 1
WAVL 0.4861 0.5876 0.6563
WWGT 1 1 1
PWAV 2
SURF 0
TYPE STANDARD
CURV 0
DISZ INFINITY
SURF 1
TYPE STANDARD
CURV 0.019530922
GLAS XXX 1 0 1.613000 57.2999
DISZ 4.941664859
DIAM 25.059152 1 0
SURF 2
TYPE STANDARD
CURV 0.008197531
DISZ 0.410970100
DIAM 25.059152 1 0
SURF 3
TYPE STANDARD
CURV 0.040670179
GLAS XXX 1 0 1.516000 64.0000
DISZ 13.000688281
DIAM 20.167004 1 0
SURF 4
TYPE STANDARD
CURV 0.059667433
DISZ 6.174575159
DIAM 12.993471 1 0
SURF 5
TYPE STANDARD
CURV 0
GLAS XXX 1 0 1.596000 39.2000
DISZ 2.054850499
DIAM 12.993070 1 0
SURF 6
TYPE STANDARD
CURV 0.070454766
GLAS XXX 1 0 1.613000 58.5997
DISZ 5.352634959
DIAM 10.742458 1 0
SURF 7
TYPE STANDARD
CURV 0
DISZ 2.676317480
DIAM 10.742458 1 0
SURF 8
STOP
TYPE STANDARD
CURV 0
DISZ 2.676317480
DIAM 9.304864 1 0
SURF 9
TYPE STANDARD
CURV 0
GLAS XXX 1 0 1.613000 58.5997
DISZ 4.941664859
DIAM 11.026027 1 0
SURF 10
TYPE STANDARD
CURV -0.041310124
GLAS XXX 1 0 1.596000 39.2000
DISZ 2.465820599
DIAM 11.026027 1 0
SURF 11
TYPE STANDARD
CURV 0
DISZ 6.585545259
DIAM 13.030759 1 0
SURF 12
TYPE STANDARD
CURV -0.053321191
GLAS XXX 1 0 1.516000 64.0000
DISZ 8.500064504
DIAM 13.531942 1 0
SURF 13
TYPE STANDARD
CURV -0.044280492
DISZ 1.443407180
DIAM 18.042590 1 0
SURF 14
TYPE STANDARD
CURV -0.002674924
GLAS XXX 1 0 1.606000 43.9000
DISZ 5.352634959
DIAM 23.054420 1 0
SURF 15
TYPE STANDARD
CURV -0.017047838
DISZ 60.618431335
DIAM 23.054420 1 0
SURF 16
TYPE STANDARD
CURV 0
DISZ 0.000000000
\";\
\>", "Input",
  CellTags->"CompoundLens"]
}, Closed]],

Cell[CellGroupData[{

Cell["Evaluate ZemaxToData", "Subsection"],

Cell[CellGroupData[{

Cell["data = ZemaxToData[lensdata]", "Input",
  CellTags->"CompoundLens"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{\(CatalogNumber \[Rule] "U"\), 
          ",", \(CenterThickness \[Rule] 127.195587512`\), 
          ",", \(ComponentBoundary \[Rule] 50.118304`\), 
          ",", \(ComponentLabel \[Rule] 
            "U . S . Patent 2671380  Example 1 of CompoundLens"\), 
          ",", \(ComponentMedium \[Rule] {{1.613`, 57.2999`}, 
              IntrinsicMedium, {1.516`, 64.`}, 
              IntrinsicMedium, {1.596`, 39.2`}, {1.613`, 58.5997`}, 
              IntrinsicMedium, 
              IntrinsicMedium, {1.613`, 58.5997`}, {1.596`, 39.2`}, 
              IntrinsicMedium, {1.516`, 64.`}, 
              IntrinsicMedium, {1.606`, 43.9`}}\), 
          ",", \(DesignRefractiveIndex \[Rule] {{1.6193798886215074`, 
                1.6130000000000002`, 1.6086817896719454`}, {1, 1, 
                1}, {1.5208081301410108`, 1.5160000000000002`, 
                1.512745630141011`}, {1, 1, 1}, {1.6050670639583682`, 
                1.5959999999999999`, 
                1.589862982325715`}, {1.6192383763060818`, 1.613`, 
                1.6087775718992332`}, {1, 1, 1}, {1, 1, 
                1}, {1.6192383763060818`, 1.613`, 
                1.6087775718992332`}, {1.6050670639583682`, 
                1.5959999999999999`, 1.589862982325715`}, {1, 1, 
                1}, {1.5208081301410108`, 1.5160000000000002`, 
                1.512745630141011`}, {1, 1, 1}, {1.6142321749302042`, 1.606`, 
                1.6004280747024138`}}\), 
          ",", \(DesignWaveLength \[Rule] {0.4861`, 0.5876`, 0.6563`}\), 
          ",", \(EntrancePupilDiameter \[Rule] {28.57142`}\), 
          ",", \(OpticaFunction \[Rule] CompoundLens\), ",", 
          RowBox[{"RadiusOfCurvature", "\[Rule]", 
            RowBox[{"{", 
              RowBox[{
              "51.200859846759926`", ",", "121.98794978634422`", ",", 
                "24.588040293601853`", ",", "16.759561283623515`", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]], ",", "14.193503956850838`", ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]], ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]], ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]], ",", \(-24.207141087255028`\), ",", 
                InterpretationBox["\[Infinity]",
                  DirectedInfinity[ 1]], ",", \(-18.754269761153687`\), 
                ",", \(-22.583308243277877`\), ",", \(-373.8423970176349`\), 
                ",", \(-58.6584644926823`\)}], "}"}]}], 
          ",", \(ReferenceWaveLengthNumber \[Rule] 2\), 
          ",", \(StopPosition \[Rule] 8\), 
          ",", \(SurfaceBoundary \[Rule] {50.118304`, 50.118304`, 40.334008`, 
              25.986942`, 25.98614`, 21.484916`, 21.484916`, 18.609728`, 
              22.052054`, 22.052054`, 26.061518`, 27.063884`, 36.08518`, 
              46.10884`, 46.10884`}\), 
          ",", \(SurfaceCurvature \[Rule] {0.019530922`, 0.008197531`, 
              0.040670179`, 0.059667433`, 0, 0.070454766`, 0, 0, 
              0, \(-0.041310124`\), 
              0, \(-0.053321191`\), \(-0.044280492`\), \(-0.002674924`\), \
\(-0.017047838`\)}\), 
          ",", \(SurfaceLabel \[Rule] {SphericalShape, SphericalShape, 
              SphericalShape, SphericalShape, SphericalShape, SphericalShape, 
              SphericalShape, SphericalShape, SphericalShape, SphericalShape, 
              SphericalShape, SphericalShape, SphericalShape, SphericalShape, 
              SphericalShape}\), 
          ",", \(SurfaceSeparation \[Rule] {4.941664859`, 0.4109701`, 
              13.000688281`, 6.174575159`, 2.054850499`, 5.352634959`, 
              2.67631748`, 2.67631748`, 4.941664859`, 2.465820599`, 
              6.585545259`, 8.500064504`, 1.44340718`, 5.352634959`}\), 
          ",", \(WaveLengthWeights \[Rule] {1, 1, 1}\)}], "}"}], 
      "}"}]], "Output",
  CellTags->"CompoundLens"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Apply ", "Input"],
  StyleBox["DataToRayica", "Input"]
}], "Subsection"],

Cell[TextData[{
  StyleBox["DataToRayica", "Input"],
  " can be used to convert the database information, generated by ",
  StyleBox["ZemaxToData", "Input"],
  ", into an ",
  StyleBox["Optica",
    FontSlant->"Italic"],
  " Component object."
}], "Text",
  CellTags->"CompoundLens"],

Cell[CellGroupData[{

Cell[TextData[{
  "?",
  StyleBox["DataToRayica", "Input"]
}], "Input",
  CellTags->"CompoundLens"],

Cell[BoxData[
    \("DataToRayica[databaselist, options] is used to build models in Rayica \
of optical components, light sources, coatings, and materials from the \
information given in databaselist. DataToRayica[databaselist, \
selectionproperties, options] first calls SearchData to select for specific \
data items. \n\nDataToRayica automatically recognizes the appropriate model \
format for each type of data entry. DataToRayica first passes databaselist \
and selectionproperties to SearchData. If no databaselist is directly given, \
DataToRayica uses the internally loaded catalog database according to the \
specified selectionproperties. DataToRayica uses the ReportedInterval option \
to restrict the maximum number of models created at one time. Note that \
DataToRayica may not use all present database information within the actual \
optical component models. See also: SearchData, ReadData, LoadData, SaveData, \
EditData, ExcelToData, DataToExcel, KDPToData, and ZemaxToData."\)], "Print",
  CellTags->"Info3311933950-5613040"]
}, Open  ]],

Cell[TextData[{
  "Next, we apply ",
  StyleBox["DataToRayica", "Input"],
  StyleBox[".", "Input"]
}], "Text",
  CellTags->"CompoundLens"],

Cell[CellGroupData[{

Cell[TextData[{
  "compoundlens = ",
  StyleBox["DataToRayica", "Input"],
  "[data, Options->{GraphicDesign->Solid}]"
}], "Input",
  CellTags->"CompoundLens"],

Cell[BoxData[
    TagBox[
      RowBox[{"CompoundLens", "[", 
        RowBox[{
          RowBox[{"{", 
            RowBox[{
            "51.200859846759926`", ",", "121.98794978634422`", ",", 
              "24.588040293601853`", ",", "16.759561283623515`", ",", 
              InterpretationBox["\[Infinity]",
                DirectedInfinity[ 1]], ",", "14.193503956850838`", ",", 
              InterpretationBox["\[Infinity]",
                DirectedInfinity[ 1]], ",", 
              InterpretationBox["\[Infinity]",
                DirectedInfinity[ 1]], ",", 
              InterpretationBox["\[Infinity]",
                DirectedInfinity[ 1]], ",", \(-24.207141087255028`\), ",", 
              InterpretationBox["\[Infinity]",
                DirectedInfinity[ 1]], ",", \(-18.754269761153687`\), 
              ",", \(-22.583308243277877`\), ",", \(-373.8423970176349`\), 
              ",", \(-58.6584644926823`\)}], "}"}], 
          ",", \({50.118304`, 50.118304`, 40.334008`, 25.986942`, 25.98614`, 
            21.484916`, 21.484916`, 18.609728`, 22.052054`, 22.052054`, 
            26.061518`, 27.063884`, 36.08518`, 46.10884`, 46.10884`}\), 
          ",", \({4.941664859`, 0.4109701`, 13.000688281`, 6.174575159`, 
            2.054850499`, 5.352634959`, 2.67631748`, 2.67631748`, 
            4.941664859`, 2.465820599`, 6.585545259`, 8.500064504`, 
            1.44340718`, 5.352634959`}\), 
          ",", \({{1.613`, 57.2999`}, IntrinsicMedium, {1.516`, 64.`}, 
            IntrinsicMedium, {1.596`, 39.2`}, {1.613`, 58.5997`}, 
            IntrinsicMedium, 
            IntrinsicMedium, {1.613`, 58.5997`}, {1.596`, 39.2`}, 
            IntrinsicMedium, {1.516`, 64.`}, 
            IntrinsicMedium, {1.606`, 43.9`}}\), 
          ",", \({GraphicDesign \[Rule] Solid}\)}], "]"}],
      HoldForm]], "Output",
  CellTags->"CompoundLens"]
}, Open  ]],

Cell[TextData[{
  "Normally, any options passed to ",
  StyleBox["DataToRayica", "Input"],
  " is assumed to be part of the searchable criteria from the database. \
However, you can specify particular options for the new component creation \
using ",
  StyleBox["Options", "Input"],
  " as shown below. In this case, we want to add the ",
  StyleBox["GraphicDesign->Solid", "Input"],
  " setting for the newly created component."
}], "Text",
  CellTags->"CompoundLens"],

Cell[TextData[{
  StyleBox["DataToRayica", "Input"],
  " has now generated a ",
  StyleBox["CompoundLens", "Input"],
  " from the passed file data. Here is the usage message for the ",
  StyleBox["CompoundLens", "Input"],
  " function."
}], "Text",
  CellTags->"CompoundLens"],

Cell[CellGroupData[{

Cell["?CompoundLens", "Input",
  CellTags->"CompoundLens"],

Cell[BoxData[
    \("CompoundLens[curvatures, surfaceboundaries, surfaceseparations, \
opticalmediumlist, label, options] refers to a lens assembly that consists of \
spherical and aspherical refracting surfaces. \n\nThe curvatures can be \
specified either by radiusofcurvatures, inverse radiusofcurvatures, and \
aspheric polynomial coefficients (see also: AsphericLensSurface), where \
either Infinity or 0 can be used to indicate planar surfaces. In addition, \
CompoundLens is specified by a list of surface separations. The \
opticalmediumlist must also be specified either as a list of symbols to \
identify built-in index functions, a list of numbers to define refractive \
index values, or as a list of functions. CompoundLens is created with its \
first surface centered about the origin and the remaining surfaces positioned \
down the x axis. The surfaceboundaries parameter gives a list of apertures \
that correspond to each surface, where an aperture may indicate a circle, \
rectangle, or polygon depending on the number and type of elements listed by \
it. \n\nCompoundLens may also include pinhole surfaces to provide field \
stops. Such a pinhole is detected by CompoundLens where IntrinsicMedium is \
listed twice consecutively or is given as the first element within \
opticalmediumlist. In such a case, the inside hole boundary is taken from \
corresponding aperture in surfaceboundaries and the outside boundary of the \
pinhole is taken from the average aperture size of the next neighboring lens \
surface(s). The user-named label parameter is optional and can be omitted. \
When it is present, its text content is used to identify the object in both \
the rendered graphics and the output cell expression. When it is omitted, \
Optica uses the default setting of the Labels option with the rendered \
graphics. See also: LensDoublet and LensTriplet."\)], "Print",
  CellTags->{"Info3251825220-2418144", "CompoundLens"}]
}, Open  ]],

Cell[TextData[{
  "We can now use the generated ",
  StyleBox["CompoundLens", "Input"],
  " in a ray-trace. Note that the ",
  StyleBox["GraphicDesign->Solid", "Input"],
  " is automatically incorporated into the rendered graphics for the lens."
}], "Text",
  CellTags->"CompoundLens"],

Cell[CellGroupData[{

Cell["\<\
result = AnalyzeSystem[{
\tWedgeOfRays[20,NumberOfRays->7,BirthPoint->{-300,0,0},StartAtBirthPoint->\
False],
\tMove[compoundlens,10],
\tBoundary[100,GraphicDesign->Off]},PlotPoints->30];\
\>", "Input",
  CellTags->"CompoundLens"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .8122 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.00452802 1.00453 -0.0695592 1.00453 [
[ 0 0 0 0 ]
[ 1 .8122 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .8122 L
0 .8122 L
closepath
clip
newpath
.35092 .48753 m .36353 .50884 L .35721 .51083 L .619 .508 .706 r
F
.35092 .48753 m .35722 .48552 L .36353 .50884 L F
.34328 .46455 m .35722 .48552 L .35092 .48753 L .628 .537 .732 r
F
.32427 .49481 m .35092 .48753 L .35721 .51083 L .832 .633 .633 r
F
.31785 .47551 m .35092 .48753 L .32427 .49481 L .836 .647 .647 r
F
.31785 .47551 m .34328 .46455 L .35092 .48753 L F
.34328 .46455 m .34958 .46251 L .35722 .48552 L .628 .537 .732 r
F
.33441 .44221 m .34958 .46251 L .34328 .46455 L .635 .564 .757 r
F
.31037 .45676 m .34328 .46455 L .31785 .47551 L .841 .661 .659 r
F
.31037 .45676 m .33441 .44221 L .34328 .46455 L F
0 g
.5 Mabswid
[ ] 0 setdash
.34328 .46455 m
.35092 .48753 L
s
.32953 .51438 m .35721 .51083 L .36207 .53413 L .83 .619 .618 r
F
.32427 .49481 m .35721 .51083 L .32953 .51438 L .832 .633 .633 r
F
.35721 .51083 m .36841 .53216 L .36207 .53413 L .609 .478 .677 r
F
.35721 .51083 m .36353 .50884 L .36841 .53216 L F
0 g
.35092 .48753 m
.35721 .51083 L
s
.3389 .49014 m .35722 .48552 L .36353 .50884 L .898 .666 .58 r
F
.33247 .47079 m .35722 .48552 L .3389 .49014 L .9 .674 .587 r
F
.33247 .47079 m .34958 .46251 L .35722 .48552 L F
.33441 .44221 m .34071 .44015 L .34958 .46251 L .635 .564 .757 r
F
.325 .452 m .34958 .46251 L .33247 .47079 L .902 .681 .593 r
F
.325 .452 m .34071 .44015 L .34958 .46251 L F
0 g
.34958 .46251 m
.35722 .48552 L
s
.32442 .42083 m .34071 .44015 L .33441 .44221 L .643 .592 .783 r
F
.30195 .43885 m .33441 .44221 L .31037 .45676 L .847 .676 .67 r
F
.30195 .43885 m .32442 .42083 L .33441 .44221 L F
0 g
.33441 .44221 m
.33523 .44428 L
s
.34419 .50975 m .36353 .50884 L .36841 .53216 L .896 .659 .571 r
F
.3389 .49014 m .36353 .50884 L .34419 .50975 L .898 .666 .58 r
F
0 g
.35722 .48552 m
.36353 .50884 L
s
.32442 .42083 m .33073 .41875 L .34071 .44015 L .643 .592 .783 r
F
.31658 .43403 m .34071 .44015 L .325 .452 L .906 .689 .599 r
F
.31658 .43403 m .33073 .41875 L .34071 .44015 L F
0 g
.34071 .44015 m
.34958 .46251 L
s
.36207 .53413 m .37178 .55513 L .36542 .55708 L .598 .446 .647 r
F
.36207 .53413 m .36841 .53216 L .37178 .55513 L F
.33357 .53395 m .36207 .53413 L .36542 .55708 L .828 .606 .602 r
F
.32953 .51438 m .36207 .53413 L .33357 .53395 L .83 .619 .618 r
F
0 g
.36005 .52442 m
.36207 .53413 L
s
.31346 .40073 m .33073 .41875 L .32442 .42083 L .649 .621 .808 r
F
.29269 .42203 m .32442 .42083 L .30195 .43885 L .854 .692 .68 r
F
.29269 .42203 m .31346 .40073 L .32442 .42083 L F
0 g
.32442 .42083 m
.32589 .42397 L
s
.34826 .52935 m .36841 .53216 L .37178 .55513 L .895 .652 .562 r
F
.34419 .50975 m .36841 .53216 L .34826 .52935 L .896 .659 .571 r
F
0 g
.36353 .50884 m
.36841 .53216 L
s
.31346 .40073 m .31977 .39862 L .33073 .41875 L .649 .621 .808 r
F
.30734 .41716 m .33073 .41875 L .31658 .43403 L .91 .697 .603 r
F
.30734 .41716 m .31977 .39862 L .33073 .41875 L F
0 g
.33073 .41875 m
.34071 .44015 L
s
.36542 .55708 m .37358 .57742 L .3672 .57936 L .585 .411 .612 r
F
.36542 .55708 m .37178 .55513 L .37358 .57742 L F
.33632 .55321 m .36542 .55708 L .3672 .57936 L .827 .593 .585 r
F
.33357 .53395 m .36542 .55708 L .33632 .55321 L .828 .606 .602 r
F
0 g
.36387 .54646 m
.36542 .55708 L
s
.35105 .54865 m .37178 .55513 L .37358 .57742 L .895 .645 .552 r
F
.34826 .52935 m .37178 .55513 L .35105 .54865 L .895 .652 .562 r
F
0 g
.36841 .53216 m
.37178 .55513 L
s
.30167 .3822 m .31977 .39862 L .31346 .40073 L .655 .651 .834 r
F
.28273 .40657 m .31346 .40073 L .29269 .42203 L .862 .708 .689 r
F
.28273 .40657 m .30167 .3822 L .31346 .40073 L F
0 g
.31346 .40073 m
.31566 .40476 L
s
.30167 .3822 m .30799 .38006 L .31977 .39862 L .655 .651 .834 r
F
.29741 .40165 m .31977 .39862 L .30734 .41716 L .914 .705 .606 r
F
.29741 .40165 m .30799 .38006 L .31977 .39862 L F
0 g
.31977 .39862 m
.33073 .41875 L
s
.30007 .50129 m .32427 .49481 L .32953 .51438 L .852 .643 .62 r
F
.29489 .48572 m .32427 .49481 L .30007 .50129 L .855 .655 .632 r
F
.29489 .48572 m .31785 .47551 L .32427 .49481 L F
.28884 .47061 m .31785 .47551 L .29489 .48572 L .859 .668 .642 r
F
.28884 .47061 m .31037 .45676 L .31785 .47551 L F
.30431 .51708 m .32953 .51438 L .33357 .53395 L .849 .631 .607 r
F
.30007 .50129 m .32953 .51438 L .30431 .51708 L .852 .643 .62 r
F
.28202 .45618 m .31037 .45676 L .28884 .47061 L .865 .681 .652 r
F
.28202 .45618 m .30195 .43885 L .31037 .45676 L F
.3672 .57936 m .37377 .59871 L .36736 .60064 L .569 .37 .572 r
F
.3672 .57936 m .37358 .57742 L .37377 .59871 L F
.33772 .57188 m .3672 .57936 L .36736 .60064 L .827 .58 .565 r
F
.33632 .55321 m .3672 .57936 L .33772 .57188 L .827 .593 .585 r
F
0 g
.3663 .56813 m
.3672 .57936 L
s
.30753 .53285 m .33357 .53395 L .33632 .55321 L .848 .62 .593 r
F
.30431 .51708 m .33357 .53395 L .30753 .53285 L .849 .631 .607 r
F
.32121 .49454 m .3389 .49014 L .34419 .50975 L .907 .67 .57 r
F
.31601 .47892 m .3389 .49014 L .32121 .49454 L .908 .677 .576 r
F
.31601 .47892 m .33247 .47079 L .3389 .49014 L F
.3525 .56735 m .37358 .57742 L .37377 .59871 L .896 .639 .541 r
F
.35105 .54865 m .37358 .57742 L .3525 .56735 L .895 .645 .552 r
F
0 g
.37178 .55513 m
.37358 .57742 L
s
.30997 .46375 m .33247 .47079 L .31601 .47892 L .911 .683 .581 r
F
.30997 .46375 m .325 .452 L .33247 .47079 L F
.32547 .51038 m .34419 .50975 L .34826 .52935 L .905 .664 .563 r
F
.32121 .49454 m .34419 .50975 L .32547 .51038 L .907 .67 .57 r
F
.28921 .36554 m .30799 .38006 L .30167 .3822 L .66 .684 .861 r
F
.27221 .39271 m .30167 .3822 L .28273 .40657 L .872 .724 .696 r
F
.27221 .39271 m .28921 .36554 L .30167 .3822 L F
0 g
.30167 .3822 m
.30465 .38688 L
s
.27452 .44267 m .30195 .43885 L .28202 .45618 L .871 .694 .66 r
F
.27452 .44267 m .29269 .42203 L .30195 .43885 L F
.30315 .44927 m .325 .452 L .30997 .46375 L .914 .69 .586 r
F
.30315 .44927 m .31658 .43403 L .325 .452 L F
.28921 .36554 m .29555 .36337 L .30799 .38006 L .66 .684 .861 r
F
.28693 .38774 m .30799 .38006 L .29741 .40165 L .919 .713 .608 r
F
.28693 .38774 m .29555 .36337 L .30799 .38006 L F
0 g
.30799 .38006 m
.31977 .39862 L
s
.32873 .5262 m .34826 .52935 L .35105 .54865 L .905 .658 .555 r
F
.32547 .51038 m .34826 .52935 L .32873 .5262 L .905 .664 .563 r
F
.30969 .54837 m .33632 .55321 L .33772 .57188 L .847 .609 .577 r
F
.30753 .53285 m .33632 .55321 L .30969 .54837 L .848 .62 .593 r
F
.29567 .43569 m .31658 .43403 L .30315 .44927 L .917 .697 .589 r
F
.29567 .43569 m .30734 .41716 L .31658 .43403 L F
.26645 .43027 m .29269 .42203 L .27452 .44267 L .878 .708 .667 r
F
.26645 .43027 m .28273 .40657 L .29269 .42203 L F
.33772 .57188 m .36736 .60064 L .33774 .58968 L .827 .58 .565 r
F
.36736 .60064 m .37233 .61866 L .36589 .62058 L .549 .322 .523 r
F
.36736 .60064 m .37377 .59871 L .37233 .61866 L F
.33774 .58968 m .36736 .60064 L .36589 .62058 L .828 .567 .544 r
F
0 g
.36727 .58913 m
.36736 .60064 L
s
.33094 .54176 m .35105 .54865 L .3525 .56735 L .905 .653 .546 r
F
.32873 .5262 m .35105 .54865 L .33094 .54176 L .905 .658 .555 r
F
.3525 .56735 m .37377 .59871 L .35258 .58517 L .896 .639 .541 r
F
.35258 .58517 m .37377 .59871 L .37233 .61866 L .898 .633 .53 r
F
0 g
.37358 .57742 m
.37377 .59871 L
s
.31076 .5634 m .33772 .57188 L .33774 .58968 L .848 .598 .56 r
F
.30969 .54837 m .33772 .57188 L .31076 .5634 L .847 .609 .577 r
F
.27625 .35101 m .29555 .36337 L .28921 .36554 L .664 .719 .89 r
F
.26129 .38068 m .28921 .36554 L .27221 .39271 L .883 .741 .701 r
F
.26129 .38068 m .27625 .35101 L .28921 .36554 L F
0 g
.28921 .36554 m
.29299 .3706 L
s
.28763 .42324 m .30734 .41716 L .29567 .43569 L .921 .703 .591 r
F
.28763 .42324 m .29741 .40165 L .30734 .41716 L F
.27807 .50704 m .30007 .50129 L .30431 .51708 L .871 .653 .605 r
F
.27415 .49526 m .30007 .50129 L .27807 .50704 L .874 .664 .615 r
F
.27415 .49526 m .29489 .48572 L .30007 .50129 L F
.26957 .48384 m .29489 .48572 L .27415 .49526 L .878 .674 .623 r
F
.26957 .48384 m .28884 .47061 L .29489 .48572 L F
.28127 .51899 m .30431 .51708 L .30753 .53285 L .869 .644 .594 r
F
.27807 .50704 m .30431 .51708 L .28127 .51899 L .871 .653 .605 r
F
.27625 .35101 m .28262 .34882 L .29555 .36337 L .664 .719 .89 r
F
.27605 .37566 m .29555 .36337 L .28693 .38774 L .925 .721 .608 r
F
.27605 .37566 m .28262 .34882 L .29555 .36337 L F
0 g
.29555 .36337 m
.30799 .38006 L
s
.25793 .4192 m .28273 .40657 L .26645 .43027 L .887 .722 .672 r
F
.25793 .4192 m .27221 .39271 L .28273 .40657 L F
.26438 .47294 m .28884 .47061 L .26957 .48384 L .882 .685 .631 r
F
.26438 .47294 m .28202 .45618 L .28884 .47061 L F
.33206 .55682 m .3525 .56735 L .35258 .58517 L .905 .647 .537 r
F
.33094 .54176 m .3525 .56735 L .33206 .55682 L .905 .653 .546 r
F
.28369 .53092 m .30753 .53285 L .30969 .54837 L .868 .634 .581 r
F
.28127 .51899 m .30753 .53285 L .28369 .53092 L .869 .644 .594 r
F
.25868 .46276 m .28202 .45618 L .26438 .47294 L .888 .696 .637 r
F
.25868 .46276 m .27452 .44267 L .28202 .45618 L F
.36589 .62058 m .36925 .63696 L .36277 .63887 L .522 .263 .462 r
F
.36589 .62058 m .37233 .61866 L .36925 .63696 L F
.33637 .60633 m .36589 .62058 L .36277 .63887 L .831 .554 .52 r
F
.33774 .58968 m .36589 .62058 L .33637 .60633 L .828 .567 .544 r
F
0 g
.36589 .62058 m
.36673 .60917 L
s
.27916 .41211 m .29741 .40165 L .28763 .42324 L .925 .71 .593 r
F
.27916 .41211 m .28693 .38774 L .29741 .40165 L F
.31076 .5634 m .33774 .58968 L .31069 .5777 L .848 .598 .56 r
F
.31069 .5777 m .33774 .58968 L .33637 .60633 L .85 .587 .541 r
F
.30414 .49871 m .32121 .49454 L .32547 .51038 L .916 .674 .559 r
F
.3002 .48689 m .32121 .49454 L .30414 .49871 L .917 .679 .564 r
F
.3002 .48689 m .31601 .47892 L .32121 .49454 L F
.29561 .47541 m .31601 .47892 L .3002 .48689 L .919 .685 .568 r
F
.29561 .47541 m .30997 .46375 L .31601 .47892 L F
.28529 .54265 m .30969 .54837 L .31076 .5634 L .868 .625 .568 r
F
.28369 .53092 m .30969 .54837 L .28529 .54265 L .868 .634 .581 r
F
.30735 .51071 m .32547 .51038 L .32873 .5262 L .915 .669 .553 r
F
.30414 .49871 m .32547 .51038 L .30735 .51071 L .916 .674 .559 r
F
.35127 .60184 m .37233 .61866 L .36925 .63696 L .9 .628 .517 r
F
.35258 .58517 m .37233 .61866 L .35127 .60184 L .898 .633 .53 r
F
0 g
.37233 .61866 m
.37377 .59871 L
s
.29044 .46446 m .30997 .46375 L .29561 .47541 L .921 .69 .571 r
F
.29044 .46446 m .30315 .44927 L .30997 .46375 L F
.25256 .45344 m .27452 .44267 L .25868 .46276 L .894 .707 .643 r
F
.25256 .45344 m .26645 .43027 L .27452 .44267 L F
.39572 .47179 m .43441 .47099 L .40093 .49093 L .275 .286 .691 r
F
.39572 .47179 m .43095 .45834 L .43441 .47099 L F
.38946 .4529 m .43095 .45834 L .39572 .47179 L .29 .329 .729 r
F
.35981 .48224 m .39572 .47179 L .40093 .49093 L .76 .592 .669 r
F
.35456 .46644 m .39572 .47179 L .35981 .48224 L .765 .612 .689 r
F
.35456 .46644 m .38946 .4529 L .39572 .47179 L F
.2491 .40964 m .27221 .39271 L .25793 .4192 L .896 .737 .676 r
F
.2491 .40964 m .26129 .38068 L .27221 .39271 L F
.38946 .4529 m .42681 .44584 L .43095 .45834 L .29 .329 .729 r
F
.38221 .43454 m .42681 .44584 L .38946 .4529 L .296 .365 .765 r
F
.34847 .45108 m .38946 .4529 L .35456 .46644 L .772 .633 .707 r
F
.34847 .45108 m .38221 .43454 L .38946 .4529 L F
0 g
.38946 .4529 m
.39572 .47179 L
s
.30981 .52268 m .32873 .5262 L .33094 .54176 L .914 .665 .546 r
F
.30735 .51071 m .32873 .5262 L .30981 .52268 L .915 .669 .553 r
F
.26299 .33889 m .28262 .34882 L .27625 .35101 L .665 .76 .92 r
F
.25013 .3707 m .27625 .35101 L .26129 .38068 L .894 .759 .705 r
F
.25013 .3707 m .26299 .33889 L .27625 .35101 L F
0 g
.27625 .35101 m
.28083 .35614 L
s
.40093 .49093 m .43712 .48359 L .40498 .51003 L .251 .236 .647 r
F
.40093 .49093 m .43441 .47099 L .43712 .48359 L F
.36414 .49826 m .40093 .49093 L .40498 .51003 L .755 .572 .649 r
F
.35981 .48224 m .40093 .49093 L .36414 .49826 L .76 .592 .669 r
F
0 g
.39572 .47179 m
.40093 .49093 L
s
.33206 .55682 m .35258 .58517 L .33206 .57114 L .905 .647 .537 r
F
.33206 .57114 m .35258 .58517 L .35127 .60184 L .907 .642 .527 r
F
.28476 .45422 m .30315 .44927 L .29044 .46446 L .924 .696 .574 r
F
.28476 .45422 m .29567 .43569 L .30315 .44927 L F
.38221 .43454 m .42204 .4337 L .42681 .44584 L .296 .365 .765 r
F
.3741 .41697 m .42204 .4337 L .38221 .43454 L .293 .397 .798 r
F
.34163 .43641 m .38221 .43454 L .34847 .45108 L .78 .654 .724 r
F
.34163 .43641 m .3741 .41697 L .38221 .43454 L F
0 g
.38221 .43454 m
.38946 .4529 L
s
.28604 .55399 m .31076 .5634 L .31069 .5777 L .869 .616 .554 r
F
.28529 .54265 m .31076 .5634 L .28604 .55399 L .868 .625 .568 r
F
.26299 .33889 m .26939 .33667 L .28262 .34882 L .665 .76 .92 r
F
.26494 .36563 m .28262 .34882 L .27605 .37566 L .931 .728 .607 r
F
.26494 .36563 m .26939 .33667 L .28262 .34882 L F
0 g
.28262 .34882 m
.29555 .36337 L
s
.40498 .51003 m .43905 .49596 L .40783 .52882 L .215 .175 .596 r
F
.40498 .51003 m .43712 .48359 L .43905 .49596 L F
.36749 .51425 m .40498 .51003 L .40783 .52882 L .75 .551 .626 r
F
.36414 .49826 m .40498 .51003 L .36749 .51425 L .755 .572 .649 r
F
0 g
.40093 .49093 m
.40498 .51003 L
s
.31145 .53445 m .33094 .54176 L .33206 .55682 L .914 .66 .539 r
F
.30981 .52268 m .33094 .54176 L .31145 .53445 L .914 .665 .546 r
F
.27037 .40248 m .28693 .38774 L .27916 .41211 L .93 .716 .593 r
F
.27037 .40248 m .27605 .37566 L .28693 .38774 L F
.2461 .44514 m .26645 .43027 L .25256 .45344 L .901 .719 .646 r
F
.2461 .44514 m .25793 .4192 L .26645 .43027 L F
.3741 .41697 m .41673 .42209 L .42204 .4337 L .293 .397 .798 r
F
.36523 .40046 m .41673 .42209 L .3741 .41697 L .279 .424 .829 r
F
.33415 .42265 m .3741 .41697 L .34163 .43641 L .789 .677 .741 r
F
.33415 .42265 m .36523 .40046 L .3741 .41697 L F
0 g
.3741 .41697 m
.38221 .43454 L
s
.33637 .60633 m .36277 .63887 L .33361 .62155 L .831 .554 .52 r
F
.30949 .59105 m .33637 .60633 L .33361 .62155 L .852 .577 .521 r
F
.31069 .5777 m .33637 .60633 L .30949 .59105 L .85 .587 .541 r
F
.27866 .44484 m .29567 .43569 L .28476 .45422 L .927 .701 .576 r
F
.27866 .44484 m .28763 .42324 L .29567 .43569 L F
.25811 .51212 m .27807 .50704 L .28127 .51899 L .892 .663 .586 r
F
.25547 .50419 m .27807 .50704 L .25811 .51212 L .894 .671 .594 r
F
.25547 .50419 m .27415 .49526 L .27807 .50704 L F
.25238 .49651 m .27415 .49526 L .25547 .50419 L .897 .679 .6 r
F
.25238 .49651 m .26957 .48384 L .27415 .49526 L F
.3317 .49019 m .35981 .48224 L .36414 .49826 L .795 .612 .654 r
F
.32747 .47748 m .35981 .48224 L .3317 .49019 L .8 .63 .671 r
F
.32747 .47748 m .35456 .46644 L .35981 .48224 L F
.32256 .46514 m .35456 .46644 L .32747 .47748 L .806 .648 .686 r
F
.32256 .46514 m .34847 .45108 L .35456 .46644 L F
.33361 .62155 m .36277 .63887 L .35802 .6552 L .834 .541 .493 r
F
.36277 .63887 m .36454 .65329 L .35802 .6552 L .486 .186 .383 r
F
.36277 .63887 m .36925 .63696 L .36454 .65329 L F
0 g
.36277 .63887 m
.36463 .62794 L
s
.3698 .52997 m .40783 .52882 L .40942 .54701 L .747 .53 .601 r
F
.36749 .51425 m .40783 .52882 L .3698 .52997 L .75 .551 .626 r
F
.40783 .52882 m .44016 .5079 L .40942 .54701 L .164 .1 .533 r
F
.40783 .52882 m .43905 .49596 L .44016 .5079 L F
0 g
.40498 .51003 m
.40783 .52882 L
s
.26026 .52016 m .28127 .51899 L .28369 .53092 L .89 .656 .577 r
F
.25811 .51212 m .28127 .51899 L .26026 .52016 L .892 .663 .586 r
F
.28604 .55399 m .31069 .5777 L .28594 .56477 L .869 .616 .554 r
F
.28594 .56477 m .31069 .5777 L .30949 .59105 L .871 .608 .538 r
F
.31226 .54582 m .33206 .55682 L .33206 .57114 L .915 .656 .532 r
F
.31145 .53445 m .33206 .55682 L .31226 .54582 L .914 .66 .539 r
F
.24888 .4892 m .26957 .48384 L .25238 .49651 L .9 .688 .606 r
F
.24888 .4892 m .26438 .47294 L .26957 .48384 L F
.33517 .50308 m .36414 .49826 L .36749 .51425 L .791 .595 .635 r
F
.3317 .49019 m .36414 .49826 L .33517 .50308 L .795 .612 .654 r
F
.24008 .40175 m .26129 .38068 L .2491 .40964 L .906 .751 .678 r
F
.24008 .40175 m .25013 .3707 L .26129 .38068 L F
.31703 .45336 m .34847 .45108 L .32256 .46514 L .813 .667 .701 r
F
.31703 .45336 m .34163 .43641 L .34847 .45108 L F
.35127 .60184 m .36925 .63696 L .34858 .61708 L .9 .628 .517 r
F
.33093 .58451 m .35127 .60184 L .34858 .61708 L .908 .638 .516 r
F
.33206 .57114 m .35127 .60184 L .33093 .58451 L .907 .642 .527 r
F
.26187 .52819 m .28369 .53092 L .28529 .54265 L .89 .649 .568 r
F
.26026 .52016 m .28369 .53092 L .26187 .52819 L .89 .656 .577 r
F
.34858 .61708 m .36925 .63696 L .36454 .65329 L .902 .623 .504 r
F
0 g
.36925 .63696 m
.37233 .61866 L
s
.36523 .40046 m .41095 .4112 L .41673 .42209 L .279 .424 .829 r
F
.35573 .38526 m .41095 .4112 L .36523 .40046 L .252 .445 .856 r
F
.32612 .41001 m .36523 .40046 L .33415 .42265 L .799 .7 .756 r
F
.32612 .41001 m .35573 .38526 L .36523 .40046 L F
0 g
.36523 .40046 m
.3741 .41697 L
s
.27224 .43649 m .28763 .42324 L .27866 .44484 L .931 .706 .577 r
F
.27224 .43649 m .27916 .41211 L .28763 .42324 L F
.2394 .438 m .25793 .4192 L .2461 .44514 L .909 .73 .648 r
F
.2394 .438 m .2491 .40964 L .25793 .4192 L F
.24503 .48237 m .26438 .47294 L .24888 .4892 L .904 .696 .611 r
F
.24503 .48237 m .25868 .46276 L .26438 .47294 L F
.33783 .51594 m .36749 .51425 L .3698 .52997 L .788 .577 .615 r
F
.33517 .50308 m .36749 .51425 L .33783 .51594 L .791 .595 .635 r
F
.31097 .44233 m .34163 .43641 L .31703 .45336 L .822 .686 .714 r
F
.31097 .44233 m .33415 .42265 L .34163 .43641 L F
.26292 .53607 m .28529 .54265 L .28604 .55399 L .889 .642 .557 r
F
.26187 .52819 m .28529 .54265 L .26292 .53607 L .89 .649 .568 r
F
.24963 .32939 m .26939 .33667 L .26299 .33889 L .661 .804 .951 r
F
.23889 .36296 m .26299 .33889 L .25013 .3707 L .907 .777 .706 r
F
.23889 .36296 m .24963 .32939 L .26299 .33889 L F
0 g
.26299 .33889 m
.2683 .34374 L
s
.26142 .39454 m .27605 .37566 L .27037 .40248 L .935 .723 .592 r
F
.26142 .39454 m .26494 .36563 L .27605 .37566 L F
.2409 .47614 m .25868 .46276 L .24503 .48237 L .909 .705 .614 r
F
.2409 .47614 m .25256 .45344 L .25868 .46276 L F
.40942 .54701 m .44043 .51921 L .40971 .56433 L .093 .005 .454 r
F
.40942 .54701 m .44016 .5079 L .44043 .51921 L F
.37103 .54518 m .40942 .54701 L .40971 .56433 L .744 .508 .573 r
F
.3698 .52997 m .40942 .54701 L .37103 .54518 L .747 .53 .601 r
F
0 g
.40783 .52882 m
.40942 .54701 L
s
.31226 .54582 m .33206 .57114 L .31221 .55662 L .915 .656 .532 r
F
.31221 .55662 m .33206 .57114 L .33093 .58451 L .916 .652 .523 r
F
.33965 .52858 m .3698 .52997 L .37103 .54518 L .786 .56 .593 r
F
.33783 .51594 m .3698 .52997 L .33965 .52858 L .788 .577 .615 r
F
.24963 .32939 m .25606 .32715 L .26939 .33667 L .661 .804 .951 r
F
.25376 .35784 m .26939 .33667 L .26494 .36563 L .937 .736 .605 r
F
.25376 .35784 m .25606 .32715 L .26939 .33667 L F
0 g
.26939 .33667 m
.28262 .34882 L
s
.28768 .50267 m .30414 .49871 L .30735 .51071 L .925 .678 .546 r
F
.28503 .4947 m .30414 .49871 L .28768 .50267 L .926 .682 .55 r
F
.28503 .4947 m .3002 .48689 L .30414 .49871 L F
.33361 .62155 m .35802 .6552 L .32947 .6351 L .834 .541 .493 r
F
.30716 .60322 m .33361 .62155 L .32947 .6351 L .856 .567 .498 r
F
.30949 .59105 m .33361 .62155 L .30716 .60322 L .852 .577 .521 r
F
.28496 .5748 m .30949 .59105 L .30716 .60322 L .873 .6 .521 r
F
.28594 .56477 m .30949 .59105 L .28496 .5748 L .871 .608 .538 r
F
.28194 .48698 m .3002 .48689 L .28503 .4947 L .927 .686 .553 r
F
.28194 .48698 m .29561 .47541 L .3002 .48689 L F
.28984 .51074 m .30735 .51071 L .30981 .52268 L .924 .674 .542 r
F
.28768 .50267 m .30735 .51071 L .28984 .51074 L .925 .678 .546 r
F
.2634 .54368 m .28604 .55399 L .28594 .56477 L .89 .635 .546 r
F
.26292 .53607 m .28604 .55399 L .2634 .54368 L .889 .642 .557 r
F
.27844 .47963 m .29561 .47541 L .28194 .48698 L .929 .69 .556 r
F
.27844 .47963 m .29044 .46446 L .29561 .47541 L F
.30447 .43222 m .33415 .42265 L .31097 .44233 L .831 .707 .727 r
F
.30447 .43222 m .32612 .41001 L .33415 .42265 L F
.31768 .3987 m .35573 .38526 L .32612 .41001 L .81 .726 .771 r
F
.31768 .3987 m .34574 .37162 L .35573 .38526 L F
.35573 .38526 m .40478 .4012 L .41095 .4112 L .252 .445 .856 r
F
.34574 .37162 m .40478 .4012 L .35573 .38526 L .207 .459 .879 r
F
0 g
.35573 .38526 m
.36523 .40046 L
s
.26559 .4293 m .27916 .41211 L .27224 .43649 L .934 .711 .576 r
F
.26559 .4293 m .27037 .40248 L .27916 .41211 L F
.29148 .5188 m .30981 .52268 L .31145 .53445 L .924 .671 .537 r
F
.28984 .51074 m .30981 .52268 L .29148 .5188 L .924 .674 .542 r
F
.23654 .47061 m .25256 .45344 L .2409 .47614 L .915 .713 .616 r
F
.23654 .47061 m .2461 .44514 L .25256 .45344 L F
.30851 .49655 m .3317 .49019 L .33517 .50308 L .828 .63 .636 r
F
.30532 .48696 m .3317 .49019 L .30851 .49655 L .832 .645 .65 r
F
.30532 .48696 m .32747 .47748 L .3317 .49019 L F
.23258 .43216 m .2491 .40964 L .2394 .438 L .917 .742 .649 r
F
.23258 .43216 m .24008 .40175 L .2491 .40964 L F
.3016 .47765 m .32747 .47748 L .30532 .48696 L .837 .66 .663 r
F
.3016 .47765 m .32256 .46514 L .32747 .47748 L F
.27461 .47275 m .29044 .46446 L .27844 .47963 L .931 .694 .558 r
F
.27461 .47275 m .28476 .45422 L .29044 .46446 L F
.31113 .50628 m .33517 .50308 L .33783 .51594 L .825 .615 .62 r
F
.30851 .49655 m .33517 .50308 L .31113 .50628 L .828 .63 .636 r
F
.23102 .39568 m .25013 .3707 L .24008 .40175 L .918 .766 .677 r
F
.23102 .39568 m .23889 .36296 L .25013 .3707 L F
.34858 .61708 m .36454 .65329 L .34452 .63063 L .902 .623 .504 r
F
.32869 .59669 m .34858 .61708 L .34452 .63063 L .911 .634 .505 r
F
.33093 .58451 m .34858 .61708 L .32869 .59669 L .908 .638 .516 r
F
.29741 .46877 m .32256 .46514 L .3016 .47765 L .844 .676 .675 r
F
.29741 .46877 m .31703 .45336 L .32256 .46514 L F
.37103 .54518 m .40971 .56433 L .37115 .55964 L .744 .508 .573 r
F
.34057 .54079 m .37103 .54518 L .37115 .55964 L .785 .542 .569 r
F
.33965 .52858 m .37103 .54518 L .34057 .54079 L .786 .56 .593 r
F
.29257 .52671 m .31145 .53445 L .31226 .54582 L .924 .668 .532 r
F
.29148 .5188 m .31145 .53445 L .29257 .52671 L .924 .671 .537 r
F
.2634 .54368 m .28594 .56477 L .2633 .5509 L .89 .635 .546 r
F
.2633 .5509 m .28594 .56477 L .28496 .5748 L .892 .629 .534 r
F
.31312 .51598 m .33783 .51594 L .33965 .52858 L .823 .601 .602 r
F
.31113 .50628 m .33783 .51594 L .31312 .51598 L .825 .615 .62 r
F
.32947 .6351 m .35802 .6552 L .35169 .66927 L .839 .528 .463 r
F
.35802 .6552 m .35825 .66736 L .35169 .66927 L .431 .083 .273 r
F
.35802 .6552 m .36454 .65329 L .35825 .66736 L F
0 g
.35802 .6552 m
.36005 .64821 L
s
.40971 .56433 m .43985 .52972 L .40869 .5805 L 0 0 .349 r
F
.40971 .56433 m .44043 .51921 L .43985 .52972 L F
.37115 .55964 m .40971 .56433 L .40869 .5805 L .741 .484 .541 r
F
0 g
.40942 .54701 m
.40971 .56433 L
s
.31131 .56667 m .33093 .58451 L .32869 .59669 L .917 .648 .515 r
F
.31221 .55662 m .33093 .58451 L .31131 .56667 L .916 .652 .523 r
F
.2705 .46648 m .28476 .45422 L .27461 .47275 L .933 .698 .559 r
F
.2705 .46648 m .27866 .44484 L .28476 .45422 L F
.29764 .4232 m .32612 .41001 L .30447 .43222 L .842 .729 .738 r
F
.29764 .4232 m .31768 .3987 L .32612 .41001 L F
.29282 .46048 m .31703 .45336 L .29741 .46877 L .851 .693 .686 r
F
.29282 .46048 m .31097 .44233 L .31703 .45336 L F
.23204 .46587 m .2461 .44514 L .23654 .47061 L .921 .722 .617 r
F
.23204 .46587 m .2394 .438 L .2461 .44514 L F
.34452 .63063 m .36454 .65329 L .35825 .66736 L .905 .619 .49 r
F
0 g
.36454 .65329 m
.36925 .63696 L
s
.30716 .60322 m .32947 .6351 L .30372 .614 L .856 .567 .498 r
F
.28313 .58392 m .30716 .60322 L .30372 .614 L .876 .592 .503 r
F
.28496 .5748 m .30716 .60322 L .28313 .58392 L .873 .6 .521 r
F
.25243 .38842 m .26494 .36563 L .26142 .39454 L .94 .728 .589 r
F
.25243 .38842 m .25376 .35784 L .26494 .36563 L F
.31445 .52552 m .33965 .52858 L .34057 .54079 L .822 .587 .583 r
F
.31312 .51598 m .33965 .52858 L .31445 .52552 L .823 .601 .602 r
F
.29309 .53434 m .31226 .54582 L .31221 .55662 L .924 .664 .526 r
F
.29257 .52671 m .31226 .54582 L .29309 .53434 L .924 .668 .532 r
F
.34574 .37162 m .39833 .39226 L .40478 .4012 L .207 .459 .879 r
F
.3354 .35976 m .39833 .39226 L .34574 .37162 L .137 .461 .889 r
F
.30894 .38891 m .34574 .37162 L .31768 .3987 L .823 .753 .786 r
F
.30894 .38891 m .3354 .35976 L .34574 .37162 L F
0 g
.34574 .37162 m
.35573 .38526 L
s
.25882 .4234 m .27037 .40248 L .26559 .4293 L .938 .716 .575 r
F
.25882 .4234 m .26142 .39454 L .27037 .40248 L F
.24009 .51655 m .25811 .51212 L .26026 .52016 L .913 .673 .563 r
F
.23876 .51255 m .25811 .51212 L .24009 .51655 L .914 .678 .568 r
F
.23876 .51255 m .25547 .50419 L .25811 .51212 L F
.2372 .50868 m .25547 .50419 L .23876 .51255 L .916 .684 .572 r
F
.2372 .50868 m .25238 .49651 L .25547 .50419 L F
.28789 .45289 m .31097 .44233 L .29282 .46048 L .86 .71 .695 r
F
.28789 .45289 m .30447 .43222 L .31097 .44233 L F
.24117 .52061 m .26026 .52016 L .26187 .52819 L .912 .668 .557 r
F
.24009 .51655 m .26026 .52016 L .24117 .52061 L .913 .673 .563 r
F
.34057 .54079 m .37115 .55964 L .3406 .55239 L .785 .542 .569 r
F
.37115 .55964 m .40869 .5805 L .37016 .57312 L .741 .484 .541 r
F
.3406 .55239 m .37115 .55964 L .37016 .57312 L .785 .523 .541 r
F
.26617 .46091 m .27866 .44484 L .2705 .46648 L .936 .702 .559 r
F
.26617 .46091 m .27224 .43649 L .27866 .44484 L F
.23542 .50499 m .25238 .49651 L .2372 .50868 L .918 .689 .576 r
F
.23542 .50499 m .24888 .4892 L .25238 .49651 L F
.32947 .6351 m .35169 .66927 L .32401 .64672 L .839 .528 .463 r
F
.30372 .614 m .32947 .6351 L .32401 .64672 L .86 .557 .473 r
F
.2626 .5576 m .28496 .5748 L .28313 .58392 L .894 .623 .521 r
F
.039 .916 .04 r
.2002 .57885 m
.26475 .56035 L
s
.2633 .5509 m .28496 .5748 L .2626 .5576 L .892 .629 .534 r
F
.23637 .32273 m .25606 .32715 L .24963 .32939 L .646 .852 .979 r
F
.22776 .35761 m .24963 .32939 L .23889 .36296 L .922 .796 .704 r
F
.22776 .35761 m .23637 .32273 L .24963 .32939 L F
0 g
.24963 .32939 m
.25557 .33362 L
s
.22573 .4277 m .24008 .40175 L .23258 .43216 L .927 .753 .647 r
F
.22573 .4277 m .23102 .39568 L .24008 .40175 L F
.24198 .52466 m .26187 .52819 L .26292 .53607 L .911 .663 .551 r
F
.24117 .52061 m .26187 .52819 L .24198 .52466 L .912 .668 .557 r
F
.23348 .50155 m .24888 .4892 L .23542 .50499 L .921 .695 .579 r
F
.23348 .50155 m .24503 .48237 L .24888 .4892 L F
.31511 .53472 m .34057 .54079 L .3406 .55239 L .822 .573 .562 r
F
.31445 .52552 m .34057 .54079 L .31511 .53472 L .822 .587 .583 r
F
.23637 .32273 m .24283 .32046 L .25606 .32715 L .646 .852 .979 r
F
.2427 .35245 m .25606 .32715 L .25376 .35784 L .944 .742 .6 r
F
.2427 .35245 m .24283 .32046 L .25606 .32715 L F
0 g
.25606 .32715 m
.26939 .33667 L
s
.22745 .46201 m .2394 .438 L .23204 .46587 L .927 .73 .616 r
F
.22745 .46201 m .23258 .43216 L .2394 .438 L F
.29057 .41543 m .31768 .3987 L .29764 .4232 L .855 .752 .748 r
F
.29057 .41543 m .30894 .38891 L .31768 .3987 L F
.29309 .53434 m .31221 .55662 L .29303 .54158 L .924 .664 .526 r
F
.29303 .54158 m .31221 .55662 L .31131 .56667 L .925 .662 .52 r
F
.2425 .52864 m .26292 .53607 L .2634 .54368 L .911 .659 .544 r
F
.24198 .52466 m .26292 .53607 L .2425 .52864 L .911 .663 .551 r
F
.23139 .49843 m .24503 .48237 L .23348 .50155 L .924 .7 .58 r
F
.23139 .49843 m .2409 .47614 L .24503 .48237 L F
.28271 .44614 m .30447 .43222 L .28789 .45289 L .87 .728 .703 r
F
.28271 .44614 m .29764 .4232 L .30447 .43222 L F
.32869 .59669 m .34452 .63063 L .32534 .60748 L .911 .634 .505 r
F
.30955 .5758 m .32869 .59669 L .32534 .60748 L .919 .645 .506 r
F
.31131 .56667 m .32869 .59669 L .30955 .5758 L .917 .648 .515 r
F
.37016 .57312 m .40869 .5805 L .40636 .59526 L .739 .458 .503 r
F
.40869 .5805 m .43842 .53925 L .40636 .59526 L 0 0 .208 r
F
.40869 .5805 m .43985 .52972 L .43842 .53925 L F
0 g
.40869 .5805 m
.40971 .56433 L
s
.28906 .50171 m .30851 .49655 L .31113 .50628 L .86 .647 .613 r
F
.28691 .49527 m .30851 .49655 L .28906 .50171 L .864 .659 .625 r
F
.28691 .49527 m .30532 .48696 L .30851 .49655 L F
.28441 .48902 m .30532 .48696 L .28691 .49527 L .868 .672 .635 r
F
.28441 .48902 m .3016 .47765 L .30532 .48696 L F
.22206 .39157 m .23889 .36296 L .23102 .39568 L .93 .781 .674 r
F
.22206 .39157 m .22776 .35761 L .23889 .36296 L F
.34452 .63063 m .35825 .66736 L .33914 .64224 L .905 .619 .49 r
F
.32534 .60748 m .34452 .63063 L .33914 .64224 L .913 .631 .493 r
F
.2617 .45613 m .27224 .43649 L .26617 .46091 L .938 .705 .559 r
F
.2617 .45613 m .26559 .4293 L .27224 .43649 L F
.29081 .50824 m .31113 .50628 L .31312 .51598 L .858 .636 .6 r
F
.28906 .50171 m .31113 .50628 L .29081 .50824 L .86 .647 .613 r
F
.24273 .53247 m .2634 .54368 L .2633 .5509 L .912 .655 .536 r
F
.2425 .52864 m .2634 .54368 L .24273 .53247 L .911 .659 .544 r
F
.28159 .48307 m .3016 .47765 L .28441 .48902 L .873 .684 .644 r
F
.28159 .48307 m .29741 .46877 L .3016 .47765 L F
.30372 .614 m .32401 .64672 L .29922 .62321 L .86 .557 .473 r
F
.28046 .59197 m .30372 .614 L .29922 .62321 L .881 .585 .483 r
F
.28313 .58392 m .30372 .614 L .28046 .59197 L .876 .592 .503 r
F
.26133 .56367 m .28313 .58392 L .28046 .59197 L .897 .618 .507 r
F
.2626 .5576 m .28313 .58392 L .26133 .56367 L .894 .623 .521 r
F
.22918 .49566 m .2409 .47614 L .23139 .49843 L .927 .705 .581 r
F
.22918 .49566 m .23654 .47061 L .2409 .47614 L F
.29213 .51475 m .31312 .51598 L .31445 .52552 L .857 .625 .586 r
F
.29081 .50824 m .31312 .51598 L .29213 .51475 L .858 .636 .6 r
F
.31511 .53472 m .3406 .55239 L .31508 .54345 L .822 .573 .562 r
F
.3406 .55239 m .37016 .57312 L .33971 .56319 L .785 .523 .541 r
F
.31508 .54345 m .3406 .55239 L .33971 .56319 L .823 .558 .539 r
F
.37016 .57312 m .40636 .59526 L .36805 .5854 L .739 .458 .503 r
F
.33971 .56319 m .37016 .57312 L .36805 .5854 L .785 .503 .509 r
F
.25205 .41889 m .26142 .39454 L .25882 .4234 L .942 .72 .573 r
F
.25205 .41889 m .25243 .38842 L .26142 .39454 L F
.27849 .47752 m .29741 .46877 L .28159 .48307 L .879 .697 .652 r
F
.27849 .47752 m .29282 .46048 L .29741 .46877 L F
.3354 .35976 m .3917 .38452 L .39833 .39226 L .137 .461 .889 r
F
.32487 .34989 m .3917 .38452 L .3354 .35976 L .033 .442 .872 r
F
.30005 .38081 m .3354 .35976 L .30894 .38891 L .838 .783 .799 r
F
.30005 .38081 m .32487 .34989 L .3354 .35976 L F
0 g
.3354 .35976 m
.34574 .37162 L
s
.29239 .54829 m .31131 .56667 L .30955 .5758 L .926 .659 .514 r
F
.29303 .54158 m .31131 .56667 L .29239 .54829 L .925 .662 .52 r
F
.039 .916 .04 r
.27425 .55761 m
.29382 .55059 L
s
.27185 .50639 m .28768 .50267 L .28984 .51074 L .934 .682 .533 r
F
.27051 .50237 m .28768 .50267 L .27185 .50639 L .935 .684 .535 r
F
.27051 .50237 m .28503 .4947 L .28768 .50267 L F
.26894 .49847 m .28503 .4947 L .27051 .50237 L .935 .687 .537 r
F
.26894 .49847 m .28194 .48698 L .28503 .4947 L F
.24273 .53247 m .2633 .5509 L .24266 .53609 L .912 .655 .536 r
F
.24266 .53609 m .2633 .5509 L .2626 .5576 L .913 .651 .528 r
F
.27294 .51047 m .28984 .51074 L .29148 .5188 L .933 .679 .53 r
F
.27185 .50639 m .28984 .51074 L .27294 .51047 L .934 .682 .533 r
F
.22286 .45911 m .23258 .43216 L .22745 .46201 L .934 .737 .614 r
F
.22286 .45911 m .22573 .4277 L .23258 .43216 L F
.29301 .52115 m .31445 .52552 L .31511 .53472 L .856 .614 .571 r
F
.29213 .51475 m .31445 .52552 L .29301 .52115 L .857 .625 .586 r
F
.27735 .44034 m .29764 .4232 L .28271 .44614 L .881 .747 .709 r
F
.27735 .44034 m .29057 .41543 L .29764 .4232 L F
.26718 .49477 m .28194 .48698 L .26894 .49847 L .936 .689 .539 r
F
.26718 .49477 m .27844 .47963 L .28194 .48698 L F
.24355 .38425 m .25376 .35784 L .25243 .38842 L .945 .733 .585 r
F
.24355 .38425 m .2427 .35245 L .25376 .35784 L F
.35169 .66927 m .35044 .6789 L .34383 .68081 L .347 0 .116 r
F
.35169 .66927 m .35825 .66736 L .35044 .6789 L F
.32401 .64672 m .35169 .66927 L .34383 .68081 L .844 .515 .43 r
F
0 g
.35169 .66927 m
.35467 .66265 L
s
.22691 .4933 m .23654 .47061 L .22918 .49566 L .931 .71 .581 r
F
.22691 .4933 m .23204 .46587 L .23654 .47061 L F
.21899 .42473 m .23102 .39568 L .22573 .4277 L .936 .764 .643 r
F
.21899 .42473 m .22206 .39157 L .23102 .39568 L F
.27517 .47245 m .29282 .46048 L .27849 .47752 L .886 .71 .658 r
F
.27517 .47245 m .28789 .45289 L .29282 .46048 L F
.27376 .51454 m .29148 .5188 L .29257 .52671 L .933 .677 .527 r
F
.27294 .51047 m .29148 .5188 L .27376 .51454 L .933 .679 .53 r
F
.28337 .40903 m .30894 .38891 L .29057 .41543 L .869 .776 .756 r
F
.28337 .40903 m .30005 .38081 L .30894 .38891 L F
.25716 .45224 m .26559 .4293 L .2617 .45613 L .941 .709 .558 r
F
.25716 .45224 m .25882 .4234 L .26559 .4293 L F
.26524 .49131 m .27844 .47963 L .26718 .49477 L .938 .692 .54 r
F
.26524 .49131 m .27461 .47275 L .27844 .47963 L F
.33914 .64224 m .35825 .66736 L .35044 .6789 L .909 .615 .475 r
F
0 g
.35825 .66736 m
.36454 .65329 L
s
.2743 .51853 m .29257 .52671 L .29309 .53434 L .933 .675 .523 r
F
.27376 .51454 m .29257 .52671 L .2743 .51853 L .933 .677 .527 r
F
.29343 .52731 m .31511 .53472 L .31508 .54345 L .857 .603 .554 r
F
.29301 .52115 m .31511 .53472 L .29343 .52731 L .856 .614 .571 r
F
.24229 .53945 m .2626 .5576 L .26133 .56367 L .914 .648 .52 r
F
.039 .916 .04 r
.18686 .56639 m
.24894 .54792 L
s
.24266 .53609 m .2626 .5576 L .24229 .53945 L .913 .651 .528 r
F
.32401 .64672 m .34383 .68081 L .31729 .65618 L .844 .515 .43 r
F
.29922 .62321 m .32401 .64672 L .31729 .65618 L .866 .547 .446 r
F
.32534 .60748 m .33914 .64224 L .32092 .61669 L .913 .631 .493 r
F
.30696 .58385 m .32534 .60748 L .32092 .61669 L .921 .643 .497 r
F
.30955 .5758 m .32534 .60748 L .30696 .58385 L .919 .645 .506 r
F
.33971 .56319 m .36805 .5854 L .33791 .573 L .785 .503 .509 r
F
.31436 .55155 m .33971 .56319 L .33791 .573 L .825 .544 .513 r
F
.31508 .54345 m .33971 .56319 L .31436 .55155 L .823 .558 .539 r
F
.26316 .48816 m .27461 .47275 L .26524 .49131 L .939 .694 .54 r
F
.26316 .48816 m .2705 .46648 L .27461 .47275 L F
.28046 .59197 m .29922 .62321 L .27699 .59881 L .881 .585 .483 r
F
.25949 .56901 m .28046 .59197 L .27699 .59881 L .9 .613 .492 r
F
.26133 .56367 m .28046 .59197 L .25949 .56901 L .897 .618 .507 r
F
.27169 .46796 m .28789 .45289 L .27517 .47245 L .895 .724 .663 r
F
.27169 .46796 m .28271 .44614 L .28789 .45289 L F
.2246 .4914 m .23204 .46587 L .22691 .4933 L .935 .715 .58 r
F
.2246 .4914 m .22745 .46201 L .23204 .46587 L F
.36805 .5854 m .40636 .59526 L .40272 .60836 L .737 .428 .459 r
F
.40636 .59526 m .43615 .54763 L .40272 .60836 L 0 0 .019 r
F
.40636 .59526 m .43842 .53925 L .43615 .54763 L F
0 g
.40636 .59526 m
.40869 .5805 L
s
.29117 .55438 m .30955 .5758 L .30696 .58385 L .927 .657 .507 r
F
.29239 .54829 m .30955 .5758 L .29117 .55438 L .926 .659 .514 r
F
.27455 .52237 m .29309 .53434 L .29303 .54158 L .933 .673 .52 r
F
.2743 .51853 m .29309 .53434 L .27455 .52237 L .933 .675 .523 r
F
.21692 .3548 m .23637 .32273 L .22776 .35761 L .937 .814 .698 r
F
.21692 .3548 m .22342 .31908 L .23637 .32273 L F
.22342 .31908 m .24283 .32046 L .23637 .32273 L .607 .895 .988 r
F
0 g
.23637 .32273 m
.24281 .32597 L
s
.27191 .4356 m .29057 .41543 L .27735 .44034 L .894 .766 .714 r
F
.27191 .4356 m .28337 .40903 L .29057 .41543 L F
.36805 .5854 m .40272 .60836 L .36484 .59627 L .737 .428 .459 r
F
.33791 .573 m .36805 .5854 L .36484 .59627 L .787 .482 .473 r
F
.26097 .48537 m .2705 .46648 L .26316 .48816 L .941 .696 .54 r
F
.26097 .48537 m .26617 .46091 L .2705 .46648 L F
.29343 .52731 m .31508 .54345 L .29339 .53315 L .857 .603 .554 r
F
.29339 .53315 m .31508 .54345 L .31436 .55155 L .859 .593 .535 r
F
.039 .916 .04 r
.30117 .54796 m
.3077 .54571 L
s
.21834 .4572 m .22573 .4277 L .22286 .45911 L .941 .745 .61 r
F
.21834 .4572 m .21899 .42473 L .22573 .4277 L F
.29922 .62321 m .31729 .65618 L .29371 .63067 L .866 .547 .446 r
F
.27699 .59881 m .29922 .62321 L .29371 .63067 L .886 .579 .461 r
F
.24163 .54249 m .26133 .56367 L .25949 .56901 L .916 .645 .511 r
F
.24229 .53945 m .26133 .56367 L .24163 .54249 L .914 .648 .52 r
F
.24537 .41588 m .25243 .38842 L .25205 .41889 L .947 .724 .569 r
F
.24537 .41588 m .24355 .38425 L .25243 .38842 L F
.33914 .64224 m .35044 .6789 L .3325 .65171 L .909 .615 .475 r
F
.32092 .61669 m .33914 .64224 L .3325 .65171 L .917 .628 .481 r
F
.25262 .44929 m .25882 .4234 L .25716 .45224 L .944 .712 .556 r
F
.25262 .44929 m .25205 .41889 L .25882 .4234 L F
.21336 .38949 m .22776 .35761 L .22206 .39157 L .943 .794 .667 r
F
.21336 .38949 m .21692 .3548 L .22776 .35761 L F
.22342 .31908 m .22993 .31679 L .24283 .32046 L .607 .895 .988 r
F
.23193 .3496 m .24283 .32046 L .2427 .35245 L .951 .748 .594 r
F
.23193 .3496 m .22993 .31679 L .24283 .32046 L F
0 g
.24283 .32046 m
.25606 .32715 L
s
.26808 .46411 m .28271 .44614 L .27169 .46796 L .904 .738 .666 r
F
.26808 .46411 m .27735 .44034 L .28271 .44614 L F
.27455 .52237 m .29303 .54158 L .2745 .52601 L .933 .673 .52 r
F
.2745 .52601 m .29303 .54158 L .29239 .54829 L .934 .671 .516 r
F
.22229 .48997 m .22745 .46201 L .2246 .4914 L .939 .719 .578 r
F
.22229 .48997 m .22286 .45911 L .22745 .46201 L F
.29113 .37455 m .32487 .34989 L .30005 .38081 L .855 .816 .81 r
F
.29113 .37455 m .31431 .3422 L .32487 .34989 L F
.32487 .34989 m .38498 .37813 L .3917 .38452 L .033 .442 .872 r
F
.31431 .3422 m .38498 .37813 L .32487 .34989 L 0 .387 .804 r
F
0 g
.32487 .34989 m
.3354 .35976 L
s
.22399 .52035 m .24009 .51655 L .24117 .52061 L .934 .682 .534 r
F
.22399 .52035 m .23876 .51255 L .24009 .51655 L .934 .684 .536 r
F
.27276 .50584 m .28906 .50171 L .29081 .50824 L .894 .664 .583 r
F
.27168 .50259 m .28906 .50171 L .27276 .50584 L .897 .672 .591 r
F
.27168 .50259 m .28691 .49527 L .28906 .50171 L F
.22399 .52035 m .2372 .50868 L .23876 .51255 L .935 .686 .537 r
F
.27042 .49945 m .28691 .49527 L .27168 .50259 L .899 .681 .598 r
F
.27042 .49945 m .28441 .48902 L .28691 .49527 L F
.22399 .52035 m .24117 .52061 L .24198 .52466 L .933 .68 .531 r
F
.27364 .50913 m .29081 .50824 L .29213 .51475 L .893 .657 .574 r
F
.27276 .50584 m .29081 .50824 L .27364 .50913 L .894 .664 .583 r
F
.22399 .52035 m .23542 .50499 L .2372 .50868 L .936 .688 .538 r
F
.27617 .40413 m .30005 .38081 L .28337 .40903 L .885 .803 .762 r
F
.27617 .40413 m .29113 .37455 L .30005 .38081 L F
.25872 .48299 m .26617 .46091 L .26097 .48537 L .942 .698 .54 r
F
.25872 .48299 m .2617 .45613 L .26617 .46091 L F
.26899 .49646 m .28441 .48902 L .27042 .49945 L .903 .689 .603 r
F
.26899 .49646 m .28159 .48307 L .28441 .48902 L F
.22399 .52035 m .24198 .52466 L .2425 .52864 L .933 .679 .529 r
F
.33791 .573 m .36484 .59627 L .33523 .58165 L .787 .482 .473 r
F
.31294 .5589 m .33791 .573 L .33523 .58165 L .828 .529 .484 r
F
.31436 .55155 m .33791 .573 L .31294 .5589 L .825 .544 .513 r
F
.22399 .52035 m .23348 .50155 L .23542 .50499 L .937 .69 .539 r
F
.21244 .4233 m .22206 .39157 L .21899 .42473 L .946 .774 .636 r
F
.21244 .4233 m .21336 .38949 L .22206 .39157 L F
.27431 .51241 m .29213 .51475 L .29301 .52115 L .892 .649 .564 r
F
.27364 .50913 m .29213 .51475 L .27431 .51241 L .893 .657 .574 r
F
.22399 .52035 m .2425 .52864 L .24273 .53247 L .933 .677 .526 r
F
.29287 .53856 m .31436 .55155 L .31294 .5589 L .861 .583 .515 r
F
.29339 .53315 m .31436 .55155 L .29287 .53856 L .859 .593 .535 r
F
.26743 .49367 m .28159 .48307 L .26899 .49646 L .907 .698 .608 r
F
.26743 .49367 m .27849 .47752 L .28159 .48307 L F
.27699 .59881 m .29371 .63067 L .27277 .60431 L .886 .579 .461 r
F
.25712 .57353 m .27699 .59881 L .27277 .60431 L .904 .61 .477 r
F
.25949 .56901 m .27699 .59881 L .25712 .57353 L .9 .613 .492 r
F
.22399 .52035 m .23139 .49843 L .23348 .50155 L .938 .692 .54 r
F
.24069 .54515 m .25949 .56901 L .25712 .57353 L .918 .642 .502 r
F
.24163 .54249 m .25949 .56901 L .24069 .54515 L .916 .645 .511 r
F
.30696 .58385 m .32092 .61669 L .30358 .59069 L .921 .643 .497 r
F
.28939 .55972 m .30696 .58385 L .30358 .59069 L .929 .655 .5 r
F
.29117 .55438 m .30696 .58385 L .28939 .55972 L .927 .657 .507 r
F
.27416 .52937 m .29239 .54829 L .29117 .55438 L .934 .67 .512 r
F
.2745 .52601 m .29239 .54829 L .27416 .52937 L .934 .671 .516 r
F
.039 .916 .04 r
.25614 .54576 m
.27977 .53761 L
s
.27474 .51562 m .29301 .52115 L .29343 .52731 L .892 .642 .553 r
F
.27431 .51241 m .29301 .52115 L .27474 .51562 L .892 .649 .564 r
F
.22399 .52035 m .24273 .53247 L .24266 .53609 L .933 .675 .524 r
F
.23493 .38213 m .2427 .35245 L .24355 .38425 L .951 .738 .579 r
F
.23493 .38213 m .23193 .3496 L .2427 .35245 L F
.22399 .52035 m .22918 .49566 L .23139 .49843 L .939 .694 .54 r
F
.26575 .49113 m .27849 .47752 L .26743 .49367 L .912 .707 .611 r
F
.26575 .49113 m .27517 .47245 L .27849 .47752 L F
.26443 .46098 m .27735 .44034 L .26808 .46411 L .914 .752 .667 r
F
.26443 .46098 m .27191 .4356 L .27735 .44034 L F
.26647 .43199 m .28337 .40903 L .27191 .4356 L .908 .786 .715 r
F
.26647 .43199 m .27617 .40413 L .28337 .40903 L F
.32092 .61669 m .3325 .65171 L .31551 .62414 L .917 .628 .481 r
F
.30358 .59069 m .32092 .61669 L .31551 .62414 L .924 .641 .487 r
F
.22003 .48905 m .22286 .45911 L .22229 .48997 L .944 .723 .574 r
F
.22003 .48905 m .21834 .4572 L .22286 .45911 L F
.25643 .48106 m .2617 .45613 L .25872 .48299 L .944 .7 .539 r
F
.25643 .48106 m .25716 .45224 L .2617 .45613 L F
.22399 .52035 m .24266 .53609 L .24229 .53945 L .934 .674 .521 r
F
.21398 .45633 m .21899 .42473 L .21834 .4572 L .948 .751 .603 r
F
.21398 .45633 m .21244 .4233 L .21899 .42473 L F
.27494 .51872 m .29343 .52731 L .29339 .53315 L .893 .635 .541 r
F
.27474 .51562 m .29343 .52731 L .27494 .51872 L .892 .642 .553 r
F
.22399 .52035 m .22691 .4933 L .22918 .49566 L .94 .695 .539 r
F
.24816 .44735 m .25205 .41889 L .25262 .44929 L .947 .714 .553 r
F
.24816 .44735 m .24537 .41588 L .25205 .41889 L F
.26399 .48888 m .27517 .47245 L .26575 .49113 L .918 .715 .614 r
F
.26399 .48888 m .27169 .46796 L .27517 .47245 L F
.36484 .59627 m .39782 .61956 L .36057 .60553 L .735 .394 .405 r
F
.36484 .59627 m .40272 .60836 L .39782 .61956 L F
.33523 .58165 m .36484 .59627 L .36057 .60553 L .789 .459 .43 r
F
.31729 .65618 m .34383 .68081 L .33455 .68956 L .85 .501 .392 r
F
.34383 .68081 m .3412 .68764 L .33455 .68956 L .211 0 0 r
F
.34383 .68081 m .35044 .6789 L .3412 .68764 L F
0 g
.34383 .68081 m
.34783 .67494 L
s
.40931 .46457 m .43095 .45834 L .43441 .47099 L .773 .599 .663 r
F
.40585 .45413 m .43095 .45834 L .40931 .46457 L .779 .619 .682 r
F
.40585 .45413 m .42681 .44584 L .43095 .45834 L F
.43095 .45834 m .47442 .45525 L .43441 .47098 L .518 .444 .713 r
F
.43095 .45834 m .47152 .44466 L .47442 .45525 L F
.42681 .44584 m .47152 .44466 L .43095 .45834 L .528 .478 .744 r
F
.42422 .4598 m .43095 .45834 L .43441 .47098 L .958 .688 .48 r
F
.42075 .44934 m .43095 .45834 L .42422 .4598 L F
.42075 .44934 m .42681 .44584 L .43095 .45834 L F
.40272 .60836 m .43308 .55472 L .39782 .61956 L 0 0 0 r
F
.40272 .60836 m .43615 .54763 L .43308 .55472 L F
0 g
.40272 .60836 m
.40636 .59526 L
s
.22399 .52035 m .24229 .53945 L .24163 .54249 L .934 .673 .517 r
F
.039 .916 .04 r
.17309 .55383 m
.23535 .53461 L
s
.31729 .65618 m .33455 .68956 L .30939 .6633 L .85 .501 .392 r
F
.29371 .63067 m .31729 .65618 L .30939 .6633 L .872 .538 .416 r
F
.40185 .44398 m .42681 .44584 L .40585 .45413 L .785 .64 .7 r
F
.40185 .44398 m .42204 .4337 L .42681 .44584 L F
0 g
.42681 .44584 m
.42681 .44584 L
s
.42681 .44584 m .46805 .4342 L .47152 .44466 L .528 .478 .744 r
F
.42205 .4337 m .46805 .4342 L .42681 .44584 L .536 .51 .774 r
F
.41676 .43916 m .42681 .44584 L .42075 .44934 L .958 .688 .48 r
F
.41676 .43916 m .42205 .4337 L .42681 .44584 L F
0 g
.42681 .44584 m
.43095 .45834 L
s
.31294 .5589 m .33523 .58165 L .31086 .56537 L .828 .529 .484 r
F
.29188 .54346 m .31294 .5589 L .31086 .56537 L .865 .573 .493 r
F
.29287 .53856 m .31294 .5589 L .29188 .54346 L .861 .583 .515 r
F
.27353 .53241 m .29117 .55438 L .28939 .55972 L .935 .669 .508 r
F
.27416 .52937 m .29117 .55438 L .27353 .53241 L .934 .67 .512 r
F
.22399 .52035 m .2246 .4914 L .22691 .4933 L .942 .697 .539 r
F
.25712 .57353 m .27277 .60431 L .25425 .57714 L .904 .61 .477 r
F
.23947 .54738 m .25712 .57353 L .25425 .57714 L .921 .64 .492 r
F
.24069 .54515 m .25712 .57353 L .23947 .54738 L .918 .642 .502 r
F
.41219 .47514 m .43441 .47099 L .43712 .48359 L .768 .579 .642 r
F
.40931 .46457 m .43441 .47099 L .41219 .47514 L .773 .599 .663 r
F
0 g
.4344 .47098 m
.43441 .47099 L
s
.43441 .47098 m .47673 .46579 L .43712 .48359 L .503 .407 .679 r
F
.43441 .47098 m .47442 .45525 L .47673 .46579 L F
.42711 .4704 m .43441 .47098 L .43712 .48359 L .958 .688 .48 r
F
.42422 .4598 m .43441 .47098 L .42711 .4704 L F
0 g
.43095 .45834 m
.43441 .47098 L
s
.27494 .51872 m .29339 .53315 L .27491 .52165 L .893 .635 .541 r
F
.27491 .52165 m .29339 .53315 L .29287 .53856 L .894 .629 .529 r
F
.039 .916 .04 r
.28583 .53552 m
.28864 .53458 L
s
.29371 .63067 m .30939 .6633 L .28727 .63622 L .872 .538 .416 r
F
.27277 .60431 m .29371 .63067 L .28727 .63622 L .891 .573 .439 r
F
.39739 .43429 m .42204 .4337 L .40185 .44398 L .793 .661 .717 r
F
.39739 .43429 m .41673 .42209 L .42204 .4337 L F
0 g
.42204 .4337 m
.42204 .4337 L
s
.42205 .4337 m .46408 .42402 L .46805 .4342 L .536 .51 .774 r
F
.41673 .42209 m .46408 .42402 L .42205 .4337 L .541 .541 .804 r
F
.4123 .42944 m .42205 .4337 L .41676 .43916 L .958 .688 .48 r
F
.4123 .42944 m .41673 .42209 L .42205 .4337 L F
0 g
.42205 .4337 m
.42681 .44584 L
s
.23891 .41441 m .24355 .38425 L .24537 .41588 L .951 .727 .564 r
F
.23891 .41441 m .23493 .38213 L .24355 .38425 L F
.3325 .65171 m .35044 .6789 L .3412 .68764 L .913 .612 .46 r
F
0 g
.35044 .6789 m
.35825 .66736 L
s
.33523 .58165 m .36057 .60553 L .3317 .58901 L .789 .459 .43 r
F
.31086 .56537 m .33523 .58165 L .3317 .58901 L .832 .514 .45 r
F
.22399 .52035 m .24163 .54249 L .24069 .54515 L .935 .672 .514 r
F
.25664 .50989 m .26097 .48537 L .26316 .48816 L .945 .69 .52 r
F
.26218 .48696 m .27169 .46796 L .26399 .48888 L .924 .724 .614 r
F
.26218 .48696 m .26808 .46411 L .27169 .46796 L F
.25415 .47962 m .25716 .45224 L .25643 .48106 L .946 .702 .538 r
F
.25415 .47962 m .25262 .44929 L .25716 .45224 L F
.26078 .45862 m .27191 .4356 L .26443 .46098 L .925 .766 .666 r
F
.26078 .45862 m .26647 .43199 L .27191 .4356 L F
.21784 .48866 m .21834 .4572 L .22003 .48905 L .948 .727 .57 r
F
.21784 .48866 m .21398 .45633 L .21834 .4572 L F
.41444 .48568 m .43712 .48359 L .43905 .49596 L .764 .559 .62 r
F
.41219 .47514 m .43712 .48359 L .41444 .48568 L .768 .579 .642 r
F
0 g
.43712 .48359 m
.43712 .48359 L
s
.43712 .48359 m .4784 .47612 L .43905 .49596 L .485 .366 .641 r
F
.43712 .48359 m .47673 .46579 L .4784 .47612 L F
.42938 .48096 m .43712 .48359 L .43905 .49596 L .958 .688 .48 r
F
.42711 .4704 m .43712 .48359 L .42938 .48096 L F
0 g
.43441 .47098 m
.43712 .48359 L
s
.22399 .52035 m .22229 .48997 L .2246 .4914 L .943 .698 .538 r
F
.27277 .60431 m .28727 .63622 L .26785 .60837 L .891 .573 .439 r
F
.25425 .57714 m .27277 .60431 L .26785 .60837 L .909 .606 .461 r
F
.25664 .50989 m .27185 .50639 L .27294 .51047 L .943 .685 .518 r
F
.25664 .50989 m .27051 .50237 L .27185 .50639 L .943 .686 .518 r
F
.25664 .50989 m .26894 .49847 L .27051 .50237 L .943 .687 .519 r
F
.28235 .37027 m .31431 .3422 L .29113 .37455 L .873 .851 .818 r
F
.26908 .40082 m .29113 .37455 L .27617 .40413 L .903 .83 .764 r
F
.26908 .40082 m .28235 .37027 L .29113 .37455 L F
.25664 .50989 m .27294 .51047 L .27376 .51454 L .943 .684 .517 r
F
.30358 .59069 m .31551 .62414 L .29944 .59619 L .924 .641 .487 r
F
.28708 .56424 m .30358 .59069 L .29944 .59619 L .931 .654 .493 r
F
.28939 .55972 m .30358 .59069 L .28708 .56424 L .929 .655 .5 r
F
.39253 .4252 m .41673 .42209 L .39739 .43429 L .802 .683 .733 r
F
.39253 .4252 m .41095 .4112 L .41673 .42209 L F
0 g
.41673 .42209 m
.41673 .42209 L
s
.25664 .50989 m .26718 .49477 L .26894 .49847 L .944 .688 .52 r
F
.41673 .42209 m .45968 .41429 L .46408 .42402 L .541 .541 .804 r
F
.41095 .4112 m .45968 .41429 L .41673 .42209 L .543 .572 .834 r
F
.40745 .42034 m .41673 .42209 L .4123 .42944 L .958 .688 .48 r
F
.40745 .42034 m .41095 .4112 L .41673 .42209 L F
0 g
.41673 .42209 m
.42205 .4337 L
s
.27463 .52437 m .29287 .53856 L .29188 .54346 L .896 .623 .515 r
F
.27491 .52165 m .29287 .53856 L .27463 .52437 L .894 .629 .529 r
F
.25664 .50989 m .27376 .51454 L .2743 .51853 L .942 .684 .516 r
F
.22399 .52035 m .24069 .54515 L .23947 .54738 L .936 .671 .511 r
F
.28235 .37027 m .30389 .33685 L .31431 .3422 L .873 .851 .818 r
F
.31431 .3422 m .37829 .3732 L .38498 .37813 L 0 .387 .804 r
F
.30389 .33685 m .37829 .3732 L .31431 .3422 L 0 .284 .66 r
F
0 g
.31431 .3422 m
.32487 .34989 L
s
.25664 .50989 m .26524 .49131 L .26718 .49477 L .944 .688 .52 r
F
.3325 .65171 m .3412 .68764 L .32468 .65881 L .913 .612 .46 r
F
.31551 .62414 m .3325 .65171 L .32468 .65881 L .92 .626 .469 r
F
.26112 .42959 m .27617 .40413 L .26647 .43199 L .923 .807 .714 r
F
.26112 .42959 m .26908 .40082 L .27617 .40413 L F
.27262 .53507 m .28939 .55972 L .28708 .56424 L .936 .668 .504 r
F
.27353 .53241 m .28939 .55972 L .27262 .53507 L .935 .669 .508 r
F
.25664 .50989 m .2743 .51853 L .27455 .52237 L .942 .683 .514 r
F
.20656 .35462 m .22342 .31908 L .21692 .3548 L .952 .831 .687 r
F
.20506 .38953 m .21692 .3548 L .21336 .38949 L .956 .807 .657 r
F
.20506 .38953 m .20656 .35462 L .21692 .3548 L F
.25664 .50989 m .25872 .48299 L .26097 .48537 L .946 .691 .52 r
F
.26034 .48541 m .26808 .46411 L .26218 .48696 L .93 .732 .613 r
F
.26034 .48541 m .26443 .46098 L .26808 .46411 L F
.22399 .52035 m .22003 .48905 L .22229 .48997 L .945 .699 .536 r
F
.20622 .42347 m .21336 .38949 L .21244 .4233 L .957 .782 .626 r
F
.20622 .42347 m .20506 .38953 L .21336 .38949 L F
.25664 .50989 m .26316 .48816 L .26524 .49131 L .944 .689 .52 r
F
.41602 .49602 m .43905 .49596 L .44016 .5079 L .761 .538 .595 r
F
.41444 .48568 m .43905 .49596 L .41602 .49602 L .764 .559 .62 r
F
0 g
.43905 .49595 m
.43905 .49596 L
s
.43905 .49596 m .47939 .48607 L .44016 .50789 L .462 .317 .598 r
F
.43905 .49596 m .4784 .47612 L .47939 .48607 L F
.43099 .49131 m .43905 .49596 L .44016 .50789 L .958 .688 .48 r
F
.42938 .48096 m .43905 .49596 L .43099 .49131 L F
0 g
.43712 .48359 m
.43905 .49596 L
s
.31086 .56537 m .3317 .58901 L .30813 .57084 L .832 .514 .45 r
F
.29045 .54775 m .31086 .56537 L .30813 .57084 L .869 .564 .468 r
F
.29188 .54346 m .31086 .56537 L .29045 .54775 L .865 .573 .493 r
F
.25425 .57714 m .26785 .60837 L .25092 .57977 L .909 .606 .461 r
F
.23801 .54915 m .25425 .57714 L .25092 .57977 L .924 .639 .483 r
F
.23947 .54738 m .25425 .57714 L .23801 .54915 L .921 .64 .492 r
F
.21102 .31856 m .22993 .31679 L .22342 .31908 L .514 .903 .942 r
F
.20656 .35462 m .21102 .31856 L .22342 .31908 L .952 .831 .687 r
F
0 g
.22342 .31908 m
.23018 .32098 L
s
.39193 .46943 m .40931 .46457 L .41219 .47514 L .806 .618 .647 r
F
.38915 .46105 m .40931 .46457 L .39193 .46943 L .811 .635 .664 r
F
.38915 .46105 m .40585 .45413 L .40931 .46457 L F
.38593 .4529 m .40585 .45413 L .38915 .46105 L .817 .654 .68 r
F
.38593 .4529 m .40185 .44398 L .40585 .45413 L F
.20984 .45653 m .21244 .4233 L .21398 .45633 L .955 .757 .595 r
F
.20984 .45653 m .20622 .42347 L .21244 .4233 L F
.25664 .50989 m .27455 .52237 L .2745 .52601 L .943 .682 .513 r
F
.24385 .44645 m .24537 .41588 L .24816 .44735 L .95 .716 .549 r
F
.24385 .44645 m .23891 .41441 L .24537 .41588 L F
.39424 .47793 m .41219 .47514 L .41444 .48568 L .803 .6 .629 r
F
.39193 .46943 m .41219 .47514 L .39424 .47793 L .806 .618 .647 r
F
.22399 .52035 m .23947 .54738 L .23801 .54915 L .937 .671 .508 r
F
.25191 .47868 m .25262 .44929 L .25415 .47962 L .948 .704 .536 r
F
.25191 .47868 m .24816 .44735 L .25262 .44929 L F
.38735 .41688 m .41095 .4112 L .39253 .4252 L .812 .707 .748 r
F
.38735 .41688 m .40478 .4012 L .41095 .4112 L F
0 g
.41095 .4112 m
.41095 .4112 L
s
.41095 .4112 m .4549 .40516 L .45968 .41429 L .543 .572 .834 r
F
.40479 .4012 m .4549 .40516 L .41095 .4112 L .542 .604 .865 r
F
.40229 .41198 m .41095 .4112 L .40745 .42034 L .958 .688 .48 r
F
.40229 .41198 m .40479 .4012 L .41095 .4112 L F
0 g
.41095 .4112 m
.41673 .42209 L
s
.38234 .44513 m .40185 .44398 L .38593 .4529 L .825 .672 .694 r
F
.38234 .44513 m .39739 .43429 L .40185 .44398 L F
.25664 .50989 m .2745 .52601 L .27416 .52937 L .943 .682 .512 r
F
.27412 .52681 m .29188 .54346 L .29045 .54775 L .899 .617 .5 r
F
.27463 .52437 m .29188 .54346 L .27412 .52681 L .896 .623 .515 r
F
.22399 .52035 m .21784 .48866 L .22003 .48905 L .946 .7 .534 r
F
.21578 .48881 m .21398 .45633 L .21784 .48866 L .952 .73 .564 r
F
.21578 .48881 m .20984 .45653 L .21398 .45633 L F
.31551 .62414 m .32468 .65881 L .30916 .62968 L .92 .626 .469 r
F
.29944 .59619 m .31551 .62414 L .30916 .62968 L .927 .639 .478 r
F
.21102 .31856 m .21756 .31626 L .22993 .31679 L .514 .903 .942 r
F
.22165 .34938 m .22993 .31679 L .23193 .3496 L .957 .753 .586 r
F
.22165 .34938 m .21756 .31626 L .22993 .31679 L F
0 g
.22993 .31679 m
.24283 .32046 L
s
.25719 .45707 m .26647 .43199 L .26078 .45862 L .936 .78 .662 r
F
.25719 .45707 m .26112 .42959 L .26647 .43199 L F
.39603 .48639 m .41444 .48568 L .41602 .49602 L .8 .583 .608 r
F
.39424 .47793 m .41444 .48568 L .39603 .48639 L .803 .6 .629 r
F
.25937 .50902 m .27276 .50584 L .27364 .50913 L .93 .68 .539 r
F
.25937 .50902 m .27168 .50259 L .27276 .50584 L .931 .683 .542 r
F
.25937 .50902 m .27042 .49945 L .27168 .50259 L .932 .687 .545 r
F
.25937 .50902 m .27364 .50913 L .27431 .51241 L .929 .677 .535 r
F
.25664 .50989 m .25643 .48106 L .25872 .48299 L .946 .691 .52 r
F
.2585 .48425 m .26443 .46098 L .26034 .48541 L .937 .74 .611 r
F
.2585 .48425 m .26078 .45862 L .26443 .46098 L F
.25937 .50902 m .26899 .49646 L .27042 .49945 L .933 .69 .547 r
F
.25937 .50902 m .27431 .51241 L .27474 .51562 L .929 .674 .531 r
F
.37842 .43785 m .39739 .43429 L .38234 .44513 L .833 .692 .707 r
F
.37842 .43785 m .39253 .4252 L .39739 .43429 L F
.23801 .54915 m .25092 .57977 L .23633 .55043 L .924 .639 .483 r
F
.22399 .52035 m .23801 .54915 L .23633 .55043 L .938 .67 .505 r
F
.25937 .50902 m .26743 .49367 L .26899 .49646 L .935 .693 .548 r
F
.36057 .60553 m .39171 .62864 L .3553 .61301 L .731 .354 .337 r
F
.36057 .60553 m .39782 .61956 L .39171 .62864 L F
.3317 .58901 m .36057 .60553 L .3553 .61301 L .791 .433 .378 r
F
.41691 .50599 m .44016 .5079 L .44043 .51921 L .758 .516 .566 r
F
.41602 .49602 m .44016 .5079 L .41691 .50599 L .761 .538 .595 r
F
0 g
.44016 .50789 m
.44016 .5079 L
s
.44016 .50789 m .4797 .49549 L .44043 .51921 L .43 .259 .546 r
F
.44016 .50789 m .47939 .48607 L .4797 .49549 L F
.4319 .5013 m .44016 .50789 L .44043 .51921 L .958 .688 .48 r
F
.43099 .49131 m .44016 .50789 L .4319 .5013 L F
0 g
.43905 .49596 m
.44016 .50789 L
s
.22672 .38213 m .23193 .3496 L .23493 .38213 L .956 .742 .572 r
F
.22672 .38213 m .22165 .34938 L .23193 .3496 L F
.3317 .58901 m .3553 .61301 L .32736 .59492 L .791 .433 .378 r
F
.30813 .57084 m .3317 .58901 L .32736 .59492 L .837 .497 .412 r
F
.25664 .50989 m .27416 .52937 L .27353 .53241 L .943 .681 .51 r
F
.039 .916 .04 r
.23941 .53336 m
.26729 .52409 L
s
.25937 .50902 m .27474 .51562 L .27494 .51872 L .929 .671 .527 r
F
.28708 .56424 m .29944 .59619 L .28428 .56784 L .931 .654 .493 r
F
.27144 .53731 m .28708 .56424 L .28428 .56784 L .938 .667 .5 r
F
.27262 .53507 m .28708 .56424 L .27144 .53731 L .936 .668 .504 r
F
.25937 .50902 m .26575 .49113 L .26743 .49367 L .937 .696 .549 r
F
.22399 .52035 m .21578 .48881 L .21784 .48866 L .947 .701 .532 r
F
.41742 .46128 m .42422 .4598 L .42711 .4704 L .958 .688 .48 r
F
.41463 .45287 m .42422 .4598 L .41742 .46128 L F
.41463 .45287 m .42075 .44934 L .42422 .4598 L F
.41141 .44469 m .42075 .44934 L .41463 .45287 L F
.41141 .44469 m .41676 .43916 L .42075 .44934 L F
.39728 .49468 m .41602 .49602 L .41691 .50599 L .798 .566 .586 r
F
.39603 .48639 m .41602 .49602 L .39728 .49468 L .8 .583 .608 r
F
.25937 .50902 m .27494 .51872 L .27491 .52165 L .929 .669 .522 r
F
.29045 .54775 m .30813 .57084 L .28859 .55137 L .869 .564 .468 r
F
.27339 .52895 m .29045 .54775 L .28859 .55137 L .903 .612 .485 r
F
.27412 .52681 m .29045 .54775 L .27339 .52895 L .899 .617 .5 r
F
.26785 .60837 m .27999 .63975 L .26232 .6109 L .898 .568 .414 r
F
.26785 .60837 m .28727 .63622 L .27999 .63975 L F
.25092 .57977 m .26785 .60837 L .26232 .6109 L .914 .604 .445 r
F
.25092 .57977 m .26232 .6109 L .24719 .58137 L F
.23633 .55043 m .25092 .57977 L .24719 .58137 L .927 .638 .474 r
F
.41974 .46981 m .42711 .4704 L .42938 .48096 L .958 .688 .48 r
F
.41742 .46128 m .42711 .4704 L .41974 .46981 L F
.29944 .59619 m .30916 .62968 L .29461 .60023 L .927 .639 .478 r
F
.28428 .56784 m .29944 .59619 L .29461 .60023 L .933 .653 .486 r
F
.25937 .50902 m .26399 .48888 L .26575 .49113 L .939 .699 .549 r
F
.38193 .40945 m .40478 .4012 L .38735 .41688 L .824 .732 .763 r
F
.38193 .40945 m .39833 .39226 L .40478 .4012 L F
0 g
.40478 .4012 m
.40479 .4012 L
s
.40479 .4012 m .44982 .39679 L .4549 .40516 L .542 .604 .865 r
F
.39834 .39226 m .44982 .39679 L .40479 .4012 L .535 .637 .897 r
F
.39689 .40453 m .40479 .4012 L .40229 .41198 L .958 .688 .48 r
F
.39689 .40453 m .39834 .39226 L .40479 .4012 L F
0 g
.40479 .4012 m
.41095 .4112 L
s
.40782 .43688 m .41676 .43916 L .41141 .44469 L .958 .688 .48 r
F
.40782 .43688 m .4123 .42944 L .41676 .43916 L F
.39782 .61956 m .42924 .56038 L .39171 .62864 L .708 .863 .451 r
F
0 g
.40216 .60963 m
.40272 .60836 L
s
.39782 .61956 m .43308 .55472 L .42924 .56038 L .708 .863 .451 r
F
.30813 .57084 m .32736 .59492 L .30481 .57521 L .837 .497 .412 r
F
.28859 .55137 m .30813 .57084 L .30481 .57521 L .874 .555 .441 r
F
.28727 .63622 m .30042 .66791 L .27999 .63975 L .879 .529 .383 r
F
.28727 .63622 m .30939 .6633 L .30042 .66791 L F
.25664 .50989 m .27353 .53241 L .27262 .53507 L .943 .681 .509 r
F
.23277 .41454 m .23493 .38213 L .23891 .41441 L .955 .73 .558 r
F
.23277 .41454 m .22672 .38213 L .23493 .38213 L F
.24976 .47828 m .24816 .44735 L .25191 .47868 L .949 .705 .533 r
F
.24976 .47828 m .24385 .44645 L .24816 .44735 L F
.23633 .55043 m .24719 .58137 L .23444 .55119 L .927 .638 .474 r
F
.22399 .52035 m .23633 .55043 L .23444 .55119 L .939 .67 .502 r
F
.37425 .4312 m .39253 .4252 L .37842 .43785 L .843 .712 .719 r
F
.37425 .4312 m .38735 .41688 L .39253 .4252 L F
.25937 .50902 m .27491 .52165 L .27463 .52437 L .93 .667 .517 r
F
.039 .916 .04 r
.27101 .52285 m
.27261 .52233 L
s
.25671 .4835 m .26078 .45862 L .2585 .48425 L .945 .748 .606 r
F
.25671 .4835 m .25719 .45707 L .26078 .45862 L F
.25937 .50902 m .26218 .48696 L .26399 .48888 L .941 .702 .549 r
F
.25664 .50989 m .25415 .47962 L .25643 .48106 L .947 .692 .519 r
F
.42156 .4783 m .42938 .48096 L .43099 .49131 L .958 .688 .48 r
F
.41974 .46981 m .42938 .48096 L .42156 .4783 L F
.26223 .39917 m .28235 .37027 L .26908 .40082 L .922 .859 .762 r
F
.25595 .42846 m .26908 .40082 L .26112 .42959 L .939 .827 .707 r
F
.25595 .42846 m .26223 .39917 L .26908 .40082 L F
.21387 .48949 m .20984 .45653 L .21578 .48881 L .957 .732 .557 r
F
.22399 .52035 m .21387 .48949 L .21578 .48881 L .949 .701 .53 r
F
.20599 .4578 m .20622 .42347 L .20984 .45653 L .963 .761 .585 r
F
.21387 .48949 m .20599 .4578 L .20984 .45653 L .957 .732 .557 r
F
.30939 .6633 m .32397 .69531 L .30042 .66791 L .856 .487 .349 r
F
.30939 .6633 m .33455 .68956 L .32397 .69531 L F
.37748 .47335 m .39193 .46943 L .39424 .47793 L .838 .635 .628 r
F
.37538 .46704 m .39193 .46943 L .37748 .47335 L .843 .65 .642 r
F
.37538 .46704 m .38915 .46105 L .39193 .46943 L F
.27383 .36805 m .30389 .33685 L .28235 .37027 L .893 .89 .82 r
F
.26223 .39917 m .27383 .36805 L .28235 .37027 L .922 .859 .762 r
F
.22399 .52035 m .21215 .49069 L .21387 .48949 L .95 .702 .527 r
F
.22399 .52035 m .21064 .4924 L .21215 .49069 L .951 .701 .524 r
F
.22399 .52035 m .20938 .49459 L .21064 .4924 L .952 .701 .52 r
F
.22399 .52035 m .20839 .49722 L .20938 .49459 L .953 .7 .517 r
F
.22399 .52035 m .20768 .50025 L .20839 .49722 L .954 .699 .514 r
F
.22399 .52035 m .20727 .50362 L .20768 .50025 L .954 .698 .51 r
F
.22399 .52035 m .20717 .50729 L .20727 .50362 L .955 .697 .507 r
F
.22399 .52035 m .20738 .51117 L .20717 .50729 L .955 .695 .503 r
F
.039 .916 .04 r
.14431 .52845 m
.20719 .50757 L
s
.22399 .52035 m .2079 .51522 L .20738 .51117 L .955 .693 .5 r
F
.22399 .52035 m .20871 .51935 L .2079 .51522 L .954 .691 .498 r
F
.22399 .52035 m .20981 .5235 L .20871 .51935 L .954 .689 .495 r
F
.22399 .52035 m .21117 .52758 L .20981 .5235 L .953 .687 .493 r
F
.039 .916 .04 r
.15891 .54118 m
.21023 .52475 L
s
.22399 .52035 m .21277 .53153 L .21117 .52758 L .953 .685 .491 r
F
.22399 .52035 m .21459 .53528 L .21277 .53153 L .952 .683 .49 r
F
.22399 .52035 m .21658 .53876 L .21459 .53528 L .951 .681 .489 r
F
.22399 .52035 m .21872 .54192 L .21658 .53876 L .95 .679 .489 r
F
.22399 .52035 m .22097 .54469 L .21872 .54192 L .948 .677 .489 r
F
.22399 .52035 m .22328 .54703 L .22097 .54469 L .947 .675 .49 r
F
.22399 .52035 m .22562 .5489 L .22328 .54703 L .946 .674 .491 r
F
.22399 .52035 m .22795 .55027 L .22562 .5489 L .944 .673 .492 r
F
.22399 .52035 m .23022 .55111 L .22795 .55027 L .943 .672 .494 r
F
.22399 .52035 m .2324 .55142 L .23022 .55111 L .942 .671 .497 r
F
.22399 .52035 m .23444 .55119 L .2324 .55142 L .94 .671 .499 r
F
.37296 .46091 m .38915 .46105 L .37538 .46704 L .848 .666 .655 r
F
.37296 .46091 m .38593 .4529 L .38915 .46105 L F
.25937 .50902 m .27463 .52437 L .27412 .52681 L .931 .665 .512 r
F
.40392 .42956 m .4123 .42944 L .40782 .43688 L .958 .688 .48 r
F
.40392 .42956 m .40745 .42034 L .4123 .42944 L F
.37922 .47975 m .39424 .47793 L .39603 .48639 L .835 .62 .612 r
F
.37748 .47335 m .39424 .47793 L .37922 .47975 L .838 .635 .628 r
F
.25374 .45637 m .26112 .42959 L .25719 .45707 L .948 .792 .654 r
F
.25374 .45637 m .25595 .42846 L .26112 .42959 L F
.41691 .50599 m .44043 .51921 L .41709 .51543 L .758 .516 .566 r
F
.39797 .50268 m .41691 .50599 L .41709 .51543 L .797 .548 .561 r
F
.39728 .49468 m .41691 .50599 L .39797 .50268 L .798 .566 .586 r
F
.20043 .42524 m .20506 .38953 L .20622 .42347 L .967 .79 .612 r
F
.20599 .4578 m .20043 .42524 L .20622 .42347 L .963 .761 .585 r
F
.25664 .50989 m .27262 .53507 L .27144 .53731 L .944 .68 .507 r
F
.25937 .50902 m .26034 .48541 L .26218 .48696 L .943 .705 .548 r
F
.37025 .45506 m .38593 .4529 L .37296 .46091 L .854 .682 .667 r
F
.37025 .45506 m .38234 .44513 L .38593 .4529 L F
.23977 .44663 m .23891 .41441 L .24385 .44645 L .953 .718 .544 r
F
.23977 .44663 m .23277 .41454 L .23891 .41441 L F
.41709 .51543 m .44043 .51921 L .43985 .52972 L .757 .493 .534 r
F
0 g
.44043 .5192 m
.44043 .51921 L
s
.4319 .5013 m .44043 .51921 L .43211 .51075 L .958 .688 .48 r
F
.44043 .51921 m .47931 .50421 L .43985 .52972 L .388 .186 .48 r
F
.44043 .51921 m .4797 .49549 L .47931 .50421 L F
.43211 .51075 m .44043 .51921 L .43985 .52972 L .958 .688 .48 r
F
0 g
.44016 .50789 m
.44043 .51921 L
s
.23444 .55119 m .24312 .58192 L .2324 .55142 L .931 .638 .465 r
F
.23444 .55119 m .24719 .58137 L .24312 .58192 L F
.28859 .55137 m .30481 .57521 L .28633 .55425 L .874 .555 .441 r
F
.27244 .53074 m .28859 .55137 L .28633 .55425 L .907 .608 .469 r
F
.27339 .52895 m .28859 .55137 L .27244 .53074 L .903 .612 .485 r
F
.25664 .50989 m .25191 .47868 L .25415 .47962 L .947 .692 .518 r
F
.28428 .56784 m .29461 .60023 L .28102 .57046 L .933 .653 .486 r
F
.27001 .53908 m .28428 .56784 L .28102 .57046 L .939 .666 .496 r
F
.27144 .53731 m .28428 .56784 L .27001 .53908 L .938 .667 .5 r
F
.38056 .48612 m .39603 .48639 L .39728 .49468 L .833 .606 .594 r
F
.37922 .47975 m .39603 .48639 L .38056 .48612 L .835 .62 .612 r
F
.42284 .48662 m .43099 .49131 L .4319 .5013 L .958 .688 .48 r
F
.42156 .4783 m .43099 .49131 L .42284 .48662 L F
.25937 .50902 m .27412 .52681 L .27339 .52895 L .932 .663 .507 r
F
.36987 .42526 m .38735 .41688 L .37425 .4312 L .854 .734 .73 r
F
.36987 .42526 m .38193 .40945 L .38735 .41688 L F
.21215 .49069 m .20599 .4578 L .21387 .48949 L .96 .733 .549 r
F
.33455 .68956 m .33066 .69339 L .32397 .69531 L .002 0 0 r
F
.33455 .68956 m .3412 .68764 L .33066 .69339 L F
0 g
.33455 .68956 m
.33958 .68481 L
s
.19732 .39172 m .20656 .35462 L .20506 .38953 L .968 .818 .641 r
F
.20043 .42524 m .19732 .39172 L .20506 .38953 L .967 .79 .612 r
F
.36729 .44959 m .38234 .44513 L .37025 .45506 L .862 .698 .678 r
F
.36729 .44959 m .37842 .43785 L .38234 .44513 L F
.25937 .50902 m .2585 .48425 L .26034 .48541 L .946 .707 .546 r
F
.30389 .33685 m .37174 .36982 L .37829 .3732 L 0 .284 .66 r
F
.27383 .36805 m .29379 .33396 L .30389 .33685 L .893 .89 .82 r
F
.29379 .33396 m .37174 .36982 L .30389 .33685 L .453 0 0 r
F
.25498 .48318 m .25719 .45707 L .25671 .4835 L .952 .754 .599 r
F
.25498 .48318 m .25374 .45637 L .25719 .45707 L F
.39977 .42287 m .40745 .42034 L .40392 .42956 L .958 .688 .48 r
F
.39977 .42287 m .40229 .41198 L .40745 .42034 L F
.24719 .58137 m .25626 .61183 L .24312 .58192 L .919 .602 .428 r
F
.24719 .58137 m .26232 .6109 L .25626 .61183 L F
.25664 .50989 m .27144 .53731 L .27001 .53908 L .944 .68 .506 r
F
.37635 .40304 m .39833 .39226 L .38193 .40945 L .838 .759 .776 r
F
.37635 .40304 m .3917 .38452 L .39833 .39226 L F
0 g
.39833 .39226 m
.39834 .39226 L
s
.39834 .39226 m .44453 .3893 L .44982 .39679 L .535 .637 .897 r
F
.3917 .38452 m .44453 .3893 L .39834 .39226 L .521 .671 .931 r
F
.39133 .39809 m .39834 .39226 L .39689 .40453 L .958 .688 .48 r
F
.39133 .39809 m .3917 .38452 L .39834 .39226 L F
0 g
.39834 .39226 m
.40479 .4012 L
s
.24773 .47841 m .24385 .44645 L .24976 .47828 L .951 .706 .53 r
F
.24773 .47841 m .23977 .44663 L .24385 .44645 L F
.25937 .50902 m .27339 .52895 L .27244 .53074 L .933 .661 .501 r
F
.38149 .49237 m .39728 .49468 L .39797 .50268 L .832 .592 .575 r
F
.38056 .48612 m .39728 .49468 L .38149 .49237 L .833 .606 .594 r
F
.2324 .55142 m .23878 .58137 L .23022 .55111 L .935 .639 .456 r
F
.2324 .55142 m .24312 .58192 L .23878 .58137 L F
.25664 .50989 m .24976 .47828 L .25191 .47868 L .948 .693 .517 r
F
.32468 .65881 m .3412 .68764 L .33066 .69339 L .918 .61 .445 r
F
0 g
.3412 .68764 m
.35044 .6789 L
s
.30481 .57521 m .32228 .59926 L .30093 .57841 L .842 .48 .368 r
F
.30481 .57521 m .32736 .59492 L .32228 .59926 L F
.28633 .55425 m .30481 .57521 L .30093 .57841 L .88 .546 .412 r
F
.25937 .50902 m .25671 .4835 L .2585 .48425 L .948 .709 .544 r
F
.32468 .65881 m .33066 .69339 L .3158 .66339 L .918 .61 .445 r
F
.30916 .62968 m .32468 .65881 L .3158 .66339 L .924 .624 .456 r
F
.32736 .59492 m .34909 .61855 L .32228 .59926 L .793 .403 .316 r
F
.32736 .59492 m .3553 .61301 L .34909 .61855 L F
.39797 .50268 m .41709 .51543 L .39808 .51025 L .797 .548 .561 r
F
.41709 .51543 m .43985 .52972 L .41655 .52419 L .757 .493 .534 r
F
.39808 .51025 m .41709 .51543 L .41655 .52419 L .797 .529 .533 r
F
.36413 .44459 m .37842 .43785 L .36729 .44959 L .871 .715 .687 r
F
.36413 .44459 m .37425 .4312 L .37842 .43785 L F
.21215 .49069 m .20252 .46013 L .20599 .4578 L .96 .733 .549 r
F
.21064 .4924 m .20252 .46013 L .21215 .49069 L .964 .733 .54 r
F
.19687 .35711 m .21102 .31856 L .20656 .35462 L .967 .847 .67 r
F
.19732 .39172 m .19687 .35711 L .20656 .35462 L .968 .818 .641 r
F
.30916 .62968 m .3158 .66339 L .30198 .63318 L .924 .624 .456 r
F
.29461 .60023 m .30916 .62968 L .30198 .63318 L .93 .639 .468 r
F
.20252 .46013 m .20043 .42524 L .20599 .4578 L .969 .764 .572 r
F
.42357 .49464 m .4319 .5013 L .43211 .51075 L .958 .688 .48 r
F
.42284 .48662 m .4319 .5013 L .42357 .49464 L F
.28633 .55425 m .30093 .57841 L .28371 .55633 L .88 .546 .412 r
F
.27129 .53216 m .28633 .55425 L .28371 .55633 L .911 .605 .452 r
F
.27244 .53074 m .28633 .55425 L .27129 .53216 L .907 .608 .469 r
F
.26232 .6109 m .27198 .64115 L .25626 .61183 L .904 .564 .389 r
F
.26232 .6109 m .27999 .63975 L .27198 .64115 L F
.25937 .50902 m .27244 .53074 L .27129 .53216 L .935 .66 .495 r
F
.27001 .53908 m .28102 .57046 L .26836 .54035 L .939 .666 .496 r
F
.25664 .50989 m .27001 .53908 L .26836 .54035 L .944 .68 .505 r
F
.29461 .60023 m .30198 .63318 L .28917 .60273 L .93 .639 .468 r
F
.28102 .57046 m .29461 .60023 L .28917 .60273 L .935 .653 .48 r
F
.3553 .61301 m .38448 .63542 L .34909 .61855 L .723 .303 .251 r
F
.3553 .61301 m .39171 .62864 L .38448 .63542 L F
.23022 .55111 m .23424 .57975 L .22795 .55027 L .939 .64 .448 r
F
.23022 .55111 m .23878 .58137 L .23424 .57975 L F
.38199 .49839 m .39797 .50268 L .39808 .51025 L .832 .577 .553 r
F
.38149 .49237 m .39797 .50268 L .38199 .49839 L .832 .592 .575 r
F
.25937 .50902 m .25498 .48318 L .25671 .4835 L .95 .711 .54 r
F
.36538 .42016 m .38193 .40945 L .36987 .42526 L .867 .757 .739 r
F
.36538 .42016 m .37635 .40304 L .38193 .40945 L F
.39542 .4169 m .40229 .41198 L .39977 .42287 L .958 .688 .48 r
F
.39542 .4169 m .39689 .40453 L .40229 .41198 L F
.25664 .50989 m .24773 .47841 L .24976 .47828 L .948 .693 .516 r
F
.41655 .52419 m .43985 .52972 L .43842 .53925 L .755 .467 .496 r
F
0 g
.43985 .52972 m
.43985 .52971 L
s
.43985 .52972 m .47822 .5121 L .43842 .53924 L .328 .091 .394 r
F
.43985 .52972 m .47931 .50421 L .47822 .5121 L F
.43161 .51952 m .43985 .52972 L .43842 .53924 L .958 .688 .48 r
F
.43211 .51075 m .43985 .52972 L .43161 .51952 L F
0 g
.43985 .52972 m
.44043 .51921 L
s
.25105 .42861 m .26223 .39917 L .25595 .42846 L .955 .847 .695 r
F
.25047 .45654 m .25595 .42846 L .25374 .45637 L .961 .804 .643 r
F
.25047 .45654 m .25105 .42861 L .25595 .42846 L F
.28102 .57046 m .28917 .60273 L .27735 .57204 L .935 .653 .48 r
F
.26836 .54035 m .28102 .57046 L .27735 .57204 L .94 .666 .492 r
F
.25335 .48329 m .25374 .45637 L .25498 .48318 L .959 .76 .59 r
F
.25335 .48329 m .25047 .45654 L .25374 .45637 L F
.21064 .4924 m .19947 .46349 L .20252 .46013 L .964 .733 .54 r
F
.20938 .49459 m .19947 .46349 L .21064 .4924 L .967 .732 .53 r
F
.41054 .46278 m .41742 .46128 L .41974 .46981 L .958 .688 .48 r
F
.40843 .45643 m .41742 .46128 L .41054 .46278 L F
.40843 .45643 m .41463 .45287 L .41742 .46128 L F
.36083 .44015 m .37425 .4312 L .36413 .44459 L .881 .733 .694 r
F
.36083 .44015 m .36987 .42526 L .37425 .4312 L F
.40601 .45027 m .41463 .45287 L .40843 .45643 L .958 .688 .48 r
F
.40601 .45027 m .41141 .44469 L .41463 .45287 L F
.27129 .53216 m .28371 .55633 L .26996 .53318 L .911 .605 .452 r
F
.25937 .50902 m .27129 .53216 L .26996 .53318 L .936 .66 .49 r
F
.25571 .39925 m .27383 .36805 L .26223 .39917 L .941 .888 .751 r
F
.25105 .42861 m .25571 .39925 L .26223 .39917 L .955 .847 .695 r
F
.41229 .46921 m .41974 .46981 L .42156 .4783 L .958 .688 .48 r
F
.41054 .46278 m .41974 .46981 L .41229 .46921 L F
.36535 .47653 m .37748 .47335 L .37922 .47975 L .871 .652 .604 r
F
.36395 .4723 m .37748 .47335 L .36535 .47653 L .874 .664 .615 r
F
.36395 .4723 m .37538 .46704 L .37748 .47335 L F
.26836 .54035 m .27735 .57204 L .26652 .5411 L .94 .666 .492 r
F
.25664 .50989 m .26836 .54035 L .26652 .5411 L .945 .68 .503 r
F
.24312 .58192 m .24978 .61113 L .23878 .58137 L .925 .602 .412 r
F
.24312 .58192 m .25626 .61183 L .24978 .61113 L F
.36232 .46819 m .37538 .46704 L .36395 .4723 L .878 .676 .625 r
F
.36232 .46819 m .37296 .46091 L .37538 .46704 L F
.19939 .32127 m .21756 .31626 L .21102 .31856 L .33 .811 .774 r
F
.19687 .35711 m .19939 .32127 L .21102 .31856 L .967 .847 .67 r
F
0 g
.21102 .31856 m
.21788 .31885 L
s
.25937 .50902 m .25335 .48329 L .25498 .48318 L .953 .712 .537 r
F
.4033 .44438 m .41141 .44469 L .40601 .45027 L .958 .688 .48 r
F
.4033 .44438 m .40782 .43688 L .41141 .44469 L F
.36651 .48081 m .37922 .47975 L .38056 .48612 L .868 .64 .591 r
F
.36535 .47653 m .37922 .47975 L .36651 .48081 L .871 .652 .604 r
F
.19518 .42861 m .19732 .39172 L .20043 .42524 L .976 .795 .595 r
F
.20252 .46013 m .19518 .42861 L .20043 .42524 L .969 .764 .572 r
F
.22706 .41629 m .22672 .38213 L .23277 .41454 L .959 .732 .551 r
F
.23599 .44788 m .23277 .41454 L .23977 .44663 L .956 .719 .539 r
F
.23599 .44788 m .22706 .41629 L .23277 .41454 L F
.22795 .55027 m .22957 .57707 L .22562 .5489 L .942 .642 .441 r
F
.22795 .55027 m .23424 .57975 L .22957 .57707 L F
.27999 .63975 m .29052 .66986 L .27198 .64115 L .886 .52 .347 r
F
.27999 .63975 m .30042 .66791 L .29052 .66986 L F
.24585 .47907 m .23977 .44663 L .24773 .47841 L .953 .706 .527 r
F
.24585 .47907 m .23599 .44788 L .23977 .44663 L F
.3605 .46428 m .37296 .46091 L .36232 .46819 L .883 .689 .634 r
F
.3605 .46428 m .37025 .45506 L .37296 .46091 L F
.21907 .38428 m .22165 .34938 L .22672 .38213 L .962 .744 .563 r
F
.22706 .41629 m .21907 .38428 L .22672 .38213 L .959 .732 .551 r
F
.37071 .39777 m .3917 .38452 L .37635 .40304 L .853 .789 .787 r
F
.37071 .39777 m .38498 .37813 L .3917 .38452 L F
0 g
.3917 .38452 m
.3917 .38453 L
s
.3917 .38452 m .4391 .38283 L .44453 .3893 L .521 .671 .931 r
F
.42357 .49464 m .43211 .51075 L .42372 .50222 L .958 .688 .48 r
F
.42372 .50222 m .43211 .51075 L .43161 .51952 L F
.38498 .37813 m .4391 .38283 L .3917 .38452 L .494 .705 .964 r
F
.38572 .39279 m .3917 .38452 L .39133 .39809 L .958 .688 .48 r
F
.38572 .39279 m .38498 .37813 L .3917 .38452 L F
0 g
.3917 .38452 m
.39834 .39226 L
s
.25664 .50989 m .24585 .47907 L .24773 .47841 L .949 .693 .515 r
F
.41366 .47561 m .42156 .4783 L .42284 .48662 L .958 .688 .48 r
F
.41229 .46921 m .42156 .4783 L .41366 .47561 L F
.41655 .52419 m .43842 .53925 L .41529 .53212 L .755 .467 .496 r
F
.39761 .51726 m .41655 .52419 L .41529 .53212 L .798 .51 .5 r
F
.39808 .51025 m .41655 .52419 L .39761 .51726 L .797 .529 .533 r
F
.21204 .35185 m .21756 .31626 L .22165 .34938 L .964 .757 .575 r
F
.21907 .38428 m .21204 .35185 L .22165 .34938 L .962 .744 .563 r
F
.36741 .48508 m .38056 .48612 L .38149 .49237 L .867 .629 .576 r
F
.36651 .48081 m .38056 .48612 L .36741 .48508 L .868 .64 .591 r
F
.38199 .49839 m .39808 .51025 L .38206 .50407 L .832 .577 .553 r
F
.38206 .50407 m .39808 .51025 L .39761 .51726 L .834 .563 .529 r
F
.039 .916 .04 r
.31472 .54328 m
.38814 .50923 L
s
.28371 .55633 m .29656 .58035 L .28076 .55758 L .887 .537 .38 r
F
.28371 .55633 m .30093 .57841 L .29656 .58035 L F
.26996 .53318 m .28371 .55633 L .28076 .55758 L .916 .602 .435 r
F
.20938 .49459 m .1969 .46781 L .19947 .46349 L .967 .732 .53 r
F
.20839 .49722 m .1969 .46781 L .20938 .49459 L .97 .73 .519 r
F
.26996 .53318 m .28076 .55758 L .26848 .53378 L .916 .602 .435 r
F
.25937 .50902 m .26996 .53318 L .26848 .53378 L .938 .659 .485 r
F
.25664 .50989 m .24416 .48027 L .24585 .47907 L .95 .693 .514 r
F
.25664 .50989 m .24269 .48197 L .24416 .48027 L .95 .693 .513 r
F
.25664 .50989 m .24147 .48416 L .24269 .48197 L .95 .693 .511 r
F
.25664 .50989 m .24051 .48679 L .24147 .48416 L .951 .693 .51 r
F
.25664 .50989 m .23983 .48982 L .24051 .48679 L .951 .692 .508 r
F
.25664 .50989 m .23945 .49321 L .23983 .48982 L .951 .692 .507 r
F
.25664 .50989 m .23938 .49688 L .23945 .49321 L .951 .691 .505 r
F
.25664 .50989 m .23961 .50078 L .23938 .49688 L .952 .69 .504 r
F
.25664 .50989 m .24014 .50484 L .23961 .50078 L .951 .69 .503 r
F
.25664 .50989 m .24097 .50899 L .24014 .50484 L .951 .689 .502 r
F
.25664 .50989 m .24208 .51316 L .24097 .50899 L .951 .688 .501 r
F
.25664 .50989 m .24345 .51726 L .24208 .51316 L .951 .687 .5 r
F
.039 .916 .04 r
.22399 .52035 m
.2425 .51442 L
s
.25664 .50989 m .24505 .52124 L .24345 .51726 L .951 .686 .499 r
F
.25664 .50989 m .24686 .52501 L .24505 .52124 L .95 .685 .499 r
F
.25664 .50989 m .24885 .52852 L .24686 .52501 L .95 .684 .498 r
F
.25664 .50989 m .25098 .53169 L .24885 .52852 L .949 .684 .498 r
F
.25664 .50989 m .25321 .53449 L .25098 .53169 L .949 .683 .498 r
F
.25664 .50989 m .2555 .53685 L .25321 .53449 L .948 .682 .498 r
F
.25664 .50989 m .25782 .53874 L .2555 .53685 L .948 .681 .499 r
F
.25664 .50989 m .26011 .54013 L .25782 .53874 L .947 .681 .499 r
F
.25664 .50989 m .26236 .54099 L .26011 .54013 L .947 .681 .5 r
F
.25664 .50989 m .2645 .54132 L .26236 .54099 L .946 .68 .501 r
F
.25664 .50989 m .26652 .5411 L .2645 .54132 L .945 .68 .502 r
F
.40036 .43888 m .40782 .43688 L .4033 .44438 L .958 .688 .48 r
F
.40036 .43888 m .40392 .42956 L .40782 .43688 L F
.35852 .46062 m .37025 .45506 L .3605 .46428 L .89 .702 .642 r
F
.35852 .46062 m .36729 .44959 L .37025 .45506 L F
.19947 .46349 m .19518 .42861 L .20252 .46013 L .975 .765 .556 r
F
.26574 .36797 m .29379 .33396 L .27383 .36805 L .911 .929 .813 r
F
.25571 .39925 m .26574 .36797 L .27383 .36805 L .941 .888 .751 r
F
.19939 .32127 m .20597 .31895 L .21756 .31626 L .33 .811 .774 r
F
.21204 .35185 m .20597 .31895 L .21756 .31626 L .964 .757 .575 r
F
0 g
.21756 .31626 m
.22993 .31679 L
s
.70805 .37301 m .72407 .39264 L .71448 .39567 L .619 .508 .706 r
F
.70805 .37301 m .71762 .36995 L .72407 .39264 L F
.70066 .35055 m .71762 .36995 L .70805 .37301 L .627 .536 .732 r
F
.70016 .37433 m .70805 .37301 L .71448 .39567 L .977 .674 .34 r
F
.69394 .35542 m .70805 .37301 L .70016 .37433 L .975 .669 .336 r
F
.69394 .35542 m .70066 .35055 L .70805 .37301 L F
.39171 .62864 m .42469 .5645 L .38448 .63542 L .837 .965 .639 r
F
.39171 .62864 m .42924 .56038 L .42469 .5645 L F
0 g
.39171 .62864 m
.39782 .61956 L
s
.25184 .48384 m .25047 .45654 L .25335 .48329 L .966 .764 .579 r
F
.25937 .50902 m .25184 .48384 L .25335 .48329 L .955 .713 .532 r
F
.30093 .57841 m .31654 .60196 L .29656 .58035 L .848 .462 .317 r
F
.30093 .57841 m .32228 .59926 L .31654 .60196 L F
.70066 .35055 m .71023 .34746 L .71762 .36995 L .627 .536 .732 r
F
.69242 .32861 m .71023 .34746 L .70066 .35055 L .635 .564 .758 r
F
.687 .33697 m .70066 .35055 L .69394 .35542 L .974 .665 .333 r
F
.687 .33697 m .69242 .32861 L .70066 .35055 L F
0 g
.70066 .35055 m
.70805 .37301 L
s
.25937 .50902 m .25049 .4848 L .25184 .48384 L .957 .713 .527 r
F
.25937 .50902 m .24931 .48618 L .25049 .4848 L .959 .713 .522 r
F
.25937 .50902 m .24833 .48794 L .24931 .48618 L .961 .712 .516 r
F
.25937 .50902 m .24757 .49006 L .24833 .48794 L .962 .711 .51 r
F
.25937 .50902 m .24703 .4925 L .24757 .49006 L .963 .709 .504 r
F
.25937 .50902 m .24673 .49523 L .24703 .4925 L .964 .707 .497 r
F
.25937 .50902 m .24667 .49818 L .24673 .49523 L .965 .705 .491 r
F
.25937 .50902 m .24686 .50132 L .24667 .49818 L .965 .702 .485 r
F
.25937 .50902 m .2473 .50458 L .24686 .50132 L .965 .698 .48 r
F
.25937 .50902 m .24796 .50792 L .2473 .50458 L .964 .695 .474 r
F
.25937 .50902 m .24886 .51126 L .24796 .50792 L .963 .691 .47 r
F
.25937 .50902 m .24995 .51456 L .24886 .51126 L .962 .687 .466 r
F
.25937 .50902 m .25124 .51776 L .24995 .51456 L .961 .683 .463 r
F
.25937 .50902 m .2527 .52079 L .25124 .51776 L .959 .679 .461 r
F
.25937 .50902 m .25429 .52361 L .2527 .52079 L .958 .676 .46 r
F
.25937 .50902 m .256 .52617 L .25429 .52361 L .956 .673 .46 r
F
.25937 .50902 m .25779 .52842 L .256 .52617 L .954 .67 .46 r
F
.25937 .50902 m .25963 .53032 L .25779 .52842 L .952 .667 .462 r
F
.25937 .50902 m .26149 .53185 L .25963 .53032 L .949 .665 .464 r
F
.25937 .50902 m .26333 .53297 L .26149 .53185 L .947 .663 .467 r
F
.25937 .50902 m .26513 .53367 L .26333 .53297 L .945 .661 .471 r
F
.25937 .50902 m .26686 .53394 L .26513 .53367 L .943 .66 .475 r
F
.25937 .50902 m .26848 .53378 L .26686 .53394 L .94 .66 .48 r
F
.39096 .41175 m .39689 .40453 L .39542 .4169 L .958 .688 .48 r
F
.39096 .41175 m .39133 .39809 L .39689 .40453 L F
.26652 .5411 m .27335 .57256 L .2645 .54132 L .942 .667 .488 r
F
.26652 .5411 m .27735 .57204 L .27335 .57256 L F
.35744 .43634 m .36987 .42526 L .36083 .44015 L .892 .752 .7 r
F
.35744 .43634 m .36538 .42016 L .36987 .42526 L F
.36803 .48926 m .38149 .49237 L .38199 .49839 L .867 .618 .56 r
F
.36741 .48508 m .38149 .49237 L .36803 .48926 L .867 .629 .576 r
F
.22562 .5489 m .22487 .57336 L .22328 .54703 L .946 .645 .435 r
F
.22562 .5489 m .22957 .57707 L .22487 .57336 L F
.41462 .48188 m .42284 .48662 L .42357 .49464 L .958 .688 .48 r
F
.41366 .47561 m .42284 .48662 L .41462 .48188 L F
.24745 .45756 m .25105 .42861 L .25047 .45654 L .972 .814 .626 r
F
.25184 .48384 m .24745 .45756 L .25047 .45654 L .966 .764 .579 r
F
.36083 .41597 m .37635 .40304 L .36538 .42016 L .882 .782 .746 r
F
.36083 .41597 m .37071 .39777 L .37635 .40304 L F
.47152 .44466 m .47742 .45429 L .47442 .45525 L .615 .505 .705 r
F
.47152 .44466 m .47451 .4437 L .47742 .45429 L F
.46805 .4342 m .47451 .4437 L .47152 .44466 L .624 .535 .733 r
F
.4541 .44965 m .47152 .44466 L .47442 .45525 L .779 .602 .66 r
F
.45121 .44091 m .47152 .44466 L .4541 .44965 L .784 .622 .68 r
F
.45121 .44091 m .46805 .4342 L .47152 .44466 L F
.46408 .42402 m .47105 .43323 L .46805 .4342 L .632 .564 .759 r
F
.46805 .4342 m .47105 .43323 L .47451 .4437 L .624 .535 .733 r
F
.44789 .43241 m .46805 .4342 L .45121 .44091 L .791 .643 .697 r
F
.44789 .43241 m .46408 .42402 L .46805 .4342 L F
0 g
.46805 .4342 m
.47152 .44466 L
s
.3564 .45729 m .36729 .44959 L .35852 .46062 L .897 .715 .648 r
F
.3564 .45729 m .36413 .44459 L .36729 .44959 L F
.26848 .53378 m .27754 .55796 L .26686 .53394 L .921 .6 .417 r
F
.26848 .53378 m .28076 .55758 L .27754 .55796 L F
.71448 .39567 m .72947 .4152 L .71986 .4182 L .609 .478 .677 r
F
.71448 .39567 m .72407 .39264 L .72947 .4152 L F
.70556 .39339 m .71448 .39567 L .71986 .4182 L .978 .678 .346 r
F
.70016 .37433 m .71448 .39567 L .70556 .39339 L .977 .674 .34 r
F
0 g
.70805 .37301 m
.71448 .39567 L
s
.24416 .48027 m .23599 .44788 L .24585 .47907 L .954 .707 .523 r
F
.20839 .49722 m .19488 .47305 L .1969 .46781 L .97 .73 .519 r
F
.20768 .50025 m .19488 .47305 L .20839 .49722 L .972 .727 .507 r
F
.27735 .57204 m .28319 .60364 L .27335 .57256 L .938 .653 .473 r
F
.27735 .57204 m .28917 .60273 L .28319 .60364 L F
.47442 .45525 m .47973 .46484 L .47673 .46579 L .605 .474 .676 r
F
.47442 .45525 m .47742 .45429 L .47973 .46484 L F
.45653 .45849 m .47442 .45525 L .47673 .46579 L .774 .582 .639 r
F
.4541 .44965 m .47442 .45525 L .45653 .45849 L .779 .602 .66 r
F
0 g
.47152 .44466 m
.47442 .45525 L
s
.39722 .43384 m .40392 .42956 L .40036 .43888 L .958 .688 .48 r
F
.39722 .43384 m .39977 .42287 L .40392 .42956 L F
.46408 .42402 m .46708 .42305 L .47105 .43323 L .632 .564 .759 r
F
0 g
.47105 .43323 m
.47451 .4437 L
s
.46894 .44489 m .47435 .44374 L .47725 .45428 L .962 .688 .467 r
F
0 g
.47451 .4437 m
.47742 .45429 L
s
.46605 .43617 m .47435 .44374 L .46894 .44489 L .962 .688 .467 r
F
.46605 .43617 m .4709 .43332 L .47435 .44374 L F
.25049 .4848 m .24745 .45756 L .25184 .48384 L .973 .767 .565 r
F
.45968 .41429 m .46708 .42305 L .46408 .42402 L .64 .593 .785 r
F
.44419 .42429 m .46408 .42402 L .44789 .43241 L .799 .664 .714 r
F
.44419 .42429 m .45968 .41429 L .46408 .42402 L F
0 g
.46408 .42402 m
.46805 .4342 L
s
.46274 .42769 m .4709 .43332 L .46605 .43617 L .962 .688 .467 r
F
.46274 .42769 m .46695 .42319 L .4709 .43332 L F
.32228 .59926 m .34204 .62204 L .31654 .60196 L .792 .368 .241 r
F
.32228 .59926 m .34909 .61855 L .34204 .62204 L F
.19027 .39605 m .19687 .35711 L .19732 .39172 L .98 .827 .619 r
F
.19518 .42861 m .19027 .39605 L .19732 .39172 L .976 .795 .595 r
F
.69242 .32861 m .70199 .32549 L .71023 .34746 L .635 .564 .758 r
F
.68344 .30749 m .70199 .32549 L .69242 .32861 L .642 .592 .783 r
F
.67943 .31922 m .69242 .32861 L .687 .33697 L .973 .662 .331 r
F
.67943 .31922 m .68344 .30749 L .69242 .32861 L F
0 g
.69242 .32861 m
.70066 .35055 L
s
.36835 .49328 m .38199 .49839 L .38206 .50407 L .867 .607 .543 r
F
.36803 .48926 m .38199 .49839 L .36835 .49328 L .867 .618 .56 r
F
.30042 .66791 m .31223 .6979 L .29052 .66986 L .862 .472 .3 r
F
.30042 .66791 m .32397 .69531 L .31223 .6979 L F
.039 .916 .04 r
.21022 .50657 m
.23942 .49758 L
s
.71894 .36833 m .71762 .36995 L .72407 .39264 L 0 0 .314 r
F
.71271 .34937 m .71762 .36995 L .71894 .36833 L 0 0 .349 r
F
.71271 .34937 m .71023 .34746 L .71762 .36995 L F
.41529 .53212 m .43842 .53925 L .43615 .54763 L .754 .439 .451 r
F
0 g
.43842 .53925 m
.43842 .53924 L
s
.43842 .53924 m .47645 .51902 L .43615 .54762 L .241 0 .273 r
F
.43842 .53924 m .47822 .5121 L .47645 .51902 L F
.43039 .52745 m .43842 .53924 L .43615 .54762 L .958 .688 .48 r
F
.43161 .51952 m .43842 .53924 L .43039 .52745 L F
0 g
.43842 .53924 m
.43985 .52972 L
s
.24652 .43006 m .25571 .39925 L .25105 .42861 L .971 .864 .675 r
F
.24745 .45756 m .24652 .43006 L .25105 .42861 L .972 .814 .626 r
F
.22328 .54703 m .22021 .5687 L .22097 .54469 L .95 .649 .43 r
F
.22328 .54703 m .22487 .57336 L .22021 .5687 L F
.47136 .45371 m .47725 .45428 L .47954 .46477 L .962 .688 .467 r
F
.46894 .44489 m .47725 .45428 L .47136 .45371 L F
.39761 .51726 m .41529 .53212 L .39656 .5236 L .798 .51 .5 r
F
.38168 .50934 m .39761 .51726 L .39656 .5236 L .836 .549 .503 r
F
.38206 .50407 m .39761 .51726 L .38168 .50934 L .834 .563 .529 r
F
.23878 .58137 m .24297 .6088 L .23424 .57975 L .93 .603 .396 r
F
.23878 .58137 m .24978 .61113 L .24297 .6088 L F
.70577 .33086 m .71023 .34746 L .71271 .34937 L 0 0 .372 r
F
.70577 .33086 m .70199 .32549 L .71023 .34746 L F
0 g
.71023 .34746 m
.71762 .36995 L
s
.49446 .43749 m .49562 .43724 L .49878 .44871 L .964 .688 .462 r
F
.49083 .42651 m .49562 .43724 L .49446 .43749 L F
.49083 .42651 m .49186 .4259 L .49562 .43724 L F
.25626 .61183 m .26338 .64038 L .24978 .61113 L .911 .56 .363 r
F
.25626 .61183 m .27198 .64115 L .26338 .64038 L F
.2645 .54132 m .26906 .57199 L .26236 .54099 L .944 .667 .485 r
F
.2645 .54132 m .27335 .57256 L .26906 .57199 L F
.45968 .41429 m .46267 .41332 L .46708 .42305 L .64 .593 .785 r
F
0 g
.46708 .42305 m
.47105 .43323 L
s
.48669 .41583 m .49186 .4259 L .49083 .42651 L .964 .688 .462 r
F
.48669 .41583 m .48758 .41486 L .49186 .4259 L F
0 g
.49186 .4259 m
.49562 .43724 L
s
.28917 .60273 m .29406 .63455 L .28319 .60364 L .934 .638 .459 r
F
.28917 .60273 m .30198 .63318 L .29406 .63455 L F
.47673 .46579 m .4814 .47517 L .4784 .47612 L .593 .44 .644 r
F
.47673 .46579 m .47973 .46484 L .4814 .47517 L F
0 g
.47742 .45429 m
.47973 .46484 L
s
.45844 .4673 m .47673 .46579 L .4784 .47612 L .77 .562 .616 r
F
.45653 .45849 m .47673 .46579 L .45844 .4673 L .774 .582 .639 r
F
0 g
.47523 .45895 m
.47673 .46579 L
s
.45907 .41959 m .46695 .42319 L .46274 .42769 L .962 .688 .467 r
F
.45907 .41959 m .46257 .4135 L .46695 .42319 L F
.4233 .50924 m .43161 .51952 L .43039 .52745 L .958 .688 .48 r
F
.42372 .50222 m .43161 .51952 L .4233 .50924 L F
.35418 .45433 m .36413 .44459 L .3564 .45729 L .905 .729 .652 r
F
.35418 .45433 m .36083 .44015 L .36413 .44459 L F
.41516 .48791 m .42357 .49464 L .42372 .50222 L .958 .688 .48 r
F
.41462 .48188 m .42357 .49464 L .41516 .48791 L F
.28076 .55758 m .29177 .58101 L .27754 .55796 L .893 .529 .345 r
F
.28076 .55758 m .29656 .58035 L .29177 .58101 L F
.26686 .53394 m .27411 .55747 L .26513 .53367 L .927 .599 .399 r
F
.26686 .53394 m .27754 .55796 L .27411 .55747 L F
.20768 .50025 m .19342 .4791 L .19488 .47305 L .972 .727 .507 r
F
.20727 .50362 m .19342 .4791 L .20768 .50025 L .973 .723 .496 r
F
.23258 .45019 m .22706 .41629 L .23599 .44788 L .959 .72 .533 r
F
.24416 .48027 m .23258 .45019 L .23599 .44788 L .954 .707 .523 r
F
.49752 .44858 m .49878 .44871 L .5013 .46013 L .964 .688 .462 r
F
.49446 .43749 m .49878 .44871 L .49752 .44858 L F
0 g
.49562 .43724 m
.49878 .44871 L
s
.24269 .48197 m .23258 .45019 L .24416 .48027 L .956 .706 .519 r
F
.72438 .38744 m .72407 .39264 L .72947 .4152 L 0 0 .266 r
F
.71894 .36833 m .72407 .39264 L .72438 .38744 L 0 0 .314 r
F
0 g
.71762 .36995 m
.72407 .39264 L
s
.4549 .40516 m .46267 .41332 L .45968 .41429 L .646 .622 .812 r
F
.44018 .41668 m .45968 .41429 L .44419 .42429 L .808 .686 .73 r
F
.44018 .41668 m .4549 .40516 L .45968 .41429 L F
0 g
.45968 .41429 m
.46075 .41666 L
s
.41529 .53212 m .43615 .54763 L .41333 .53908 L .754 .439 .451 r
F
.39656 .5236 m .41529 .53212 L .41333 .53908 L .8 .489 .463 r
F
.48209 .40562 m .48758 .41486 L .48669 .41583 L .964 .688 .462 r
F
.48209 .40562 m .48283 .40431 L .48758 .41486 L F
0 g
.48758 .41486 m
.49186 .4259 L
s
.25049 .4848 m .24473 .45945 L .24745 .45756 L .973 .767 .565 r
F
.24931 .48618 m .24473 .45945 L .25049 .4848 L .979 .767 .549 r
F
.47328 .4625 m .47954 .46477 L .48121 .47505 L .962 .688 .467 r
F
.47136 .45371 m .47954 .46477 L .47328 .4625 L F
.35401 .43322 m .36538 .42016 L .35744 .43634 L .905 .771 .703 r
F
.35401 .43322 m .36083 .41597 L .36538 .42016 L F
.57706 .41183 m .6264 .3975 L .63139 .41529 L .762 .592 .667 r
F
.57267 .39854 m .6264 .3975 L .57706 .41183 L .768 .614 .688 r
F
.57267 .39854 m .62059 .37989 L .6264 .3975 L F
.64163 .39168 m .6264 .3975 L .63139 .41529 L .276 .288 .693 r
F
.63674 .37684 m .6264 .3975 L .64163 .39168 L .289 .328 .729 r
F
.63674 .37684 m .62059 .37989 L .6264 .3975 L F
.39395 .42936 m .39977 .42287 L .39722 .43384 L .958 .688 .48 r
F
.39395 .42936 m .39542 .4169 L .39977 .42287 L F
.22097 .54469 m .21567 .56315 L .21872 .54192 L .954 .653 .426 r
F
.22097 .54469 m .22021 .5687 L .21567 .56315 L F
.56771 .3856 m .62059 .37989 L .57267 .39854 L .775 .636 .707 r
F
.56771 .3856 m .61406 .36271 L .62059 .37989 L F
.63125 .36236 m .62059 .37989 L .63674 .37684 L .295 .362 .762 r
F
.63125 .36236 m .61406 .36271 L .62059 .37989 L F
0 g
.62059 .37989 m
.6264 .3975 L
s
.49331 .43773 m .49446 .43749 L .49752 .44858 L .964 .688 .462 r
F
.4898 .42712 m .49446 .43749 L .49331 .43773 L F
.4898 .42712 m .49083 .42651 L .49446 .43749 L F
.19947 .46349 m .19055 .43354 L .19518 .42861 L .975 .765 .556 r
F
.1969 .46781 m .19055 .43354 L .19947 .46349 L .98 .764 .539 r
F
.71986 .4182 m .73375 .43731 L .7241 .44029 L .598 .446 .646 r
F
.71986 .4182 m .72947 .4152 L .73375 .43731 L F
.71007 .41235 m .71986 .4182 L .7241 .44029 L .979 .682 .352 r
F
.70556 .39339 m .71986 .4182 L .71007 .41235 L .978 .678 .346 r
F
0 g
.71448 .39567 m
.71986 .4182 L
s
.26574 .36797 m .28417 .33364 L .29379 .33396 L .911 .929 .813 r
F
.29379 .33396 m .36543 .36808 L .37174 .36982 L .453 0 0 r
F
.28417 .33364 m .36543 .36808 L .29379 .33396 L .577 .005 0 r
F
0 g
.29379 .33396 m
.30389 .33685 L
s
.36835 .49328 m .38206 .50407 L .36838 .49708 L .867 .607 .543 r
F
.36838 .49708 m .38206 .50407 L .38168 .50934 L .869 .597 .524 r
F
.48579 .41681 m .49083 .42651 L .4898 .42712 L .964 .688 .462 r
F
.48579 .41681 m .48669 .41583 L .49083 .42651 L F
.30198 .63318 m .30598 .66533 L .29406 .63455 L .929 .624 .444 r
F
.30198 .63318 m .3158 .66339 L .30598 .66533 L F
.4549 .40516 m .4579 .40419 L .46267 .41332 L .646 .622 .812 r
F
0 g
.46267 .41332 m
.46708 .42305 L
s
.24473 .45945 m .24652 .43006 L .24745 .45756 L .983 .821 .604 r
F
.68344 .30749 m .69301 .30434 L .70199 .32549 L .642 .592 .783 r
F
.69822 .31306 m .70199 .32549 L .70577 .33086 L 0 0 .381 r
F
.69822 .31306 m .69301 .30434 L .70199 .32549 L F
0 g
.70199 .32549 m
.71023 .34746 L
s
.45509 .41199 m .46257 .4135 L .45907 .41959 L .962 .688 .467 r
F
.45509 .41199 m .45781 .40441 L .46257 .4135 L F
.36509 .39372 m .38498 .37813 L .37071 .39777 L .87 .821 .797 r
F
.36509 .39372 m .37829 .3732 L .38498 .37813 L F
0 g
.38498 .37813 m
.38498 .37813 L
s
.38498 .37813 m .43363 .37748 L .4391 .38283 L .494 .705 .964 r
F
.37829 .3732 m .43363 .37748 L .38498 .37813 L .445 .736 .989 r
F
.38013 .38872 m .38498 .37813 L .38572 .39279 L .958 .688 .48 r
F
.38013 .38872 m .37829 .3732 L .38498 .37813 L F
0 g
.38498 .37813 m
.3917 .38452 L
s
.38646 .40753 m .39133 .39809 L .39096 .41175 L .958 .688 .48 r
F
.38646 .40753 m .38572 .39279 L .39133 .39809 L F
.20727 .50362 m .19257 .48587 L .19342 .4791 L .973 .723 .496 r
F
.20717 .50729 m .19257 .48587 L .20727 .50362 L .974 .718 .484 r
F
.49996 .45963 m .5013 .46013 L .50314 .47132 L .964 .688 .462 r
F
.49752 .44858 m .5013 .46013 L .49996 .45963 L F
0 g
.49878 .44871 m
.5013 .46013 L
s
.26513 .53367 m .27051 .55611 L .26333 .53297 L .932 .599 .382 r
F
.26513 .53367 m .27411 .55747 L .27051 .55611 L F
.49626 .44846 m .49752 .44858 L .49996 .45963 L .964 .688 .462 r
F
.49331 .43773 m .49752 .44858 L .49626 .44846 L F
.26236 .54099 m .26458 .57034 L .26011 .54013 L .945 .668 .481 r
F
.26236 .54099 m .26906 .57199 L .26458 .57034 L F
.5808 .42525 m .63139 .41529 L .63549 .43299 L .756 .57 .645 r
F
.57706 .41183 m .63139 .41529 L .5808 .42525 L .762 .592 .667 r
F
.64585 .40666 m .63139 .41529 L .63549 .43299 L .253 .242 .652 r
F
.64163 .39168 m .63139 .41529 L .64585 .40666 L .276 .288 .693 r
F
0 g
.6264 .3975 m
.63139 .41529 L
s
.24967 .40106 m .26574 .36797 L .25571 .39925 L .958 .914 .728 r
F
.24652 .43006 m .24967 .40106 L .25571 .39925 L .971 .864 .675 r
F
.4784 .47612 m .4824 .48513 L .47939 .48607 L .579 .403 .607 r
F
.4784 .47612 m .4814 .47517 L .4824 .48513 L F
0 g
.47973 .46484 m
.4814 .47517 L
s
.45981 .47593 m .4784 .47612 L .47939 .48607 L .767 .541 .591 r
F
.45844 .4673 m .4784 .47612 L .45981 .47593 L .77 .562 .616 r
F
0 g
.4772 .46871 m
.4784 .47612 L
s
.19055 .43354 m .19027 .39605 L .19518 .42861 L .984 .797 .573 r
F
.35191 .45179 m .36083 .44015 L .35418 .45433 L .914 .742 .655 r
F
.35191 .45179 m .35744 .43634 L .36083 .44015 L F
.48135 .40694 m .48669 .41583 L .48579 .41681 L .964 .688 .462 r
F
.48135 .40694 m .48209 .40562 L .48669 .41583 L F
.44002 .45357 m .4541 .44965 L .45653 .45849 L .812 .62 .643 r
F
.4377 .44655 m .4541 .44965 L .44002 .45357 L .817 .638 .661 r
F
.4377 .44655 m .45121 .44091 L .4541 .44965 L F
.22189 .41964 m .21907 .38428 L .22706 .41629 L .963 .733 .543 r
F
.23258 .45019 m .22189 .41964 L .22706 .41629 L .959 .72 .533 r
F
.34909 .61855 m .37622 .63973 L .34204 .62204 L .707 .239 .138 r
F
.34909 .61855 m .38448 .63542 L .37622 .63973 L F
.43502 .43974 m .45121 .44091 L .4377 .44655 L .823 .656 .676 r
F
.43502 .43974 m .44789 .43241 L .45121 .44091 L F
.24931 .48618 m .24236 .46216 L .24473 .45945 L .979 .767 .549 r
F
.24833 .48794 m .24236 .46216 L .24931 .48618 L .984 .766 .53 r
F
.21872 .54192 m .21134 .55681 L .21658 .53876 L .958 .658 .424 r
F
.21872 .54192 m .21567 .56315 L .21134 .55681 L F
.47711 .39604 m .48283 .40431 L .48209 .40562 L .964 .688 .462 r
F
.47711 .39604 m .47768 .3944 L .48283 .40431 L F
0 g
.48283 .40431 m
.48758 .41486 L
s
.35631 .41278 m .37071 .39777 L .36083 .41597 L .898 .807 .75 r
F
.35631 .41278 m .36509 .39372 L .37071 .39777 L F
.24269 .48197 m .22959 .45353 L .23258 .45019 L .956 .706 .519 r
F
.24147 .48416 m .22959 .45353 L .24269 .48197 L .957 .706 .515 r
F
.56224 .37319 m .61406 .36271 L .56771 .3856 L .784 .659 .726 r
F
.56224 .37319 m .60689 .34621 L .61406 .36271 L F
.62523 .34847 m .61406 .36271 L .63125 .36236 L .292 .391 .793 r
F
.62523 .34847 m .60689 .34621 L .61406 .36271 L F
0 g
.61406 .36271 m
.62059 .37989 L
s
.29656 .58035 m .31022 .60293 L .29177 .58101 L .851 .442 .259 r
F
.29656 .58035 m .31654 .60196 L .31022 .60293 L F
.67385 .28752 m .69301 .30434 L .68344 .30749 L .649 .621 .808 r
F
.67136 .30246 m .68344 .30749 L .67943 .31922 L .972 .659 .331 r
F
.67136 .30246 m .67385 .28752 L .68344 .30749 L F
0 g
.68344 .30749 m
.69242 .32861 L
s
.35524 .47905 m .36535 .47653 L .36651 .48081 L .904 .668 .571 r
F
.35453 .47692 m .36535 .47653 L .35524 .47905 L .907 .676 .579 r
F
.35453 .47692 m .36395 .4723 L .36535 .47653 L F
.41516 .48791 m .42372 .50222 L .41526 .49362 L .958 .688 .48 r
F
.41526 .49362 m .42372 .50222 L .4233 .50924 L F
.039 .916 .04 r
.39151 .50772 m
.41816 .49925 L
s
.49215 .43798 m .49331 .43773 L .49626 .44846 L .964 .688 .462 r
F
.48876 .42774 m .49331 .43773 L .49215 .43798 L F
.48876 .42774 m .4898 .42712 L .49331 .43773 L F
.35371 .47486 m .36395 .4723 L .35453 .47692 L .909 .685 .586 r
F
.35371 .47486 m .36232 .46819 L .36395 .4723 L F
.44196 .46067 m .45653 .45849 L .45844 .4673 L .808 .603 .625 r
F
.44002 .45357 m .45653 .45849 L .44196 .46067 L .812 .62 .643 r
F
.47466 .4711 m .48121 .47505 L .4822 .48496 L .962 .688 .467 r
F
.47328 .4625 m .48121 .47505 L .47466 .4711 L F
.48489 .41778 m .4898 .42712 L .48876 .42774 L .964 .688 .462 r
F
.48489 .41778 m .48579 .41681 L .4898 .42712 L F
.44982 .39679 m .4579 .40419 L .4549 .40516 L .652 .654 .839 r
F
.43592 .4097 m .4549 .40516 L .44018 .41668 L .819 .71 .745 r
F
.43592 .4097 m .44982 .39679 L .4549 .40516 L F
0 g
.4549 .40516 m
.45647 .40816 L
s
.27335 .57256 m .27679 .6029 L .26906 .57199 L .941 .653 .467 r
F
.27335 .57256 m .28319 .60364 L .27679 .6029 L F
.20717 .50729 m .19235 .49324 L .19257 .48587 L .974 .718 .484 r
F
.20738 .51117 m .19235 .49324 L .20717 .50729 L .974 .712 .472 r
F
.35582 .4812 m .36651 .48081 L .36741 .48508 L .903 .66 .562 r
F
.35524 .47905 m .36651 .48081 L .35582 .4812 L .904 .668 .571 r
F
.3158 .66339 m .31897 .69596 L .30598 .66533 L .923 .609 .429 r
F
.3158 .66339 m .33066 .69339 L .31897 .69596 L F
.39656 .5236 m .41333 .53908 L .39495 .52916 L .8 .489 .463 r
F
.38086 .51409 m .39656 .5236 L .39495 .52916 L .839 .534 .472 r
F
.38168 .50934 m .39656 .5236 L .38086 .51409 L .836 .549 .503 r
F
.3528 .4729 m .36232 .46819 L .35371 .47486 L .913 .693 .591 r
F
.3528 .4729 m .3605 .46428 L .36232 .46819 L F
.43205 .43323 m .44789 .43241 L .43502 .43974 L .83 .675 .691 r
F
.43205 .43323 m .44419 .42429 L .44789 .43241 L F
.49996 .45963 m .50314 .47132 L .50174 .47046 L .964 .688 .462 r
F
.49862 .45914 m .49996 .45963 L .50174 .47046 L F
.49626 .44846 m .49996 .45963 L .49862 .45914 L F
.495 .44833 m .49626 .44846 L .49862 .45914 L F
.49215 .43798 m .49626 .44846 L .495 .44833 L F
.40359 .4643 m .41054 .46278 L .41229 .46921 L .958 .688 .48 r
F
.40217 .46004 m .41054 .46278 L .40359 .4643 L F
.40217 .46004 m .40843 .45643 L .41054 .46278 L F
.72893 .40644 m .72947 .4152 L .73375 .43731 L 0 0 .206 r
F
.72438 .38744 m .72947 .4152 L .72893 .40644 L 0 0 .266 r
F
0 g
.72407 .39264 m
.72947 .4152 L
s
.26333 .53297 m .26681 .5539 L .26149 .53185 L .938 .601 .366 r
F
.26333 .53297 m .27051 .55611 L .26681 .5539 L F
.32397 .69531 m .31897 .69596 L .31223 .6979 L .252 .76 .744 r
F
.32397 .69531 m .33066 .69339 L .31897 .69596 L F
0 g
.33066 .69339 m
.3412 .68764 L
s
.40055 .45591 m .40843 .45643 L .40217 .46004 L .958 .688 .48 r
F
.40055 .45591 m .40601 .45027 L .40843 .45643 L F
.35627 .48335 m .36741 .48508 L .36803 .48926 L .902 .653 .552 r
F
.35582 .4812 m .36741 .48508 L .35627 .48335 L .903 .66 .562 r
F
.18801 .36231 m .19939 .32127 L .19687 .35711 L .981 .859 .644 r
F
.19027 .39605 m .18801 .36231 L .19687 .35711 L .98 .827 .619 r
F
.27754 .55796 m .28664 .58035 L .27411 .55747 L .899 .522 .308 r
F
.27754 .55796 m .29177 .58101 L .28664 .58035 L F
.21658 .53876 m .20731 .54979 L .21459 .53528 L .961 .664 .424 r
F
.21658 .53876 m .21134 .55681 L .20731 .54979 L F
.36812 .5006 m .38168 .50934 L .38086 .51409 L .871 .587 .503 r
F
.039 .916 .04 r
.29321 .53304 m
.36932 .50187 L
s
.36838 .49708 m .38168 .50934 L .36812 .5006 L .869 .597 .524 r
F
.44982 .39679 m .45282 .3958 L .4579 .40419 L .652 .654 .839 r
F
0 g
.4579 .40419 m
.46267 .41332 L
s
.23424 .57975 m .23596 .60486 L .22957 .57707 L .936 .604 .381 r
F
.23424 .57975 m .24297 .6088 L .23596 .60486 L F
.40476 .4686 m .41229 .46921 L .41366 .47561 L .958 .688 .48 r
F
.40359 .4643 m .41229 .46921 L .40476 .4686 L F
.3518 .47106 m .3605 .46428 L .3528 .4729 L .917 .702 .596 r
F
.3518 .47106 m .35852 .46062 L .3605 .46428 L F
.4806 .40826 m .48579 .41681 L .48489 .41778 L .964 .688 .462 r
F
.4806 .40826 m .48135 .40694 L .48579 .41681 L F
.45086 .40503 m .45781 .40441 L .45509 .41199 L .962 .688 .467 r
F
.45086 .40503 m .45277 .39607 L .45781 .40441 L F
.44349 .46774 m .45844 .4673 L .45981 .47593 L .805 .585 .604 r
F
.44196 .46067 m .45844 .4673 L .44349 .46774 L .808 .603 .625 r
F
.26011 .54013 m .25996 .56762 L .25782 .53874 L .947 .669 .479 r
F
.26011 .54013 m .26458 .57034 L .25996 .56762 L F
.39059 .42551 m .39542 .4169 L .39395 .42936 L .958 .688 .48 r
F
.39059 .42551 m .39096 .41175 L .39542 .4169 L F
.50174 .47046 m .50314 .47132 L .50427 .48211 L .964 .688 .462 r
F
0 g
.5013 .46013 m
.50314 .47132 L
s
.47653 .39768 m .48209 .40562 L .48135 .40694 L .964 .688 .462 r
F
.47653 .39768 m .47711 .39604 L .48209 .40562 L F
.20738 .51117 m .19275 .50108 L .19235 .49324 L .974 .712 .472 r
F
.039 .916 .04 r
.12929 .51564 m
.19238 .49392 L
s
.2079 .51522 m .19275 .50108 L .20738 .51117 L .974 .706 .461 r
F
.39873 .45197 m .40601 .45027 L .40055 .45591 L .958 .688 .48 r
F
.39873 .45197 m .4033 .44438 L .40601 .45027 L F
.24833 .48794 m .24037 .46565 L .24236 .46216 L .984 .766 .53 r
F
.24757 .49006 m .24037 .46565 L .24833 .48794 L .988 .762 .509 r
F
.58384 .43861 m .63549 .43299 L .63864 .45033 L .752 .548 .62 r
F
.5808 .42525 m .63549 .43299 L .58384 .43861 L .756 .57 .645 r
F
.64932 .42156 m .63549 .43299 L .63864 .45033 L .219 .185 .605 r
F
.64585 .40666 m .63549 .43299 L .64932 .42156 L .253 .242 .652 r
F
0 g
.63139 .41529 m
.63549 .43299 L
s
.35658 .48545 m .36803 .48926 L .36835 .49328 L .902 .645 .54 r
F
.35627 .48335 m .36803 .48926 L .35658 .48545 L .902 .653 .552 r
F
.49099 .43822 m .49215 .43798 L .495 .44833 L .964 .688 .462 r
F
.48772 .42835 m .49215 .43798 L .49099 .43822 L F
.48772 .42835 m .48876 .42774 L .49215 .43798 L F
.43039 .52745 m .43615 .54762 L .42847 .53442 L .958 .688 .48 r
F
.4223 .51559 m .43039 .52745 L .42847 .53442 L F
.4233 .50924 m .43039 .52745 L .4223 .51559 L F
.48399 .41876 m .48876 .42774 L .48772 .42835 L .964 .688 .462 r
F
.48399 .41876 m .48489 .41778 L .48876 .42774 L F
.42882 .42713 m .44419 .42429 L .43205 .43323 L .839 .695 .704 r
F
.42882 .42713 m .44018 .41668 L .44419 .42429 L F
.21459 .53528 m .20363 .54222 L .21277 .53153 L .964 .671 .426 r
F
.21459 .53528 m .20731 .54979 L .20363 .54222 L F
.40567 .47289 m .41366 .47561 L .41462 .48188 L .958 .688 .48 r
F
.40476 .4686 m .41366 .47561 L .40567 .47289 L F
.22959 .45353 m .22189 .41964 L .23258 .45019 L .961 .72 .526 r
F
.27198 .64115 m .27983 .66908 L .26338 .64038 L .892 .512 .308 r
F
.27198 .64115 m .29052 .66986 L .27983 .66908 L F
.3506 .43085 m .36083 .41597 L .35401 .43322 L .919 .791 .703 r
F
.3506 .43085 m .35631 .41278 L .36083 .41597 L F
.34961 .44973 m .35744 .43634 L .35191 .45179 L .924 .756 .655 r
F
.34961 .44973 m .35401 .43322 L .35744 .43634 L F
.24147 .48416 m .22709 .45786 L .22959 .45353 L .957 .706 .515 r
F
.24051 .48679 m .22709 .45786 L .24147 .48416 L .958 .705 .511 r
F
.47939 .48607 m .48272 .49455 L .4797 .49549 L .561 .359 .564 r
F
.47939 .48607 m .4824 .48513 L .48272 .49455 L F
0 g
.4814 .47517 m
.4824 .48513 L
s
.46062 .48424 m .47939 .48607 L .4797 .49549 L .765 .519 .562 r
F
.45981 .47593 m .47939 .48607 L .46062 .48424 L .767 .541 .591 r
F
0 g
.47862 .47838 m
.47939 .48607 L
s
.49862 .45914 m .50174 .47046 L .50034 .4696 L .964 .688 .462 r
F
.49727 .45864 m .49862 .45914 L .50034 .4696 L F
.495 .44833 m .49862 .45914 L .49727 .45864 L F
.35073 .46939 m .35852 .46062 L .3518 .47106 L .922 .71 .599 r
F
.35073 .46939 m .3564 .45729 L .35852 .46062 L F
.24242 .4328 m .24967 .40106 L .24652 .43006 L .984 .876 .645 r
F
.24473 .45945 m .24242 .4328 L .24652 .43006 L .983 .821 .604 r
F
.21212 .38859 m .21204 .35185 L .21907 .38428 L .967 .746 .553 r
F
.22189 .41964 m .21212 .38859 L .21907 .38428 L .963 .733 .543 r
F
.2079 .51522 m .19378 .50924 L .19275 .50108 L .974 .706 .461 r
F
.20871 .51935 m .19378 .50924 L .2079 .51522 L .973 .699 .451 r
F
.49374 .4482 m .495 .44833 L .49727 .45864 L .964 .688 .462 r
F
.49099 .43822 m .495 .44833 L .49374 .4482 L F
.24236 .46216 m .24242 .4328 L .24473 .45945 L .992 .824 .576 r
F
.67385 .28752 m .68343 .28433 L .69301 .30434 L .649 .621 .808 r
F
.69017 .29623 m .69301 .30434 L .69822 .31306 L 0 0 .376 r
F
.69017 .29623 m .68343 .28433 L .69301 .30434 L F
0 g
.69301 .30434 m
.70199 .32549 L
s
.47183 .38723 m .47768 .3944 L .47711 .39604 L .964 .688 .462 r
F
.47183 .38723 m .47223 .3853 L .47768 .3944 L F
0 g
.47768 .3944 m
.48283 .40431 L
s
.39676 .44828 m .4033 .44438 L .39873 .45197 L .958 .688 .48 r
F
.39676 .44828 m .40036 .43888 L .4033 .44438 L F
.26149 .53185 m .26308 .55086 L .25963 .53032 L .943 .603 .351 r
F
.26149 .53185 m .26681 .5539 L .26308 .55086 L F
.21277 .53153 m .20039 .53423 L .21117 .52758 L .967 .678 .43 r
F
.21277 .53153 m .20363 .54222 L .20039 .53423 L F
.41333 .53908 m .43615 .54763 L .43308 .55472 L .753 .406 .397 r
F
0 g
.43615 .54763 m
.43615 .54762 L
s
.1969 .46781 m .18665 .43996 L .19055 .43354 L .98 .764 .539 r
F
.19488 .47305 m .18665 .43996 L .1969 .46781 L .984 .761 .519 r
F
.43615 .54762 m .47402 .52484 L .43308 .55471 L .11 0 .099 r
F
.43615 .54762 m .47645 .51902 L .47402 .52484 L F
.42847 .53442 m .43615 .54762 L .43308 .55471 L .958 .688 .48 r
F
0 g
.43615 .54762 m
.43842 .53924 L
s
.20871 .51935 m .19541 .51759 L .19378 .50924 L .973 .699 .451 r
F
.20981 .5235 m .19541 .51759 L .20871 .51935 L .971 .692 .443 r
F
.47986 .40958 m .48489 .41778 L .48399 .41876 L .964 .688 .462 r
F
.47986 .40958 m .4806 .40826 L .48489 .41778 L F
.50174 .47046 m .50427 .48211 L .50283 .48089 L F
.50034 .4696 m .50174 .47046 L .50283 .48089 L F
.55636 .36153 m .60689 .34621 L .56224 .37319 L .793 .683 .743 r
F
.55636 .36153 m .59918 .33066 L .60689 .34621 L F
.61879 .33539 m .60689 .34621 L .62523 .34847 L .279 .416 .822 r
F
.61879 .33539 m .59918 .33066 L .60689 .34621 L F
0 g
.60689 .34621 m
.61406 .36271 L
s
.35674 .48746 m .36835 .49328 L .36838 .49708 L .902 .638 .528 r
F
.35658 .48545 m .36835 .49328 L .35674 .48746 L .902 .645 .54 r
F
.47596 .39932 m .48135 .40694 L .4806 .40826 L .964 .688 .462 r
F
.47596 .39932 m .47653 .39768 L .48135 .40694 L F
.21117 .52758 m .19763 .52597 L .20981 .5235 L .969 .685 .436 r
F
.21117 .52758 m .20039 .53423 L .19763 .52597 L F
.20981 .5235 m .19763 .52597 L .19541 .51759 L .971 .692 .443 r
F
.7241 .44029 m .73683 .45866 L .72714 .46161 L .584 .41 .611 r
F
.7241 .44029 m .73375 .43731 L .73683 .45866 L F
.71362 .43091 m .7241 .44029 L .72714 .46161 L .98 .687 .359 r
F
.71007 .41235 m .7241 .44029 L .71362 .43091 L .979 .682 .352 r
F
0 g
.71986 .4182 m
.7241 .44029 L
s
.47549 .47938 m .4822 .48496 L .48251 .49433 L .962 .688 .467 r
F
.47466 .4711 m .4822 .48496 L .47549 .47938 L F
.41333 .53908 m .43308 .55472 L .41069 .54496 L .753 .406 .397 r
F
.39495 .52916 m .41333 .53908 L .41069 .54496 L .802 .466 .419 r
F
.44458 .47466 m .45981 .47593 L .46062 .48424 L .803 .568 .582 r
F
.44349 .46774 m .45981 .47593 L .44458 .47466 L .805 .585 .604 r
F
.24757 .49006 m .23882 .46987 L .24037 .46565 L .988 .762 .509 r
F
.24703 .4925 m .23882 .46987 L .24757 .49006 L .99 .756 .486 r
F
.40631 .47709 m .41462 .48188 L .41516 .48791 L .958 .688 .48 r
F
.40567 .47289 m .41462 .48188 L .40631 .47709 L F
.25821 .37007 m .28417 .33364 L .26574 .36797 L .921 .964 .786 r
F
.24967 .40106 m .25821 .37007 L .26574 .36797 L .958 .914 .728 r
F
.25782 .53874 m .2553 .56387 L .2555 .53685 L .949 .671 .477 r
F
.25782 .53874 m .25996 .56762 L .2553 .56387 L F
.44453 .3893 m .45282 .3958 L .44982 .39679 L .657 .688 .868 r
F
.43148 .40348 m .44982 .39679 L .43592 .4097 L .831 .735 .759 r
F
.43148 .40348 m .44453 .3893 L .44982 .39679 L F
0 g
.44982 .39679 m
.45189 .4002 L
s
.48983 .43847 m .49099 .43822 L .49374 .4482 L .964 .688 .462 r
F
.48668 .42897 m .49099 .43822 L .48983 .43847 L F
.48668 .42897 m .48772 .42835 L .49099 .43822 L F
.41493 .49889 m .4233 .50924 L .4223 .51559 L .958 .688 .48 r
F
.41526 .49362 m .4233 .50924 L .41493 .49889 L F
.34962 .46791 m .3564 .45729 L .35073 .46939 L .928 .719 .6 r
F
.34962 .46791 m .35418 .45433 L .3564 .45729 L F
.48309 .41973 m .48772 .42835 L .48668 .42897 L .964 .688 .462 r
F
.48309 .41973 m .48399 .41876 L .48772 .42835 L F
.24978 .61113 m .25432 .6374 L .24297 .6088 L .917 .558 .336 r
F
.24978 .61113 m .26338 .64038 L .25432 .6374 L F
.46347 .44606 m .46894 .44489 L .47136 .45371 L .962 .688 .467 r
F
.46115 .43905 m .46894 .44489 L .46347 .44606 L F
.46115 .43905 m .46605 .43617 L .46894 .44489 L F
.49727 .45864 m .50034 .4696 L .49893 .46873 L .964 .688 .462 r
F
.49593 .45814 m .49727 .45864 L .49893 .46873 L F
.49374 .4482 m .49727 .45864 L .49593 .45814 L F
.4585 .43224 m .46605 .43617 L .46115 .43905 L .962 .688 .467 r
F
.4585 .43224 m .46274 .42769 L .46605 .43617 L F
.38198 .4043 m .38572 .39279 L .38646 .40753 L .958 .688 .48 r
F
.38198 .4043 m .38013 .38872 L .38572 .39279 L F
.31654 .60196 m .33425 .62337 L .31022 .60293 L .787 .326 .148 r
F
.31654 .60196 m .34204 .62204 L .33425 .62337 L F
.38086 .51409 m .39495 .52916 L .37962 .51824 L .839 .534 .472 r
F
.36756 .50376 m .38086 .51409 L .37962 .51824 L .875 .577 .48 r
F
.36812 .5006 m .38086 .51409 L .36756 .50376 L .871 .587 .503 r
F
.47143 .38917 m .47711 .39604 L .47653 .39768 L .964 .688 .462 r
F
.47143 .38917 m .47183 .38723 L .47711 .39604 L F
.39465 .44492 m .40036 .43888 L .39676 .44828 L .958 .688 .48 r
F
.39465 .44492 m .39722 .43384 L .40036 .43888 L F
.42539 .42155 m .44018 .41668 L .42882 .42713 L .849 .716 .716 r
F
.42539 .42155 m .43592 .4097 L .44018 .41668 L F
.28319 .60364 m .28555 .63374 L .27679 .6029 L .937 .639 .45 r
F
.28319 .60364 m .29406 .63455 L .28555 .63374 L F
.49247 .44807 m .49374 .4482 L .49593 .45814 L .964 .688 .462 r
F
.48983 .43847 m .49374 .4482 L .49247 .44807 L F
.25963 .53032 m .25938 .54706 L .25779 .52842 L .948 .608 .338 r
F
.25963 .53032 m .26308 .55086 L .25938 .54706 L F
.24051 .48679 m .22513 .46309 L .22709 .45786 L .958 .705 .511 r
F
.23983 .48982 m .22513 .46309 L .24051 .48679 L .959 .704 .506 r
F
.51237 .43169 m .53132 .43755 L .51538 .44261 L .615 .505 .705 r
F
.51237 .43169 m .52829 .42661 L .53132 .43755 L F
.5088 .4209 m .52829 .42661 L .51237 .43169 L .624 .535 .733 r
F
.50693 .43284 m .51237 .43169 L .51538 .44261 L .965 .687 .457 r
F
.50394 .4238 m .51237 .43169 L .50693 .43284 L F
.50394 .4238 m .5088 .4209 L .51237 .43169 L F
.44453 .3893 m .44754 .38831 L .45282 .3958 L .657 .688 .868 r
F
0 g
.45282 .3958 m
.4579 .40419 L
s
.46542 .45315 m .47136 .45371 L .47328 .4625 L .962 .688 .467 r
F
.46347 .44606 m .47136 .45371 L .46542 .45315 L F
.5088 .4209 m .52471 .41578 L .52829 .42661 L .624 .535 .733 r
F
.50473 .41039 m .52471 .41578 L .5088 .4209 L .632 .564 .759 r
F
.50053 .415 m .5088 .4209 L .50394 .4238 L .965 .687 .457 r
F
.50053 .415 m .50473 .41039 L .5088 .4209 L F
0 g
.5088 .4209 m
.51237 .43169 L
s
.35674 .48746 m .36838 .49708 L .35675 .48937 L .902 .638 .528 r
F
.35675 .48937 m .36838 .49708 L .36812 .5006 L .904 .632 .515 r
F
.50034 .4696 m .50283 .48089 L .50138 .47968 L .964 .688 .462 r
F
.49893 .46873 m .50034 .4696 L .50138 .47968 L F
.44646 .39881 m .45277 .39607 L .45086 .40503 L .962 .688 .467 r
F
.44646 .39881 m .4475 .38862 L .45277 .39607 L F
.47911 .4109 m .48399 .41876 L .48309 .41973 L .964 .688 .462 r
F
.47911 .4109 m .47986 .40958 L .48399 .41876 L F
.50283 .48089 m .50427 .48211 L .50465 .49231 L F
0 g
.50314 .47132 m
.50427 .48211 L
s
.47538 .40097 m .4806 .40826 L .47986 .40958 L .964 .688 .462 r
F
.47538 .40097 m .47596 .39932 L .4806 .40826 L F
.45554 .42573 m .46274 .42769 L .4585 .43224 L .962 .688 .467 r
F
.45554 .42573 m .45907 .41959 L .46274 .42769 L F
.24703 .4925 m .23772 .47475 L .23882 .46987 L .99 .756 .486 r
F
.24673 .49523 m .23772 .47475 L .24703 .4925 L .991 .748 .462 r
F
.39495 .52916 m .41069 .54496 L .39279 .53383 L .802 .466 .419 r
F
.37962 .51824 m .39495 .52916 L .39279 .53383 L .843 .518 .438 r
F
.27411 .55747 m .28126 .57837 L .27051 .55611 L .904 .515 .269 r
F
.27411 .55747 m .28664 .58035 L .28126 .57837 L F
.51538 .44261 m .53375 .44844 L .5178 .45348 L .605 .474 .676 r
F
.51538 .44261 m .53132 .43755 L .53375 .44844 L F
.50946 .44198 m .51538 .44261 L .5178 .45348 L .965 .687 .457 r
F
.50693 .43284 m .51538 .44261 L .50946 .44198 L F
0 g
.51237 .43169 m
.51538 .44261 L
s
.039 .916 .04 r
.24286 .49652 m
.24673 .49531 L
s
.26906 .57199 m .27005 .60053 L .26458 .57034 L .943 .654 .462 r
F
.26906 .57199 m .27679 .6029 L .27005 .60053 L F
.3872 .42236 m .39096 .41175 L .39059 .42551 L .958 .688 .48 r
F
.3872 .42236 m .38646 .40753 L .39096 .41175 L F
.34848 .46665 m .35418 .45433 L .34962 .46791 L .934 .727 .601 r
F
.34848 .46665 m .35191 .45179 L .35418 .45433 L F
.20327 .35702 m .20597 .31895 L .21204 .35185 L .97 .759 .563 r
F
.21212 .38859 m .20327 .35702 L .21204 .35185 L .967 .746 .553 r
F
.34733 .44817 m .35401 .43322 L .34961 .44973 L .935 .77 .653 r
F
.34733 .44817 m .3506 .43085 L .35401 .43322 L F
.4283 .45673 m .44002 .45357 L .44196 .46067 L .844 .638 .623 r
F
.42655 .45145 m .44002 .45357 L .4283 .45673 L .848 .653 .638 r
F
.42655 .45145 m .4377 .44655 L .44002 .45357 L F
.40667 .48113 m .41516 .48791 L .41526 .49362 L .958 .688 .48 r
F
.40631 .47709 m .41516 .48791 L .40667 .48113 L F
.48866 .43872 m .48983 .43847 L .49247 .44807 L .964 .688 .462 r
F
.48564 .42959 m .48983 .43847 L .48866 .43872 L F
.48564 .42959 m .48668 .42897 L .48983 .43847 L F
.42454 .44632 m .4377 .44655 L .42655 .45145 L .853 .668 .651 r
F
.42454 .44632 m .43502 .43974 L .4377 .44655 L F
.35958 .39098 m .37829 .3732 L .36509 .39372 L .889 .856 .802 r
F
.35188 .41064 m .36509 .39372 L .35631 .41278 L .916 .835 .751 r
F
.35188 .41064 m .35958 .39098 L .36509 .39372 L F
.22957 .57707 m .22887 .59935 L .22487 .57336 L .942 .608 .367 r
F
.22957 .57707 m .23596 .60486 L .22887 .59935 L F
.48219 .42071 m .48668 .42897 L .48564 .42959 L .964 .688 .462 r
F
.48219 .42071 m .48309 .41973 L .48668 .42897 L F
.58612 .45168 m .63864 .45033 L .64078 .46705 L .748 .525 .592 r
F
.58384 .43861 m .63864 .45033 L .58612 .45168 L .752 .548 .62 r
F
.65199 .43614 m .63864 .45033 L .64078 .46705 L .173 .117 .548 r
F
.64932 .42156 m .63864 .45033 L .65199 .43614 L .219 .185 .605 r
F
0 g
.63549 .43299 m
.63864 .45033 L
s
.35958 .39098 m .37174 .36982 L .37829 .3732 L .889 .856 .802 r
F
0 g
.37829 .3732 m
.37829 .3732 L
s
.37829 .3732 m .4282 .37336 L .43363 .37748 L .445 .736 .989 r
F
.37174 .36983 m .4282 .37336 L .37829 .3732 L .356 .747 .986 r
F
.37467 .38595 m .37829 .3732 L .38013 .38872 L .958 .688 .48 r
F
.37467 .38595 m .37174 .36983 L .37829 .3732 L F
0 g
.37829 .3732 m
.38498 .37813 L
s
.50473 .41039 m .52064 .40524 L .52471 .41578 L .632 .564 .759 r
F
.50022 .40033 m .52064 .40524 L .50473 .41039 L .64 .593 .785 r
F
.49676 .40659 m .50473 .41039 L .50053 .415 L .965 .687 .457 r
F
.49676 .40659 m .50022 .40033 L .50473 .41039 L F
0 g
.50473 .41039 m
.5088 .4209 L
s
.2555 .53685 m .25068 .55917 L .25321 .53449 L .95 .672 .475 r
F
.2555 .53685 m .2553 .56387 L .25068 .55917 L F
.66377 .26899 m .68343 .28433 L .67385 .28752 L .655 .651 .835 r
F
.66288 .28694 m .67385 .28752 L .67136 .30246 L .971 .656 .332 r
F
.66288 .28694 m .66377 .26899 L .67385 .28752 L F
0 g
.67385 .28752 m
.68344 .30749 L
s
.49593 .45814 m .49893 .46873 L .49752 .46787 L .964 .688 .462 r
F
.49458 .45763 m .49593 .45814 L .49752 .46787 L F
.49247 .44807 m .49593 .45814 L .49458 .45763 L F
.38448 .63542 m .41949 .56699 L .37622 .63973 L .895 .988 .752 r
F
.38448 .63542 m .42469 .5645 L .41949 .56699 L F
0 g
.38448 .63542 m
.39171 .62864 L
s
.46696 .4602 m .47328 .4625 L .47466 .4711 L .962 .688 .467 r
F
.46542 .45315 m .47328 .4625 L .46696 .4602 L F
.47103 .39112 m .47653 .39768 L .47596 .39932 L .964 .688 .462 r
F
.47103 .39112 m .47143 .38917 L .47653 .39768 L F
.25779 .52842 m .25578 .54255 L .256 .52617 L .953 .614 .328 r
F
.25779 .52842 m .25938 .54706 L .25578 .54255 L F
.42976 .46208 m .44196 .46067 L .44349 .46774 L .841 .623 .607 r
F
.4283 .45673 m .44196 .46067 L .42976 .46208 L .844 .638 .623 r
F
.73253 .42504 m .73375 .43731 L .73683 .45866 L 0 0 .133 r
F
.72893 .40644 m .73375 .43731 L .73253 .42504 L 0 0 .206 r
F
0 g
.72947 .4152 m
.73375 .43731 L
s
.46062 .48424 m .4797 .49549 L .46084 .4921 L .765 .519 .562 r
F
.44521 .48133 m .46062 .48424 L .46084 .4921 L .803 .55 .556 r
F
.44458 .47466 m .46062 .48424 L .44521 .48133 L .803 .568 .582 r
F
.18405 .40248 m .18801 .36231 L .19027 .39605 L .99 .831 .59 r
F
.19055 .43354 m .18405 .40248 L .19027 .39605 L .984 .797 .573 r
F
.29177 .58101 m .30344 .60214 L .28664 .58035 L .853 .419 .192 r
F
.29177 .58101 m .31022 .60293 L .30344 .60214 L F
.4912 .44794 m .49247 .44807 L .49458 .45763 L .964 .688 .462 r
F
.48866 .43872 m .49247 .44807 L .4912 .44794 L F
.4797 .49549 m .48233 .50328 L .47931 .50421 L .539 .307 .512 r
F
.4797 .49549 m .48272 .49455 L .48233 .50328 L F
0 g
.4824 .48513 m
.48272 .49455 L
s
.46084 .4921 m .4797 .49549 L .47931 .50421 L .763 .496 .529 r
F
0 g
.47945 .48781 m
.4797 .49549 L
s
.42229 .44142 m .43502 .43974 L .42454 .44632 L .86 .684 .663 r
F
.42229 .44142 m .43205 .43323 L .43502 .43974 L F
.39246 .44193 m .39722 .43384 L .39465 .44492 L .958 .688 .48 r
F
.39246 .44193 m .39395 .42936 L .39722 .43384 L F
.46633 .37936 m .47223 .3853 L .47183 .38723 L .964 .688 .462 r
F
.46633 .37936 m .46654 .37715 L .47223 .3853 L F
0 g
.47223 .3853 m
.47768 .3944 L
s
.50283 .48089 m .50465 .49231 L .5032 .49076 L .964 .688 .462 r
F
.50138 .47968 m .50283 .48089 L .5032 .49076 L F
.49893 .46873 m .50138 .47968 L .49994 .47846 L F
.49752 .46787 m .49893 .46873 L .49994 .47846 L F
.24673 .49523 m .2371 .48021 L .23772 .47475 L .991 .748 .462 r
F
.24667 .49818 m .2371 .48021 L .24673 .49523 L .991 .738 .437 r
F
.23983 .48982 m .22373 .46915 L .22513 .46309 L .959 .704 .506 r
F
.23945 .49321 m .22373 .46915 L .23983 .48982 L .96 .702 .501 r
F
.45234 .41964 m .45907 .41959 L .45554 .42573 L .962 .688 .467 r
F
.45234 .41964 m .45509 .41199 L .45907 .41959 L F
.35661 .49113 m .36812 .5006 L .36756 .50376 L .906 .626 .501 r
F
.35675 .48937 m .36812 .5006 L .35661 .49113 L .904 .632 .515 r
F
.24236 .46216 m .23883 .4368 L .24242 .4328 L .992 .824 .576 r
F
.24037 .46565 m .23883 .4368 L .24236 .46216 L .998 .822 .54 r
F
.4748 .40261 m .47986 .40958 L .47911 .4109 L .964 .688 .462 r
F
.4748 .40261 m .47538 .40097 L .47986 .40958 L F
.47836 .41223 m .48309 .41973 L .48219 .42071 L F
.47836 .41223 m .47911 .4109 L .48309 .41973 L F
.18665 .43996 m .18405 .40248 L .19055 .43354 L .991 .797 .547 r
F
.5178 .45348 m .53555 .4591 L .51957 .46412 L .593 .44 .644 r
F
.5178 .45348 m .53375 .44844 L .53555 .4591 L F
.51147 .45107 m .5178 .45348 L .51957 .46412 L .965 .687 .457 r
F
.50946 .44198 m .5178 .45348 L .51147 .45107 L F
0 g
.51538 .44261 m
.5178 .45348 L
s
.18801 .36231 m .18874 .32724 L .19939 .32127 L .981 .859 .644 r
F
.18874 .32724 m .20597 .31895 L .19939 .32127 L 0 0 0 r
F
0 g
.20279 .32048 m
.20591 .31975 L
s
.34727 .42928 m .35631 .41278 L .3506 .43085 L .934 .811 .7 r
F
.34727 .42928 m .35188 .41064 L .35631 .41278 L F
.43091 .4674 m .44349 .46774 L .44458 .47466 L .839 .608 .589 r
F
.42976 .46208 m .44349 .46774 L .43091 .4674 L .841 .623 .607 r
F
.22959 .45353 m .21736 .42455 L .22189 .41964 L .961 .72 .526 r
F
.22709 .45786 m .21736 .42455 L .22959 .45353 L .963 .719 .519 r
F
.42182 .41658 m .43592 .4097 L .42539 .42155 L .86 .738 .726 r
F
.42182 .41658 m .43148 .40348 L .43592 .4097 L F
.25321 .53449 m .24618 .55357 L .25098 .53169 L .952 .674 .474 r
F
.25321 .53449 m .25068 .55917 L .24618 .55357 L F
.256 .52617 m .25233 .53741 L .25429 .52361 L .957 .621 .321 r
F
.256 .52617 m .25578 .54255 L .25233 .53741 L F
.47549 .47938 m .48251 .49433 L .47574 .48721 L .962 .688 .467 r
F
.47574 .48721 m .48251 .49433 L .48213 .50302 L F
.21736 .42455 m .21212 .38859 L .22189 .41964 L .966 .733 .534 r
F
.19488 .47305 m .18356 .44776 L .18665 .43996 L .984 .761 .519 r
F
.19342 .4791 m .18356 .44776 L .19488 .47305 L .987 .755 .498 r
F
.34732 .46562 m .35191 .45179 L .34848 .46665 L .94 .736 .599 r
F
.34732 .46562 m .34961 .44973 L .35191 .45179 L F
0 g
.48564 .42959 m
.48866 .43872 L
s
.2442 .4046 m .25821 .37007 L .24967 .40106 L .968 .932 .687 r
F
.24242 .4328 m .2442 .4046 L .24967 .40106 L .984 .876 .645 r
F
.47063 .39306 m .47596 .39932 L .47538 .40097 L .964 .688 .462 r
F
.47063 .39306 m .47103 .39112 L .47596 .39932 L F
0 g
.48219 .42071 m
.48564 .42959 L
s
.41986 .43685 m .43205 .43323 L .42229 .44142 L .868 .701 .673 r
F
.41986 .43685 m .42882 .42713 L .43205 .43323 L F
.49458 .45763 m .49752 .46787 L .49611 .467 L .964 .688 .462 r
F
.49323 .45713 m .49458 .45763 L .49611 .467 L F
.4912 .44794 m .49458 .45763 L .49323 .45713 L F
0 g
.48866 .43872 m
.4912 .44794 L
s
.55014 .35078 m .59918 .33066 L .55636 .36153 L .804 .709 .76 r
F
.55014 .35078 m .59106 .31629 L .59918 .33066 L F
.61201 .32331 m .59918 .33066 L .61879 .33539 L .254 .436 .848 r
F
.61201 .32331 m .59106 .31629 L .59918 .33066 L F
0 g
.59918 .33066 m
.60689 .34621 L
s
.37962 .51824 m .39279 .53383 L .37797 .52173 L .843 .518 .438 r
F
.36671 .50652 m .37962 .51824 L .37797 .52173 L .879 .567 .454 r
F
.36756 .50376 m .37962 .51824 L .36671 .50652 L .875 .577 .48 r
F
.24667 .49818 m .23698 .48615 L .2371 .48021 L .991 .738 .437 r
F
.24686 .50132 m .23698 .48615 L .24667 .49818 L .989 .725 .413 r
F
.50022 .40033 m .51614 .39516 L .52064 .40524 L .64 .593 .785 r
F
.49535 .39089 m .51614 .39516 L .50022 .40033 L .646 .622 .812 r
F
.49268 .3987 m .50022 .40033 L .49676 .40659 L .965 .687 .457 r
F
.49268 .3987 m .49535 .39089 L .50022 .40033 L F
0 g
.50022 .40033 m
.50473 .41039 L
s
.42847 .53442 m .43308 .55471 L .42588 .54029 L .958 .688 .48 r
F
.42074 .52115 m .42847 .53442 L .42588 .54029 L F
.4223 .51559 m .42847 .53442 L .42074 .52115 L F
.46807 .46711 m .47466 .4711 L .47549 .47938 L .962 .688 .467 r
F
.46696 .4602 m .47466 .4711 L .46807 .46711 L F
.4391 .38283 m .44754 .38831 L .44453 .3893 L .66 .725 .898 r
F
.42692 .39811 m .44453 .3893 L .43148 .40348 L .845 .763 .772 r
F
.42692 .39811 m .4391 .38283 L .44453 .3893 L F
0 g
.44453 .3893 m
.44707 .39289 L
s
.41417 .50365 m .4223 .51559 L .42074 .52115 L .958 .688 .48 r
F
.41493 .49889 m .4223 .51559 L .41417 .50365 L F
.46611 .38157 m .47183 .38723 L .47143 .38917 L .964 .688 .462 r
F
.46611 .38157 m .46633 .37936 L .47183 .38723 L F
.40667 .48113 m .41526 .49362 L .40673 .48494 L .958 .688 .48 r
F
.40673 .48494 m .41526 .49362 L .41493 .49889 L F
.50138 .47968 m .5032 .49076 L .50174 .48921 L .964 .688 .462 r
F
.49994 .47846 m .50138 .47968 L .50174 .48921 L F
.49752 .46787 m .49994 .47846 L .49849 .47724 L F
.49611 .467 m .49752 .46787 L .49849 .47724 L F
.23945 .49321 m .22294 .47593 L .22373 .46915 L .96 .702 .501 r
F
.23938 .49688 m .22294 .47593 L .23945 .49321 L .96 .7 .497 r
F
.25098 .53169 m .24187 .54719 L .24885 .52852 L .954 .677 .474 r
F
.25429 .52361 m .24911 .53174 L .2527 .52079 L .962 .631 .318 r
F
.25098 .53169 m .24618 .55357 L .24187 .54719 L .954 .677 .474 r
F
.25429 .52361 m .25233 .53741 L .24911 .53174 L .962 .631 .318 r
F
.47422 .40427 m .47911 .4109 L .47836 .41223 L .964 .688 .462 r
F
.47422 .40427 m .4748 .40261 L .47911 .4109 L F
0 g
.47836 .41223 m
.48219 .42071 L
s
.66377 .26899 m .67338 .26575 L .68343 .28433 L .655 .651 .835 r
F
.68173 .28065 m .68343 .28433 L .69017 .29623 L 0 0 .356 r
F
.68173 .28065 m .67338 .26575 L .68343 .28433 L F
0 g
.68343 .28433 m
.69301 .30434 L
s
.23883 .4368 m .2442 .4046 L .24242 .4328 L .992 .881 .601 r
F
.43172 .47261 m .44458 .47466 L .44521 .48133 L .838 .594 .57 r
F
.43091 .4674 m .44458 .47466 L .43172 .47261 L .839 .608 .589 r
F
.24686 .50132 m .23735 .49246 L .23698 .48615 L .989 .725 .413 r
F
.2473 .50458 m .23735 .49246 L .24686 .50132 L .986 .711 .389 r
F
.35632 .49271 m .36756 .50376 L .36671 .50652 L .908 .62 .485 r
F
.35661 .49113 m .36756 .50376 L .35632 .49271 L .906 .626 .501 r
F
.039 .916 .04 r
.27484 .5216 m
.35645 .492 L
s
.29406 .63455 m .29537 .66451 L .28555 .63374 L .933 .624 .432 r
F
.29406 .63455 m .30598 .66533 L .29537 .66451 L F
.4391 .38283 m .44211 .38183 L .44754 .38831 L .66 .725 .898 r
F
0 g
.44754 .38831 m
.45282 .3958 L
s
.44894 .41406 m .45509 .41199 L .45234 .41964 L .962 .688 .467 r
F
.44894 .41406 m .45086 .40503 L .45509 .41199 L F
.18874 .32724 m .19536 .32491 L .20597 .31895 L 0 0 0 r
F
.20327 .35702 m .19536 .32491 L .20597 .31895 L .97 .759 .563 r
F
0 g
.20597 .31895 m
.21756 .31626 L
s
.29052 .66986 m .29952 .69718 L .27983 .66908 L .867 .456 .246 r
F
.29052 .66986 m .31223 .6979 L .29952 .69718 L F
.5849 .40859 m .57706 .41183 L .5808 .42525 L .136 .194 .66 r
F
.58122 .39743 m .57706 .41183 L .5849 .40859 L .152 .237 .699 r
F
.58122 .39743 m .57267 .39854 L .57706 .41183 L F
.39021 .43937 m .39395 .42936 L .39246 .44193 L .958 .688 .48 r
F
.39021 .43937 m .39059 .42551 L .39395 .42936 L F
.44195 .39345 m .4475 .38862 L .44646 .39881 L .962 .688 .467 r
F
.44195 .39345 m .44211 .38217 L .4475 .38862 L F
.27051 .55611 m .27571 .57509 L .26681 .5539 L .908 .509 .229 r
F
.27051 .55611 m .28126 .57837 L .27571 .57509 L F
.52829 .42661 m .57352 .42688 L .53132 .43755 L .697 .554 .689 r
F
.52829 .42661 m .56991 .41395 L .57352 .42688 L F
.52471 .41578 m .56991 .41395 L .52829 .42661 L .704 .58 .713 r
F
.52884 .42583 m .52829 .42661 L .53132 .43755 L 0 0 .296 r
F
.52585 .41676 m .52829 .42661 L .52884 .42583 L 0 0 .337 r
F
.52585 .41676 m .52471 .41578 L .52829 .42661 L F
.3451 .44714 m .3506 .43085 L .34733 .44817 L .946 .783 .647 r
F
.3451 .44714 m .34727 .42928 L .3506 .43085 L F
.57706 .38656 m .57267 .39854 L .58122 .39743 L .156 .273 .734 r
F
.57706 .38656 m .56771 .3856 L .57267 .39854 L F
0 g
.57267 .39854 m
.57706 .41183 L
s
.5032 .49076 m .50465 .49231 L .5043 .50177 L .964 .688 .462 r
F
0 g
.50427 .48211 m
.50465 .49231 L
s
.47023 .39501 m .47538 .40097 L .4748 .40261 L .964 .688 .462 r
F
.47023 .39501 m .47063 .39306 L .47538 .40097 L F
.24885 .52852 m .23785 .54013 L .24686 .52501 L .955 .679 .474 r
F
.24686 .52501 m .23418 .53251 L .24505 .52124 L .956 .682 .475 r
F
.24686 .52501 m .23785 .54013 L .23418 .53251 L F
.2527 .52079 m .24618 .52562 L .25124 .51776 L .966 .642 .319 r
F
.24885 .52852 m .24187 .54719 L .23785 .54013 L .955 .679 .474 r
F
.2527 .52079 m .24911 .53174 L .24618 .52562 L .966 .642 .319 r
F
.52471 .41578 m .56569 .40115 L .56991 .41395 L .704 .58 .713 r
F
.52064 .40524 m .56569 .40115 L .52471 .41578 L .712 .605 .736 r
F
.52244 .40793 m .52471 .41578 L .52585 .41676 L 0 0 .362 r
F
.52244 .40793 m .52064 .40524 L .52471 .41578 L F
0 g
.52471 .41578 m
.52829 .42661 L
s
.44521 .48133 m .46084 .4921 L .44537 .48762 L .803 .55 .556 r
F
.46084 .4921 m .47931 .50421 L .46048 .49938 L .763 .496 .529 r
F
.44537 .48762 m .46084 .4921 L .46048 .49938 L .803 .531 .527 r
F
.039 .916 .04 r
.42017 .49861 m
.44813 .48977 L
s
.51957 .46412 m .53668 .46937 L .52067 .47438 L .579 .403 .607 r
F
.51957 .46412 m .53555 .4591 L .53668 .46937 L F
.51295 .45998 m .51957 .46412 L .52067 .47438 L .965 .687 .457 r
F
.51147 .45107 m .51957 .46412 L .51295 .45998 L F
0 g
.5178 .45348 m
.51957 .46412 L
s
.49323 .45713 m .49611 .467 L .4947 .46613 L .964 .688 .462 r
F
0 g
.4912 .44794 m
.49323 .45713 L
s
.41727 .43266 m .42882 .42713 L .41986 .43685 L .877 .718 .682 r
F
.41727 .43266 m .42539 .42155 L .42882 .42713 L F
.4659 .38378 m .47143 .38917 L .47103 .39112 L .964 .688 .462 r
F
.4659 .38378 m .46611 .38157 L .47143 .38917 L F
.34699 .48097 m .35524 .47905 L .35582 .4812 L .939 .682 .523 r
F
.34699 .48097 m .35453 .47692 L .35524 .47905 L .939 .686 .526 r
F
.23938 .49688 m .22276 .48332 L .22294 .47593 L .96 .7 .497 r
F
.23961 .50078 m .22276 .48332 L .23938 .49688 L .96 .698 .493 r
F
.2473 .50458 m .23822 .49904 L .23735 .49246 L .986 .711 .389 r
F
.24796 .50792 m .23822 .49904 L .2473 .50458 L .983 .697 .368 r
F
.34699 .48097 m .35371 .47486 L .35453 .47692 L .941 .689 .529 r
F
.41069 .54496 m .42924 .56038 L .40742 .54964 L .75 .367 .329 r
F
.41069 .54496 m .43308 .55472 L .42924 .56038 L F
0 g
.43308 .55472 m
.43308 .55471 L
s
.39279 .53383 m .41069 .54496 L .40742 .54964 L .805 .44 .367 r
F
.49994 .47846 m .50174 .48921 L .50028 .48765 L .964 .688 .462 r
F
.49849 .47724 m .49994 .47846 L .50028 .48765 L F
.34618 .46485 m .34961 .44973 L .34732 .46562 L .947 .743 .596 r
F
.34618 .46485 m .34733 .44817 L .34961 .44973 L F
.34699 .48097 m .35582 .4812 L .35627 .48335 L .938 .679 .519 r
F
.38383 .41996 m .38646 .40753 L .3872 .42236 L .958 .688 .48 r
F
.38383 .41996 m .38198 .4043 L .38646 .40753 L F
.34699 .48097 m .3528 .4729 L .35371 .47486 L .942 .692 .531 r
F
.53132 .43755 m .57644 .43975 L .53375 .44844 L .689 .528 .663 r
F
.53132 .43755 m .57352 .42688 L .57644 .43975 L F
.53138 .435 m .53132 .43755 L .53375 .44844 L 0 0 .24 r
F
.52884 .42583 m .53132 .43755 L .53138 .435 L 0 0 .296 r
F
0 g
.52829 .42661 m
.53132 .43755 L
s
.24505 .52124 m .23094 .52448 L .24345 .51726 L .957 .684 .477 r
F
.25124 .51776 m .24358 .51918 L .24995 .51456 L .971 .654 .325 r
F
.24505 .52124 m .23418 .53251 L .23094 .52448 L .957 .684 .477 r
F
.25124 .51776 m .24618 .52562 L .24358 .51918 L .971 .654 .325 r
F
.58805 .41986 m .5808 .42525 L .58384 .43861 L .108 .141 .613 r
F
.5849 .40859 m .5808 .42525 L .58805 .41986 L .136 .194 .66 r
F
0 g
.57706 .41183 m
.5808 .42525 L
s
.49611 .467 m .49849 .47724 L .49704 .47601 L .964 .688 .462 r
F
.4947 .46613 m .49611 .467 L .49704 .47601 L F
.52064 .40524 m .5609 .38868 L .56569 .40115 L .712 .605 .736 r
F
0 g
.56569 .40115 m
.56991 .41395 L
s
.34699 .48097 m .35627 .48335 L .35658 .48545 L .938 .676 .515 r
F
.22487 .57336 m .22182 .59237 L .22021 .5687 L .947 .612 .355 r
F
.22487 .57336 m .22887 .59935 L .22182 .59237 L F
.23961 .50078 m .22321 .49118 L .22276 .48332 L .96 .698 .493 r
F
.24014 .50484 m .22321 .49118 L .23961 .50078 L .96 .695 .489 r
F
.24014 .50484 m .22427 .49938 L .22321 .49118 L F
.24097 .50899 m .22427 .49938 L .24014 .50484 L .96 .693 .485 r
F
.24796 .50792 m .23956 .50577 L .23822 .49904 L .983 .697 .368 r
F
.24886 .51126 m .23956 .50577 L .24796 .50792 L .979 .682 .35 r
F
.56363 .41524 m .56973 .41399 L .57331 .42686 L .969 .687 .442 r
F
0 g
.56991 .41395 m
.57352 .42688 L
s
.56011 .40457 m .56973 .41399 L .56363 .41524 L .969 .687 .442 r
F
.56011 .40457 m .56552 .40125 L .56973 .41399 L F
.39279 .53383 m .40742 .54964 L .39012 .53754 L .805 .44 .367 r
F
.37797 .52173 m .39279 .53383 L .39012 .53754 L .848 .502 .398 r
F
.34699 .48097 m .3518 .47106 L .3528 .4729 L .944 .695 .532 r
F
.37761 .40213 m .38013 .38872 L .38198 .4043 L .958 .688 .48 r
F
.37761 .40213 m .37467 .38595 L .38013 .38872 L F
.34204 .62204 m .36705 .64146 L .33425 .62337 L .675 .156 0 r
F
.34204 .62204 m .37622 .63973 L .36705 .64146 L F
.24208 .51316 m .22593 .50776 L .24097 .50899 L .959 .69 .482 r
F
.24995 .51456 m .24136 .51252 L .24886 .51126 L .975 .668 .336 r
F
.24345 .51726 m .22817 .51618 L .24208 .51316 L .958 .687 .479 r
F
.24345 .51726 m .23094 .52448 L .22817 .51618 L F
.24208 .51316 m .22817 .51618 L .22593 .50776 L .959 .69 .482 r
F
.24995 .51456 m .24358 .51918 L .24136 .51252 L .975 .668 .336 r
F
.26458 .57034 m .26311 .59654 L .25996 .56762 L .946 .656 .457 r
F
.26458 .57034 m .27005 .60053 L .26311 .59654 L F
.24097 .50899 m .22593 .50776 L .22427 .49938 L .96 .693 .485 r
F
.24886 .51126 m .24136 .51252 L .23956 .50577 L .979 .682 .35 r
F
.55611 .39417 m .56552 .40125 L .56011 .40457 L .969 .687 .442 r
F
.55611 .39417 m .56076 .38884 L .56552 .40125 L F
.72714 .46161 m .73865 .47891 L .72892 .48185 L .568 .369 .571 r
F
.72714 .46161 m .73683 .45866 L .73865 .47891 L F
.71614 .4488 m .72714 .46161 L .72892 .48185 L .981 .691 .367 r
F
.71362 .43091 m .72714 .46161 L .71614 .4488 L .98 .687 .359 r
F
0 g
.7241 .44029 m
.72714 .46161 L
s
.51614 .39516 m .5609 .38868 L .52064 .40524 L .72 .632 .758 r
F
.51867 .39949 m .52064 .40524 L .52244 .40793 L 0 0 .373 r
F
.51867 .39949 m .51614 .39516 L .52064 .40524 L F
0 g
.52064 .40524 m
.52471 .41578 L
s
.42588 .54029 m .43308 .55471 L .42924 .56037 L .958 .688 .48 r
F
.43308 .55471 m .47096 .52946 L .42924 .56037 L 0 0 0 r
F
.43308 .55471 m .47402 .52484 L .47096 .52946 L F
0 g
.43308 .55471 m
.43615 .54762 L
s
.34699 .48097 m .35658 .48545 L .35674 .48746 L .938 .674 .511 r
F
.57248 .37615 m .56771 .3856 L .57706 .38656 L .148 .301 .764 r
F
.57248 .37615 m .56224 .37319 L .56771 .3856 L F
0 g
.56771 .3856 m
.57267 .39854 L
s
.24037 .46565 m .23583 .44199 L .23883 .4368 L .998 .822 .54 r
F
.23882 .46987 m .23583 .44199 L .24037 .46565 L 1 .814 .497 r
F
.49535 .39089 m .51128 .38569 L .51614 .39516 L .646 .622 .812 r
F
.49019 .38222 m .51128 .38569 L .49535 .39089 L .652 .654 .839 r
F
.48836 .39146 m .49535 .39089 L .49268 .3987 L .965 .687 .457 r
F
.48836 .39146 m .49019 .38222 L .49535 .39089 L F
0 g
.49535 .39089 m
.50022 .40033 L
s
.46872 .47376 m .47549 .47938 L .47574 .48721 L .962 .688 .467 r
F
.46807 .46711 m .47549 .47938 L .46872 .47376 L F
.5032 .49076 m .5043 .50177 L .50285 .4999 L .964 .688 .462 r
F
.50174 .48921 m .5032 .49076 L .50285 .4999 L F
.34699 .48097 m .35073 .46939 L .3518 .47106 L .945 .698 .533 r
F
.28417 .33364 m .35948 .36802 L .36543 .36808 L .577 .005 0 r
F
.25821 .37007 m .27521 .33595 L .28417 .33364 L .921 .964 .786 r
F
.27521 .33595 m .35948 .36802 L .28417 .33364 L .651 .13 0 r
F
0 g
.28417 .33364 m
.29379 .33396 L
s
.4065 .48846 m .41493 .49889 L .41417 .50365 L .958 .688 .48 r
F
.40673 .48494 m .41493 .49889 L .4065 .48846 L F
.039 .916 .04 r
.37403 .49997 m
.40699 .48944 L
s
.41815 .4123 m .43148 .40348 L .42182 .41658 L .873 .761 .735 r
F
.41815 .4123 m .42692 .39811 L .43148 .40348 L F
.43218 .47762 m .44521 .48133 L .44537 .48762 L .838 .579 .548 r
F
.43172 .47261 m .44521 .48133 L .43218 .47762 L .838 .594 .57 r
F
.46983 .39697 m .4748 .40261 L .47422 .40427 L .964 .688 .462 r
F
0 g
.47422 .40427 m
.47836 .41223 L
s
.46983 .39697 m .47023 .39501 L .4748 .40261 L .964 .688 .462 r
F
.56663 .42602 m .57331 .42686 L .57622 .43966 L .969 .687 .442 r
F
.56363 .41524 m .57331 .42686 L .56663 .42602 L F
.47931 .50421 m .48125 .51117 L .47822 .5121 L .509 .242 .445 r
F
.47931 .50421 m .48233 .50328 L .48125 .51117 L F
0 g
.48233 .50328 m
.48272 .49455 L
s
.46048 .49938 m .47931 .50421 L .47822 .5121 L .762 .47 .491 r
F
0 g
.47931 .50421 m
.47964 .49685 L
s
.46568 .386 m .47103 .39112 L .47063 .39306 L .964 .688 .462 r
F
.46568 .386 m .4659 .38378 L .47103 .39112 L F
.46069 .37254 m .46654 .37715 L .46633 .37936 L F
.46069 .37254 m .46071 .37009 L .46654 .37715 L F
0 g
.46654 .37715 m
.47223 .3853 L
s
.36671 .50652 m .37797 .52173 L .3656 .50884 L .879 .567 .454 r
F
.35589 .49409 m .36671 .50652 L .3656 .50884 L .912 .615 .469 r
F
.35632 .49271 m .36671 .50652 L .35589 .49409 L .908 .62 .485 r
F
.34699 .48097 m .35674 .48746 L .35675 .48937 L .938 .671 .506 r
F
.039 .916 .04 r
.19772 .49209 m
.22284 .48466 L
s
.39656 .46583 m .40359 .4643 L .40476 .4686 L .958 .688 .48 r
F
.39585 .46369 m .40359 .4643 L .39656 .46583 L F
.39585 .46369 m .40217 .46004 L .40359 .4643 L F
.58762 .46428 m .64078 .46705 L .64186 .4829 L .744 .5 .561 r
F
.58612 .45168 m .64078 .46705 L .58762 .46428 L .748 .525 .592 r
F
.65382 .45018 m .64078 .46705 L .64186 .4829 L .108 .03 .477 r
F
.65199 .43614 m .64078 .46705 L .65382 .45018 L .173 .117 .548 r
F
0 g
.63864 .45033 m
.64078 .46705 L
s
.49849 .47724 m .50028 .48765 L .49882 .4861 L .964 .688 .462 r
F
.49704 .47601 m .49849 .47724 L .49882 .4861 L F
.51614 .39516 m .55563 .37674 L .5609 .38868 L .72 .632 .758 r
F
0 g
.5609 .38868 m
.56569 .40115 L
s
.39503 .46161 m .40217 .46004 L .39585 .46369 L .958 .688 .48 r
F
.39503 .46161 m .40055 .45591 L .40217 .46004 L F
.24297 .6088 m .24496 .63225 L .23596 .60486 L .924 .558 .31 r
F
.24297 .6088 m .25432 .6374 L .24496 .63225 L F
.34699 .48097 m .34962 .46791 L .35073 .46939 L .947 .701 .533 r
F
.39715 .46799 m .40476 .4686 L .40567 .47289 L .958 .688 .48 r
F
.39656 .46583 m .40476 .4686 L .39715 .46799 L F
.37797 .52173 m .39012 .53754 L .37594 .52449 L .848 .502 .398 r
F
.3656 .50884 m .37797 .52173 L .37594 .52449 L .884 .557 .426 r
F
.53375 .44844 m .57863 .45234 L .53555 .4591 L .682 .501 .635 r
F
.53375 .44844 m .57644 .43975 L .57863 .45234 L F
0 g
.57352 .42688 m
.57644 .43975 L
s
.53342 .44412 m .53375 .44844 L .53555 .4591 L 0 0 .168 r
F
.53138 .435 m .53375 .44844 L .53342 .44412 L 0 0 .24 r
F
0 g
.53132 .43755 m
.53375 .44844 L
s
.19342 .4791 m .18132 .45684 L .18356 .44776 L .987 .755 .498 r
F
.19257 .48587 m .18132 .45684 L .19342 .4791 L .989 .748 .475 r
F
.55171 .38422 m .56076 .38884 L .55611 .39417 L .969 .687 .442 r
F
.55171 .38422 m .55551 .37696 L .56076 .38884 L F
.4947 .46613 m .49704 .47601 L .49559 .47479 L .964 .688 .462 r
F
0 g
.49323 .45713 m
.4947 .46613 L
s
.39411 .45963 m .40055 .45591 L .39503 .46161 L .958 .688 .48 r
F
.39411 .45963 m .39873 .45197 L .40055 .45591 L F
.44541 .40908 m .45086 .40503 L .44894 .41406 L .962 .688 .467 r
F
.44541 .40908 m .44646 .39881 L .45086 .40503 L F
.41457 .42893 m .42539 .42155 L .41727 .43266 L .887 .736 .689 r
F
.41457 .42893 m .42182 .41658 L .42539 .42155 L F
.59061 .43107 m .58384 .43861 L .58612 .45168 L .065 .075 .558 r
F
.58805 .41986 m .58384 .43861 L .59061 .43107 L .108 .141 .613 r
F
0 g
.5808 .42525 m
.58384 .43861 L
s
.34699 .48097 m .35675 .48937 L .35661 .49113 L .938 .668 .5 r
F
.4754 .49445 m .48213 .50302 L .48106 .51087 L .962 .688 .467 r
F
.47574 .48721 m .48213 .50302 L .4754 .49445 L F
.38794 .43728 m .39059 .42551 L .39021 .43937 L .958 .688 .48 r
F
.38794 .43728 m .3872 .42236 L .39059 .42551 L F
.27679 .6029 m .27657 .63072 L .27005 .60053 L .941 .64 .442 r
F
.27679 .6029 m .28555 .63374 L .27657 .63072 L F
.34506 .46435 m .34733 .44817 L .34618 .46485 L .954 .75 .59 r
F
.34506 .46435 m .3451 .44714 L .34733 .44817 L F
.22709 .45786 m .21354 .43096 L .21736 .42455 L .963 .719 .519 r
F
.22513 .46309 m .21354 .43096 L .22709 .45786 L .965 .717 .511 r
F
.50174 .48921 m .50285 .4999 L .5014 .49804 L .964 .688 .462 r
F
.50028 .48765 m .50174 .48921 L .5014 .49804 L F
.34763 .40959 m .35958 .39098 L .35188 .41064 L .934 .862 .745 r
F
.34407 .42854 m .35188 .41064 L .34727 .42928 L .949 .83 .692 r
F
.34407 .42854 m .34763 .40959 L .35188 .41064 L F
.3543 .3896 m .37174 .36982 L .35958 .39098 L .909 .892 .802 r
F
.34763 .40959 m .3543 .3896 L .35958 .39098 L .934 .862 .745 r
F
.3976 .47015 m .40567 .47289 L .40631 .47709 L .958 .688 .48 r
F
.39715 .46799 m .40567 .47289 L .3976 .47015 L F
.69181 .37576 m .70016 .37433 L .70556 .39339 L .977 .676 .353 r
F
.68679 .36049 m .70016 .37433 L .69181 .37576 L .976 .673 .35 r
F
.68679 .36049 m .69394 .35542 L .70016 .37433 L F
.34699 .48097 m .34848 .46665 L .34962 .46791 L .949 .704 .532 r
F
.51128 .38569 m .55563 .37674 L .51614 .39516 L .729 .659 .78 r
F
.5146 .39156 m .51614 .39516 L .51867 .39949 L 0 0 .366 r
F
.5146 .39156 m .51128 .38569 L .51614 .39516 L F
0 g
.51614 .39516 m
.52064 .40524 L
s
.28664 .58035 m .29629 .59957 L .28126 .57837 L .849 .395 .117 r
F
.28664 .58035 m .30344 .60214 L .29629 .59957 L F
.41848 .45928 m .4283 .45673 L .42976 .46208 L .876 .654 .598 r
F
.41731 .45575 m .4283 .45673 L .41848 .45928 L .88 .666 .61 r
F
.41731 .45575 m .42655 .45145 L .4283 .45673 L F
.26338 .64038 m .26855 .66553 L .25432 .6374 L .898 .505 .267 r
F
.26338 .64038 m .27983 .66908 L .26855 .66553 L F
.68118 .34558 m .69394 .35542 L .68679 .36049 L .975 .669 .347 r
F
.68118 .34558 m .687 .33697 L .69394 .35542 L F
.46067 .37499 m .46633 .37936 L .46611 .38157 L .964 .688 .462 r
F
.46067 .37499 m .46069 .37254 L .46633 .37936 L F
.39312 .45778 m .39873 .45197 L .39411 .45963 L .958 .688 .48 r
F
.39312 .45778 m .39676 .44828 L .39873 .45197 L F
.41596 .45231 m .42655 .45145 L .41731 .45575 L .884 .679 .62 r
F
.41596 .45231 m .42454 .44632 L .42655 .45145 L F
.46547 .38822 m .47063 .39306 L .47023 .39501 L .964 .688 .462 r
F
.46547 .38822 m .46568 .386 L .47063 .39306 L F
.45796 .44723 m .46347 .44606 L .46542 .45315 L .962 .688 .467 r
F
.45622 .44196 m .46347 .44606 L .45796 .44723 L F
.45622 .44196 m .46115 .43905 L .46347 .44606 L F
.42074 .52115 m .42588 .54029 L .41865 .52582 L .958 .688 .48 r
F
.41298 .50781 m .42074 .52115 L .41865 .52582 L F
.41417 .50365 m .42074 .52115 L .41298 .50781 L F
.31022 .60293 m .32585 .62248 L .30344 .60214 L .77 .274 .035 r
F
.31022 .60293 m .33425 .62337 L .32585 .62248 L F
.45421 .43682 m .46115 .43905 L .45622 .44196 L .962 .688 .467 r
F
.45421 .43682 m .4585 .43224 L .46115 .43905 L F
.52067 .47438 m .53712 .47908 L .52108 .48407 L .562 .359 .564 r
F
.52067 .47438 m .53668 .46937 L .53712 .47908 L F
.51386 .46855 m .52067 .47438 L .52108 .48407 L .965 .687 .457 r
F
.51295 .45998 m .52067 .47438 L .51386 .46855 L F
0 g
.51957 .46412 m
.52067 .47438 L
s
.20599 .395 m .20327 .35702 L .21212 .38859 L .971 .746 .541 r
F
.21736 .42455 m .20599 .395 L .21212 .38859 L .966 .733 .534 r
F
.41946 .46286 m .42976 .46208 L .43091 .4674 L .874 .642 .585 r
F
.41848 .45928 m .42976 .46208 L .41946 .46286 L .876 .654 .598 r
F
.26681 .5539 m .2701 .57057 L .26308 .55086 L .91 .505 .189 r
F
.26681 .5539 m .27571 .57509 L .2701 .57057 L F
.49704 .47601 m .49882 .4861 L .49735 .48454 L .964 .688 .462 r
F
.49559 .47479 m .49704 .47601 L .49735 .48454 L F
.56906 .43675 m .57622 .43966 L .5784 .4522 L .969 .687 .442 r
F
.56663 .42602 m .57622 .43966 L .56906 .43675 L F
.34699 .48097 m .35661 .49113 L .35632 .49271 L .939 .666 .495 r
F
.43363 .37748 m .44211 .38183 L .4391 .38283 L .659 .767 .93 r
F
.42233 .39369 m .4391 .38283 L .42692 .39811 L .86 .792 .783 r
F
.42233 .39369 m .43363 .37748 L .4391 .38283 L F
0 g
.4391 .38283 m
.44205 .38634 L
s
.56756 .36636 m .56224 .37319 L .57248 .37615 L .126 .321 .789 r
F
.56756 .36636 m .55636 .36153 L .56224 .37319 L F
0 g
.56224 .37319 m
.56771 .3856 L
s
.34297 .44667 m .34727 .42928 L .3451 .44714 L .958 .795 .638 r
F
.34297 .44667 m .34407 .42854 L .34727 .42928 L F
.73253 .42504 m .73683 .45866 L .73512 .44296 L 0 0 .133 r
F
.73512 .44296 m .73683 .45866 L .73865 .47891 L .723 .535 0 r
F
0 g
.73375 .43731 m
.7363 .455 L
s
.41446 .44904 m .42454 .44632 L .41596 .45231 L .889 .692 .629 r
F
.41446 .44904 m .42229 .44142 L .42454 .44632 L F
.45943 .45257 m .46542 .45315 L .46696 .4602 L .962 .688 .467 r
F
.45796 .44723 m .46542 .45315 L .45943 .45257 L F
.39792 .47226 m .40631 .47709 L .40667 .48113 L .958 .688 .48 r
F
.3976 .47015 m .40631 .47709 L .39792 .47226 L F
.34699 .48097 m .34732 .46562 L .34848 .46665 L .952 .707 .531 r
F
.46048 .49938 m .47822 .5121 L .45953 .50594 L .762 .47 .491 r
F
.44505 .49344 m .46048 .49938 L .45953 .50594 L .804 .512 .494 r
F
.44537 .48762 m .46048 .49938 L .44505 .49344 L .803 .531 .527 r
F
.50145 .43399 m .50693 .43284 L .50946 .44198 L .965 .687 .457 r
F
.49904 .42672 m .50693 .43284 L .50145 .43399 L F
.49904 .42672 m .50394 .4238 L .50693 .43284 L F
.45198 .43193 m .4585 .43224 L .45421 .43682 L .962 .688 .467 r
F
.45198 .43193 m .45554 .42573 L .4585 .43224 L F
.69618 .39117 m .70556 .39339 L .71007 .41235 L .978 .679 .357 r
F
.69181 .37576 m .70556 .39339 L .69618 .39117 L .977 .676 .353 r
F
.65335 .25218 m .67338 .26575 L .66377 .26899 L .66 .684 .862 r
F
.65413 .2729 m .66377 .26899 L .66288 .28694 L .97 .654 .334 r
F
.65413 .2729 m .65335 .25218 L .66377 .26899 L F
0 g
.66377 .26899 m
.67385 .28752 L
s
.3543 .3896 m .36543 .36808 L .37174 .36982 L .909 .892 .802 r
F
0 g
.37174 .36982 m
.37174 .36983 L
s
.37174 .36983 m .4229 .37055 L .4282 .37336 L .356 .747 .986 r
F
.36544 .36808 m .4229 .37055 L .37174 .36983 L .201 .704 .908 r
F
.36942 .38455 m .37174 .36983 L .37467 .38595 L .958 .688 .48 r
F
.36942 .38455 m .36544 .36808 L .37174 .36983 L F
0 g
.37174 .36983 m
.37829 .3732 L
s
.50028 .48765 m .5014 .49804 L .49995 .49617 L .964 .688 .462 r
F
.49882 .4861 m .50028 .48765 L .49995 .49617 L F
.30598 .66533 m .3063 .69523 L .29537 .66451 L .928 .608 .414 r
F
.30598 .66533 m .31897 .69596 L .3063 .69523 L F
.4963 .41966 m .50394 .4238 L .49904 .42672 L .965 .687 .457 r
F
.4963 .41966 m .50053 .415 L .50394 .4238 L F
.43218 .47762 m .44537 .48762 L .43228 .48235 L .838 .579 .548 r
F
.43228 .48235 m .44537 .48762 L .44505 .49344 L .839 .565 .523 r
F
.51128 .38569 m .54995 .36551 L .55563 .37674 L .729 .659 .78 r
F
0 g
.55563 .37674 m
.5609 .38868 L
s
.39206 .4561 m .39676 .44828 L .39312 .45778 L .958 .688 .48 r
F
.39206 .4561 m .39465 .44492 L .39676 .44828 L F
.42022 .46642 m .43091 .4674 L .43172 .47261 L .873 .631 .57 r
F
.41946 .46286 m .43091 .4674 L .42022 .46642 L .874 .642 .585 r
F
.3656 .50884 m .37594 .52449 L .36422 .51066 L .884 .557 .426 r
F
.35532 .49524 m .3656 .50884 L .36422 .51066 L .915 .61 .452 r
F
.35589 .49409 m .3656 .50884 L .35532 .49524 L .912 .615 .469 r
F
.5437 .34113 m .59106 .31629 L .55014 .35078 L .816 .736 .776 r
F
.5437 .34113 m .58265 .30333 L .59106 .31629 L F
.60499 .31243 m .59106 .31629 L .61201 .32331 L .214 .449 .87 r
F
.60499 .31243 m .58265 .30333 L .59106 .31629 L F
0 g
.59106 .31629 m
.59918 .33066 L
s
.43363 .37748 m .43664 .37648 L .44211 .38183 L .659 .767 .93 r
F
0 g
.44211 .38183 m
.44754 .38831 L
s
.46064 .37744 m .46611 .38157 L .4659 .38378 L .964 .688 .462 r
F
.46064 .37744 m .46067 .37499 L .46611 .38157 L F
.22021 .5687 m .21496 .58402 L .21567 .56315 L .953 .619 .346 r
F
.22021 .5687 m .22182 .59237 L .21496 .58402 L F
.54697 .37487 m .55551 .37696 L .55171 .38422 L .969 .687 .442 r
F
.54697 .37487 m .54986 .36578 L .55551 .37696 L F
.18018 .37017 m .18874 .32724 L .18801 .36231 L .991 .865 .608 r
F
.18405 .40248 m .18018 .37017 L .18801 .36231 L .99 .831 .59 r
F
.46872 .47376 m .47574 .48721 L .46891 .48003 L .962 .688 .467 r
F
.46891 .48003 m .47574 .48721 L .4754 .49445 L F
.4374 .38903 m .44211 .38217 L .44195 .39345 L F
.4374 .38903 m .43667 .37685 L .44211 .38217 L F
.34699 .48097 m .35632 .49271 L .35589 .49409 L .94 .664 .489 r
F
.53555 .4591 m .58005 .46448 L .53668 .46937 L .674 .472 .604 r
F
.53555 .4591 m .57863 .45234 L .58005 .46448 L F
0 g
.57644 .43975 m
.57863 .45234 L
s
.53493 .45305 m .53555 .4591 L .53668 .46937 L 0 0 .083 r
F
.53342 .44412 m .53555 .4591 L .53493 .45305 L 0 0 .168 r
F
0 g
.53375 .44844 m
.53555 .4591 L
s
.41282 .44598 m .42229 .44142 L .41446 .44904 L .896 .705 .636 r
F
.41282 .44598 m .41986 .43685 L .42229 .44142 L F
.50347 .44134 m .50946 .44198 L .51147 .45107 L .965 .687 .457 r
F
.50145 .43399 m .50946 .44198 L .50347 .44134 L F
.40598 .49163 m .41417 .50365 L .41298 .50781 L .958 .688 .48 r
F
.4065 .48846 m .41417 .50365 L .40598 .49163 L F
.42588 .54029 m .42924 .56037 L .42265 .54497 L F
.41865 .52582 m .42588 .54029 L .42265 .54497 L F
.18665 .43996 m .17878 .41093 L .18405 .40248 L .991 .797 .547 r
F
.18356 .44776 m .17878 .41093 L .18665 .43996 L .995 .792 .517 r
F
.46525 .39044 m .47023 .39501 L .46983 .39697 L .964 .688 .462 r
F
0 g
.46983 .39697 m
.47422 .40427 L
s
.46525 .39044 m .46547 .38822 L .47023 .39501 L .964 .688 .462 r
F
.46059 .45789 m .46696 .4602 L .46807 .46711 L .962 .688 .467 r
F
.45943 .45257 m .46696 .4602 L .46059 .45789 L F
.23882 .46987 m .23347 .44829 L .23583 .44199 L 1 .814 .497 r
F
.23772 .47475 m .23347 .44829 L .23882 .46987 L .998 .799 .448 r
F
.49019 .38222 m .50613 .37699 L .51128 .38569 L .652 .654 .839 r
F
.48482 .37446 m .50613 .37699 L .49019 .38222 L .657 .688 .867 r
F
.48386 .38499 m .49019 .38222 L .48836 .39146 L .965 .687 .457 r
F
.48386 .38499 m .48482 .37446 L .49019 .38222 L F
0 g
.49019 .38222 m
.49535 .39089 L
s
.25138 .37435 m .27521 .33595 L .25821 .37007 L .912 .98 .725 r
F
.2442 .4046 m .25138 .37435 L .25821 .37007 L .968 .932 .687 r
F
.50285 .4999 m .5043 .50177 L .50319 .51032 L .964 .688 .462 r
F
0 g
.5043 .50177 m
.50465 .49231 L
s
.67506 .33127 m .687 .33697 L .68118 .34558 L .974 .666 .346 r
F
.67506 .33127 m .67943 .31922 L .687 .33697 L F
.49559 .47479 m .49735 .48454 L .49589 .48298 L .964 .688 .462 r
F
0 g
.4947 .46613 m
.49559 .47479 L
s
.34699 .48097 m .34618 .46485 L .34732 .46562 L .954 .709 .529 r
F
.3981 .47428 m .40667 .48113 L .40673 .48494 L .958 .688 .48 r
F
.39792 .47226 m .40667 .48113 L .3981 .47428 L F
.49327 .4129 m .50053 .415 L .4963 .41966 L .965 .687 .457 r
F
.49327 .4129 m .49676 .40659 L .50053 .415 L F
.38055 .41836 m .38198 .4043 L .38383 .41996 L .958 .688 .48 r
F
.38055 .41836 m .37761 .40213 L .38198 .4043 L F
.34399 .46413 m .3451 .44714 L .34506 .46435 L .961 .756 .582 r
F
.34399 .46413 m .34297 .44667 L .3451 .44714 L F
.44957 .42734 m .45554 .42573 L .45198 .43193 L .962 .688 .467 r
F
.44957 .42734 m .45234 .41964 L .45554 .42573 L F
.41181 .42573 m .42182 .41658 L .41457 .42893 L .898 .755 .695 r
F
.41181 .42573 m .41815 .4123 L .42182 .41658 L F
.23883 .4368 m .2394 .40984 L .2442 .4046 L .992 .881 .601 r
F
.23583 .44199 m .2394 .40984 L .23883 .4368 L .991 .875 .541 r
F
.42076 .4699 m .43172 .47261 L .43218 .47762 L .872 .62 .554 r
F
.42022 .46642 m .43172 .47261 L .42076 .4699 L .873 .631 .57 r
F
.25996 .56762 m .25608 .59098 L .2553 .56387 L .949 .658 .453 r
F
.25996 .56762 m .26311 .59654 L .25608 .59098 L F
.21354 .43096 m .20599 .395 L .21736 .42455 L .969 .732 .523 r
F
.41445 .40879 m .42692 .39811 L .41815 .4123 L .888 .785 .741 r
F
.41445 .40879 m .42233 .39369 L .42692 .39811 L F
.59254 .44204 m .58612 .45168 L .58762 .46428 L .005 0 .49 r
F
.59061 .43107 m .58612 .45168 L .59254 .44204 L .065 .075 .558 r
F
0 g
.58384 .43861 m
.58612 .45168 L
s
.49882 .4861 m .49995 .49617 L .49849 .4943 L .964 .688 .462 r
F
.49735 .48454 m .49882 .4861 L .49849 .4943 L F
.39096 .4546 m .39465 .44492 L .39206 .4561 L .958 .688 .48 r
F
.39096 .4546 m .39246 .44193 L .39465 .44492 L F
.34699 .48097 m .35589 .49409 L .35532 .49524 L .941 .663 .483 r
F
.19257 .48587 m .18 .46702 L .18132 .45684 L .989 .748 .475 r
F
.19235 .49324 m .18 .46702 L .19257 .48587 L .989 .738 .452 r
F
.50613 .37699 m .54995 .36551 L .51128 .38569 L .739 .688 .802 r
F
.5103 .38429 m .51128 .38569 L .5146 .39156 L .627 .22 0 r
F
0 g
.51224 .38758 m
.51614 .39516 L
s
.5103 .38429 m .50613 .37699 L .51128 .38569 L .627 .22 0 r
F
.46062 .37989 m .4659 .38378 L .46568 .386 L .964 .688 .462 r
F
.46062 .37989 m .46064 .37744 L .4659 .38378 L F
.3857 .43569 m .3872 .42236 L .38794 .43728 L .958 .688 .48 r
F
.3857 .43569 m .38383 .41996 L .3872 .42236 L F
.39012 .53754 m .40356 .55303 L .38699 .54022 L .806 .411 .303 r
F
.39012 .53754 m .40742 .54964 L .40356 .55303 L F
.37594 .52449 m .39012 .53754 L .38699 .54022 L .853 .484 .352 r
F
.44179 .40479 m .44646 .39881 L .44541 .40908 L .962 .688 .467 r
F
.44179 .40479 m .44195 .39345 L .44646 .39881 L F
.50509 .44864 m .51147 .45107 L .51295 .45998 L .965 .687 .457 r
F
.50347 .44134 m .51147 .45107 L .50509 .44864 L F
.41109 .44319 m .41986 .43685 L .41282 .44598 L .903 .718 .642 r
F
.41109 .44319 m .41727 .43266 L .41986 .43685 L F
.37594 .52449 m .38699 .54022 L .37356 .52647 L .853 .484 .352 r
F
.36422 .51066 m .37594 .52449 L .37356 .52647 L .889 .548 .395 r
F
.50285 .4999 m .50319 .51032 L .50178 .50817 L .964 .688 .462 r
F
.5014 .49804 m .50285 .4999 L .50178 .50817 L F
.34699 .48097 m .34506 .46435 L .34618 .46485 L .956 .711 .526 r
F
.46141 .46309 m .46807 .46711 L .46872 .47376 L .962 .688 .467 r
F
.46059 .45789 m .46807 .46711 L .46141 .46309 L F
.57088 .44724 m .5784 .4522 L .57982 .46427 L .969 .687 .442 r
F
.56906 .43675 m .5784 .4522 L .57088 .44724 L F
.2394 .40984 m .25138 .37435 L .2442 .4046 L .963 .934 .619 r
F
.3981 .47428 m .40673 .48494 L .39813 .47619 L .958 .688 .48 r
F
.39813 .47619 m .40673 .48494 L .4065 .48846 L F
.48998 .40657 m .49676 .40659 L .49327 .4129 L .965 .687 .457 r
F
.48998 .40657 m .49268 .3987 L .49676 .40659 L F
.65335 .25218 m .66299 .24891 L .67338 .26575 L .66 .684 .862 r
F
.67304 .26655 m .67338 .26575 L .68173 .28065 L .649 .233 0 r
F
0 g
.67935 .27679 m
.68343 .28433 L
s
.67304 .26655 m .66299 .24891 L .67338 .26575 L .649 .233 0 r
F
.40742 .54964 m .42469 .5645 L .40356 .55303 L .743 .319 .243 r
F
.40742 .54964 m .42924 .56038 L .42469 .5645 L F
0 g
.42924 .56038 m
.42924 .56037 L
s
.47822 .5121 m .47949 .51808 L .47645 .51902 L .467 .157 .357 r
F
.47822 .5121 m .48125 .51117 L .47949 .51808 L F
0 g
.48125 .51117 m
.48233 .50328 L
s
.45953 .50594 m .47822 .5121 L .47645 .51902 L .761 .442 .445 r
F
0 g
.47822 .5121 m
.47915 .50534 L
s
.26308 .55086 m .26453 .56487 L .25938 .54706 L .91 .503 .153 r
F
.26308 .55086 m .2701 .57057 L .26453 .56487 L F
.36422 .51066 m .37356 .52647 L .36262 .51196 L .889 .548 .395 r
F
.35463 .49614 m .36422 .51066 L .36262 .51196 L .919 .606 .434 r
F
.35532 .49524 m .36422 .51066 L .35463 .49614 L .915 .61 .452 r
F
.69981 .40647 m .71007 .41235 L .71362 .43091 L .979 .683 .362 r
F
.69618 .39117 m .71007 .41235 L .69981 .40647 L .978 .679 .357 r
F
.17878 .41093 m .18018 .37017 L .18405 .40248 L .997 .83 .554 r
F
.34699 .48097 m .35532 .49524 L .35463 .49614 L .943 .662 .477 r
F
.49735 .48454 m .49849 .4943 L .49704 .49243 L .964 .688 .462 r
F
.49589 .48298 m .49735 .48454 L .49704 .49243 L F
.45501 .3669 m .46071 .37009 L .46069 .37254 L F
.45501 .3669 m .45484 .36426 L .46071 .37009 L F
0 g
.46071 .37009 m
.46654 .37715 L
s
.56236 .35735 m .55636 .36153 L .56756 .36636 L .087 .332 .807 r
F
.56236 .35735 m .55014 .35078 L .55636 .36153 L F
0 g
.55636 .36153 m
.56224 .37319 L
s
.42106 .47325 m .43218 .47762 L .43228 .48235 L .873 .609 .536 r
F
.42076 .4699 m .43218 .47762 L .42106 .47325 L .872 .62 .554 r
F
.44701 .42315 m .45234 .41964 L .44957 .42734 L .962 .688 .467 r
F
.44701 .42315 m .44894 .41406 L .45234 .41964 L F
.37341 .40106 m .37467 .38595 L .37761 .40213 L .958 .688 .48 r
F
.37341 .40106 m .36942 .38455 L .37467 .38595 L F
.22513 .46309 m .21052 .43876 L .21354 .43096 L .965 .717 .511 r
F
.22373 .46915 m .21052 .43876 L .22513 .46309 L .967 .715 .504 r
F
.4606 .38235 m .46568 .386 L .46547 .38822 L .964 .688 .462 r
F
.4606 .38235 m .46062 .37989 L .46568 .386 L F
.31223 .6979 m .3063 .69523 L .29952 .69718 L .456 .875 .935 r
F
.31223 .6979 m .31897 .69596 L .3063 .69523 L F
0 g
.31223 .6979 m
.32397 .69531 L
s
.31897 .69596 m
.33066 .69339 L
s
.44505 .49344 m .45953 .50594 L .44426 .4987 L .804 .512 .494 r
F
.43203 .48672 m .44505 .49344 L .44426 .4987 L .842 .55 .495 r
F
.43228 .48235 m .44505 .49344 L .43203 .48672 L .839 .565 .523 r
F
.38983 .45332 m .39246 .44193 L .39096 .4546 L .958 .688 .48 r
F
.38983 .45332 m .39021 .43937 L .39246 .44193 L F
.5014 .49804 m .50178 .50817 L .50036 .50602 L .964 .688 .462 r
F
.49995 .49617 m .5014 .49804 L .50036 .50602 L F
.51386 .46855 m .52108 .48407 L .51419 .47665 L .965 .687 .457 r
F
.52108 .48407 m .53686 .48806 L .52078 .49305 L .539 .307 .512 r
F
.52108 .48407 m .53712 .47908 L .53686 .48806 L F
.51419 .47665 m .52108 .48407 L .52078 .49305 L .965 .687 .457 r
F
0 g
.52067 .47438 m
.52108 .48407 L
s
.34699 .48097 m .34399 .46413 L .34506 .46435 L .958 .712 .522 r
F
.50613 .37699 m .54395 .35516 L .54995 .36551 L .739 .688 .802 r
F
0 g
.54995 .36551 m
.55563 .37674 L
s
.34106 .42863 m .34763 .40959 L .34407 .42854 L .965 .848 .677 r
F
.34096 .44676 m .34407 .42854 L .34297 .44667 L .969 .806 .625 r
F
.34096 .44676 m .34106 .42863 L .34407 .42854 L F
.40928 .4407 m .41727 .43266 L .41109 .44319 L .911 .732 .646 r
F
.40928 .4407 m .41457 .42893 L .41727 .43266 L F
.21567 .56315 m .2084 .57446 L .21134 .55681 L .958 .626 .34 r
F
.21567 .56315 m .21496 .58402 L .2084 .57446 L F
.54197 .36627 m .54986 .36578 L .54697 .37487 L .969 .687 .442 r
F
.54197 .36627 m .54389 .35549 L .54986 .36578 L F
.47449 .50099 m .48106 .51087 L .4793 .51775 L .962 .688 .467 r
F
.4754 .49445 m .48106 .51087 L .47449 .50099 L F
.34299 .46418 m .34297 .44667 L .34399 .46413 L .968 .761 .572 r
F
.34299 .46418 m .34096 .44676 L .34297 .44667 L F
.53668 .46937 m .58069 .47596 L .53712 .47908 L .666 .439 .567 r
F
.53668 .46937 m .58005 .46448 L .58069 .47596 L F
0 g
.57863 .45234 m
.58005 .46448 L
s
.53493 .45305 m .53668 .46937 L .53587 .46164 L 0 0 .083 r
F
.53587 .46164 m .53668 .46937 L .53712 .47908 L .762 .587 .015 r
F
0 g
.53555 .4591 m
.53596 .46284 L
s
.71811 .36736 m .71894 .36833 L .72438 .38744 L .719 .429 0 r
F
.71307 .35203 m .71894 .36833 L .71811 .36736 L .708 .398 0 r
F
.71307 .35203 m .71271 .34937 L .71894 .36833 L F
.34363 .40967 m .3543 .3896 L .34763 .40959 L .952 .889 .731 r
F
.34106 .42863 m .34363 .40967 L .34763 .40959 L .965 .848 .677 r
F
.23772 .47475 m .2318 .45561 L .23347 .44829 L .998 .799 .448 r
F
.2371 .48021 m .2318 .45561 L .23772 .47475 L .991 .777 .394 r
F
.50627 .4558 m .51295 .45998 L .51386 .46855 L .965 .687 .457 r
F
.50509 .44864 m .51295 .45998 L .50627 .4558 L F
.41298 .50781 m .41865 .52582 L .41139 .51129 L .958 .688 .48 r
F
.40518 .4944 m .41298 .50781 L .41139 .51129 L F
.40598 .49163 m .41298 .50781 L .40518 .4944 L F
.45518 .36955 m .46069 .37254 L .46067 .37499 L .964 .688 .462 r
F
.45518 .36955 m .45501 .3669 L .46069 .37254 L F
.41865 .52582 m .42265 .54497 L .41604 .52952 L .958 .688 .48 r
F
.41139 .51129 m .41865 .52582 L .41604 .52952 L F
.35463 .49614 m .36262 .51196 L .35382 .49678 L .919 .606 .434 r
F
.34699 .48097 m .35463 .49614 L .35382 .49678 L .944 .661 .472 r
F
.70746 .33706 m .71271 .34937 L .71307 .35203 L .706 .376 0 r
F
.70746 .33706 m .70577 .33086 L .71271 .34937 L F
.45953 .50594 m .47645 .51902 L .458 .51169 L .761 .442 .445 r
F
.44426 .4987 m .45953 .50594 L .458 .51169 L .806 .49 .456 r
F
.66853 .31777 m .67943 .31922 L .67506 .33127 L .973 .664 .345 r
F
.66853 .31777 m .67136 .30246 L .67943 .31922 L F
.46863 .48584 m .4754 .49445 L .47449 .50099 L .962 .688 .467 r
F
.46891 .48003 m .4754 .49445 L .46863 .48584 L F
.039 .916 .04 r
.45035 .48907 m
.46876 .48316 L
s
.49589 .48298 m .49704 .49243 L .49558 .49055 L .964 .688 .462 r
F
0 g
.49559 .47479 m
.49589 .48298 L
s
.4619 .46809 m .46872 .47376 L .46891 .48003 L .962 .688 .467 r
F
.46141 .46309 m .46872 .47376 L .4619 .46809 L F
.39801 .47796 m .4065 .48846 L .40598 .49163 L .958 .688 .48 r
F
.39813 .47619 m .4065 .48846 L .39801 .47796 L F
.58762 .46428 m .64186 .4829 L .5883 .4762 L .744 .5 .561 r
F
.65382 .45018 m .64186 .4829 L .65478 .46346 L .108 .03 .477 r
F
.5883 .4762 m .64186 .4829 L .64187 .49762 L .741 .474 .525 r
F
.65478 .46346 m .64186 .4829 L .64187 .49762 L .02 0 .385 r
F
0 g
.64078 .46705 m
.64186 .4829 L
s
.46057 .38481 m .46547 .38822 L .46525 .39044 L .964 .688 .462 r
F
0 g
.46525 .39044 m
.46983 .39697 L
s
.46057 .38481 m .4606 .38235 L .46547 .38822 L .964 .688 .462 r
F
.40902 .42311 m .41815 .4123 L .41181 .42573 L .911 .774 .697 r
F
.40902 .42311 m .41445 .40879 L .41815 .4123 L F
.039 .916 .04 r
.22942 .48272 m
.2371 .48038 L
s
.49995 .49617 m .50036 .50602 L .49894 .50386 L .964 .688 .462 r
F
.49849 .4943 m .49995 .49617 L .49894 .50386 L F
.34699 .48097 m .34299 .46418 L .34399 .46413 L .96 .713 .518 r
F
.23596 .60486 m .23547 .62497 L .22887 .59935 L .929 .559 .284 r
F
.23596 .60486 m .24496 .63225 L .23547 .62497 L F
.19235 .49324 m .17963 .47813 L .18 .46702 L .989 .738 .452 r
F
.19275 .50108 m .17963 .47813 L .19235 .49324 L .988 .727 .429 r
F
.42924 .56037 m .46731 .53279 L .42469 .5645 L 0 0 0 r
F
.42924 .56037 m .47096 .52946 L .46731 .53279 L F
.42265 .54497 m .42924 .56037 L .42469 .5645 L .958 .688 .48 r
F
0 g
.42924 .56037 m
.43308 .55471 L
s
.28126 .57837 m .2889 .59526 L .27571 .57509 L .837 .368 .036 r
F
.28126 .57837 m .29629 .59957 L .2889 .59526 L F
.039 .916 .04 r
.47115 .48239 m
.48968 .47637 L
s
.4282 .37336 m .43664 .37648 L .43363 .37748 L .652 .814 .961 r
F
.41777 .3903 m .43363 .37748 L .42233 .39369 L .878 .824 .792 r
F
.41777 .3903 m .4282 .37336 L .43363 .37748 L F
0 g
.43363 .37748 m
.4369 .38068 L
s
.42106 .47325 m .43228 .48235 L .42112 .47641 L .873 .609 .536 r
F
.42112 .47641 m .43228 .48235 L .43203 .48672 L .875 .598 .516 r
F
.039 .916 .04 r
.41016 .48843 m
.42788 .48279 L
s
.48651 .40076 m .49268 .3987 L .48998 .40657 L .965 .687 .457 r
F
.48651 .40076 m .48836 .39146 L .49268 .3987 L F
.19552 .36486 m .19536 .32491 L .20327 .35702 L .975 .76 .548 r
F
.20599 .395 m .19552 .36486 L .20327 .35702 L .971 .746 .541 r
F
.48482 .37446 m .50079 .3692 L .50613 .37699 L .657 .688 .867 r
F
.47932 .36774 m .50079 .3692 L .48482 .37446 L .66 .725 .898 r
F
.47927 .37939 m .48482 .37446 L .48386 .38499 L .965 .687 .457 r
F
.47927 .37939 m .47932 .36774 L .48482 .37446 L F
0 g
.48482 .37446 m
.49019 .38222 L
s
.37622 .63973 m .41373 .56779 L .36705 .64146 L .908 .966 .807 r
F
.37622 .63973 m .41949 .56699 L .41373 .56779 L F
0 g
.37622 .63973 m
.38448 .63542 L
s
.72251 .38282 m .72438 .38744 L .72893 .40644 L .74 .467 0 r
F
.71811 .36736 m .72438 .38744 L .72251 .38282 L .719 .429 0 r
F
.38869 .45228 m .39021 .43937 L .38983 .45332 L .958 .688 .48 r
F
.38869 .45228 m .38794 .43728 L .39021 .43937 L F
.34931 .38963 m .36543 .36808 L .3543 .3896 L .926 .929 .789 r
F
.34363 .40967 m .34931 .38963 L .3543 .3896 L .952 .889 .731 r
F
.45535 .37219 m .46067 .37499 L .46064 .37744 L .964 .688 .462 r
F
.45535 .37219 m .45518 .36955 L .46067 .37499 L F
.50079 .3692 m .54395 .35516 L .50613 .37699 L .749 .72 .824 r
F
.50583 .37778 m .50613 .37699 L .5103 .38429 L .675 .238 0 r
F
.50583 .37778 m .50079 .3692 L .50613 .37699 L F
0 g
.50613 .37699 m
.51128 .38569 L
s
.44435 .41941 m .44894 .41406 L .44701 .42315 L .962 .688 .467 r
F
.44435 .41941 m .44541 .40908 L .44894 .41406 L F
.64994 .38805 m .64163 .39168 L .64585 .40666 L .043 .131 .631 r
F
.64599 .37606 m .64163 .39168 L .64994 .38805 L .059 .174 .671 r
F
.64599 .37606 m .63674 .37684 L .64163 .39168 L F
.71614 .4488 m .72892 .48185 L .71759 .46574 L .981 .691 .367 r
F
.72892 .48185 m .73918 .49775 L .7294 .50068 L .548 .32 .522 r
F
.72892 .48185 m .73865 .47891 L .73918 .49775 L F
.71759 .46574 m .72892 .48185 L .7294 .50068 L .982 .695 .375 r
F
0 g
.72714 .46161 m
.72892 .48185 L
s
.38351 .43464 m .38383 .41996 L .3857 .43569 L .958 .688 .48 r
F
.38351 .43464 m .38055 .41836 L .38383 .41996 L F
.36262 .51196 m .37087 .52762 L .36081 .51271 L .895 .539 .361 r
F
.36262 .51196 m .37356 .52647 L .37087 .52762 L F
.35382 .49678 m .36262 .51196 L .36081 .51271 L .924 .603 .416 r
F
.35382 .49678 m .36081 .51271 L .35291 .49714 L F
.34699 .48097 m .35382 .49678 L .35291 .49714 L .946 .66 .466 r
F
.5938 .45259 m .58762 .46428 L .5883 .4762 L 0 0 .403 r
F
.59254 .44204 m .58762 .46428 L .5938 .45259 L .005 0 .49 r
F
0 g
.58612 .45168 m
.58762 .46428 L
s
.28555 .63374 m .28416 .66092 L .27657 .63072 L .938 .625 .421 r
F
.28555 .63374 m .29537 .66451 L .28416 .66092 L F
.64156 .36437 m .63674 .37684 L .64599 .37606 L .062 .208 .704 r
F
.64156 .36437 m .63125 .36236 L .63674 .37684 L F
.2553 .56387 m .24909 .58394 L .25068 .55917 L .952 .661 .45 r
F
.2553 .56387 m .25608 .59098 L .24909 .58394 L F
.4282 .37336 m .43122 .37236 L .43664 .37648 L .652 .814 .961 r
F
0 g
.43664 .37648 m
.44211 .38183 L
s
.40743 .43858 m .41457 .42893 L .40928 .4407 L .92 .745 .648 r
F
.40743 .43858 m .41181 .42573 L .41457 .42893 L F
.25938 .54706 m .25908 .55809 L .25578 .54255 L .908 .504 .12 r
F
.25938 .54706 m .26453 .56487 L .25908 .55809 L F
.49849 .4943 m .49894 .50386 L .49752 .50171 L .964 .688 .462 r
F
.49704 .49243 m .49849 .4943 L .49752 .50171 L F
.4329 .38564 m .43667 .37685 L .4374 .38903 L .962 .688 .467 r
F
.4329 .38564 m .43127 .37275 L .43667 .37685 L F
.27005 .60053 m .26729 .62551 L .26311 .59654 L .945 .642 .434 r
F
.27005 .60053 m .27657 .63072 L .26729 .62551 L F
.43814 .40127 m .44195 .39345 L .44179 .40479 L .962 .688 .467 r
F
.43814 .40127 m .4374 .38903 L .44195 .39345 L F
.37356 .52647 m .38343 .5418 L .37087 .52762 L .857 .465 .3 r
F
.37356 .52647 m .38699 .54022 L .38343 .5418 L F
.41079 .4061 m .42233 .39369 L .41445 .40879 L .904 .811 .745 r
F
.41079 .4061 m .41777 .3903 L .42233 .39369 L F
.34207 .46453 m .34096 .44676 L .34299 .46418 L .974 .765 .56 r
F
.34699 .48097 m .34207 .46453 L .34299 .46418 L .963 .714 .513 r
F
.70136 .32268 m .70577 .33086 L .70746 .33706 L .714 .362 0 r
F
.70136 .32268 m .69822 .31306 L .70577 .33086 L F
.37741 .41759 m .37761 .40213 L .38055 .41836 L .958 .688 .48 r
F
.37741 .41759 m .37341 .40106 L .37761 .40213 L F
.34699 .48097 m .34125 .46514 L .34207 .46453 L .964 .714 .508 r
F
.34699 .48097 m .34055 .46603 L .34125 .46514 L .966 .714 .502 r
F
.34699 .48097 m .33997 .46716 L .34055 .46603 L .968 .713 .496 r
F
.34699 .48097 m .33953 .46853 L .33997 .46716 L .969 .711 .49 r
F
.34699 .48097 m .33923 .47011 L .33953 .46853 L .97 .709 .483 r
F
.34699 .48097 m .33908 .47188 L .33923 .47011 L .97 .707 .476 r
F
.34699 .48097 m .33908 .47379 L .33908 .47188 L .971 .704 .47 r
F
.34699 .48097 m .33924 .47582 L .33908 .47379 L .971 .701 .464 r
F
.34699 .48097 m .33954 .47794 L .33924 .47582 L .97 .697 .458 r
F
.34699 .48097 m .33999 .48011 L .33954 .47794 L .97 .694 .452 r
F
.34699 .48097 m .34058 .48229 L .33999 .48011 L .969 .69 .448 r
F
.34699 .48097 m .3413 .48444 L .34058 .48229 L .968 .686 .444 r
F
.039 .916 .04 r
.25937 .50902 m
.3408 .48295 L
s
.34699 .48097 m .34212 .48652 L .3413 .48444 L .967 .682 .441 r
F
.34699 .48097 m .34305 .4885 L .34212 .48652 L .965 .679 .439 r
F
.34699 .48097 m .34406 .49035 L .34305 .4885 L .963 .675 .438 r
F
.34699 .48097 m .34514 .49203 L .34406 .49035 L .962 .672 .438 r
F
.34699 .48097 m .34627 .49351 L .34514 .49203 L .96 .669 .439 r
F
.34699 .48097 m .34742 .49477 L .34627 .49351 L .958 .667 .441 r
F
.34699 .48097 m .34858 .49578 L .34742 .49477 L .956 .665 .443 r
F
.34699 .48097 m .34973 .49654 L .34858 .49578 L .954 .663 .447 r
F
.34699 .48097 m .35085 .49702 L .34973 .49654 L .952 .662 .451 r
F
.34699 .48097 m .35191 .49722 L .35085 .49702 L .95 .661 .455 r
F
.34699 .48097 m .35291 .49714 L .35191 .49722 L .948 .66 .461 r
F
.52816 .42545 m .52884 .42583 L .53138 .435 L .762 .467 0 r
F
.52575 .41815 m .52884 .42583 L .52816 .42545 L .749 .432 0 r
F
.52575 .41815 m .52585 .41676 L .52884 .42583 L F
.57205 .45734 m .57982 .46427 L .58045 .47569 L .969 .687 .442 r
F
.57088 .44724 m .57982 .46427 L .57205 .45734 L F
.52301 .41105 m .52585 .41676 L .52575 .41815 L .747 .406 0 r
F
.52301 .41105 m .52244 .40793 L .52585 .41676 L F
.65335 .40016 m .64585 .40666 L .64932 .42156 L .013 .077 .584 r
F
.64994 .38805 m .64585 .40666 L .65335 .40016 L .043 .131 .631 r
F
.41032 .4613 m .41848 .45928 L .41946 .46286 L .91 .67 .563 r
F
.40973 .45952 m .41848 .45928 L .41032 .4613 L .912 .678 .571 r
F
.40973 .45952 m .41731 .45575 L .41848 .45928 L F
.21134 .55681 m .20227 .56385 L .20731 .54979 L .962 .636 .338 r
F
.21134 .55681 m .2084 .57446 L .20227 .56385 L F
.40905 .4578 m .41731 .45575 L .40973 .45952 L .915 .687 .578 r
F
.40905 .4578 m .41596 .45231 L .41731 .45575 L F
.50178 .50817 m .50319 .51032 L .50135 .51782 L .964 .688 .462 r
F
0 g
.50319 .51032 m
.5043 .50177 L
s
.33912 .44742 m .34106 .42863 L .34096 .44676 L .98 .814 .606 r
F
.34207 .46453 m .33912 .44742 L .34096 .44676 L .974 .765 .56 r
F
.45552 .37485 m .46064 .37744 L .46062 .37989 L .964 .688 .462 r
F
.45552 .37485 m .45535 .37219 L .46064 .37744 L F
.39774 .47954 m .40598 .49163 L .40518 .4944 L .958 .688 .48 r
F
.39801 .47796 m .40598 .49163 L .39774 .47954 L F
.039 .916 .04 r
.35922 .49101 m
.39789 .47863 L
s
.41081 .46309 m .41946 .46286 L .42022 .46642 L .909 .662 .554 r
F
.41032 .4613 m .41946 .46286 L .41081 .46309 L .91 .67 .563 r
F
.44426 .4987 m .458 .51169 L .44301 .50328 L .806 .49 .456 r
F
.43142 .49065 m .44426 .4987 L .44301 .50328 L .845 .535 .464 r
F
.43203 .48672 m .44426 .4987 L .43142 .49065 L .842 .55 .495 r
F
.50699 .46267 m .51386 .46855 L .51419 .47665 L .965 .687 .457 r
F
.50627 .4558 m .51386 .46855 L .50699 .46267 L F
.4083 .45616 m .41596 .45231 L .40905 .4578 L .919 .695 .584 r
F
.4083 .45616 m .41446 .44904 L .41596 .45231 L F
.5302 .43282 m .53138 .435 L .53342 .44412 L .784 .51 0 r
F
.52816 .42545 m .53138 .435 L .5302 .43282 L .762 .467 0 r
F
.2371 .48021 m .23085 .46381 L .2318 .45561 L .991 .777 .394 r
F
.23698 .48615 m .23085 .46381 L .2371 .48021 L .979 .749 .336 r
F
.35291 .49714 m .35883 .51289 L .35191 .49722 L .928 .6 .397 r
F
.35291 .49714 m .36081 .51271 L .35883 .51289 L F
.55746 .4165 m .56363 .41524 L .56663 .42602 L .969 .687 .442 r
F
.55463 .40792 m .56363 .41524 L .55746 .4165 L F
.55463 .40792 m .56011 .40457 L .56363 .41524 L F
.23583 .44199 m .23538 .41669 L .2394 .40984 L .991 .875 .541 r
F
.23347 .44829 m .23538 .41669 L .23583 .44199 L .978 .854 .464 r
F
.4619 .46809 m .46891 .48003 L .46204 .47281 L .962 .688 .467 r
F
.46204 .47281 m .46891 .48003 L .46863 .48584 L F
.63671 .35315 m .63125 .36236 L .64156 .36437 L .051 .233 .731 r
F
.63671 .35315 m .62523 .34847 L .63125 .36236 L F
.42265 .54497 m .42469 .5645 L .41883 .54835 L .958 .688 .48 r
F
.41604 .52952 m .42265 .54497 L .41883 .54835 L F
.49704 .49243 m .49752 .50171 L .4961 .49955 L .964 .688 .462 r
F
.49558 .49055 m .49704 .49243 L .4961 .49955 L F
.70265 .42145 m .71362 .43091 L .71614 .4488 L .98 .686 .368 r
F
.69981 .40647 m .71362 .43091 L .70265 .42145 L .979 .683 .362 r
F
.41119 .46488 m .42022 .46642 L .42076 .4699 L .908 .654 .543 r
F
.41081 .46309 m .42022 .46642 L .41119 .46488 L .909 .662 .554 r
F
.55141 .39956 m .56011 .40457 L .55463 .40792 L .969 .687 .442 r
F
.55141 .39956 m .55611 .39417 L .56011 .40457 L F
.22373 .46915 m .20837 .44785 L .21052 .43876 L .967 .715 .504 r
F
.22294 .47593 m .20837 .44785 L .22373 .46915 L .968 .712 .495 r
F
.33425 .62337 m .35711 .64051 L .32585 .62248 L .614 .05 0 r
F
.33425 .62337 m .36705 .64146 L .35711 .64051 L F
.51998 .40426 m .52244 .40793 L .52301 .41105 L .753 .389 0 r
F
.51998 .40426 m .51867 .39949 L .52244 .40793 L F
.38699 .54022 m .39916 .55506 L .38343 .5418 L .805 .376 .226 r
F
.38699 .54022 m .40356 .55303 L .39916 .55506 L F
.42094 .47933 m .43203 .48672 L .43142 .49065 L .877 .588 .494 r
F
.42112 .47641 m .43203 .48672 L .42094 .47933 L .875 .598 .516 r
F
.19275 .50108 m .18021 .48999 L .17963 .47813 L .988 .727 .429 r
F
.039 .916 .04 r
.11385 .50276 m
.17968 .47925 L
s
.19378 .50924 m .18021 .48999 L .19275 .50108 L .986 .714 .407 r
F
.18356 .44776 m .17458 .42127 L .17878 .41093 L .995 .792 .517 r
F
.18132 .45684 m .17458 .42127 L .18356 .44776 L .998 .783 .482 r
F
.53711 .33273 m .58265 .30333 L .5437 .34113 L .83 .766 .791 r
F
.53711 .33273 m .57405 .29199 L .58265 .30333 L F
.59785 .30293 m .58265 .30333 L .60499 .31243 L .151 .453 .882 r
F
.59785 .30293 m .57405 .29199 L .58265 .30333 L F
0 g
.58265 .30333 m
.59106 .31629 L
s
.55699 .34927 m .55014 .35078 L .56236 .35735 L .028 .332 .815 r
F
.55699 .34927 m .5437 .34113 L .55014 .35078 L F
0 g
.55014 .35078 m
.55636 .36153 L
s
.34125 .46514 m .33912 .44742 L .34207 .46453 L .98 .767 .545 r
F
.30344 .60214 m .31698 .61936 L .29629 .59957 L .738 .213 0 r
F
.30344 .60214 m .32585 .62248 L .31698 .61936 L F
.38757 .4515 m .38794 .43728 L .38869 .45228 L .958 .688 .48 r
F
.38757 .4515 m .3857 .43569 L .38794 .43728 L F
.40748 .45462 m .41446 .44904 L .4083 .45616 L .923 .704 .588 r
F
.40748 .45462 m .41282 .44598 L .41446 .44904 L F
.3383 .42958 m .34363 .40967 L .34106 .42863 L .979 .863 .654 r
F
.33912 .44742 m .3383 .42958 L .34106 .42863 L .98 .814 .606 r
F
.50178 .50817 m .50135 .51782 L .49999 .51542 L .964 .688 .462 r
F
.50036 .50602 m .50178 .50817 L .49999 .51542 L F
.4524 .44842 m .45796 .44723 L .45943 .45257 L .962 .688 .467 r
F
.45123 .44489 m .45796 .44723 L .4524 .44842 L F
.45123 .44489 m .45622 .44196 L .45796 .44723 L F
.45569 .3775 m .46062 .37989 L .4606 .38235 L .964 .688 .462 r
F
.45569 .3775 m .45552 .37485 L .46062 .37989 L F
.50079 .3692 m .53772 .34588 L .54395 .35516 L .749 .72 .824 r
F
0 g
.54395 .35516 m
.54995 .36551 L
s
.55987 .42518 m .56663 .42602 L .56906 .43675 L .969 .687 .442 r
F
.55746 .4165 m .56663 .42602 L .55987 .42518 L F
.41139 .51129 m .41604 .52952 L .40942 .51404 L .958 .688 .48 r
F
.4041 .49671 m .41139 .51129 L .40942 .51404 L F
.40518 .4944 m .41139 .51129 L .4041 .49671 L F
.44989 .44145 m .45622 .44196 L .45123 .44489 L .962 .688 .467 r
F
.44989 .44145 m .45421 .43682 L .45622 .44196 L F
.34931 .38963 m .35948 .36802 L .36543 .36808 L .926 .929 .789 r
F
0 g
.36543 .36808 m
.36544 .36808 L
s
.36544 .36808 m .41782 .3691 L .41854 .37036 L .201 .704 .908 r
F
.36448 .38456 m .36544 .36808 L .36942 .38455 L .958 .688 .48 r
F
.36448 .38456 m .35949 .36802 L .36544 .36808 L F
.35949 .36802 m .41782 .3691 L .36544 .36808 L .021 0 0 r
F
.4134 .36902 m .41305 .36905 L .41782 .3691 L F
.35949 .36802 m .41305 .36905 L .4134 .36902 L F
.34471 .39107 m .35948 .36802 L .34931 .38963 L .936 .959 .758 r
F
.34471 .39107 m .354 .36966 L .35948 .36802 L F
.35992 .38599 m .35949 .36802 L .36448 .38456 L .958 .688 .48 r
F
.35992 .38599 m .354 .36967 L .35949 .36802 L F
.40858 .3691 m .40868 .37043 L .41305 .36905 L .246 0 0 r
F
.354 .36967 m .40868 .37043 L .40858 .3691 L F
.40142 .38805 m .40868 .37043 L .41305 .36905 L .941 .959 .743 r
F
.39816 .39042 m .40868 .37043 L .40142 .38805 L .928 .966 .674 r
F
.39816 .39042 m .40478 .37321 L .40868 .37043 L F
.40478 .37321 m .40872 .37105 L .40868 .37043 L .017 0 0 r
F
.354 .36967 m .41305 .36905 L .35949 .36802 L .246 0 0 r
F
.40868 .37043 m .41173 .3694 L .4161 .36803 L .238 .743 .688 r
F
.40872 .37105 m .41173 .3694 L .40868 .37043 L .017 0 0 r
F
.40868 .37043 m .41288 .36907 L .41305 .36905 L .238 .743 .688 r
F
.41288 .36907 m .4161 .36803 L .41305 .36905 L F
.41305 .36905 m .41748 .3685 L .41782 .3691 L .454 .881 .907 r
F
.41748 .3685 m .42086 .36809 L .41782 .3691 L F
.41854 .37036 m .41782 .3691 L .4229 .37055 L .201 .704 .908 r
F
0 g
.35949 .36802 m
.36543 .36808 L
s
.35949 .36802 m
.36544 .36808 L
s
.53587 .46164 m .53712 .47908 L .53624 .46975 L .762 .587 .015 r
F
.53712 .47908 m .58051 .48659 L .53686 .48806 L .656 .403 .525 r
F
.53712 .47908 m .58069 .47596 L .58051 .48659 L F
0 g
.58005 .46448 m
.58069 .47596 L
s
.53624 .46975 m .53712 .47908 L .53686 .48806 L .828 .667 .122 r
F
0 g
.53668 .46937 m
.53712 .47908 L
s
.41146 .46663 m .42076 .4699 L .42106 .47325 L .908 .647 .532 r
F
.41119 .46488 m .42076 .4699 L .41146 .46663 L .908 .654 .543 r
F
.53678 .35857 m .54389 .35549 L .54197 .36627 L .969 .687 .442 r
F
.53678 .35857 m .5377 .34625 L .54389 .35549 L F
.4829 .39558 m .48836 .39146 L .48651 .40076 L .965 .687 .457 r
F
.4829 .39558 m .48386 .38499 L .48836 .39146 L F
.72619 .39818 m .72893 .40644 L .73253 .42504 L .769 .512 0 r
F
.72251 .38282 m .72893 .40644 L .72619 .39818 L .74 .467 0 r
F
.45338 .452 m .45943 .45257 L .46059 .45789 L .962 .688 .467 r
F
.4524 .44842 m .45943 .45257 L .45338 .452 L F
.73512 .44296 m .73865 .47891 L .73664 .45993 L .723 .535 0 r
F
.73664 .45993 m .73865 .47891 L .73918 .49775 L .786 .61 .046 r
F
0 g
.73683 .45866 m
.73865 .47891 L
s
.52078 .49305 m .5359 .49618 L .51977 .50116 L .509 .243 .446 r
F
.52078 .49305 m .53686 .48806 L .5359 .49618 L F
.51392 .48414 m .52078 .49305 L .51977 .50116 L .965 .687 .457 r
F
.51419 .47665 m .52078 .49305 L .51392 .48414 L F
0 g
.52078 .49305 m
.52108 .48407 L
s
.40626 .42112 m .41445 .40879 L .40902 .42311 L .925 .794 .697 r
F
.40626 .42112 m .41079 .4061 L .41445 .40879 L F
.38945 .46737 m .39656 .46583 L .39715 .46799 L .958 .688 .48 r
F
.38945 .46737 m .39585 .46369 L .39656 .46583 L F
.53184 .44015 m .53342 .44412 L .53493 .45305 L .814 .56 .003 r
F
.5302 .43282 m .53342 .44412 L .53184 .44015 L .784 .51 0 r
F
.36081 .51271 m .36791 .52794 L .35883 .51289 L .9 .53 .325 r
F
.36081 .51271 m .37087 .52762 L .36791 .52794 L F
.38945 .46737 m .39503 .46161 L .39585 .46369 L .958 .688 .48 r
F
.44162 .4162 m .44541 .40908 L .44435 .41941 L .962 .688 .467 r
F
.44162 .4162 m .44179 .40479 L .44541 .40908 L F
.54787 .39156 m .55611 .39417 L .55141 .39956 L .969 .687 .442 r
F
.54787 .39156 m .55171 .38422 L .55611 .39417 L F
.40556 .43684 m .41181 .42573 L .40743 .43858 L .93 .759 .648 r
F
.40556 .43684 m .40902 .42311 L .41181 .42573 L F
.35191 .49722 m .3567 .51251 L .35085 .49702 L .933 .599 .378 r
F
.35191 .49722 m .35883 .51289 L .3567 .51251 L F
.27983 .66908 m .28604 .69311 L .26855 .66553 L .869 .44 .185 r
F
.27983 .66908 m .29952 .69718 L .28604 .69311 L F
.38945 .46737 m .39715 .46799 L .3976 .47015 L .958 .688 .48 r
F
.4484 .43817 m .45421 .43682 L .44989 .44145 L .962 .688 .467 r
F
.4484 .43817 m .45198 .43193 L .45421 .43682 L F
.4066 .45322 m .41282 .44598 L .40748 .45462 L .928 .713 .591 r
F
.4066 .45322 m .41109 .44319 L .41282 .44598 L F
.49558 .49055 m .4961 .49955 L .49467 .49739 L .964 .688 .462 r
F
0 g
.49558 .49055 m
.49589 .48298 L
s
.38945 .46737 m .39411 .45963 L .39503 .46161 L .958 .688 .48 r
F
.25578 .54255 m .25388 .55034 L .25233 .53741 L .905 .509 .095 r
F
.25578 .54255 m .25908 .55809 L .25388 .55034 L F
.47645 .51902 m .47707 .5239 L .47402 .52484 L .403 .042 .234 r
F
.47645 .51902 m .47949 .51808 L .47707 .5239 L F
0 g
.47949 .51808 m
.48125 .51117 L
s
.458 .51169 m .47645 .51902 L .47402 .52484 L .76 .409 .39 r
F
0 g
.47645 .51902 m
.47797 .5131 L
s
.20731 .54979 m .19669 .55238 L .20363 .54222 L .967 .647 .34 r
F
.20731 .54979 m .20227 .56385 L .19669 .55238 L F
.65616 .41218 m .64932 .42156 L .65199 .43614 L 0 .009 .527 r
F
.65335 .40016 m .64932 .42156 L .65616 .41218 L .013 .077 .584 r
F
.38945 .46737 m .3976 .47015 L .39792 .47226 L .958 .688 .48 r
F
.50036 .50602 m .49999 .51542 L .49863 .51301 L .964 .688 .462 r
F
.49894 .50386 m .50036 .50602 L .49863 .51301 L F
.21354 .43096 m .20082 .40344 L .20599 .395 L .969 .732 .523 r
F
.21052 .43876 m .20082 .40344 L .21354 .43096 L .972 .73 .512 r
F
.47449 .50099 m .4793 .51775 L .47301 .50671 L .962 .688 .467 r
F
.46789 .49106 m .47449 .50099 L .47301 .50671 L F
.46863 .48584 m .47449 .50099 L .46789 .49106 L F
.34125 .46514 m .33748 .44863 L .33912 .44742 L .98 .767 .545 r
F
.34055 .46603 m .33748 .44863 L .34125 .46514 L .985 .767 .527 r
F
.49591 .43515 m .50145 .43399 L .50347 .44134 L .965 .687 .457 r
F
.4941 .42968 m .50145 .43399 L .49591 .43515 L F
.4941 .42968 m .49904 .42672 L .50145 .43399 L F
.38945 .46737 m .39312 .45778 L .39411 .45963 L .958 .688 .48 r
F
.25432 .6374 m .25685 .65921 L .24496 .63225 L .902 .499 .225 r
F
.25432 .6374 m .26855 .66553 L .25685 .65921 L F
.45416 .45556 m .46059 .45789 L .46141 .46309 L .962 .688 .467 r
F
.45338 .452 m .46059 .45789 L .45416 .45556 L F
.44938 .36254 m .45484 .36426 L .45501 .3669 L .964 .688 .462 r
F
.44938 .36254 m .44902 .35974 L .45484 .36426 L F
0 g
.45484 .36426 m
.46071 .37009 L
s
.39733 .48092 m .40518 .4944 L .4041 .49671 L .958 .688 .48 r
F
.39774 .47954 m .40518 .4944 L .39733 .48092 L F
.51671 .3979 m .51867 .39949 L .51998 .40426 L .768 .382 0 r
F
.51671 .3979 m .5146 .39156 L .51867 .39949 L F
.49203 .42435 m .49904 .42672 L .4941 .42968 L .965 .687 .457 r
F
.49203 .42435 m .4963 .41966 L .49904 .42672 L F
.45586 .38016 m .4606 .38235 L .46057 .38481 L .964 .688 .462 r
F
0 g
.46057 .38481 m
.46525 .39044 L
s
.45586 .38016 m .45569 .3775 L .4606 .38235 L .964 .688 .462 r
F
.458 .51169 m .47402 .52484 L .45593 .51652 L .76 .409 .39 r
F
.44301 .50328 m .458 .51169 L .45593 .51652 L .808 .467 .411 r
F
.41161 .46831 m .42106 .47325 L .42112 .47641 L .908 .64 .519 r
F
.41146 .46663 m .42106 .47325 L .41161 .46831 L .908 .647 .532 r
F
.18018 .37017 m .17929 .33644 L .18874 .32724 L .991 .865 .608 r
F
.17929 .33644 m .19536 .32491 L .18874 .32724 L .153 0 0 r
F
0 g
.18874 .32724 m
.19939 .32127 L
s
.64274 .23738 m .66299 .24891 L .65335 .25218 L .664 .72 .891 r
F
.64524 .26058 m .65335 .25218 L .65413 .2729 L .969 .652 .338 r
F
.64524 .26058 m .64274 .23738 L .65335 .25218 L F
0 g
.65335 .25218 m
.66377 .26899 L
s
.38945 .46737 m .39792 .47226 L .3981 .47428 L .958 .688 .48 r
F
.66169 .30529 m .67136 .30246 L .66853 .31777 L .972 .662 .346 r
F
.66169 .30529 m .66288 .28694 L .67136 .30246 L F
.19378 .50924 m .18175 .50236 L .18021 .48999 L .986 .714 .407 r
F
.19541 .51759 m .18175 .50236 L .19378 .50924 L .983 .7 .387 r
F
.33748 .44863 m .3383 .42958 L .33912 .44742 L .989 .82 .582 r
F
.49744 .44069 m .50347 .44134 L .50509 .44864 L .965 .687 .457 r
F
.49591 .43515 m .50347 .44134 L .49744 .44069 L F
.44678 .43511 m .45198 .43193 L .4484 .43817 L .962 .688 .467 r
F
.44678 .43511 m .44957 .42734 L .45198 .43193 L F
.38142 .43415 m .38055 .41836 L .38351 .43464 L .958 .688 .48 r
F
.38142 .43415 m .37741 .41759 L .38055 .41836 L F
.56182 .4338 m .56906 .43675 L .57088 .44724 L .969 .687 .442 r
F
.55987 .42518 m .56906 .43675 L .56182 .4338 L F
.38945 .46737 m .39206 .4561 L .39312 .45778 L .958 .688 .48 r
F
.33994 .41088 m .34931 .38963 L .34363 .40967 L .967 .912 .704 r
F
.3383 .42958 m .33994 .41088 L .34363 .40967 L .979 .863 .654 r
F
.23698 .48615 m .23065 .47276 L .23085 .46381 L .979 .749 .336 r
F
.23735 .49246 m .23065 .47276 L .23698 .48615 L .964 .716 .278 r
F
.20082 .40344 m .19552 .36486 L .20599 .395 L .975 .745 .527 r
F
.41604 .52952 m .41883 .54835 L .41297 .53219 L .958 .688 .48 r
F
.40942 .51404 m .41604 .52952 L .41297 .53219 L F
.40356 .55303 m .41949 .56699 L .39916 .55506 L .728 .258 .132 r
F
.40356 .55303 m .42469 .5645 L .41949 .56699 L F
0 g
.42469 .5645 m
.4247 .56449 L
s
.25068 .55917 m .24227 .57554 L .24618 .55357 L .954 .665 .448 r
F
.25068 .55917 m .24909 .58394 L .24227 .57554 L F
.47301 .50671 m .4793 .51775 L .47689 .52354 L .962 .688 .467 r
F
.4057 .45198 m .41109 .44319 L .4066 .45322 L .934 .721 .592 r
F
.4057 .45198 m .40928 .4407 L .41109 .44319 L F
.69486 .3091 m .69822 .31306 L .70136 .32268 L .73 .357 0 r
F
.69486 .3091 m .69017 .29623 L .69822 .31306 L F
.35085 .49702 m .35447 .51156 L .34973 .49654 L .938 .598 .36 r
F
.35085 .49702 m .3567 .51251 L .35447 .51156 L F
.48974 .41927 m .4963 .41966 L .49203 .42435 L .965 .687 .457 r
F
.48974 .41927 m .49327 .4129 L .4963 .41966 L F
.36947 .40111 m .36942 .38455 L .37341 .40106 L .958 .688 .48 r
F
.36947 .40111 m .36448 .38456 L .36942 .38455 L F
.49532 .36245 m .53772 .34588 L .50079 .3692 L .761 .755 .847 r
F
.47932 .36774 m .49532 .36245 L .50079 .3692 L .66 .725 .898 r
F
.50127 .37215 m .50079 .3692 L .50583 .37778 L .725 .266 0 r
F
.50127 .37215 m .49532 .36245 L .50079 .3692 L F
0 g
.50079 .3692 m
.50613 .37699 L
s
.49894 .50386 m .49863 .51301 L .49727 .5106 L .964 .688 .462 r
F
.49752 .50171 m .49894 .50386 L .49727 .5106 L F
.38945 .46737 m .3981 .47428 L .39813 .47619 L .958 .688 .48 r
F
.63152 .34259 m .62523 .34847 L .63671 .35315 L .025 .25 .752 r
F
.63152 .34259 m .61879 .33539 L .62523 .34847 L F
.38647 .45098 m .3857 .43569 L .38757 .4515 L .958 .688 .48 r
F
.38647 .45098 m .38351 .43464 L .3857 .43569 L F
.44974 .36534 m .45501 .3669 L .45518 .36955 L .964 .688 .462 r
F
.44974 .36534 m .44938 .36254 L .45501 .3669 L F
.43142 .49065 m .44301 .50328 L .43046 .49408 L .845 .535 .464 r
F
.42052 .48195 m .43142 .49065 L .43046 .49408 L .88 .577 .47 r
F
.42094 .47933 m .43142 .49065 L .42052 .48195 L .877 .588 .494 r
F
.25138 .37435 m .26709 .34088 L .27521 .33595 L .912 .98 .725 r
F
.27521 .33595 m .354 .36966 L .35948 .36802 L .651 .13 0 r
F
0 g
.35948 .36802 m
.35949 .36802 L
s
.26709 .34088 m .354 .36966 L .27521 .33595 L .69 .226 .144 r
F
0 g
.27521 .33595 m
.28417 .33364 L
s
.20363 .54222 m .19176 .54027 L .20039 .53423 L .971 .659 .346 r
F
.20363 .54222 m .19669 .55238 L .19176 .54027 L F
.38945 .46737 m .39096 .4546 L .39206 .4561 L .958 .688 .48 r
F
.45471 .45904 m .46141 .46309 L .4619 .46809 L .962 .688 .467 r
F
.45416 .45556 m .46141 .46309 L .45471 .45904 L F
.34055 .46603 m .33606 .45038 L .33748 .44863 L .985 .767 .527 r
F
.33997 .46716 m .33606 .45038 L .34055 .46603 L .989 .764 .507 r
F
.37087 .52762 m .37951 .54226 L .36791 .52794 L .859 .444 .239 r
F
.37087 .52762 m .38343 .5418 L .37951 .54226 L F
.46182 .47716 m .46863 .48584 L .46789 .49106 L .962 .688 .467 r
F
.46204 .47281 m .46863 .48584 L .46182 .47716 L F
.50699 .46267 m .51419 .47665 L .50725 .46917 L .965 .687 .457 r
F
.50725 .46917 m .51419 .47665 L .51392 .48414 L F
.47379 .36218 m .49532 .36245 L .47932 .36774 L .66 .767 .929 r
F
.47464 .37477 m .47932 .36774 L .47927 .37939 L .965 .687 .457 r
F
.47464 .37477 m .47379 .36218 L .47932 .36774 L F
0 g
.47932 .36774 m
.48482 .37446 L
s
.54406 .38406 m .55171 .38422 L .54787 .39156 L .969 .687 .442 r
F
.54406 .38406 m .54697 .37487 L .55171 .38422 L F
.53305 .44733 m .53493 .45305 L .53587 .46164 L .849 .613 .071 r
F
.53184 .44015 m .53493 .45305 L .53305 .44733 L .814 .56 .003 r
F
.49865 .44619 m .50509 .44864 L .50627 .4558 L .965 .687 .457 r
F
.49744 .44069 m .50509 .44864 L .49865 .44619 L F
.41161 .46831 m .42112 .47641 L .41164 .46989 L .908 .64 .519 r
F
.41164 .46989 m .42112 .47641 L .42094 .47933 L .909 .633 .505 r
F
.58898 .40655 m .5849 .40859 L .58805 .41986 L 0 .003 .558 r
F
.58601 .39756 m .5849 .40859 L .58898 .40655 L 0 .049 .6 r
F
.58601 .39756 m .58122 .39743 L .5849 .40859 L F
.27571 .57509 m .28141 .58926 L .2701 .57057 L .817 .341 0 r
F
.27571 .57509 m .2889 .59526 L .28141 .58926 L F
.19541 .51759 m .18422 .51502 L .18175 .50236 L .983 .7 .387 r
F
.19763 .52597 m .18422 .51502 L .19541 .51759 L .98 .686 .37 r
F
.43453 .39858 m .4374 .38903 L .43814 .40127 L .962 .688 .467 r
F
.43453 .39858 m .4329 .38564 L .4374 .38903 L F
.2394 .40984 m .24539 .38076 L .25138 .37435 L .963 .934 .619 r
F
.23538 .41669 m .24539 .38076 L .2394 .40984 L .933 .908 .518 r
F
.44301 .50328 m .45593 .51652 L .44131 .50713 L .808 .467 .411 r
F
.43046 .49408 m .44301 .50328 L .44131 .50713 L .849 .519 .428 r
F
.58266 .3888 m .58122 .39743 L .58601 .39756 L 0 .084 .633 r
F
.58266 .3888 m .57706 .38656 L .58122 .39743 L F
.5938 .45259 m .5883 .4762 L .59439 .46256 L 0 0 .403 r
F
.5883 .4762 m .64187 .49762 L .58814 .48724 L .741 .474 .525 r
F
.59439 .46256 m .5883 .4762 L .58814 .48724 L 0 0 .291 r
F
0 g
.58762 .46428 m
.5883 .4762 L
s
.38945 .46737 m .39813 .47619 L .39801 .47796 L .958 .688 .48 r
F
.44507 .4323 m .44957 .42734 L .44678 .43511 L .962 .688 .467 r
F
.44507 .4323 m .44701 .42315 L .44957 .42734 L F
.25233 .53741 m .24901 .54176 L .24911 .53174 L .902 .518 .08 r
F
.25233 .53741 m .25388 .55034 L .24901 .54176 L F
.22294 .47593 m .20712 .45805 L .20837 .44785 L .968 .712 .495 r
F
.22276 .48332 m .20712 .45805 L .22294 .47593 L .968 .709 .487 r
F
.49752 .50171 m .49727 .5106 L .49591 .5082 L .964 .688 .462 r
F
.4961 .49955 m .49752 .50171 L .49591 .5082 L F
.4229 .37055 m .43122 .37236 L .4282 .37336 L .63 .862 .986 r
F
.41333 .388 m .4282 .37336 L .41777 .3903 L .897 .859 .796 r
F
.41333 .388 m .4229 .37055 L .4282 .37336 L F
0 g
.4282 .37336 m
.43168 .37601 L
s
.4501 .36815 m .45518 .36955 L .45535 .37219 L .964 .688 .462 r
F
.4501 .36815 m .44974 .36534 L .45518 .36955 L F
.20039 .53423 m .18758 .52774 L .19763 .52597 L .976 .672 .356 r
F
.20039 .53423 m .19176 .54027 L .18758 .52774 L F
.34973 .49654 m .35217 .51007 L .34858 .49578 L .942 .599 .342 r
F
.34973 .49654 m .35447 .51156 L .35217 .51007 L F
.35883 .51289 m .36473 .52739 L .3567 .51251 L .905 .522 .286 r
F
.35883 .51289 m .36791 .52794 L .36473 .52739 L F
.38945 .46737 m .38983 .45332 L .39096 .4546 L .958 .688 .48 r
F
.48727 .4145 m .49327 .4129 L .48974 .41927 L .965 .687 .457 r
F
.48727 .4145 m .48998 .40657 L .49327 .4129 L F
.40477 .45092 m .40928 .4407 L .4057 .45198 L .94 .73 .592 r
F
.40477 .45092 m .40743 .43858 L .40928 .4407 L F
.40722 .4043 m .41777 .3903 L .41079 .4061 L .922 .838 .744 r
F
.40722 .4043 m .41333 .388 L .41777 .3903 L F
.40372 .43552 m .40902 .42311 L .40556 .43684 L .941 .773 .645 r
F
.40372 .43552 m .40626 .42112 L .40902 .42311 L F
.19763 .52597 m .18758 .52774 L .18422 .51502 L .98 .686 .37 r
F
.57205 .45734 m .58045 .47569 L .57256 .46688 L .969 .687 .442 r
F
.57256 .46688 m .58045 .47569 L .58027 .48627 L F
.19552 .36486 m .18596 .3341 L .19536 .32491 L .975 .76 .548 r
F
.17929 .33644 m .18596 .3341 L .19536 .32491 L .153 0 0 r
F
0 g
.19536 .32491 m
.20597 .31895 L
s
.59152 .41563 m .58805 .41986 L .59061 .43107 L 0 0 .505 r
F
.58898 .40655 m .58805 .41986 L .59152 .41563 L 0 .003 .558 r
F
.22887 .59935 m .22602 .61568 L .22182 .59237 L .934 .562 .262 r
F
.22887 .59935 m .23547 .62497 L .22602 .61568 L F
.51325 .39206 m .5146 .39156 L .51671 .3979 L .789 .382 0 r
F
.51325 .39206 m .5103 .38429 L .5146 .39156 L F
.24539 .38076 m .26709 .34088 L .25138 .37435 L .863 .956 .612 r
F
.33997 .46716 m .33489 .45264 L .33606 .45038 L .989 .764 .507 r
F
.33953 .46853 m .33489 .45264 L .33997 .46716 L .991 .76 .484 r
F
.4041 .49671 m .40942 .51404 L .40278 .49852 L .958 .688 .48 r
F
.39679 .48207 m .4041 .49671 L .40278 .49852 L F
.39733 .48092 m .4041 .49671 L .39679 .48207 L F
.23735 .49246 m .2312 .4823 L .23065 .47276 L .964 .716 .278 r
F
.23822 .49904 m .2312 .4823 L .23735 .49246 L .948 .68 .223 r
F
.43888 .41357 m .44179 .40479 L .44162 .4162 L .962 .688 .467 r
F
.43888 .41357 m .43814 .40127 L .44179 .40479 L F
.37446 .41766 m .37341 .40106 L .37741 .41759 L .958 .688 .48 r
F
.37446 .41766 m .36947 .40111 L .37341 .40106 L F
.38945 .46737 m .39801 .47796 L .39774 .47954 L F
.47921 .39111 m .48386 .38499 L .4829 .39558 L .965 .687 .457 r
F
.47921 .39111 m .47927 .37939 L .48386 .38499 L F
.57898 .38041 m .57706 .38656 L .58266 .3888 L 0 .106 .656 r
F
.57898 .38041 m .57248 .37615 L .57706 .38656 L F
.33582 .43137 m .33994 .41088 L .3383 .42958 L .989 .873 .62 r
F
.33748 .44863 m .33582 .43137 L .3383 .42958 L .989 .82 .582 r
F
.45503 .46238 m .4619 .46809 L .46204 .47281 L .962 .688 .467 r
F
.45471 .45904 m .4619 .46809 L .45503 .46238 L F
.40942 .51404 m .41297 .53219 L .4071 .51601 L .958 .688 .48 r
F
.40278 .49852 m .40942 .51404 L .4071 .51601 L F
.4229 .37055 m .42593 .36954 L .43122 .37236 L .63 .862 .986 r
F
0 g
.43122 .37236 m
.43664 .37648 L
s
.56328 .44224 m .57088 .44724 L .57205 .45734 L .969 .687 .442 r
F
.56182 .4338 m .57088 .44724 L .56328 .44224 L F
.64274 .23738 m .65243 .23407 L .66299 .24891 L .664 .72 .891 r
F
.66421 .25416 m .66299 .24891 L .67304 .26655 L .698 .259 0 r
F
.66421 .25416 m .65243 .23407 L .66299 .24891 L F
0 g
.66299 .24891 m
.67338 .26575 L
s
.42851 .38333 m .43127 .37275 L .4329 .38564 L .962 .688 .467 r
F
.42851 .38333 m .426 .36994 L .43127 .37275 L F
.45047 .37096 m .45535 .37219 L .45552 .37485 L .964 .688 .462 r
F
.45047 .37096 m .4501 .36815 L .45535 .37219 L F
.4961 .49955 m .49591 .5082 L .49454 .50579 L F
.49467 .49739 m .4961 .49955 L .49454 .50579 L F
.38945 .46737 m .38869 .45228 L .38983 .45332 L .958 .688 .48 r
F
.41154 .47135 m .42094 .47933 L .42052 .48195 L .911 .626 .491 r
F
.41164 .46989 m .42094 .47933 L .41154 .47135 L .909 .633 .505 r
F
.039 .916 .04 r
.39989 .47799 m
.41349 .47365 L
s
.33606 .45038 m .33582 .43137 L .33748 .44863 L .996 .821 .551 r
F
.65833 .42395 m .65199 .43614 L .65382 .45018 L 0 0 .456 r
F
.65616 .41218 m .65199 .43614 L .65833 .42395 L 0 .009 .527 r
F
.49954 .45158 m .50627 .4558 L .50699 .46267 L .965 .687 .457 r
F
.49865 .44619 m .50627 .4558 L .49954 .45158 L F
.33994 .41088 m .34471 .39107 L .34931 .38963 L .967 .912 .704 r
F
.34858 .49578 m .34984 .50804 L .34742 .49477 L .946 .601 .326 r
F
.34858 .49578 m .35217 .51007 L .34984 .50804 L F
.40358 .41979 m .41079 .4061 L .40626 .42112 L .94 .814 .693 r
F
.40358 .41979 m .40722 .4043 L .41079 .4061 L F
.58814 .48724 m .64187 .49762 L .64079 .51096 L .738 .444 .482 r
F
.65483 .47577 m .64187 .49762 L .64079 .51096 L 0 0 .262 r
F
.65478 .46346 m .64187 .49762 L .65483 .47577 L .02 0 .385 r
F
0 g
.64186 .4829 m
.64187 .49762 L
s
.38543 .45075 m .38351 .43464 L .38647 .45098 L .958 .688 .48 r
F
.38543 .45075 m .38142 .43415 L .38351 .43464 L F
.72909 .41319 m .73253 .42504 L .73512 .44296 L .803 .561 0 r
F
.72619 .39818 m .73253 .42504 L .72909 .41319 L .769 .512 0 r
F
.44328 .42981 m .44701 .42315 L .44507 .4323 L .962 .688 .467 r
F
.44328 .42981 m .44435 .41941 L .44701 .42315 L F
.24911 .53174 m .24456 .53251 L .24618 .52562 L .901 .532 .075 r
F
.24911 .53174 m .24901 .54176 L .24456 .53251 L F
.17878 .41093 m .17353 .38059 L .18018 .37017 L .997 .83 .554 r
F
.17458 .42127 m .17353 .38059 L .17878 .41093 L 1 .823 .51 r
F
.23347 .44829 m .23221 .42506 L .23538 .41669 L .978 .854 .464 r
F
.2318 .45561 m .23221 .42506 L .23347 .44829 L .95 .814 .369 r
F
.33953 .46853 m .33399 .45537 L .33489 .45264 L .991 .76 .484 r
F
.33923 .47011 m .33399 .45537 L .33953 .46853 L .993 .753 .46 r
F
.38945 .46737 m .39774 .47954 L .39733 .48092 L .958 .688 .48 r
F
.40383 .45006 m .40743 .43858 L .40477 .45092 L .946 .738 .59 r
F
.40383 .45006 m .40556 .43684 L .40743 .43858 L F
.38343 .5418 m .39431 .55568 L .37951 .54226 L .798 .334 .133 r
F
.38343 .5418 m .39916 .55506 L .39431 .55568 L F
.53686 .48806 m .57952 .4962 L .5359 .49618 L .644 .359 .472 r
F
.53686 .48806 m .58051 .48659 L .57952 .4962 L F
0 g
.58051 .48659 m
.58069 .47596 L
s
.53602 .47725 m .53686 .48806 L .5359 .49618 L .889 .739 .231 r
F
.53624 .46975 m .53686 .48806 L .53602 .47725 L .828 .667 .122 r
F
0 g
.53686 .48806 m
.53712 .47908 L
s
.5515 .34226 m .5437 .34113 L .55699 .34927 L 0 .315 .803 r
F
.5515 .34226 m .53711 .33273 L .5437 .34113 L F
0 g
.5437 .34113 m
.55014 .35078 L
s
.49999 .51542 m .50135 .51782 L .4988 .52413 L .964 .688 .462 r
F
0 g
.50135 .51782 m
.50319 .51032 L
s
.24618 .55357 m .23575 .56592 L .24187 .54719 L .957 .668 .447 r
F
.24618 .55357 m .24227 .57554 L .23575 .56592 L F
.43046 .49408 m .44131 .50713 L .42916 .49696 L .849 .519 .428 r
F
.41987 .48423 m .43046 .49408 L .42916 .49696 L .884 .567 .444 r
F
.42052 .48195 m .43046 .49408 L .41987 .48423 L .88 .577 .47 r
F
.59358 .42466 m .59061 .43107 L .59254 .44204 L 0 0 .439 r
F
.59152 .41563 m .59061 .43107 L .59358 .42466 L 0 0 .505 r
F
.48465 .41014 m .48998 .40657 L .48727 .4145 L .965 .687 .457 r
F
.48465 .41014 m .48651 .40076 L .48998 .40657 L F
.45083 .37377 m .45552 .37485 L .45569 .3775 L .964 .688 .462 r
F
.45083 .37377 m .45047 .37096 L .45552 .37485 L F
.29537 .66451 m .29285 .69113 L .28416 .66092 L .934 .609 .399 r
F
.29537 .66451 m .3063 .69523 L .29285 .69113 L F
.26311 .59654 m .25787 .61818 L .25608 .59098 L .948 .645 .428 r
F
.26311 .59654 m .26729 .62551 L .25787 .61818 L F
.49532 .36245 m .53137 .33781 L .53772 .34588 L .761 .755 .847 r
F
0 g
.53772 .34588 m
.54395 .35516 L
s
.41883 .54835 m .42469 .5645 L .41949 .56699 L .958 .688 .48 r
F
.42469 .5645 m .46314 .53475 L .41949 .56699 L .565 .92 .736 r
F
.46374 .53544 m .46731 .53279 L .46314 .53475 L F
.45024 .52309 m .46731 .53279 L .46314 .53475 L .735 .261 .121 r
F
.46731 .53279 m .46622 .53381 L .46314 .53475 L 0 0 0 r
F
.46314 .53475 m .46622 .53381 L .46268 .53422 L .341 .821 .822 r
F
.45024 .52309 m .46314 .53475 L .44672 .52469 L .735 .261 .121 r
F
.44672 .52469 m .46314 .53475 L .45851 .5353 L .703 .182 0 r
F
.46314 .53475 m .46268 .53422 L .46159 .53435 L .341 .821 .822 r
F
.42469 .5645 m .46374 .53544 L .46314 .53475 L .565 .92 .736 r
F
.54003 .37716 m .54697 .37487 L .54406 .38406 L .969 .687 .442 r
F
.54003 .37716 m .54197 .36627 L .54697 .37487 L F
.70466 .43586 m .71614 .4488 L .71759 .46574 L .981 .69 .374 r
F
.70265 .42145 m .71614 .4488 L .70466 .43586 L .98 .686 .368 r
F
.23822 .49904 m .23251 .49225 L .2312 .4823 L .948 .68 .223 r
F
.23956 .50577 m .23251 .49225 L .23822 .49904 L .932 .644 .173 r
F
.49467 .49739 m .49454 .50579 L .49317 .50337 L .964 .688 .462 r
F
0 g
.49467 .49739 m
.49558 .49055 L
s
.38945 .46737 m .38757 .4515 L .38869 .45228 L .958 .688 .48 r
F
.53381 .45422 m .53587 .46164 L .53624 .46975 L .887 .666 .147 r
F
.53305 .44733 m .53587 .46164 L .53381 .45422 L .849 .613 .071 r
F
.17353 .38059 m .17929 .33644 L .18018 .37017 L .996 .863 .559 r
F
.53149 .35189 m .5377 .34625 L .53678 .35857 L .969 .687 .442 r
F
.53149 .35189 m .53137 .33822 L .5377 .34625 L F
.34742 .49477 m .34753 .50553 L .34627 .49351 L .95 .604 .312 r
F
.34742 .49477 m .34984 .50804 L .34753 .50553 L F
.37945 .43423 m .37741 .41759 L .38142 .43415 L .958 .688 .48 r
F
.37945 .43423 m .37446 .41766 L .37741 .41759 L F
.18132 .45684 m .17154 .43336 L .17458 .42127 L .998 .783 .482 r
F
.18 .46702 m .17154 .43336 L .18132 .45684 L .997 .77 .445 r
F
.47301 .50671 m .47689 .52354 L .47098 .51152 L .962 .688 .467 r
F
.46669 .49563 m .47301 .50671 L .47098 .51152 L F
.46789 .49106 m .47301 .50671 L .46669 .49563 L F
.51977 .50116 m .53425 .50329 L .51808 .50827 L .467 .158 .358 r
F
.51977 .50116 m .5359 .49618 L .53425 .50329 L F
.51307 .49089 m .51977 .50116 L .51808 .50827 L .965 .687 .457 r
F
.51392 .48414 m .51977 .50116 L .51307 .49089 L F
0 g
.51977 .50116 m
.52078 .49305 L
s
.3567 .51251 m .36139 .526 L .35447 .51156 L .908 .514 .245 r
F
.3567 .51251 m .36473 .52739 L .36139 .526 L F
.33923 .47011 m .33339 .45853 L .33399 .45537 L .993 .753 .46 r
F
.33908 .47188 m .33339 .45853 L .33923 .47011 L .992 .743 .435 r
F
.24618 .52562 m .24062 .52275 L .24358 .51918 L .903 .553 .082 r
F
.24618 .52562 m .24456 .53251 L .24062 .52275 L F
.49999 .51542 m .4988 .52413 L .49752 .52151 L .964 .688 .462 r
F
.49863 .51301 m .49999 .51542 L .49752 .52151 L F
.62608 .33285 m .61879 .33539 L .63152 .34259 L 0 .255 .764 r
F
.62608 .33285 m .61201 .32331 L .61879 .33539 L F
.46125 .48108 m .46789 .49106 L .46669 .49563 L .962 .688 .467 r
F
.46182 .47716 m .46789 .49106 L .46125 .48108 L F
.45503 .46238 m .46204 .47281 L .45512 .46553 L F
.45512 .46553 m .46204 .47281 L .46182 .47716 L F
.039 .916 .04 r
.43116 .48175 m
.45926 .47273 L
s
.57502 .37253 m .57248 .37615 L .57898 .38041 L 0 .116 .668 r
F
.57502 .37253 m .56756 .36636 L .57248 .37615 L F
.41133 .47266 m .42052 .48195 L .41987 .48423 L .914 .621 .475 r
F
.41154 .47135 m .42052 .48195 L .41133 .47266 L .911 .626 .491 r
F
.38945 .46737 m .39733 .48092 L .39679 .48207 L .958 .688 .48 r
F
.45119 .37658 m .45569 .3775 L .45586 .38016 L .964 .688 .462 r
F
0 g
.45586 .38016 m
.46057 .38481 L
s
.45119 .37658 m .45083 .37377 L .45569 .3775 L .964 .688 .462 r
F
.41883 .54835 m .41949 .56699 L .41448 .55037 L .958 .688 .48 r
F
.41297 .53219 m .41883 .54835 L .41448 .55037 L F
.22276 .48332 m .20681 .46919 L .20712 .45805 L .968 .709 .487 r
F
.22321 .49118 m .20681 .46919 L .22276 .48332 L .968 .705 .48 r
F
.039 .916 .04 r
.18654 .47683 m
.20798 .47076 L
s
.23956 .50577 m .23454 .50243 L .23251 .49225 L .932 .644 .173 r
F
.24136 .51252 m .23454 .50243 L .23956 .50577 L .919 .61 .132 r
F
.40192 .43465 m .40626 .42112 L .40372 .43552 L .952 .786 .639 r
F
.40192 .43465 m .40358 .41979 L .40626 .42112 L F
.40278 .49852 m .4071 .51601 L .40122 .49981 L .958 .688 .48 r
F
.39612 .48297 m .40278 .49852 L .40122 .49981 L F
.39679 .48207 m .40278 .49852 L .39612 .48297 L F
.50702 .47517 m .51392 .48414 L .51307 .49089 L .965 .687 .457 r
F
.50725 .46917 m .51392 .48414 L .50702 .47517 L F
.039 .916 .04 r
.48968 .47637 m
.50719 .47067 L
s
.34627 .49351 m .34527 .50256 L .34514 .49203 L .954 .609 .301 r
F
.34627 .49351 m .34753 .50553 L .34527 .50256 L F
.36791 .52794 m .37529 .54158 L .36473 .52739 L .858 .421 .171 r
F
.36791 .52794 m .37951 .54226 L .37529 .54158 L F
.45593 .51652 m .47096 .52946 L .45333 .52035 L .757 .37 .321 r
F
.45593 .51652 m .47402 .52484 L .47096 .52946 L F
.44131 .50713 m .45593 .51652 L .45333 .52035 L .81 .441 .357 r
F
.38945 .46737 m .38647 .45098 L .38757 .4515 L .958 .688 .48 r
F
.50008 .45675 m .50699 .46267 L .50725 .46917 L .965 .687 .457 r
F
.49954 .45158 m .50699 .46267 L .50008 .45675 L F
.50967 .38684 m .5103 .38429 L .51325 .39206 L .813 .39 0 r
F
.50967 .38684 m .50583 .37778 L .5103 .38429 L F
.24358 .51918 m .23726 .51266 L .24136 .51252 L .909 .579 .101 r
F
.24358 .51918 m .24062 .52275 L .23726 .51266 L F
.4037 .46281 m .41032 .4613 L .41081 .46309 L .944 .684 .512 r
F
.4037 .46281 m .40973 .45952 L .41032 .4613 L .945 .687 .515 r
F
.4037 .46281 m .40905 .4578 L .40973 .45952 L .946 .69 .518 r
F
.24136 .51252 m .23726 .51266 L .23454 .50243 L .919 .61 .132 r
F
.4029 .4494 m .40556 .43684 L .40383 .45006 L .953 .745 .586 r
F
.4029 .4494 m .40372 .43552 L .40556 .43684 L F
.4037 .46281 m .41081 .46309 L .41119 .46488 L .943 .68 .508 r
F
.68806 .29655 m .69017 .29623 L .69486 .3091 L .752 .359 0 r
F
.68806 .29655 m .68173 .28065 L .69017 .29623 L F
.49863 .51301 m .49752 .52151 L .49624 .51889 L .964 .688 .462 r
F
.49727 .5106 m .49863 .51301 L .49624 .51889 L F
.33908 .47188 m .33308 .46206 L .33339 .45853 L .992 .743 .435 r
F
.33908 .47379 m .33308 .46206 L .33908 .47188 L .991 .732 .409 r
F
.44146 .42768 m .44435 .41941 L .44328 .42981 L .962 .688 .467 r
F
.44146 .42768 m .44162 .4162 L .44435 .41941 L F
.4037 .46281 m .4083 .45616 L .40905 .4578 L .947 .693 .52 r
F
.33606 .45038 m .33369 .43396 L .33582 .43137 L .996 .821 .551 r
F
.33489 .45264 m .33369 .43396 L .33606 .45038 L 1 .817 .513 r
F
.44131 .50713 m .45333 .52035 L .4392 .51017 L .81 .441 .357 r
F
.42916 .49696 m .44131 .50713 L .4392 .51017 L .853 .502 .387 r
F
.47402 .52484 m .47401 .52852 L .47096 .52946 L .302 0 .054 r
F
.47402 .52484 m .47707 .5239 L .47401 .52852 L F
0 g
.47402 .52484 m
.47563 .52098 L
s
.47707 .5239 m
.47949 .51808 L
s
.4037 .46281 m .41119 .46488 L .41146 .46663 L .943 .677 .504 r
F
.48982 .35686 m .53137 .33781 L .49532 .36245 L .773 .794 .87 r
F
.47379 .36218 m .48982 .35686 L .49532 .36245 L .66 .767 .929 r
F
.49669 .3675 m .49532 .36245 L .50127 .37215 L .771 .299 0 r
F
.49669 .3675 m .48982 .35686 L .49532 .36245 L F
0 g
.49532 .36245 m
.50079 .3692 L
s
.41297 .53219 m .41448 .55037 L .40947 .53375 L .958 .688 .48 r
F
.4071 .51601 m .41297 .53219 L .40947 .53375 L F
.33664 .41321 m .34471 .39107 L .33994 .41088 L .974 .926 .658 r
F
.33582 .43137 m .33664 .41321 L .33994 .41088 L .989 .873 .62 r
F
.4037 .46281 m .40748 .45462 L .4083 .45616 L .949 .696 .521 r
F
.38945 .46737 m .39679 .48207 L .39612 .48297 L .958 .688 .48 r
F
.34514 .49203 m .3431 .49919 L .34406 .49035 L .957 .616 .293 r
F
.34514 .49203 m .34527 .50256 L .3431 .49919 L F
.56421 .45035 m .57205 .45734 L .57256 .46688 L .969 .687 .442 r
F
.56328 .44224 m .57205 .45734 L .56421 .45035 L F
.38445 .4508 m .38142 .43415 L .38543 .45075 L .958 .688 .48 r
F
.38445 .4508 m .37945 .43423 L .38142 .43415 L F
.43617 .41156 m .43814 .40127 L .43888 .41357 L .962 .688 .467 r
F
.43617 .41156 m .43453 .39858 L .43814 .40127 L F
.4037 .46281 m .41146 .46663 L .41161 .46831 L .943 .674 .499 r
F
.48193 .40625 m .48651 .40076 L .48465 .41014 L .965 .687 .457 r
F
.48193 .40625 m .4829 .39558 L .48651 .40076 L F
.44389 .35955 m .44902 .35974 L .44938 .36254 L .964 .688 .462 r
F
.44389 .35955 m .44334 .35664 L .44902 .35974 L F
0 g
.44902 .35974 m
.45484 .36426 L
s
.4037 .46281 m .4066 .45322 L .40748 .45462 L .951 .7 .521 r
F
.33908 .47379 m .33308 .4659 L .33308 .46206 L .991 .732 .409 r
F
.33924 .47582 m .33308 .4659 L .33908 .47379 L .988 .719 .384 r
F
.039 .916 .04 r
.24679 .49529 m
.33585 .47036 L
s
.29629 .59957 m .30778 .61403 L .2889 .59526 L .681 .142 0 r
F
.29629 .59957 m .31698 .61936 L .30778 .61403 L F
.59514 .43349 m .59254 .44204 L .5938 .45259 L 0 0 .356 r
F
.59358 .42466 m .59254 .44204 L .59514 .43349 L 0 0 .439 r
F
.49727 .5106 m .49624 .51889 L .49496 .51627 L .964 .688 .462 r
F
.49591 .5082 m .49727 .5106 L .49496 .51627 L F
.27657 .63072 m .27253 .65455 L .26729 .62551 L .942 .627 .41 r
F
.27657 .63072 m .28416 .66092 L .27253 .65455 L F
.21052 .43876 m .19671 .41379 L .20082 .40344 L .972 .73 .512 r
F
.20837 .44785 m .19671 .41379 L .21052 .43876 L .974 .727 .501 r
F
.7294 .50068 m .73838 .51488 L .72854 .51781 L .521 .26 .46 r
F
.7294 .50068 m .73918 .49775 L .73838 .51488 L F
.71794 .48148 m .7294 .50068 L .72854 .51781 L .983 .699 .384 r
F
.71759 .46574 m .7294 .50068 L .71794 .48148 L .982 .695 .375 r
F
0 g
.72892 .48185 m
.7294 .50068 L
s
.43102 .39676 m .4329 .38564 L .43453 .39858 L .962 .688 .467 r
F
.43102 .39676 m .42851 .38333 L .4329 .38564 L F
.38945 .46737 m .38543 .45075 L .38647 .45098 L .958 .688 .48 r
F
.65463 .29403 m .66288 .28694 L .66169 .30529 L .972 .66 .348 r
F
.65463 .29403 m .65413 .2729 L .66288 .28694 L F
.24187 .54719 m .22964 .55525 L .23785 .54013 L .959 .672 .447 r
F
.24187 .54719 m .23575 .56592 L .22964 .55525 L F
.5305 .32574 m .57405 .29199 L .53711 .33273 L .846 .799 .805 r
F
.5305 .32574 m .56542 .28248 L .57405 .29199 L F
.5907 .29499 m .57405 .29199 L .59785 .30293 L .059 .438 .875 r
F
.5907 .29499 m .56542 .28248 L .57405 .29199 L F
0 g
.57405 .29199 m
.58265 .30333 L
s
.2701 .57057 m .27395 .58166 L .26453 .56487 L .787 .314 0 r
F
.2701 .57057 m .28141 .58926 L .27395 .58166 L F
.41987 .48423 m .42916 .49696 L .419 .48614 L .884 .567 .444 r
F
.411 .4738 m .41987 .48423 L .419 .48614 L .917 .615 .458 r
F
.41133 .47266 m .41987 .48423 L .411 .4738 L .914 .621 .475 r
F
.4037 .46281 m .41161 .46831 L .41164 .46989 L .943 .672 .494 r
F
.47098 .51152 m .47689 .52354 L .47385 .52814 L .962 .688 .467 r
F
.33369 .43396 m .33664 .41321 L .33582 .43137 L .994 .875 .572 r
F
.34406 .49035 m .34106 .49548 L .34305 .4885 L .961 .625 .29 r
F
.34406 .49035 m .3431 .49919 L .34106 .49548 L F
.4071 .51601 m .40947 .53375 L .40446 .51715 L .958 .688 .48 r
F
.40122 .49981 m .4071 .51601 L .40446 .51715 L F
.46831 .35788 m .48982 .35686 L .47379 .36218 L .652 .814 .961 r
F
.47007 .37122 m .47379 .36218 L .47464 .37477 L .965 .687 .457 r
F
.47007 .37122 m .46831 .35788 L .47379 .36218 L F
0 g
.47379 .36218 m
.47932 .36774 L
s
.4755 .38743 m .47927 .37939 L .47921 .39111 L .965 .687 .457 r
F
.4755 .38743 m .47464 .37477 L .47927 .37939 L F
.4037 .46281 m .4057 .45198 L .4066 .45322 L .953 .702 .521 r
F
.42916 .49696 m .4392 .51017 L .42756 .49922 L .853 .502 .387 r
F
.419 .48614 m .42916 .49696 L .42756 .49922 L .889 .557 .414 r
F
.33924 .47582 m .33339 .46999 L .33308 .4659 L .988 .719 .384 r
F
.33954 .47794 m .33339 .46999 L .33924 .47582 L .985 .704 .36 r
F
.45497 .46844 m .46182 .47716 L .46125 .48108 L .962 .688 .467 r
F
.45512 .46553 m .46182 .47716 L .45497 .46844 L F
.039 .916 .04 r
.46133 .47207 m
.47996 .46603 L
s
.44444 .36246 m .44938 .36254 L .44974 .36534 L .964 .688 .462 r
F
.44444 .36246 m .44389 .35955 L .44938 .36254 L F
.35447 .51156 m .35794 .52377 L .35217 .51007 L .909 .507 .204 r
F
.35447 .51156 m .36139 .526 L .35794 .52377 L F
.49591 .5082 m .49496 .51627 L .49367 .51365 L .964 .688 .462 r
F
.49454 .50579 m .49591 .5082 L .49367 .51365 L F
.40907 .38684 m .4229 .37055 L .41333 .388 L .916 .895 .793 r
F
.4038 .40341 m .41333 .388 L .40722 .4043 L .94 .865 .737 r
F
.4038 .40341 m .40907 .38684 L .41333 .388 L F
.39916 .55506 m .41373 .56779 L .39431 .55568 L .698 .18 0 r
F
.39916 .55506 m .41949 .56699 L .41373 .56779 L F
.34305 .4885 m .33919 .4915 L .34212 .48652 L .964 .635 .291 r
F
.34305 .4885 m .34106 .49548 L .33919 .4915 L F
.44679 .44962 m .4524 .44842 L .45338 .452 L .962 .688 .467 r
F
.4462 .44784 m .4524 .44842 L .44679 .44962 L F
.4462 .44784 m .45123 .44489 L .4524 .44842 L F
.39612 .48297 m .40122 .49981 L .39534 .4836 L .958 .688 .48 r
F
.38945 .46737 m .39612 .48297 L .39534 .4836 L F
.4037 .46281 m .41164 .46989 L .41154 .47135 L .943 .669 .488 r
F
.40101 .41916 m .40722 .4043 L .40358 .41979 L .955 .833 .683 r
F
.40101 .41916 m .4038 .40341 L .40722 .4043 L F
.44553 .44612 m .45123 .44489 L .4462 .44784 L .962 .688 .467 r
F
.44553 .44612 m .44989 .44145 L .45123 .44489 L F
.40201 .44898 m .40372 .43552 L .4029 .4494 L .959 .752 .58 r
F
.40201 .44898 m .40192 .43465 L .40372 .43552 L F
.52632 .42542 m .52816 .42545 L .5302 .43282 L .893 .58 .08 r
F
.5245 .41992 m .52816 .42545 L .52632 .42542 L .885 .555 .055 r
F
.5245 .41992 m .52575 .41815 L .52816 .42545 L F
.22321 .49118 m .20745 .48107 L .20681 .46919 L .968 .705 .48 r
F
.22427 .49938 m .20745 .48107 L .22321 .49118 L .968 .701 .472 r
F
.53381 .45422 m .53624 .46975 L .5341 .46073 L .887 .666 .147 r
F
.5341 .46073 m .53624 .46975 L .53602 .47725 L .923 .716 .226 r
F
.58814 .48724 m .64079 .51096 L .58714 .49722 L .738 .444 .482 r
F
.59427 .47179 m .58814 .48724 L .58714 .49722 L 0 0 .145 r
F
.59439 .46256 m .58814 .48724 L .59427 .47179 L 0 0 .291 r
F
0 g
.58814 .48724 m
.5883 .4762 L
s
.33954 .47794 m .334 .47425 L .33339 .46999 L .985 .704 .36 r
F
.33999 .48011 m .334 .47425 L .33954 .47794 L .981 .689 .339 r
F
.53586 .37099 m .54197 .36627 L .54003 .37716 L .969 .687 .442 r
F
.53586 .37099 m .53678 .35857 L .54197 .36627 L F
.36584 .4023 m .36448 .38456 L .36947 .40111 L .958 .688 .48 r
F
.36584 .4023 m .35992 .38599 L .36448 .38456 L F
.52244 .41457 m .52575 .41815 L .5245 .41992 L .881 .535 .04 r
F
.52244 .41457 m .52301 .41105 L .52575 .41815 L F
.44728 .45142 m .45338 .452 L .45416 .45556 L .962 .688 .467 r
F
.44679 .44962 m .45338 .452 L .44728 .45142 L F
.65982 .43525 m .65382 .45018 L .65478 .46346 L 0 0 .366 r
F
.65833 .42395 m .65382 .45018 L .65982 .43525 L 0 0 .456 r
F
.57085 .36529 m .56756 .36636 L .57502 .37253 L 0 .113 .665 r
F
.57085 .36529 m .56236 .35735 L .56756 .36636 L F
.4037 .46281 m .40477 .45092 L .4057 .45198 L .955 .705 .521 r
F
.5724 .47571 m .58027 .48627 L .57929 .49584 L .969 .687 .442 r
F
.57256 .46688 m .58027 .48627 L .5724 .47571 L F
.34212 .48652 m .33753 .48731 L .3413 .48444 L .968 .647 .296 r
F
.34212 .48652 m .33919 .4915 L .33753 .48731 L F
.44478 .44447 m .44989 .44145 L .44553 .44612 L .962 .688 .467 r
F
.44478 .44447 m .4484 .43817 L .44989 .44145 L F
.40122 .49981 m .40446 .51715 L .39946 .50055 L .958 .688 .48 r
F
.39534 .4836 m .40122 .49981 L .39946 .50055 L F
.33999 .48011 m .33491 .47861 L .334 .47425 L .981 .689 .339 r
F
.34058 .48229 m .33491 .47861 L .33999 .48011 L .977 .675 .32 r
F
.38945 .46737 m .38445 .4508 L .38543 .45075 L .958 .688 .48 r
F
.44499 .36538 m .44974 .36534 L .4501 .36815 L .964 .688 .462 r
F
.44499 .36538 m .44444 .36246 L .44974 .36534 L F
.3413 .48444 m .33609 .48299 L .34058 .48229 L .972 .66 .306 r
F
.3413 .48444 m .33753 .48731 L .33609 .48299 L F
.52786 .43098 m .5302 .43282 L .53184 .44015 L .905 .609 .113 r
F
.52632 .42542 m .5302 .43282 L .52786 .43098 L .893 .58 .08 r
F
.22182 .59237 m .21679 .60452 L .21496 .58402 L .938 .568 .243 r
F
.22182 .59237 m .22602 .61568 L .21679 .60452 L F
.37175 .41859 m .36947 .40111 L .37446 .41766 L .958 .688 .48 r
F
.37175 .41859 m .36584 .4023 L .36947 .40111 L F
.34058 .48229 m .33609 .48299 L .33491 .47861 L .977 .675 .32 r
F
.43963 .42593 m .44162 .4162 L .44146 .42768 L .962 .688 .467 r
F
.43963 .42593 m .43888 .41357 L .44162 .4162 L F
.50008 .45675 m .50725 .46917 L .50026 .46163 L .965 .687 .457 r
F
.50026 .46163 m .50725 .46917 L .50702 .47517 L F
.33489 .45264 m .33192 .43733 L .33369 .43396 L 1 .817 .513 r
F
.33399 .45537 m .33192 .43733 L .33489 .45264 L .999 .806 .468 r
F
.44767 .4532 m .45416 .45556 L .45471 .45904 L .962 .688 .467 r
F
.44728 .45142 m .45416 .45556 L .44767 .4532 L F
.4037 .46281 m .41154 .47135 L .41133 .47266 L .944 .667 .483 r
F
.49454 .50579 m .49367 .51365 L .49239 .51102 L .964 .688 .462 r
F
.49317 .50337 m .49454 .50579 L .49239 .51102 L F
.40021 .43425 m .40358 .41979 L .40192 .43465 L .963 .798 .629 r
F
.40021 .43425 m .40101 .41916 L .40358 .41979 L F
.40907 .38684 m .41782 .3691 L .4229 .37055 L .916 .895 .793 r
F
.41782 .3691 m .42593 .36954 L .4229 .37055 L .575 .898 .984 r
F
0 g
.4229 .37055 m
.42647 .37245 L
s
.52015 .40946 m .52301 .41105 L .52244 .41457 L .881 .519 .034 r
F
.52015 .40946 m .51998 .40426 L .52301 .41105 L F
.44397 .44294 m .4484 .43817 L .44478 .44447 L .962 .688 .467 r
F
.44397 .44294 m .44678 .43511 L .4484 .43817 L F
.37766 .43487 m .37446 .41766 L .37945 .43423 L .958 .688 .48 r
F
.37766 .43487 m .37175 .41859 L .37446 .41766 L F
.55123 .41778 m .55746 .4165 L .55987 .42518 L .969 .687 .442 r
F
.54909 .41131 m .55746 .4165 L .55123 .41778 L F
.54909 .41131 m .55463 .40792 L .55746 .4165 L F
.4037 .46281 m .40383 .45006 L .40477 .45092 L .957 .708 .519 r
F
.2318 .45561 m .22996 .43481 L .23221 .42506 L .95 .814 .369 r
F
.23085 .46381 m .22996 .43481 L .2318 .45561 L .907 .756 .263 r
F
.46669 .49563 m .47098 .51152 L .46504 .49946 L .962 .688 .467 r
F
.46034 .4845 m .46669 .49563 L .46504 .49946 L F
.46125 .48108 m .46669 .49563 L .46034 .4845 L F
.68302 .37732 m .69181 .37576 L .69618 .39117 L .977 .678 .365 r
F
.67921 .36575 m .69181 .37576 L .68302 .37732 L .976 .675 .362 r
F
.67921 .36575 m .68679 .36049 L .69181 .37576 L F
.32585 .62248 m .34658 .63685 L .31698 .61936 L .511 0 0 r
F
.32585 .62248 m .35711 .64051 L .34658 .63685 L F
.54666 .40501 m .55463 .40792 L .54909 .41131 L .969 .687 .442 r
F
.54666 .40501 m .55141 .39956 L .55463 .40792 L F
.039 .916 .04 r
.21628 .46841 m
.23084 .46412 L
s
.49032 .43633 m .49591 .43515 L .49744 .44069 L .965 .687 .457 r
F
.48911 .43266 m .49591 .43515 L .49032 .43633 L F
.48911 .43266 m .4941 .42968 L .49591 .43515 L F
.39534 .4836 m .39946 .50055 L .39445 .48396 L .958 .688 .48 r
F
.38945 .46737 m .39534 .4836 L .39445 .48396 L F
.44554 .3683 m .4501 .36815 L .45047 .37096 L .964 .688 .462 r
F
.44554 .3683 m .44499 .36538 L .4501 .36815 L F
.18895 .37528 m .18596 .3341 L .19552 .36486 L .98 .759 .532 r
F
.20082 .40344 m .18895 .37528 L .19552 .36486 L .975 .745 .527 r
F
.23785 .54013 m .22406 .54372 L .23418 .53251 L .962 .677 .449 r
F
.23785 .54013 m .22964 .55525 L .22406 .54372 L F
.419 .48614 m .42756 .49922 L .41792 .48763 L .889 .557 .414 r
F
.41055 .47475 m .419 .48614 L .41792 .48763 L .92 .61 .44 r
F
.411 .4738 m .419 .48614 L .41055 .47475 L .917 .615 .458 r
F
.48772 .42909 m .4941 .42968 L .48911 .43266 L .965 .687 .457 r
F
.48772 .42909 m .49203 .42435 L .4941 .42968 L F
.38356 .45113 m .37945 .43423 L .38445 .4508 L .958 .688 .48 r
F
.38356 .45113 m .37766 .43487 L .37945 .43423 L F
.67495 .35447 m .68679 .36049 L .67921 .36575 L .976 .673 .361 r
F
.67495 .35447 m .68118 .34558 L .68679 .36049 L F
.36705 .64146 m .40751 .56687 L .35711 .64051 L .899 .927 .828 r
F
.36705 .64146 m .41373 .56779 L .40751 .56687 L F
0 g
.36705 .64146 m
.37622 .63973 L
s
.44795 .45495 m .45471 .45904 L .45503 .46238 L .962 .688 .467 r
F
.44767 .4532 m .45471 .45904 L .44795 .45495 L F
.50601 .38234 m .50583 .37778 L .50967 .38684 L .837 .403 0 r
F
.50601 .38234 m .50127 .37215 L .50583 .37778 L F
.4037 .46281 m .41133 .47266 L .411 .4738 L .945 .665 .477 r
F
.49317 .50337 m .49239 .51102 L .4911 .50839 L .964 .688 .462 r
F
0 g
.49317 .50337 m
.49467 .49739 L
s
.5291 .43651 m .53184 .44015 L .53305 .44733 L .921 .641 .155 r
F
.52786 .43098 m .53184 .44015 L .5291 .43651 L .905 .609 .113 r
F
.55304 .42432 m .55987 .42518 L .56182 .4338 L .969 .687 .442 r
F
.55123 .41778 m .55987 .42518 L .55304 .42432 L F
.49134 .44003 m .49744 .44069 L .49865 .44619 L .965 .687 .457 r
F
.49032 .43633 m .49744 .44069 L .49134 .44003 L F
.41782 .3691 m .42086 .36809 L .42593 .36954 L .575 .898 .984 r
F
0 g
.42593 .36954 m
.43122 .37236 L
s
.24496 .63225 m .24495 .65018 L .23547 .62497 L .904 .494 .182 r
F
.24496 .63225 m .25685 .65921 L .24495 .65018 L F
.73708 .47568 m .73918 .49775 L .73838 .51488 L .848 .681 .145 r
F
.73664 .45993 m .73918 .49775 L .73708 .47568 L .786 .61 .046 r
F
0 g
.73865 .47891 m
.73918 .49775 L
s
.42431 .38217 m .426 .36994 L .42851 .38333 L .962 .688 .467 r
F
.42431 .38217 m .42096 .3685 L .426 .36994 L F
.5359 .49618 m .57773 .50463 L .53425 .50329 L .628 .306 .406 r
F
.5359 .49618 m .57952 .4962 L .57773 .50463 L F
0 g
.57952 .4962 m
.58051 .48659 L
s
.53522 .48401 m .5359 .49618 L .53425 .50329 L .937 .797 .335 r
F
.53602 .47725 m .5359 .49618 L .53522 .48401 L .889 .739 .231 r
F
0 g
.5359 .49618 m
.53686 .48806 L
s
.47915 .4029 m .4829 .39558 L .48193 .40625 L .965 .687 .457 r
F
.47915 .4029 m .47921 .39111 L .4829 .39558 L F
.36473 .52739 m .37085 .53975 L .36139 .526 L .851 .395 .095 r
F
.36473 .52739 m .37529 .54158 L .37085 .53975 L F
.37951 .54226 m .38907 .55487 L .37529 .54158 L .78 .283 .021 r
F
.37951 .54226 m .39431 .55568 L .38907 .55487 L F
.38945 .46737 m .38356 .45113 L .38445 .4508 L .958 .688 .48 r
F
.73117 .42764 m .73512 .44296 L .73664 .45993 L .842 .613 .068 r
F
.72909 .41319 m .73512 .44296 L .73117 .42764 L .803 .561 0 r
F
.4431 .44153 m .44678 .43511 L .44397 .44294 L .962 .688 .467 r
F
.4431 .44153 m .44507 .4323 L .44678 .43511 L F
.48619 .42569 m .49203 .42435 L .48772 .42909 L .965 .687 .457 r
F
.48619 .42569 m .48974 .41927 L .49203 .42435 L F
.23538 .41669 m .24036 .38923 L .24539 .38076 L .933 .908 .518 r
F
.23221 .42506 m .24036 .38923 L .23538 .41669 L .869 .844 .38 r
F
.22427 .49938 m .20904 .49348 L .20745 .48107 L .968 .701 .472 r
F
.22593 .50776 m .20904 .49348 L .22427 .49938 L .967 .696 .466 r
F
.4037 .46281 m .4029 .4494 L .40383 .45006 L .959 .71 .517 r
F
.54399 .39898 m .55141 .39956 L .54666 .40501 L .969 .687 .442 r
F
.54399 .39898 m .54787 .39156 L .55141 .39956 L F
.4461 .37122 m .45047 .37096 L .45083 .37377 L .964 .688 .462 r
F
.4461 .37122 m .44554 .3683 L .45047 .37096 L F
.29952 .69718 m .29285 .69113 L .28604 .69311 L .567 .879 .993 r
F
.29952 .69718 m .3063 .69523 L .29285 .69113 L F
0 g
.29952 .69718 m
.31223 .6979 L
s
.3063 .69523 m
.31897 .69596 L
s
.40115 .44878 m .40192 .43465 L .40201 .44898 L .966 .758 .572 r
F
.40115 .44878 m .40021 .43425 L .40192 .43465 L F
.35217 .51007 m .35444 .52075 L .34984 .50804 L .909 .501 .163 r
F
.35217 .51007 m .35794 .52377 L .35444 .52075 L F
.51769 .40466 m .51998 .40426 L .52015 .40946 L .885 .509 .039 r
F
.51769 .40466 m .51671 .3979 L .51998 .40426 L F
.68632 .38899 m .69618 .39117 L .69981 .40647 L .978 .681 .368 r
F
.68302 .37732 m .69618 .39117 L .68632 .38899 L .977 .678 .365 r
F
.62046 .3241 m .61201 .32331 L .62608 .33285 L 0 .247 .761 r
F
.62046 .3241 m .60499 .31243 L .61201 .32331 L F
.38945 .46737 m .38276 .45174 L .38356 .45113 L .958 .688 .48 r
F
.38945 .46737 m .38208 .45262 L .38276 .45174 L F
.38945 .46737 m .38153 .45376 L .38208 .45262 L F
.38945 .46737 m .38111 .45513 L .38153 .45376 L F
.38945 .46737 m .38083 .45671 L .38111 .45513 L F
.38945 .46737 m .3807 .45848 L .38083 .45671 L F
.38945 .46737 m .38072 .4604 L .3807 .45848 L F
.38945 .46737 m .38089 .46244 L .38072 .4604 L F
.38945 .46737 m .38121 .46457 L .38089 .46244 L F
.38945 .46737 m .38167 .46675 L .38121 .46457 L F
.38945 .46737 m .38226 .46894 L .38167 .46675 L F
.38945 .46737 m .38298 .4711 L .38226 .46894 L F
.039 .916 .04 r
.34699 .48097 m
.38249 .4696 L
s
.38945 .46737 m .38381 .4732 L .38298 .4711 L .958 .688 .48 r
F
.38945 .46737 m .38474 .4752 L .38381 .4732 L F
.38945 .46737 m .38574 .47706 L .38474 .4752 L F
.38945 .46737 m .38681 .47875 L .38574 .47706 L F
.38945 .46737 m .38793 .48025 L .38681 .47875 L F
.38945 .46737 m .38907 .48152 L .38793 .48025 L F
.38945 .46737 m .39021 .48255 L .38907 .48152 L F
.38945 .46737 m .39134 .48332 L .39021 .48255 L F
.38945 .46737 m .39244 .48382 L .39134 .48332 L F
.38945 .46737 m .39348 .48403 L .39244 .48382 L F
.38945 .46737 m .39445 .48396 L .39348 .48403 L F
.45458 .47105 m .46125 .48108 L .46034 .4845 L .962 .688 .467 r
F
.45497 .46844 m .46125 .48108 L .45458 .47105 L F
.47098 .51152 m .47385 .52814 L .46842 .51532 L F
.46504 .49946 m .47098 .51152 L .46842 .51532 L F
.51307 .49089 m .51808 .50827 L .51163 .4968 L .965 .687 .457 r
F
.50632 .48057 m .51307 .49089 L .51163 .4968 L F
.50702 .47517 m .51307 .49089 L .50632 .48057 L F
.59616 .44197 m .5938 .45259 L .59439 .46256 L 0 0 .252 r
F
.59514 .43349 m .5938 .45259 L .59616 .44197 L 0 0 .356 r
F
.49216 .44372 m .49865 .44619 L .49954 .45158 L .965 .687 .457 r
F
.49134 .44003 m .49865 .44619 L .49216 .44372 L F
.48982 .35686 m .52498 .3311 L .53137 .33781 L .773 .794 .87 r
F
0 g
.53137 .33781 m
.53772 .34588 L
s
.34059 .39392 m .354 .36966 L .34471 .39107 L .926 .971 .693 r
F
.33664 .41321 m .34059 .39392 L .34471 .39107 L .974 .926 .658 r
F
.18 .46702 m .16972 .44697 L .17154 .43336 L .997 .77 .445 r
F
.17963 .47813 m .16972 .44697 L .18 .46702 L .994 .753 .406 r
F
.54601 .33643 m .53711 .33273 L .5515 .34226 L 0 .274 .758 r
F
.54601 .33643 m .5305 .32574 L .53711 .33273 L F
0 g
.53711 .33273 m
.5437 .34113 L
s
.4037 .46281 m .411 .4738 L .41055 .47475 L .946 .663 .471 r
F
.44811 .45663 m .45503 .46238 L .45512 .46553 L .962 .688 .467 r
F
.44795 .45495 m .45503 .46238 L .44811 .45663 L F
.39445 .48396 m .39752 .50072 L .39348 .48403 L .958 .688 .48 r
F
.39445 .48396 m .39946 .50055 L .39752 .50072 L F
.4392 .51017 m .45024 .52309 L .4367 .51233 L .811 .41 .292 r
F
.4392 .51017 m .45333 .52035 L .45024 .52309 L F
.42756 .49922 m .4392 .51017 L .4367 .51233 L .857 .483 .34 r
F
.56421 .45035 m .57256 .46688 L .56461 .458 L .969 .687 .442 r
F
.56461 .458 m .57256 .46688 L .5724 .47571 L F
.52618 .34635 m .53137 .33822 L .53149 .35189 L F
.52618 .34635 m .52501 .33154 L .53137 .33822 L F
.19671 .41379 m .18895 .37528 L .20082 .40344 L .978 .743 .513 r
F
.43353 .41022 m .43453 .39858 L .43617 .41156 L .962 .688 .467 r
F
.43353 .41022 m .43102 .39676 L .43453 .39858 L F
.42756 .49922 m .4367 .51233 L .42566 .50082 L .857 .483 .34 r
F
.41792 .48763 m .42756 .49922 L .42566 .50082 L .894 .547 .382 r
F
.23418 .53251 m .21913 .53155 L .23094 .52448 L .963 .682 .451 r
F
.23418 .53251 m .22406 .54372 L .21913 .53155 L F
.44665 .37414 m .45083 .37377 L .45119 .37658 L .964 .688 .462 r
F
0 g
.45119 .37658 m
.45586 .38016 L
s
.44665 .37414 m .4461 .37122 L .45083 .37377 L .964 .688 .462 r
F
.48453 .4225 m .48974 .41927 L .48619 .42569 L .965 .687 .457 r
F
.48453 .4225 m .48727 .4145 L .48974 .41927 L F
.25608 .59098 m .24848 .60883 L .24909 .58394 L .952 .649 .423 r
F
.25608 .59098 m .25787 .61818 L .24848 .60883 L F
.55451 .43082 m .56182 .4338 L .56328 .44224 L .969 .687 .442 r
F
.55304 .42432 m .56182 .4338 L .55451 .43082 L F
.67032 .34364 m .68118 .34558 L .67495 .35447 L .975 .671 .359 r
F
.67032 .34364 m .67506 .33127 L .68118 .34558 L F
.4037 .46281 m .40201 .44898 L .4029 .4494 L .961 .712 .514 r
F
.33399 .45537 m .33057 .44142 L .33192 .43733 L .999 .806 .468 r
F
.33339 .45853 m .33057 .44142 L .33399 .45537 L .994 .789 .416 r
F
.44221 .44029 m .44507 .4323 L .4431 .44153 L .962 .688 .467 r
F
.44221 .44029 m .44328 .42981 L .44507 .4323 L F
.39946 .50055 m .40156 .51744 L .39752 .50072 L .958 .688 .48 r
F
.39946 .50055 m .40446 .51715 L .40156 .51744 L F
.49752 .52151 m .4988 .52413 L .49557 .52914 L .964 .688 .462 r
F
0 g
.4988 .52413 m
.50135 .51782 L
s
.51808 .50827 m .53193 .50926 L .5157 .51424 L .404 .043 .235 r
F
.51808 .50827 m .53425 .50329 L .53193 .50926 L F
.51163 .4968 m .51808 .50827 L .5157 .51424 L .965 .687 .457 r
F
0 g
.51808 .50827 m
.51977 .50116 L
s
.38276 .45174 m .37766 .43487 L .38356 .45113 L .958 .688 .48 r
F
.22593 .50776 m .21155 .50619 L .20904 .49348 L .967 .696 .466 r
F
.22817 .51618 m .21155 .50619 L .22593 .50776 L .966 .691 .46 r
F
.45333 .52035 m .46731 .53279 L .45024 .52309 L .75 .322 .233 r
F
.45333 .52035 m .47096 .52946 L .46731 .53279 L F
.6321 .22484 m .65243 .23407 L .64274 .23738 L .665 .761 .922 r
F
.63633 .2502 m .64274 .23738 L .64524 .26058 L .969 .651 .342 r
F
.63633 .2502 m .6321 .22484 L .64274 .23738 L F
0 g
.64274 .23738 m
.65335 .25218 L
s
.53 .44191 m .53305 .44733 L .53381 .45422 L .938 .673 .202 r
F
.5291 .43651 m .53305 .44733 L .53 .44191 L .921 .641 .155 r
F
.33369 .43396 m .33379 .41663 L .33664 .41321 L .994 .875 .572 r
F
.33192 .43733 m .33379 .41663 L .33369 .43396 L .989 .864 .509 r
F
.43782 .4246 m .43888 .41357 L .43963 .42593 L .962 .688 .467 r
F
.43782 .4246 m .43617 .41156 L .43888 .41357 L F
.41792 .48763 m .42566 .50082 L .41664 .48869 L .894 .547 .382 r
F
.41001 .47549 m .41792 .48763 L .41664 .48869 L .924 .606 .421 r
F
.41055 .47475 m .41792 .48763 L .41001 .47549 L .92 .61 .44 r
F
.40446 .51715 m .40561 .53419 L .40156 .51744 L .958 .688 .48 r
F
.40446 .51715 m .40947 .53375 L .40561 .53419 L F
.54111 .39333 m .54787 .39156 L .54399 .39898 L .969 .687 .442 r
F
.54111 .39333 m .54406 .38406 L .54787 .39156 L F
.4037 .46281 m .41055 .47475 L .41001 .47549 L .947 .662 .464 r
F
.23094 .52448 m .21493 .51896 L .22817 .51618 L .965 .686 .455 r
F
.23094 .52448 m .21913 .53155 L .21493 .51896 L F
.49274 .44733 m .49954 .45158 L .50008 .45675 L .965 .687 .457 r
F
.49216 .44372 m .49954 .45158 L .49274 .44733 L F
.70466 .43586 m .71759 .46574 L .7058 .44948 L .981 .69 .374 r
F
.7058 .44948 m .71759 .46574 L .71794 .48148 L .981 .693 .381 r
F
.49752 .52151 m .49557 .52914 L .49439 .52635 L .964 .688 .462 r
F
.49624 .51889 m .49752 .52151 L .49439 .52635 L F
.22817 .51618 m .21493 .51896 L .21155 .50619 L .966 .691 .46 r
F
.50008 .46614 m .50702 .47517 L .50632 .48057 L .965 .687 .457 r
F
.50026 .46163 m .50702 .47517 L .50008 .46614 L F
.26453 .56487 m .26666 .57258 L .25908 .55809 L .75 .291 0 r
F
.26453 .56487 m .27395 .58166 L .26666 .57258 L F
.33379 .41663 m .34059 .39392 L .33664 .41321 L .965 .922 .586 r
F
.44811 .45663 m .45512 .46553 L .44815 .45821 L .962 .688 .467 r
F
.44815 .45821 m .45512 .46553 L .45497 .46844 L F
.40947 .53375 m .40967 .55098 L .40561 .53419 L .958 .688 .48 r
F
.40947 .53375 m .41448 .55037 L .40967 .55098 L F
.56654 .35881 m .56236 .35735 L .57085 .36529 L 0 .093 .642 r
F
.56654 .35881 m .55699 .34927 L .56236 .35735 L F
.48438 .35253 m .52498 .3311 L .48982 .35686 L .785 .839 .892 r
F
.46831 .35788 m .48438 .35253 L .48982 .35686 L .652 .814 .961 r
F
.49216 .36391 m .48982 .35686 L .49669 .3675 L .81 .335 0 r
F
.49216 .36391 m .48438 .35253 L .48982 .35686 L F
0 g
.48982 .35686 m
.49532 .36245 L
s
.39348 .48403 m .39543 .50032 L .39244 .48382 L .958 .688 .48 r
F
.39348 .48403 m .39752 .50072 L .39543 .50032 L F
.4037 .46281 m .40115 .44878 L .40201 .44898 L .963 .713 .51 r
F
.3986 .41922 m .4038 .40341 L .40101 .41916 L .97 .851 .667 r
F
.3986 .43431 m .40101 .41916 L .40021 .43425 L .974 .808 .614 r
F
.3986 .43431 m .3986 .41922 L .40101 .41916 L F
.53392 .46674 m .53602 .47725 L .53522 .48401 L .953 .76 .304 r
F
.5341 .46073 m .53602 .47725 L .53392 .46674 L .923 .716 .226 r
F
.039 .916 .04 r
.50831 .47031 m
.53406 .46204 L
s
.53439 .46194 m
.53446 .46192 L
s
.51509 .40027 m .51671 .3979 L .51769 .40466 L .891 .504 .053 r
F
.51509 .40027 m .51325 .39206 L .51671 .3979 L F
.37606 .43607 m .37175 .41859 L .37766 .43487 L .958 .688 .48 r
F
.38276 .45174 m .37606 .43607 L .37766 .43487 L F
.47184 .38461 m .47464 .37477 L .4755 .38743 L .965 .687 .457 r
F
.47184 .38461 m .47007 .37122 L .47464 .37477 L F
.26855 .66553 m .27202 .68567 L .25685 .65921 L .867 .423 .121 r
F
.26855 .66553 m .28604 .69311 L .27202 .68567 L F
.48278 .41959 m .48727 .4145 L .48453 .4225 L .965 .687 .457 r
F
.48278 .41959 m .48465 .41014 L .48727 .4145 L F
.42766 .39586 m .42851 .38333 L .43102 .39676 L .962 .688 .467 r
F
.42766 .39586 m .42431 .38217 L .42851 .38333 L F
.41448 .55037 m .41374 .56779 L .40967 .55098 L .958 .688 .48 r
F
.41448 .55037 m .41949 .56699 L .41374 .56779 L F
0 g
.41949 .56699 m
.42469 .5645 L
s
.40035 .44882 m .40021 .43425 L .40115 .44878 L .973 .763 .561 r
F
.40035 .44882 m .3986 .43431 L .40021 .43425 L F
.34984 .50804 m .35096 .51697 L .34753 .50553 L .905 .497 .125 r
F
.34984 .50804 m .35444 .52075 L .35096 .51697 L F
.4006 .40346 m .40907 .38684 L .4038 .40341 L .958 .891 .721 r
F
.3986 .41922 m .4006 .40346 L .4038 .40341 L .97 .851 .667 r
F
.49624 .51889 m .49439 .52635 L .49321 .52355 L .964 .688 .462 r
F
.49496 .51627 m .49624 .51889 L .49321 .52355 L F
.53161 .36565 m .53678 .35857 L .53586 .37099 L .969 .687 .442 r
F
.53161 .36565 m .53149 .35189 L .53678 .35857 L F
.68106 .28523 m .68173 .28065 L .68806 .29655 L .779 .369 0 r
F
.68106 .28523 m .67304 .26655 L .68173 .28065 L F
.44129 .43922 m .44328 .42981 L .44221 .44029 L .962 .688 .467 r
F
.44129 .43922 m .44146 .42768 L .44328 .42981 L F
.68906 .40058 m .69981 .40647 L .70265 .42145 L .978 .683 .372 r
F
.68632 .38899 m .69981 .40647 L .68906 .40058 L .978 .681 .368 r
F
.38208 .45262 m .37606 .43607 L .38276 .45174 L .958 .688 .48 r
F
.41001 .47549 m .41664 .48869 L .40937 .47601 L .924 .606 .421 r
F
.4037 .46281 m .41001 .47549 L .40937 .47601 L .949 .661 .458 r
F
.41949 .56699 m .45851 .5353 L .41374 .56779 L .703 .982 .888 r
F
.41949 .56699 m .46314 .53475 L .45851 .5353 L F
0 g
.41949 .56699 m
.42469 .5645 L
s
.58714 .49722 m .64079 .51096 L .63862 .52271 L .734 .409 .431 r
F
.65397 .48689 m .64079 .51096 L .63862 .52271 L 0 0 .097 r
F
.65483 .47577 m .64079 .51096 L .65397 .48689 L 0 0 .262 r
F
0 g
.64079 .51096 m
.64187 .49762 L
s
.47096 .52946 m .47038 .53185 L .46731 .53279 L .141 0 0 r
F
.47096 .52946 m .47401 .52852 L .47038 .53185 L F
0 g
.47096 .52946 m
.47306 .52628 L
s
.47401 .52852 m
.47707 .5239 L
s
.5556 .43718 m .56328 .44224 L .56421 .45035 L .969 .687 .442 r
F
.55451 .43082 m .56328 .44224 L .5556 .43718 L F
.49496 .51627 m .49321 .52355 L .49203 .52076 L .964 .688 .462 r
F
.49367 .51365 m .49496 .51627 L .49203 .52076 L F
.24539 .38076 m .25995 .34842 L .26709 .34088 L .863 .956 .612 r
F
.24036 .38923 m .25995 .34842 L .24539 .38076 L .753 .864 .434 r
F
.17458 .42127 m .16821 .39345 L .17353 .38059 L 1 .823 .51 r
F
.17154 .43336 m .16821 .39345 L .17458 .42127 L .998 .808 .459 r
F
.36934 .42036 m .36584 .4023 L .37175 .41859 L .958 .688 .48 r
F
.37606 .43607 m .36934 .42036 L .37175 .41859 L F
.4037 .46281 m .40035 .44882 L .40115 .44878 L .965 .714 .505 r
F
.46034 .4845 m .46504 .49946 L .45909 .48736 L .962 .688 .467 r
F
.45396 .47332 m .46034 .4845 L .45909 .48736 L F
.45458 .47105 m .46034 .4845 L .45396 .47332 L F
.47637 .40015 m .47921 .39111 L .47915 .4029 L .965 .687 .457 r
F
.47637 .40015 m .4755 .38743 L .47921 .39111 L F
.33339 .45853 m .32965 .44615 L .33057 .44142 L .994 .789 .416 r
F
.33308 .46206 m .32965 .44615 L .33339 .45853 L .983 .764 .36 r
F
.20837 .44785 m .19375 .42588 L .19671 .41379 L .974 .727 .501 r
F
.20712 .45805 m .19375 .42588 L .20837 .44785 L .975 .723 .489 r
F
.46504 .49946 m .46842 .51532 L .46299 .50247 L .962 .688 .467 r
F
.45909 .48736 m .46504 .49946 L .46299 .50247 L F
.39244 .48382 m .39324 .49935 L .39134 .48332 L .958 .688 .48 r
F
.39244 .48382 m .39543 .50032 L .39324 .49935 L F
.4931 .45079 m .50008 .45675 L .50026 .46163 L .965 .687 .457 r
F
.49274 .44733 m .50008 .45675 L .4931 .45079 L F
.40508 .38686 m .41782 .3691 L .40907 .38684 L .933 .931 .779 r
F
.4006 .40346 m .40508 .38686 L .40907 .38684 L .958 .891 .721 r
F
.44807 .45966 m .45497 .46844 L .45458 .47105 L .962 .688 .467 r
F
.44815 .45821 m .45497 .46844 L .44807 .45966 L F
.039 .916 .04 r
.41596 .47286 m
.44947 .46211 L
s
.23085 .46381 m .22868 .44577 L .22996 .43481 L .907 .756 .263 r
F
.23065 .47276 m .22868 .44577 L .23085 .46381 L .853 .684 .151 r
F
.53057 .4471 m .53381 .45422 L .5341 .46073 L .955 .705 .253 r
F
.53 .44191 m .53381 .45422 L .53057 .4471 L .938 .673 .202 r
F
.21496 .58402 m .20795 .59169 L .2084 .57446 L .942 .576 .229 r
F
.21496 .58402 m .21679 .60452 L .20795 .59169 L F
.46298 .35492 m .48438 .35253 L .46831 .35788 L .631 .862 .986 r
F
.46563 .36878 m .46831 .35788 L .47007 .37122 L .965 .687 .457 r
F
.46563 .36878 m .46298 .35492 L .46831 .35788 L F
0 g
.46831 .35788 m
.47379 .36218 L
s
.36139 .526 m .36626 .5368 L .35794 .52377 L .837 .368 .014 r
F
.36139 .526 m .37085 .53975 L .36626 .5368 L F
.66537 .33344 m .67506 .33127 L .67032 .34364 L .974 .669 .359 r
F
.66537 .33344 m .66853 .31777 L .67506 .33127 L F
.49367 .51365 m .49203 .52076 L .49085 .51796 L .964 .688 .462 r
F
.49239 .51102 m .49367 .51365 L .49085 .51796 L F
.41664 .48869 m .42351 .50174 L .4152 .48929 L .899 .537 .347 r
F
.41664 .48869 m .42566 .50082 L .42351 .50174 L F
.40937 .47601 m .41664 .48869 L .4152 .48929 L .928 .602 .402 r
F
.50235 .37863 m .50127 .37215 L .50601 .38234 L .858 .419 .003 r
F
.50235 .37863 m .49669 .3675 L .50127 .37215 L F
.65982 .43525 m .65478 .46346 L .6606 .44593 L 0 0 .366 r
F
.6606 .44593 m .65478 .46346 L .65483 .47577 L 0 0 .252 r
F
.46842 .51532 m .47385 .52814 L .47023 .53144 L .962 .688 .467 r
F
.43864 .35799 m .44334 .35664 L .44389 .35955 L .964 .688 .462 r
F
.43864 .35799 m .4379 .35501 L .44334 .35664 L F
0 g
.44334 .35664 m
.44902 .35974 L
s
.39752 .50072 m .39844 .51687 L .39543 .50032 L .958 .688 .48 r
F
.39752 .50072 m .40156 .51744 L .39844 .51687 L F
.53808 .38814 m .54406 .38406 L .54111 .39333 L .969 .687 .442 r
F
.53808 .38814 m .54003 .37716 L .54406 .38406 L F
.40937 .47601 m .4152 .48929 L .40864 .4763 L .928 .602 .402 r
F
.4037 .46281 m .40937 .47601 L .40864 .4763 L .95 .66 .452 r
F
.38208 .45262 m .37468 .43781 L .37606 .43607 L .958 .688 .48 r
F
.38153 .45376 m .37468 .43781 L .38208 .45262 L F
.6321 .22484 m .64183 .22148 L .65243 .23407 L .665 .761 .922 r
F
.65538 .24371 m .65243 .23407 L .66421 .25416 L .748 .292 0 r
F
.65538 .24371 m .64183 .22148 L .65243 .23407 L F
0 g
.65243 .23407 m
.66299 .24891 L
s
.3626 .40462 m .35992 .38599 L .36584 .4023 L .958 .688 .48 r
F
.36934 .42036 m .3626 .40462 L .36584 .4023 L F
.44038 .43835 m .44146 .42768 L .44129 .43922 L .962 .688 .467 r
F
.44038 .43835 m .43963 .42593 L .44146 .42768 L F
.48096 .417 m .48465 .41014 L .48278 .41959 L .965 .687 .457 r
F
.48096 .417 m .48193 .40625 L .48465 .41014 L F
.42566 .50082 m .43385 .51359 L .42351 .50174 L .861 .463 .285 r
F
.42566 .50082 m .4367 .51233 L .43385 .51359 L F
.39962 .4491 m .3986 .43431 L .40035 .44882 L .979 .766 .547 r
F
.4037 .46281 m .39962 .4491 L .40035 .44882 L .967 .714 .5 r
F
.26709 .34088 m .34907 .37301 L .354 .36966 L .69 .226 .144 r
F
.25995 .34842 m .34907 .37301 L .26709 .34088 L .711 .298 .262 r
F
0 g
.26709 .34088 m
.27521 .33595 L
s
.43606 .42372 m .43617 .41156 L .43782 .4246 L .962 .688 .467 r
F
.43606 .42372 m .43353 .41022 L .43617 .41156 L F
.49239 .51102 m .49085 .51796 L .48967 .51516 L .964 .688 .462 r
F
.4911 .50839 m .49239 .51102 L .48967 .51516 L F
.34753 .50553 m .34756 .51252 L .34527 .50256 L .901 .496 .092 r
F
.34753 .50553 m .35096 .51697 L .34756 .51252 L F
.43937 .36096 m .44389 .35955 L .44444 .36246 L .964 .688 .462 r
F
.43937 .36096 m .43864 .35799 L .44389 .35955 L F
.4037 .46281 m .39897 .4496 L .39962 .4491 L .969 .714 .495 r
F
.4037 .46281 m .39841 .45033 L .39897 .4496 L .971 .714 .488 r
F
.4037 .46281 m .39796 .45127 L .39841 .45033 L .972 .713 .482 r
F
.4037 .46281 m .39762 .4524 L .39796 .45127 L .973 .711 .475 r
F
.4037 .46281 m .3974 .45371 L .39762 .4524 L .974 .709 .468 r
F
.4037 .46281 m .3973 .45517 L .3974 .45371 L .974 .706 .461 r
F
.4037 .46281 m .39732 .45676 L .3973 .45517 L .974 .703 .454 r
F
.4037 .46281 m .39747 .45845 L .39732 .45676 L .974 .7 .448 r
F
.4037 .46281 m .39774 .46021 L .39747 .45845 L .974 .696 .442 r
F
.4037 .46281 m .39812 .46202 L .39774 .46021 L .973 .693 .436 r
F
.4037 .46281 m .39861 .46383 L .39812 .46202 L .972 .689 .431 r
F
.4037 .46281 m .39921 .46562 L .39861 .46383 L .971 .685 .428 r
F
.039 .916 .04 r
.38945 .46737 m
.3988 .46438 L
s
.4037 .46281 m .39989 .46736 L .39921 .46562 L .97 .681 .425 r
F
.4037 .46281 m .40066 .46901 L .39989 .46736 L .968 .677 .423 r
F
.4037 .46281 m .40148 .47056 L .40066 .46901 L .967 .674 .422 r
F
.4037 .46281 m .40237 .47196 L .40148 .47056 L .965 .671 .422 r
F
.4037 .46281 m .40328 .4732 L .40237 .47196 L .963 .668 .423 r
F
.4037 .46281 m .40422 .47426 L .40328 .4732 L .961 .666 .425 r
F
.4037 .46281 m .40516 .47512 L .40422 .47426 L .96 .664 .428 r
F
.4037 .46281 m .40609 .47576 L .40516 .47512 L .958 .662 .432 r
F
.4037 .46281 m .40699 .47617 L .40609 .47576 L .956 .661 .436 r
F
.4037 .46281 m .40784 .47636 L .40699 .47617 L .954 .66 .441 r
F
.4037 .46281 m .40864 .4763 L .40784 .47636 L .952 .66 .446 r
F
.2889 .59526 m .29842 .60656 L .28141 .58926 L .6 .07 0 r
F
.2889 .59526 m .30778 .61403 L .29842 .60656 L F
.51239 .39635 m .51325 .39206 L .51509 .40027 L .898 .503 .075 r
F
.51239 .39635 m .50967 .38684 L .51325 .39206 L F
.59616 .44197 m .59439 .46256 L .59663 .44998 L 0 0 .252 r
F
.59663 .44998 m .59439 .46256 L .59427 .47179 L 0 0 .126 r
F
.39714 .43484 m .3986 .41922 L .3986 .43431 L .984 .816 .594 r
F
.39962 .4491 m .39714 .43484 L .3986 .43431 L .979 .766 .547 r
F
.39134 .48332 m .39097 .49783 L .39021 .48255 L .958 .688 .48 r
F
.39134 .48332 m .39324 .49935 L .39097 .49783 L F
.57155 .48368 m .57929 .49584 L .5775 .50422 L .969 .687 .442 r
F
.5724 .47571 m .57929 .49584 L .57155 .48368 L F
.39431 .55568 m .40751 .56687 L .38907 .55487 L .641 .082 0 r
F
.39431 .55568 m .41373 .56779 L .40751 .56687 L F
.58714 .49722 m .63862 .52271 L .5853 .50598 L .734 .409 .431 r
F
.59345 .48011 m .58714 .49722 L .5853 .50598 L 0 0 0 r
F
.59427 .47179 m .58714 .49722 L .59345 .48011 L 0 0 .145 r
F
0 g
.58714 .49722 m
.58814 .48724 L
s
.64747 .28419 m .65413 .2729 L .65463 .29403 L .971 .659 .35 r
F
.64747 .28419 m .64524 .26058 L .65413 .2729 L F
.37468 .43781 m .36934 .42036 L .37606 .43607 L .958 .688 .48 r
F
.43102 .40957 m .43102 .39676 L .43353 .41022 L .962 .688 .467 r
F
.43102 .40957 m .42766 .39586 L .43102 .39676 L F
.4401 .36394 m .44444 .36246 L .44499 .36538 L .964 .688 .462 r
F
.4401 .36394 m .43937 .36096 L .44444 .36246 L F
.40864 .4763 m .41361 .48941 L .40784 .47636 L .932 .599 .382 r
F
.40864 .4763 m .4152 .48929 L .41361 .48941 L F
.35585 .38883 m .354 .36967 L .35992 .38599 L .958 .688 .48 r
F
.3626 .40462 m .35585 .38883 L .35992 .38599 L F
.4911 .50839 m .48967 .51516 L .48849 .51236 L .964 .688 .462 r
F
0 g
.4911 .50839 m
.49317 .50337 L
s
.33308 .46206 m .32918 .45145 L .32965 .44615 L .983 .764 .36 r
F
.33308 .4659 m .32918 .45145 L .33308 .46206 L .969 .734 .301 r
F
.33192 .43733 m .33143 .42109 L .33379 .41663 L .989 .864 .509 r
F
.33057 .44142 m .33143 .42109 L .33192 .43733 L .971 .838 .428 r
F
.38153 .45376 m .37356 .44007 L .37468 .43781 L .958 .688 .48 r
F
.38111 .45513 m .37356 .44007 L .38153 .45376 L F
.37529 .54158 m .38354 .55262 L .37085 .53975 L .745 .223 0 r
F
.37529 .54158 m .38907 .55487 L .38354 .55262 L F
.4367 .51233 m .44672 .52469 L .43385 .51359 L .809 .375 .212 r
F
.4367 .51233 m .45024 .52309 L .44672 .52469 L F
.44787 .46097 m .45458 .47105 L .45396 .47332 L .962 .688 .467 r
F
.44807 .45966 m .45458 .47105 L .44787 .46097 L F
.17963 .47813 m .16918 .46188 L .16972 .44697 L .994 .753 .406 r
F
.18021 .48999 m .16918 .46188 L .17963 .47813 L .989 .733 .367 r
F
.51163 .4968 m .5157 .51424 L .50963 .50175 L .965 .687 .457 r
F
.50516 .48528 m .51163 .4968 L .50963 .50175 L F
.50632 .48057 m .51163 .4968 L .50516 .48528 L F
.39897 .4496 m .39714 .43484 L .39962 .4491 L .984 .767 .531 r
F
.56446 .46507 m .5724 .47571 L .57155 .48368 L .969 .687 .442 r
F
.56461 .458 m .5724 .47571 L .56446 .46507 L F
.40508 .38686 m .41305 .36905 L .41782 .3691 L .933 .931 .779 r
F
0 g
.41782 .3691 m
.42135 .37011 L
s
.49955 .47019 m .50632 .48057 L .50516 .48528 L .965 .687 .457 r
F
.50008 .46614 m .50632 .48057 L .49955 .47019 L F
.4931 .45079 m .50026 .46163 L .49322 .45405 L F
.49322 .45405 m .50026 .46163 L .50008 .46614 L F
.039 .916 .04 r
.47996 .46603 m
.4969 .46054 L
s
.3964 .41999 m .4006 .40346 L .3986 .41922 L .983 .865 .642 r
F
.39714 .43484 m .3964 .41999 L .3986 .41922 L .984 .816 .594 r
F
.44084 .36693 m .44499 .36538 L .44554 .3683 L .964 .688 .462 r
F
.44084 .36693 m .4401 .36394 L .44499 .36538 L F
.5563 .44329 m .56421 .45035 L .56461 .458 L .969 .687 .442 r
F
.5556 .43718 m .56421 .45035 L .5563 .44329 L F
.40156 .51744 m .40145 .53348 L .39844 .51687 L .958 .688 .48 r
F
.40156 .51744 m .40561 .53419 L .40145 .53348 L F
.46842 .51532 m .47023 .53144 L .46539 .51803 L .962 .688 .467 r
F
.46299 .50247 m .46842 .51532 L .46539 .51803 L F
.53425 .50329 m .57514 .51172 L .53193 .50926 L .605 .238 .319 r
F
.53425 .50329 m .57773 .50463 L .57514 .51172 L F
0 g
.57773 .50463 m
.57952 .4962 L
s
.53384 .48992 m .53425 .50329 L .53193 .50926 L .971 .837 .427 r
F
.53522 .48401 m .53425 .50329 L .53384 .48992 L .937 .797 .335 r
F
0 g
.53425 .50329 m
.5359 .49618 L
s
.59018 .40542 m .58898 .40655 L .59152 .41563 L 0 0 .351 r
F
.58794 .39863 m .58898 .40655 L .59018 .40542 L 0 0 .391 r
F
.58794 .39863 m .58601 .39756 L .58898 .40655 L F
.39021 .48255 m .38868 .49578 L .38907 .48152 L .958 .688 .48 r
F
.39021 .48255 m .39097 .49783 L .38868 .49578 L F
.25908 .55809 m .25967 .56219 L .25388 .55034 L .711 .277 0 r
F
.25908 .55809 m .26666 .57258 L .25967 .56219 L F
.17353 .38059 m .17124 .34879 L .17929 .33644 L .996 .863 .559 r
F
.17124 .34879 m .18596 .3341 L .17929 .33644 L .308 0 .106 r
F
0 g
.17929 .33644 m
.18874 .32724 L
s
.34059 .39392 m .34907 .37301 L .354 .36966 L .926 .971 .693 r
F
0 g
.354 .36966 m
.35948 .36802 L
s
.35585 .38883 m .34908 .37301 L .354 .36967 L .958 .688 .48 r
F
.34908 .37301 m .40868 .37043 L .354 .36967 L .406 0 0 r
F
0 g
.354 .36967 m
.35949 .36802 L
s
.43947 .43769 m .43963 .42593 L .44038 .43835 L .962 .688 .467 r
F
.43947 .43769 m .43782 .4246 L .43963 .42593 L F
.58541 .39201 m .58601 .39756 L .58794 .39863 L 0 0 .417 r
F
.58541 .39201 m .58266 .3888 L .58601 .39756 L F
.6912 .4119 m .70265 .42145 L .70466 .43586 L .979 .686 .376 r
F
.68906 .40058 m .70265 .42145 L .6912 .4119 L .978 .683 .372 r
F
.4152 .48929 m .42114 .50195 L .41361 .48941 L .903 .528 .308 r
F
.4152 .48929 m .42351 .50174 L .42114 .50195 L F
.44157 .36991 m .44554 .3683 L .4461 .37122 L .964 .688 .462 r
F
.44157 .36991 m .44084 .36693 L .44554 .3683 L F
.34527 .50256 m .34429 .50745 L .3431 .49919 L .895 .499 .066 r
F
.34527 .50256 m .34756 .51252 L .34429 .50745 L F
.6535 .38592 m .64994 .38805 L .65335 .40016 L 0 0 .478 r
F
.65051 .37684 m .64994 .38805 L .6535 .38592 L 0 0 .519 r
F
.65051 .37684 m .64599 .37606 L .64994 .38805 L F
.40784 .47636 m .4119 .48907 L .40699 .47617 L .936 .597 .362 r
F
.40784 .47636 m .41361 .48941 L .4119 .48907 L F
.61475 .31649 m .60499 .31243 L .62046 .3241 L 0 .221 .737 r
F
.61475 .31649 m .59785 .30293 L .60499 .31243 L F
.45909 .48736 m .46299 .50247 L .45754 .4896 L .962 .688 .467 r
F
.45312 .47522 m .45909 .48736 L .45754 .4896 L F
.45396 .47332 m .45909 .48736 L .45312 .47522 L F
.53057 .4471 m .5341 .46073 L .53079 .452 L .955 .705 .253 r
F
.53079 .452 m .5341 .46073 L .53392 .46674 L .971 .734 .305 r
F
.64716 .36799 m .64599 .37606 L .65051 .37684 L 0 0 .548 r
F
.64716 .36799 m .64156 .36437 L .64599 .37606 L F
.38111 .45513 m .37271 .4428 L .37356 .44007 L .958 .688 .48 r
F
.38083 .45671 m .37271 .4428 L .38111 .45513 L F
.41305 .36905 m .4161 .36803 L .42086 .36809 L .454 .881 .907 r
F
0 g
.42086 .36809 m
.42593 .36954 L
s
.4161 .36803 m
.42086 .36809 L
s
.26729 .62551 m .26069 .64548 L .25787 .61818 L .947 .63 .401 r
F
.26729 .62551 m .27253 .65455 L .26069 .64548 L F
.4791 .41477 m .48193 .40625 L .48096 .417 L .965 .687 .457 r
F
.4791 .41477 m .47915 .4029 L .48193 .40625 L F
.42037 .38217 m .42096 .3685 L .42431 .38217 L .962 .688 .467 r
F
.42037 .38217 m .41622 .36845 L .42096 .3685 L F
.56215 .35319 m .55699 .34927 L .56654 .35881 L 0 .055 .591 r
F
.56215 .35319 m .5515 .34226 L .55699 .34927 L F
.5921 .41228 m .59152 .41563 L .59358 .42466 L 0 0 .296 r
F
.59018 .40542 m .59152 .41563 L .5921 .41228 L 0 0 .351 r
F
.52396 .32028 m .56542 .28248 L .5305 .32574 L .864 .835 .817 r
F
.52396 .32028 m .55688 .27496 L .56542 .28248 L F
.58365 .28874 m .56542 .28248 L .5907 .29499 L 0 .394 .827 r
F
.58365 .28874 m .55688 .27496 L .56542 .28248 L F
0 g
.56542 .28248 m
.57405 .29199 L
s
.7152 .36704 m .71811 .36736 L .72251 .38282 L .85 .538 .008 r
F
.71138 .35541 m .71811 .36736 L .7152 .36704 L .842 .516 0 r
F
.71138 .35541 m .71307 .35203 L .71811 .36736 L F
.39543 .50032 m .39515 .51545 L .39324 .49935 L .958 .688 .48 r
F
.39543 .50032 m .39844 .51687 L .39515 .51545 L F
.39897 .4496 m .39584 .43584 L .39714 .43484 L .984 .767 .531 r
F
.39841 .45033 m .39584 .43584 L .39897 .4496 L .988 .766 .512 r
F
.44113 .45083 m .44679 .44962 L .44728 .45142 L .962 .688 .467 r
F
.44113 .45083 m .4462 .44784 L .44679 .44962 L F
.44113 .45083 m .44553 .44612 L .4462 .44784 L F
.4423 .37289 m .4461 .37122 L .44665 .37414 L .964 .688 .462 r
F
0 g
.44665 .37414 m
.45119 .37658 L
s
.4423 .37289 m .44157 .36991 L .4461 .37122 L .964 .688 .462 r
F
.53327 .47215 m .53522 .48401 L .53384 .48992 L .977 .794 .377 r
F
.53392 .46674 m .53522 .48401 L .53327 .47215 L .953 .76 .304 r
F
.44113 .45083 m .44728 .45142 L .44767 .4532 L .962 .688 .467 r
F
.24909 .58394 m .23929 .59761 L .24227 .57554 L .956 .653 .419 r
F
.24909 .58394 m .24848 .60883 L .23929 .59761 L F
.33308 .4659 m .32918 .45723 L .32918 .45145 L .969 .734 .301 r
F
.33339 .46999 m .32918 .45723 L .33308 .4659 L .952 .7 .243 r
F
.53493 .38351 m .54003 .37716 L .53808 .38814 L .969 .687 .442 r
F
.53493 .38351 m .53586 .37099 L .54003 .37716 L F
.70712 .34407 m .71307 .35203 L .71138 .35541 L .84 .498 0 r
F
.70712 .34407 m .70746 .33706 L .71307 .35203 L F
.44113 .45083 m .44478 .44447 L .44553 .44612 L .962 .688 .467 r
F
.16821 .39345 m .17124 .34879 L .17353 .38059 L .993 .85 .498 r
F
.28416 .66092 m .27887 .68367 L .27253 .65455 L .939 .611 .385 r
F
.28416 .66092 m .29285 .69113 L .27887 .68367 L F
.58263 .38568 m .58266 .3888 L .58541 .39201 L 0 0 .429 r
F
.58263 .38568 m .57898 .38041 L .58266 .3888 L F
.39584 .43584 m .3964 .41999 L .39714 .43484 L .993 .82 .568 r
F
.65608 .39509 m .65335 .40016 L .65616 .41218 L 0 0 .426 r
F
.6535 .38592 m .65335 .40016 L .65608 .39509 L 0 0 .478 r
F
.39766 .40446 m .40508 .38686 L .4006 .40346 L .971 .913 .691 r
F
.3964 .41999 m .39766 .40446 L .4006 .40346 L .983 .865 .642 r
F
.47362 .39805 m .4755 .38743 L .47637 .40015 L .965 .687 .457 r
F
.47362 .39805 m .47184 .38461 L .4755 .38743 L F
.44113 .45083 m .44767 .4532 L .44795 .45495 L .962 .688 .467 r
F
.38907 .48152 m .38639 .49323 L .38793 .48025 L .958 .688 .48 r
F
.38907 .48152 m .38868 .49578 L .38639 .49323 L F
.73117 .42764 m .73664 .45993 L .73239 .44129 L .842 .613 .068 r
F
.73239 .44129 m .73664 .45993 L .73708 .47568 L .882 .664 .141 r
F
.44113 .45083 m .44397 .44294 L .44478 .44447 L .962 .688 .467 r
F
.33379 .41663 m .33702 .39815 L .34059 .39392 L .965 .922 .586 r
F
.33143 .42109 m .33702 .39815 L .33379 .41663 L .931 .891 .482 r
F
.44756 .4621 m .45396 .47332 L .45312 .47522 L .962 .688 .467 r
F
.44787 .46097 m .45396 .47332 L .44756 .4621 L F
.039 .916 .04 r
.45131 .46153 m
.47005 .45548 L
s
.36726 .42295 m .3626 .40462 L .36934 .42036 L .958 .688 .48 r
F
.37468 .43781 m .36726 .42295 L .36934 .42036 L F
.48438 .35253 m .51866 .32587 L .52498 .3311 L .785 .839 .892 r
F
0 g
.52498 .3311 m
.53137 .33781 L
s
.23221 .42506 m .23639 .39964 L .24036 .38923 L .869 .844 .38 r
F
.22996 .43481 m .23639 .39964 L .23221 .42506 L .77 .739 .215 r
F
.40699 .47617 m .4101 .48825 L .40609 .47576 L .94 .596 .342 r
F
.40699 .47617 m .4119 .48907 L .4101 .48825 L F
.23065 .47276 m .2284 .45777 L .22868 .44577 L .853 .684 .151 r
F
.2312 .4823 m .2284 .45777 L .23065 .47276 L .795 .604 .042 r
F
.35794 .52377 m .36159 .53278 L .35444 .52075 L .812 .339 0 r
F
.35794 .52377 m .36626 .5368 L .36159 .53278 L F
.46828 .38269 m .47007 .37122 L .47184 .38461 L .965 .687 .457 r
F
.46828 .38269 m .46563 .36878 L .47007 .37122 L F
.33702 .39815 m .34907 .37301 L .34059 .39392 L .877 .943 .578 r
F
.52093 .34205 m .52501 .33154 L .52618 .34635 L .969 .687 .442 r
F
.52093 .34205 m .51873 .32634 L .52501 .33154 L F
.44113 .45083 m .44795 .45495 L .44811 .45663 L .962 .688 .467 r
F
.38083 .45671 m .37214 .44596 L .37271 .4428 L .958 .688 .48 r
F
.3807 .45848 m .37214 .44596 L .38083 .45671 L F
.52735 .36124 m .53149 .35189 L .53161 .36565 L .969 .687 .442 r
F
.52735 .36124 m .52618 .34635 L .53149 .35189 L F
.40561 .53419 m .40448 .55014 L .40145 .53348 L .958 .688 .48 r
F
.40561 .53419 m .40967 .55098 L .40448 .55014 L F
.50964 .39298 m .50967 .38684 L .51239 .39635 L .906 .505 .104 r
F
.50964 .39298 m .50601 .38234 L .50967 .38684 L F
.64349 .35951 m .64156 .36437 L .64716 .36799 L 0 0 .565 r
F
.64349 .35951 m .63671 .35315 L .64156 .36437 L F
.43438 .4233 m .43353 .41022 L .43606 .42372 L .962 .688 .467 r
F
.43438 .4233 m .43102 .40957 L .43353 .41022 L F
.37356 .44007 m .36726 .42295 L .37468 .43781 L .958 .688 .48 r
F
.71853 .37876 m .72251 .38282 L .72619 .39818 L .863 .565 .039 r
F
.7152 .36704 m .72251 .38282 L .71853 .37876 L .85 .538 .008 r
F
.54059 .3319 m .5305 .32574 L .54601 .33643 L 0 .202 .664 r
F
.54059 .3319 m .52396 .32028 L .5305 .32574 L F
0 g
.5305 .32574 m
.53711 .33273 L
s
.3431 .49919 m .34122 .50186 L .34106 .49548 L .89 .506 .05 r
F
.3431 .49919 m .34429 .50745 L .34122 .50186 L F
.5157 .51424 m .52896 .51399 L .51269 .51897 L .303 0 .056 r
F
.5157 .51424 m .53193 .50926 L .52896 .51399 L F
.50963 .50175 m .5157 .51424 L .51269 .51897 L .965 .687 .457 r
F
0 g
.5157 .51424 m
.51808 .50827 L
s
.44113 .45083 m .4431 .44153 L .44397 .44294 L .962 .688 .467 r
F
.42351 .50174 m .43071 .5139 L .42114 .50195 L .862 .441 .222 r
F
.42351 .50174 m .43385 .51359 L .43071 .5139 L F
.46299 .50247 m .46539 .51803 L .46055 .50461 L .962 .688 .467 r
F
.45754 .4896 m .46299 .50247 L .46055 .50461 L F
.39841 .45033 m .39472 .43728 L .39584 .43584 L .988 .766 .512 r
F
.39796 .45127 m .39472 .43728 L .39841 .45033 L .992 .763 .49 r
F
.66019 .32403 m .66853 .31777 L .66537 .33344 L .973 .667 .36 r
F
.66019 .32403 m .66169 .30529 L .66853 .31777 L F
.2084 .57446 m .19969 .57742 L .20227 .56385 L .946 .587 .221 r
F
.2084 .57446 m .20795 .59169 L .19969 .57742 L F
.59366 .41909 m .59358 .42466 L .59514 .43349 L 0 0 .226 r
F
.5921 .41228 m .59358 .42466 L .59366 .41909 L 0 0 .296 r
F
.42452 .39589 m .42431 .38217 L .42766 .39586 L .962 .688 .467 r
F
.42452 .39589 m .42037 .38217 L .42431 .38217 L F
.49309 .45705 m .50008 .46614 L .49955 .47019 L .965 .687 .457 r
F
.49322 .45405 m .50008 .46614 L .49309 .45705 L F
.44113 .45083 m .44811 .45663 L .44815 .45821 L .962 .688 .467 r
F
.18895 .37528 m .17796 .34644 L .18596 .3341 L .98 .759 .532 r
F
.17124 .34879 m .17796 .34644 L .18596 .3341 L .308 0 .106 r
F
0 g
.18596 .3341 m
.19536 .32491 L
s
.43859 .43726 m .43782 .4246 L .43947 .43769 L .962 .688 .467 r
F
.43859 .43726 m .43606 .42372 L .43782 .4246 L F
.38793 .48025 m .38415 .49024 L .38681 .47875 L .958 .688 .48 r
F
.38793 .48025 m .38639 .49323 L .38415 .49024 L F
.52338 .42575 m .52632 .42542 L .52786 .43098 L .957 .645 .228 r
F
.52217 .42206 m .52632 .42542 L .52338 .42575 L .952 .629 .212 r
F
.52217 .42206 m .5245 .41992 L .52632 .42542 L F
.33339 .46999 m .32964 .46339 L .32918 .45723 L .952 .7 .243 r
F
.039 .916 .04 r
.2372 .48035 m
.32926 .45826 L
s
.334 .47425 m .32964 .46339 L .33339 .46999 L .934 .663 .188 r
F
.52078 .41848 m .5245 .41992 L .52217 .42206 L .948 .615 .201 r
F
.52078 .41848 m .52244 .41457 L .5245 .41992 L F
.44113 .45083 m .44221 .44029 L .4431 .44153 L .962 .688 .467 r
F
.47909 .34954 m .51866 .32587 L .48438 .35253 L .796 .889 .912 r
F
.46298 .35492 m .47909 .34954 L .48438 .35253 L .631 .862 .986 r
F
.48776 .36145 m .48438 .35253 L .49216 .36391 L .838 .37 .015 r
F
.48776 .36145 m .47909 .34954 L .48438 .35253 L F
0 g
.48438 .35253 m
.48982 .35686 L
s
.48468 .43751 m .49032 .43633 L .49134 .44003 L .965 .687 .457 r
F
.48407 .43567 m .49032 .43633 L .48468 .43751 L F
.48407 .43567 m .48911 .43266 L .49032 .43633 L F
.49439 .52635 m .49557 .52914 L .49171 .53275 L .964 .688 .462 r
F
0 g
.49557 .52914 m
.4988 .52413 L
s
.48337 .43388 m .48911 .43266 L .48407 .43567 L .965 .687 .457 r
F
.48337 .43388 m .48772 .42909 L .48911 .43266 L F
.7025 .33318 m .70746 .33706 L .70712 .34407 L .842 .486 0 r
F
.7025 .33318 m .70136 .32268 L .70746 .33706 L F
.40609 .47576 m .40825 .48698 L .40516 .47512 L .944 .596 .323 r
F
.40609 .47576 m .4101 .48825 L .40825 .48698 L F
.23547 .62497 m .23307 .63859 L .22602 .61568 L .904 .491 .142 r
F
.23547 .62497 m .24495 .65018 L .23307 .63859 L F
.41361 .48941 m .41859 .50145 L .4119 .48907 L .907 .518 .267 r
F
.41361 .48941 m .42114 .50195 L .41859 .50145 L F
.3807 .45848 m .37187 .4495 L .37214 .44596 L .958 .688 .48 r
F
.38072 .4604 m .37187 .4495 L .3807 .45848 L F
.52442 .42947 m .52786 .43098 L .5291 .43651 L .963 .662 .248 r
F
.52338 .42575 m .52786 .43098 L .52442 .42947 L .957 .645 .228 r
F
.72854 .51781 m .73624 .53001 L .72633 .53293 L .483 .182 .379 r
F
.72854 .51781 m .73838 .51488 L .73624 .53001 L F
.71716 .49574 m .72854 .51781 L .72633 .53293 L .983 .702 .393 r
F
.71794 .48148 m .72854 .51781 L .71716 .49574 L .983 .699 .384 r
F
0 g
.72854 .51781 m
.7294 .50068 L
s
.48519 .43937 m .49134 .44003 L .49216 .44372 L .965 .687 .457 r
F
.48468 .43751 m .49134 .44003 L .48519 .43937 L F
.49873 .37577 m .49669 .3675 L .50235 .37863 L .875 .437 .063 r
F
.49873 .37577 m .49216 .36391 L .49669 .3675 L F
.57965 .37974 m .57898 .38041 L .58263 .38568 L 0 0 .424 r
F
.57965 .37974 m .57502 .37253 L .57898 .38041 L F
.44113 .45083 m .44815 .45821 L .44807 .45966 L .962 .688 .467 r
F
.33057 .44142 m .32961 .42652 L .33143 .42109 L .971 .838 .428 r
F
.32965 .44615 m .32961 .42652 L .33057 .44142 L .939 .794 .333 r
F
.51925 .41505 m .52244 .41457 L .52078 .41848 L .946 .603 .197 r
F
.51925 .41505 m .52015 .40946 L .52244 .41457 L F
.4826 .43217 m .48772 .42909 L .48337 .43388 L .965 .687 .457 r
F
.4826 .43217 m .48619 .42569 L .48772 .42909 L F
.49439 .52635 m .49171 .53275 L .49065 .52983 L .964 .688 .462 r
F
.49321 .52355 m .49439 .52635 L .49065 .52983 L F
.34106 .49548 m .33839 .49585 L .33919 .4915 L .887 .519 .045 r
F
.34106 .49548 m .34122 .50186 L .33839 .49585 L F
.39796 .45127 m .39381 .43915 L .39472 .43728 L .992 .763 .49 r
F
.39762 .4524 m .39381 .43915 L .39796 .45127 L .993 .758 .467 r
F
.65821 .40418 m .65616 .41218 L .65833 .42395 L 0 0 .359 r
F
.65608 .39509 m .65616 .41218 L .65821 .40418 L 0 0 .426 r
F
.20712 .45805 m .19201 .43952 L .19375 .42588 L .975 .723 .489 r
F
.20681 .46919 m .19201 .43952 L .20712 .45805 L .976 .718 .477 r
F
.5563 .44329 m .56461 .458 L .55658 .44904 L .969 .687 .442 r
F
.55658 .44904 m .56461 .458 L .56446 .46507 L F
.039 .916 .04 r
.53446 .46192 m
.55901 .45398 L
s
.38681 .47875 m .382 .48684 L .38574 .47706 L .958 .688 .48 r
F
.38681 .47875 m .38415 .49024 L .382 .48684 L F
.44113 .45083 m .44129 .43922 L .44221 .44029 L .962 .688 .467 r
F
.47724 .41294 m .47915 .4029 L .4791 .41477 L .965 .687 .457 r
F
.47724 .41294 m .47637 .40015 L .47915 .4029 L F
.39444 .42146 m .39766 .40446 L .3964 .41999 L .992 .873 .605 r
F
.39584 .43584 m .39444 .42146 L .3964 .41999 L .993 .82 .568 r
F
.4856 .44123 m .49216 .44372 L .49274 .44733 L .965 .687 .457 r
F
.48519 .43937 m .49216 .44372 L .4856 .44123 L F
.334 .47425 m .33056 .46981 L .32964 .46339 L .934 .663 .188 r
F
.33491 .47861 m .33056 .46981 L .334 .47425 L .917 .627 .14 r
F
.49321 .52355 m .49065 .52983 L .4896 .5269 L .964 .688 .462 r
F
.49203 .52076 m .49321 .52355 L .4896 .5269 L F
.18021 .48999 m .16995 .47782 L .16918 .46188 L .989 .733 .367 r
F
.18175 .50236 m .16995 .47782 L .18021 .48999 L .982 .71 .329 r
F
.39324 .49935 m .39174 .51319 L .39097 .49783 L .958 .688 .48 r
F
.39324 .49935 m .39515 .51545 L .39174 .51319 L F
.40142 .38805 m .41305 .36905 L .40508 .38686 L .941 .959 .743 r
F
0 g
.41305 .36905 m
.41641 .36909 L
s
.39766 .40446 m .40142 .38805 L .40508 .38686 L .971 .913 .691 r
F
.38072 .4604 m .37191 .45336 L .37187 .4495 L .958 .688 .48 r
F
.38089 .46244 m .37191 .45336 L .38072 .4604 L F
.039 .916 .04 r
.33782 .46981 m
.37606 .45756 L
s
.39472 .43728 m .39444 .42146 L .39584 .43584 L .998 .82 .534 r
F
.31698 .61936 m .33562 .63051 L .30778 .61403 L .368 0 0 r
F
.31698 .61936 m .34658 .63685 L .33562 .63051 L F
.52524 .43317 m .5291 .43651 L .53 .44191 L .97 .68 .273 r
F
.52442 .42947 m .5291 .43651 L .52524 .43317 L .963 .662 .248 r
F
.40967 .55098 m .40751 .56686 L .40448 .55014 L .958 .688 .48 r
F
.40967 .55098 m .41374 .56779 L .40751 .56686 L F
0 g
.41373 .56779 m
.41949 .56699 L
s
.25388 .55034 m .25312 .55066 L .24901 .54176 L .675 .272 0 r
F
.25388 .55034 m .25967 .56219 L .25312 .55066 L F
.45312 .47522 m .45754 .4896 L .45208 .4767 L .962 .688 .467 r
F
.44714 .46304 m .45312 .47522 L .45208 .4767 L F
.44756 .4621 m .45312 .47522 L .44714 .46304 L F
.40516 .47512 m .40636 .48527 L .40422 .47426 L .947 .597 .306 r
F
.40516 .47512 m .40825 .48698 L .40636 .48527 L F
.48177 .43057 m .48619 .42569 L .4826 .43217 L .965 .687 .457 r
F
.48177 .43057 m .48453 .4225 L .48619 .42569 L F
.42867 .40962 m .42766 .39586 L .43102 .40957 L .962 .688 .467 r
F
.42867 .40962 m .42452 .39589 L .42766 .39586 L F
.44113 .45083 m .44807 .45966 L .44787 .46097 L F
.33919 .4915 m .33588 .48952 L .33753 .48731 L .888 .538 .051 r
F
.33919 .4915 m .33839 .49585 L .33588 .48952 L F
.50516 .48528 m .50963 .50175 L .50354 .48923 L .965 .687 .457 r
F
.49866 .47372 m .50516 .48528 L .50354 .48923 L F
.49955 .47019 m .50516 .48528 L .49866 .47372 L F
.49203 .52076 m .4896 .5269 L .48854 .52398 L .964 .688 .462 r
F
.49085 .51796 m .49203 .52076 L .48854 .52398 L F
.35981 .40803 m .35585 .38883 L .3626 .40462 L .958 .688 .48 r
F
.36726 .42295 m .35981 .40803 L .3626 .40462 L F
.53065 .45651 m .53392 .46674 L .53327 .47215 L .984 .759 .357 r
F
.53079 .452 m .53392 .46674 L .53065 .45651 L .971 .734 .305 r
F
.45754 .4896 m .46055 .50461 L .4557 .49118 L .962 .688 .467 r
F
.45208 .4767 m .45754 .4896 L .4557 .49118 L F
.54492 .41907 m .55123 .41778 L .55304 .42432 L .969 .687 .442 r
F
.54349 .41473 m .55123 .41778 L .54492 .41907 L F
.54349 .41473 m .54909 .41131 L .55123 .41778 L F
.38574 .47706 m .37997 .4831 L .38474 .4752 L .958 .688 .48 r
F
.38574 .47706 m .382 .48684 L .37997 .4831 L F
.59654 .45737 m .59427 .47179 L .59345 .48011 L 0 0 0 r
F
.59663 .44998 m .59427 .47179 L .59654 .45737 L 0 0 .126 r
F
.5176 .41184 m .52015 .40946 L .51925 .41505 L .945 .594 .198 r
F
.5176 .41184 m .51769 .40466 L .52015 .40946 L F
.46731 .53279 m .47038 .53185 L .46622 .53381 L 0 0 0 r
F
0 g
.46731 .53279 m
.46987 .53045 L
s
.47038 .53185 m
.47401 .52852 L
s
.39844 .51687 m .39706 .53162 L .39515 .51545 L .958 .688 .48 r
F
.39844 .51687 m .40145 .53348 L .39706 .53162 L F
.39762 .4524 m .39313 .44141 L .39381 .43915 L .993 .758 .467 r
F
.3974 .45371 m .39313 .44141 L .39762 .4524 L .994 .75 .441 r
F
.33491 .47861 m .33193 .47639 L .33056 .46981 L .917 .627 .14 r
F
.33609 .48299 m .33193 .47639 L .33491 .47861 L .903 .593 .099 r
F
.54186 .41051 m .54909 .41131 L .54349 .41473 L .969 .687 .442 r
F
.54186 .41051 m .54666 .40501 L .54909 .41131 L F
.63958 .35152 m .63671 .35315 L .64349 .35951 L 0 0 .569 r
F
.63958 .35152 m .63152 .34259 L .63671 .35315 L F
.44113 .45083 m .44038 .43835 L .44129 .43922 L .962 .688 .467 r
F
.43385 .51359 m .44282 .52512 L .43071 .5139 L .8 .331 .116 r
F
.43385 .51359 m .44672 .52469 L .44282 .52512 L F
.19671 .41379 m .1837 .38813 L .18895 .37528 L .978 .743 .513 r
F
.19375 .42588 m .1837 .38813 L .19671 .41379 L .98 .739 .497 r
F
.38089 .46244 m .37225 .45746 L .37191 .45336 L .958 .688 .48 r
F
.38121 .46457 m .37225 .45746 L .38089 .46244 L F
.72131 .39039 m .72619 .39818 L .72909 .41319 L .88 .596 .077 r
F
.71853 .37876 m .72619 .39818 L .72131 .39039 L .863 .565 .039 r
F
.48589 .44304 m .49274 .44733 L .4931 .45079 L .965 .687 .457 r
F
.4856 .44123 m .49274 .44733 L .48589 .44304 L F
.33753 .48731 m .33371 .483 L .33609 .48299 L .893 .563 .07 r
F
.33753 .48731 m .33588 .48952 L .33371 .483 L F
.49085 .51796 m .48854 .52398 L .48749 .52105 L .964 .688 .462 r
F
.48967 .51516 m .49085 .51796 L .48749 .52105 L F
.59483 .42575 m .59514 .43349 L .59616 .44197 L 0 0 .142 r
F
.59366 .41909 m .59514 .43349 L .59483 .42575 L 0 0 .226 r
F
.33609 .48299 m .33371 .483 L .33193 .47639 L .903 .593 .099 r
F
.54614 .42346 m .55304 .42432 L .55451 .43082 L .969 .687 .442 r
F
.54492 .41907 m .55304 .42432 L .54614 .42346 L F
.37356 .44007 m .36556 .42631 L .36726 .42295 L .958 .688 .48 r
F
.37271 .4428 m .36556 .42631 L .37356 .44007 L F
.43775 .43705 m .43606 .42372 L .43859 .43726 L .962 .688 .467 r
F
.43775 .43705 m .43438 .4233 L .43606 .42372 L F
.45788 .35336 m .47909 .34954 L .46298 .35492 L .576 .898 .984 r
F
.46138 .36753 m .46298 .35492 L .46563 .36878 L .965 .687 .457 r
F
.46138 .36753 m .45788 .35336 L .46298 .35492 L F
0 g
.46298 .35492 m
.46831 .35788 L
s
.67398 .27531 m .67304 .26655 L .68106 .28523 L .807 .384 0 r
F
.67398 .27531 m .66421 .25416 L .67304 .26655 L F
.38474 .4752 m .37811 .47909 L .38381 .4732 L .958 .688 .48 r
F
.38474 .4752 m .37997 .4831 L .37811 .47909 L F
.70603 .46209 m .71794 .48148 L .71716 .49574 L .982 .696 .388 r
F
.7058 .44948 m .71794 .48148 L .70603 .46209 L .981 .693 .381 r
F
.53173 .37952 m .53586 .37099 L .53493 .38351 L .969 .687 .442 r
F
.53173 .37952 m .53161 .36565 L .53586 .37099 L F
.40422 .47426 m .40448 .48316 L .40328 .4732 L .95 .6 .291 r
F
.40422 .47426 m .40636 .48527 L .40448 .48316 L F
.48089 .42911 m .48453 .4225 L .48177 .43057 L .965 .687 .457 r
F
.48089 .42911 m .48278 .41959 L .48453 .4225 L F
.44113 .45083 m .44787 .46097 L .44756 .4621 L .962 .688 .467 r
F
.48967 .51516 m .48749 .52105 L .48643 .51813 L .964 .688 .462 r
F
.48849 .51236 m .48967 .51516 L .48643 .51813 L F
.38121 .46457 m .37288 .46174 L .37225 .45746 L .958 .688 .48 r
F
.38167 .46675 m .37288 .46174 L .38121 .46457 L F
.54007 .40648 m .54666 .40501 L .54186 .41051 L .969 .687 .442 r
F
.54007 .40648 m .54399 .39898 L .54666 .40501 L F
.37085 .53975 m .37782 .54897 L .36626 .5368 L .687 .156 0 r
F
.37085 .53975 m .38354 .55262 L .37782 .54897 L F
.2312 .4823 m .22914 .47058 L .2284 .45777 L .795 .604 .042 r
F
.23251 .49225 m .22914 .47058 L .2312 .4823 L .738 .525 0 r
F
.66066 .4558 m .65483 .47577 L .65397 .48689 L 0 0 .108 r
F
.6606 .44593 m .65483 .47577 L .66066 .4558 L 0 0 .252 r
F
.52585 .43679 m .53 .44191 L .53057 .4471 L .976 .698 .302 r
F
.52524 .43317 m .53 .44191 L .52585 .43679 L .97 .68 .273 r
F
.4119 .48907 m .41589 .50025 L .4101 .48825 L .908 .509 .225 r
F
.4119 .48907 m .41859 .50145 L .41589 .50025 L F
.38381 .4732 m .37644 .47487 L .38298 .4711 L .958 .688 .48 r
F
.38381 .4732 m .37811 .47909 L .37644 .47487 L F
.46539 .51803 m .47023 .53144 L .46609 .53339 L .962 .688 .467 r
F
0 g
.46622 .53381 m
.47038 .53185 L
s
.3974 .45371 m .39268 .44403 L .39313 .44141 L .994 .75 .441 r
F
.3973 .45517 m .39268 .44403 L .3974 .45371 L .992 .74 .415 r
F
.44113 .45083 m .43947 .43769 L .44038 .43835 L .962 .688 .467 r
F
.49273 .45975 m .49955 .47019 L .49866 .47372 L .965 .687 .457 r
F
.49309 .45705 m .49955 .47019 L .49273 .45975 L F
.38167 .46675 m .3738 .46612 L .37288 .46174 L .958 .688 .48 r
F
.38226 .46894 m .3738 .46612 L .38167 .46675 L F
.35444 .52075 m .35694 .52775 L .35096 .51697 L .779 .312 0 r
F
.35444 .52075 m .36159 .53278 L .35694 .52775 L F
.50963 .50175 m .51269 .51897 L .5071 .50566 L .965 .687 .457 r
F
.50354 .48923 m .50963 .50175 L .5071 .50566 L F
.69269 .42278 m .70466 .43586 L .7058 .44948 L .98 .688 .381 r
F
.6912 .4119 m .70466 .43586 L .69269 .42278 L .979 .686 .376 r
F
.48849 .51236 m .48643 .51813 L .48538 .5152 L .964 .688 .462 r
F
0 g
.48849 .51236 m
.4911 .50839 L
s
.38298 .4711 m .375 .47052 L .38226 .46894 L .958 .688 .48 r
F
.38298 .4711 m .37644 .47487 L .375 .47052 L F
.38226 .46894 m .375 .47052 L .3738 .46612 L F
.57155 .48368 m .5775 .50422 L .57003 .49064 L .969 .687 .442 r
F
.56376 .47144 m .57155 .48368 L .57003 .49064 L F
.56446 .46507 m .57155 .48368 L .56376 .47144 L F
.43282 .42335 m .43102 .40957 L .43438 .4233 L .962 .688 .467 r
F
.43282 .42335 m .42867 .40962 L .43102 .40957 L F
.57651 .37429 m .57502 .37253 L .57965 .37974 L 0 0 .402 r
F
.57651 .37429 m .57085 .36529 L .57502 .37253 L F
.50689 .3902 m .50601 .38234 L .50964 .39298 L .912 .51 .139 r
F
.50689 .3902 m .50235 .37863 L .50601 .38234 L F
.20227 .56385 m .19215 .56197 L .19669 .55238 L .95 .602 .22 r
F
.20227 .56385 m .19969 .57742 L .19215 .56197 L F
.54712 .42782 m .55451 .43082 L .5556 .43718 L .969 .687 .442 r
F
.54614 .42346 m .55451 .43082 L .54712 .42782 L F
.48607 .44477 m .4931 .45079 L .49322 .45405 L .965 .687 .457 r
F
.48589 .44304 m .4931 .45079 L .48607 .44477 L F
.42114 .50195 m .42732 .51326 L .41859 .50145 L .859 .416 .151 r
F
.42114 .50195 m .43071 .5139 L .42732 .51326 L F
.41374 .56779 m .45349 .53441 L .40751 .56686 L .758 .959 .936 r
F
.41374 .56779 m .45851 .5353 L .45349 .53441 L F
0 g
.41374 .56779 m
.41949 .56699 L
s
.43371 .35789 m .4379 .35501 L .43864 .35799 L .964 .688 .462 r
F
.43371 .35789 m .4328 .3549 L .4379 .35501 L F
0 g
.4379 .35501 m
.44334 .35664 L
s
.40328 .4732 m .40264 .48067 L .40237 .47196 L .953 .604 .279 r
F
.40328 .4732 m .40448 .48316 L .40264 .48067 L F
.51586 .40891 m .51769 .40466 L .5176 .41184 L .944 .587 .204 r
F
.51586 .40891 m .51509 .40027 L .51769 .40466 L F
.69758 .32291 m .70136 .32268 L .7025 .33318 L .848 .478 0 r
F
.69758 .32291 m .69486 .3091 L .70136 .32268 L F
.47095 .39664 m .47184 .38461 L .47362 .39805 L .965 .687 .457 r
F
.47095 .39664 m .46828 .38269 L .47184 .38461 L F
.36556 .42631 m .35981 .40803 L .36726 .42295 L .958 .688 .48 r
F
.73639 .48995 m .73838 .51488 L .73624 .53001 L .903 .743 .243 r
F
.73708 .47568 m .73838 .51488 L .73639 .48995 L .848 .681 .145 r
F
0 g
.73838 .51488 m
.73918 .49775 L
s
.44113 .45083 m .44756 .4621 L .44714 .46304 L .962 .688 .467 r
F
.46539 .51803 m .46609 .53339 L .46193 .51962 L F
0 g
.46478 .53397 m
.46608 .53336 L
s
.46055 .50461 m .46539 .51803 L .46193 .51962 L .962 .688 .467 r
F
.3973 .45517 m .39247 .44695 L .39268 .44403 L .992 .74 .415 r
F
.39732 .45676 m .39247 .44695 L .3973 .45517 L .99 .727 .388 r
F
.43461 .36089 m .43864 .35799 L .43937 .36096 L .964 .688 .462 r
F
.43461 .36089 m .43371 .35789 L .43864 .35799 L F
.39472 .43728 m .39276 .42361 L .39444 .42146 L .998 .82 .534 r
F
.39381 .43915 m .39276 .42361 L .39472 .43728 L 1 .814 .494 r
F
.17154 .43336 m .16433 .40854 L .16821 .39345 L .998 .808 .459 r
F
.16972 .44697 m .16433 .40854 L .17154 .43336 L .991 .785 .401 r
F
.28141 .58926 m .28908 .59704 L .27395 .58166 L 0 0 .497 r
F
.28141 .58926 m .29842 .60656 L .28908 .59704 L F
.45208 .4767 m .4557 .49118 L .45085 .47774 L .962 .688 .467 r
F
.44661 .46378 m .45208 .4767 L .45085 .47774 L F
.44714 .46304 m .45208 .4767 L .44661 .46378 L F
.38907 .55487 m .40092 .56421 L .38354 .55262 L .545 0 0 r
F
.38907 .55487 m .40751 .56687 L .40092 .56421 L F
.1837 .38813 m .17796 .34644 L .18895 .37528 L .984 .755 .513 r
F
.47997 .42781 m .48278 .41959 L .48089 .42911 L .965 .687 .457 r
F
.47997 .42781 m .48096 .417 L .48278 .41959 L F
.65986 .41307 m .65833 .42395 L .65982 .43525 L 0 0 .276 r
F
.65821 .40418 m .65833 .42395 L .65986 .41307 L 0 0 .359 r
F
.53814 .40269 m .54399 .39898 L .54007 .40648 L .969 .687 .442 r
F
.53814 .40269 m .54111 .39333 L .54399 .39898 L F
.39505 .40638 m .40142 .38805 L .39766 .40446 L .975 .924 .641 r
F
.39444 .42146 m .39505 .40638 L .39766 .40446 L .992 .873 .605 r
F
.39097 .49783 m .38829 .51013 L .38868 .49578 L .958 .688 .48 r
F
.39097 .49783 m .39174 .51319 L .38829 .51013 L F
.44113 .45083 m .43859 .43726 L .43947 .43769 L .962 .688 .467 r
F
.53384 .48992 m .53193 .50926 L .53189 .49487 L .971 .837 .427 r
F
.53216 .47686 m .53384 .48992 L .53189 .49487 L .992 .818 .443 r
F
.53327 .47215 m .53384 .48992 L .53216 .47686 L .977 .794 .377 r
F
.55776 .34853 m .5515 .34226 L .56215 .35319 L 0 0 .508 r
F
.55776 .34853 m .54601 .33643 L .5515 .34226 L F
.43552 .36388 m .43937 .36096 L .4401 .36394 L .964 .688 .462 r
F
.43552 .36388 m .43461 .36089 L .43937 .36096 L F
.24227 .57554 m .23049 .58471 L .23575 .56592 L .959 .658 .418 r
F
.24227 .57554 m .23929 .59761 L .23049 .58471 L F
.4754 .41155 m .47637 .40015 L .47724 .41294 L .965 .687 .457 r
F
.4754 .41155 m .47362 .39805 L .47637 .40015 L F
.40237 .47196 m .40087 .47785 L .40148 .47056 L .956 .61 .271 r
F
.40237 .47196 m .40264 .48067 L .40087 .47785 L F
.57003 .49064 m .5775 .50422 L .57493 .51127 L .969 .687 .442 r
F
.35232 .39305 m .34908 .37301 L .35585 .38883 L .958 .688 .48 r
F
.35981 .40803 m .35232 .39305 L .35585 .38883 L F
.32965 .44615 m .32838 .43283 L .32961 .42652 L .939 .794 .333 r
F
.32918 .45145 m .32838 .43283 L .32965 .44615 L .893 .734 .227 r
F
.24901 .54176 m .24713 .5382 L .24456 .53251 L .649 .28 0 r
F
.24901 .54176 m .25312 .55066 L .24713 .5382 L F
.35711 .64051 m .40092 .56421 L .34658 .63685 L .882 .883 .83 r
F
.35711 .64051 m .40751 .56687 L .40092 .56421 L F
0 g
.35711 .64051 m
.36705 .64146 L
s
.40751 .56687 m
.41373 .56779 L
s
.18175 .50236 m .172 .49448 L .16995 .47782 L .982 .71 .329 r
F
.18422 .51502 m .172 .49448 L .18175 .50236 L .975 .686 .295 r
F
.43642 .36687 m .4401 .36394 L .44084 .36693 L .964 .688 .462 r
F
.43642 .36687 m .43552 .36388 L .4401 .36394 L F
.39732 .45676 m .39252 .45014 L .39247 .44695 L .99 .727 .388 r
F
.39747 .45845 m .39252 .45014 L .39732 .45676 L .986 .713 .362 r
F
.46055 .50461 m .46193 .51962 L .45776 .50585 L .962 .688 .467 r
F
.4557 .49118 m .46055 .50461 L .45776 .50585 L F
.52623 .44026 m .53057 .4471 L .53079 .452 L .983 .715 .332 r
F
.52585 .43679 m .53057 .4471 L .52623 .44026 L .976 .698 .302 r
F
.5853 .50598 m .63538 .53265 L .58265 .51335 L .729 .368 .366 r
F
.5853 .50598 m .63862 .52271 L .63538 .53265 L F
.59345 .48011 m .5853 .50598 L .59193 .48738 L 0 0 0 r
F
.59193 .48738 m .5853 .50598 L .58265 .51335 L .669 .74 .241 r
F
0 g
.58533 .50587 m
.58714 .49722 L
s
.53193 .50926 m .57181 .51734 L .52896 .51399 L .569 .146 .2 r
F
.53193 .50926 m .57514 .51172 L .57181 .51734 L F
0 g
.57514 .51172 m
.57773 .50463 L
s
.53189 .49487 m .53193 .50926 L .52896 .51399 L .99 .861 .504 r
F
0 g
.53193 .50926 m
.53425 .50329 L
s
.33143 .42109 m .33407 .40369 L .33702 .39815 L .931 .891 .482 r
F
.32961 .42652 m .33407 .40369 L .33143 .42109 L .865 .823 .345 r
F
.44113 .45083 m .44714 .46304 L .44661 .46378 L .962 .688 .467 r
F
.39276 .42361 m .39505 .40638 L .39444 .42146 L .994 .872 .554 r
F
.43697 .43709 m .43438 .4233 L .43775 .43705 L .962 .688 .467 r
F
.43697 .43709 m .43282 .42335 L .43438 .4233 L F
.43733 .36987 m .44084 .36693 L .44157 .36991 L .964 .688 .462 r
F
.43733 .36987 m .43642 .36687 L .44084 .36693 L F
.48607 .44477 m .49322 .45405 L .48613 .44641 L .965 .687 .457 r
F
.48613 .44641 m .49322 .45405 L .49309 .45705 L F
.40148 .47056 m .39921 .47475 L .40066 .46901 L .958 .618 .266 r
F
.40148 .47056 m .40087 .47785 L .39921 .47475 L F
.37271 .4428 m .36426 .4304 L .36556 .42631 L .958 .688 .48 r
F
.37214 .44596 m .36426 .4304 L .37271 .4428 L F
.54785 .43207 m .5556 .43718 L .5563 .44329 L .969 .687 .442 r
F
.54712 .42782 m .5556 .43718 L .54785 .43207 L F
.39747 .45845 m .39281 .45354 L .39252 .45014 L .986 .713 .362 r
F
.039 .916 .04 r
.3789 .45665 m
.39269 .45222 L
s
.39774 .46021 m .39281 .45354 L .39747 .45845 L .982 .698 .337 r
F
.55646 .45435 m .56446 .46507 L .56376 .47144 L .969 .687 .442 r
F
.55658 .44904 m .56446 .46507 L .55646 .45435 L F
.44672 .52469 m .45851 .5353 L .44282 .52512 L .703 .182 0 r
F
.65221 .49665 m .63862 .52271 L .63538 .53265 L 0 0 0 r
F
.65397 .48689 m .63862 .52271 L .65221 .49665 L 0 0 .097 r
F
0 g
.63862 .52271 m
.64079 .51096 L
s
.43824 .37286 m .44157 .36991 L .4423 .37289 L .964 .688 .462 r
F
0 g
.4423 .37289 m
.44665 .37414 L
s
.43824 .37286 m .43733 .36987 L .44157 .36991 L .964 .688 .462 r
F
.5956 .43214 m .59616 .44197 L .59663 .44998 L 0 0 .044 r
F
.59483 .42575 m .59616 .44197 L .5956 .43214 L 0 0 .142 r
F
.23251 .49225 m .23089 .48396 L .22914 .47058 L .738 .525 0 r
F
.23454 .50243 m .23089 .48396 L .23251 .49225 L 0 0 .141 r
F
.4101 .48825 m .41311 .49835 L .40825 .48698 L .908 .5 .181 r
F
.4101 .48825 m .41589 .50025 L .41311 .49835 L F
.44113 .45083 m .43775 .43705 L .43859 .43726 L .962 .688 .467 r
F
.63547 .34418 m .63152 .34259 L .63958 .35152 L 0 0 .556 r
F
.63547 .34418 m .62608 .33285 L .63152 .34259 L F
.46489 .38172 m .46563 .36878 L .46828 .38269 L .965 .687 .457 r
F
.46489 .38172 m .46138 .36753 L .46563 .36878 L F
.40145 .53348 m .39899 .54788 L .39706 .53162 L .958 .688 .48 r
F
.40145 .53348 m .40448 .55014 L .39899 .54788 L F
.65485 .31558 m .66169 .30529 L .66019 .32403 L .973 .665 .361 r
F
.65485 .31558 m .65463 .29403 L .66169 .30529 L F
.40066 .46901 m .39767 .47143 L .39989 .46736 L .961 .628 .267 r
F
.40066 .46901 m .39921 .47475 L .39767 .47143 L F
.24036 .38923 m .25395 .35847 L .25995 .34842 L .753 .864 .434 r
F
.23639 .39964 m .25395 .35847 L .24036 .38923 L 0 0 0 r
F
.51405 .40629 m .51509 .40027 L .51586 .40891 L .944 .582 .215 r
F
.51405 .40629 m .51239 .39635 L .51509 .40027 L F
.4557 .49118 m .45776 .50585 L .4536 .49209 L .962 .688 .467 r
F
.45085 .47774 m .4557 .49118 L .4536 .49209 L F
.47904 .4267 m .48096 .417 L .47997 .42781 L .965 .687 .457 r
F
.47904 .4267 m .4791 .41477 L .48096 .417 L F
.39774 .46021 m .39334 .45707 L .39281 .45354 L .982 .698 .337 r
F
.39812 .46202 m .39334 .45707 L .39774 .46021 L .978 .683 .315 r
F
.52314 .35783 m .52618 .34635 L .52735 .36124 L .969 .687 .442 r
F
.52314 .35783 m .52093 .34205 L .52618 .34635 L F
.39989 .46736 m .3963 .46794 L .39921 .46562 L .965 .64 .272 r
F
.39989 .46736 m .39767 .47143 L .3963 .46794 L F
.5361 .39923 m .54111 .39333 L .53814 .40269 L .969 .687 .442 r
F
.5361 .39923 m .53808 .38814 L .54111 .39333 L F
.41676 .38334 m .41622 .36845 L .42037 .38217 L .962 .688 .467 r
F
.41676 .38334 m .41188 .36981 L .41622 .36845 L F
0 g
.41147 .36955 m
.41305 .36905 L
s
.6216 .21479 m .64183 .22148 L .6321 .22484 L .66 .806 .953 r
F
.62756 .24193 m .6321 .22484 L .63633 .2502 L .968 .651 .347 r
F
.62756 .24193 m .6216 .21479 L .6321 .22484 L F
0 g
.6321 .22484 m
.64274 .23738 L
s
.53016 .46056 m .53327 .47215 L .53216 .47686 L .993 .778 .406 r
F
.53065 .45651 m .53327 .47215 L .53016 .46056 L .984 .759 .357 r
F
.60904 .31013 m .59785 .30293 L .61475 .31649 L 0 .173 .679 r
F
.60904 .31013 m .5907 .29499 L .59785 .30293 L F
.19669 .55238 m .1855 .54563 L .19176 .54027 L .955 .619 .228 r
F
.19669 .55238 m .19215 .56197 L .1855 .54563 L F
.39812 .46202 m .39411 .4607 L .39334 .45707 L .978 .683 .315 r
F
.39861 .46383 m .39411 .4607 L .39812 .46202 L .973 .668 .296 r
F
.39921 .46562 m .3951 .46434 L .39861 .46383 L .969 .653 .282 r
F
.39921 .46562 m .3963 .46794 L .3951 .46434 L F
.44661 .46378 m .45085 .47774 L .44599 .46429 L .962 .688 .467 r
F
.44113 .45083 m .44661 .46378 L .44599 .46429 L F
.39861 .46383 m .3951 .46434 L .39411 .4607 L .973 .668 .296 r
F
.7235 .40175 m .72909 .41319 L .73117 .42764 L .899 .628 .121 r
F
.72131 .39039 m .72909 .41319 L .7235 .40175 L .88 .596 .077 r
F
.20681 .46919 m .19155 .45445 L .19201 .43952 L .976 .718 .477 r
F
.20745 .48107 m .19155 .45445 L .20681 .46919 L .976 .712 .465 r
F
.39381 .43915 m .39139 .4264 L .39276 .42361 L 1 .814 .494 r
F
.39313 .44141 m .39139 .4264 L .39381 .43915 L .997 .801 .446 r
F
.42165 .39686 m .42037 .38217 L .42452 .39589 L .962 .688 .467 r
F
.42165 .39686 m .41676 .38334 L .42037 .38217 L F
.39515 .51545 m .39252 .52865 L .39174 .51319 L .958 .688 .48 r
F
.39515 .51545 m .39706 .53162 L .39252 .52865 L F
.49866 .47372 m .50354 .48923 L .49743 .47666 L .965 .687 .457 r
F
.49213 .4621 m .49866 .47372 L .49743 .47666 L F
.49273 .45975 m .49866 .47372 L .49213 .4621 L F
.35096 .51697 m .35239 .52179 L .34756 .51252 L .74 .289 0 r
F
.35096 .51697 m .35694 .52775 L .35239 .52179 L F
.49522 .37383 m .49216 .36391 L .49873 .37577 L .886 .456 .123 r
F
.49522 .37383 m .48776 .36145 L .49216 .36391 L F
.24456 .53251 m .24182 .52505 L .24062 .52275 L 0 0 .285 r
F
.24456 .53251 m .24713 .5382 L .24182 .52505 L F
.45085 .47774 m .4536 .49209 L .44944 .47833 L .962 .688 .467 r
F
.44599 .46429 m .45085 .47774 L .44944 .47833 L F
.64032 .27594 m .64524 .26058 L .64747 .28419 L .97 .658 .354 r
F
.64032 .27594 m .63633 .2502 L .64524 .26058 L F
.50354 .48923 m .5071 .50566 L .5015 .49233 L .965 .687 .457 r
F
.49743 .47666 m .50354 .48923 L .5015 .49233 L F
.38868 .49578 m .38484 .50632 L .38639 .49323 L .958 .688 .48 r
F
.38868 .49578 m .38829 .51013 L .38484 .50632 L F
.44113 .45083 m .43697 .43709 L .43775 .43705 L .962 .688 .467 r
F
.18422 .51502 m .17532 .51156 L .172 .49448 L .975 .686 .295 r
F
.18758 .52774 m .17532 .51156 L .18422 .51502 L .967 .662 .265 r
F
.42652 .41037 m .42452 .39589 L .42867 .40962 L .962 .688 .467 r
F
.42652 .41037 m .42165 .39686 L .42452 .39589 L F
.57327 .36941 m .57085 .36529 L .57651 .37429 L .618 .189 0 r
F
.57327 .36941 m .56654 .35881 L .57085 .36529 L F
.22996 .43481 m .23357 .41183 L .23639 .39964 L .77 .739 .215 r
F
.22868 .44577 m .23357 .41183 L .22996 .43481 L 0 0 0 r
F
.25685 .65921 m .25771 .67492 L .24495 .65018 L .859 .407 .055 r
F
.25685 .65921 m .27202 .68567 L .25771 .67492 L F
.48606 .44791 m .49309 .45705 L .49273 .45975 L .965 .687 .457 r
F
.48613 .44641 m .49309 .45705 L .48606 .44791 L F
.33702 .39815 m .34481 .37801 L .34907 .37301 L .877 .943 .578 r
F
.33407 .40369 m .34481 .37801 L .33702 .39815 L .774 .853 .406 r
F
.25995 .34842 m .34481 .37801 L .34907 .37301 L .711 .298 .262 r
F
0 g
.34907 .37301 m
.354 .36966 L
s
.35232 .39305 m .34481 .37801 L .34908 .37301 L .958 .688 .48 r
F
.34908 .37301 m .40478 .37321 L .40868 .37043 L .406 0 0 r
F
.34481 .37801 m .40478 .37321 L .34908 .37301 L .502 .053 .115 r
F
0 g
.34908 .37301 m
.354 .36967 L
s
.23454 .50243 m .23362 .49767 L .23089 .48396 L 0 0 .141 r
F
.23726 .51266 m .23362 .49767 L .23454 .50243 L 0 0 .207 r
F
.52852 .37622 m .53161 .36565 L .53173 .37952 L .969 .687 .442 r
F
.52852 .37622 m .52735 .36124 L .53161 .36565 L F
.52623 .44026 m .53079 .452 L .52637 .44353 L .983 .715 .332 r
F
.52637 .44353 m .53079 .452 L .53065 .45651 L .988 .731 .363 r
F
.039 .916 .04 r
.52974 .44999 m
.52984 .44996 L
s
.4987 .45996 m
.52862 .45035 L
s
.4314 .42387 m .42867 .40962 L .43282 .42335 L .962 .688 .467 r
F
.4314 .42387 m .42652 .41037 L .42867 .40962 L F
.43071 .5139 m .43861 .52435 L .42732 .51326 L .779 .279 .002 r
F
.43071 .5139 m .44282 .52512 L .43861 .52435 L F
.51269 .51897 m .5254 .51737 L .50908 .52237 L .143 0 0 r
F
.51269 .51897 m .52896 .51399 L .5254 .51737 L F
.5071 .50566 m .51269 .51897 L .50908 .52237 L .965 .687 .457 r
F
0 g
.51269 .51897 m
.5157 .51424 L
s
.41859 .50145 m .42374 .51168 L .41589 .50025 L .849 .389 .073 r
F
.41859 .50145 m .42732 .51326 L .42374 .51168 L F
.54831 .43616 m .5563 .44329 L .55658 .44904 L .969 .687 .442 r
F
.54785 .43207 m .5563 .44329 L .54831 .43616 L F
.19176 .54027 m .17985 .52872 L .18758 .52774 L .961 .639 .243 r
F
.19176 .54027 m .1855 .54563 L .17985 .52872 L F
.44599 .46429 m .44944 .47833 L .44529 .46458 L .962 .688 .467 r
F
.44113 .45083 m .44599 .46429 L .44529 .46458 L F
.47909 .34954 m .51253 .32221 L .51866 .32587 L .796 .889 .912 r
F
0 g
.51866 .32587 m
.52498 .3311 L
s
.37214 .44596 m .36339 .43514 L .36426 .4304 L .958 .688 .48 r
F
.37187 .4495 m .36339 .43514 L .37214 .44596 L F
.43626 .43735 m .43282 .42335 L .43697 .43709 L .962 .688 .467 r
F
.43626 .43735 m .4314 .42387 L .43282 .42335 L F
.51584 .33907 m .51873 .32634 L .52093 .34205 L .969 .687 .442 r
F
.51584 .33907 m .51262 .32271 L .51873 .32634 L F
.47811 .42579 m .4791 .41477 L .47904 .4267 L .965 .687 .457 r
F
.47811 .42579 m .47724 .41294 L .4791 .41477 L F
.40825 .48698 m .41028 .4958 L .40636 .48527 L .905 .493 .138 r
F
.40825 .48698 m .41311 .49835 L .41028 .4958 L F
.18758 .52774 m .17985 .52872 L .17532 .51156 L .967 .662 .265 r
F
.50418 .38807 m .50235 .37863 L .50689 .3902 L .916 .517 .176 r
F
.50418 .38807 m .49873 .37577 L .50235 .37863 L F
.24062 .52275 m .23729 .51146 L .23726 .51266 L 0 0 .256 r
F
.24062 .52275 m .24182 .52505 L .23729 .51146 L F
.32918 .45145 m .32775 .43992 L .32838 .43283 L .893 .734 .227 r
F
.32918 .45723 m .32775 .43992 L .32918 .45145 L .837 .661 .119 r
F
.47404 .34796 m .51253 .32221 L .47909 .34954 L .799 .942 .92 r
F
.45788 .35336 m .47404 .34796 L .47909 .34954 L .576 .898 .984 r
F
.48357 .36017 m .47909 .34954 L .48776 .36145 L .856 .402 .099 r
F
.48357 .36017 m .47404 .34796 L .47909 .34954 L F
0 g
.47909 .34954 m
.48438 .35253 L
s
.39505 .40638 m .39816 .39042 L .40142 .38805 L .975 .924 .641 r
F
.35751 .41248 m .35232 .39305 L .35981 .40803 L .958 .688 .48 r
F
.36556 .42631 m .35751 .41248 L .35981 .40803 L F
.23726 .51266 m .23729 .51146 L .23362 .49767 L 0 0 .207 r
F
.47362 .41062 m .47362 .39805 L .4754 .41155 L .965 .687 .457 r
F
.47362 .41062 m .47095 .39664 L .47362 .39805 L F
.44113 .45083 m .43626 .43735 L .43697 .43709 L .962 .688 .467 r
F
.36426 .4304 m .35751 .41248 L .36556 .42631 L .958 .688 .48 r
F
.25787 .61818 m .24886 .63383 L .24848 .60883 L .951 .634 .394 r
F
.25787 .61818 m .26069 .64548 L .24886 .63383 L F
.28604 .69311 m .27887 .68367 L .27202 .68567 L .618 .838 .984 r
F
.28604 .69311 m .29285 .69113 L .27887 .68367 L F
0 g
.28604 .69311 m
.29952 .69718 L
s
.29285 .69113 m
.3063 .69523 L
s
.69244 .31344 m .69486 .3091 L .69758 .32291 L .858 .476 0 r
F
.69244 .31344 m .68806 .29655 L .69486 .3091 L F
.51222 .40404 m .51239 .39635 L .51405 .40629 L .944 .58 .231 r
F
.51222 .40404 m .50964 .39298 L .51239 .39635 L F
.51761 .31647 m .55688 .27496 L .52396 .32028 L .882 .875 .824 r
F
.53533 .32875 m .52396 .32028 L .54059 .3319 L .463 0 0 r
F
.53533 .32875 m .51761 .31647 L .52396 .32028 L F
0 g
.52809 .32373 m
.5305 .32574 L
s
.66098 .42161 m .65982 .43525 L .6606 .44593 L 0 0 .176 r
F
.65986 .41307 m .65982 .43525 L .66098 .42161 L 0 0 .276 r
F
.36626 .5368 m .37199 .54395 L .36159 .53278 L .607 .087 0 r
F
.36626 .5368 m .37782 .54897 L .37199 .54395 L F
.59654 .45737 m .59345 .48011 L .59589 .46402 L 0 0 0 r
F
.59589 .46402 m .59345 .48011 L .59193 .48738 L .755 .716 .183 r
F
.44113 .45083 m .43564 .43785 L .43626 .43735 L .962 .688 .467 r
F
.44113 .45083 m .4351 .43857 L .43564 .43785 L F
.44113 .45083 m .43467 .43951 L .4351 .43857 L F
.44113 .45083 m .43435 .44064 L .43467 .43951 L F
.44113 .45083 m .43415 .44194 L .43435 .44064 L F
.44113 .45083 m .43406 .4434 L .43415 .44194 L F
.44113 .45083 m .4341 .44498 L .43406 .4434 L F
.44113 .45083 m .43425 .44667 L .4341 .44498 L F
.44113 .45083 m .43453 .44843 L .43425 .44667 L F
.44113 .45083 m .43492 .45024 L .43453 .44843 L F
.44113 .45083 m .43541 .45205 L .43492 .45024 L F
.44113 .45083 m .43601 .45384 L .43541 .45205 L F
.039 .916 .04 r
.4037 .46281 m
.4356 .4526 L
s
.44113 .45083 m .43669 .45558 L .43601 .45384 L .962 .688 .467 r
F
.44113 .45083 m .43745 .45724 L .43669 .45558 L F
.44113 .45083 m .43827 .45878 L .43745 .45724 L F
.44113 .45083 m .43914 .46019 L .43827 .45878 L F
.44113 .45083 m .44004 .46144 L .43914 .46019 L F
.44113 .45083 m .44096 .46251 L .44004 .46144 L F
.44113 .45083 m .44189 .46337 L .44096 .46251 L F
.44113 .45083 m .44279 .46402 L .44189 .46337 L F
.44113 .45083 m .44367 .46444 L .44279 .46402 L F
.44113 .45083 m .44451 .46462 L .44367 .46444 L F
.44113 .45083 m .44529 .46458 L .44451 .46462 L F
0 0 0 r
2 Mabswid
.44113 .45083 Mdot
.039 .916 .04 r
.5 Mabswid
.44113 .45083 m
.46 .44479 L
s
.534 .39614 m .53808 .38814 L .5361 .39923 L .969 .687 .442 r
F
.534 .39614 m .53493 .38351 L .53808 .38814 L F
.39313 .44141 m .39036 .42978 L .39139 .4264 L .997 .801 .446 r
F
.39268 .44403 m .39036 .42978 L .39313 .44141 L .989 .781 .392 r
F
.46841 .39593 m .46828 .38269 L .47095 .39664 L .965 .687 .457 r
F
.46841 .39593 m .46489 .38172 L .46828 .38269 L F
.73273 .45392 m .73708 .47568 L .73639 .48995 L .918 .711 .216 r
F
.73239 .44129 m .73708 .47568 L .73273 .45392 L .882 .664 .141 r
F
.49065 .52983 m .49171 .53275 L .48727 .53489 L .964 .688 .462 r
F
0 g
.49171 .53275 m
.49557 .52914 L
s
.39276 .42361 m .39281 .40922 L .39505 .40638 L .994 .872 .554 r
F
.39139 .4264 m .39281 .40922 L .39276 .42361 L .986 .858 .486 r
F
.44529 .46458 m .44789 .47844 L .44451 .46462 L .962 .688 .467 r
F
.44529 .46458 m .44944 .47833 L .44789 .47844 L F
.49065 .52983 m .48727 .53489 L .48636 .53188 L .964 .688 .462 r
F
.4896 .5269 m .49065 .52983 L .48636 .53188 L F
.38639 .49323 m .38147 .50182 L .38415 .49024 L .958 .688 .48 r
F
.38639 .49323 m .38484 .50632 L .38147 .50182 L F
.48588 .44926 m .49273 .45975 L .49213 .4621 L .965 .687 .457 r
F
.48606 .44791 m .49273 .45975 L .48588 .44926 L F
.039 .916 .04 r
.47005 .45548 m
.48635 .45023 L
s
.6216 .21479 m .63138 .2114 L .64183 .22148 L .66 .806 .953 r
F
.64669 .23539 m .64183 .22148 L .65538 .24371 L .792 .328 0 r
F
.64669 .23539 m .63138 .2114 L .64183 .22148 L F
0 g
.64183 .22148 m
.65243 .23407 L
s
.23575 .56592 m .22225 .57037 L .22964 .55525 L .962 .664 .417 r
F
.23575 .56592 m .23049 .58471 L .22225 .57037 L F
.4896 .5269 m .48636 .53188 L .48545 .52887 L .964 .688 .462 r
F
.48854 .52398 m .4896 .5269 L .48545 .52887 L F
.40448 .55014 m .40092 .5642 L .39899 .54788 L .958 .688 .48 r
F
.40448 .55014 m .40751 .56686 L .40092 .5642 L F
.44944 .47833 m .45129 .49228 L .44789 .47844 L .962 .688 .467 r
F
.44944 .47833 m .4536 .49209 L .45129 .49228 L F
.39281 .40922 m .39816 .39042 L .39505 .40638 L .963 .916 .565 r
F
.22602 .61568 m .22144 .62459 L .21679 .60452 L .902 .492 .108 r
F
.22602 .61568 m .23307 .63859 L .22144 .62459 L F
.5956 .43214 m .59663 .44998 L .59596 .43816 L 0 0 .044 r
F
.59596 .43816 m .59663 .44998 L .59654 .45737 L .779 .628 .066 r
F
.039 .916 .04 r
.52984 .44996 m
.52986 .44995 L
s
.43564 .43785 m .4314 .42387 L .43626 .43735 L .962 .688 .467 r
F
.48854 .52398 m .48545 .52887 L .48454 .52587 L .964 .688 .462 r
F
.48749 .52105 m .48854 .52398 L .48454 .52587 L F
.48749 .52105 m .48454 .52587 L .48363 .52286 L F
.48643 .51813 m .48749 .52105 L .48363 .52286 L F
.34756 .51252 m .34801 .515 L .34429 .50745 L .7 .273 0 r
F
.34756 .51252 m .35239 .52179 L .34801 .515 L F
.5071 .50566 m .50908 .52237 L .50408 .50845 L .965 .687 .457 r
F
.5015 .49233 m .5071 .50566 L .50408 .50845 L F
.4536 .49209 m .45468 .50614 L .45129 .49228 L .962 .688 .467 r
F
.4536 .49209 m .45776 .50585 L .45468 .50614 L F
.48643 .51813 m .48363 .52286 L .48272 .51985 L .964 .688 .462 r
F
.48538 .5152 m .48643 .51813 L .48272 .51985 L F
.37187 .4495 m .36297 .44045 L .36339 .43514 L .958 .688 .48 r
F
.37191 .45336 m .36297 .44045 L .37187 .4495 L F
.69269 .42278 m .7058 .44948 L .69352 .43305 L .98 .688 .381 r
F
.69352 .43305 m .7058 .44948 L .70603 .46209 L .98 .691 .386 r
F
.46314 .53475 m .46159 .53435 L .45851 .5353 L .341 .821 .822 r
F
.40636 .48527 m .40746 .49263 L .40448 .48316 L .899 .488 .099 r
F
.40636 .48527 m .41028 .4958 L .40746 .49263 L F
.47719 .4251 m .47724 .41294 L .47811 .42579 L .965 .687 .457 r
F
.47719 .4251 m .4754 .41155 L .47724 .41294 L F
.48538 .5152 m .48272 .51985 L .48181 .51685 L .964 .688 .462 r
F
0 g
.48538 .5152 m
.48849 .51236 L
s
.51761 .31647 m .54858 .2696 L .55688 .27496 L .882 .875 .824 r
F
.57682 .28431 m .55688 .27496 L .58365 .28874 L 0 .307 .714 r
F
.57682 .28431 m .54858 .2696 L .55688 .27496 L F
0 g
.55688 .27496 m
.56542 .28248 L
s
.25395 .35847 m .34481 .37801 L .25995 .34842 L .722 .354 .352 r
F
0 g
.25995 .34842 m
.26709 .34088 L
s
.52627 .44655 m .53065 .45651 L .53016 .46056 L .993 .744 .395 r
F
.52637 .44353 m .53065 .45651 L .52627 .44655 L .988 .731 .363 r
F
.45776 .50585 m .45808 .52003 L .45468 .50614 L .962 .688 .467 r
F
.45776 .50585 m .46193 .51962 L .45808 .52003 L F
.57003 .49064 m .57493 .51127 L .56786 .49649 L .969 .687 .442 r
F
.56252 .477 m .57003 .49064 L .56786 .49649 L F
.56376 .47144 m .57003 .49064 L .56252 .477 L F
.44451 .46462 m .44623 .47808 L .44367 .46444 L .962 .688 .467 r
F
.44451 .46462 m .44789 .47844 L .44623 .47808 L F
.63125 .33759 m .62608 .33285 L .63547 .34418 L 0 0 .523 r
F
.63125 .33759 m .62046 .3241 L .62608 .33285 L F
.43013 .42485 m .42652 .41037 L .4314 .42387 L .962 .688 .467 r
F
.43564 .43785 m .43013 .42485 L .4314 .42387 L F
.49743 .47666 m .5015 .49233 L .49589 .47897 L .965 .687 .457 r
F
.4913 .46405 m .49743 .47666 L .49589 .47897 L F
.49213 .4621 m .49743 .47666 L .4913 .46405 L F
.55592 .45913 m .56376 .47144 L .56252 .477 L .969 .687 .442 r
F
.55646 .45435 m .56376 .47144 L .55592 .45913 L F
.54831 .43616 m .55658 .44904 L .54849 .44001 L F
.54849 .44001 m .55658 .44904 L .55646 .45435 L F
.32961 .42652 m .3318 .41045 L .33407 .40369 L .865 .823 .345 r
F
.32838 .43283 m .3318 .41045 L .32961 .42652 L .767 .719 .186 r
F
.4531 .35326 m .47404 .34796 L .45788 .35336 L .455 .882 .908 r
F
.45741 .36749 m .45788 .35336 L .46138 .36753 L .965 .687 .457 r
F
.45741 .36749 m .4531 .35326 L .45788 .35336 L F
0 g
.45788 .35336 m
.46298 .35492 L
s
.53189 .49487 m .52896 .51399 L .52942 .49877 L .99 .861 .504 r
F
.5306 .4808 m .53189 .49487 L .52942 .49877 L .999 .832 .498 r
F
.53216 .47686 m .53189 .49487 L .5306 .4808 L .992 .818 .443 r
F
.46193 .51962 m .46149 .53393 L .45808 .52003 L .962 .688 .467 r
F
.46193 .51962 m .46609 .53339 L .46149 .53393 L F
.32918 .45723 m .32774 .44765 L .32775 .43992 L .837 .661 .119 r
F
.32964 .46339 m .32774 .44765 L .32918 .45723 L .778 .583 .014 r
F
.39174 .51319 m .3879 .52459 L .38829 .51013 L .958 .688 .48 r
F
.39174 .51319 m .39252 .52865 L .3879 .52459 L F
.47898 .43871 m .48468 .43751 L .48519 .43937 L .965 .687 .457 r
F
.47898 .43871 m .48407 .43567 L .48468 .43751 L F
.4351 .43857 m .43013 .42485 L .43564 .43785 L .962 .688 .467 r
F
.52931 .46409 m .53216 .47686 L .5306 .4808 L .998 .792 .451 r
F
.53016 .46056 m .53216 .47686 L .52931 .46409 L .993 .778 .406 r
F
.39268 .44403 m .38968 .4337 L .39036 .42978 L .989 .781 .392 r
F
.39247 .44695 m .38968 .4337 L .39268 .44403 L .976 .755 .334 r
F
.47898 .43871 m .48337 .43388 L .48407 .43567 L .965 .687 .457 r
F
.20745 .48107 m .19237 .47043 L .19155 .45445 L .976 .712 .465 r
F
.20904 .49348 m .19237 .47043 L .20745 .48107 L .975 .705 .454 r
F
.47898 .43871 m .48519 .43937 L .4856 .44123 L .965 .687 .457 r
F
.47898 .43871 m .4826 .43217 L .48337 .43388 L F
.55344 .34492 m .54601 .33643 L .55776 .34853 L .595 .073 0 r
F
.55344 .34492 m .54059 .3319 L .54601 .33643 L F
.38415 .49024 m .37822 .49672 L .382 .48684 L .958 .688 .48 r
F
.38415 .49024 m .38147 .50182 L .37822 .49672 L F
.56997 .36519 m .56654 .35881 L .57327 .36941 L .676 .22 0 r
F
.56997 .36519 m .56215 .35319 L .56654 .35881 L F
.41589 .50025 m .42003 .50917 L .41311 .49835 L .83 .359 0 r
F
.41589 .50025 m .42374 .51168 L .42003 .50917 L F
.47898 .43871 m .4856 .44123 L .48589 .44304 L .965 .687 .457 r
F
.42462 .41182 m .42165 .39686 L .42652 .41037 L .962 .688 .467 r
F
.43013 .42485 m .42462 .41182 L .42652 .41037 L F
.27395 .58166 m .27993 .58563 L .26666 .57258 L 0 .042 .578 r
F
.27395 .58166 m .28908 .59704 L .27993 .58563 L F
.51038 .4022 m .50964 .39298 L .51222 .40404 L .943 .579 .249 r
F
.51038 .4022 m .50689 .3902 L .50964 .39298 L F
.51938 .42641 m .52338 .42575 L .52442 .42947 L .977 .675 .337 r
F
.51877 .42455 m .52338 .42575 L .51938 .42641 L .975 .667 .329 r
F
.51877 .42455 m .52217 .42206 L .52338 .42575 L F
.47898 .43871 m .48177 .43057 L .4826 .43217 L .965 .687 .457 r
F
.51807 .42275 m .52217 .42206 L .51877 .42455 L .972 .659 .323 r
F
.51807 .42275 m .52078 .41848 L .52217 .42206 L F
.48557 .45043 m .49213 .4621 L .4913 .46405 L .965 .687 .457 r
F
.48588 .44926 m .49213 .4621 L .48557 .45043 L F
.44367 .46444 m .44447 .47726 L .44279 .46402 L .962 .688 .467 r
F
.44367 .46444 m .44623 .47808 L .44447 .47726 L F
.65999 .4647 m .65397 .48689 L .65221 .49665 L 0 0 0 r
F
.66066 .4558 m .65397 .48689 L .65999 .4647 L 0 0 .108 r
F
.38354 .55262 m .39407 .55984 L .37782 .54897 L .412 0 0 r
F
.38354 .55262 m .40092 .56421 L .39407 .55984 L F
.53185 .39348 m .53493 .38351 L .534 .39614 L .969 .687 .442 r
F
.53185 .39348 m .53173 .37952 L .53493 .38351 L F
.5199 .42828 m .52442 .42947 L .52524 .43317 L .98 .684 .348 r
F
.51938 .42641 m .52442 .42947 L .5199 .42828 L .977 .675 .337 r
F
.39706 .53162 m .39329 .54419 L .39252 .52865 L .958 .688 .48 r
F
.39706 .53162 m .39899 .54788 L .39329 .54419 L F
.47898 .43871 m .48589 .44304 L .48607 .44477 L .965 .687 .457 r
F
.72507 .41267 m .73117 .42764 L .73239 .44129 L .92 .661 .17 r
F
.7235 .40175 m .73117 .42764 L .72507 .41267 L .899 .628 .121 r
F
.19375 .42588 m .1799 .40323 L .1837 .38813 L .98 .739 .497 r
F
.19201 .43952 m .1799 .40323 L .19375 .42588 L .982 .733 .481 r
F
.37191 .45336 m .36301 .44625 L .36297 .44045 L .958 .688 .48 r
F
.37225 .45746 m .36301 .44625 L .37191 .45336 L F
.039 .916 .04 r
.33148 .4577 m
.36388 .4473 L
s
.5173 .42103 m .52078 .41848 L .51807 .42275 L .97 .652 .32 r
F
.5173 .42103 m .51925 .41505 L .52078 .41848 L F
.47193 .41017 m .47095 .39664 L .47362 .41062 L .965 .687 .457 r
F
.47193 .41017 m .46841 .39593 L .47095 .39664 L F
.40448 .48316 m .40469 .48889 L .40264 .48067 L .892 .485 .064 r
F
.40448 .48316 m .40746 .49263 L .40469 .48889 L F
.67375 .379 m .68302 .37732 L .68632 .38899 L .977 .68 .376 r
F
.67118 .37121 m .68302 .37732 L .67375 .379 L .976 .678 .375 r
F
.67118 .37121 m .67921 .36575 L .68302 .37732 L F
.16821 .39345 m .16478 .36411 L .17124 .34879 L .993 .85 .498 r
F
.16433 .40854 m .16478 .36411 L .16821 .39345 L .98 .824 .422 r
F
.47898 .43871 m .48089 .42911 L .48177 .43057 L .965 .687 .457 r
F
.44789 .47844 m .44879 .49177 L .44623 .47808 L .962 .688 .467 r
F
.44789 .47844 m .45129 .49228 L .44879 .49177 L F
.5015 .49233 m .50408 .50845 L .49907 .49453 L .965 .687 .457 r
F
.49589 .47897 m .5015 .49233 L .49907 .49453 L F
.4351 .43857 m .42906 .42628 L .43013 .42485 L .962 .688 .467 r
F
.43467 .43951 m .42906 .42628 L .4351 .43857 L F
.44282 .52512 m .45349 .53441 L .43861 .52435 L .644 .085 0 r
F
.44282 .52512 m .45851 .5353 L .45349 .53441 L F
.66832 .36362 m .67921 .36575 L .67118 .37121 L .976 .676 .373 r
F
.66832 .36362 m .67495 .35447 L .67921 .36575 L F
.41909 .39877 m .41676 .38334 L .42165 .39686 L .962 .688 .467 r
F
.42462 .41182 m .41909 .39877 L .42165 .39686 L F
.42919 .35929 m .4328 .3549 L .43371 .35789 L .964 .688 .462 r
F
.42919 .35929 m .42813 .35634 L .4328 .3549 L F
0 g
.4328 .3549 m
.4379 .35501 L
s
.34429 .50745 m .34389 .50751 L .34122 .50186 L .664 .268 0 r
F
.34429 .50745 m .34801 .515 L .34389 .50751 L F
.34942 .39858 m .34481 .37801 L .35232 .39305 L .958 .688 .48 r
F
.35751 .41248 m .34942 .39858 L .35232 .39305 L F
.52031 .43014 m .52524 .43317 L .52585 .43679 L .982 .693 .36 r
F
.5199 .42828 m .52524 .43317 L .52031 .43014 L .98 .684 .348 r
F
.43026 .36225 m .43371 .35789 L .43461 .36089 L .964 .688 .462 r
F
.43026 .36225 m .42919 .35929 L .43371 .35789 L F
.36426 .4304 m .35575 .41791 L .35751 .41248 L .958 .688 .48 r
F
.36339 .43514 m .35575 .41791 L .36426 .4304 L F
.46172 .38172 m .46138 .36753 L .46489 .38172 L .965 .687 .457 r
F
.46172 .38172 m .45741 .36749 L .46138 .36753 L F
.47898 .43871 m .48607 .44477 L .48613 .44641 L F
.43132 .3652 m .43461 .36089 L .43552 .36388 L .964 .688 .462 r
F
.43132 .3652 m .43026 .36225 L .43461 .36089 L F
.27253 .65455 m .2646 .6729 L .26069 .64548 L .944 .614 .373 r
F
.27253 .65455 m .27887 .68367 L .2646 .6729 L F
.30778 .61403 m .32444 .62154 L .29842 .60656 L 0 .292 .741 r
F
.30778 .61403 m .33562 .63051 L .32444 .62154 L F
.4763 .42464 m .4754 .41155 L .47719 .4251 L .965 .687 .457 r
F
.4763 .42464 m .47362 .41062 L .4754 .41155 L F
.52537 .37368 m .52735 .36124 L .52852 .37622 L .969 .687 .442 r
F
.52537 .37368 m .52314 .35783 L .52735 .36124 L F
.43239 .36816 m .43552 .36388 L .43642 .36687 L .964 .688 .462 r
F
.43239 .36816 m .43132 .3652 L .43552 .36388 L F
.43345 .37111 m .43642 .36687 L .43733 .36987 L F
.43345 .37111 m .43239 .36816 L .43642 .36687 L F
.39139 .4264 m .39098 .41291 L .39281 .40922 L .986 .858 .486 r
F
.39036 .42978 m .39098 .41291 L .39139 .4264 L .963 .827 .402 r
F
.42732 .51326 m .43415 .52239 L .42374 .51168 L .741 .218 0 r
F
.42732 .51326 m .43861 .52435 L .43415 .52239 L F
.16972 .44697 m .162 .42561 L .16433 .40854 L .991 .785 .401 r
F
.16918 .46188 m .162 .42561 L .16972 .44697 L .978 .755 .339 r
F
.39247 .44695 m .38937 .4381 L .38968 .4337 L .976 .755 .334 r
F
.39252 .45014 m .38937 .4381 L .39247 .44695 L .959 .722 .274 r
F
.51647 .41942 m .51925 .41505 L .5173 .42103 L .968 .646 .319 r
F
.51647 .41942 m .5176 .41184 L .51925 .41505 L F
.43452 .37407 m .43733 .36987 L .43824 .37286 L .964 .688 .462 r
F
0 g
.43824 .37286 m
.4423 .37289 L
s
.43452 .37407 m .43345 .37111 L .43733 .36987 L .964 .688 .462 r
F
.50155 .38663 m .49873 .37577 L .50418 .38807 L .919 .525 .215 r
F
.50155 .38663 m .49522 .37383 L .49873 .37577 L F
.47898 .43871 m .47997 .42781 L .48089 .42911 L .965 .687 .457 r
F
.44279 .46402 m .44265 .47597 L .44189 .46337 L .962 .688 .467 r
F
.44279 .46402 m .44447 .47726 L .44265 .47597 L F
.382 .48684 m .37516 .49109 L .37997 .4831 L .958 .688 .48 r
F
.382 .48684 m .37822 .49672 L .37516 .49109 L F
.67597 .38686 m .68632 .38899 L .68906 .40058 L .977 .681 .379 r
F
.67375 .379 m .68632 .38899 L .67597 .38686 L .977 .68 .376 r
F
.52896 .51399 m .56777 .52137 L .5254 .51737 L .508 .02 .031 r
F
.52896 .51399 m .57181 .51734 L .56777 .52137 L F
.52942 .49877 m .52896 .51399 L .5254 .51737 L .995 .869 .563 r
F
0 g
.52896 .51399 m
.53193 .50926 L
s
.64945 .30821 m .65463 .29403 L .65485 .31558 L .972 .664 .363 r
F
.64945 .30821 m .64747 .28419 L .65463 .29403 L F
.58896 .40505 m .59018 .40542 L .5921 .41228 L .801 .498 0 r
F
.58745 .40049 m .59018 .40542 L .58896 .40505 L .79 .468 0 r
F
.58745 .40049 m .58794 .39863 L .59018 .40542 L F
.66691 .26699 m .66421 .25416 L .67398 .27531 L .835 .403 0 r
F
.66691 .26699 m .65538 .24371 L .66421 .25416 L F
.51907 .35549 m .52093 .34205 L .52314 .35783 L .969 .687 .442 r
F
.51907 .35549 m .51584 .33907 L .52093 .34205 L F
.40751 .56686 m .44817 .53209 L .40092 .5642 L .771 .907 .934 r
F
.40751 .56686 m .45349 .53441 L .44817 .53209 L F
0 g
.40751 .56686 m
.41374 .56779 L
s
.42906 .42628 m .42462 .41182 L .43013 .42485 L .962 .688 .467 r
F
.58576 .39606 m .58794 .39863 L .58745 .40049 L .787 .445 0 r
F
.58576 .39606 m .58541 .39201 L .58794 .39863 L F
.32964 .46339 m .32836 .45589 L .32774 .44765 L .778 .583 .014 r
F
.33056 .46981 m .32836 .45589 L .32964 .46339 L .723 .506 0 r
F
.22964 .55525 m .21472 .55485 L .22406 .54372 L .965 .67 .419 r
F
.22964 .55525 m .22225 .57037 L .21472 .55485 L F
.49188 .37283 m .48776 .36145 L .49522 .37383 L .892 .474 .182 r
F
.49188 .37283 m .48357 .36017 L .48776 .36145 L F
.41356 .38569 m .41188 .36981 L .41676 .38334 L .962 .688 .467 r
F
.41909 .39877 m .41356 .38569 L .41676 .38334 L F
.47898 .43871 m .48613 .44641 L .48606 .44791 L .965 .687 .457 r
F
.43467 .43951 m .42819 .42814 L .42906 .42628 L .962 .688 .467 r
F
.43435 .44064 m .42819 .42814 L .43467 .43951 L F
.52062 .43195 m .52585 .43679 L .52623 .44026 L .984 .701 .374 r
F
.52031 .43014 m .52585 .43679 L .52062 .43195 L .982 .693 .36 r
F
.56786 .49649 m .57493 .51127 L .57161 .51686 L .969 .687 .442 r
F
0 g
.57181 .51734 m
.57514 .51172 L
s
.52594 .44925 m .53016 .46056 L .52931 .46409 L .995 .755 .425 r
F
.039 .916 .04 r
.52986 .44995 m
.5301 .44988 L
s
.52627 .44655 m .53016 .46056 L .52594 .44925 L .993 .744 .395 r
F
.37225 .45746 m .36351 .45242 L .36301 .44625 L .958 .688 .48 r
F
.37288 .46174 m .36351 .45242 L .37225 .45746 L F
.59024 .40965 m .5921 .41228 L .59366 .41909 L .819 .535 0 r
F
.58896 .40505 m .5921 .41228 L .59024 .40965 L .801 .498 0 r
F
.66519 .35634 m .67495 .35447 L .66832 .36362 L .975 .674 .372 r
F
.66519 .35634 m .67032 .34364 L .67495 .35447 L F
.47898 .43871 m .47904 .4267 L .47997 .42781 L .965 .687 .457 r
F
.40264 .48067 m .40202 .48465 L .40087 .47785 L .883 .486 .038 r
F
.40264 .48067 m .40469 .48889 L .40202 .48465 L F
.36159 .53278 m .36617 .53765 L .35694 .52775 L 0 0 .485 r
F
.36159 .53278 m .37199 .54395 L .36617 .53765 L F
.66098 .42161 m .6606 .44593 L .66158 .42966 L 0 0 .176 r
F
.66158 .42966 m .6606 .44593 L .66066 .4558 L 0 0 .059 r
F
.71716 .49574 m .72633 .53293 L .71525 .50828 L .983 .702 .393 r
F
.70536 .47349 m .71716 .49574 L .71525 .50828 L .982 .699 .395 r
F
.70603 .46209 m .71716 .49574 L .70536 .47349 L .982 .696 .388 r
F
.45129 .49228 m .45135 .50549 L .44879 .49177 L .962 .688 .467 r
F
.45129 .49228 m .45468 .50614 L .45135 .50549 L F
.5156 .41795 m .5176 .41184 L .51647 .41942 L .966 .641 .321 r
F
.5156 .41795 m .51586 .40891 L .5176 .41184 L F
.5484 .44355 m .55646 .45435 L .55592 .45913 L .969 .687 .442 r
F
.54849 .44001 m .55646 .45435 L .5484 .44355 L F
.039 .916 .04 r
.5301 .44988 m
.54858 .44392 L
s
.58389 .39181 m .58541 .39201 L .58576 .39606 L .792 .429 0 r
F
.58389 .39181 m .58263 .38568 L .58541 .39201 L F
.22868 .44577 m .23197 .42558 L .23357 .41183 L 0 0 0 r
F
.2284 .45777 m .23197 .42558 L .22868 .44577 L 0 0 .116 r
F
.039 .916 .04 r
.23096 .46409 m
.32775 .44483 L
s
.35575 .41791 m .34942 .39858 L .35751 .41248 L .958 .688 .48 r
F
.44189 .46337 m .44079 .47425 L .44096 .46251 L .962 .688 .467 r
F
.44189 .46337 m .44265 .47597 L .44079 .47425 L F
.4913 .46405 m .49589 .47897 L .49027 .46557 L .965 .687 .457 r
F
.48515 .4514 m .4913 .46405 L .49027 .46557 L F
.48557 .45043 m .4913 .46405 L .48515 .4514 L F
.41356 .38569 m .40801 .37258 L .41188 .36981 L .962 .688 .467 r
F
.59589 .44372 m .59654 .45737 L .59589 .46402 L .85 .709 .181 r
F
.59596 .43816 m .59654 .45737 L .59589 .44372 L .779 .628 .066 r
F
.039 .916 .04 r
.56055 .45348 m
.59591 .44184 L
s
.59616 .44176 m
.59644 .44167 L
s
.40478 .37321 m .40784 .37218 L .41173 .3694 L .017 0 0 r
F
0 g
.41173 .3694 m
.4161 .36803 L
s
.46604 .39596 m .46489 .38172 L .46841 .39593 L .965 .687 .457 r
F
.46604 .39596 m .46172 .38172 L .46489 .38172 L F
.58265 .51335 m .6311 .54058 L .57922 .5192 L .721 .317 .283 r
F
.58265 .51335 m .63538 .53265 L .6311 .54058 L F
.58974 .49349 m .58265 .51335 L .57922 .5192 L .812 .874 .436 r
F
.59193 .48738 m .58265 .51335 L .58974 .49349 L .669 .74 .241 r
F
0 g
.58265 .51335 m
.5853 .50598 L
s
.47898 .43871 m .48606 .44791 L .48588 .44926 L .965 .687 .457 r
F
.37997 .4831 m .37235 .48504 L .37811 .47909 L .958 .688 .48 r
F
.37997 .4831 m .37516 .49109 L .37235 .48504 L F
.39252 .45014 m .38943 .4429 L .38937 .4381 L .959 .722 .274 r
F
.039 .916 .04 r
.36831 .44588 m
.38938 .43909 L
s
.39281 .45354 m .38943 .4429 L .39252 .45014 L .939 .686 .214 r
F
.34122 .50186 m .34011 .49945 L .33839 .49585 L 0 0 .303 r
F
.34122 .50186 m .34389 .50751 L .34011 .49945 L F
.53855 .42038 m .54492 .41907 L .54614 .42346 L .969 .687 .442 r
F
.53782 .4182 m .54492 .41907 L .53855 .42038 L F
.53782 .4182 m .54349 .41473 L .54492 .41907 L F
.20904 .49348 m .19448 .48713 L .19237 .47043 L .975 .705 .454 r
F
.21155 .50619 m .19448 .48713 L .20904 .49348 L .974 .699 .444 r
F
.68715 .30492 m .68806 .29655 L .69244 .31344 L .87 .478 .008 r
F
.68715 .30492 m .68106 .28523 L .68806 .29655 L F
.53701 .41608 m .54349 .41473 L .53782 .4182 L .969 .687 .442 r
F
.53701 .41608 m .54186 .41051 L .54349 .41473 L F
.49589 .47897 m .49907 .49453 L .49405 .48059 L .965 .687 .457 r
F
.49027 .46557 m .49589 .47897 L .49405 .48059 L F
.43435 .44064 m .42754 .43039 L .42819 .42814 L .962 .688 .467 r
F
.43415 .44194 m .42754 .43039 L .43435 .44064 L F
.33407 .40369 m .34128 .38461 L .34481 .37801 L .774 .853 .406 r
F
.3318 .41045 m .34128 .38461 L .33407 .40369 L 0 0 0 r
F
.47898 .43871 m .47811 .42579 L .47904 .4267 L .965 .687 .457 r
F
.53916 .42259 m .54614 .42346 L .54712 .42782 L .969 .687 .442 r
F
.53855 .42038 m .54614 .42346 L .53916 .42259 L F
.39281 .40922 m .39535 .39392 L .39816 .39042 L .963 .916 .565 r
F
.39098 .41291 m .39535 .39392 L .39281 .40922 L .924 .879 .456 r
F
.37288 .46174 m .36446 .45887 L .36351 .45242 L .958 .688 .48 r
F
.3738 .46612 m .36446 .45887 L .37288 .46174 L F
.44623 .47808 m .44615 .49055 L .44447 .47726 L .962 .688 .467 r
F
.44623 .47808 m .44879 .49177 L .44615 .49055 L F
.5208 .4337 m .52623 .44026 L .52637 .44353 L .986 .709 .389 r
F
.52062 .43195 m .52623 .44026 L .5208 .4337 L .984 .701 .374 r
F
.39535 .39392 m .40478 .37321 L .39816 .39042 L .876 .933 .555 r
F
.59129 .41422 m .59366 .41909 L .59483 .42575 L .844 .577 .035 r
F
.59024 .40965 m .59366 .41909 L .59129 .41422 L .819 .535 0 r
F
.50857 .40079 m .50689 .3902 L .51038 .4022 L .942 .58 .271 r
F
.50857 .40079 m .50418 .38807 L .50689 .3902 L F
.38829 .51013 m .38328 .51952 L .38484 .50632 L .958 .688 .48 r
F
.38829 .51013 m .3879 .52459 L .38328 .51952 L F
.41311 .49835 m .41626 .50577 L .41028 .4958 L .802 .328 0 r
F
.41311 .49835 m .42003 .50917 L .41626 .50577 L F
.16478 .36411 m .17796 .34644 L .17124 .34879 L .405 .067 .275 r
F
0 g
.17124 .34879 m
.17929 .33644 L
s
.5361 .41405 m .54186 .41051 L .53701 .41608 L .969 .687 .442 r
F
.5361 .41405 m .54007 .40648 L .54186 .41051 L F
.33056 .46981 m .3296 .46451 L .32836 .45589 L .723 .506 0 r
F
.33193 .47639 m .3296 .46451 L .33056 .46981 L 0 0 .158 r
F
.67781 .39466 m .68906 .40058 L .6912 .4119 L .978 .683 .381 r
F
.67597 .38686 m .68906 .40058 L .67781 .39466 L .977 .681 .379 r
F
.47545 .42443 m .47362 .41062 L .4763 .42464 L .965 .687 .457 r
F
.47545 .42443 m .47193 .41017 L .47362 .41062 L F
.40087 .47785 m .39951 .47999 L .39921 .47475 L .876 .492 .021 r
F
.40087 .47785 m .40202 .48465 L .39951 .47999 L F
.44096 .46251 m .43895 .47213 L .44004 .46144 L .962 .688 .467 r
F
.44096 .46251 m .44079 .47425 L .43895 .47213 L F
.37811 .47909 m .36983 .47868 L .37644 .47487 L .958 .688 .48 r
F
.37811 .47909 m .37235 .48504 L .36983 .47868 L F
.52971 .39129 m .53173 .37952 L .53185 .39348 L .969 .687 .442 r
F
.52971 .39129 m .52852 .37622 L .53173 .37952 L F
.51469 .41664 m .51586 .40891 L .5156 .41795 L .964 .637 .325 r
F
.51469 .41664 m .51405 .40629 L .51586 .40891 L F
.60344 .30516 m .5907 .29499 L .60904 .31013 L 0 .098 .577 r
F
.60344 .30516 m .58365 .28874 L .5907 .29499 L F
.47898 .43871 m .48588 .44926 L .48557 .45043 L .965 .687 .457 r
F
.42299 .41395 m .41909 .39877 L .42462 .41182 L .962 .688 .467 r
F
.42906 .42628 m .42299 .41395 L .42462 .41182 L F
.58189 .38783 m .58263 .38568 L .58389 .39181 L .803 .421 0 r
F
.58189 .38783 m .57965 .37974 L .58263 .38568 L F
.72633 .53293 m .73276 .54286 L .72279 .54578 L .428 .078 .268 r
F
.72633 .53293 m .73624 .53001 L .73276 .54286 L F
.71525 .50828 m .72633 .53293 L .72279 .54578 L .984 .705 .401 r
F
0 g
.72633 .53293 m
.72854 .51781 L
s
.53965 .42478 m .54712 .42782 L .54785 .43207 L .969 .687 .442 r
F
.53916 .42259 m .54712 .42782 L .53965 .42478 L F
.3738 .46612 m .36585 .46548 L .36446 .45887 L .958 .688 .48 r
F
.375 .47052 m .36585 .46548 L .3738 .46612 L F
.43415 .44194 m .42712 .433 L .42754 .43039 L .962 .688 .467 r
F
.43406 .4434 m .42712 .433 L .43415 .44194 L F
.45468 .50614 m .45393 .51925 L .45135 .50549 L F
.45468 .50614 m .45808 .52003 L .45393 .51925 L F
.39281 .45354 m .38986 .448 L .38943 .4429 L .939 .686 .214 r
F
.39334 .45707 m .38986 .448 L .39281 .45354 L .919 .648 .158 r
F
.32838 .43283 m .33026 .41834 L .3318 .41045 L .767 .719 .186 r
F
.32775 .43992 m .33026 .41834 L .32838 .43283 L 0 0 0 r
F
.50908 .52237 m .5213 .51935 L .50493 .52436 L F
.5213 .51935 m .55782 .52437 L .52064 .52029 L .231 0 0 r
F
.50908 .52237 m .52195 .51843 L .5213 .51935 L 0 0 0 r
F
.50493 .52436 m .51784 .5204 L .51672 .51986 L .339 .82 .821 r
F
.51784 .5204 m .5213 .51935 L .51672 .51986 L F
.5213 .51935 m .52064 .52029 L .51672 .51986 L .231 0 0 r
F
.5213 .51935 m .56308 .52374 L .55782 .52437 L F
.52303 .50315 m .5213 .51935 L .51672 .51986 L .982 .855 .639 r
F
.52303 .50315 m .51672 .51986 L .51922 .50353 L F
.51922 .50353 m .51672 .51986 L .51174 .51888 L .969 .84 .66 r
F
.51672 .51986 m .55207 .52323 L .51558 .5193 L 0 .562 .775 r
F
.51672 .51986 m .51558 .5193 L .51174 .51888 L F
.52195 .51843 m .5254 .51737 L .5213 .51935 L 0 0 0 r
F
0 g
.51125 .52033 m
.5126 .51905 L
s
.50408 .50845 m .50908 .52237 L .50493 .52436 L .965 .687 .457 r
F
0 g
.50908 .52237 m
.51125 .52033 L
s
.42819 .42814 m .42299 .41395 L .42906 .42628 L .962 .688 .467 r
F
.37644 .47487 m .36765 .47212 L .375 .47052 L .958 .688 .48 r
F
.37644 .47487 m .36983 .47868 L .36765 .47212 L F
.33839 .49585 m .33673 .49096 L .33588 .48952 L 0 0 .294 r
F
.33839 .49585 m .34011 .49945 L .33673 .49096 L F
.59468 .46983 m .59193 .48738 L .58974 .49349 L .859 .819 .339 r
F
.59589 .46402 m .59193 .48738 L .59468 .46983 L .755 .716 .183 r
F
.375 .47052 m .36765 .47212 L .36585 .46548 L .958 .688 .48 r
F
.47898 .43871 m .47719 .4251 L .47811 .42579 L .965 .687 .457 r
F
.53513 .41215 m .54007 .40648 L .5361 .41405 L .969 .687 .442 r
F
.53513 .41215 m .53814 .40269 L .54007 .40648 L F
.22406 .54372 m .20806 .53845 L .21913 .53155 L .968 .677 .423 r
F
.22406 .54372 m .21472 .55485 L .20806 .53845 L F
.5306 .4808 m .52942 .49877 L .52861 .4839 L .999 .832 .498 r
F
.52814 .46703 m .5306 .4808 L .52861 .4839 L .999 .801 .49 r
F
.52931 .46409 m .5306 .4808 L .52814 .46703 L .998 .792 .451 r
F
.47035 .4102 m .46841 .39593 L .47193 .41017 L .965 .687 .457 r
F
.47035 .4102 m .46604 .39596 L .46841 .39593 L F
.56252 .477 m .56786 .49649 L .56076 .48165 L .969 .687 .442 r
F
.55498 .46328 m .56252 .477 L .56076 .48165 L F
.55592 .45913 m .56252 .477 L .55498 .46328 L F
.66186 .34949 m .67032 .34364 L .66519 .35634 L .975 .673 .372 r
F
.66186 .34949 m .66537 .33344 L .67032 .34364 L F
.33193 .47639 m .33142 .47333 L .3296 .46451 L 0 0 .158 r
F
.33371 .483 m .33142 .47333 L .33193 .47639 L 0 0 .221 r
F
.47404 .34796 m .50667 .32022 L .51253 .32221 L .799 .942 .92 r
F
0 g
.51253 .32221 m
.51866 .32587 L
s
.46931 .34784 m .50667 .32022 L .47404 .34796 L .779 .985 .901 r
F
.4531 .35326 m .46931 .34784 L .47404 .34796 L .455 .882 .908 r
F
.47966 .3601 m .47404 .34796 L .48357 .36017 L .865 .431 .176 r
F
.47966 .3601 m .46931 .34784 L .47404 .34796 L F
0 g
.47404 .34796 m
.47909 .34954 L
s
.62696 .33187 m .62046 .3241 L .63125 .33759 L 0 0 .466 r
F
.62696 .33187 m .61475 .31649 L .62046 .3241 L F
.39036 .42978 m .38959 .41741 L .39098 .41291 L .963 .827 .402 r
F
.38968 .4337 m .38959 .41741 L .39036 .42978 L .926 .779 .304 r
F
.44004 .46144 m .43713 .46963 L .43914 .46019 L .962 .688 .467 r
F
.44004 .46144 m .43895 .47213 L .43713 .46963 L F
.56668 .36171 m .56215 .35319 L .56997 .36519 L .733 .258 0 r
F
.56668 .36171 m .55776 .34853 L .56215 .35319 L F
.36339 .43514 m .35457 .42423 L .35575 .41791 L .958 .688 .48 r
F
.36297 .44045 m .35457 .42423 L .36339 .43514 L F
.39921 .47475 m .3972 .47498 L .39767 .47143 L .872 .504 .015 r
F
.39921 .47475 m .39951 .47999 L .3972 .47498 L F
.5208 .4337 m .52637 .44353 L .52087 .43533 L .986 .709 .389 r
F
.52087 .43533 m .52637 .44353 L .52627 .44655 L .987 .717 .405 r
F
.33588 .48952 m .33382 .4822 L .33371 .483 L 0 0 .266 r
F
.33588 .48952 m .33673 .49096 L .33382 .4822 L F
.43406 .4434 m .42694 .43591 L .42712 .433 L .962 .688 .467 r
F
.4341 .44498 m .42694 .43591 L .43406 .4434 L F
.47898 .43871 m .48557 .45043 L .48515 .4514 L .965 .687 .457 r
F
.21155 .50619 m .19785 .50426 L .19448 .48713 L .974 .699 .444 r
F
.21493 .51896 m .19785 .50426 L .21155 .50619 L .973 .691 .435 r
F
.39334 .45707 m .39067 .45333 L .38986 .448 L .919 .648 .158 r
F
.39411 .4607 m .39067 .45333 L .39334 .45707 L .901 .611 .109 r
F
.59207 .41868 m .59483 .42575 L .5956 .43214 L .872 .622 .094 r
F
.59129 .41422 m .59483 .42575 L .59207 .41868 L .844 .577 .035 r
F
.33371 .483 m .33382 .4822 L .33142 .47333 L 0 0 .221 r
F
.54001 .42692 m .54785 .43207 L .54831 .43616 L .969 .687 .442 r
F
.53965 .42478 m .54785 .43207 L .54001 .42692 L F
.23639 .39964 m .24922 .37089 L .25395 .35847 L 0 0 0 r
F
.23357 .41183 m .24922 .37089 L .23639 .39964 L 0 0 .014 r
F
.50408 .50845 m .50493 .52436 L .5006 .51007 L .965 .687 .457 r
F
.49907 .49453 m .50408 .50845 L .5006 .51007 L F
.25395 .35847 m .34128 .38461 L .34481 .37801 L .722 .354 .352 r
F
0 g
.34481 .37801 m
.34907 .37301 L
s
.34481 .37801 m .40142 .37737 L .40478 .37321 L .502 .053 .115 r
F
.34942 .39858 m .34129 .38461 L .34481 .37801 L .958 .688 .48 r
F
.34129 .38461 m .40142 .37737 L .34481 .37801 L .558 .172 .265 r
F
0 g
.34481 .37801 m
.34908 .37301 L
s
.49027 .46557 m .49405 .48059 L .48903 .46664 L .965 .687 .457 r
F
.48463 .45216 m .49027 .46557 L .48903 .46664 L F
.48515 .4514 m .49027 .46557 L .48463 .45216 L F
.51099 .33748 m .51262 .32271 L .51584 .33907 L .969 .687 .442 r
F
.51099 .33748 m .5068 .32073 L .51262 .32271 L F
.43914 .46019 m .43538 .46681 L .43827 .45878 L .962 .688 .467 r
F
.43914 .46019 m .43713 .46963 L .43538 .46681 L F
.47898 .43871 m .4763 .42464 L .47719 .4251 L .965 .687 .457 r
F
.52537 .45159 m .52931 .46409 L .52814 .46703 L .996 .763 .453 r
F
.52594 .44925 m .52931 .46409 L .52537 .45159 L .995 .755 .425 r
F
.39767 .47143 m .39512 .46971 L .3963 .46794 L .871 .522 .021 r
F
.39767 .47143 m .3972 .47498 L .39512 .46971 L F
.39899 .54788 m .39408 .55983 L .39329 .54419 L .958 .688 .48 r
F
.39899 .54788 m .40092 .5642 L .39408 .55983 L F
.51377 .41552 m .51405 .40629 L .51469 .41664 L .962 .633 .332 r
F
.51377 .41552 m .51222 .40404 L .51405 .40629 L F
.53411 .41041 m .53814 .40269 L .53513 .41215 L .969 .687 .442 r
F
.53411 .41041 m .5361 .39923 L .53814 .40269 L F
.48181 .51685 m .47859 .5203 L .47785 .51727 L .964 .688 .462 r
F
.48181 .51685 m .48272 .51985 L .47859 .5203 L F
0 g
.48181 .51685 m
.48538 .5152 L
s
.39411 .4607 m .39183 .45879 L .39067 .45333 L .901 .611 .109 r
F
.3951 .46434 m .39183 .45879 L .39411 .4607 L .886 .576 .069 r
F
.44447 .47726 m .44341 .48864 L .44265 .47597 L .962 .688 .467 r
F
.44447 .47726 m .44615 .49055 L .44341 .48864 L F
.1837 .38813 m .17154 .36176 L .17796 .34644 L .984 .755 .513 r
F
.16478 .36411 m .17154 .36176 L .17796 .34644 L .405 .067 .275 r
F
0 g
.17796 .34644 m
.18596 .3341 L
s
.48272 .51985 m .47934 .52334 L .47859 .5203 L .964 .688 .462 r
F
.48272 .51985 m .48363 .52286 L .47934 .52334 L F
.4341 .44498 m .42701 .4391 L .42694 .43591 L .962 .688 .467 r
F
.43425 .44667 m .42701 .4391 L .4341 .44498 L F
.52942 .49877 m .5254 .51737 L .52645 .50155 L .995 .869 .563 r
F
.52861 .4839 m .52942 .49877 L .52645 .50155 L .999 .837 .544 r
F
.21913 .53155 m .2024 .52148 L .21493 .51896 L .971 .684 .428 r
F
.21913 .53155 m .20806 .53845 L .2024 .52148 L F
.45808 .52003 m .45651 .53305 L .45393 .51925 L .962 .688 .467 r
F
.45808 .52003 m .46149 .53393 L .45651 .53305 L F
.48363 .52286 m .48009 .52637 L .47934 .52334 L .964 .688 .462 r
F
.48363 .52286 m .48454 .52587 L .48009 .52637 L F
.24848 .60883 m .23728 .61978 L .23929 .59761 L .956 .64 .388 r
F
.24848 .60883 m .24886 .63383 L .23728 .61978 L F
.21679 .60452 m .21029 .60845 L .20795 .59169 L .898 .496 .08 r
F
.21679 .60452 m .22144 .62459 L .21029 .60845 L F
.3963 .46794 m .39332 .46429 L .3951 .46434 L .876 .546 .039 r
F
.3963 .46794 m .39512 .46971 L .39332 .46429 L F
.57979 .38418 m .57965 .37974 L .58189 .38783 L .819 .421 0 r
F
.57979 .38418 m .57651 .37429 L .57965 .37974 L F
.48454 .52587 m .48083 .52941 L .48009 .52637 L .964 .688 .462 r
F
.48454 .52587 m .48545 .52887 L .48083 .52941 L F
.3951 .46434 m .39332 .46429 L .39183 .45879 L .886 .576 .069 r
F
.39252 .52865 m .3875 .53915 L .3879 .52459 L .958 .688 .48 r
F
.39252 .52865 m .39329 .54419 L .3875 .53915 L F
.48545 .52887 m .48158 .53245 L .48083 .52941 L .964 .688 .462 r
F
.48545 .52887 m .48636 .53188 L .48158 .53245 L F
.1799 .40323 m .17154 .36176 L .1837 .38813 L .986 .75 .493 r
F
.21493 .51896 m .2024 .52148 L .19785 .50426 L .973 .691 .435 r
F
.49907 .49453 m .5006 .51007 L .49627 .49578 L .965 .687 .457 r
F
.49405 .48059 m .49907 .49453 L .49627 .49578 L F
.41691 .40158 m .41356 .38569 L .41909 .39877 L .962 .688 .467 r
F
.42299 .41395 m .41691 .40158 L .41909 .39877 L F
.48636 .53188 m .48233 .53548 L .48158 .53245 L .964 .688 .462 r
F
.48636 .53188 m .48727 .53489 L .48233 .53548 L F
0 g
.48727 .53489 m
.49171 .53275 L
s
.54803 .44673 m .55592 .45913 L .55498 .46328 L .969 .687 .442 r
F
.5484 .44355 m .55592 .45913 L .54803 .44673 L F
.43827 .45878 m .43373 .4637 L .43745 .45724 L .962 .688 .467 r
F
.43827 .45878 m .43538 .46681 L .43373 .4637 L F
.56786 .49649 m .57161 .51686 L .56507 .5011 L .969 .687 .442 r
F
.56076 .48165 m .56786 .49649 L .56507 .5011 L F
.42374 .51168 m .42952 .51927 L .42003 .50917 L .679 .15 0 r
F
.42374 .51168 m .43415 .52239 L .42952 .51927 L F
.44879 .49177 m .44783 .50389 L .44615 .49055 L .962 .688 .467 r
F
.44879 .49177 m .45135 .50549 L .44783 .50389 L F
.26666 .57258 m .27114 .57254 L .25967 .56219 L 0 .069 .622 r
F
.26666 .57258 m .27993 .58563 L .27114 .57254 L F
.47898 .43871 m .48515 .4514 L .48463 .45216 L .965 .687 .457 r
F
.47467 .42445 m .47193 .41017 L .47545 .42443 L F
.47467 .42445 m .47035 .4102 L .47193 .41017 L F
.65221 .49665 m .63538 .53265 L .64955 .50486 L 0 0 0 r
F
.64955 .50486 m .63538 .53265 L .6311 .54058 L .65 .796 .347 r
F
0 g
.63569 .53169 m
.63862 .52271 L
s
.43425 .44667 m .42732 .44248 L .42701 .4391 L .962 .688 .467 r
F
.039 .916 .04 r
.39511 .45144 m
.4272 .44119 L
s
.43453 .44843 m .42732 .44248 L .43425 .44667 L .962 .688 .467 r
F
.49905 .38591 m .49522 .37383 L .50155 .38663 L .919 .534 .254 r
F
.49905 .38591 m .49188 .37283 L .49522 .37383 L F
.51154 .31437 m .54858 .2696 L .51761 .31647 L .9 .917 .823 r
F
.53033 .32704 m .51761 .31647 L .53533 .32875 L .589 .018 0 r
F
.53033 .32704 m .51154 .31437 L .51761 .31647 L F
0 g
.51761 .31647 m
.52396 .32028 L
s
.69367 .44253 m .70603 .46209 L .70536 .47349 L .98 .693 .391 r
F
.69352 .43305 m .70603 .46209 L .69367 .44253 L .98 .691 .386 r
F
.45851 .5353 m .45658 .53346 L .45349 .53441 L .512 .891 .964 r
F
.45851 .5353 m .46159 .53435 L .45658 .53346 L F
0 g
.45851 .5353 m
.46314 .53475 L
s
.46159 .53435 m
.46622 .53381 L
s
.67923 .40227 m .6912 .4119 L .69269 .42278 L .978 .685 .384 r
F
.67781 .39466 m .6912 .4119 L .67923 .40227 L .978 .683 .381 r
F
.41028 .4958 m .41249 .50154 L .40746 .49263 L .765 .299 0 r
F
.41028 .4958 m .41626 .50577 L .41249 .50154 L F
.42819 .42814 m .42167 .41672 L .42299 .41395 L .962 .688 .467 r
F
.42754 .43039 m .42167 .41672 L .42819 .42814 L F
.54024 .42897 m .54831 .43616 L .54849 .44001 L .969 .687 .442 r
F
.54001 .42692 m .54831 .43616 L .54024 .42897 L F
.43745 .45724 m .43221 .46037 L .43669 .45558 L .962 .688 .467 r
F
.43745 .45724 m .43373 .4637 L .43221 .46037 L F
.52082 .43684 m .52627 .44655 L .52594 .44925 L .988 .723 .421 r
F
.52087 .43533 m .52627 .44655 L .52082 .43684 L .987 .717 .405 r
F
.47898 .43871 m .47545 .42443 L .4763 .42464 L .965 .687 .457 r
F
.52231 .37196 m .52314 .35783 L .52537 .37368 L .969 .687 .442 r
F
.52231 .37196 m .51907 .35549 L .52314 .35783 L F
.38484 .50632 m .37876 .51352 L .38147 .50182 L .958 .688 .48 r
F
.38484 .50632 m .38328 .51952 L .37876 .51352 L F
.43453 .44843 m .42787 .44602 L .42732 .44248 L .962 .688 .467 r
F
.43492 .45024 m .42787 .44602 L .43453 .44843 L F
.50682 .39984 m .50418 .38807 L .50857 .40079 L .941 .582 .293 r
F
.50682 .39984 m .50155 .38663 L .50418 .38807 L F
.63329 .26942 m .63633 .2502 L .64032 .27594 L .969 .657 .358 r
F
.63329 .26942 m .62756 .24193 L .63633 .2502 L F
.35694 .52775 m .36046 .53018 L .35239 .52179 L 0 .018 .561 r
F
.35694 .52775 m .36617 .53765 L .36046 .53018 L F
.49405 .48059 m .49627 .49578 L .49195 .48151 L .965 .687 .457 r
F
.48903 .46664 m .49405 .48059 L .49195 .48151 L F
.73459 .5025 m .73624 .53001 L .73276 .54286 L .947 .791 .335 r
F
.73639 .48995 m .73624 .53001 L .73459 .5025 L .903 .743 .243 r
F
0 g
.73624 .53001 m
.73838 .51488 L
s
.43669 .45558 m .43084 .45688 L .43601 .45384 L .962 .688 .467 r
F
.43669 .45558 m .43221 .46037 L .43084 .45688 L F
.54926 .34243 m .54059 .3319 L .55344 .34492 L .683 .151 0 r
F
.54926 .34243 m .53533 .32875 L .54059 .3319 L F
.72507 .41267 m .73239 .44129 L .72598 .42296 L .92 .661 .17 r
F
.72598 .42296 m .73239 .44129 L .73273 .45392 L .941 .692 .221 r
F
.43492 .45024 m .42865 .44964 L .42787 .44602 L .962 .688 .467 r
F
.43541 .45205 m .42865 .44964 L .43492 .45024 L F
.43861 .52435 m .44817 .53209 L .43415 .52239 L .546 0 0 r
F
.43861 .52435 m .45349 .53441 L .44817 .53209 L F
.43601 .45384 m .42965 .45328 L .43541 .45205 L .962 .688 .467 r
F
.43601 .45384 m .43084 .45688 L .42965 .45328 L F
.34658 .63685 m .39407 .55984 L .33562 .63051 L .863 .842 .822 r
F
.34658 .63685 m .40092 .56421 L .39407 .55984 L F
0 g
.34658 .63685 m
.35711 .64051 L
s
.40092 .56421 m
.40751 .56687 L
s
.53305 .40887 m .5361 .39923 L .53411 .41041 L .969 .687 .442 r
F
.53305 .40887 m .534 .39614 L .5361 .39923 L F
.43541 .45205 m .42965 .45328 L .42865 .44964 L .962 .688 .467 r
F
.44873 .35462 m .46931 .34784 L .4531 .35326 L .24 .744 .689 r
F
.45379 .36866 m .4531 .35326 L .45741 .36749 L .965 .687 .457 r
F
.45379 .36866 m .44873 .35462 L .4531 .35326 L F
0 g
.4531 .35326 m
.45788 .35336 L
s
.37782 .54897 m .3871 .55382 L .37199 .54395 L 0 .237 .703 r
F
.37782 .54897 m .39407 .55984 L .3871 .55382 L F
.65326 .38499 m .6535 .38592 L .65608 .39509 L 0 0 .194 r
F
.65125 .37888 m .6535 .38592 L .65326 .38499 L 0 0 .228 r
F
.65125 .37888 m .65051 .37684 L .6535 .38592 L F
.59259 .42297 m .5956 .43214 L .59596 .43816 L .903 .667 .16 r
F
.59207 .41868 m .5956 .43214 L .59259 .42297 L .872 .622 .094 r
F
.51285 .4146 m .51222 .40404 L .51377 .41552 L .96 .631 .34 r
F
.51285 .4146 m .51038 .4022 L .51222 .40404 L F
.649 .37293 m .65051 .37684 L .65125 .37888 L .664 .338 0 r
F
.649 .37293 m .64716 .36799 L .65051 .37684 L F
.48463 .45216 m .48903 .46664 L .48401 .45268 L .965 .687 .457 r
F
.47898 .43871 m .48463 .45216 L .48401 .45268 L F
.42167 .41672 m .41691 .40158 L .42299 .41395 L .962 .688 .467 r
F
.5276 .38962 m .52852 .37622 L .52971 .39129 L .969 .687 .442 r
F
.5276 .38962 m .52537 .37368 L .52852 .37622 L F
.38968 .4337 m .38868 .42264 L .38959 .41741 L .926 .779 .304 r
F
.38937 .4381 m .38868 .42264 L .38968 .4337 L .876 .716 .197 r
F
.45883 .38269 m .45741 .36749 L .46172 .38172 L .965 .687 .457 r
F
.45883 .38269 m .45379 .36866 L .45741 .36749 L F
.5954 .44871 m .59589 .46402 L .59468 .46983 L .911 .778 .292 r
F
.59589 .44372 m .59589 .46402 L .5954 .44871 L .85 .709 .181 r
F
.48903 .46664 m .49195 .48151 L .48763 .46724 L .965 .687 .457 r
F
.48401 .45268 m .48903 .46664 L .48763 .46724 L F
.44265 .47597 m .44063 .48607 L .44079 .47425 L .962 .688 .467 r
F
.44265 .47597 m .44341 .48864 L .44063 .48607 L F
.65837 .34319 m .66537 .33344 L .66186 .34949 L .974 .672 .372 r
F
.65837 .34319 m .66019 .32403 L .66537 .33344 L F
.39098 .41291 m .39306 .39852 L .39535 .39392 L .924 .879 .456 r
F
.38959 .41741 m .39306 .39852 L .39098 .41291 L .852 .806 .317 r
F
.36297 .44045 m .35399 .43132 L .35457 .42423 L .958 .688 .48 r
F
.36301 .44625 m .35399 .43132 L .36297 .44045 L F
.35575 .41791 m .34719 .40535 L .34942 .39858 L F
.35457 .42423 m .34719 .40535 L .35575 .41791 L F
.47898 .43871 m .47467 .42445 L .47545 .42443 L .965 .687 .457 r
F
.655 .39115 m .65608 .39509 L .65821 .40418 L .702 .441 0 r
F
.65326 .38499 m .65608 .39509 L .655 .39115 L 0 0 .194 r
F
.46388 .39672 m .46172 .38172 L .46604 .39596 L .965 .687 .457 r
F
.46388 .39672 m .45883 .38269 L .46172 .38172 L F
.24495 .65018 m .24339 .66102 L .23307 .63859 L .845 .391 0 r
F
.24495 .65018 m .25771 .67492 L .24339 .66102 L F
.34719 .40535 m .34129 .38461 L .34942 .39858 L .958 .688 .48 r
F
.43121 .37649 m .43345 .37111 L .43452 .37407 L .964 .688 .462 r
F
0 g
.43452 .37407 m
.43824 .37286 L
s
.41081 .38917 m .40801 .37258 L .41356 .38569 L .962 .688 .467 r
F
.41691 .40158 m .41081 .38917 L .41356 .38569 L F
.48876 .37281 m .48357 .36017 L .49188 .37283 L .894 .491 .238 r
F
.48876 .37281 m .47966 .3601 L .48357 .36017 L F
.2284 .45777 m .23163 .44066 L .23197 .42558 L 0 0 .116 r
F
.22914 .47058 m .23163 .44066 L .2284 .45777 L 0 0 .251 r
F
.66158 .42966 m .66066 .4558 L .66162 .43708 L 0 0 .059 r
F
.66162 .43708 m .66066 .4558 L .65999 .4647 L .732 .635 .072 r
F
.039 .916 .04 r
.43085 .44002 m
.44985 .43398 L
s
0 0 0 r
2 Mabswid
.43085 .44002 Mdot
.54024 .42897 m .54849 .44001 L .54033 .4309 L .969 .687 .442 r
F
.54033 .4309 m .54849 .44001 L .5484 .44355 L F
.43 .37363 m .43239 .36816 L .43345 .37111 L .964 .688 .462 r
F
.43121 .37649 m .43 .37363 L .43345 .37111 L F
.57762 .38092 m .57651 .37429 L .57979 .38418 L .838 .426 0 r
F
.57762 .38092 m .57327 .36941 L .57651 .37429 L F
.73216 .46533 m .73639 .48995 L .73459 .5025 L .95 .751 .289 r
F
.73273 .45392 m .73639 .48995 L .73216 .46533 L .918 .711 .216 r
F
.16918 .46188 m .16129 .44436 L .162 .42561 L .978 .755 .339 r
F
.16995 .47782 m .16129 .44436 L .16918 .46188 L .962 .72 .277 r
F
.64654 .36723 m .64716 .36799 L .649 .37293 L .673 .323 0 r
F
.64654 .36723 m .64349 .35951 L .64716 .36799 L F
.46892 .41073 m .46604 .39596 L .47035 .4102 L .965 .687 .457 r
F
.46892 .41073 m .46388 .39672 L .46604 .39596 L F
.32775 .43992 m .32947 .42721 L .33026 .41834 L 0 0 0 r
F
.32774 .44765 m .32947 .42721 L .32775 .43992 L 0 0 .126 r
F
.4288 .37077 m .43132 .3652 L .43239 .36816 L .964 .688 .462 r
F
.43 .37363 m .4288 .37077 L .43239 .36816 L F
.52065 .43819 m .52594 .44925 L .52537 .45159 L .988 .729 .437 r
F
.52082 .43684 m .52594 .44925 L .52065 .43819 L .988 .723 .421 r
F
.039 .916 .04 r
.5 Mabswid
.52302 .43847 m
.52309 .43845 L
s
.52309 .43845 m
.5231 .43844 L
s
.48891 .44941 m
.52098 .43913 L
s
.52298 .43848 m
.52302 .43847 L
s
.42754 .43039 m .42069 .42009 L .42167 .41672 L .962 .688 .467 r
F
.42712 .433 m .42069 .42009 L .42754 .43039 L F
.48401 .45268 m .48763 .46724 L .4833 .45297 L .965 .687 .457 r
F
.47898 .43871 m .48401 .45268 L .4833 .45297 L F
.42759 .36791 m .43026 .36225 L .43132 .3652 L .964 .688 .462 r
F
.4288 .37077 m .42759 .36791 L .43132 .3652 L F
.47395 .42472 m .47035 .4102 L .47467 .42445 L .965 .687 .457 r
F
.47395 .42472 m .46892 .41073 L .47035 .4102 L F
.19201 .43952 m .17765 .42032 L .1799 .40323 L .982 .733 .481 r
F
.19155 .45445 m .17765 .42032 L .19201 .43952 L .982 .726 .465 r
F
.5152 .35426 m .51584 .33907 L .51907 .35549 L .969 .687 .442 r
F
.5152 .35426 m .51099 .33748 L .51584 .33907 L F
.42638 .36504 m .42919 .35929 L .43026 .36225 L .964 .688 .462 r
F
.42759 .36791 m .42638 .36504 L .43026 .36225 L F
.52814 .46703 m .52861 .4839 L .52664 .46933 L .999 .801 .49 r
F
.52458 .45354 m .52814 .46703 L .52664 .46933 L .995 .768 .479 r
F
.52537 .45159 m .52814 .46703 L .52458 .45354 L .996 .763 .453 r
F
.45135 .50549 m .44952 .51728 L .44783 .50389 L .962 .688 .467 r
F
.45135 .50549 m .45393 .51925 L .44952 .51728 L F
.42517 .36218 m .42813 .35634 L .42919 .35929 L .964 .688 .462 r
F
.42638 .36504 m .42517 .36218 L .42919 .35929 L F
.53197 .40754 m .534 .39614 L .53305 .40887 L .969 .687 .442 r
F
.53197 .40754 m .53185 .39348 L .534 .39614 L F
.47898 .43871 m .47395 .42472 L .47467 .42445 L .965 .687 .457 r
F
.40746 .49263 m .40878 .49654 L .40469 .48889 L .722 .275 0 r
F
.40746 .49263 m .41249 .50154 L .40878 .49654 L F
.42517 .36218 m .42396 .35931 L .42813 .35634 L .964 .688 .462 r
F
0 g
.42813 .35634 m
.4328 .3549 L
s
.39535 .39392 m .40142 .37737 L .40478 .37321 L .876 .933 .555 r
F
.40142 .37737 m .40784 .37218 L .40478 .37321 L .22 0 0 r
F
0 g
.40478 .37321 m
.40868 .37043 L
s
.5254 .51737 m .56308 .52374 L .5213 .51935 L .403 0 0 r
F
.5254 .51737 m .56777 .52137 L .56308 .52374 L F
.52645 .50155 m .5254 .51737 L .5213 .51935 L .992 .866 .608 r
F
0 g
.5254 .51737 m
.52896 .51399 L
s
.39306 .39852 m .40142 .37737 L .39535 .39392 L .769 .84 .382 r
F
.65643 .39727 m .65821 .40418 L .65986 .41307 L .736 .493 0 r
F
.655 .39115 m .65821 .40418 L .65643 .39727 L .702 .441 0 r
F
.52861 .4839 m .52645 .50155 L .52623 .48609 L .999 .837 .544 r
F
.52664 .46933 m .52861 .4839 L .52623 .48609 L .997 .804 .523 r
F
.51195 .4139 m .51038 .4022 L .51285 .4146 L .958 .63 .35 r
F
.51195 .4139 m .50857 .40079 L .51038 .4022 L F
.65999 .4647 m .65221 .49665 L .65859 .47248 L 0 0 0 r
F
.65859 .47248 m .65221 .49665 L .64955 .50486 L .736 .757 .249 r
F
.64406 .30206 m .64747 .28419 L .64945 .30821 L .971 .663 .365 r
F
.64406 .30206 m .64032 .27594 L .64747 .28419 L F
.61139 .20746 m .63138 .2114 L .6216 .21479 L .644 .854 .98 r
F
.61907 .23597 m .6216 .21479 L .62756 .24193 L .967 .651 .353 r
F
.61907 .23597 m .61139 .20746 L .6216 .21479 L F
0 g
.6216 .21479 m
.6321 .22484 L
s
.38147 .50182 m .3744 .50669 L .37822 .49672 L .958 .688 .48 r
F
.38147 .50182 m .37876 .51352 L .3744 .50669 L F
.47898 .43871 m .47333 .42523 L .47395 .42472 L .965 .687 .457 r
F
.47898 .43871 m .47279 .42597 L .47333 .42523 L F
.47898 .43871 m .47237 .42694 L .47279 .42597 L F
.47898 .43871 m .47206 .4281 L .47237 .42694 L F
.47898 .43871 m .47186 .42945 L .47206 .4281 L F
.47898 .43871 m .47179 .43095 L .47186 .42945 L F
.47898 .43871 m .47184 .4326 L .47179 .43095 L F
.47898 .43871 m .47202 .43434 L .47184 .4326 L F
.47898 .43871 m .47231 .43617 L .47202 .43434 L F
.47898 .43871 m .47272 .43804 L .47231 .43617 L F
.47898 .43871 m .47323 .43992 L .47272 .43804 L F
.47898 .43871 m .47385 .44178 L .47323 .43992 L F
.039 .916 .04 r
.46 .44479 m
.47342 .44049 L
s
.47898 .43871 m .47455 .44358 L .47385 .44178 L .965 .687 .457 r
F
.47898 .43871 m .47533 .4453 L .47455 .44358 L F
.47898 .43871 m .47618 .44691 L .47533 .4453 L F
.47898 .43871 m .47707 .44838 L .47618 .44691 L F
.47898 .43871 m .47799 .44968 L .47707 .44838 L F
.47898 .43871 m .47893 .45079 L .47799 .44968 L F
.47898 .43871 m .47987 .45169 L .47893 .45079 L F
.47898 .43871 m .48079 .45237 L .47987 .45169 L F
.47898 .43871 m .48168 .45281 L .48079 .45237 L F
.47898 .43871 m .48252 .45301 L .48168 .45281 L F
.47898 .43871 m .4833 .45297 L .48252 .45301 L F
.3318 .41045 m .33857 .3927 L .34128 .38461 L 0 0 0 r
F
.33026 .41834 m .33857 .3927 L .3318 .41045 L 0 0 .016 r
F
.44615 .49055 m .44418 .50137 L .44341 .48864 L .962 .688 .467 r
F
.44615 .49055 m .44783 .50389 L .44418 .50137 L F
.68182 .29748 m .68106 .28523 L .68715 .30492 L .883 .484 .037 r
F
.68182 .29748 m .67398 .27531 L .68106 .28523 L F
.56344 .35902 m .55776 .34853 L .56668 .36171 L .781 .299 0 r
F
.56344 .35902 m .55344 .34492 L .55776 .34853 L F
.039 .916 .04 r
.5231 .43844 m
.52319 .43842 L
s
.44079 .47425 m .43784 .48289 L .43895 .47213 L .962 .688 .467 r
F
.44079 .47425 m .44063 .48607 L .43784 .48289 L F
.55498 .46328 m .56076 .48165 L .55364 .46675 L .969 .687 .442 r
F
.54739 .4495 m .55498 .46328 L .55364 .46675 L F
.54803 .44673 m .55498 .46328 L .54739 .4495 L F
.4833 .45297 m .48607 .46734 L .48252 .45301 L .965 .687 .457 r
F
.4833 .45297 m .48763 .46724 L .48607 .46734 L F
.56076 .48165 m .56507 .5011 L .55851 .4853 L .969 .687 .442 r
F
.55364 .46675 m .56076 .48165 L .55851 .4853 L F
.59259 .42297 m .59596 .43816 L .59283 .42699 L .903 .667 .16 r
F
.59283 .42699 m .59596 .43816 L .59589 .44372 L .932 .71 .228 r
F
.64391 .36187 m .64349 .35951 L .64654 .36723 L .693 .317 0 r
F
.64391 .36187 m .63958 .35152 L .64349 .35951 L F
.38937 .4381 m .38826 .42851 L .38868 .42264 L .876 .716 .197 r
F
.38943 .4429 m .38826 .42851 L .38937 .4381 L .816 .641 .088 r
F
.41081 .38917 m .40468 .37672 L .40801 .37258 L .962 .688 .467 r
F
.40142 .37737 m .4045 .37634 L .40784 .37218 L .22 0 0 r
F
0 g
.40784 .37218 m
.41173 .3694 L
s
.40092 .5642 m .44264 .52836 L .39408 .55983 L .767 .854 .915 r
F
.40092 .5642 m .44817 .53209 L .44264 .52836 L F
0 g
.40092 .5642 m
.40751 .56686 L
s
.68023 .40958 m .69269 .42278 L .69352 .43305 L .978 .687 .388 r
F
.67923 .40227 m .69269 .42278 L .68023 .40958 L .978 .685 .384 r
F
.48763 .46724 m .48962 .48169 L .48607 .46734 L .965 .687 .457 r
F
.48763 .46724 m .49195 .48151 L .48962 .48169 L F
.50516 .39937 m .50155 .38663 L .50682 .39984 L .939 .585 .317 r
F
.50516 .39937 m .49905 .38591 L .50155 .38663 L F
.54028 .43267 m .5484 .44355 L .54803 .44673 L .969 .687 .442 r
F
.54033 .4309 m .5484 .44355 L .54028 .43267 L F
.47333 .42523 m .46892 .41073 L .47395 .42472 L .965 .687 .457 r
F
.42003 .50917 m .42481 .51503 L .41626 .50577 L .596 .081 0 r
F
.42003 .50917 m .42952 .51927 L .42481 .51503 L F
.36301 .44625 m .35403 .43907 L .35399 .43132 L .958 .688 .48 r
F
.039 .916 .04 r
.32834 .44467 m
.35402 .43639 L
s
.36351 .45242 m .35403 .43907 L .36301 .44625 L .958 .688 .48 r
F
.42712 .433 m .42005 .424 L .42069 .42009 L .962 .688 .467 r
F
.42694 .43591 m .42005 .424 L .42712 .433 L F
.51432 .42739 m .51938 .42641 L .5199 .42828 L .974 .686 .416 r
F
.51432 .42739 m .51877 .42455 L .51938 .42641 L .973 .683 .414 r
F
.71023 .36734 m .7152 .36704 L .71853 .37876 L .929 .612 .151 r
F
.70765 .35951 m .7152 .36704 L .71023 .36734 L .924 .597 .136 r
F
.70765 .35951 m .71138 .35541 L .7152 .36704 L F
.51432 .42739 m .51807 .42275 L .51877 .42455 L .972 .681 .412 r
F
.35239 .52179 m .35497 .52165 L .34801 .515 L 0 .045 .603 r
F
.35239 .52179 m .36046 .53018 L .35497 .52165 L F
.62269 .32711 m .61475 .31649 L .62696 .33187 L .607 .126 0 r
F
.62269 .32711 m .60904 .31013 L .61475 .31649 L F
.51432 .42739 m .5199 .42828 L .52031 .43014 L .974 .688 .419 r
F
.49195 .48151 m .49317 .49607 L .48962 .48169 L .965 .687 .457 r
F
.49195 .48151 m .49627 .49578 L .49317 .49607 L F
.52037 .43936 m .52537 .45159 L .52458 .45354 L .987 .733 .453 r
F
.52065 .43819 m .52537 .45159 L .52037 .43936 L .988 .729 .437 r
F
.70478 .35186 m .71138 .35541 L .70765 .35951 L .922 .584 .127 r
F
.70478 .35186 m .70712 .34407 L .71138 .35541 L F
.41513 .40525 m .41081 .38917 L .41691 .40158 L .962 .688 .467 r
F
.42167 .41672 m .41513 .40525 L .41691 .40158 L F
.29842 .60656 m .31324 .61007 L .28908 .59704 L 0 .347 .814 r
F
.29842 .60656 m .32444 .62154 L .31324 .61007 L F
.56507 .5011 m .57161 .51686 L .56759 .52087 L .969 .687 .442 r
F
0 g
.56777 .52137 m
.57181 .51734 L
s
.51432 .42739 m .5173 .42103 L .51807 .42275 L .972 .679 .411 r
F
.3879 .52459 m .38171 .53282 L .38328 .51952 L .958 .688 .48 r
F
.3879 .52459 m .3875 .53915 L .38171 .53282 L F
.51154 .31437 m .54065 .26652 L .54858 .2696 L .9 .917 .823 r
F
.57032 .2818 m .54858 .2696 L .57682 .28431 L .41 0 0 r
F
.57032 .2818 m .54065 .26652 L .54858 .2696 L F
0 g
.55627 .27457 m
.55688 .27496 L
s
.42069 .42009 m .41513 .40525 L .42167 .41672 L .962 .688 .467 r
F
.51432 .42739 m .52031 .43014 L .52062 .43195 L .975 .691 .423 r
F
.25967 .56219 m .26289 .55799 L .25312 .55066 L 0 .076 .637 r
F
.25967 .56219 m .27114 .57254 L .26289 .55799 L F
.49627 .49578 m .49673 .51046 L .49317 .49607 L .965 .687 .457 r
F
.49627 .49578 m .5006 .51007 L .49673 .51046 L F
.51432 .42739 m .51647 .41942 L .5173 .42103 L .971 .677 .41 r
F
.48252 .45301 m .48438 .46696 L .48168 .45281 L .965 .687 .457 r
F
.48252 .45301 m .48607 .46734 L .48438 .46696 L F
.5309 .40645 m .53185 .39348 L .53197 .40754 L .969 .687 .442 r
F
.5309 .40645 m .52971 .39129 L .53185 .39348 L F
.57542 .37811 m .57327 .36941 L .57762 .38092 L .857 .435 0 r
F
.57542 .37811 m .56997 .36519 L .57327 .36941 L F
.49673 .38591 m .49188 .37283 L .49905 .38591 L .918 .543 .292 r
F
.49673 .38591 m .48876 .37281 L .49188 .37283 L F
.46766 .41173 m .46388 .39672 L .46892 .41073 L .965 .687 .457 r
F
.47333 .42523 m .46766 .41173 L .46892 .41073 L F
.71247 .37523 m .71853 .37876 L .72131 .39039 L .936 .629 .17 r
F
.71023 .36734 m .71853 .37876 L .71247 .37523 L .929 .612 .151 r
F
.51432 .42739 m .52062 .43195 L .5208 .4337 L .975 .693 .426 r
F
.58974 .49349 m .57922 .5192 L .58689 .4983 L .812 .874 .436 r
F
.59292 .47468 m .58974 .49349 L .58689 .4983 L .929 .886 .472 r
F
.59468 .46983 m .58974 .49349 L .59292 .47468 L .859 .819 .339 r
F
.52556 .38848 m .52537 .37368 L .5276 .38962 L .969 .687 .442 r
F
.52556 .38848 m .52231 .37196 L .52537 .37368 L F
.5006 .51007 m .5003 .52489 L .49673 .51046 L .965 .687 .457 r
F
.5006 .51007 m .50493 .52436 L .5003 .52489 L F
.40469 .48889 m .40522 .49088 L .40202 .48465 L .679 .258 0 r
F
.40469 .48889 m .40878 .49654 L .40522 .49088 L F
.65754 .40324 m .65986 .41307 L .66098 .42161 L .778 .55 0 r
F
.65643 .39727 m .65986 .41307 L .65754 .40324 L .736 .493 0 r
F
.43895 .47213 m .43511 .47914 L .43713 .46963 L .962 .688 .467 r
F
.43895 .47213 m .43784 .48289 L .43511 .47914 L F
.51107 .41343 m .50857 .40079 L .51195 .4139 L .956 .629 .361 r
F
.51107 .41343 m .50682 .39984 L .50857 .40079 L F
.51432 .42739 m .5156 .41795 L .51647 .41942 L .97 .675 .41 r
F
.47279 .42597 m .46766 .41173 L .47333 .42523 L .965 .687 .457 r
F
.45393 .51925 m .45122 .53073 L .44952 .51728 L .962 .688 .467 r
F
.45393 .51925 m .45651 .53305 L .45122 .53073 L F
.20795 .59169 m .19984 .59044 L .19969 .57742 L .895 .505 .063 r
F
.20795 .59169 m .21029 .60845 L .19984 .59044 L F
.37822 .49672 m .3703 .49916 L .37516 .49109 L .958 .688 .48 r
F
.37822 .49672 m .3744 .50669 L .3703 .49916 L F
.50493 .52436 m .51672 .51986 L .5003 .52489 L .339 .82 .821 r
F
.32774 .44765 m .32947 .43691 L .32947 .42721 L 0 0 .126 r
F
.32836 .45589 m .32947 .43691 L .32774 .44765 L 0 0 .253 r
F
.57922 .5192 m .62584 .54634 L .57506 .5234 L .704 .252 .175 r
F
.57922 .5192 m .6311 .54058 L .62584 .54634 L F
.58689 .4983 m .57922 .5192 L .57506 .5234 L .902 .945 .589 r
F
0 g
.57922 .5192 m
.58265 .51335 L
s
.24922 .37089 m .34128 .38461 L .25395 .35847 L .729 .399 .421 r
F
0 g
.25395 .35847 m
.25995 .34842 L
s
.70167 .34454 m .70712 .34407 L .70478 .35186 L .921 .575 .123 r
F
.70167 .34454 m .7025 .33318 L .70712 .34407 L F
.65478 .33754 m .66019 .32403 L .65837 .34319 L .974 .671 .373 r
F
.65478 .33754 m .65485 .31558 L .66019 .32403 L F
.52645 .50155 m .5213 .51935 L .52303 .50315 L .992 .866 .608 r
F
0 g
.5213 .51935 m
.5254 .51737 L
s
.52623 .48609 m .52645 .50155 L .52303 .50315 L .993 .835 .579 r
F
.47785 .51727 m .47412 .51945 L .47355 .51645 L .964 .688 .462 r
F
.47785 .51727 m .47859 .5203 L .47412 .51945 L F
0 g
.47785 .51727 m
.48181 .51685 L
s
.51432 .42739 m .5208 .4337 L .52087 .43533 L .975 .695 .431 r
F
.39329 .54419 m .3871 .55382 L .3875 .53915 L .958 .688 .48 r
F
.39329 .54419 m .39408 .55983 L .3871 .55382 L F
.38959 .41741 m .39133 .40413 L .39306 .39852 L .852 .806 .317 r
F
.38868 .42264 m .39133 .40413 L .38959 .41741 L .751 .699 .159 r
F
.16433 .40854 m .16006 .3822 L .16478 .36411 L .98 .824 .422 r
F
.162 .42561 m .16006 .3822 L .16433 .40854 L .957 .784 .336 r
F
.46197 .3982 m .45883 .38269 L .46388 .39672 L .965 .687 .457 r
F
.46766 .41173 m .46197 .3982 L .46388 .39672 L F
.47609 .36126 m .46931 .34784 L .47966 .3601 L .868 .457 .245 r
F
.46573 .34902 m .46499 .34918 L .46931 .34784 L .24 .744 .689 r
F
.44873 .35462 m .46499 .34918 L .46573 .34902 L F
.45057 .37105 m .44873 .35462 L .45379 .36866 L .965 .687 .457 r
F
.45057 .37105 m .44485 .35743 L .44873 .35462 L F
.44485 .35743 m .46499 .34918 L .44873 .35462 L .015 0 0 r
F
.46149 .35061 m .46116 .35198 L .46499 .34918 L F
.44485 .35743 m .46116 .35198 L .46149 .35061 L F
.47025 .36719 m .4579 .35621 L .46116 .35198 L .865 .5 .357 r
F
.4579 .35621 m .4608 .3535 L .46116 .35198 L 0 0 0 r
F
.46116 .35198 m .46417 .34936 L .46499 .34918 L .542 .877 .615 r
F
.46417 .34936 m .49621 .32142 L .46499 .34918 L F
.47609 .36126 m .46499 .34918 L .46931 .34784 L .868 .457 .245 r
F
.46499 .34918 m .5012 .31995 L .46931 .34784 L .707 .983 .815 r
F
.46499 .34918 m .49621 .32142 L .5012 .31995 L F
.47293 .36363 m .46499 .34918 L .47609 .36126 L .867 .48 .305 r
F
.47293 .36363 m .46116 .35198 L .46499 .34918 L F
.47025 .36719 m .46116 .35198 L .47293 .36363 L .865 .5 .357 r
F
.46116 .35198 m .49179 .32463 L .49621 .32142 L .542 .877 .615 r
F
.4608 .3535 m .49179 .32463 L .46116 .35198 L 0 0 0 r
F
.46931 .34784 m .5012 .31995 L .50667 .32022 L .779 .985 .901 r
F
0 g
.46931 .34784 m
.47404 .34796 L
s
.50667 .32022 m
.51253 .32221 L
s
.46567 .34897 m
.46931 .34784 L
s
.42694 .43591 m .41977 .42838 L .42005 .424 L .962 .688 .467 r
F
.42701 .4391 m .41977 .42838 L .42694 .43591 L F
.51941 .37107 m .51907 .35549 L .52231 .37196 L .969 .687 .442 r
F
.51941 .37107 m .5152 .35426 L .51907 .35549 L F
.38943 .4429 m .38834 .43492 L .38826 .42851 L .816 .641 .088 r
F
.38986 .448 m .38834 .43492 L .38943 .4429 L .755 .561 0 r
F
.51432 .42739 m .51469 .41664 L .5156 .41795 L .969 .673 .411 r
F
.47859 .5203 m .47469 .52246 L .47412 .51945 L .964 .688 .462 r
F
.47859 .5203 m .47934 .52334 L .47469 .52246 L F
.48168 .45281 m .4826 .46608 L .48079 .45237 L .965 .687 .457 r
F
.48168 .45281 m .48438 .46696 L .4826 .46608 L F
.61139 .20746 m .62123 .20403 L .63138 .2114 L .644 .854 .98 r
F
.63829 .22936 m .63138 .2114 L .64669 .23539 L .828 .364 0 r
F
.63829 .22936 m .62123 .20403 L .63138 .2114 L F
0 g
.63138 .2114 m
.64183 .22148 L
s
.35457 .42423 m .34569 .41324 L .34719 .40535 L .958 .688 .48 r
F
.35399 .43132 m .34569 .41324 L .35457 .42423 L F
.65997 .2604 m .65538 .24371 L .66691 .26699 L .859 .424 .001 r
F
.65997 .2604 m .64669 .23539 L .65538 .24371 L F
.52664 .46933 m .52623 .48609 L .52485 .47095 L .997 .804 .523 r
F
.52358 .45506 m .52664 .46933 L .52485 .47095 L .992 .771 .502 r
F
.52458 .45354 m .52664 .46933 L .52358 .45506 L .995 .768 .479 r
F
.22914 .47058 m .23258 .45679 L .23163 .44066 L 0 0 .251 r
F
.23089 .48396 m .23258 .45679 L .22914 .47058 L 0 0 .36 r
F
.36351 .45242 m .35469 .44734 L .35403 .43907 L .958 .688 .48 r
F
.36446 .45887 m .35469 .44734 L .36351 .45242 L F
.64115 .35695 m .63958 .35152 L .64391 .36187 L .72 .321 0 r
F
.64115 .35695 m .63547 .34418 L .63958 .35152 L F
.54009 .43426 m .54803 .44673 L .54739 .4495 L .969 .687 .442 r
F
.54028 .43267 m .54803 .44673 L .54009 .43426 L F
.039 .916 .04 r
.52319 .43842 m
.54025 .43293 L
s
.27202 .68567 m .2646 .6729 L .25771 .67492 L .638 .789 .954 r
F
.27202 .68567 m .27887 .68367 L .2646 .6729 L F
0 g
.27202 .68567 m
.28604 .69311 L
s
.27887 .68367 m
.29285 .69113 L
s
.47934 .52334 m .47526 .52548 L .47469 .52246 L .964 .688 .462 r
F
.47934 .52334 m .48009 .52637 L .47526 .52548 L F
.51432 .42739 m .52087 .43533 L .52082 .43684 L .976 .697 .435 r
F
.43415 .52239 m .44264 .52836 L .42952 .51927 L .414 0 0 r
F
.43415 .52239 m .44817 .53209 L .44264 .52836 L F
.48607 .46734 m .48709 .48114 L .48438 .46696 L .965 .687 .457 r
F
.48607 .46734 m .48962 .48169 L .48709 .48114 L F
.44341 .48864 m .44046 .49796 L .44063 .48607 L .962 .688 .467 r
F
.44341 .48864 m .44418 .50137 L .44046 .49796 L F
.47279 .42597 m .46658 .4132 L .46766 .41173 L .965 .687 .457 r
F
.47237 .42694 m .46658 .4132 L .47279 .42597 L F
.039 .916 .04 r
.35778 .43517 m
.3879 .42541 L
s
.26069 .64548 m .2503 .65896 L .24886 .63383 L .949 .618 .362 r
F
.26069 .64548 m .2646 .6729 L .2503 .65896 L F
.45628 .38464 m .45379 .36866 L .45883 .38269 L .965 .687 .457 r
F
.46197 .3982 m .45628 .38464 L .45883 .38269 L F
.59802 .30167 m .58365 .28874 L .60344 .30516 L .546 0 0 r
F
.59802 .30167 m .57682 .28431 L .58365 .28874 L F
.59448 .45305 m .59468 .46983 L .59292 .47468 L .955 .828 .394 r
F
.5954 .44871 m .59468 .46983 L .59448 .45305 L .911 .778 .292 r
F
.48009 .52637 m .47583 .52849 L .47526 .52548 L .964 .688 .462 r
F
.48009 .52637 m .48083 .52941 L .47583 .52849 L F
.23929 .59761 m .22616 .60358 L .23049 .58471 L .96 .646 .385 r
F
.23929 .59761 m .23728 .61978 L .22616 .60358 L F
.51997 .44033 m .52458 .45354 L .52358 .45506 L .986 .736 .467 r
F
.52037 .43936 m .52458 .45354 L .51997 .44033 L .987 .733 .453 r
F
.51432 .42739 m .51377 .41552 L .51469 .41664 L .968 .672 .412 r
F
.43713 .46963 m .43248 .47489 L .43538 .46681 L .962 .688 .467 r
F
.43713 .46963 m .43511 .47914 L .43248 .47489 L F
.37199 .54395 m .38012 .54624 L .36617 .53765 L 0 .294 .779 r
F
.37199 .54395 m .3871 .55382 L .38012 .54624 L F
.71434 .38307 m .72131 .39039 L .7235 .40175 L .944 .647 .195 r
F
.71247 .37523 m .72131 .39039 L .71434 .38307 L .936 .629 .17 r
F
.56507 .5011 m .56759 .52087 L .56169 .50439 L .969 .687 .442 r
F
.55851 .4853 m .56507 .5011 L .56169 .50439 L F
.59278 .4307 m .59589 .44372 L .5954 .44871 L .958 .748 .296 r
F
.59283 .42699 m .59589 .44372 L .59278 .4307 L .932 .71 .228 r
F
.039 .916 .04 r
.59346 .42927 m
.59365 .42921 L
s
.24922 .37089 m .33857 .3927 L .34128 .38461 L .729 .399 .421 r
F
0 g
.34128 .38461 m
.34481 .37801 L
s
.34129 .38461 m .39868 .38285 L .40142 .37737 L .558 .172 .265 r
F
.34719 .40535 m .33857 .3927 L .34129 .38461 L .958 .688 .48 r
F
.33857 .3927 m .39868 .38285 L .34129 .38461 L .593 .258 .372 r
F
0 g
.34129 .38461 m
.34481 .37801 L
s
.48083 .52941 m .4764 .53151 L .47583 .52849 L .964 .688 .462 r
F
.48083 .52941 m .48158 .53245 L .4764 .53151 L F
.40202 .48465 m .40186 .48463 L .39951 .47999 L .642 .252 0 r
F
.40202 .48465 m .40522 .49088 L .40186 .48463 L F
.44783 .50389 m .44495 .51416 L .44418 .50137 L .962 .688 .467 r
F
.44783 .50389 m .44952 .51728 L .44495 .51416 L F
.48079 .45237 m .48075 .46474 L .47987 .45169 L .965 .687 .457 r
F
.48079 .45237 m .4826 .46608 L .48075 .46474 L F
.52984 .40562 m .52971 .39129 L .5309 .40645 L .969 .687 .442 r
F
.52984 .40562 m .5276 .38962 L .52971 .39129 L F
.51432 .42739 m .52082 .43684 L .52065 .43819 L .975 .699 .44 r
F
.42701 .4391 m .41987 .43316 L .41977 .42838 L .962 .688 .467 r
F
.42732 .44248 m .41987 .43316 L .42701 .4391 L F
.45349 .53441 m .45127 .53114 L .44817 .53209 L .597 .874 .993 r
F
.45349 .53441 m .45658 .53346 L .45127 .53114 L F
0 g
.45349 .53441 m
.45851 .5353 L
s
.45658 .53346 m
.46159 .53435 L
s
.37516 .49109 m .36652 .49106 L .37235 .48504 L .958 .688 .48 r
F
.37516 .49109 m .3703 .49916 L .36652 .49106 L F
.34801 .515 m .34979 .51224 L .34389 .50751 L 0 .052 .618 r
F
.34801 .515 m .35497 .52165 L .34979 .51224 L F
.48158 .53245 m .47697 .53452 L .4764 .53151 L .964 .688 .462 r
F
.48158 .53245 m .48233 .53548 L .47697 .53452 L F
0 g
.48233 .53548 m
.48727 .53489 L
s
.46658 .4132 m .46197 .3982 L .46766 .41173 L .965 .687 .457 r
F
.16995 .47782 m .16223 .46446 L .16129 .44436 L .962 .72 .277 r
F
.172 .49448 m .16223 .46446 L .16995 .47782 L .944 .681 .217 r
F
.71525 .50828 m .72279 .54578 L .71223 .51888 L .984 .705 .401 r
F
.70377 .48347 m .71525 .50828 L .71223 .51888 L .982 .701 .402 r
F
.70536 .47349 m .71525 .50828 L .70377 .48347 L .982 .699 .395 r
F
.45628 .38464 m .45057 .37105 L .45379 .36866 L .965 .687 .457 r
F
.55364 .46675 m .55851 .4853 L .55193 .46946 L .969 .687 .442 r
F
.54649 .45179 m .55364 .46675 L .55193 .46946 L F
.54739 .4495 m .55364 .46675 L .54649 .45179 L F
.51024 .41321 m .50682 .39984 L .51107 .41343 L .953 .63 .373 r
F
.51024 .41321 m .50516 .39937 L .50682 .39984 L F
.40856 .39374 m .40468 .37672 L .41081 .38917 L .962 .688 .467 r
F
.41513 .40525 m .40856 .39374 L .41081 .38917 L F
.51432 .42739 m .51285 .4146 L .51377 .41552 L .967 .671 .415 r
F
.50362 .3994 m .49905 .38591 L .50516 .39937 L .936 .589 .341 r
F
.50362 .3994 m .49673 .38591 L .49905 .38591 L F
.42069 .42009 m .4138 .40973 L .41513 .40525 L .962 .688 .467 r
F
.42005 .424 m .4138 .40973 L .42069 .42009 L F
.47237 .42694 m .46572 .41511 L .46658 .4132 L .965 .687 .457 r
F
.47206 .4281 m .46572 .41511 L .47237 .42694 L F
.38986 .448 m .38892 .44176 L .38834 .43492 L .755 .561 0 r
F
.039 .916 .04 r
.38968 .439 m
.41979 .42938 L
s
.39067 .45333 m .38892 .44176 L .38986 .448 L 0 0 .106 r
F
.23357 .41183 m .24587 .3855 L .24922 .37089 L 0 0 .014 r
F
.23197 .42558 m .24587 .3855 L .23357 .41183 L 0 0 .202 r
F
.50647 .33731 m .5068 .32073 L .51099 .33748 L .969 .687 .442 r
F
.50647 .33731 m .50135 .32046 L .5068 .32073 L F
.36446 .45887 m .35596 .45598 L .35469 .44734 L .958 .688 .48 r
F
.36585 .46548 m .35596 .45598 L .36446 .45887 L F
.69835 .33764 m .7025 .33318 L .70167 .34454 L .922 .567 .125 r
F
.69835 .33764 m .69758 .32291 L .7025 .33318 L F
.54529 .3411 m .53533 .32875 L .54926 .34243 L .747 .226 0 r
F
.54529 .3411 m .53033 .32704 L .53533 .32875 L F
.72621 .43246 m .73273 .45392 L .73216 .46533 L .96 .721 .273 r
F
.72598 .42296 m .73273 .45392 L .72621 .43246 L .941 .692 .221 r
F
.52623 .48609 m .52303 .50315 L .5235 .48733 L .993 .835 .579 r
F
.52485 .47095 m .52623 .48609 L .5235 .48733 L .992 .803 .55 r
F
.5321 .4217 m .53855 .42038 L .53916 .42259 L .969 .687 .442 r
F
.5321 .4217 m .53782 .4182 L .53855 .42038 L F
.43538 .46681 m .42999 .47022 L .43373 .4637 L .962 .688 .467 r
F
.43538 .46681 m .43248 .47489 L .42999 .47022 L F
.5321 .4217 m .53701 .41608 L .53782 .4182 L .969 .687 .442 r
F
.34569 .41324 m .33857 .3927 L .34719 .40535 L .958 .688 .48 r
F
.42838 .38012 m .43 .37363 L .43121 .37649 L .964 .688 .462 r
F
0 g
.43121 .37649 m
.43452 .37407 L
s
.48593 .37376 m .47966 .3601 L .48876 .37281 L .894 .507 .289 r
F
.48593 .37376 m .47609 .36126 L .47966 .3601 L F
.41626 .50577 m .42009 .50974 L .41249 .50154 L 0 0 .497 r
F
.41626 .50577 m .42481 .51503 L .42009 .50974 L F
.48962 .48169 m .48981 .49536 L .48709 .48114 L .965 .687 .457 r
F
.48962 .48169 m .49317 .49607 L .48981 .49536 L F
.65829 .40896 m .66098 .42161 L .66158 .42966 L .824 .61 .057 r
F
.65754 .40324 m .66098 .42161 L .65829 .40896 L .778 .55 0 r
F
.5321 .4217 m .53916 .42259 L .53965 .42478 L .969 .687 .442 r
F
.57322 .37579 m .56997 .36519 L .57542 .37811 L .874 .448 .032 r
F
.57322 .37579 m .56668 .36171 L .56997 .36519 L F
.51432 .42739 m .52065 .43819 L .52037 .43936 L .975 .701 .445 r
F
.69312 .45107 m .70536 .47349 L .70377 .48347 L .981 .695 .397 r
F
.69367 .44253 m .70536 .47349 L .69312 .45107 L .98 .693 .391 r
F
.5321 .4217 m .5361 .41405 L .53701 .41608 L .969 .687 .442 r
F
.47987 .45169 m .47887 .46294 L .47893 .45079 L .965 .687 .457 r
F
.47987 .45169 m .48075 .46474 L .47887 .46294 L F
.66112 .44375 m .65999 .4647 L .65859 .47248 L .826 .733 .208 r
F
.66162 .43708 m .65999 .4647 L .66112 .44375 L .732 .635 .072 r
F
.32836 .45589 m .33025 .44727 L .32947 .43691 L 0 0 .253 r
F
.3296 .46451 m .33025 .44727 L .32836 .45589 L 0 0 .356 r
F
.25312 .55066 m .25533 .54225 L .24713 .5382 L 0 .066 .63 r
F
.25312 .55066 m .26289 .55799 L .25533 .54225 L F
.42732 .44248 m .42033 .43826 L .41987 .43316 L .962 .688 .467 r
F
.42787 .44602 m .42033 .43826 L .42732 .44248 L F
.42705 .3774 m .4288 .37077 L .43 .37363 L .964 .688 .462 r
F
.42838 .38012 m .42705 .3774 L .43 .37363 L F
.5321 .4217 m .53965 .42478 L .54001 .42692 L .969 .687 .442 r
F
.39951 .47999 m .39875 .47792 L .3972 .47498 L 0 0 .324 r
F
.39951 .47999 m .40186 .48463 L .39875 .47792 L F
.37235 .48504 m .36314 .48253 L .36983 .47868 L .958 .688 .48 r
F
.37235 .48504 m .36652 .49106 L .36314 .48253 L F
.39306 .39852 m .39868 .38285 L .40142 .37737 L .769 .84 .382 r
F
.39133 .40413 m .39868 .38285 L .39306 .39852 L 0 0 0 r
F
.68023 .40958 m .69352 .43305 L .68077 .41645 L .978 .687 .388 r
F
.68077 .41645 m .69352 .43305 L .69367 .44253 L .979 .689 .391 r
F
.51432 .42739 m .51195 .4139 L .51285 .4146 L .966 .67 .417 r
F
.5321 .4217 m .53513 .41215 L .5361 .41405 L .969 .687 .442 r
F
.38328 .51952 m .37602 .52532 L .37876 .51352 L .958 .688 .48 r
F
.38328 .51952 m .38171 .53282 L .37602 .52532 L F
.47206 .4281 m .46509 .41743 L .46572 .41511 L .965 .687 .457 r
F
.47186 .42945 m .46509 .41743 L .47206 .4281 L F
.53976 .43564 m .54739 .4495 L .54649 .45179 L .969 .687 .442 r
F
.54009 .43426 m .54739 .4495 L .53976 .43564 L F
.56032 .35717 m .55344 .34492 L .56344 .35902 L .818 .34 0 r
F
.56032 .35717 m .54926 .34243 L .55344 .34492 L F
.4138 .40973 m .40856 .39374 L .41513 .40525 L .962 .688 .467 r
F
.58554 .40537 m .58896 .40505 L .59024 .40965 L .949 .634 .201 r
F
.58478 .40308 m .58896 .40505 L .58554 .40537 L .944 .619 .186 r
F
.58478 .40308 m .58745 .40049 L .58896 .40505 L F
.36585 .46548 m .35781 .46483 L .35596 .45598 L .958 .688 .48 r
F
.36765 .47212 m .35781 .46483 L .36585 .46548 L F
.48438 .46696 m .48442 .47985 L .4826 .46608 L .965 .687 .457 r
F
.48438 .46696 m .48709 .48114 L .48442 .47985 L F
.42572 .37468 m .42759 .36791 L .4288 .37077 L .964 .688 .462 r
F
.42705 .3774 m .42572 .37468 L .4288 .37077 L F
.58393 .40085 m .58745 .40049 L .58478 .40308 L .94 .605 .176 r
F
.58393 .40085 m .58576 .39606 L .58745 .40049 L F
.39067 .45333 m .39 .4489 L .38892 .44176 L 0 0 .106 r
F
.39183 .45879 m .39 .4489 L .39067 .45333 L 0 0 .182 r
F
.33026 .41834 m .33673 .40216 L .33857 .3927 L 0 0 .016 r
F
.32947 .42721 m .33673 .40216 L .33026 .41834 L 0 0 .196 r
F
.43373 .4637 m .42769 .46521 L .43221 .46037 L .962 .688 .467 r
F
.43373 .4637 m .42999 .47022 L .42769 .46521 L F
.50588 .31406 m .54065 .26652 L .51154 .31437 L .913 .956 .806 r
F
.52567 .32683 m .51154 .31437 L .53033 .32704 L .676 .13 0 r
F
.52567 .32683 m .50588 .31406 L .51154 .31437 L F
0 g
.51154 .31437 m
.51761 .31647 L
s
.5012 .31995 m
.50667 .32022 L
s
.5321 .4217 m .54001 .42692 L .54024 .42897 L .969 .687 .442 r
F
.52358 .45506 m .52485 .47095 L .52238 .45612 L .992 .771 .502 r
F
.51946 .44108 m .52358 .45506 L .52238 .45612 L .984 .737 .48 r
F
.51997 .44033 m .52358 .45506 L .51946 .44108 L .986 .736 .467 r
F
.19155 .45445 m .177 .43909 L .17765 .42032 L .982 .726 .465 r
F
.19237 .47043 m .177 .43909 L .19155 .45445 L .982 .718 .449 r
F
.58619 .40769 m .59024 .40965 L .59129 .41422 L .955 .651 .222 r
F
.58554 .40537 m .59024 .40965 L .58619 .40769 L .949 .634 .201 r
F
.52363 .38792 m .52231 .37196 L .52556 .38848 L .969 .687 .442 r
F
.52363 .38792 m .51941 .37107 L .52231 .37196 L F
.36983 .47868 m .36022 .47374 L .36765 .47212 L .958 .688 .48 r
F
.36983 .47868 m .36314 .48253 L .36022 .47374 L F
.5321 .4217 m .53411 .41041 L .53513 .41215 L .969 .687 .442 r
F
.51432 .42739 m .52037 .43936 L .51997 .44033 L .975 .702 .449 r
F
.42787 .44602 m .42116 .44358 L .42033 .43826 L .962 .688 .467 r
F
.42865 .44964 m .42116 .44358 L .42787 .44602 L F
.47893 .45079 m .47699 .46073 L .47799 .44968 L .965 .687 .457 r
F
.47893 .45079 m .47887 .46294 L .47699 .46073 L F
.36765 .47212 m .36022 .47374 L .35781 .46483 L .958 .688 .48 r
F
.55851 .4853 m .56169 .50439 L .55579 .48789 L .969 .687 .442 r
F
.55193 .46946 m .55851 .4853 L .55579 .48789 L F
.42439 .37196 m .42638 .36504 L .42759 .36791 L .964 .688 .462 r
F
.42572 .37468 m .42439 .37196 L .42759 .36791 L F
.58299 .39871 m .58576 .39606 L .58393 .40085 L .938 .594 .171 r
F
.58299 .39871 m .58389 .39181 L .58576 .39606 L F
.44063 .48607 m .43673 .49372 L .43784 .48289 L .962 .688 .467 r
F
.44063 .48607 m .44046 .49796 L .43673 .49372 L F
.63832 .35254 m .63547 .34418 L .64115 .35695 L .753 .333 0 r
F
.63832 .35254 m .63125 .33759 L .63547 .34418 L F
.38868 .42264 m .39019 .41066 L .39133 .40413 L .751 .699 .159 r
F
.38826 .42851 m .39019 .41066 L .38868 .42264 L 0 0 0 r
F
.46035 .40038 m .45628 .38464 L .46197 .3982 L .965 .687 .457 r
F
.46658 .4132 m .46035 .40038 L .46197 .3982 L F
.23089 .48396 m .2348 .47368 L .23258 .45679 L 0 0 .36 r
F
.23362 .49767 m .2348 .47368 L .23089 .48396 L 0 0 .447 r
F
.3972 .47498 m .39597 .47086 L .39512 .46971 L 0 0 .314 r
F
.3972 .47498 m .39875 .47792 L .39597 .47086 L F
.51159 .35418 m .51099 .33748 L .5152 .35426 L .969 .687 .442 r
F
.51159 .35418 m .50647 .33731 L .51099 .33748 L F
.47186 .42945 m .46469 .42012 L .46509 .41743 L .965 .687 .457 r
F
.47179 .43095 m .46469 .42012 L .47186 .42945 L F
.71581 .39071 m .7235 .40175 L .72507 .41267 L .953 .665 .223 r
F
.71434 .38307 m .7235 .40175 L .71581 .39071 L .944 .647 .195 r
F
.43221 .46037 m .42562 .45995 L .43084 .45688 L .962 .688 .467 r
F
.43221 .46037 m .42769 .46521 L .42562 .45995 L F
.49317 .49607 m .49253 .50963 L .48981 .49536 L .965 .687 .457 r
F
.49317 .49607 m .49673 .51046 L .49253 .50963 L F
.34389 .50751 m .34504 .50209 L .34011 .49945 L 0 .043 .612 r
F
.34389 .50751 m .34979 .51224 L .34504 .50209 L F
.5321 .4217 m .54024 .42897 L .54033 .4309 L .969 .687 .442 r
F
.51432 .42739 m .51107 .41343 L .51195 .4139 L .965 .669 .42 r
F
.46572 .41511 m .46035 .40038 L .46658 .4132 L .965 .687 .457 r
F
.52883 .40507 m .5276 .38962 L .52984 .40562 L .969 .687 .442 r
F
.52883 .40507 m .52556 .38848 L .5276 .38962 L F
.42306 .36923 m .42517 .36218 L .42638 .36504 L .964 .688 .462 r
F
.42439 .37196 m .42306 .36923 L .42638 .36504 L F
.39183 .45879 m .39155 .45622 L .39 .4489 L 0 0 .182 r
F
.39332 .46429 m .39155 .45622 L .39183 .45879 L 0 0 .243 r
F
.42865 .44964 m .42233 .44903 L .42116 .44358 L .962 .688 .467 r
F
.42965 .45328 m .42233 .44903 L .42865 .44964 L F
.49462 .38666 m .48876 .37281 L .49673 .38591 L .915 .552 .328 r
F
.49462 .38666 m .48593 .37376 L .48876 .37281 L F
.58671 .40999 m .59129 .41422 L .59207 .41868 L .962 .669 .247 r
F
.58619 .40769 m .59129 .41422 L .58671 .40999 L .955 .651 .222 r
F
.52485 .47095 m .5235 .48733 L .5228 .47185 L .992 .803 .55 r
F
.52238 .45612 m .52485 .47095 L .5228 .47185 L .988 .771 .522 r
F
.39868 .38285 m .4045 .37634 L .40142 .37737 L .351 0 .163 r
F
0 g
.40142 .37737 m
.40478 .37321 L
s
.50947 .41323 m .50516 .39937 L .51024 .41321 L .951 .631 .386 r
F
.50947 .41323 m .50362 .3994 L .50516 .39937 L F
.5321 .4217 m .53305 .40887 L .53411 .41041 L .969 .687 .442 r
F
.43084 .45688 m .42382 .45452 L .42965 .45328 L .962 .688 .467 r
F
.43084 .45688 m .42562 .45995 L .42382 .45452 L F
.19969 .57742 m .1903 .57091 L .19215 .56197 L .893 .521 .057 r
F
.19969 .57742 m .19984 .59044 L .1903 .57091 L F
.42965 .45328 m .42382 .45452 L .42233 .44903 L .962 .688 .467 r
F
.39512 .46971 m .39356 .46358 L .39332 .46429 L 0 0 .287 r
F
.39512 .46971 m .39597 .47086 L .39356 .46358 L F
.35399 .43132 m .34494 .42212 L .34569 .41324 L .958 .688 .48 r
F
.35403 .43907 m .34494 .42212 L .35399 .43132 L F
.47799 .44968 m .47513 .45813 L .47707 .44838 L .965 .687 .457 r
F
.47799 .44968 m .47699 .46073 L .47513 .45813 L F
.39332 .46429 m .39356 .46358 L .39155 .45622 L 0 0 .243 r
F
.42173 .36651 m .42396 .35931 L .42517 .36218 L .964 .688 .462 r
F
.42306 .36923 m .42173 .36651 L .42517 .36218 L F
.58199 .39672 m .58389 .39181 L .58299 .39871 L .938 .585 .173 r
F
.58199 .39672 m .58189 .38783 L .58389 .39181 L F
.51432 .42739 m .51997 .44033 L .51946 .44108 L .974 .703 .454 r
F
0 g
.51872 .51963 m
.5213 .51935 L
s
.33142 .47333 m .3318 .4581 L .3296 .46451 L 0 0 .439 r
F
.3296 .46451 m .3318 .4581 L .33025 .44727 L 0 0 .356 r
F
.42005 .424 m .41293 .41494 L .4138 .40973 L .962 .688 .467 r
F
.41977 .42838 m .41293 .41494 L .42005 .424 L F
.59244 .43403 m .5954 .44871 L .59448 .45305 L .978 .778 .361 r
F
.59278 .4307 m .5954 .44871 L .59244 .43403 L .958 .748 .296 r
F
.039 .916 .04 r
.55123 .44306 m
.59279 .42949 L
s
.47179 .43095 m .46454 .42314 L .46469 .42012 L .965 .687 .457 r
F
.47184 .4326 m .46454 .42314 L .47179 .43095 L F
.65115 .33264 m .65485 .31558 L .65478 .33754 L .973 .67 .375 r
F
.65115 .33264 m .64945 .30821 L .65485 .31558 L F
.5321 .4217 m .54033 .4309 L .54028 .43267 L .969 .687 .442 r
F
.42173 .36651 m .42039 .36378 L .42396 .35931 L .964 .688 .462 r
F
0 g
.42396 .35931 m
.42813 .35634 L
s
.1799 .40323 m .16686 .37985 L .17154 .36176 L .986 .75 .493 r
F
.17765 .42032 m .16686 .37985 L .1799 .40323 L .988 .743 .472 r
F
.40856 .39374 m .40197 .38217 L .40468 .37672 L .962 .688 .467 r
F
.51432 .42739 m .51024 .41321 L .51107 .41343 L .964 .669 .424 r
F
.39868 .38285 m .40177 .38182 L .4045 .37634 L .351 0 .163 r
F
0 g
.4045 .37634 m
.40784 .37218 L
s
.6185 .32341 m .60904 .31013 L .62269 .32711 L .685 .183 0 r
F
.6185 .32341 m .60344 .30516 L .60904 .31013 L F
.24713 .5382 m .24863 .52563 L .24182 .52505 L 0 .04 .605 r
F
.24713 .5382 m .25533 .54225 L .24863 .52563 L F
.5321 .4217 m .53197 .40754 L .53305 .40887 L .969 .687 .442 r
F
.67651 .29127 m .67398 .27531 L .68182 .29748 L .895 .492 .072 r
F
.67651 .29127 m .66691 .26699 L .67398 .27531 L F
.58711 .41223 m .59207 .41868 L .59259 .42297 L .97 .688 .275 r
F
.58671 .40999 m .59207 .41868 L .58711 .41223 L .962 .669 .247 r
F
.47707 .44838 m .47334 .45519 L .47618 .44691 L .965 .687 .457 r
F
.47707 .44838 m .47513 .45813 L .47334 .45519 L F
.6949 .33129 m .69758 .32291 L .69835 .33764 L .924 .563 .132 r
F
.6949 .33129 m .69244 .31344 L .69758 .32291 L F
.44952 .51728 m .44572 .52701 L .44495 .51416 L .962 .688 .467 r
F
.44952 .51728 m .45122 .53073 L .44572 .52701 L F
.4826 .46608 m .48164 .47785 L .48075 .46474 L .965 .687 .457 r
F
.4826 .46608 m .48442 .47985 L .48164 .47785 L F
.47184 .4326 m .46464 .42643 L .46454 .42314 L F
.47202 .43434 m .46464 .42643 L .47184 .4326 L F
.49673 .51046 m .49527 .52393 L .49253 .50963 L F
.49673 .51046 m .5003 .52489 L .49527 .52393 L F
.50222 .39991 m .49673 .38591 L .50362 .3994 L .934 .594 .365 r
F
.50222 .39991 m .49462 .38666 L .49673 .38591 L F
.34011 .49945 m .34079 .4914 L .33673 .49096 L 0 .019 .59 r
F
.34011 .49945 m .34504 .50209 L .34079 .4914 L F
.44418 .50137 m .44029 .50991 L .44046 .49796 L .962 .688 .467 r
F
.44418 .50137 m .44495 .51416 L .44029 .50991 L F
.54649 .45179 m .55193 .46946 L .54534 .45358 L .969 .687 .442 r
F
.53931 .43678 m .54649 .45179 L .54534 .45358 L F
.53976 .43564 m .54649 .45179 L .53931 .43678 L F
.172 .49448 m .16481 .48551 L .16223 .46446 L .944 .681 .217 r
F
.17532 .51156 m .16481 .48551 L .172 .49448 L .927 .641 .163 r
F
.58093 .39488 m .58189 .38783 L .58199 .39672 L .938 .579 .179 r
F
.58093 .39488 m .57979 .38418 L .58189 .38783 L F
.52238 .45612 m .5228 .47185 L .521 .45671 L .988 .771 .522 r
F
.51886 .44161 m .52238 .45612 L .521 .45671 L .981 .738 .492 r
F
.51946 .44108 m .52238 .45612 L .51886 .44161 L .984 .737 .48 r
F
.51671 .37105 m .5152 .35426 L .51941 .37107 L .969 .687 .442 r
F
.51671 .37105 m .51159 .35418 L .5152 .35426 L F
.63878 .29724 m .64032 .27594 L .64406 .30206 L .971 .663 .368 r
F
.63878 .29724 m .63329 .26942 L .64032 .27594 L F
.4541 .38752 m .45057 .37105 L .45628 .38464 L .965 .687 .457 r
F
.46035 .40038 m .4541 .38752 L .45628 .38464 L F
.41249 .50154 m .41546 .50348 L .40878 .49654 L 0 .022 .568 r
F
.41249 .50154 m .42009 .50974 L .41546 .50348 L F
.5321 .4217 m .54028 .43267 L .54009 .43426 L .969 .687 .442 r
F
.3875 .53915 m .38012 .54624 L .38171 .53282 L .958 .688 .48 r
F
.3875 .53915 m .3871 .55382 L .38012 .54624 L F
.51432 .42739 m .51946 .44108 L .51886 .44161 L .973 .704 .458 r
F
.23362 .49767 m .23826 .49101 L .2348 .47368 L 0 0 .447 r
F
.23729 .51146 m .23826 .49101 L .23362 .49767 L 0 0 .514 r
F
.47618 .44691 m .47165 .45196 L .47533 .4453 L .965 .687 .457 r
F
.47618 .44691 m .47334 .45519 L .47165 .45196 L F
.42952 .51927 m .44264 .52836 L .43699 .52327 L 0 .227 .7 r
F
.39408 .55983 m .43699 .52327 L .3871 .55382 L .758 .805 .89 r
F
.39408 .55983 m .44264 .52836 L .43699 .52327 L F
0 g
.39408 .55983 m
.40092 .5642 L
s
.33562 .63051 m .39407 .55984 L .3871 .55382 L .846 .804 .81 r
F
0 g
.39407 .55984 m
.40092 .56421 L
s
.48709 .48114 m .48624 .49368 L .48442 .47985 L .965 .687 .457 r
F
.48709 .48114 m .48981 .49536 L .48624 .49368 L F
.65829 .40896 m .66158 .42966 L .65869 .41435 L .824 .61 .057 r
F
.65869 .41435 m .66158 .42966 L .66162 .43708 L .87 .669 .14 r
F
.039 .916 .04 r
.66113 .42726 m
.66137 .42721 L
s
.59644 .44167 m
.66038 .42743 L
s
.64604 .51137 m .6311 .54058 L .62584 .54634 L .805 .929 .554 r
F
.64955 .50486 m .6311 .54058 L .64604 .51137 L .65 .796 .347 r
F
0 g
.6311 .54058 m
.63538 .53265 L
s
.42952 .51927 m .43699 .52327 L .42481 .51503 L 0 .227 .7 r
F
.16006 .3822 m .17154 .36176 L .16478 .36411 L .466 .179 .392 r
F
0 g
.16478 .36411 m
.17124 .34879 L
s
.47355 .51645 m .46937 .51731 L .46899 .51438 L .964 .688 .462 r
F
.47355 .51645 m .47412 .51945 L .46937 .51731 L F
0 g
.47355 .51645 m
.47785 .51727 L
s
.55193 .46946 m .55579 .48789 L .54987 .47137 L .969 .687 .442 r
F
.54534 .45358 m .55193 .46946 L .54987 .47137 L F
.33142 .47333 m .33411 .4692 L .3318 .4581 L 0 0 .439 r
F
.33382 .4822 m .33411 .4692 L .33142 .47333 L 0 0 .503 r
F
.47202 .43434 m .46498 .42994 L .46464 .42643 L .965 .687 .457 r
F
.039 .916 .04 r
.44985 .43398 m
.46491 .42919 L
s
.47231 .43617 m .46498 .42994 L .47202 .43434 L .965 .687 .457 r
F
.5235 .48733 m .52303 .50315 L .51922 .50353 L .985 .827 .606 r
F
.57107 .37401 m .56668 .36171 L .57322 .37579 L .888 .463 .083 r
F
.57107 .37401 m .56344 .35902 L .56668 .36171 L F
.23307 .63859 m .22933 .64416 L .22144 .62459 L .826 .38 0 r
F
.23307 .63859 m .24339 .66102 L .22933 .64416 L F
.6265 .26476 m .62756 .24193 L .63329 .26942 L .969 .657 .363 r
F
.6265 .26476 m .61907 .23597 L .62756 .24193 L F
.5321 .4217 m .5309 .40645 L .53197 .40754 L .969 .687 .442 r
F
.43784 .48289 m .43308 .48872 L .43511 .47914 L .962 .688 .467 r
F
.43784 .48289 m .43673 .49372 L .43308 .48872 L F
.72279 .54578 m .72798 .55316 L .71795 .55609 L .341 0 .108 r
F
.72279 .54578 m .73276 .54286 L .72798 .55316 L F
.71223 .51888 m .72279 .54578 L .71795 .55609 L .984 .707 .41 r
F
0 g
.72279 .54578 m
.72633 .53293 L
s
.46572 .41511 m .45905 .40323 L .46035 .40038 L .965 .687 .457 r
F
.46509 .41743 m .45905 .40323 L .46572 .41511 L F
.51432 .42739 m .50947 .41323 L .51024 .41321 L .963 .669 .427 r
F
.47533 .4453 m .47008 .4485 L .47455 .44358 L .965 .687 .457 r
F
.47533 .4453 m .47165 .45196 L .47008 .4485 L F
.039 .916 .04 r
.59365 .42921 m
.59366 .42921 L
s
.36617 .53765 m .37326 .53724 L .36046 .53018 L 0 .321 .808 r
F
.36617 .53765 m .38012 .54624 L .37326 .53724 L F
.039 .916 .04 r
.42051 .42915 m
.43963 .42311 L
s
.59292 .47468 m .58689 .4983 L .59065 .47849 L .929 .886 .472 r
F
.59316 .45666 m .59292 .47468 L .59065 .47849 L .982 .858 .479 r
F
.59448 .45305 m .59292 .47468 L .59316 .45666 L .955 .828 .394 r
F
.33673 .49096 m .33712 .48037 L .33382 .4822 L 0 0 .553 r
F
.33673 .49096 m .34079 .4914 L .33712 .48037 L F
.47231 .43617 m .46557 .4336 L .46498 .42994 L .965 .687 .457 r
F
.47272 .43804 m .46557 .4336 L .47231 .43617 L F
.24182 .52505 m .2429 .50844 L .23729 .51146 L 0 0 .567 r
F
.24182 .52505 m .24863 .52563 L .2429 .50844 L F
.37876 .51352 m .37055 .51677 L .3744 .50669 L .958 .688 .48 r
F
.37876 .51352 m .37602 .52532 L .37055 .51677 L F
.47412 .51945 m .46975 .52024 L .46937 .51731 L .964 .688 .462 r
F
.47412 .51945 m .47469 .52246 L .46975 .52024 L F
.58689 .4983 m .57506 .5234 L .58344 .50173 L .902 .945 .589 r
F
.59065 .47849 m .58689 .4983 L .58344 .50173 L .966 .916 .573 r
F
.33382 .4822 m .33712 .48037 L .33411 .4692 L 0 0 .503 r
F
.58736 .41438 m .59259 .42297 L .59283 .42699 L .977 .705 .305 r
F
.58711 .41223 m .59259 .42297 L .58736 .41438 L .97 .688 .275 r
F
.65648 .47899 m .64955 .50486 L .64604 .51137 L .854 .867 .421 r
F
.65859 .47248 m .64955 .50486 L .65648 .47899 L .736 .757 .249 r
F
.50878 .41349 m .50362 .3994 L .50947 .41323 L .949 .633 .399 r
F
.50878 .41349 m .50222 .39991 L .50362 .3994 L F
.47455 .44358 m .46867 .44487 L .47385 .44178 L .965 .687 .457 r
F
.47455 .44358 m .47008 .4485 L .46867 .44487 L F
.52786 .40479 m .52556 .38848 L .52883 .40507 L .969 .687 .442 r
F
.52786 .40479 m .52363 .38792 L .52556 .38848 L F
.23729 .51146 m .2429 .50844 L .23826 .49101 L 0 0 .514 r
F
.23049 .58471 m .21572 .58551 L .22225 .57037 L .964 .653 .384 r
F
.23049 .58471 m .22616 .60358 L .21572 .58551 L F
.47272 .43804 m .46639 .43736 L .46557 .4336 L .965 .687 .457 r
F
.47323 .43992 m .46639 .43736 L .47272 .43804 L F
.28908 .59704 m .30224 .59628 L .27993 .58563 L .029 .369 .838 r
F
.28908 .59704 m .31324 .61007 L .30224 .59628 L F
.47385 .44178 m .46743 .44114 L .47323 .43992 L .965 .687 .457 r
F
.47385 .44178 m .46867 .44487 L .46743 .44114 L F
.47323 .43992 m .46743 .44114 L .46639 .43736 L F
.5321 .4217 m .54009 .43426 L .53976 .43564 L .969 .687 .442 r
F
.38826 .42851 m .38966 .41801 L .39019 .41066 L 0 0 0 r
F
.38834 .43492 m .38966 .41801 L .38826 .42851 L 0 0 .145 r
F
.51886 .44161 m .521 .45671 L .51817 .44189 L .981 .738 .492 r
F
.51432 .42739 m .51886 .44161 L .51817 .44189 L .973 .704 .462 r
F
.33562 .63051 m .3871 .55382 L .32444 .62154 L .846 .804 .81 r
F
0 g
.33562 .63051 m
.34658 .63685 L
s
.5235 .48733 m .51922 .50353 L .52045 .48759 L .985 .827 .606 r
F
.5228 .47185 m .5235 .48733 L .52045 .48759 L .985 .798 .572 r
F
.5003 .52489 m .51174 .51888 L .49527 .52393 L .511 .891 .963 r
F
.5003 .52489 m .51672 .51986 L .51174 .51888 L F
0 g
.5003 .52489 m
.50493 .52436 L
s
.41977 .42838 m .41255 .42079 L .41293 .41494 L .962 .688 .467 r
F
.41987 .43316 m .41255 .42079 L .41977 .42838 L F
.4138 .40973 m .40688 .39932 L .40856 .39374 L F
.41293 .41494 m .40688 .39932 L .4138 .40973 L F
.47469 .52246 m .47013 .52318 L .46975 .52024 L .964 .688 .462 r
F
.47469 .52246 m .47526 .52548 L .47013 .52318 L F
.45905 .40323 m .4541 .38752 L .46035 .40038 L .965 .687 .457 r
F
.57984 .39325 m .57979 .38418 L .58093 .39488 L .939 .576 .191 r
F
.57984 .39325 m .57762 .38092 L .57979 .38418 L F
.56169 .50439 m .56759 .52087 L .56293 .52323 L .969 .687 .442 r
F
0 g
.56308 .52374 m
.56777 .52137 L
s
.40688 .39932 m .40197 .38217 L .40856 .39374 L .962 .688 .467 r
F
.73459 .5025 m .73276 .54286 L .73167 .51309 L .947 .791 .335 r
F
.73069 .47532 m .73459 .5025 L .73167 .51309 L .974 .782 .357 r
F
.73216 .46533 m .73459 .5025 L .73069 .47532 L .95 .751 .289 r
F
.5321 .4217 m .52984 .40562 L .5309 .40645 L .969 .687 .442 r
F
.63546 .34872 m .63125 .33759 L .63832 .35254 L .787 .351 0 r
F
.63546 .34872 m .62696 .33187 L .63125 .33759 L F
.19215 .56197 m .18187 .55024 L .1855 .54563 L .895 .542 .064 r
F
.19215 .56197 m .1903 .57091 L .18187 .55024 L F
.51432 .42739 m .50878 .41349 L .50947 .41323 L .962 .669 .431 r
F
.48075 .46474 m .47881 .47517 L .47887 .46294 L .965 .687 .457 r
F
.48075 .46474 m .48164 .47785 L .47881 .47517 L F
.71685 .39804 m .72507 .41267 L .72598 .42296 L .962 .684 .253 r
F
.71581 .39071 m .72507 .41267 L .71685 .39804 L .953 .665 .223 r
F
.52184 .38792 m .51941 .37107 L .52363 .38792 L .969 .687 .442 r
F
.52184 .38792 m .51671 .37105 L .51941 .37107 L F
.47526 .52548 m .47051 .52611 L .47013 .52318 L .964 .688 .462 r
F
.47526 .52548 m .47583 .52849 L .47051 .52611 L F
.35403 .43907 m .34497 .43183 L .34494 .42212 L .958 .688 .48 r
F
.35469 .44734 m .34497 .43183 L .35403 .43907 L F
.5228 .47185 m .52045 .48759 L .52051 .47202 L .985 .798 .572 r
F
.521 .45671 m .5228 .47185 L .52051 .47202 L .983 .768 .538 r
F
.44783 .37462 m .44485 .35743 L .45057 .37105 L .965 .687 .457 r
F
.4541 .38752 m .44783 .37462 L .45057 .37105 L F
.39133 .40413 m .39661 .38956 L .39868 .38285 L 0 0 0 r
F
.39019 .41066 m .39661 .38956 L .39133 .40413 L 0 0 .031 r
F
.34569 .41324 m .33673 .40216 L .33857 .3927 L .958 .688 .48 r
F
.34494 .42212 m .33673 .40216 L .34569 .41324 L F
.51432 .42739 m .50817 .414 L .50878 .41349 L .961 .67 .436 r
F
.51432 .42739 m .50766 .41474 L .50817 .414 L .96 .671 .44 r
F
.51432 .42739 m .50725 .4157 L .50766 .41474 L .96 .672 .444 r
F
.51432 .42739 m .50695 .41686 L .50725 .4157 L .959 .673 .449 r
F
.51432 .42739 m .50677 .41821 L .50695 .41686 L .959 .674 .453 r
F
.51432 .42739 m .50672 .41972 L .50677 .41821 L .959 .676 .457 r
F
.51432 .42739 m .50678 .42137 L .50672 .41972 L .958 .678 .461 r
F
.51432 .42739 m .50697 .42312 L .50678 .42137 L .959 .68 .465 r
F
.51432 .42739 m .50727 .42495 L .50697 .42312 L .959 .682 .468 r
F
.51432 .42739 m .50769 .42683 L .50727 .42495 L .959 .684 .471 r
F
.51432 .42739 m .50821 .42872 L .50769 .42683 L .959 .686 .473 r
F
.51432 .42739 m .50883 .43059 L .50821 .42872 L .96 .688 .476 r
F
.039 .916 .04 r
.47898 .43871 m
.5084 .42929 L
s
.51432 .42739 m .50953 .4324 L .50883 .43059 L .961 .69 .477 r
F
.51432 .42739 m .51031 .43414 L .50953 .4324 L .962 .692 .478 r
F
.51432 .42739 m .51115 .43576 L .51031 .43414 L .963 .695 .479 r
F
.51432 .42739 m .51203 .43723 L .51115 .43576 L .964 .696 .479 r
F
.51432 .42739 m .51294 .43854 L .51203 .43723 L .965 .698 .479 r
F
.51432 .42739 m .51387 .43967 L .51294 .43854 L .966 .7 .478 r
F
.51432 .42739 m .5148 .44058 L .51387 .43967 L .967 .701 .477 r
F
.51432 .42739 m .5157 .44127 L .5148 .44058 L .968 .702 .475 r
F
.51432 .42739 m .51658 .44172 L .5157 .44127 L .97 .703 .472 r
F
.51432 .42739 m .51741 .44193 L .51658 .44172 L .971 .704 .469 r
F
.51432 .42739 m .51817 .44189 L .51741 .44193 L .972 .704 .466 r
F
.16006 .3822 m .16686 .37985 L .17154 .36176 L .466 .179 .392 r
F
0 g
.17154 .36176 m
.17796 .34644 L
s
.68084 .42279 m .69367 .44253 L .69312 .45107 L .979 .69 .395 r
F
.68077 .41645 m .69367 .44253 L .68084 .42279 L .979 .689 .391 r
F
.5321 .4217 m .53976 .43564 L .53931 .43678 L .969 .687 .442 r
F
.521 .45671 m .52051 .47202 L .51948 .4568 L .983 .768 .538 r
F
.51817 .44189 m .521 .45671 L .51948 .4568 L .978 .737 .503 r
F
.32947 .42721 m .3358 .41283 L .33673 .40216 L 0 0 .196 r
F
.32947 .43691 m .3358 .41283 L .32947 .42721 L 0 0 .337 r
F
.039 .916 .04 r
.68358 .42012 m
.68361 .42011 L
s
.44817 .53209 m .44575 .5274 L .44264 .52836 L .634 .829 .975 r
F
.44817 .53209 m .45127 .53114 L .44575 .5274 L F
0 g
.44817 .53209 m
.45349 .53441 L
s
.45127 .53114 m
.45658 .53346 L
s
.42608 .38488 m .42705 .3774 L .42838 .38012 L .964 .688 .462 r
F
0 g
.42838 .38012 m
.43121 .37649 L
s
.51817 .44189 m .51948 .4568 L .51741 .44193 L .978 .737 .503 r
F
.56169 .50439 m .56293 .52323 L .55779 .50629 L .969 .687 .442 r
F
.55579 .48789 m .56169 .50439 L .55779 .50629 L F
.17532 .51156 m .169 .50711 L .16481 .48551 L .927 .641 .163 r
F
.17985 .52872 m .169 .50711 L .17532 .51156 L .912 .604 .119 r
F
.47583 .52849 m .47089 .52906 L .47051 .52611 L .964 .688 .462 r
F
.47583 .52849 m .4764 .53151 L .47089 .52906 L F
.46509 .41743 m .45808 .40671 L .45905 .40323 L .965 .687 .457 r
F
.46469 .42012 m .45808 .40671 L .46509 .41743 L F
.58736 .41438 m .59283 .42699 L .58748 .4164 L .977 .705 .305 r
F
.58748 .4164 m .59283 .42699 L .59278 .4307 L .984 .722 .337 r
F
.54534 .45358 m .54987 .47137 L .54395 .45483 L .969 .687 .442 r
F
.53872 .43766 m .54534 .45358 L .54395 .45483 L F
.53931 .43678 m .54534 .45358 L .53872 .43766 L F
.48343 .37569 m .47609 .36126 L .48593 .37376 L .891 .522 .335 r
F
.48343 .37569 m .47293 .36363 L .47609 .36126 L F
.43511 .47914 m .42955 .48305 L .43248 .47489 L .962 .688 .467 r
F
.43511 .47914 m .43308 .48872 L .42955 .48305 L F
.59183 .43691 m .59448 .45305 L .59316 .45666 L .992 .8 .42 r
F
.59244 .43403 m .59448 .45305 L .59183 .43691 L .978 .778 .361 r
F
.5321 .4217 m .52883 .40507 L .52984 .40562 L .969 .687 .442 r
F
.55736 .35621 m .54926 .34243 L .56032 .35717 L .843 .379 .056 r
F
.55736 .35621 m .54529 .3411 L .54926 .34243 L F
.33857 .3927 m .39661 .38956 L .39868 .38285 L .593 .258 .372 r
F
.33673 .40216 m .39661 .38956 L .33857 .3927 L .616 .324 .45 r
F
0 g
.33857 .39269 m
.34128 .38461 L
s
.33857 .3927 m
.34129 .38461 L
s
.24587 .3855 m .33857 .3927 L .24922 .37089 L .734 .435 .475 r
F
0 g
.24922 .37089 m
.25395 .35847 L
s
.24587 .3855 m .33673 .40216 L .33857 .3927 L .734 .435 .475 r
F
0 g
.33857 .3927 m
.33857 .39269 L
s
.19237 .47043 m .17799 .45922 L .177 .43909 L .982 .718 .449 r
F
.19448 .48713 m .17799 .45922 L .19237 .47043 L .981 .709 .433 r
F
.48981 .49536 m .48808 .50756 L .48624 .49368 L .965 .687 .457 r
F
.48981 .49536 m .49253 .50963 L .48808 .50756 L F
.50817 .414 m .50222 .39991 L .50878 .41349 L .947 .635 .412 r
F
.57506 .5234 m .61966 .54979 L .57022 .52587 L .673 .167 .033 r
F
.57506 .5234 m .62584 .54634 L .61966 .54979 L F
.58344 .50173 m .57506 .5234 L .57022 .52587 L .941 .963 .688 r
F
0 g
.57506 .5234 m
.57922 .5192 L
s
.40878 .49654 m .41099 .49636 L .40522 .49088 L 0 .047 .607 r
F
.40878 .49654 m .41546 .50348 L .41099 .49636 L F
.4764 .53151 m .47127 .532 L .47089 .52906 L .964 .688 .462 r
F
.4764 .53151 m .47697 .53452 L .47127 .532 L F
0 g
.47697 .53452 m
.48233 .53548 L
s
.42465 .38235 m .42572 .37468 L .42705 .3774 L .964 .688 .462 r
F
.42608 .38488 m .42465 .38235 L .42705 .3774 L F
.49276 .38813 m .48593 .37376 L .49462 .38666 L .912 .562 .362 r
F
.49276 .38813 m .48343 .37569 L .48593 .37376 L F
.664 .38081 m .67375 .379 L .67597 .38686 L .976 .681 .387 r
F
.6627 .37688 m .67375 .379 L .664 .38081 L .976 .68 .386 r
F
.6627 .37688 m .67118 .37121 L .67375 .379 L F
.73167 .51309 m .73276 .54286 L .72798 .55316 L .976 .825 .416 r
F
0 g
.73276 .54286 m
.73624 .53001 L
s
.50099 .4009 m .49462 .38666 L .50222 .39991 L .93 .599 .388 r
F
.50817 .414 m .50099 .4009 L .50222 .39991 L .947 .635 .412 r
F
.66125 .37304 m .67118 .37121 L .6627 .37688 L .975 .679 .385 r
F
.66125 .37304 m .66832 .36362 L .67118 .37121 L F
.57874 .39185 m .57762 .38092 L .57984 .39325 L .941 .574 .207 r
F
.57874 .39185 m .57542 .37811 L .57762 .38092 L F
.1855 .54563 m .17472 .52883 L .17985 .52872 L .901 .57 .085 r
F
.1855 .54563 m .18187 .55024 L .17472 .52883 L F
.41987 .43316 m .41267 .42718 L .41255 .42079 L .962 .688 .467 r
F
.42033 .43826 m .41267 .42718 L .41987 .43316 L F
.50099 .4009 m .49276 .38813 L .49462 .38666 L .93 .599 .388 r
F
.69135 .32559 m .69244 .31344 L .6949 .33129 L .927 .561 .145 r
F
.69135 .32559 m .68715 .30492 L .69244 .31344 L F
.55579 .48789 m .55779 .50629 L .55264 .48935 L .969 .687 .442 r
F
.54987 .47137 m .55579 .48789 L .55264 .48935 L F
.48442 .47985 m .48254 .49104 L .48164 .47785 L .965 .687 .457 r
F
.48442 .47985 m .48624 .49368 L .48254 .49104 L F
.66007 .44956 m .65859 .47248 L .65648 .47899 L .902 .811 .337 r
F
.66112 .44375 m .65859 .47248 L .66007 .44956 L .826 .733 .208 r
F
.5416 .34098 m .53033 .32704 L .54529 .3411 L .787 .292 .02 r
F
.5416 .34098 m .52567 .32683 L .53033 .32704 L F
.44046 .49796 m .43562 .50462 L .43673 .49372 L .962 .688 .467 r
F
.44046 .49796 m .44029 .50991 L .43562 .50462 L F
.5321 .4217 m .53931 .43678 L .53872 .43766 L .969 .687 .442 r
F
.51741 .44193 m .51783 .4564 L .51658 .44172 L .975 .736 .512 r
F
.51741 .44193 m .51948 .4568 L .51783 .4564 L F
.17985 .52872 m .17472 .52883 L .169 .50711 L .912 .604 .119 r
F
.52697 .40481 m .52363 .38792 L .52786 .40479 L .969 .687 .442 r
F
.52697 .40481 m .52184 .38792 L .52363 .38792 L F
.47887 .46294 m .47598 .47185 L .47699 .46073 L .965 .687 .457 r
F
.47887 .46294 m .47881 .47517 L .47598 .47185 L F
.66512 .38478 m .67597 .38686 L .67781 .39466 L .976 .682 .388 r
F
.664 .38081 m .67597 .38686 L .66512 .38478 L .976 .681 .387 r
F
.3744 .50669 m .36538 .50732 L .3703 .49916 L .958 .688 .48 r
F
.3744 .50669 m .37055 .51677 L .36538 .50732 L F
.42322 .37982 m .42439 .37196 L .42572 .37468 L .964 .688 .462 r
F
.42465 .38235 m .42322 .37982 L .42572 .37468 L F
.162 .42561 m .15722 .40275 L .16006 .3822 L .957 .784 .336 r
F
.16129 .44436 m .15722 .40275 L .162 .42561 L .924 .732 .244 r
F
.23197 .42558 m .24399 .40206 L .24587 .3855 L 0 0 .202 r
F
.23163 .44066 m .24399 .40206 L .23197 .42558 L 0 0 .347 r
F
.38834 .43492 m .38977 .42605 L .38966 .41801 L 0 0 .145 r
F
.039 .916 .04 r
.3879 .42541 m
.3884 .42524 L
s
.38892 .44176 m .38977 .42605 L .38834 .43492 L 0 0 .267 r
F
.44783 .37462 m .44154 .36167 L .44485 .35743 L .965 .687 .457 r
F
.44154 .36167 m .46116 .35198 L .44485 .35743 L .219 0 0 r
F
0 g
.44485 .35743 m
.44873 .35462 L
s
.65967 .36937 m .66832 .36362 L .66125 .37304 L .975 .678 .385 r
F
.65967 .36937 m .66519 .35634 L .66832 .36362 L F
.50766 .41474 m .50099 .4009 L .50817 .414 L .945 .638 .425 r
F
.5321 .4217 m .52786 .40479 L .52883 .40507 L .969 .687 .442 r
F
.039 .916 .04 r
.3884 .42524 m
.38871 .42515 L
s
.56899 .3728 m .56344 .35902 L .57107 .37401 L .898 .478 .136 r
F
.56899 .3728 m .56032 .35717 L .56344 .35902 L F
.65871 .41931 m .66162 .43708 L .66112 .44375 L .913 .722 .225 r
F
.039 .916 .04 r
.66137 .42721 m
.66151 .42716 L
s
.65869 .41435 m .66162 .43708 L .65871 .41931 L .87 .669 .14 r
F
.039 .916 .04 r
.66151 .42716 m
.68082 .421 L
s
.72577 .44101 m .73216 .46533 L .73069 .47532 L .975 .746 .324 r
F
.72621 .43246 m .73216 .46533 L .72577 .44101 L .96 .721 .273 r
F
.46469 .42012 m .45748 .41074 L .45808 .40671 L .965 .687 .457 r
F
.46454 .42314 m .45748 .41074 L .46469 .42012 L F
.54987 .47137 m .55264 .48935 L .5475 .47243 L .969 .687 .442 r
F
.54395 .45483 m .54987 .47137 L .5475 .47243 L F
.42179 .37729 m .42306 .36923 L .42439 .37196 L .964 .688 .462 r
F
.42322 .37982 m .42179 .37729 L .42439 .37196 L F
.59289 .29972 m .57682 .28431 L .59802 .30167 L .651 .098 0 r
F
.59289 .29972 m .57032 .2818 L .57682 .28431 L F
.43248 .47489 m .42621 .4768 L .42999 .47022 L .962 .688 .467 r
F
.43248 .47489 m .42955 .48305 L .42621 .4768 L F
.64755 .32857 m .64945 .30821 L .65115 .33264 L .973 .669 .376 r
F
.64755 .32857 m .64406 .30206 L .64945 .30821 L F
.44495 .51416 m .44011 .52194 L .44029 .50991 L .962 .688 .467 r
F
.44495 .51416 m .44572 .52701 L .44011 .52194 L F
.58745 .41826 m .59278 .4307 L .59244 .43403 L .989 .736 .369 r
F
.58748 .4164 m .59278 .4307 L .58745 .41826 L .984 .722 .337 r
F
.039 .916 .04 r
.58808 .41746 m
.58812 .41745 L
s
.58803 .41748 m
.58808 .41746 L
s
.45234 .3913 m .44783 .37462 L .4541 .38752 L .965 .687 .457 r
F
.45905 .40323 m .45234 .3913 L .4541 .38752 L F
.50588 .31406 m .53324 .26581 L .54065 .26652 L .913 .956 .806 r
F
.56427 .28129 m .54065 .26652 L .57032 .2818 L .552 0 0 r
F
.56427 .28129 m .53324 .26581 L .54065 .26652 L F
0 g
.54065 .26652 m
.54858 .2696 L
s
.35469 .44734 m .34578 .4422 L .34497 .43183 L .958 .688 .48 r
F
.35596 .45598 m .34578 .4422 L .35469 .44734 L F
.50235 .3386 m .50135 .32046 L .50647 .33731 L .969 .687 .442 r
F
.50235 .3386 m .49639 .32192 L .50135 .32046 L F
.45808 .40671 m .45234 .3913 L .45905 .40323 L .965 .687 .457 r
F
.51948 .4568 m .51803 .47144 L .51783 .4564 L .977 .764 .552 r
F
.51948 .4568 m .52051 .47202 L .51803 .47144 L F
.51658 .44172 m .51607 .45551 L .5157 .44127 L .971 .733 .519 r
F
.51658 .44172 m .51783 .4564 L .51607 .45551 L F
.39661 .38956 m .40177 .38182 L .39868 .38285 L .432 .107 .312 r
F
0 g
.39868 .38285 m
.40142 .37737 L
s
.66604 .38872 m .67781 .39466 L .67923 .40227 L .977 .683 .39 r
F
.66512 .38478 m .67781 .39466 L .66604 .38872 L .976 .682 .388 r
F
.42481 .51503 m .43133 .51691 L .42009 .50974 L 0 .282 .773 r
F
.42481 .51503 m .43699 .52327 L .43133 .51691 L F
.41293 .41494 m .40577 .40583 L .40688 .39932 L .962 .688 .467 r
F
.41255 .42079 m .40577 .40583 L .41293 .41494 L F
.53872 .43766 m .54395 .45483 L .53803 .43827 L .969 .687 .442 r
F
.5321 .4217 m .53872 .43766 L .53803 .43827 L F
.36046 .53018 m .36665 .52695 L .35497 .52165 L .045 .325 .808 r
F
.36046 .53018 m .37326 .53724 L .36665 .52695 L F
.42033 .43826 m .41328 .434 L .41267 .42718 L .962 .688 .467 r
F
.42116 .44358 m .41328 .434 L .42033 .43826 L F
.42035 .37476 m .42173 .36651 L .42306 .36923 L .964 .688 .462 r
F
.42179 .37729 m .42035 .37476 L .42306 .36923 L F
.24886 .63383 m .23627 .64208 L .23728 .61978 L .954 .624 .354 r
F
.24886 .63383 m .2503 .65896 L .23627 .64208 L F
.50831 .35525 m .50647 .33731 L .51159 .35418 L .969 .687 .442 r
F
.50831 .35525 m .50235 .3386 L .50647 .33731 L F
.38171 .53282 m .37326 .53723 L .37602 .52532 L .958 .688 .48 r
F
.38171 .53282 m .38012 .54624 L .37326 .53723 L F
.50766 .41474 m .49995 .40237 L .50099 .4009 L .945 .638 .425 r
F
.50725 .4157 m .49995 .40237 L .50766 .41474 L .943 .641 .438 r
F
.70377 .48347 m .71223 .51888 L .70129 .49186 L .982 .701 .402 r
F
.69189 .45852 m .70377 .48347 L .70129 .49186 L .981 .697 .402 r
F
.69312 .45107 m .70377 .48347 L .69189 .45852 L .981 .695 .397 r
F
.54395 .45483 m .5475 .47243 L .54237 .45551 L .969 .687 .442 r
F
.53803 .43827 m .54395 .45483 L .54237 .45551 L F
.40522 .49088 m .40676 .48852 L .40186 .48463 L 0 .055 .62 r
F
.40522 .49088 m .41099 .49636 L .40676 .48852 L F
.22225 .57037 m .2062 .56592 L .21472 .55485 L .968 .662 .386 r
F
.22225 .57037 m .21572 .58551 L .2062 .56592 L F
.47699 .46073 m .47319 .46795 L .47513 .45813 L .965 .687 .457 r
F
.47699 .46073 m .47598 .47185 L .47319 .46795 L F
.57764 .39069 m .57542 .37811 L .57874 .39185 L .942 .574 .226 r
F
.57764 .39069 m .57322 .37579 L .57542 .37811 L F
.5321 .4217 m .52697 .40481 L .52786 .40479 L .969 .687 .442 r
F
.65799 .36593 m .66519 .35634 L .65967 .36937 L .975 .677 .385 r
F
.65799 .36593 m .66186 .34949 L .66519 .35634 L F
.52051 .47202 m .51714 .48686 L .51803 .47144 L .976 .791 .589 r
F
.52051 .47202 m .52045 .48759 L .51714 .48686 L F
.49253 .50963 m .48992 .5215 L .48808 .50756 L .965 .687 .457 r
F
.49253 .50963 m .49527 .52393 L .48992 .5215 L F
.51427 .37189 m .51159 .35418 L .51671 .37105 L .969 .687 .442 r
F
.51427 .37189 m .50831 .35525 L .51159 .35418 L F
.40688 .39932 m .39991 .38885 L .40197 .38217 L .962 .688 .467 r
F
.49995 .40237 m .49276 .38813 L .50099 .4009 L .927 .605 .41 r
F
.39661 .38956 m .3997 .38854 L .40177 .38182 L .432 .107 .312 r
F
0 g
.40177 .38182 m
.4045 .37634 L
s
.41892 .37223 m .42039 .36378 L .42173 .36651 L .964 .688 .462 r
F
.42035 .37476 m .41892 .37223 L .42173 .36651 L F
.65329 .25568 m .64669 .23539 L .65997 .2604 L .878 .446 .061 r
F
.65329 .25568 m .63829 .22936 L .64669 .23539 L F
.42999 .47022 m .42313 .47009 L .42769 .46521 L .962 .688 .467 r
F
.42999 .47022 m .42621 .4768 L .42313 .47009 L F
.46899 .51438 m .46443 .51389 L .46425 .51109 L .964 .688 .462 r
F
.46899 .51438 m .46937 .51731 L .46443 .51389 L F
0 g
.46899 .51438 m
.47355 .51645 L
s
.5157 .44127 m .51425 .45415 L .5148 .44058 L .967 .729 .525 r
F
.5157 .44127 m .51607 .45551 L .51425 .45415 L F
.63261 .34556 m .62696 .33187 L .63546 .34872 L .819 .374 0 r
F
.63261 .34556 m .62269 .32711 L .62696 .33187 L F
.61099 .23244 m .61139 .20746 L .61907 .23597 L .967 .651 .36 r
F
.61099 .23244 m .60166 .20301 L .61139 .20746 L F
.60166 .20301 m .62123 .20403 L .61139 .20746 L .603 .896 .988 r
F
0 g
.61139 .20746 m
.6216 .21479 L
s
.3703 .49916 m .36063 .49715 L .36652 .49106 L .958 .688 .48 r
F
.3703 .49916 m .36538 .50732 L .36063 .49715 L F
.52022 .38851 m .51671 .37105 L .52184 .38792 L .969 .687 .442 r
F
.52022 .38851 m .51427 .37189 L .51671 .37105 L F
.46454 .42314 m .45724 .41527 L .45748 .41074 L .965 .687 .457 r
F
.46464 .42643 m .45724 .41527 L .46454 .42314 L F
.51672 .51986 m .55782 .52437 L .55207 .52323 L 0 .562 .775 r
F
.52045 .48759 m .51508 .50267 L .51714 .48686 L .974 .816 .625 r
F
.52045 .48759 m .51922 .50353 L .51508 .50267 L F
.38892 .44176 m .3905 .43463 L .38977 .42605 L 0 0 .267 r
F
.39 .4489 m .3905 .43463 L .38892 .44176 L 0 0 .367 r
F
.71685 .39804 m .72598 .42296 L .71745 .40494 L .962 .684 .253 r
F
.71745 .40494 m .72598 .42296 L .72621 .43246 L .971 .702 .285 r
F
.51922 .50353 m .51174 .51888 L .51508 .50267 L .969 .84 .66 r
F
.61446 .32083 m .60344 .30516 L .6185 .32341 L .749 .244 0 r
F
.61446 .32083 m .59802 .30167 L .60344 .30516 L F
.42116 .44358 m .41438 .44112 L .41328 .434 L .962 .688 .467 r
F
.42233 .44903 m .41438 .44112 L .42116 .44358 L F
.50071 .31556 m .53324 .26581 L .50588 .31406 L .908 .983 .76 r
F
.52143 .32813 m .50588 .31406 L .52567 .32683 L .727 .223 .031 r
F
.52143 .32813 m .50071 .31556 L .50588 .31406 L F
0 g
.50588 .31406 m
.51154 .31437 L
s
.49621 .32142 m
.5012 .31995 L
s
.59065 .47849 m .58344 .50173 L .5879 .48118 L .966 .916 .573 r
F
.59146 .45948 m .59065 .47849 L .5879 .48118 L .993 .871 .546 r
F
.59316 .45666 m .59065 .47849 L .59146 .45948 L .982 .858 .479 r
F
.50725 .4157 m .49913 .40428 L .49995 .40237 L .943 .641 .438 r
F
.50695 .41686 m .49913 .40428 L .50725 .4157 L .941 .645 .45 r
F
.53803 .43827 m .54237 .45551 L .53723 .4386 L .969 .687 .442 r
F
.5321 .4217 m .53803 .43827 L .53723 .4386 L F
.41892 .37223 m .41748 .36969 L .42039 .36378 L .964 .688 .462 r
F
0 g
.42039 .36378 m
.42396 .35931 L
s
.40577 .40583 m .39991 .38885 L .40688 .39932 L .962 .688 .467 r
F
.52616 .40512 m .52184 .38792 L .52697 .40481 L .969 .687 .442 r
F
.52616 .40512 m .52022 .38851 L .52184 .38792 L F
.32947 .43691 m .33581 .42451 L .3358 .41283 L 0 0 .337 r
F
.33025 .44727 m .33581 .42451 L .32947 .43691 L 0 0 .444 r
F
.39019 .41066 m .39525 .3974 L .39661 .38956 L 0 0 .031 r
F
.38966 .41801 m .39525 .3974 L .39019 .41066 L 0 0 .205 r
F
.48164 .47785 m .47875 .48748 L .47881 .47517 L .965 .687 .457 r
F
.48164 .47785 m .48254 .49104 L .47875 .48748 L F
.66676 .39256 m .67923 .40227 L .68023 .40958 L .977 .684 .392 r
F
.66604 .38872 m .67923 .40227 L .66676 .39256 L .977 .683 .39 r
F
.46937 .51731 m .46461 .5167 L .46443 .51389 L .964 .688 .462 r
F
.46937 .51731 m .46975 .52024 L .46461 .5167 L F
.35596 .45598 m .34736 .45305 L .34578 .4422 L .958 .688 .48 r
F
.35781 .46483 m .34736 .45305 L .35596 .45598 L F
.59094 .43931 m .59316 .45666 L .59146 .45948 L .999 .814 .471 r
F
.59183 .43691 m .59316 .45666 L .59094 .43931 L .992 .8 .42 r
F
.19448 .48713 m .18062 .48031 L .17799 .45922 L .981 .709 .433 r
F
.19785 .50426 m .18062 .48031 L .19448 .48713 L .979 .7 .42 r
F
.42769 .46521 m .42036 .46304 L .42562 .45995 L .962 .688 .467 r
F
.42769 .46521 m .42313 .47009 L .42036 .46304 L F
.58728 .41992 m .59244 .43403 L .59183 .43691 L .993 .748 .4 r
F
.58745 .41826 m .59244 .43403 L .58728 .41992 L .989 .736 .369 r
F
.5321 .4217 m .52616 .40512 L .52697 .40481 L .969 .687 .442 r
F
.49119 .3903 m .48343 .37569 L .49276 .38813 L .908 .571 .393 r
F
.49995 .40237 m .49119 .3903 L .49276 .38813 L .927 .605 .41 r
F
.47513 .45813 m .47049 .46353 L .47334 .45519 L .965 .687 .457 r
F
.47513 .45813 m .47319 .46795 L .47049 .46353 L F
.34494 .42212 m .3358 .41283 L .33673 .40216 L .958 .688 .48 r
F
.34497 .43183 m .3358 .41283 L .34494 .42212 L F
.3871 .55382 m .43133 .51691 L .38012 .54624 L .748 .762 .864 r
F
.3871 .55382 m .43699 .52327 L .43133 .51691 L F
0 g
.3871 .55382 m
.39408 .55983 L
s
.32444 .62154 m .3871 .55382 L .38012 .54624 L .829 .77 .796 r
F
0 g
.3871 .55382 m
.39407 .55984 L
s
.5148 .44058 m .5124 .45233 L .51387 .43967 L .963 .725 .529 r
F
.5148 .44058 m .51425 .45415 L .5124 .45233 L F
.43673 .49372 m .43102 .49837 L .43308 .48872 L .962 .688 .467 r
F
.43673 .49372 m .43562 .50462 L .43102 .49837 L F
.64968 .38511 m .65326 .38499 L .655 .39115 L .914 .598 .119 r
F
.64867 .38203 m .65326 .38499 L .64968 .38511 L .908 .58 .101 r
F
.64867 .38203 m .65125 .37888 L .65326 .38499 L F
.64753 .37902 m .65125 .37888 L .64867 .38203 L .905 .564 .089 r
F
.64753 .37902 m .649 .37293 L .65125 .37888 L F
.51783 .4564 m .5154 .47014 L .51607 .45551 L .97 .759 .562 r
F
.51783 .4564 m .51803 .47144 L .5154 .47014 L F
.42233 .44903 m .41594 .44842 L .41438 .44112 L .962 .688 .467 r
F
.42382 .45452 m .41594 .44842 L .42233 .44903 L F
.40186 .48463 m .40287 .48008 L .39875 .47792 L 0 .046 .614 r
F
.40186 .48463 m .40676 .48852 L .40287 .48008 L F
.5321 .4217 m .52546 .40571 L .52616 .40512 L .969 .687 .442 r
F
.5321 .4217 m .52486 .40657 L .52546 .40571 L F
.5321 .4217 m .52439 .4077 L .52486 .40657 L F
.5321 .4217 m .52405 .40907 L .52439 .4077 L F
.5321 .4217 m .52385 .41065 L .52405 .40907 L F
.5321 .4217 m .52379 .41243 L .52385 .41065 L F
.5321 .4217 m .52388 .41437 L .52379 .41243 L F
.5321 .4217 m .5241 .41644 L .52388 .41437 L F
.5321 .4217 m .52447 .4186 L .5241 .41644 L F
.5321 .4217 m .52496 .42081 L .52447 .4186 L F
.5321 .4217 m .52558 .42304 L .52496 .42081 L F
.5321 .4217 m .52631 .42525 L .52558 .42304 L F
.039 .916 .04 r
.51432 .42739 m
.5258 .42372 L
s
.5321 .4217 m .52714 .42739 L .52631 .42525 L .969 .687 .442 r
F
.5321 .4217 m .52805 .42944 L .52714 .42739 L F
.5321 .4217 m .52903 .43135 L .52805 .42944 L F
.5321 .4217 m .53007 .4331 L .52903 .43135 L F
.5321 .4217 m .53114 .43465 L .53007 .4331 L F
.5321 .4217 m .53222 .43597 L .53114 .43465 L F
.5321 .4217 m .5333 .43705 L .53222 .43597 L F
.5321 .4217 m .53436 .43786 L .5333 .43705 L F
.5321 .4217 m .53538 .4384 L .53436 .43786 L F
.5321 .4217 m .53634 .43865 L .53538 .4384 L F
.5321 .4217 m .53723 .4386 L .53634 .43865 L F
.48624 .49368 m .48344 .50429 L .48254 .49104 L .965 .687 .457 r
F
.48624 .49368 m .48808 .50756 L .48344 .50429 L F
.50695 .41686 m .49852 .4066 L .49913 .40428 L .941 .645 .45 r
F
.50677 .41821 m .49852 .4066 L .50695 .41686 L .94 .649 .462 r
F
.65056 .38821 m .655 .39115 L .65643 .39727 L .923 .619 .144 r
F
.64968 .38511 m .655 .39115 L .65056 .38821 L .914 .598 .119 r
F
.42562 .45995 m .41795 .45578 L .42382 .45452 L .962 .688 .467 r
F
.42562 .45995 m .42036 .46304 L .41795 .45578 L F
.46464 .42643 m .45738 .42022 L .45724 .41527 L .965 .687 .457 r
F
.039 .916 .04 r
.43963 .42311 m
.4573 .41752 L
s
.46498 .42994 m .45738 .42022 L .46464 .42643 L .965 .687 .457 r
F
.42382 .45452 m .41795 .45578 L .41594 .44842 L .962 .688 .467 r
F
.46975 .52024 m .46479 .5195 L .46461 .5167 L .964 .688 .462 r
F
.46975 .52024 m .47013 .52318 L .46479 .5195 L F
.67131 .28639 m .66691 .26699 L .67651 .29127 L .906 .503 .11 r
F
.67131 .28639 m .65997 .2604 L .66691 .26699 L F
.71223 .51888 m .71795 .55609 L .70811 .52732 L .984 .707 .41 r
F
.70129 .49186 m .71223 .51888 L .70811 .52732 L .982 .703 .409 r
F
.65623 .36276 m .66186 .34949 L .65799 .36593 L .974 .676 .385 r
F
.65623 .36276 m .65837 .34319 L .66186 .34949 L F
.36652 .49106 m .35638 .48643 L .36314 .48253 L .958 .688 .48 r
F
.36652 .49106 m .36063 .49715 L .35638 .48643 L F
.64629 .37615 m .649 .37293 L .64753 .37902 L .905 .552 .085 r
F
.64629 .37615 m .64654 .36723 L .649 .37293 L F
.53723 .4386 m .5406 .45562 L .53634 .43865 L .969 .687 .442 r
F
.53723 .4386 m .54237 .45551 L .5406 .45562 L F
.44561 .37932 m .44154 .36167 L .44783 .37462 L .965 .687 .457 r
F
.45234 .3913 m .44561 .37932 L .44783 .37462 L F
.45808 .40671 m .45104 .39592 L .45234 .3913 L F
.45748 .41074 m .45104 .39592 L .45808 .40671 L F
.57656 .38981 m .57322 .37579 L .57764 .39069 L .942 .576 .248 r
F
.57656 .38981 m .57107 .37401 L .57322 .37579 L F
.39 .4489 m .39186 .4436 L .3905 .43463 L 0 0 .367 r
F
.39155 .45622 m .39186 .4436 L .39 .4489 L 0 0 .446 r
F
.48131 .37857 m .47293 .36363 L .48343 .37569 L .888 .537 .376 r
F
.49119 .3903 m .48131 .37857 L .48343 .37569 L .908 .571 .393 r
F
.51387 .43967 m .51053 .45009 L .51294 .43854 L .96 .721 .532 r
F
.51387 .43967 m .5124 .45233 L .51053 .45009 L F
.27993 .58563 m .29165 .58042 L .27114 .57254 L .1 .368 .832 r
F
.27993 .58563 m .30224 .59628 L .29165 .58042 L F
.49913 .40428 m .49119 .3903 L .49995 .40237 L .924 .611 .431 r
F
.42436 .39071 m .42465 .38235 L .42608 .38488 L .964 .688 .462 r
F
0 g
.42608 .38488 m
.42838 .38012 L
s
.35781 .46483 m .34968 .46418 L .34736 .45305 L .958 .688 .48 r
F
.36022 .47374 m .34968 .46418 L .35781 .46483 L F
.58344 .50173 m .57022 .52587 L .57944 .50371 L .941 .963 .688 r
F
.5879 .48118 m .58344 .50173 L .57944 .50371 L .978 .92 .643 r
F
.68778 .32064 m .68715 .30492 L .69135 .32559 L .931 .561 .161 r
F
.68778 .32064 m .68182 .29748 L .68715 .30492 L F
.68045 .42848 m .69312 .45107 L .69189 .45852 L .979 .692 .399 r
F
.68084 .42279 m .69312 .45107 L .68045 .42848 L .979 .69 .395 r
F
.41255 .42079 m .40528 .41314 L .40577 .40583 L .962 .688 .467 r
F
.41267 .42718 m .40528 .41314 L .41255 .42079 L F
.039 .916 .04 r
.38975 .42481 m
.4083 .41889 L
s
.25771 .67492 m .2503 .65896 L .24339 .66102 L .645 .742 .92 r
F
.25771 .67492 m .2646 .6729 L .2503 .65896 L F
0 g
.25771 .67492 m
.27202 .68567 L
s
.2646 .6729 m
.27887 .68367 L
s
.47334 .45519 m .46793 .45868 L .47165 .45196 L .965 .687 .457 r
F
.47334 .45519 m .47049 .46353 L .46793 .45868 L F
.54237 .45551 m .54486 .47263 L .5406 .45562 L .969 .687 .442 r
F
.54237 .45551 m .5475 .47243 L .54486 .47263 L F
.50677 .41821 m .49816 .40929 L .49852 .4066 L .94 .649 .462 r
F
.50672 .41972 m .49816 .40929 L .50677 .41821 L .939 .654 .473 r
F
.52546 .40571 m .52022 .38851 L .52616 .40512 L .969 .687 .442 r
F
.47013 .52318 m .46497 .52231 L .46479 .5195 L .964 .688 .462 r
F
.47013 .52318 m .47051 .52611 L .46497 .52231 L F
.65128 .3913 m .65643 .39727 L .65754 .40324 L .934 .642 .174 r
F
.65056 .38821 m .65643 .39727 L .65128 .3913 L .923 .619 .144 r
F
.49527 .52393 m .50643 .51642 L .48992 .5215 L .597 .874 .993 r
F
.49527 .52393 m .51174 .51888 L .50643 .51642 L F
0 g
.49527 .52393 m
.5003 .52489 L
s
.56702 .37218 m .56032 .35717 L .56899 .3728 L .904 .494 .189 r
F
.56702 .37218 m .55736 .35621 L .56032 .35717 L F
.21472 .55485 m .19776 .54519 L .20806 .53845 L .971 .671 .39 r
F
.21472 .55485 m .2062 .56592 L .19776 .54519 L F
.36314 .48253 m .35271 .47537 L .36022 .47374 L .958 .688 .48 r
F
.36314 .48253 m .35638 .48643 L .35271 .47537 L F
.48131 .37857 m .47025 .36719 L .47293 .36363 L .888 .537 .376 r
F
.55462 .35615 m .54529 .3411 L .55736 .35621 L .858 .413 .141 r
F
.55462 .35615 m .5416 .34098 L .54529 .3411 L F
.17765 .42032 m .16405 .40041 L .16686 .37985 L .988 .743 .472 r
F
.177 .43909 m .16405 .40041 L .17765 .42032 L .988 .734 .451 r
F
.44264 .52836 m .44011 .52231 L .43699 .52327 L .648 .78 .944 r
F
.44264 .52836 m .44575 .5274 L .44011 .52231 L F
0 g
.44264 .52836 m
.44817 .53209 L
s
.44575 .5274 m
.45127 .53114 L
s
.46498 .42994 m .45789 .4255 L .45738 .42022 L .965 .687 .457 r
F
.46557 .4336 m .45789 .4255 L .46498 .42994 L F
.39875 .47792 m .39937 .47121 L .39597 .47086 L 0 .023 .592 r
F
.39875 .47792 m .40287 .48008 L .39937 .47121 L F
.5475 .47243 m .54913 .48967 L .54486 .47263 L .969 .687 .442 r
F
.5475 .47243 m .55264 .48935 L .54913 .48967 L F
.36022 .47374 m .35271 .47537 L .34968 .46418 L .958 .688 .48 r
F
.35497 .52165 m .36041 .51557 L .34979 .51224 L .093 .314 .791 r
F
.35497 .52165 m .36665 .52695 L .36041 .51557 L F
.60166 .20301 m .61155 .19955 L .62123 .20403 L .603 .896 .988 r
F
.63031 .22578 m .62123 .20403 L .63829 .22936 L .855 .399 .041 r
F
.63031 .22578 m .61155 .19955 L .62123 .20403 L F
0 g
.62123 .20403 m
.63138 .2114 L
s
.039 .916 .04 r
.68361 .42011 m
.68361 .42011 L
s
.44154 .36167 m .4579 .35621 L .46116 .35198 L .219 0 0 r
F
.64497 .37346 m .64654 .36723 L .64629 .37615 L .907 .544 .088 r
F
.64497 .37346 m .64391 .36187 L .64654 .36723 L F
.51294 .43854 m .5087 .44747 L .51203 .43723 L .956 .715 .534 r
F
.51294 .43854 m .51053 .45009 L .5087 .44747 L F
.65837 .42375 m .66112 .44375 L .66007 .44956 L .949 .767 .308 r
F
.65871 .41931 m .66112 .44375 L .65837 .42375 L .913 .722 .225 r
F
.63369 .29384 m .63329 .26942 L .63878 .29724 L .97 .663 .372 r
F
.63369 .29384 m .6265 .26476 L .63329 .26942 L F
.42285 .38842 m .42322 .37982 L .42465 .38235 L .964 .688 .462 r
F
.42436 .39071 m .42285 .38842 L .42465 .38235 L F
.22144 .62459 m .21582 .62464 L .21029 .60845 L .805 .374 0 r
F
.22144 .62459 m .22933 .64416 L .21582 .62464 L F
.39155 .45622 m .39381 .4528 L .39186 .4436 L 0 0 .446 r
F
.39356 .46358 m .39381 .4528 L .39155 .45622 L 0 0 .508 r
F
.45104 .39592 m .44561 .37932 L .45234 .3913 L .965 .687 .457 r
F
.55264 .48935 m .55341 .50674 L .54913 .48967 L .969 .687 .442 r
F
.55264 .48935 m .55779 .50629 L .55341 .50674 L F
.51803 .47144 m .51362 .48515 L .5154 .47014 L .967 .782 .601 r
F
.51803 .47144 m .51714 .48686 L .51362 .48515 L F
.66725 .39624 m .68023 .40958 L .68077 .41645 L .977 .685 .394 r
F
.66676 .39256 m .68023 .40958 L .66725 .39624 L .977 .684 .392 r
F
.50672 .41972 m .49804 .41232 L .49816 .40929 L .939 .654 .473 r
F
.50678 .42137 m .49804 .41232 L .50672 .41972 L .938 .659 .483 r
F
.47051 .52611 m .46515 .52512 L .46497 .52231 L .964 .688 .462 r
F
.47051 .52611 m .47089 .52906 L .46515 .52512 L F
.42009 .50974 m .42577 .50937 L .41546 .50348 L 0 .309 .801 r
F
.42009 .50974 m .43133 .51691 L .42577 .50937 L F
.47165 .45196 m .46557 .45347 L .47008 .4485 L .965 .687 .457 r
F
.47165 .45196 m .46793 .45868 L .46557 .45347 L F
.53634 .43865 m .53868 .45515 L .53538 .4384 L .969 .687 .442 r
F
.53634 .43865 m .5406 .45562 L .53868 .45515 L F
.5188 .38967 m .51427 .37189 L .52022 .38851 L F
.52546 .40571 m .5188 .38967 L .52022 .38851 L F
.44029 .50991 m .43449 .5156 L .43562 .50462 L .962 .688 .467 r
F
.44029 .50991 m .44011 .52194 L .43449 .5156 L F
.19785 .50426 m .18485 .50195 L .18062 .48031 L .979 .7 .42 r
F
.2024 .52148 m .18485 .50195 L .19785 .50426 L .977 .69 .408 r
F
.51607 .45551 m .51266 .46811 L .51425 .45415 L .964 .752 .57 r
F
.51607 .45551 m .5154 .47014 L .51266 .46811 L F
.39597 .47086 m .39633 .46206 L .39356 .46358 L 0 0 .557 r
F
.39597 .47086 m .39937 .47121 L .39633 .46206 L F
.58697 .42136 m .59183 .43691 L .59094 .43931 L .995 .758 .43 r
F
.58728 .41992 m .59183 .43691 L .58697 .42136 L .993 .748 .4 r
F
.039 .916 .04 r
.54173 .43246 m
.58746 .41766 L
s
.33673 .40216 m .39525 .3974 L .39661 .38956 L .616 .324 .45 r
F
.3358 .41283 m .39525 .3974 L .33673 .40216 L .633 .375 .51 r
F
0 g
.33673 .40215 m
.33857 .3927 L
s
.33673 .40216 m
.33857 .3927 L
s
.24399 .40206 m .33673 .40216 L .24587 .3855 L .737 .467 .52 r
F
0 g
.24587 .3855 m
.24922 .37089 L
s
.24399 .40206 m .3358 .41283 L .33673 .40216 L .737 .467 .52 r
F
0 g
.33673 .40216 m
.33673 .40215 L
s
.39356 .46358 m .39633 .46206 L .39381 .4528 L 0 0 .508 r
F
.46557 .4336 m .45877 .43102 L .45789 .4255 L .965 .687 .457 r
F
.46639 .43736 m .45877 .43102 L .46557 .4336 L F
.58004 .40635 m .58554 .40537 L .58619 .40769 L .977 .68 .37 r
F
.58004 .40635 m .58478 .40308 L .58554 .40537 L .976 .676 .366 r
F
.55779 .50629 m .55769 .52385 L .55341 .50674 L .969 .687 .442 r
F
.55779 .50629 m .56293 .52323 L .55769 .52385 L F
.58004 .40635 m .58393 .40085 L .58478 .40308 L .975 .672 .363 r
F
.51203 .43723 m .50692 .44451 L .51115 .43576 L .952 .71 .534 r
F
.51203 .43723 m .5087 .44747 L .50692 .44451 L F
.47881 .47517 m .47496 .48306 L .47598 .47185 L .965 .687 .457 r
F
.47881 .47517 m .47875 .48748 L .47496 .48306 L F
.37602 .52532 m .36665 .52695 L .37055 .51677 L .958 .688 .48 r
F
.37602 .52532 m .37326 .53723 L .36665 .52695 L F
.58004 .40635 m .58619 .40769 L .58671 .40999 L .979 .684 .375 r
F
.52486 .40657 m .5188 .38967 L .52546 .40571 L .969 .687 .442 r
F
.65183 .3943 m .65754 .40324 L .65829 .40896 L .946 .666 .209 r
F
.65128 .3913 m .65754 .40324 L .65183 .3943 L .934 .642 .174 r
F
.58004 .40635 m .58299 .39871 L .58393 .40085 L .974 .668 .361 r
F
.42134 .38613 m .42179 .37729 L .42322 .37982 L .964 .688 .462 r
F
.42285 .38842 m .42134 .38613 L .42322 .37982 L F
.50678 .42137 m .49816 .41562 L .49804 .41232 L .938 .659 .483 r
F
.50697 .42312 m .49816 .41562 L .50678 .42137 L .938 .664 .493 r
F
.47008 .4485 m .46343 .448 L .46867 .44487 L .965 .687 .457 r
F
.47008 .4485 m .46557 .45347 L .46343 .448 L F
.43308 .48872 m .42659 .49127 L .42955 .48305 L .962 .688 .467 r
F
.43308 .48872 m .43102 .49837 L .42659 .49127 L F
.33025 .44727 m .33676 .43701 L .33581 .42451 L 0 0 .444 r
F
.3318 .4581 m .33676 .43701 L .33025 .44727 L .024 .032 .528 r
F
.47089 .52906 m .46533 .52794 L .46515 .52512 L .964 .688 .462 r
F
.47089 .52906 m .47127 .532 L .46533 .52794 L F
0 g
.47127 .532 m
.47697 .53452 L
s
.55782 .52437 m
.56308 .52374 L
s
.58004 .40635 m .58671 .40999 L .58711 .41223 L .98 .689 .381 r
F
.46639 .43736 m .46001 .43667 L .45877 .43102 L .965 .687 .457 r
F
.46743 .44114 m .46001 .43667 L .46639 .43736 L F
.65442 .35993 m .65837 .34319 L .65623 .36276 L .974 .676 .385 r
F
.65442 .35993 m .65478 .33754 L .65837 .34319 L F
.49913 .40428 m .48993 .39315 L .49119 .3903 L .924 .611 .431 r
F
.49852 .4066 m .48993 .39315 L .49913 .40428 L .922 .618 .45 r
F
.58004 .40635 m .58199 .39672 L .58299 .39871 L .972 .665 .36 r
F
.51115 .43576 m .50524 .44126 L .51031 .43414 L .949 .704 .533 r
F
.51115 .43576 m .50692 .44451 L .50524 .44126 L F
.20806 .53845 m .1906 .52373 L .2024 .52148 L .974 .68 .398 r
F
.20806 .53845 m .19776 .54519 L .1906 .52373 L F
.46867 .44487 m .46157 .44237 L .46743 .44114 L .965 .687 .457 r
F
.46867 .44487 m .46343 .448 L .46157 .44237 L F
.51212 .37359 m .50831 .35525 L .51427 .37189 L .969 .687 .442 r
F
.5188 .38967 m .51212 .37359 L .51427 .37189 L F
.64604 .51137 m .62584 .54634 L .64171 .51604 L .805 .929 .554 r
F
.65368 .48412 m .64604 .51137 L .64171 .51604 L .927 .927 .557 r
F
.65648 .47899 m .64604 .51137 L .65368 .48412 L .854 .867 .421 r
F
.46743 .44114 m .46157 .44237 L .46001 .43667 L .965 .687 .457 r
F
.23163 .44066 m .24363 .42028 L .24399 .40206 L 0 0 .347 r
F
.23258 .45679 m .24363 .42028 L .23163 .44066 L .002 0 .456 r
F
.48993 .39315 m .48131 .37857 L .49119 .3903 L .905 .581 .422 r
F
.64358 .37098 m .64391 .36187 L .64497 .37346 L .91 .539 .098 r
F
.64358 .37098 m .64115 .35695 L .64391 .36187 L F
.50697 .42312 m .49853 .41914 L .49816 .41562 L .938 .664 .493 r
F
.039 .916 .04 r
.46896 .4279 m
.49846 .41847 L
s
.5034 .41689 m
.50343 .41688 L
s
.50343 .41688 m
.50351 .41685 L
s
.50351 .41685 m
.50352 .41685 L
s
.50727 .42495 m .49853 .41914 L .50697 .42312 L .939 .669 .502 r
F
0 0 0 r
2 Mabswid
.41018 .41829 Mdot
.57552 .38922 m .57107 .37401 L .57656 .38981 L .942 .579 .272 r
F
.57552 .38922 m .56899 .3728 L .57107 .37401 L F
.2024 .52148 m .1906 .52373 L .18485 .50195 L .977 .69 .408 r
F
.58004 .40635 m .58711 .41223 L .58736 .41438 L .981 .693 .388 r
F
.53538 .4384 m .53664 .4541 L .53436 .43786 L .969 .687 .442 r
F
.53538 .4384 m .53868 .45515 L .53664 .4541 L F
.64402 .3254 m .64406 .30206 L .64755 .32857 L .972 .669 .378 r
F
.64402 .3254 m .63878 .29724 L .64406 .30206 L F
.45748 .41074 m .45021 .4013 L .45104 .39592 L .965 .687 .457 r
F
.45724 .41527 m .45021 .4013 L .45748 .41074 L F
.38966 .41801 m .39463 .40624 L .39525 .3974 L 0 0 .205 r
F
.38977 .42605 m .39463 .40624 L .38966 .41801 L 0 0 .341 r
F
.41983 .38384 m .42035 .37476 L .42179 .37729 L .964 .688 .462 r
F
.42134 .38613 m .41983 .38384 L .42179 .37729 L F
.51031 .43414 m .50367 .43778 L .50953 .4324 L .946 .698 .53 r
F
.51031 .43414 m .50524 .44126 L .50367 .43778 L F
.62982 .34312 m .62269 .32711 L .63261 .34556 L .846 .399 0 r
F
.62982 .34312 m .6185 .32341 L .62269 .32711 L F
.65848 .4544 m .65648 .47899 L .65368 .48412 L .953 .863 .447 r
F
.66007 .44956 m .65648 .47899 L .65848 .4544 L .902 .811 .337 r
F
.51714 .48686 m .51067 .50057 L .51362 .48515 L .962 .803 .638 r
F
.51714 .48686 m .51508 .50267 L .51067 .50057 L F
.58004 .40635 m .58093 .39488 L .58199 .39672 L .971 .662 .361 r
F
.50727 .42495 m .49913 .42281 L .49853 .41914 L .939 .669 .502 r
F
.50769 .42683 m .49913 .42281 L .50727 .42495 L .939 .675 .509 r
F
.39525 .3974 m .3997 .38854 L .39661 .38956 L .485 .207 .416 r
F
0 g
.5 Mabswid
.39661 .38956 m
.39868 .38285 L
s
.41267 .42718 m .40541 .42115 L .40528 .41314 L .962 .688 .467 r
F
.039 .916 .04 r
.41018 .41829 m
.42941 .41223 L
s
.41328 .434 m .40541 .42115 L .41267 .42718 L .962 .688 .467 r
F
.53825 .34206 m .52567 .32683 L .5416 .34098 L .808 .346 .134 r
F
.53825 .34206 m .52143 .32813 L .52567 .32683 L F
.44561 .37932 m .43884 .36728 L .44154 .36167 L .965 .687 .457 r
F
.43884 .36728 m .4579 .35621 L .44154 .36167 L .35 0 .162 r
F
0 g
.44154 .36167 m
.44485 .35743 L
s
.59146 .45948 m .5879 .48118 L .58939 .46146 L .993 .871 .546 r
F
.5898 .44117 m .59146 .45948 L .58939 .46146 L 1 .821 .514 r
F
.59094 .43931 m .59146 .45948 L .5898 .44117 L .999 .814 .471 r
F
.40577 .40583 m .39857 .39665 L .39991 .38885 L .962 .688 .467 r
F
.40528 .41314 m .39857 .39665 L .40577 .40583 L F
.5406 .45562 m .54198 .47195 L .53868 .45515 L .969 .687 .442 r
F
.5406 .45562 m .54486 .47263 L .54198 .47195 L F
.50953 .4324 m .50226 .43413 L .50883 .43059 L .944 .693 .527 r
F
.50953 .4324 m .50367 .43778 L .50226 .43413 L F
.52486 .40657 m .5176 .39138 L .5188 .38967 L .969 .687 .442 r
F
.52439 .4077 m .5176 .39138 L .52486 .40657 L F
.50769 .42683 m .49997 .42658 L .49913 .42281 L .939 .675 .509 r
F
.50821 .42872 m .49997 .42658 L .50769 .42683 L .94 .681 .516 r
F
.34497 .43183 m .33581 .42451 L .3358 .41283 L .958 .688 .48 r
F
.34578 .4422 m .33581 .42451 L .34497 .43183 L F
.48808 .50756 m .48434 .51761 L .48344 .50429 L .965 .687 .457 r
F
.48808 .50756 m .48992 .5215 L .48434 .51761 L F
.50883 .43059 m .50101 .43038 L .50821 .42872 L .942 .687 .522 r
F
.50883 .43059 m .50226 .43413 L .50101 .43038 L F
.46425 .51109 m .45939 .50926 L .45941 .50664 L .964 .688 .462 r
F
.46425 .51109 m .46443 .51389 L .45939 .50926 L F
0 g
.46425 .51109 m
.46899 .51438 L
s
.58004 .40635 m .58736 .41438 L .58748 .4164 L .981 .697 .396 r
F
.50821 .42872 m .50101 .43038 L .49997 .42658 L .94 .681 .516 r
F
.50543 .35748 m .50235 .3386 L .50831 .35525 L .969 .687 .442 r
F
.51212 .37359 m .50543 .35748 L .50831 .35525 L F
.71759 .41129 m .72621 .43246 L .72577 .44101 L .979 .718 .318 r
F
.71745 .40494 m .72621 .43246 L .71759 .41129 L .971 .702 .285 r
F
.039 .916 .04 r
.71937 .409 m
.71954 .40895 L
s
.51425 .45415 m .50986 .4654 L .5124 .45233 L .957 .744 .575 r
F
.51425 .45415 m .51266 .46811 L .50986 .4654 L F
.58004 .40635 m .57984 .39325 L .58093 .39488 L .97 .659 .363 r
F
.48254 .49104 m .47869 .49986 L .47875 .48748 L .965 .687 .457 r
F
.48254 .49104 m .48344 .50429 L .47869 .49986 L F
.41832 .38154 m .41892 .37223 L .42035 .37476 L .964 .688 .462 r
F
.41983 .38384 m .41832 .38154 L .42035 .37476 L F
.34979 .51224 m .35467 .5033 L .34504 .50209 L .12 .292 .765 r
F
.34979 .51224 m .36041 .51557 L .35467 .5033 L F
.65221 .39718 m .65829 .40896 L .65869 .41435 L .958 .689 .247 r
F
.65183 .3943 m .65829 .40896 L .65221 .39718 L .946 .666 .209 r
F
.39525 .3974 m .39835 .39638 L .3997 .38854 L .485 .207 .416 r
F
0 g
.3997 .38854 m
.40177 .38182 L
s
.57022 .52587 m .61267 .55084 L .56478 .52653 L .614 .056 0 r
F
.57022 .52587 m .61966 .54979 L .61267 .55084 L F
.57944 .50371 m .57022 .52587 L .56478 .52653 L .947 .947 .744 r
F
0 g
.57022 .52587 m
.57506 .5234 L
s
.64171 .51604 m .62584 .54634 L .61966 .54979 L .889 .98 .695 r
F
0 g
.62584 .54634 m
.6311 .54058 L
s
.16129 .44436 m .15632 .4254 L .15722 .40275 L .924 .732 .244 r
F
.16223 .46446 m .15632 .4254 L .16129 .44436 L .885 .671 .151 r
F
.53436 .43786 m .53452 .45249 L .5333 .43705 L .969 .687 .442 r
F
.53436 .43786 m .53664 .4541 L .53452 .45249 L F
.32444 .62154 m .38012 .54624 L .31324 .61007 L .829 .77 .796 r
F
0 g
.32444 .62154 m
.33562 .63051 L
s
.66725 .39624 m .68077 .41645 L .66751 .39969 L .977 .685 .394 r
F
.66751 .39969 m .68077 .41645 L .68084 .42279 L .977 .686 .396 r
F
.5176 .39138 m .51212 .37359 L .5188 .38967 L .969 .687 .442 r
F
.58004 .40635 m .58748 .4164 L .58745 .41826 L .982 .701 .404 r
F
.51508 .50267 m .50643 .51642 L .51067 .50057 L .955 .822 .673 r
F
.51508 .50267 m .51174 .51888 L .50643 .51642 L F
.58652 .42255 m .59094 .43931 L .5898 .44117 L .996 .764 .456 r
F
.58697 .42136 m .59094 .43931 L .58652 .42255 L .995 .758 .43 r
F
.62006 .26208 m .61907 .23597 L .6265 .26476 L .968 .657 .368 r
F
.62006 .26208 m .61099 .23244 L .61907 .23597 L F
.5879 .48118 m .57944 .50371 L .5847 .4827 L .978 .92 .643 r
F
.58939 .46146 m .5879 .48118 L .5847 .4827 L .993 .871 .596 r
F
.47598 .47185 m .47122 .47785 L .47319 .46795 L .965 .687 .457 r
F
.47598 .47185 m .47496 .48306 L .47122 .47785 L F
.49852 .4066 m .48901 .39662 L .48993 .39315 L .922 .618 .45 r
F
.49816 .40929 m .48901 .39662 L .49852 .4066 L .92 .625 .468 r
F
.49872 .34132 m .49639 .32192 L .50235 .3386 L .969 .687 .442 r
F
.50543 .35748 m .49872 .34132 L .50235 .3386 L F
.46443 .51389 m .45936 .51188 L .45939 .50926 L .964 .688 .462 r
F
.46443 .51389 m .46461 .5167 L .45936 .51188 L F
.42955 .48305 m .4224 .48344 L .42621 .4768 L .962 .688 .467 r
F
.42955 .48305 m .42659 .49127 L .4224 .48344 L F
.52439 .4077 m .51665 .39362 L .5176 .39138 L .969 .687 .442 r
F
.52405 .40907 m .51665 .39362 L .52439 .4077 L F
.5154 .47014 m .50996 .48248 L .51266 .46811 L .958 .771 .61 r
F
.5154 .47014 m .51362 .48515 L .50996 .48248 L F
.64216 .36878 m .64115 .35695 L .64358 .37098 L .915 .538 .113 r
F
.64216 .36878 m .63832 .35254 L .64115 .35695 L F
.58004 .40635 m .57874 .39185 L .57984 .39325 L .969 .657 .366 r
F
.3318 .4581 m .33866 .4501 L .33676 .43701 L .024 .032 .528 r
F
.33411 .4692 m .33866 .4501 L .3318 .4581 L .075 .109 .593 r
F
.41681 .37925 m .41748 .36969 L .41892 .37223 L .964 .688 .462 r
F
.41832 .38154 m .41681 .37925 L .41892 .37223 L F
.47961 .38234 m .47025 .36719 L .48131 .37857 L .884 .55 .413 r
F
.48993 .39315 m .47961 .38234 L .48131 .37857 L .905 .581 .422 r
F
.56521 .37217 m .55736 .35621 L .56702 .37218 L .906 .509 .239 r
F
.56521 .37217 m .55462 .35615 L .55736 .35621 L F
.41546 .50348 m .42039 .50079 L .41099 .49636 L .035 .314 .801 r
F
.41546 .50348 m .42577 .50937 L .42039 .50079 L F
.54486 .47263 m .5453 .48882 L .54198 .47195 L .969 .687 .442 r
F
.54486 .47263 m .54913 .48967 L .5453 .48882 L F
.73069 .47532 m .73167 .51309 L .72832 .4837 L .974 .782 .357 r
F
.72463 .44846 m .73069 .47532 L .72832 .4837 L .987 .765 .372 r
F
.72577 .44101 m .73069 .47532 L .72463 .44846 L .975 .746 .324 r
F
.15722 .40275 m .16686 .37985 L .16006 .3822 L .508 .262 .477 r
F
0 g
.16006 .3822 m
.16478 .36411 L
s
.73167 .51309 m .72798 .55316 L .72766 .52152 L .976 .825 .416 r
F
.72832 .4837 m .73167 .51309 L .72766 .52152 L .99 .804 .418 r
F
.51174 .51888 m .54592 .52031 L .50643 .51642 L .192 .668 .933 r
F
.51174 .51888 m .55207 .52323 L .54592 .52031 L F
0 g
.51174 .51888 m
.51672 .51986 L
s
.45724 .41527 m .44988 .40735 L .45021 .4013 L .965 .687 .457 r
F
.45738 .42022 m .44988 .40735 L .45724 .41527 L F
.45104 .39592 m .44395 .38507 L .44561 .37932 L F
.45021 .4013 m .44395 .38507 L .45104 .39592 L F
.58004 .40635 m .58745 .41826 L .58728 .41992 L .982 .704 .413 r
F
.5333 .43705 m .53235 .45034 L .53222 .43597 L .969 .687 .442 r
F
.5333 .43705 m .53452 .45249 L .53235 .45034 L F
.38012 .54624 m .42577 .50937 L .37326 .53723 L .737 .723 .839 r
F
.38012 .54624 m .43133 .51691 L .42577 .50937 L F
0 g
.38012 .54624 m
.3871 .55382 L
s
.31324 .61007 m .38012 .54624 L .37326 .53724 L .815 .739 .78 r
F
0 g
.38012 .54624 m
.3871 .55382 L
s
.41328 .434 m .40617 .4297 L .40541 .42115 L .962 .688 .467 r
F
.41438 .44112 m .40617 .4297 L .41328 .434 L F
.42325 .3975 m .42285 .38842 L .42436 .39071 L .964 .688 .462 r
F
0 g
.42436 .39071 m
.42608 .38488 L
s
.57454 .38892 m .56899 .3728 L .57552 .38922 L .941 .583 .297 r
F
.57454 .38892 m .56702 .37218 L .56899 .3728 L F
.49872 .34132 m .49199 .32512 L .49639 .32192 L .969 .687 .442 r
F
.44395 .38507 m .43884 .36728 L .44561 .37932 L .965 .687 .457 r
F
.46461 .5167 m .45934 .5145 L .45936 .51188 L .964 .688 .462 r
F
.46461 .5167 m .46479 .5195 L .45934 .5145 L F
.37055 .51677 m .36042 .51557 L .36538 .50732 L .958 .688 .48 r
F
.37055 .51677 m .36665 .52695 L .36042 .51557 L F
.65259 .35749 m .65478 .33754 L .65442 .35993 L .974 .675 .386 r
F
.65259 .35749 m .65115 .33264 L .65478 .33754 L F
.41681 .37925 m .41529 .37695 L .41748 .36969 L .964 .688 .462 r
F
0 g
.41748 .36969 m
.42039 .36378 L
s
.5124 .45233 m .50706 .46205 L .51053 .45009 L .95 .736 .578 r
F
.5124 .45233 m .50986 .4654 L .50706 .46205 L F
.7032 .36827 m .71023 .36734 L .71247 .37523 L .966 .654 .265 r
F
.7019 .36431 m .71023 .36734 L .7032 .36827 L .964 .646 .257 r
F
.7019 .36431 m .70765 .35951 L .71023 .36734 L F
.43562 .50462 m .42896 .5081 L .43102 .49837 L .962 .688 .467 r
F
.43562 .50462 m .43449 .5156 L .42896 .5081 L F
.58004 .40635 m .57764 .39069 L .57874 .39185 L .967 .656 .37 r
F
.70045 .36045 m .70765 .35951 L .7019 .36431 L .962 .639 .251 r
F
.70045 .36045 m .70478 .35186 L .70765 .35951 L F
.52405 .40907 m .51596 .39635 L .51665 .39362 L .969 .687 .442 r
F
.52385 .41065 m .51596 .39635 L .52405 .40907 L F
.68423 .31652 m .68182 .29748 L .68778 .32064 L .935 .563 .181 r
F
.68423 .31652 m .67651 .29127 L .68182 .29748 L F
.34504 .50209 m .34953 .49037 L .34079 .4914 L .13 .261 .732 r
F
.34504 .50209 m .35467 .5033 L .34953 .49037 L F
.61065 .31943 m .59802 .30167 L .61446 .32083 L .796 .3 0 r
F
.61065 .31943 m .59289 .29972 L .59802 .30167 L F
.48901 .39662 m .47961 .38234 L .48993 .39315 L .902 .591 .448 r
F
.27114 .57254 m .28167 .56276 L .26289 .55799 L .145 .353 .811 r
F
.27114 .57254 m .29165 .58042 L .28167 .56276 L F
.23728 .61978 m .22277 .62252 L .22616 .60358 L .959 .632 .349 r
F
.23728 .61978 m .23627 .64208 L .22277 .62252 L F
.53868 .45515 m .53893 .47041 L .53664 .4541 L .969 .687 .442 r
F
.53868 .45515 m .54198 .47195 L .53893 .47041 L F
.65766 .42761 m .66007 .44956 L .65848 .4544 L .975 .801 .383 r
F
.65837 .42375 m .66007 .44956 L .65766 .42761 L .949 .767 .308 r
F
.65221 .39718 m .65869 .41435 L .65241 .39989 L .958 .689 .247 r
F
.65241 .39989 m .65869 .41435 L .65871 .41931 L .97 .712 .287 r
F
.039 .916 .04 r
.65798 .41273 m
.65814 .41269 L
s
.59366 .42921 m
.65668 .41306 L
s
.70433 .37226 m .71247 .37523 L .71434 .38307 L .969 .663 .275 r
F
.7032 .36827 m .71247 .37523 L .70433 .37226 L .966 .654 .265 r
F
.58813 .29938 m .57032 .2818 L .59289 .29972 L .722 .192 0 r
F
.58813 .29938 m .56427 .28129 L .57032 .2818 L F
.49816 .40929 m .48844 .40066 L .48901 .39662 L .92 .625 .468 r
F
.49804 .41232 m .48844 .40066 L .49816 .40929 L .918 .632 .485 r
F
.38977 .42605 m .39477 .41591 L .39463 .40624 L 0 0 .341 r
F
.3905 .43463 m .39477 .41591 L .38977 .42605 L 0 0 .446 r
F
.33411 .4692 m .34145 .46352 L .33866 .4501 L .075 .109 .593 r
F
.33712 .48037 m .34145 .46352 L .33411 .4692 L .108 .171 .647 r
F
.42621 .4768 m .41853 .47502 L .42313 .47009 L .962 .688 .467 r
F
.42621 .4768 m .4224 .48344 L .41853 .47502 L F
.53222 .43597 m .53017 .4477 L .53114 .43465 L .969 .687 .442 r
F
.53222 .43597 m .53235 .45034 L .53017 .4477 L F
.58004 .40635 m .58728 .41992 L .58697 .42136 L .982 .707 .421 r
F
.43699 .52327 m .43446 .51594 L .43133 .51691 L .652 .735 .911 r
F
.43699 .52327 m .44011 .52231 L .43446 .51594 L F
0 g
.43699 .52327 m
.44264 .52836 L
s
.44011 .52231 m
.44575 .5274 L
s
.42169 .3955 m .42134 .38613 L .42285 .38842 L .964 .688 .462 r
F
.42325 .3975 m .42169 .3955 L .42285 .38842 L F
.46808 .37188 m .4579 .35621 L .47025 .36719 L .861 .519 .403 r
F
.47961 .38234 m .46808 .37188 L .47025 .36719 L .884 .55 .413 r
F
.69888 .35676 m .70478 .35186 L .70045 .36045 L .961 .633 .249 r
F
.69888 .35676 m .70167 .34454 L .70478 .35186 L F
.46479 .5195 m .45931 .51713 L .45934 .5145 L .964 .688 .462 r
F
.46479 .5195 m .46497 .52231 L .45931 .51713 L F
.55214 .357 m .5416 .34098 L .55462 .35615 L .865 .443 .216 r
F
.55214 .357 m .53825 .34206 L .5416 .34098 L F
.47319 .46795 m .46761 .47195 L .47049 .46353 L .965 .687 .457 r
F
.47319 .46795 m .47122 .47785 L .46761 .47195 L F
.5103 .37613 m .50543 .35748 L .51212 .37359 L .969 .687 .442 r
F
.5176 .39138 m .5103 .37613 L .51212 .37359 L F
.34578 .4422 m .33677 .43701 L .33581 .42451 L .958 .688 .48 r
F
.34736 .45305 m .33677 .43701 L .34578 .4422 L F
.70129 .49186 m .70811 .52732 L .69793 .4985 L .982 .703 .409 r
F
.68997 .46474 m .70129 .49186 L .69793 .4985 L .981 .698 .408 r
F
.69189 .45852 m .70129 .49186 L .68997 .46474 L .981 .697 .402 r
F
.67959 .43341 m .69189 .45852 L .68997 .46474 L .979 .693 .402 r
F
.68045 .42848 m .69189 .45852 L .67959 .43341 L .979 .692 .399 r
F
.52385 .41065 m .51555 .39952 L .51596 .39635 L .969 .687 .442 r
F
.52379 .41243 m .51555 .39952 L .52385 .41065 L F
.54913 .48967 m .54863 .50574 L .5453 .48882 L F
.54913 .48967 m .55341 .50674 L .54863 .50574 L F
.34079 .4914 m .3451 .47703 L .33712 .48037 L .126 .221 .693 r
F
.34079 .4914 m .34953 .49037 L .3451 .47703 L F
.58004 .40635 m .57656 .38981 L .57764 .39069 L .966 .655 .375 r
F
.51665 .39362 m .5103 .37613 L .5176 .39138 L .969 .687 .442 r
F
.41438 .44112 m .40754 .43864 L .40617 .4297 L .962 .688 .467 r
F
.41594 .44842 m .40754 .43864 L .41438 .44112 L F
.33712 .48037 m .3451 .47703 L .34145 .46352 L .108 .171 .647 r
F
.71795 .55609 m .72195 .5607 L .71184 .56364 L .202 0 0 r
F
.71795 .55609 m .72798 .55316 L .72195 .5607 L F
.70811 .52732 m .71795 .55609 L .71184 .56364 L .983 .709 .418 r
F
0 g
.71795 .55609 m
.72279 .54578 L
s
.64072 .36687 m .63832 .35254 L .64216 .36878 L .92 .539 .135 r
F
.64072 .36687 m .63546 .34872 L .63832 .35254 L F
.5898 .44117 m .58939 .46146 L .58841 .44246 L 1 .821 .514 r
F
.58595 .42346 m .5898 .44117 L .58841 .44246 L .994 .767 .48 r
F
.58652 .42255 m .5898 .44117 L .58595 .42346 L .996 .764 .456 r
F
.15722 .40275 m .16405 .40041 L .16686 .37985 L .508 .262 .477 r
F
0 g
.16686 .37985 m
.17154 .36176 L
s
.40528 .41314 m .39796 .40544 L .39857 .39665 L .962 .688 .467 r
F
.40541 .42115 m .39796 .40544 L .40528 .41314 L F
.48992 .5215 m .5009 .51251 L .48434 .51761 L .634 .829 .976 r
F
.48992 .5215 m .50643 .51642 L .5009 .51251 L F
0 g
.48992 .5215 m
.49527 .52393 L
s
.70528 .37621 m .71434 .38307 L .71581 .39071 L .972 .672 .288 r
F
.70433 .37226 m .71434 .38307 L .70528 .37621 L .969 .663 .275 r
F
.51053 .45009 m .50429 .45812 L .5087 .44747 L .944 .727 .579 r
F
.51053 .45009 m .50706 .46205 L .50429 .45812 L F
.50071 .31556 m .52647 .26752 L .53324 .26581 L .908 .983 .76 r
F
.49614 .31887 m .52647 .26752 L .50071 .31556 L .867 .974 .663 r
F
.5177 .33095 m .50071 .31556 L .52143 .32813 L .754 .296 .164 r
F
.5177 .33095 m .49614 .31887 L .50071 .31556 L F
0 g
.50071 .31556 m
.50588 .31406 L
s
.45738 .42022 m .45006 .41396 L .44988 .40735 L .965 .687 .457 r
F
.45789 .4255 m .45006 .41396 L .45738 .42022 L F
.51362 .48515 m .50608 .49727 L .50996 .48248 L .95 .788 .646 r
F
.51362 .48515 m .51067 .50057 L .50608 .49727 L F
.53114 .43465 m .52802 .4446 L .53007 .4331 L .969 .687 .442 r
F
.53114 .43465 m .53017 .4477 L .52802 .4446 L F
.3358 .41283 m .39463 .40624 L .39525 .3974 L .633 .375 .51 r
F
.33581 .42451 m .39463 .40624 L .3358 .41283 L .646 .418 .558 r
F
0 g
.3358 .41282 m
.33673 .40216 L
s
.3358 .41283 m
.33673 .40216 L
s
.24363 .42028 m .3358 .41283 L .24399 .40206 L .741 .495 .558 r
F
.24363 .42028 m .33581 .42451 L .3358 .41283 L F
0 g
.3358 .41283 m
.3358 .41282 L
s
.3358 .41283 m
.3358 .41284 L
s
.58939 .46146 m .5847 .4827 L .58699 .46256 L .993 .871 .596 r
F
.58841 .44246 m .58939 .46146 L .58699 .46256 L .996 .821 .549 r
F
.46497 .52231 m .45929 .51977 L .45931 .51713 L .964 .688 .462 r
F
.46497 .52231 m .46515 .52512 L .45929 .51977 L F
.42013 .39349 m .41983 .38384 L .42134 .38613 L F
.42169 .3955 m .42013 .39349 L .42134 .38613 L F
.47875 .48748 m .47393 .49434 L .47496 .48306 L .965 .687 .457 r
F
.47875 .48748 m .47869 .49986 L .47393 .49434 L F
.57944 .50371 m .56478 .52653 L .57493 .50418 L .947 .947 .744 r
F
.5847 .4827 m .57944 .50371 L .57493 .50418 L .973 .906 .687 r
F
.66754 .40286 m .68084 .42279 L .68045 .42848 L .977 .687 .398 r
F
.66751 .39969 m .68084 .42279 L .66754 .40286 L .977 .686 .396 r
F
.58004 .40635 m .58697 .42136 L .58652 .42255 L .982 .71 .429 r
F
.42313 .47009 m .41505 .46617 L .42036 .46304 L .962 .688 .467 r
F
.42313 .47009 m .41853 .47502 L .41505 .46617 L F
.23258 .45679 m .24482 .43981 L .24363 .42028 L .002 0 .456 r
F
.2348 .47368 m .24482 .43981 L .23258 .45679 L .073 .063 .539 r
F
.51266 .46811 m .50622 .47889 L .50986 .4654 L .948 .76 .615 r
F
.51266 .46811 m .50996 .48248 L .50622 .47889 L F
.52379 .41243 m .51542 .40308 L .51555 .39952 L .969 .687 .442 r
F
.52388 .41437 m .51542 .40308 L .52379 .41243 L F
.4579 .35621 m .48803 .32955 L .49179 .32463 L 0 0 0 r
F
0 g
.49179 .32463 m
.49621 .32142 L
s
.46808 .37188 m .45525 .36182 L .4579 .35621 L .861 .519 .403 r
F
.45525 .36182 m .48803 .32955 L .4579 .35621 L 0 0 0 r
F
.43884 .36728 m .45525 .36182 L .4579 .35621 L .35 0 .162 r
F
0 g
.4579 .35621 m
.46116 .35198 L
s
.49804 .41232 m .48825 .4052 L .48844 .40066 L .918 .632 .485 r
F
.49816 .41562 m .48825 .4052 L .49804 .41232 L .917 .64 .5 r
F
0 g
.24399 .40206 m
.24587 .3855 L
s
.6972 .35328 m .70167 .34454 L .69888 .35676 L .96 .628 .249 r
F
.6972 .35328 m .69835 .33764 L .70167 .34454 L F
0 0 0 r
2 Mabswid
.42941 .41223 Mdot
.62714 .34143 m .6185 .32341 L .62982 .34312 L .868 .424 .05 r
F
.62714 .34143 m .61446 .32083 L .6185 .32341 L F
.41594 .44842 m .4095 .44781 L .40754 .43864 L .962 .688 .467 r
F
.41795 .45578 m .4095 .44781 L .41594 .44842 L F
.41099 .49636 m .4153 .49132 L .40676 .48852 L .082 .304 .785 r
F
.41099 .49636 m .42039 .50079 L .4153 .49132 L F
.58004 .40635 m .57552 .38922 L .57656 .38981 L .965 .655 .381 r
F
.57364 .38892 m .56702 .37218 L .57454 .38892 L .94 .588 .322 r
F
.57364 .38892 m .56521 .37217 L .56702 .37218 L F
.21029 .60845 m .20314 .60281 L .19984 .59044 L .784 .376 0 r
F
.21029 .60845 m .21582 .62464 L .20314 .60281 L F
.45941 .50664 m .45433 .50347 L .45456 .50108 L .964 .688 .462 r
F
.45941 .50664 m .45939 .50926 L .45433 .50347 L F
0 g
.5 Mabswid
.45941 .50664 m
.46425 .51109 L
s
.53007 .4331 m .52594 .4411 L .52903 .43135 L .969 .687 .442 r
F
.53007 .4331 m .52802 .4446 L .52594 .4411 L F
.36538 .50732 m .35468 .5033 L .36063 .49715 L .958 .688 .48 r
F
.36538 .50732 m .36042 .51557 L .35468 .5033 L F
.42036 .46304 m .41202 .45704 L .41795 .45578 L .962 .688 .467 r
F
.42036 .46304 m .41505 .46617 L .41202 .45704 L F
.39463 .40624 m .39835 .39638 L .39525 .3974 L .522 .282 .492 r
F
0 g
.39525 .3974 m
.39661 .38956 L
s
.47049 .46353 m .46418 .46545 L .46793 .45868 L .965 .687 .457 r
F
.47049 .46353 m .46761 .47195 L .46418 .46545 L F
.66632 .28293 m .65997 .2604 L .67131 .28639 L .914 .514 .151 r
F
.66632 .28293 m .65329 .25568 L .65997 .2604 L F
.55878 .2828 m .53324 .26581 L .56427 .28129 L .644 .102 0 r
F
.55878 .2828 m .52647 .26752 L .53324 .26581 L F
0 g
.53324 .26581 m
.54065 .26652 L
s
.41795 .45578 m .41202 .45704 L .4095 .44781 L .962 .688 .467 r
F
.46515 .52512 m .45926 .5224 L .45929 .51977 L .964 .688 .462 r
F
.46515 .52512 m .46533 .52794 L .45926 .5224 L F
0 g
.46533 .52794 m
.47127 .532 L
s
.53664 .4541 m .53574 .46802 L .53452 .45249 L .969 .687 .442 r
F
.53664 .4541 m .53893 .47041 L .53574 .46802 L F
.52388 .41437 m .51558 .40697 L .51542 .40308 L F
.5241 .41644 m .51558 .40697 L .52388 .41437 L F
.039 .916 .04 r
.50352 .41685 m
.5198 .41166 L
s
.48344 .50429 m .47864 .51231 L .47869 .49986 L .965 .687 .457 r
F
.48344 .50429 m .48434 .51761 L .47864 .51231 L F
.41857 .39148 m .41832 .38154 L .41983 .38384 L .964 .688 .462 r
F
.42013 .39349 m .41857 .39148 L .41983 .38384 L F
.55341 .50674 m .55197 .52271 L .54863 .50574 L .969 .687 .442 r
F
.55341 .50674 m .55769 .52385 L .55197 .52271 L F
.177 .43909 m .16319 .42307 L .16405 .40041 L .988 .734 .451 r
F
.17799 .45922 m .16319 .42307 L .177 .43909 L .987 .724 .43 r
F
.65242 .40237 m .65871 .41931 L .65837 .42375 L .98 .731 .327 r
F
.65241 .39989 m .65871 .41931 L .65242 .40237 L .97 .712 .287 r
F
.039 .916 .04 r
.65814 .41269 m
.67049 .40873 L
s
.5087 .44747 m .50161 .45367 L .50692 .44451 L .939 .718 .578 r
F
.5087 .44747 m .50429 .45812 L .50161 .45367 L F
.48901 .39662 m .47836 .38696 L .47961 .38234 L .902 .591 .448 r
F
.48844 .40066 m .47836 .38696 L .48901 .39662 L .899 .6 .472 r
F
.50298 .36082 m .49872 .34132 L .50543 .35748 L .969 .687 .442 r
F
.5103 .37613 m .50298 .36082 L .50543 .35748 L F
.45021 .4013 m .4429 .39179 L .44395 .38507 L .965 .687 .457 r
F
.44988 .40735 m .4429 .39179 L .45021 .4013 L F
.58004 .40635 m .58652 .42255 L .58595 .42346 L .981 .712 .438 r
F
.3905 .43463 m .39566 .42625 L .39477 .41591 L 0 0 .446 r
F
.39186 .4436 m .39566 .42625 L .3905 .43463 L .014 .029 .528 r
F
.52903 .43135 m .52396 .43726 L .52805 .42944 L .969 .687 .442 r
F
.52903 .43135 m .52594 .4411 L .52396 .43726 L F
.47836 .38696 m .46808 .37188 L .47961 .38234 L .88 .564 .446 r
F
.70601 .38007 m .71581 .39071 L .71685 .39804 L .976 .681 .302 r
F
.70528 .37621 m .71581 .39071 L .70601 .38007 L .972 .672 .288 r
F
.45789 .4255 m .45074 .42102 L .45006 .41396 L .965 .687 .457 r
F
.45877 .43102 m .45074 .42102 L .45789 .4255 L F
.65078 .35547 m .65115 .33264 L .65259 .35749 L .973 .675 .387 r
F
.65078 .35547 m .64755 .32857 L .65115 .33264 L F
.54198 .47195 m .54122 .4868 L .53893 .47041 L .969 .687 .442 r
F
.54198 .47195 m .5453 .48882 L .54122 .4868 L F
.56357 .37276 m .55462 .35615 L .56521 .37217 L .906 .523 .286 r
F
.56357 .37276 m .55214 .357 L .55462 .35615 L F
.34736 .45305 m .33866 .45009 L .33677 .43701 L .958 .688 .48 r
F
.34968 .46418 m .33866 .45009 L .34736 .45305 L F
.5241 .41644 m .51603 .41112 L .51558 .40697 L .969 .687 .442 r
F
.52447 .4186 m .51603 .41112 L .5241 .41644 L F
.49816 .41562 m .48842 .41016 L .48825 .4052 L .917 .64 .5 r
F
.039 .916 .04 r
.45886 .41702 m
.48833 .40761 L
s
.49058 .4069 m
.49068 .40687 L
s
.49853 .41914 m .48842 .41016 L .49816 .41562 L .917 .648 .514 r
F
.64063 .3232 m .63878 .29724 L .64402 .3254 L .972 .669 .381 r
F
.64063 .3232 m .63369 .29384 L .63878 .29724 L F
.43102 .49837 m .42361 .49956 L .42659 .49127 L .962 .688 .467 r
F
.43102 .49837 m .42896 .5081 L .42361 .49956 L F
.39463 .40624 m .39774 .40521 L .39835 .39638 L .522 .282 .492 r
F
0 g
.39835 .39638 m
.3997 .38854 L
s
.71727 .41698 m .72577 .44101 L .72463 .44846 L .986 .732 .35 r
F
.71759 .41129 m .72577 .44101 L .71727 .41698 L .979 .718 .318 r
F
.039 .916 .04 r
.68361 .42011 m
.71755 .40956 L
s
.51665 .39362 m .50886 .37947 L .5103 .37613 L .969 .687 .442 r
F
.51596 .39635 m .50886 .37947 L .51665 .39362 L F
.45939 .50926 m .4541 .50586 L .45433 .50347 L .964 .688 .462 r
F
.45939 .50926 m .45936 .51188 L .4541 .50586 L F
.58004 .40635 m .57454 .38892 L .57552 .38922 L .964 .655 .387 r
F
.52805 .42944 m .52212 .43314 L .52714 .42739 L .969 .687 .442 r
F
.52805 .42944 m .52396 .43726 L .52212 .43314 L F
.44395 .38507 m .43683 .37417 L .43884 .36728 L .965 .687 .457 r
F
.43683 .37417 m .45525 .36182 L .43884 .36728 L .432 .106 .311 r
F
0 g
.43884 .36728 m
.44154 .36167 L
s
.64697 .25294 m .63829 .22936 L .65329 .25568 L .892 .467 .121 r
F
.64697 .25294 m .63031 .22578 L .63829 .22936 L F
.417 .38947 m .41681 .37925 L .41832 .38154 L .964 .688 .462 r
F
.41857 .39148 m .417 .38947 L .41832 .38154 L F
.52447 .4186 m .51675 .41546 L .51603 .41112 L .969 .687 .442 r
F
.52496 .42081 m .51675 .41546 L .52447 .4186 L F
.72766 .52152 m .72798 .55316 L .72195 .5607 L .992 .844 .483 r
F
0 g
.72798 .55316 m
.73276 .54286 L
s
.51067 .50057 m .5009 .51251 L .50608 .49727 L .94 .803 .68 r
F
.51067 .50057 m .50643 .51642 L .5009 .51251 L F
.63929 .3653 m .63546 .34872 L .64072 .36687 L .925 .542 .16 r
F
.63929 .3653 m .63261 .34556 L .63546 .34872 L F
.69546 .35009 m .69835 .33764 L .6972 .35328 L .959 .624 .252 r
F
.69546 .35009 m .6949 .33129 L .69835 .33764 L F
.46793 .45868 m .46101 .45848 L .46557 .45347 L .965 .687 .457 r
F
.46793 .45868 m .46418 .46545 L .46101 .45848 L F
.58841 .44246 m .58699 .46256 L .58681 .44316 L .996 .821 .549 r
F
.58525 .4241 m .58841 .44246 L .58681 .44316 L .991 .768 .501 r
F
.58595 .42346 m .58841 .44246 L .58525 .4241 L .994 .767 .48 r
F
.52714 .42739 m .52045 .42883 L .52631 .42525 L .969 .687 .442 r
F
.52714 .42739 m .52212 .43314 L .52045 .42883 L F
.50692 .44451 m .49907 .44879 L .50524 .44126 L .934 .709 .575 r
F
.50692 .44451 m .50161 .45367 L .49907 .44879 L F
.42277 .40516 m .42169 .3955 L .42325 .3975 L .964 .688 .462 r
F
0 g
.42325 .3975 m
.42436 .39071 L
s
.52496 .42081 m .51774 .41991 L .51675 .41546 L .969 .687 .442 r
F
.52558 .42304 m .51774 .41991 L .52496 .42081 L F
.5847 .4827 m .57493 .50418 L .58112 .48301 L .973 .906 .687 r
F
.58699 .46256 m .5847 .4827 L .58112 .48301 L .986 .862 .632 r
F
.52631 .42525 m .51898 .42439 L .52558 .42304 L .969 .687 .442 r
F
.52631 .42525 m .52045 .42883 L .51898 .42439 L F
.52558 .42304 m .51898 .42439 L .51774 .41991 L F
.26289 .55799 m .27253 .54364 L .25533 .54225 L .17 .328 .781 r
F
.26289 .55799 m .28167 .56276 L .27253 .54364 L F
.36063 .49715 m .34954 .49037 L .35638 .48643 L .958 .688 .48 r
F
.36063 .49715 m .35468 .5033 L .34954 .49037 L F
.62888 .29194 m .6265 .26476 L .63369 .29384 L .97 .663 .376 r
F
.62888 .29194 m .62006 .26208 L .6265 .26476 L F
.46001 .43667 m .45191 .42841 L .45877 .43102 L .965 .687 .457 r
F
.45877 .43102 m .45191 .42841 L .45074 .42102 L F
.40676 .48852 m .41061 .48114 L .40287 .48008 L .109 .283 .76 r
F
.40676 .48852 m .4153 .49132 L .41061 .48114 L F
.58004 .40635 m .58595 .42346 L .58525 .4241 L .981 .713 .445 r
F
.65368 .48412 m .64171 .51604 L .65024 .48775 L .927 .927 .557 r
F
.65638 .45818 m .65368 .48412 L .65024 .48775 L .98 .888 .535 r
F
.65848 .4544 m .65368 .48412 L .65638 .45818 L .953 .863 .447 r
F
.53532 .34436 m .52143 .32813 L .53825 .34206 L .818 .391 .229 r
F
.53532 .34436 m .5177 .33095 L .52143 .32813 L F
.49853 .41914 m .48897 .41546 L .48842 .41016 L .917 .648 .514 r
F
.49913 .42281 m .48897 .41546 L .49853 .41914 L .917 .656 .527 r
F
.16223 .46446 m .15744 .44973 L .15632 .4254 L .885 .671 .151 r
F
.16481 .48551 m .15744 .44973 L .16223 .46446 L .845 .608 .064 r
F
.4429 .39179 m .43683 .37417 L .44395 .38507 L .965 .687 .457 r
F
.40541 .42115 m .3981 .41507 L .39796 .40544 L .962 .688 .467 r
F
.40617 .4297 m .3981 .41507 L .40541 .42115 L F
0 g
.55207 .52323 m
.55782 .52437 L
s
.37326 .53723 m .42039 .50079 L .36665 .52695 L .727 .689 .814 r
F
.37326 .53723 m .42577 .50937 L .42039 .50079 L F
0 g
.37326 .53723 m
.38012 .54624 L
s
.30224 .59628 m .37326 .53724 L .36665 .52695 L .803 .711 .763 r
F
.31324 .61007 m .37326 .53724 L .30224 .59628 L .815 .739 .78 r
F
0 g
.37326 .53724 m
.38012 .54624 L
s
.31324 .61007 m
.32444 .62154 L
s
.50886 .37947 m .50298 .36082 L .5103 .37613 L .969 .687 .442 r
F
.50986 .4654 m .50246 .47443 L .50706 .46205 L .939 .748 .617 r
F
.50986 .4654 m .50622 .47889 L .50246 .47443 L F
.45936 .51188 m .45387 .50826 L .4541 .50586 L .964 .688 .462 r
F
.45936 .51188 m .45934 .5145 L .45387 .50826 L F
.34968 .46418 m .34146 .46352 L .33866 .45009 L .958 .688 .48 r
F
.35271 .47537 m .34146 .46352 L .34968 .46418 L F
.039 .916 .04 r
.71955 .40894 m
.89765 .34177 L
s
.71954 .40895 m
.71955 .40894 L
s
0 0 0 r
2 Mabswid
.71954 .40895 Mdot
.41544 .38746 m .41529 .37695 L .41681 .37925 L .964 .688 .462 r
F
.417 .38947 m .41544 .38746 L .41681 .37925 L F
.46557 .45347 m .45815 .45116 L .46343 .448 L .965 .687 .457 r
F
.46557 .45347 m .46101 .45848 L .45815 .45116 L F
.58004 .40635 m .57364 .38892 L .57454 .38892 L .963 .655 .394 r
F
.50524 .44126 m .49671 .44355 L .50367 .43778 L .929 .7 .571 r
F
.50524 .44126 m .49907 .44879 L .49671 .44355 L F
.53452 .45249 m .53247 .46481 L .53235 .45034 L .969 .687 .442 r
F
.53452 .45249 m .53574 .46802 L .53247 .46481 L F
.47496 .48306 m .46924 .48783 L .47122 .47785 L .965 .687 .457 r
F
.47496 .48306 m .47393 .49434 L .46924 .48783 L F
.57283 .38923 m .56521 .37217 L .57364 .38892 L .938 .593 .346 r
F
.57283 .38923 m .56357 .37276 L .56521 .37217 L F
.39186 .4436 m .39731 .43707 L .39566 .42625 L .014 .029 .528 r
F
.39381 .4528 m .39731 .43707 L .39186 .4436 L .065 .104 .592 r
F
.46001 .43667 m .45356 .43598 L .45191 .42841 L .965 .687 .457 r
F
.46157 .44237 m .45356 .43598 L .46001 .43667 L F
.49913 .42281 m .48987 .42099 L .48897 .41546 L .917 .656 .527 r
F
.49997 .42658 m .48987 .42099 L .49913 .42281 L .918 .664 .539 r
F
.49563 .34545 m .49199 .32512 L .49872 .34132 L .969 .687 .442 r
F
.50298 .36082 m .49563 .34545 L .49872 .34132 L F
.42119 .40348 m .42013 .39349 L .42169 .3955 L .964 .688 .462 r
F
.42277 .40516 m .42119 .40348 L .42169 .3955 L F
.6566 .43081 m .65848 .4544 L .65638 .45818 L .991 .823 .448 r
F
.65766 .42761 m .65848 .4544 L .6566 .43081 L .975 .801 .383 r
F
.35638 .48643 m .3451 .47703 L .35271 .47537 L .958 .688 .48 r
F
.35638 .48643 m .34954 .49037 L .3451 .47703 L F
.70653 .38376 m .71685 .39804 L .71745 .40494 L .979 .69 .318 r
F
.70601 .38007 m .71685 .39804 L .70653 .38376 L .976 .681 .302 r
F
.43133 .51691 m .42889 .50839 L .42577 .50937 L .65 .695 .878 r
F
.43133 .51691 m .43446 .51594 L .42889 .50839 L F
0 g
.5 Mabswid
.43133 .51691 m
.43699 .52327 L
s
.43446 .51594 m
.44011 .52231 L
s
.46343 .448 m .45565 .44361 L .46157 .44237 L .965 .687 .457 r
F
.46343 .448 m .45815 .45116 L .45565 .44361 L F
.66732 .4057 m .68045 .42848 L .67959 .43341 L .977 .688 .4 r
F
.66754 .40286 m .68045 .42848 L .66732 .4057 L .977 .687 .398 r
F
.039 .916 .04 r
.67383 .40766 m
.67385 .40766 L
s
.67385 .40766 m
.67385 .40766 L
s
.67382 .40767 m
.67383 .40766 L
s
.46157 .44237 m .45565 .44361 L .45356 .43598 L .965 .687 .457 r
F
.35271 .47537 m .3451 .47703 L .34146 .46352 L .958 .688 .48 r
F
.50996 .48248 m .50138 .4928 L .50622 .47889 L .938 .772 .65 r
F
.50996 .48248 m .50608 .49727 L .50138 .4928 L F
.2348 .47368 m .24755 .4603 L .24482 .43981 L .073 .063 .539 r
F
.23826 .49101 m .24755 .4603 L .2348 .47368 L .123 .141 .606 r
F
.50367 .43778 m .49458 .43805 L .50226 .43413 L .925 .691 .565 r
F
.50367 .43778 m .49671 .44355 L .49458 .43805 L F
.48844 .40066 m .47758 .39234 L .47836 .38696 L .899 .6 .472 r
F
.48825 .4052 m .47758 .39234 L .48844 .40066 L .897 .61 .494 r
F
.70811 .52732 m .71184 .56364 L .70295 .53343 L .983 .709 .418 r
F
.69793 .4985 m .70811 .52732 L .70295 .53343 L .982 .704 .415 r
F
.68077 .31331 m .67651 .29127 L .68423 .31652 L .938 .567 .204 r
F
.68077 .31331 m .67131 .28639 L .67651 .29127 L F
.65224 .40459 m .65837 .42375 L .65766 .42761 L .988 .748 .366 r
F
.65242 .40237 m .65837 .42375 L .65224 .40459 L .98 .731 .327 r
F
.49997 .42658 m .49113 .42667 L .48987 .42099 L .918 .664 .539 r
F
.50101 .43038 m .49113 .42667 L .49997 .42658 L .92 .673 .549 r
F
.58525 .4241 m .58681 .44316 L .58445 .42443 L .991 .768 .501 r
F
.58004 .40635 m .58525 .4241 L .58445 .42443 L .98 .714 .452 r
F
.58699 .46256 m .58112 .48301 L .58431 .46274 L .986 .862 .632 r
F
.58681 .44316 m .58699 .46256 L .58431 .46274 L .99 .816 .576 r
F
.46649 .37764 m .45525 .36182 L .46808 .37188 L .858 .536 .442 r
F
.47836 .38696 m .46649 .37764 L .46808 .37188 L .88 .564 .446 r
F
.51596 .39635 m .50781 .38354 L .50886 .37947 L .969 .687 .442 r
F
.51555 .39952 m .50781 .38354 L .51596 .39635 L F
.50643 .51642 m .53948 .51566 L .5009 .51251 L .328 .694 .981 r
F
.50643 .51642 m .54592 .52031 L .53948 .51566 L F
0 g
.50643 .51642 m
.51174 .51888 L
s
.45934 .5145 m .45364 .51066 L .45387 .50826 L .964 .688 .462 r
F
.45934 .5145 m .45931 .51713 L .45364 .51066 L F
.41544 .38746 m .41387 .38544 L .41529 .37695 L F
0 g
.41529 .37695 m
.41748 .36969 L
s
.50226 .43413 m .4927 .43239 L .50101 .43038 L .922 .682 .557 r
F
.50226 .43413 m .49458 .43805 L .4927 .43239 L F
.40287 .48008 m .40639 .47042 L .39937 .47121 L .119 .253 .728 r
F
.40287 .48008 m .41061 .48114 L .40639 .47042 L F
.50101 .43038 m .4927 .43239 L .49113 .42667 L .92 .673 .549 r
F
.64171 .51604 m .61966 .54979 L .63663 .51877 L .889 .98 .695 r
F
.65024 .48775 m .64171 .51604 L .63663 .51877 L .959 .944 .65 r
F
.24339 .66102 m .23627 .64208 L .22933 .64416 L .645 .7 .886 r
F
.24339 .66102 m .2503 .65896 L .23627 .64208 L F
0 g
.24339 .66102 m
.25771 .67492 L
s
.2503 .65896 m
.2646 .6729 L
s
.44988 .40735 m .44247 .39936 L .4429 .39179 L .965 .687 .457 r
F
.45006 .41396 m .44247 .39936 L .44988 .40735 L F
.039 .916 .04 r
.42941 .41223 m
.44638 .40688 L
s
.5453 .48882 m .54353 .50327 L .54122 .4868 L .969 .687 .442 r
F
.5453 .48882 m .54863 .50574 L .54353 .50327 L F
.42659 .49127 m .41855 .49013 L .4224 .48344 L .962 .688 .467 r
F
.42659 .49127 m .42361 .49956 L .41855 .49013 L F
.33581 .42451 m .39477 .41591 L .39463 .40624 L .646 .418 .558 r
F
.33677 .43701 m .39477 .41591 L .33581 .42451 L .657 .455 .598 r
F
0 g
.3358 .41283 m
.33581 .42451 L
s
.24482 .43981 m .33581 .42451 L .24363 .42028 L .745 .521 .59 r
F
.24482 .43981 m .33676 .43701 L .33581 .42451 L F
0 g
.3358 .41284 m
.33581 .42451 L
s
.33581 .42451 m
.33581 .42453 L
s
.58004 .40635 m .57283 .38923 L .57364 .38892 L .962 .656 .401 r
F
.54997 .35875 m .53825 .34206 L .55214 .357 L .866 .469 .282 r
F
.54997 .35875 m .53532 .34436 L .53825 .34206 L F
.39381 .4528 m .39967 .44818 L .39731 .43707 L .065 .104 .592 r
F
.39633 .46206 m .39967 .44818 L .39381 .4528 L .098 .165 .645 r
F
.69367 .34723 m .6949 .33129 L .69546 .35009 L .959 .621 .257 r
F
.69367 .34723 m .69135 .32559 L .6949 .33129 L F
.4196 .40179 m .41857 .39148 L .42013 .39349 L .964 .688 .462 r
F
.42119 .40348 m .4196 .40179 L .42013 .39349 L F
.45456 .50108 m .44935 .49663 L .44978 .49452 L F
.45456 .50108 m .45433 .50347 L .44935 .49663 L F
0 g
.45456 .50108 m
.45941 .50664 L
s
.56478 .52653 m .60495 .5494 L .55883 .52536 L .51 0 0 r
F
.56478 .52653 m .61267 .55084 L .60495 .5494 L F
.57493 .50418 m .56478 .52653 L .55883 .52536 L .936 .916 .771 r
F
0 g
.56478 .52653 m
.57022 .52587 L
s
.59257 .20158 m .61155 .19955 L .60166 .20301 L .506 .901 .938 r
F
.60347 .23144 m .60166 .20301 L .61099 .23244 L .966 .652 .368 r
F
.60347 .23144 m .59257 .20158 L .60166 .20301 L F
0 g
.60166 .20301 m
.61139 .20746 L
s
.58681 .44316 m .58431 .46274 L .58502 .44325 L .99 .816 .576 r
F
.58445 .42443 m .58681 .44316 L .58502 .44325 L .987 .767 .519 r
F
.22616 .60358 m .2101 .60067 L .21572 .58551 L .963 .64 .347 r
F
.22616 .60358 m .22277 .62252 L .2101 .60067 L F
.39937 .47121 m .40272 .45936 L .39633 .46206 L .115 .213 .69 r
F
.39937 .47121 m .40639 .47042 L .40272 .45936 L F
.53893 .47041 m .53697 .48364 L .53574 .46802 L .969 .687 .442 r
F
.53893 .47041 m .54122 .4868 L .53697 .48364 L F
.6379 .36409 m .63261 .34556 L .63929 .3653 L .93 .547 .189 r
F
.6379 .36409 m .62982 .34312 L .63261 .34556 L F
.39633 .46206 m .40272 .45936 L .39967 .44818 L .098 .165 .645 r
F
.47758 .39234 m .46649 .37764 L .47836 .38696 L .877 .576 .475 r
F
.64901 .35391 m .64755 .32857 L .65078 .35547 L .973 .674 .388 r
F
.64901 .35391 m .64402 .3254 L .64755 .32857 L F
.58004 .40635 m .57212 .38984 L .57283 .38923 L .961 .657 .409 r
F
.58004 .40635 m .57153 .39074 L .57212 .38984 L .96 .659 .416 r
F
.58004 .40635 m .57107 .39191 L .57153 .39074 L .959 .661 .424 r
F
.58004 .40635 m .57075 .39334 L .57107 .39191 L .959 .663 .431 r
F
.58004 .40635 m .57056 .395 L .57075 .39334 L .958 .666 .438 r
F
.58004 .40635 m .57053 .39686 L .57056 .395 L .958 .669 .445 r
F
.58004 .40635 m .57064 .39889 L .57053 .39686 L .958 .672 .451 r
F
.58004 .40635 m .57089 .40106 L .57064 .39889 L .958 .675 .457 r
F
.58004 .40635 m .57129 .40332 L .57089 .40106 L .958 .678 .463 r
F
.58004 .40635 m .57181 .40565 L .57129 .40332 L .959 .682 .468 r
F
.58004 .40635 m .57247 .40799 L .57181 .40565 L .959 .685 .472 r
F
.58004 .40635 m .57323 .41031 L .57247 .40799 L .96 .688 .475 r
F
.039 .916 .04 r
.5321 .4217 m
.5727 .4087 L
s
.58004 .40635 m .5741 .41257 L .57323 .41031 L .961 .692 .478 r
F
.58004 .40635 m .57505 .41472 L .5741 .41257 L .963 .695 .48 r
F
.58004 .40635 m .57607 .41674 L .57505 .41472 L .964 .699 .481 r
F
.58004 .40635 m .57714 .41858 L .57607 .41674 L .966 .702 .481 r
F
.58004 .40635 m .57824 .42021 L .57714 .41858 L .968 .705 .481 r
F
.58004 .40635 m .57935 .42161 L .57824 .42021 L .97 .707 .479 r
F
.58004 .40635 m .58046 .42276 L .57935 .42161 L .971 .709 .477 r
F
.58004 .40635 m .58154 .42362 L .58046 .42276 L .973 .711 .474 r
F
.58004 .40635 m .58258 .42419 L .58154 .42362 L .975 .713 .47 r
F
.58004 .40635 m .58355 .42447 L .58258 .42419 L .977 .714 .465 r
F
.58004 .40635 m .58445 .42443 L .58355 .42447 L .978 .714 .459 r
F
.45931 .51713 m .4534 .51306 L .45364 .51066 L .964 .688 .462 r
F
.45931 .51713 m .45929 .51977 L .4534 .51306 L F
.50706 .46205 m .49875 .46919 L .50429 .45812 L .931 .736 .616 r
F
.50706 .46205 m .50246 .47443 L .49875 .46919 L F
.39477 .41591 m .39774 .40521 L .39463 .40624 L .548 .341 .551 r
F
0 g
.39463 .40624 m
.39525 .3974 L
s
.53235 .45034 m .52919 .46085 L .53017 .4477 L .969 .687 .442 r
F
.53235 .45034 m .53247 .46481 L .52919 .46085 L F
.58445 .42443 m .58502 .44325 L .58355 .42447 L .987 .767 .519 r
F
.40617 .4297 m .399 .42536 L .3981 .41507 L .962 .688 .467 r
F
.40754 .43864 m .399 .42536 L .40617 .4297 L F
.60713 .31923 m .59289 .29972 L .61065 .31943 L .825 .351 .06 r
F
.60713 .31923 m .58813 .29938 L .59289 .29972 L F
.25533 .54225 m .26439 .52343 L .24863 .52563 L .179 .295 .746 r
F
.25533 .54225 m .27253 .54364 L .26439 .52343 L F
.47869 .49986 m .4729 .50571 L .47393 .49434 L .965 .687 .457 r
F
.47869 .49986 m .47864 .51231 L .4729 .50571 L F
.48434 .51761 m .49523 .50719 L .47864 .51231 L .648 .78 .944 r
F
.48434 .51761 m .5009 .51251 L .49523 .50719 L F
0 g
.48434 .51761 m
.48992 .5215 L
s
.62462 .34053 m .61446 .32083 L .62714 .34143 L .882 .449 .118 r
F
.62462 .34053 m .61065 .31943 L .61446 .32083 L F
.68997 .46474 m .69793 .4985 L .68741 .46963 L .981 .698 .408 r
F
.67828 .43752 m .68997 .46474 L .68741 .46963 L .979 .694 .406 r
F
.67959 .43341 m .68997 .46474 L .67828 .43752 L .979 .693 .402 r
F
.56214 .37395 m .55214 .357 L .56357 .37276 L .904 .537 .328 r
F
.56214 .37395 m .54997 .35875 L .55214 .357 L F
.49563 .34545 m .48825 .33002 L .49199 .32512 L .969 .687 .442 r
F
.19984 .59044 m .19156 .5791 L .1903 .57091 L .769 .388 0 r
F
.19984 .59044 m .20314 .60281 L .19156 .5791 L F
.57212 .38984 m .56357 .37276 L .57283 .38923 L .936 .599 .37 r
F
.41802 .4001 m .417 .38947 L .41857 .39148 L .964 .688 .462 r
F
.4196 .40179 m .41802 .4001 L .41857 .39148 L F
.57212 .38984 m .56214 .37395 L .56357 .37276 L .936 .599 .37 r
F
.47122 .47785 m .4647 .48044 L .46761 .47195 L .965 .687 .457 r
F
.47122 .47785 m .46924 .48783 L .4647 .48044 L F
.45433 .50347 m .44891 .49875 L .44935 .49663 L .964 .688 .462 r
F
.45433 .50347 m .4541 .50586 L .44891 .49875 L F
.51555 .39952 m .50717 .3883 L .50781 .38354 L .969 .687 .442 r
F
.51542 .40308 m .50717 .3883 L .51555 .39952 L F
.39477 .41591 m .39788 .41489 L .39774 .40521 L .548 .341 .551 r
F
0 g
.39774 .40521 m
.39835 .39638 L
s
.48825 .4052 m .4773 .3984 L .47758 .39234 L .897 .61 .494 r
F
.48842 .41016 m .4773 .3984 L .48825 .4052 L .895 .621 .513 r
F
.72832 .4837 m .72766 .52152 L .72509 .49032 L .99 .804 .418 r
F
.72283 .45468 m .72832 .4837 L .72509 .49032 L .995 .779 .415 r
F
.72463 .44846 m .72832 .4837 L .72283 .45468 L .987 .765 .372 r
F
.23826 .49101 m .25178 .48134 L .24755 .4603 L .123 .141 .606 r
F
.2429 .50844 m .25178 .48134 L .23826 .49101 L .156 .203 .66 r
F
.42294 .41354 m .42119 .40348 L .42277 .40516 L .964 .688 .462 r
F
0 g
.42277 .40516 m
.42325 .3975 L
s
.50103 .36524 m .49563 .34545 L .50298 .36082 L .969 .687 .442 r
F
.50886 .37947 m .50103 .36524 L .50298 .36082 L F
.70653 .38376 m .71745 .40494 L .70683 .38723 L .979 .69 .318 r
F
.70683 .38723 m .71745 .40494 L .71759 .41129 L .982 .699 .335 r
F
.45525 .36182 m .48501 .33612 L .48803 .32955 L 0 0 0 r
F
0 g
.48803 .32955 m
.49179 .32463 L
s
.46649 .37764 m .45329 .3687 L .45525 .36182 L .858 .536 .442 r
F
.45329 .3687 m .48501 .33612 L .45525 .36182 L .109 0 .184 r
F
.43683 .37417 m .45329 .3687 L .45525 .36182 L .432 .106 .311 r
F
0 g
.45525 .36182 m
.4579 .35621 L
s
.45929 .51977 m .45317 .51547 L .4534 .51306 L .964 .688 .462 r
F
.45929 .51977 m .45926 .5224 L .45317 .51547 L F
0 g
.45926 .5224 m
.46533 .52794 L
s
.50781 .38354 m .50103 .36524 L .50886 .37947 L .969 .687 .442 r
F
.65375 .38276 m .664 .38081 L .66512 .38478 L .975 .682 .397 r
F
.65375 .38276 m .6627 .37688 L .664 .38081 L F
.65375 .38276 m .66125 .37304 L .6627 .37688 L .975 .681 .397 r
F
.4224 .48344 m .41388 .47999 L .41853 .47502 L .962 .688 .467 r
F
.4224 .48344 m .41855 .49013 L .41388 .47999 L F
.58355 .42447 m .58307 .44274 L .58258 .42419 L .982 .764 .533 r
F
.58355 .42447 m .58502 .44325 L .58307 .44274 L F
.65375 .38276 m .66512 .38478 L .66604 .38872 L .975 .682 .398 r
F
.57493 .50418 m .55883 .52536 L .57001 .50311 L .936 .916 .771 r
F
.58112 .48301 m .57493 .50418 L .57001 .50311 L .959 .883 .713 r
F
.36665 .52695 m .4153 .49132 L .36042 .51557 L .717 .658 .79 r
F
.36665 .52695 m .42039 .50079 L .4153 .49132 L F
0 g
.36665 .52695 m
.37326 .53723 L
s
.29165 .58042 m .36665 .52695 L .36041 .51557 L .792 .684 .746 r
F
.30224 .59628 m .36665 .52695 L .29165 .58042 L .803 .711 .763 r
F
0 g
.36665 .52695 m
.37326 .53724 L
s
.30224 .59628 m
.31324 .61007 L
s
.65375 .38276 m .65967 .36937 L .66125 .37304 L .975 .681 .397 r
F
.24863 .52563 m .25743 .50252 L .2429 .50844 L .175 .254 .706 r
F
.24863 .52563 m .26439 .52343 L .25743 .50252 L F
.45006 .41396 m .44268 .40764 L .44247 .39936 L .965 .687 .457 r
F
.45074 .42102 m .44268 .40764 L .45006 .41396 L F
.50608 .49727 m .49523 .50719 L .50138 .4928 L .926 .783 .683 r
F
.50608 .49727 m .5009 .51251 L .49523 .50719 L F
.65188 .40651 m .65766 .42761 L .6566 .43081 L .994 .761 .402 r
F
.65224 .40459 m .65766 .42761 L .65188 .40651 L .988 .748 .366 r
F
.4429 .39179 m .43554 .38222 L .43683 .37417 L .965 .687 .457 r
F
.44247 .39936 m .43554 .38222 L .4429 .39179 L F
.17799 .45922 m .16434 .44742 L .16319 .42307 L .987 .724 .43 r
F
.18062 .48031 m .16434 .44742 L .17799 .45922 L .985 .712 .41 r
F
.41643 .39841 m .41544 .38746 L .417 .38947 L .964 .688 .462 r
F
.41802 .4001 m .41643 .39841 L .417 .38947 L F
.53017 .4477 m .52595 .4562 L .52802 .4446 L .969 .687 .442 r
F
.53017 .4477 m .52919 .46085 L .52595 .4562 L F
.57153 .39074 m .56214 .37395 L .57212 .38984 L .933 .605 .393 r
F
.2429 .50844 m .25743 .50252 L .25178 .48134 L .156 .203 .66 r
F
.64295 .38621 m .64968 .38511 L .65056 .38821 L .976 .673 .335 r
F
.64295 .38621 m .64867 .38203 L .64968 .38511 L .975 .668 .33 r
F
.16481 .48551 m .16057 .47527 L .15744 .44973 L .845 .608 .064 r
F
.169 .50711 m .16057 .47527 L .16481 .48551 L .81 .546 0 r
F
.40754 .43864 m .40064 .43613 L .399 .42536 L .962 .688 .467 r
F
.4095 .44781 m .40064 .43613 L .40754 .43864 L F
.64295 .38621 m .64753 .37902 L .64867 .38203 L .974 .663 .326 r
F
.65375 .38276 m .66604 .38872 L .66676 .39256 L .975 .683 .398 r
F
.50622 .47889 m .49666 .48725 L .50246 .47443 L .927 .757 .651 r
F
.50622 .47889 m .50138 .4928 L .49666 .48725 L F
.4541 .50586 m .44848 .50088 L .44891 .49875 L .964 .688 .462 r
F
.4541 .50586 m .45387 .50826 L .44848 .50088 L F
.54863 .50574 m .54585 .51981 L .54353 .50327 L .969 .687 .442 r
F
.54863 .50574 m .55197 .52271 L .54585 .51981 L F
.50429 .45812 m .49516 .46325 L .50161 .45367 L .924 .723 .614 r
F
.50429 .45812 m .49875 .46919 L .49516 .46325 L F
.59257 .20158 m .60253 .1981 L .61155 .19955 L .506 .901 .938 r
F
.6229 .22474 m .61155 .19955 L .63031 .22578 L .872 .431 .119 r
F
.6229 .22474 m .60253 .1981 L .61155 .19955 L F
0 g
.61155 .19955 m
.62123 .20403 L
s
.64295 .38621 m .65056 .38821 L .65128 .3913 L .978 .678 .341 r
F
.69187 .34476 m .69135 .32559 L .69367 .34723 L .959 .619 .265 r
F
.69187 .34476 m .68778 .32064 L .69135 .32559 L F
.42136 .41221 m .4196 .40179 L .42119 .40348 L .964 .688 .462 r
F
.42294 .41354 m .42136 .41221 L .42119 .40348 L F
.63663 .51877 m .61966 .54979 L .61267 .55084 L .918 .975 .772 r
F
0 g
.61966 .54979 m
.62584 .54634 L
s
.64295 .38621 m .64629 .37615 L .64753 .37902 L .972 .659 .325 r
F
.65375 .38276 m .65799 .36593 L .65967 .36937 L .975 .681 .397 r
F
.7165 .42192 m .72463 .44846 L .72283 .45468 L .991 .744 .381 r
F
.71727 .41698 m .72463 .44846 L .7165 .42192 L .986 .732 .35 r
F
.43554 .38222 m .45329 .3687 L .43683 .37417 L .485 .206 .415 r
F
0 g
.43683 .37417 m
.43884 .36728 L
s
.66688 .40816 m .67959 .43341 L .67828 .43752 L .977 .689 .403 r
F
.66732 .4057 m .67959 .43341 L .66688 .40816 L .977 .688 .4 r
F
.58502 .44325 m .58138 .46201 L .58307 .44274 L .981 .808 .596 r
F
.58502 .44325 m .58431 .46274 L .58138 .46201 L F
.58382 .30067 m .56427 .28129 L .58813 .29938 L .764 .27 .052 r
F
.58382 .30067 m .55878 .2828 L .56427 .28129 L F
.42577 .50937 m .42352 .49981 L .42039 .50079 L .646 .659 .848 r
F
.42577 .50937 m .42889 .50839 L .42352 .49981 L F
0 g
.42577 .50937 m
.43133 .51691 L
s
.42889 .50839 m
.43446 .51594 L
s
.49614 .31887 m .52048 .27168 L .52647 .26752 L .867 .974 .663 r
F
.49225 .32397 m .52048 .27168 L .49614 .31887 L .763 .897 .497 r
F
.51454 .33523 m .49614 .31887 L .5177 .33095 L .767 .354 .268 r
F
.51454 .33523 m .49225 .32397 L .49614 .31887 L F
0 g
.49614 .31887 m
.50071 .31556 L
s
.58112 .48301 m .57001 .50311 L .5772 .48209 L .959 .883 .713 r
F
.58431 .46274 m .58112 .48301 L .5772 .48209 L .974 .847 .655 r
F
.51542 .40308 m .50697 .39364 L .50717 .3883 L .969 .687 .442 r
F
.51558 .40697 m .50697 .39364 L .51542 .40308 L F
.64295 .38621 m .65128 .3913 L .65183 .3943 L .979 .683 .349 r
F
.58258 .42419 m .581 .44161 L .58154 .42362 L .976 .759 .545 r
F
.58258 .42419 m .58307 .44274 L .581 .44161 L F
.58431 .46274 m .5772 .48209 L .58138 .46201 L .974 .847 .655 r
F
.48842 .41016 m .47751 .40503 L .4773 .3984 L .895 .621 .513 r
F
.48897 .41546 m .47751 .40503 L .48842 .41016 L .895 .631 .531 r
F
.69793 .4985 m .70295 .53343 L .69375 .50324 L .982 .704 .415 r
F
.68741 .46963 m .69793 .4985 L .69375 .50324 L .98 .7 .413 r
F
.64295 .38621 m .64497 .37346 L .64629 .37615 L .971 .655 .324 r
F
.63744 .322 m .63369 .29384 L .64063 .3232 L .971 .669 .384 r
F
.63744 .322 m .62888 .29194 L .63369 .29384 L F
.15632 .4254 m .16405 .40041 L .15722 .40275 L .538 .326 .541 r
F
0 g
.15722 .40275 m
.16006 .3822 L
s
.41853 .47502 m .40968 .46932 L .41505 .46617 L .962 .688 .467 r
F
.41853 .47502 m .41388 .47999 L .40968 .46932 L F
.65375 .38276 m .66676 .39256 L .66725 .39624 L .975 .683 .399 r
F
.6141 .26144 m .61099 .23244 L .62006 .26208 L .968 .658 .374 r
F
.6141 .26144 m .60347 .23144 L .61099 .23244 L F
.33677 .43701 m .39566 .42625 L .39477 .41591 L .657 .455 .598 r
F
.33866 .45009 m .39566 .42625 L .33677 .43701 L .667 .487 .633 r
F
0 g
.33581 .42451 m
.33677 .43701 L
s
.24755 .4603 m .33676 .43701 L .24482 .43981 L .749 .545 .619 r
F
.24755 .4603 m .33866 .4501 L .33676 .43701 L F
0 g
.33581 .42453 m
.33676 .43701 L
s
.44978 .49452 m .44453 .48887 L .44517 .48706 L .964 .688 .462 r
F
.44978 .49452 m .44935 .49663 L .44453 .48887 L F
0 g
.44978 .49452 m
.45456 .50108 L
s
.63656 .36326 m .62982 .34312 L .6379 .36409 L .932 .553 .219 r
F
.63656 .36326 m .62714 .34143 L .62982 .34312 L F
.46761 .47195 m .4604 .47229 L .46418 .46545 L .965 .687 .457 r
F
.46761 .47195 m .4647 .48044 L .4604 .47229 L F
.41484 .39672 m .41387 .38544 L .41544 .38746 L .964 .688 .462 r
F
.41643 .39841 m .41484 .39672 L .41544 .38746 L F
.57153 .39074 m .56095 .37573 L .56214 .37395 L .933 .605 .393 r
F
.57107 .39191 m .56095 .37573 L .57153 .39074 L .931 .612 .414 r
F
.64295 .38621 m .65183 .3943 L .65221 .39718 L .981 .688 .357 r
F
.53574 .46802 m .5326 .4794 L .53247 .46481 L .969 .687 .442 r
F
.53574 .46802 m .53697 .48364 L .5326 .4794 L F
.4095 .44781 m .403 .44719 L .40064 .43613 L .962 .688 .467 r
F
.41202 .45704 m .403 .44719 L .4095 .44781 L F
.65375 .38276 m .65623 .36276 L .65799 .36593 L .975 .68 .397 r
F
.47758 .39234 m .46548 .38436 L .46649 .37764 L .877 .576 .475 r
F
.4773 .3984 m .46548 .38436 L .47758 .39234 L .875 .589 .501 r
F
.45387 .50826 m .44804 .503 L .44848 .50088 L .964 .688 .462 r
F
.45387 .50826 m .45364 .51066 L .44804 .503 L F
0 g
.24363 .42028 m
.24399 .40206 L
s
.56095 .37573 m .54997 .35875 L .56214 .37395 L .902 .55 .367 r
F
.65638 .45818 m .65024 .48775 L .6538 .46084 L .98 .888 .535 r
F
.65519 .43329 m .65638 .45818 L .6538 .46084 L .999 .835 .502 r
F
.6566 .43081 m .65638 .45818 L .65519 .43329 L .991 .823 .448 r
F
.46548 .38436 m .45329 .3687 L .46649 .37764 L .855 .553 .476 r
F
.64295 .38621 m .64358 .37098 L .64497 .37346 L .97 .652 .325 r
F
.52802 .4446 m .52281 .45094 L .52594 .4411 L .969 .687 .442 r
F
.52802 .4446 m .52595 .4562 L .52281 .45094 L F
.72766 .52152 m .72195 .5607 L .72262 .52762 L .992 .844 .483 r
F
.72509 .49032 m .72766 .52152 L .72262 .52762 L .998 .817 .469 r
F
.41978 .41088 m .41802 .4001 L .4196 .40179 L .964 .688 .462 r
F
.42136 .41221 m .41978 .41088 L .4196 .40179 L F
.41505 .46617 m .40603 .45832 L .41202 .45704 L .962 .688 .467 r
F
.41505 .46617 m .40968 .46932 L .40603 .45832 L F
.39566 .42625 m .39788 .41489 L .39477 .41591 L .568 .389 .598 r
F
0 g
.39463 .40624 m
.39477 .41591 L
s
.45074 .42102 m .44352 .4165 L .44268 .40764 L .965 .687 .457 r
F
.45191 .42841 m .44352 .4165 L .45074 .42102 L F
.41202 .45704 m .40603 .45832 L .403 .44719 L .962 .688 .467 r
F
.50161 .45367 m .49175 .45672 L .49907 .44879 L .917 .711 .609 r
F
.50161 .45367 m .49516 .46325 L .49175 .45672 L F
.64732 .35284 m .64402 .3254 L .64901 .35391 L .973 .674 .39 r
F
.64732 .35284 m .64063 .3232 L .64402 .3254 L F
.65375 .38276 m .66725 .39624 L .66751 .39969 L .975 .683 .4 r
F
.1903 .57091 m .18131 .55396 L .18187 .55024 L .762 .411 0 r
F
.1903 .57091 m .19156 .5791 L .18131 .55396 L F
.54122 .4868 m .5382 .49936 L .53697 .48364 L .969 .687 .442 r
F
.54122 .4868 m .54353 .50327 L .5382 .49936 L F
.58154 .42362 m .57883 .4399 L .58046 .42276 L .97 .753 .554 r
F
.58154 .42362 m .581 .44161 L .57883 .4399 L F
.53284 .34782 m .5177 .33095 L .53532 .34436 L .821 .428 .307 r
F
.53284 .34782 m .51454 .33523 L .5177 .33095 L F
.64295 .38621 m .65221 .39718 L .65241 .39989 L .982 .694 .367 r
F
.51558 .40697 m .5072 .39949 L .50697 .39364 L .969 .687 .442 r
F
.51603 .41112 m .5072 .39949 L .51558 .40697 L F
.039 .916 .04 r
.49068 .40687 m
.5085 .4012 L
s
.42376 .42249 m .42136 .41221 L .42294 .41354 L .964 .688 .462 r
F
0 g
.42277 .40516 m
.42294 .41354 L
s
.47393 .49434 m .46725 .49789 L .46924 .48783 L .965 .687 .457 r
F
.47393 .49434 m .4729 .50571 L .46725 .49789 L F
.66162 .28098 m .65329 .25568 L .66632 .28293 L .92 .526 .192 r
F
.66162 .28098 m .64697 .25294 L .65329 .25568 L F
.70689 .39041 m .71759 .41129 L .71727 .41698 L .985 .706 .352 r
F
.70683 .38723 m .71759 .41129 L .70689 .39041 L .982 .699 .335 r
F
.41484 .39672 m .41324 .39502 L .41387 .38544 L .964 .688 .462 r
F
0 g
.41387 .38544 m
.41529 .37695 L
s
.54815 .36139 m .53532 .34436 L .54997 .35875 L .865 .492 .339 r
F
.56095 .37573 m .54815 .36139 L .54997 .35875 L .902 .55 .367 r
F
.48897 .41546 m .47823 .41211 L .47751 .40503 L .895 .631 .531 r
F
.48987 .42099 m .47823 .41211 L .48897 .41546 L .895 .642 .547 r
F
.44935 .49663 m .4439 .49067 L .44453 .48887 L .964 .688 .462 r
F
.44935 .49663 m .44891 .49875 L .4439 .49067 L F
.65375 .38276 m .65442 .35993 L .65623 .36276 L .975 .68 .397 r
F
.49316 .35093 m .48825 .33002 L .49563 .34545 L .969 .687 .442 r
F
.50103 .36524 m .49316 .35093 L .49563 .34545 L F
.57107 .39191 m .56001 .37806 L .56095 .37573 L .931 .612 .414 r
F
.57075 .39334 m .56001 .37806 L .57107 .39191 L .929 .619 .435 r
F
.64295 .38621 m .64216 .36878 L .64358 .37098 L .969 .65 .328 r
F
.50781 .38354 m .4996 .37066 L .50103 .36524 L .969 .687 .442 r
F
.50717 .3883 m .4996 .37066 L .50781 .38354 L F
.65024 .48775 m .63663 .51877 L .6462 .48982 L .959 .944 .65 r
F
.6538 .46084 m .65024 .48775 L .6462 .48982 L .989 .893 .598 r
F
.54815 .36139 m .53284 .34782 L .53532 .34436 L .865 .492 .339 r
F
.5009 .51251 m .53286 .50933 L .49523 .50719 L .408 .68 .972 r
F
.5009 .51251 m .53948 .51566 L .53286 .50933 L F
0 g
.5009 .51251 m
.50643 .51642 L
s
.39566 .42625 m .39878 .42523 L .39788 .41489 L .568 .389 .598 r
F
0 g
.39774 .40521 m
.39788 .41489 L
s
.45364 .51066 m .4476 .50513 L .44804 .503 L .964 .688 .462 r
F
.45364 .51066 m .4534 .51306 L .4476 .50513 L F
.15632 .4254 m .16319 .42307 L .16405 .40041 L .538 .326 .541 r
F
0 g
.16405 .40041 m
.16686 .37985 L
s
.67745 .31106 m .67131 .28639 L .68077 .31331 L .94 .571 .229 r
F
.67745 .31106 m .66632 .28293 L .67131 .28639 L F
.36042 .51557 m .41061 .48114 L .35468 .5033 L .708 .629 .766 r
F
.36042 .51557 m .4153 .49132 L .41061 .48114 L F
0 g
.36042 .51557 m
.36665 .52695 L
s
.28167 .56276 m .36041 .51557 L .35467 .5033 L .782 .659 .728 r
F
.29165 .58042 m .36041 .51557 L .28167 .56276 L .792 .684 .746 r
F
0 g
.36041 .51557 m
.36665 .52695 L
s
.21572 .58551 m .19852 .57692 L .2062 .56592 L .968 .65 .348 r
F
.21572 .58551 m .2101 .60067 L .19852 .57692 L F
.46418 .46545 m .45641 .46354 L .46101 .45848 L .965 .687 .457 r
F
.46418 .46545 m .4604 .47229 L .45641 .46354 L F
.52594 .4411 m .51982 .44516 L .52396 .43726 L .969 .687 .442 r
F
.52594 .4411 m .52281 .45094 L .51982 .44516 L F
.169 .50711 m .16565 .50151 L .16057 .47527 L .81 .546 0 r
F
.17472 .52883 m .16565 .50151 L .169 .50711 L .783 .491 0 r
F
.4182 .40954 m .41643 .39841 L .41802 .4001 L .964 .688 .462 r
F
.41978 .41088 m .4182 .40954 L .41802 .4001 L F
.58307 .44274 m .57825 .46037 L .581 .44161 L .971 .797 .611 r
F
.58307 .44274 m .58138 .46201 L .57825 .46037 L F
.65134 .40809 m .6566 .43081 L .65519 .43329 L .997 .77 .436 r
F
.65188 .40651 m .6566 .43081 L .65134 .40809 L .994 .761 .402 r
F
0 g
.54592 .52031 m
.55207 .52323 L
s
.49907 .44879 m .48858 .44971 L .49671 .44355 L .911 .699 .603 r
F
.49907 .44879 m .49175 .45672 L .48858 .44971 L F
.64295 .38621 m .65241 .39989 L .65242 .40237 L .983 .698 .376 r
F
.039 .916 .04 r
.58812 .41745 m
.65069 .39942 L
s
.65185 .39909 m
.65194 .39906 L
s
.58046 .42276 m .5766 .43763 L .57935 .42161 L .964 .746 .56 r
F
.58046 .42276 m .57883 .4399 L .5766 .43763 L F
.50246 .47443 m .49199 .48071 L .49875 .46919 L .917 .741 .649 r
F
.50246 .47443 m .49666 .48725 L .49199 .48071 L F
.65375 .38276 m .66751 .39969 L .66754 .40286 L .976 .684 .4 r
F
.51603 .41112 m .50786 .40574 L .5072 .39949 L .969 .687 .442 r
F
.51675 .41546 m .50786 .40574 L .51603 .41112 L F
.45191 .42841 m .44499 .42577 L .44352 .4165 L .965 .687 .457 r
F
.45356 .43598 m .44499 .42577 L .45191 .42841 L F
.6223 .34045 m .61065 .31943 L .62462 .34053 L .891 .471 .181 r
F
.6223 .34045 m .60713 .31923 L .61065 .31943 L F
.48987 .42099 m .47943 .41951 L .47823 .41211 L .895 .642 .547 r
F
.49113 .42667 m .47943 .41951 L .48987 .42099 L .897 .653 .561 r
F
.69009 .34272 m .68778 .32064 L .69187 .34476 L .959 .619 .274 r
F
.69009 .34272 m .68423 .31652 L .68778 .32064 L F
.44247 .39936 m .43501 .39131 L .43554 .38222 L .965 .687 .457 r
F
.44268 .40764 m .43501 .39131 L .44247 .39936 L F
.47864 .51231 m .48953 .50055 L .4729 .50571 L .652 .735 .911 r
F
.47864 .51231 m .49523 .50719 L .48953 .50055 L F
0 g
.47864 .51231 m
.48434 .51761 L
s
.64295 .38621 m .64072 .36687 L .64216 .36878 L .968 .648 .332 r
F
.57075 .39334 m .55935 .3809 L .56001 .37806 L .929 .619 .435 r
F
.57056 .395 m .55935 .3809 L .57075 .39334 L .927 .626 .453 r
F
.42222 .42154 m .41978 .41088 L .42136 .41221 L .964 .688 .462 r
F
.42376 .42249 m .42222 .42154 L .42136 .41221 L F
.33866 .45009 m .39731 .43707 L .39566 .42625 L .667 .487 .633 r
F
.34146 .46352 m .39731 .43707 L .33866 .45009 L .675 .517 .663 r
F
0 g
.33677 .43701 m
.33866 .45009 L
s
.25178 .48134 m .33866 .4501 L .24755 .4603 L .754 .568 .644 r
F
.25178 .48134 m .34145 .46352 L .33866 .4501 L F
0 g
.33676 .43701 m
.33866 .4501 L
s
.4996 .37066 m .49316 .35093 L .50103 .36524 L .969 .687 .442 r
F
.42039 .50079 m .41844 .49034 L .4153 .49132 L .641 .625 .818 r
F
.42039 .50079 m .42352 .49981 L .41844 .49034 L F
0 g
.42039 .50079 m
.42577 .50937 L
s
.42352 .49981 m
.42889 .50839 L
s
.44891 .49875 m .44327 .49248 L .4439 .49067 L .964 .688 .462 r
F
.44891 .49875 m .44848 .50088 L .44327 .49248 L F
.44517 .48706 m .43998 .4803 L .44079 .47885 L F
.44517 .48706 m .44453 .48887 L .43998 .4803 L F
0 g
.44517 .48706 m
.44978 .49452 L
s
.65375 .38276 m .65259 .35749 L .65442 .35993 L .974 .68 .397 r
F
.18187 .55024 m .17261 .52793 L .17472 .52883 L .766 .445 0 r
F
.18187 .55024 m .18131 .55396 L .17261 .52793 L F
.52396 .43726 m .51705 .43896 L .52212 .43314 L .969 .687 .442 r
F
.52396 .43726 m .51982 .44516 L .51705 .43896 L F
.4534 .51306 m .44716 .50727 L .4476 .50513 L .964 .688 .462 r
F
.4534 .51306 m .45317 .51547 L .44716 .50727 L F
0 g
.45317 .51547 m
.45926 .5224 L
s
.56001 .37806 m .54815 .36139 L .56095 .37573 L .898 .563 .402 r
F
.49671 .44355 m .48572 .44235 L .49458 .43805 L .906 .687 .595 r
F
.49671 .44355 m .48858 .44971 L .48572 .44235 L F
.46101 .45848 m .45282 .45434 L .45815 .45116 L .965 .687 .457 r
F
.46101 .45848 m .45641 .46354 L .45282 .45434 L F
.50138 .4928 m .48953 .50055 L .49666 .48725 L .913 .764 .681 r
F
.50138 .4928 m .49523 .50719 L .48953 .50055 L F
.17472 .52883 m .17261 .52793 L .16565 .50151 L .783 .491 0 r
F
.51675 .41546 m .50895 .41228 L .50786 .40574 L .969 .687 .442 r
F
.51774 .41991 m .50895 .41228 L .51675 .41546 L F
.57935 .42161 m .57437 .43484 L .57824 .42021 L .958 .738 .563 r
F
.57935 .42161 m .5766 .43763 L .57437 .43484 L F
.62444 .29158 m .62006 .26208 L .62888 .29194 L .969 .663 .381 r
F
.62444 .29158 m .6141 .26144 L .62006 .26208 L F
.49113 .42667 m .4811 .42712 L .47943 .41951 L .897 .653 .561 r
F
.4927 .43239 m .4811 .42712 L .49113 .42667 L .899 .664 .574 r
F
.41662 .4082 m .41484 .39672 L .41643 .39841 L .964 .688 .462 r
F
.4182 .40954 m .41662 .4082 L .41643 .39841 L F
.18485 .50195 m .16749 .47298 L .18062 .48031 L .983 .699 .392 r
F
.18062 .48031 m .16749 .47298 L .16434 .44742 L .985 .712 .41 r
F
.4773 .3984 m .4651 .39194 L .46548 .38436 L .875 .589 .501 r
F
.47751 .40503 m .4651 .39194 L .4773 .3984 L .874 .602 .524 r
F
.039 .916 .04 r
.47568 .39754 m
.47575 .39752 L
s
.44876 .40614 m
.47164 .39883 L
s
.63531 .36283 m .62714 .34143 L .63656 .36326 L .934 .56 .25 r
F
.63531 .36283 m .62462 .34053 L .62714 .34143 L F
.53247 .46481 m .52821 .47412 L .52919 .46085 L .969 .687 .442 r
F
.53247 .46481 m .5326 .4794 L .52821 .47412 L F
.64295 .38621 m .65242 .40237 L .65224 .40459 L .984 .703 .387 r
F
.45356 .43598 m .44705 .43528 L .44499 .42577 L .965 .687 .457 r
F
.45565 .44361 m .44705 .43528 L .45356 .43598 L F
.55395 .28635 m .52647 .26752 L .55878 .2828 L .695 .207 .087 r
F
.55395 .28635 m .52048 .27168 L .52647 .26752 L F
0 g
.52647 .26752 m
.53324 .26581 L
s
.67828 .43752 m .68741 .46963 L .67653 .44071 L .979 .694 .406 r
F
.66621 .41019 m .67828 .43752 L .67653 .44071 L .977 .689 .405 r
F
.66688 .40816 m .67828 .43752 L .66621 .41019 L .977 .689 .403 r
F
.49458 .43805 m .48321 .43478 L .4927 .43239 L .902 .675 .585 r
F
.49458 .43805 m .48572 .44235 L .48321 .43478 L F
.57056 .395 m .55896 .38422 L .55935 .3809 L .927 .626 .453 r
F
.57053 .39686 m .55896 .38422 L .57056 .395 L .926 .634 .471 r
F
.52212 .43314 m .51453 .43246 L .52045 .42883 L .969 .687 .442 r
F
.52212 .43314 m .51705 .43896 L .51453 .43246 L F
.4927 .43239 m .48321 .43478 L .4811 .42712 L .899 .664 .574 r
F
.45329 .3687 m .48278 .34423 L .48501 .33612 L .109 0 .184 r
F
.46548 .38436 m .45205 .37676 L .45329 .3687 L .855 .553 .476 r
F
.45205 .37676 m .48278 .34423 L .45329 .3687 L .228 0 .336 r
F
.43554 .38222 m .45205 .37676 L .45329 .3687 L .485 .206 .415 r
F
0 g
.45329 .3687 m
.45525 .36182 L
s
.58138 .46201 m .57301 .47996 L .57825 .46037 L .96 .829 .67 r
F
.58138 .46201 m .5772 .48209 L .57301 .47996 L F
.45815 .45116 m .44968 .44487 L .45565 .44361 L .965 .687 .457 r
F
.45815 .45116 m .45282 .45434 L .44968 .44487 L F
.42522 .43186 m .42222 .42154 L .42376 .42249 L .964 .688 .462 r
F
0 g
.42294 .41354 m
.42376 .42249 L
s
.51774 .41991 m .51044 .419 L .50895 .41228 L .969 .687 .442 r
F
.51898 .42439 m .51044 .419 L .51774 .41991 L F
.39731 .43707 m .39878 .42523 L .39566 .42625 L .584 .43 .638 r
F
0 g
.39477 .41591 m
.39566 .42625 L
s
.45565 .44361 m .44968 .44487 L .44705 .43528 L .965 .687 .457 r
F
.65375 .38276 m .66754 .40286 L .66732 .4057 L .976 .684 .401 r
F
.64295 .38621 m .63929 .3653 L .64072 .36687 L .967 .647 .337 r
F
.68741 .46963 m .69375 .50324 L .68422 .47308 L .98 .7 .413 r
F
.67653 .44071 m .68741 .46963 L .68422 .47308 L .979 .695 .41 r
F
.35468 .5033 m .40639 .47042 L .34954 .49037 L .7 .601 .742 r
F
.35468 .5033 m .41061 .48114 L .40639 .47042 L F
0 g
.35468 .5033 m
.36042 .51557 L
s
.27253 .54364 m .35467 .5033 L .34953 .49037 L .774 .636 .709 r
F
.28167 .56276 m .35467 .5033 L .27253 .54364 L .782 .659 .728 r
F
0 g
.35467 .5033 m
.36041 .51557 L
s
.039 .916 .04 r
.47575 .39752 m
.47602 .39743 L
s
.52045 .42883 m .51231 .42576 L .51898 .42439 L .969 .687 .442 r
F
.52045 .42883 m .51453 .43246 L .51231 .42576 L F
.51898 .42439 m .51231 .42576 L .51044 .419 L F
.42067 .42059 m .4182 .40954 L .41978 .41088 L .964 .688 .462 r
F
.42222 .42154 m .42067 .42059 L .41978 .41088 L F
.57824 .42021 m .57215 .43157 L .57714 .41858 L .952 .729 .565 r
F
.57824 .42021 m .57437 .43484 L .57215 .43157 L F
.60396 .32026 m .58813 .29938 L .60713 .31923 L .841 .394 .156 r
F
.60396 .32026 m .58382 .30067 L .58813 .29938 L F
.44848 .50088 m .44263 .49429 L .44327 .49248 L .964 .688 .462 r
F
.44848 .50088 m .44804 .503 L .44263 .49429 L F
.55883 .52536 m .59664 .54548 L .55247 .52234 L .359 0 0 r
F
.55883 .52536 m .60495 .5494 L .59664 .54548 L F
.57001 .50311 m .55883 .52536 L .55247 .52234 L .918 .88 .781 r
F
0 g
.55883 .52536 m
.56478 .52653 L
s
.44453 .48887 m .43915 .48176 L .43998 .4803 L .964 .688 .462 r
F
.44453 .48887 m .4439 .49067 L .43915 .48176 L F
.43501 .39131 m .45205 .37676 L .43554 .38222 L .521 .281 .492 r
F
0 g
.43554 .38222 m
.43683 .37417 L
s
.50717 .3883 m .49873 .37699 L .4996 .37066 L .969 .687 .442 r
F
.50697 .39364 m .49873 .37699 L .50717 .3883 L F
.581 .44161 m .57499 .45784 L .57883 .4399 L .96 .784 .62 r
F
.581 .44161 m .57825 .46037 L .57499 .45784 L F
.65375 .38276 m .65078 .35547 L .65259 .35749 L .974 .68 .397 r
F
.34146 .46352 m .39967 .44818 L .39731 .43707 L .675 .517 .663 r
F
.3451 .47703 m .39967 .44818 L .34146 .46352 L .683 .546 .691 r
F
0 g
.33866 .45009 m
.34146 .46352 L
s
.25743 .50252 m .34145 .46352 L .25178 .48134 L .76 .591 .667 r
F
.25743 .50252 m .3451 .47703 L .34145 .46352 L F
0 g
.33866 .4501 m
.34145 .46352 L
s
.57053 .39686 m .55888 .38794 L .55896 .38422 L .926 .634 .471 r
F
.57064 .39889 m .55888 .38794 L .57053 .39686 L .925 .642 .487 r
F
.039 .916 .04 r
.56935 .39596 m
.56944 .39593 L
s
.52237 .41084 m
.56796 .3964 L
s
.46924 .48783 m .46177 .489 L .4647 .48044 L .965 .687 .457 r
F
.46924 .48783 m .46725 .49789 L .46177 .489 L F
.41503 .40686 m .41324 .39502 L .41484 .39672 L .964 .688 .462 r
F
.41662 .4082 m .41503 .40686 L .41484 .39672 L F
.39731 .43707 m .40043 .43606 L .39878 .42523 L .584 .43 .638 r
F
0 g
.39788 .41489 m
.39878 .42523 L
s
.4651 .39194 m .45205 .37676 L .46548 .38436 L .853 .568 .506 r
F
.64295 .38621 m .65224 .40459 L .65188 .40651 L .985 .707 .397 r
F
.039 .916 .04 r
.65194 .39906 m
.66157 .39598 L
s
.5772 .48209 m .56475 .50052 L .57301 .47996 L .943 .856 .726 r
F
.5772 .48209 m .57001 .50311 L .56475 .50052 L F
.70672 .39325 m .71727 .41698 L .7165 .42192 L .987 .713 .369 r
F
.039 .916 .04 r
.67385 .40766 m
.70798 .39694 L
s
.70689 .39041 m .71727 .41698 L .70672 .39325 L .985 .706 .352 r
F
.039 .916 .04 r
.71198 .39568 m
.71213 .39563 L
s
.71213 .39563 m
.71215 .39562 L
s
.71191 .3957 m
.71198 .39568 L
s
.49316 .35093 m .48525 .33655 L .48825 .33002 L .969 .687 .442 r
F
.64112 .25226 m .63031 .22578 L .64697 .25294 L .901 .488 .179 r
F
.64112 .25226 m .6229 .22474 L .63031 .22578 L F
0 g
.29165 .58042 m
.30224 .59628 L
s
.70295 .53343 m .71184 .56364 L .70455 .56824 L .983 .71 .426 r
F
.71184 .56364 m .71473 .56528 L .70455 .56824 L 0 0 0 r
F
.71184 .56364 m .72195 .5607 L .71473 .56528 L F
0 g
.71184 .56364 m
.71795 .55609 L
s
.63663 .51877 m .61267 .55084 L .63087 .51948 L .918 .975 .772 r
F
.6462 .48982 m .63663 .51877 L .63087 .51948 L .963 .932 .706 r
F
0 g
.48501 .33612 m
.48803 .32955 L
s
.49875 .46919 m .48748 .47328 L .49516 .46325 L .908 .726 .644 r
F
.49875 .46919 m .49199 .48071 L .48748 .47328 L F
.57001 .50311 m .55247 .52234 L .56475 .50052 L .918 .88 .781 r
F
.57714 .41858 m .57 .42788 L .57607 .41674 L .946 .72 .564 r
F
.57714 .41858 m .57215 .43157 L .57 .42788 L F
.54353 .50327 m .53944 .51518 L .5382 .49936 L .969 .687 .442 r
F
.54353 .50327 m .54585 .51981 L .53944 .51518 L F
.44079 .47885 m .43576 .47109 L .43675 .47001 L .964 .688 .462 r
F
.44079 .47885 m .43998 .4803 L .43576 .47109 L F
0 g
.44079 .47885 m
.44517 .48706 L
s
.34954 .49037 m .40272 .45936 L .3451 .47703 L .692 .573 .717 r
F
.34954 .49037 m .40639 .47042 L .40272 .45936 L F
0 g
.34954 .49037 m
.35468 .5033 L
s
.26439 .52343 m .34953 .49037 L .3451 .47703 L .766 .613 .689 r
F
.27253 .54364 m .34953 .49037 L .26439 .52343 L .774 .636 .709 r
F
0 g
.34953 .49037 m
.35467 .5033 L
s
.54671 .36486 m .53284 .34782 L .54815 .36139 L .862 .513 .388 r
F
.56001 .37806 m .54671 .36486 L .54815 .36139 L .898 .563 .402 r
F
.64573 .35228 m .64063 .3232 L .64732 .35284 L .973 .674 .391 r
F
.64573 .35228 m .63744 .322 L .64063 .3232 L F
.2062 .56592 m .18827 .55176 L .19776 .54519 L .972 .662 .354 r
F
.2062 .56592 m .19852 .57692 L .18827 .55176 L F
.64295 .38621 m .6379 .36409 L .63929 .3653 L .966 .646 .343 r
F
.57064 .39889 m .55909 .39202 L .55888 .38794 L .925 .642 .487 r
F
.57089 .40106 m .55909 .39202 L .57064 .39889 L .924 .65 .501 r
F
.039 .916 .04 r
.56944 .39593 m
.56968 .39584 L
s
.3451 .47703 m .40272 .45936 L .39967 .44818 L .683 .546 .691 r
F
0 g
.3451 .47703 m
.34954 .49037 L
s
.34146 .46352 m
.3451 .47703 L
s
.26439 .52343 m .3451 .47703 L .25743 .50252 L .766 .613 .689 r
F
0 g
.3451 .47703 m
.34953 .49037 L
s
.34145 .46352 m
.3451 .47703 L
s
.4153 .49132 m .41374 .48014 L .41061 .48114 L .634 .593 .79 r
F
.4153 .49132 m .41844 .49034 L .41374 .48014 L F
0 g
.4153 .49132 m
.42039 .50079 L
s
.41844 .49034 m
.42352 .49981 L
s
.42374 .43131 m .42067 .42059 L .42222 .42154 L .964 .688 .462 r
F
.42522 .43186 m .42374 .43131 L .42222 .42154 L F
.22933 .64416 m .22277 .62252 L .21582 .62464 L .642 .662 .854 r
F
.22933 .64416 m .23627 .64208 L .22277 .62252 L F
0 g
.22933 .64416 m
.24339 .66102 L
s
.23627 .64208 m
.2503 .65896 L
s
.55935 .3809 m .54671 .36486 L .56001 .37806 L .895 .575 .434 r
F
.65519 .43329 m .6538 .46084 L .65346 .43501 L .999 .835 .502 r
F
.65063 .40932 m .65519 .43329 L .65346 .43501 L .997 .776 .466 r
F
.65134 .40809 m .65519 .43329 L .65063 .40932 L .997 .77 .436 r
F
.53697 .48364 m .53273 .49408 L .5326 .4794 L .969 .687 .442 r
F
.53697 .48364 m .5382 .49936 L .53273 .49408 L F
.039 .916 .04 r
.71215 .39562 m
.7126 .39546 L
s
0 0 0 r
2 Mabswid
.71215 .39562 Mdot
.72283 .45468 m .72509 .49032 L .72038 .45955 L .995 .779 .415 r
F
.71527 .42602 m .72283 .45468 L .72038 .45955 L .994 .752 .41 r
F
.7165 .42192 m .72283 .45468 L .71527 .42602 L .991 .744 .381 r
F
.41912 .41964 m .41662 .4082 L .4182 .40954 L .964 .688 .462 r
F
.42067 .42059 m .41912 .41964 L .4182 .40954 L F
.65375 .38276 m .66732 .4057 L .66688 .40816 L .976 .684 .402 r
F
.039 .916 .04 r
.5 Mabswid
.6639 .39523 m
.66392 .39523 L
s
.66389 .39524 m
.6639 .39523 L
s
.66389 .39524 m
.66389 .39524 L
s
.44804 .503 m .44199 .4961 L .44263 .49429 L .964 .688 .462 r
F
.44804 .503 m .4476 .50513 L .44199 .4961 L F
.6538 .46084 m .6462 .48982 L .65078 .46231 L .989 .893 .598 r
F
.65346 .43501 m .6538 .46084 L .65078 .46231 L .999 .837 .545 r
F
.57607 .41674 m .56794 .42384 L .57505 .41472 L .941 .711 .562 r
F
.57607 .41674 m .57 .42788 L .56794 .42384 L F
.44268 .40764 m .43524 .40128 L .43501 .39131 L .965 .687 .457 r
F
.44352 .4165 m .43524 .40128 L .44268 .40764 L F
.42729 .44147 m .42374 .43131 L .42522 .43186 L .964 .688 .462 r
F
0 g
.42376 .42249 m
.42522 .43186 L
s
.47751 .40503 m .46535 .40024 L .4651 .39194 L .874 .602 .524 r
F
.47823 .41211 m .46535 .40024 L .47751 .40503 L .873 .615 .545 r
F
.4439 .49067 m .43833 .48321 L .43915 .48176 L .964 .688 .462 r
F
.4439 .49067 m .44327 .49248 L .43833 .48321 L F
.57089 .40106 m .55959 .39637 L .55909 .39202 L .924 .65 .501 r
F
.57129 .40332 m .55959 .39637 L .57089 .40106 L .925 .658 .514 r
F
.41503 .40686 m .41344 .40552 L .41324 .39502 L .964 .688 .462 r
F
0 g
.41324 .39502 m
.41387 .38544 L
s
.52919 .46085 m .52387 .46792 L .52595 .4562 L .969 .687 .442 r
F
.52919 .46085 m .52821 .47412 L .52387 .46792 L F
.39967 .44818 m .40043 .43606 L .39731 .43707 L .597 .467 .673 r
F
0 g
.39566 .42625 m
.39731 .43707 L
s
.18485 .50195 m .17259 .49925 L .16749 .47298 L .983 .699 .392 r
F
.1906 .52373 m .17259 .49925 L .18485 .50195 L .979 .687 .376 r
F
.68836 .34113 m .68423 .31652 L .69009 .34272 L .959 .619 .286 r
F
.68836 .34113 m .68077 .31331 L .68423 .31652 L F
.64295 .38621 m .65188 .40651 L .65134 .40809 L .985 .71 .407 r
F
.57505 .41472 m .56603 .41951 L .5741 .41257 L .937 .702 .557 r
F
.57505 .41472 m .56794 .42384 L .56603 .41951 L F
.65375 .38276 m .64901 .35391 L .65078 .35547 L .974 .68 .398 r
F
.57181 .40565 m .56038 .40092 L .57129 .40332 L .926 .667 .526 r
F
.57129 .40332 m .56038 .40092 L .55959 .39637 L .925 .658 .514 r
F
.63449 .32184 m .62888 .29194 L .63744 .322 L .971 .669 .387 r
F
.63449 .32184 m .62444 .29158 L .62888 .29194 L F
.72509 .49032 m .72262 .52762 L .72103 .49504 L .998 .817 .469 r
F
.72038 .45955 m .72509 .49032 L .72103 .49504 L .999 .788 .453 r
F
.43675 .47001 m .43196 .46141 L .43311 .46073 L .964 .688 .462 r
F
.43675 .47001 m .43576 .47109 L .43196 .46141 L F
0 g
.43675 .47001 m
.44079 .47885 L
s
.5741 .41257 m .56429 .41497 L .57323 .41031 L .933 .693 .552 r
F
.5741 .41257 m .56603 .41951 L .56429 .41497 L F
.53088 .35242 m .51454 .33523 L .53284 .34782 L .821 .459 .371 r
F
.54671 .36486 m .53088 .35242 L .53284 .34782 L .862 .513 .388 r
F
.43998 .4803 m .43476 .47217 L .43576 .47109 L .964 .688 .462 r
F
.43998 .4803 m .43915 .48176 L .43476 .47217 L F
.57181 .40565 m .56143 .40559 L .56038 .40092 L .926 .667 .526 r
F
.57247 .40799 m .56143 .40559 L .57181 .40565 L .928 .675 .536 r
F
.63416 .36281 m .62462 .34053 L .63531 .36283 L .935 .568 .282 r
F
.63416 .36281 m .6223 .34045 L .62462 .34053 L F
.57883 .4399 m .57163 .45445 L .5766 .43763 L .95 .771 .626 r
F
.57883 .4399 m .57499 .45784 L .57163 .45445 L F
.49523 .50719 m .52618 .50141 L .48953 .50055 L .454 .652 .944 r
F
.49523 .50719 m .53286 .50933 L .52618 .50141 L F
0 g
.49523 .50719 m
.5009 .51251 L
s
.57323 .41031 m .56275 .4103 L .57247 .40799 L .93 .684 .544 r
F
.57323 .41031 m .56429 .41497 L .56275 .4103 L F
.64295 .38621 m .63656 .36326 L .6379 .36409 L .965 .646 .351 r
F
.70295 .53343 m .70455 .56824 L .69682 .53706 L .983 .71 .426 r
F
.69375 .50324 m .70295 .53343 L .69682 .53706 L .981 .705 .422 r
F
.57247 .40799 m .56275 .4103 L .56143 .40559 L .928 .675 .536 r
F
.39967 .44818 m .4028 .44717 L .40043 .43606 L .597 .467 .673 r
F
0 g
.39878 .42523 m
.40043 .43606 L
s
.42225 .43076 m .41912 .41964 L .42067 .42059 L .964 .688 .462 r
F
.42374 .43131 m .42225 .43076 L .42067 .42059 L F
.42729 .44147 m .42589 .44133 L .42374 .43131 L F
.42994 .45115 m .42589 .44133 L .42729 .44147 L F
0 g
.42522 .43186 m
.42729 .44147 L
s
.49666 .48725 m .4839 .4927 L .49199 .48071 L .902 .745 .677 r
F
.49666 .48725 m .48953 .50055 L .4839 .4927 L F
.41757 .41868 m .41503 .40686 L .41662 .4082 L .964 .688 .462 r
F
.41912 .41964 m .41757 .41868 L .41662 .4082 L F
.50697 .39364 m .49844 .38413 L .49873 .37699 L .969 .687 .442 r
F
.5072 .39949 m .49844 .38413 L .50697 .39364 L F
.4996 .37066 m .49135 .35768 L .49316 .35093 L F
.49873 .37699 m .49135 .35768 L .4996 .37066 L F
.41061 .48114 m .40952 .46942 L .40639 .47042 L .627 .562 .762 r
F
.41061 .48114 m .41374 .48014 L .40952 .46942 L F
0 g
.41061 .48114 m
.4153 .49132 L
s
.41374 .48014 m
.41844 .49034 L
s
.4476 .50513 m .44136 .49792 L .44199 .4961 L .964 .688 .462 r
F
.4476 .50513 m .44716 .50727 L .44136 .49792 L F
0 g
.44716 .50727 m
.45317 .51547 L
s
.19776 .54519 m .17957 .52569 L .1906 .52373 L .976 .674 .363 r
F
.19776 .54519 m .18827 .55176 L .17957 .52569 L F
.49516 .46325 m .48319 .46509 L .49175 .45672 L .9 .71 .638 r
F
.49516 .46325 m .48748 .47328 L .48319 .46509 L F
.49225 .32397 m .51539 .27825 L .52048 .27168 L .763 .897 .497 r
F
.51201 .34094 m .49225 .32397 L .51454 .33523 L .772 .399 .349 r
F
.51201 .34094 m .48912 .33077 L .49225 .32397 L F
.48912 .33077 m .51539 .27825 L .49225 .32397 L 0 0 0 r
F
0 g
.49305 .32292 m
.49614 .31887 L
s
.4729 .50571 m .4839 .4927 L .46725 .49789 L .65 .695 .878 r
F
.4729 .50571 m .48953 .50055 L .4839 .4927 L F
0 g
.4729 .50571 m
.47864 .51231 L
s
.49135 .35768 m .48525 .33655 L .49316 .35093 L .969 .687 .442 r
F
0 g
.24363 .42028 m
.24482 .43981 L
s
.4647 .48044 m .45658 .47919 L .4604 .47229 L .965 .687 .457 r
F
.4647 .48044 m .46177 .489 L .45658 .47919 L F
.57825 .46037 m .56863 .47663 L .57499 .45784 L .945 .809 .678 r
F
.57825 .46037 m .57301 .47996 L .56863 .47663 L F
.72262 .52762 m .72195 .5607 L .71473 .56528 L .998 .85 .536 r
F
0 g
.72195 .5607 m
.72798 .55316 L
s
.42589 .44133 m .42225 .43076 L .42374 .43131 L .964 .688 .462 r
F
.53088 .35242 m .51201 .34094 L .51454 .33523 L .821 .459 .371 r
F
.43311 .46073 m .42865 .45143 L .42994 .45115 L .964 .688 .462 r
F
.43311 .46073 m .43196 .46141 L .42865 .45143 L F
0 g
.43311 .46073 m
.43675 .47001 L
s
.1906 .52373 m .17957 .52569 L .17259 .49925 L .979 .687 .376 r
F
.44327 .49248 m .43751 .48468 L .43833 .48321 L .964 .688 .462 r
F
.44327 .49248 m .44263 .49429 L .43751 .48468 L F
.65375 .38276 m .66688 .40816 L .66621 .41019 L .976 .685 .402 r
F
.40272 .45936 m .4028 .44717 L .39967 .44818 L .609 .5 .705 r
F
0 g
.39731 .43707 m
.39967 .44818 L
s
.42994 .45115 m .42865 .45143 L .42589 .44133 L .964 .688 .462 r
F
0 g
.42994 .45115 m
.43311 .46073 L
s
.42729 .44147 m
.42994 .45115 L
s
.55935 .3809 m .54568 .36911 L .54671 .36486 L .895 .575 .434 r
F
.55896 .38422 m .54568 .36911 L .55935 .3809 L .893 .587 .462 r
F
.62022 .34118 m .60713 .31923 L .6223 .34045 L .895 .492 .24 r
F
.62022 .34118 m .60396 .32026 L .60713 .31923 L F
.64295 .38621 m .65134 .40809 L .65063 .40932 L .985 .713 .417 r
F
.67653 .44071 m .68422 .47308 L .67438 .44294 L .979 .695 .41 r
F
.66532 .41175 m .67653 .44071 L .67438 .44294 L .977 .69 .407 r
F
.66621 .41019 m .67653 .44071 L .66532 .41175 L .977 .689 .405 r
F
.47823 .41211 m .46623 .40911 L .46535 .40024 L .873 .615 .545 r
F
.47943 .41951 m .46623 .40911 L .47823 .41211 L .874 .627 .563 r
F
.67433 .30983 m .66632 .28293 L .67745 .31106 L .942 .577 .255 r
F
.67433 .30983 m .66162 .28098 L .66632 .28293 L F
.40639 .47042 m .40585 .45836 L .40272 .45936 L .618 .532 .734 r
F
.40639 .47042 m .40952 .46942 L .40585 .45836 L F
0 g
.40639 .47042 m
.41061 .48114 L
s
.40952 .46942 m
.41374 .48014 L
s
.6941 .36984 m .7032 .36827 L .70433 .37226 L .977 .675 .352 r
F
.6941 .36984 m .7019 .36431 L .7032 .36827 L .976 .673 .35 r
F
.6941 .36984 m .70045 .36045 L .7019 .36431 L .975 .67 .348 r
F
.40272 .45936 m .40585 .45836 L .4028 .44717 L .609 .5 .705 r
F
0 g
.40272 .45936 m
.40639 .47042 L
s
.39967 .44818 m
.40272 .45936 L
s
.40043 .43606 m
.4028 .44717 L
s
.58006 .30359 m .55878 .2828 L .58382 .30067 L .785 .333 .173 r
F
.58006 .30359 m .55395 .28635 L .55878 .2828 L F
.65375 .38276 m .64732 .35284 L .64901 .35391 L .974 .68 .398 r
F
.44352 .4165 m .43624 .41194 L .43524 .40128 L .965 .687 .457 r
F
.44499 .42577 m .43624 .41194 L .44352 .4165 L F
.43576 .47109 m .43081 .46209 L .43196 .46141 L .964 .688 .462 r
F
.43576 .47109 m .43476 .47217 L .43081 .46209 L F
.43915 .48176 m .43377 .47325 L .43476 .47217 L F
.43915 .48176 m .43833 .48321 L .43377 .47325 L F
.6941 .36984 m .70433 .37226 L .70528 .37621 L .978 .678 .355 r
F
0 g
.4028 .44717 m
.40585 .45836 L
s
.4651 .39194 m .45155 .38586 L .45205 .37676 L .853 .568 .506 r
F
.46535 .40024 m .45155 .38586 L .4651 .39194 L .852 .583 .532 r
F
.52595 .4562 m .51965 .46089 L .52281 .45094 L .969 .687 .442 r
F
.52595 .4562 m .52387 .46792 L .51965 .46089 L F
.64295 .38621 m .63531 .36283 L .63656 .36326 L .965 .646 .359 r
F
.6941 .36984 m .69888 .35676 L .70045 .36045 L .975 .668 .347 r
F
.42076 .4302 m .41757 .41868 L .41912 .41964 L .964 .688 .462 r
F
.42225 .43076 m .42076 .4302 L .41912 .41964 L F
.41601 .41772 m .41344 .40552 L .41503 .40686 L F
.41757 .41868 m .41601 .41772 L .41503 .40686 L F
.15744 .44973 m .16319 .42307 L .15632 .4254 L .56 .378 .592 r
F
0 g
.15632 .4254 m
.15722 .40275 L
s
.6462 .48982 m .63087 .51948 L .64163 .49027 L .963 .932 .706 r
F
.65078 .46231 m .6462 .48982 L .64163 .49027 L .985 .884 .642 r
F
.70631 .39571 m .7165 .42192 L .71527 .42602 L .988 .719 .386 r
F
.70672 .39325 m .7165 .42192 L .70631 .39571 L .987 .713 .369 r
F
.039 .916 .04 r
.7126 .39546 m
.89065 .33174 L
s
.45205 .37676 m .4814 .35376 L .48278 .34423 L .228 0 .336 r
F
.45155 .38586 m .4814 .35376 L .45205 .37676 L .31 .113 .443 r
F
.43501 .39131 m .45155 .38586 L .45205 .37676 L .521 .281 .492 r
F
0 g
.45205 .37676 m
.45329 .3687 L
s
.42589 .44133 m .42449 .44119 L .42225 .43076 L .964 .688 .462 r
F
.42865 .45143 m .42449 .44119 L .42589 .44133 L F
.69375 .50324 m .69682 .53706 L .68879 .50599 L .981 .705 .422 r
F
.68422 .47308 m .69375 .50324 L .68879 .50599 L .98 .7 .418 r
F
.54568 .36911 m .53088 .35242 L .54671 .36486 L .859 .531 .43 r
F
.6941 .36984 m .70528 .37621 L .70601 .38007 L .978 .68 .359 r
F
.43524 .40128 m .45155 .38586 L .43501 .39131 L .548 .34 .551 r
F
0 g
.43501 .39131 m
.43554 .38222 L
s
.40585 .45836 m
.40952 .46942 L
s
.65346 .43501 m .65078 .46231 L .65145 .43594 L .999 .837 .545 r
F
.64976 .41015 m .65346 .43501 L .65145 .43594 L .996 .778 .491 r
F
.65063 .40932 m .65346 .43501 L .64976 .41015 L .997 .776 .466 r
F
.49175 .45672 m .47921 .45631 L .48858 .44971 L .893 .696 .629 r
F
.49175 .45672 m .48319 .46509 L .47921 .45631 L F
.5766 .43763 m .56825 .45028 L .57437 .43484 L .939 .757 .628 r
F
.5766 .43763 m .57163 .45445 L .56825 .45028 L F
.44263 .49429 m .43668 .48614 L .43751 .48468 L .964 .688 .462 r
F
.44263 .49429 m .44199 .4961 L .43668 .48614 L F
.42449 .44119 m .42076 .4302 L .42225 .43076 L F
.6941 .36984 m .6972 .35328 L .69888 .35676 L .974 .667 .347 r
F
.43196 .46141 m .42736 .4517 L .42865 .45143 L .964 .688 .462 r
F
.43196 .46141 m .43081 .46209 L .42736 .4517 L F
.5072 .39949 m .49874 .39195 L .49844 .38413 L .969 .687 .442 r
F
.039 .916 .04 r
.47602 .39743 m
.49867 .39025 L
s
.50786 .40574 m .49874 .39195 L .5072 .39949 L .969 .687 .442 r
F
.42865 .45143 m .42736 .4517 L .42449 .44119 L .964 .688 .462 r
F
.47943 .41951 m .46773 .41841 L .46623 .40911 L .874 .627 .563 r
F
.4811 .42712 m .46773 .41841 L .47943 .41951 L .875 .641 .58 r
F
.64295 .38621 m .65063 .40932 L .64976 .41015 L .984 .715 .427 r
F
.5326 .4794 m .52722 .48751 L .52821 .47412 L .969 .687 .442 r
F
.5326 .4794 m .53273 .49408 L .52722 .48751 L F
.64427 .35224 m .63744 .322 L .64573 .35228 L .972 .674 .393 r
F
.64427 .35224 m .63449 .32184 L .63744 .322 L F
.4604 .47229 m .45177 .46865 L .45641 .46354 L .965 .687 .457 r
F
.4604 .47229 m .45658 .47919 L .45177 .46865 L F
.65375 .38276 m .66621 .41019 L .66532 .41175 L .976 .685 .403 r
F
.57301 .47996 m .55924 .49642 L .56863 .47663 L .925 .828 .731 r
F
.57301 .47996 m .56475 .50052 L .55924 .49642 L F
.6941 .36984 m .70601 .38007 L .70653 .38376 L .979 .683 .363 r
F
.55896 .38422 m .54508 .37408 L .54568 .36911 L .893 .587 .462 r
F
.55888 .38794 m .54508 .37408 L .55896 .38422 L .891 .599 .487 r
F
.63087 .51948 m .61267 .55084 L .60495 .5494 L .916 .942 .805 r
F
0 g
.61267 .55084 m
.61966 .54979 L
s
.43833 .48321 m .43277 .47434 L .43377 .47325 L .964 .688 .462 r
F
.43833 .48321 m .43751 .48468 L .43277 .47434 L F
.41601 .41772 m .41445 .41676 L .41344 .40552 L F
0 g
.41324 .39502 m
.41344 .40552 L
s
.65728 .28057 m .64697 .25294 L .66162 .28098 L .924 .538 .233 r
F
.65728 .28057 m .64112 .25226 L .64697 .25294 L F
.43476 .47217 m .42965 .46277 L .43081 .46209 L .964 .688 .462 r
F
.43476 .47217 m .43377 .47325 L .42965 .46277 L F
.6941 .36984 m .69546 .35009 L .6972 .35328 L .974 .665 .347 r
F
.5843 .20328 m .60253 .1981 L .59257 .20158 L .318 .802 .763 r
F
.59666 .23306 m .59257 .20158 L .60347 .23144 L .965 .653 .375 r
F
.59666 .23306 m .5843 .20328 L .59257 .20158 L F
0 g
.59257 .20158 m
.60166 .20301 L
s
.41926 .42965 m .41601 .41772 L .41757 .41868 L .964 .688 .462 r
F
.42076 .4302 m .41926 .42965 L .41757 .41868 L F
.48858 .44971 m .47561 .44707 L .48572 .44235 L .887 .681 .619 r
F
.48858 .44971 m .47921 .45631 L .47561 .44707 L F
.68671 .34004 m .68077 .31331 L .68836 .34113 L .959 .62 .298 r
F
.68671 .34004 m .67745 .31106 L .68077 .31331 L F
.64295 .38621 m .63416 .36281 L .63531 .36283 L .964 .647 .367 r
F
.44499 .42577 m .438 .42311 L .43624 .41194 L .965 .687 .457 r
F
.44705 .43528 m .438 .42311 L .44499 .42577 L F
.63313 .3632 m .6223 .34045 L .63416 .36281 L .934 .576 .312 r
F
.63313 .3632 m .62022 .34118 L .6223 .34045 L F
.15744 .44973 m .16434 .44742 L .16319 .42307 L .56 .378 .592 r
F
0 g
.16319 .42307 m
.16405 .40041 L
s
.65375 .38276 m .64573 .35228 L .64732 .35284 L .974 .68 .399 r
F
.49199 .48071 m .47844 .48378 L .48748 .47328 L .891 .726 .671 r
F
.49199 .48071 m .4839 .4927 L .47844 .48378 L F
.42449 .44119 m .42309 .44105 L .42076 .4302 L .964 .688 .462 r
F
.42736 .4517 m .42309 .44105 L .42449 .44119 L F
.52281 .45094 m .51564 .45315 L .51982 .44516 L .969 .687 .442 r
F
.52281 .45094 m .51965 .46089 L .51564 .45315 L F
.4811 .42712 m .46982 .42795 L .46773 .41841 L .875 .641 .58 r
F
.48321 .43478 m .46982 .42795 L .4811 .42712 L .878 .654 .595 r
F
.44199 .4961 m .43585 .48761 L .43668 .48614 L .964 .688 .462 r
F
.44199 .4961 m .44136 .49792 L .43585 .48761 L F
0 g
.44136 .49792 m
.44716 .50727 L
s
.68422 .47308 m .68879 .50599 L .68047 .47501 L .98 .7 .418 r
F
.67438 .44294 m .68422 .47308 L .68047 .47501 L .978 .695 .413 r
F
.5382 .49936 m .53286 .50888 L .53273 .49408 L .969 .687 .442 r
F
.5382 .49936 m .53944 .51518 L .53286 .50888 L F
.42309 .44105 m .41926 .42965 L .42076 .4302 L .964 .688 .462 r
F
.6941 .36984 m .70653 .38376 L .70683 .38723 L .979 .685 .368 r
F
.48572 .44235 m .47246 .43756 L .48321 .43478 L .882 .667 .608 r
F
.48572 .44235 m .47561 .44707 L .47246 .43756 L F
.57437 .43484 m .56491 .44537 L .57215 .43157 L .93 .742 .627 r
F
.57437 .43484 m .56825 .45028 L .56491 .44537 L F
.57499 .45784 m .56413 .47215 L .57163 .45445 L .931 .789 .681 r
F
.57499 .45784 m .56863 .47663 L .56413 .47215 L F
.43081 .46209 m .42607 .45197 L .42736 .4517 L .964 .688 .462 r
F
.43081 .46209 m .42965 .46277 L .42607 .45197 L F
.48321 .43478 m .47246 .43756 L .46982 .42795 L .878 .654 .595 r
F
.65078 .46231 m .64163 .49027 L .64737 .46256 L .985 .884 .642 r
F
.65145 .43594 m .65078 .46231 L .64737 .46256 L .993 .833 .578 r
F
.49873 .37699 m .49023 .36559 L .49135 .35768 L .969 .687 .442 r
F
.49844 .38413 m .49023 .36559 L .49873 .37699 L F
0 g
.28167 .56276 m
.29165 .58042 L
s
.42736 .4517 m .42607 .45197 L .42309 .44105 L .964 .688 .462 r
F
.45641 .46354 m .44743 .45756 L .45282 .45434 L .965 .687 .457 r
F
.45641 .46354 m .45177 .46865 L .44743 .45756 L F
.50786 .40574 m .49962 .40031 L .49874 .39195 L .969 .687 .442 r
F
.50895 .41228 m .49962 .40031 L .50786 .40574 L F
.6087 .2629 m .60347 .23144 L .6141 .26144 L .967 .659 .38 r
F
.6087 .2629 m .59666 .23306 L .60347 .23144 L F
.56475 .50052 m .5458 .5175 L .55924 .49642 L .899 .844 .781 r
F
.56475 .50052 m .55247 .52234 L .5458 .5175 L F
.6941 .36984 m .69367 .34723 L .69546 .35009 L .973 .664 .349 r
F
.64976 .41015 m .65145 .43594 L .64874 .41059 L .996 .778 .491 r
F
.64295 .38621 m .64976 .41015 L .64874 .41059 L .983 .716 .435 r
F
.6012 .32251 m .58382 .30067 L .60396 .32026 L .848 .43 .238 r
F
.6012 .32251 m .58006 .30359 L .58382 .30067 L F
.46725 .49789 m .47844 .48378 L .46177 .489 L .646 .659 .848 r
F
.46725 .49789 m .4839 .4927 L .47844 .48378 L F
0 g
.46725 .49789 m
.4729 .50571 L
s
.52946 .35807 m .51201 .34094 L .53088 .35242 L .82 .486 .423 r
F
.54568 .36911 m .52946 .35807 L .53088 .35242 L .859 .531 .43 r
F
.44705 .43528 m .44048 .43458 L .438 .42311 L .965 .687 .457 r
F
.44968 .44487 m .44048 .43458 L .44705 .43528 L F
.48953 .50055 m .51957 .49205 L .4839 .4927 L .48 .619 .91 r
F
.48953 .50055 m .52618 .50141 L .51957 .49205 L F
0 g
.48953 .50055 m
.49523 .50719 L
s
.55888 .38794 m .54493 .37967 L .54508 .37408 L .891 .599 .487 r
F
.55909 .39202 m .54493 .37967 L .55888 .38794 L .889 .611 .51 r
F
.039 .916 .04 r
.55606 .38627 m
.55624 .38621 L
s
.51258 .39991 m
.55344 .38709 L
s
.46535 .40024 m .45182 .39584 L .45155 .38586 L .852 .583 .532 r
F
.46623 .40911 m .45182 .39584 L .46535 .40024 L .852 .598 .555 r
F
.43751 .48468 m .43177 .47542 L .43277 .47434 L .964 .688 .462 r
F
.43751 .48468 m .43668 .48614 L .43177 .47542 L F
.41777 .42909 m .41445 .41676 L .41601 .41772 L F
.41926 .42965 m .41777 .42909 L .41601 .41772 L F
.43377 .47325 m .4285 .46346 L .42965 .46277 L F
.43377 .47325 m .43277 .47434 L .4285 .46346 L F
.55247 .52234 m .58788 .53908 L .5458 .5175 L 0 .333 .754 r
F
0 g
.53948 .51566 m
.54592 .52031 L
s
.55247 .52234 m .59664 .54548 L .58788 .53908 L 0 .333 .754 r
F
.72262 .52762 m .71473 .56528 L .7166 .53122 L .998 .85 .536 r
F
.72103 .49504 m .72262 .52762 L .7166 .53122 L 1 .821 .511 r
F
.66532 .41175 m .67438 .44294 L .66422 .41283 L .977 .69 .407 r
F
.65375 .38276 m .66532 .41175 L .66422 .41283 L .975 .685 .404 r
F
.49135 .35768 m .48303 .34462 L .48525 .33655 L .969 .687 .442 r
F
0 g
.48278 .34423 m
.48501 .33612 L
s
.45282 .45434 m .44364 .44613 L .44968 .44487 L .965 .687 .457 r
F
.45282 .45434 m .44743 .45756 L .44364 .44613 L F
.64295 .38621 m .63313 .3632 L .63416 .36281 L .963 .649 .376 r
F
.51982 .44516 m .51192 .44484 L .51705 .43896 L .969 .687 .442 r
F
.51982 .44516 m .51564 .45315 L .51192 .44484 L F
.72038 .45955 m .72103 .49504 L .71731 .46297 L .999 .788 .453 r
F
.71361 .4292 m .72038 .45955 L .71731 .46297 L .995 .758 .436 r
F
.71527 .42602 m .72038 .45955 L .71361 .4292 L .994 .752 .41 r
F
.44968 .44487 m .44364 .44613 L .44048 .43458 L .965 .687 .457 r
F
.6941 .36984 m .70683 .38723 L .70689 .39041 L .98 .688 .372 r
F
.54508 .37408 m .52946 .35807 L .54568 .36911 L .857 .549 .466 r
F
.42309 .44105 m .42168 .44091 L .41926 .42965 L .964 .688 .462 r
F
.42607 .45197 m .42168 .44091 L .42309 .44105 L F
.62044 .29279 m .6141 .26144 L .62444 .29158 L .969 .664 .386 r
F
.62044 .29279 m .6087 .2629 L .6141 .26144 L F
.67438 .44294 m .68047 .47501 L .67185 .44415 L .978 .695 .413 r
F
.66422 .41283 m .67438 .44294 L .67185 .44415 L .977 .69 .409 r
F
.42168 .44091 m .41777 .42909 L .41926 .42965 L .964 .688 .462 r
F
.65145 .43594 m .64737 .46256 L .64917 .43605 L .993 .833 .578 r
F
.64874 .41059 m .65145 .43594 L .64917 .43605 L .992 .777 .513 r
F
.50895 .41228 m .50107 .40907 L .49962 .40031 L .969 .687 .442 r
F
.51044 .419 m .50107 .40907 L .50895 .41228 L F
.57215 .43157 m .56165 .43983 L .57 .42788 L .922 .728 .624 r
F
.57215 .43157 m .56491 .44537 L .56165 .43983 L F
.6162 .22632 m .60253 .1981 L .6229 .22474 L .882 .46 .191 r
F
.5843 .20328 m .59433 .19977 L .60253 .1981 L .318 .802 .763 r
F
.6162 .22632 m .59433 .19977 L .60253 .1981 L .882 .46 .191 r
F
0 g
.60253 .1981 m
.61155 .19955 L
s
.65375 .38276 m .64427 .35224 L .64573 .35228 L .974 .68 .399 r
F
.49023 .36559 m .48303 .34462 L .49135 .35768 L .969 .687 .442 r
F
.6941 .36984 m .69187 .34476 L .69367 .34723 L .973 .663 .35 r
F
.42965 .46277 m .42478 .45225 L .42607 .45197 L .964 .688 .462 r
F
.42965 .46277 m .4285 .46346 L .42478 .45225 L F
.43524 .40128 m .45182 .39584 L .45155 .38586 L .548 .34 .551 r
F
.43624 .41194 m .45182 .39584 L .43524 .40128 L .568 .389 .598 r
F
0 g
.43501 .39131 m
.43524 .40128 L
s
.70569 .39773 m .71527 .42602 L .71361 .4292 L .989 .724 .402 r
F
.70631 .39571 m .71527 .42602 L .70569 .39773 L .988 .719 .386 r
F
.42607 .45197 m .42478 .45225 L .42168 .44091 L .964 .688 .462 r
F
.64295 .38621 m .63224 .36399 L .63313 .3632 L .962 .651 .385 r
F
.64295 .38621 m .63151 .36518 L .63224 .36399 L .962 .653 .394 r
F
.64295 .38621 m .63094 .36673 L .63151 .36518 L .961 .656 .404 r
F
.64295 .38621 m .63056 .36863 L .63094 .36673 L .961 .659 .412 r
F
.64295 .38621 m .63036 .37085 L .63056 .36863 L .96 .662 .421 r
F
.64295 .38621 m .63036 .37334 L .63036 .37085 L .96 .665 .429 r
F
.64295 .38621 m .63054 .37607 L .63036 .37334 L .96 .669 .437 r
F
.039 .916 .04 r
.63112 .37409 m
.63117 .37408 L
s
.56968 .39584 m
.63042 .37434 L
s
.6311 .3741 m
.63112 .37409 L
s
.63117 .37408 m
.63118 .37407 L
s
.64295 .38621 m .63091 .37898 L .63054 .37607 L .96 .673 .444 r
F
.64295 .38621 m .63147 .38202 L .63091 .37898 L .961 .676 .45 r
F
.64295 .38621 m .63219 .38515 L .63147 .38202 L .962 .68 .456 r
F
.64295 .38621 m .63308 .38831 L .63219 .38515 L .962 .684 .46 r
F
.64295 .38621 m .63411 .39144 L .63308 .38831 L .964 .688 .464 r
F
.039 .916 .04 r
.58004 .40635 m
.6334 .38927 L
s
.64295 .38621 m .63527 .39449 L .63411 .39144 L .965 .692 .467 r
F
.64295 .38621 m .63653 .3974 L .63527 .39449 L .966 .696 .47 r
F
.64295 .38621 m .63788 .40012 L .63653 .3974 L .968 .7 .471 r
F
.64295 .38621 m .63929 .40261 L .63788 .40012 L .97 .703 .471 r
F
.64295 .38621 m .64073 .40483 L .63929 .40261 L .972 .707 .47 r
F
.64295 .38621 m .64219 .40672 L .64073 .40483 L .974 .709 .468 r
F
.64295 .38621 m .64362 .40828 L .64219 .40672 L .976 .712 .465 r
F
.64295 .38621 m .64502 .40945 L .64362 .40828 L .978 .714 .461 r
F
.64295 .38621 m .64636 .41024 L .64502 .40945 L .979 .715 .456 r
F
.64295 .38621 m .6476 .41062 L .64636 .41024 L .981 .716 .45 r
F
.64295 .38621 m .64874 .41059 L .6476 .41062 L .982 .716 .443 r
F
.039 .916 .04 r
.55624 .38621 m
.55626 .38621 L
s
.61841 .34272 m .60396 .32026 L .62022 .34118 L .896 .511 .293 r
F
.61841 .34272 m .6012 .32251 L .60396 .32026 L F
0 g
.24482 .43981 m
.24755 .4603 L
s
.64874 .41059 m .64917 .43605 L .6476 .41062 L .992 .777 .513 r
F
.21582 .62464 m .2101 .60067 L .20314 .60281 L .637 .627 .823 r
F
.21582 .62464 m .22277 .62252 L .2101 .60067 L F
0 g
.21582 .62464 m
.22933 .64416 L
s
.22277 .62252 m
.23627 .64208 L
s
.55909 .39202 m .54523 .3858 L .54493 .37967 L .889 .611 .51 r
F
.55959 .39637 m .54523 .3858 L .55909 .39202 L .889 .623 .53 r
F
.51705 .43896 m .50853 .43612 L .51453 .43246 L .969 .687 .442 r
F
.51705 .43896 m .51192 .44484 L .50853 .43612 L F
.45155 .38586 m .48091 .36454 L .4814 .35376 L .31 .113 .443 r
F
.45182 .39584 m .48091 .36454 L .45155 .38586 L .366 .202 .521 r
F
0 g
.45155 .38586 m
.45205 .37676 L
s
.63186 .32273 m .62444 .29158 L .63449 .32184 L .971 .669 .39 r
F
.63186 .32273 m .62044 .29279 L .62444 .29158 L F
.52821 .47412 m .52176 .47975 L .52387 .46792 L .969 .687 .442 r
F
.52821 .47412 m .52722 .48751 L .52176 .47975 L F
.48748 .47328 m .47327 .47394 L .48319 .46509 L .882 .709 .662 r
F
.48748 .47328 m .47844 .48378 L .47327 .47394 L F
.43668 .48614 m .43076 .47651 L .43177 .47542 L .964 .688 .462 r
F
.43668 .48614 m .43585 .48761 L .43076 .47651 L F
0 g
.43585 .48761 m
.44136 .49792 L
s
.41777 .42909 m .41627 .42853 L .41445 .41676 L .964 .688 .462 r
F
0 g
.41344 .40552 m
.41445 .41676 L
s
.51044 .419 m .50306 .41807 L .50107 .40907 L .969 .687 .442 r
F
.51231 .42576 m .50306 .41807 L .51044 .419 L F
.43277 .47434 m .42734 .46415 L .4285 .46346 L .964 .688 .462 r
F
.43277 .47434 m .43177 .47542 L .42734 .46415 L F
.51018 .34798 m .48912 .33077 L .51201 .34094 L .775 .436 .413 r
F
.52946 .35807 m .51018 .34798 L .51201 .34094 L .82 .486 .423 r
F
.6941 .36984 m .70689 .39041 L .70672 .39325 L .98 .69 .377 r
F
.63087 .51948 m .60495 .5494 L .62453 .51812 L .916 .942 .805 r
F
.64163 .49027 m .63087 .51948 L .62453 .51812 L .953 .907 .737 r
F
.51453 .43246 m .50557 .42714 L .51231 .42576 L .969 .687 .442 r
F
.51453 .43246 m .50853 .43612 L .50557 .42714 L F
.63224 .36399 m .62022 .34118 L .63313 .3632 L .933 .584 .341 r
F
.51231 .42576 m .50557 .42714 L .50306 .41807 L .969 .687 .442 r
F
.63224 .36399 m .61841 .34272 L .62022 .34118 L .933 .584 .341 r
F
.54987 .29191 m .52048 .27168 L .55395 .28635 L .721 .287 .218 r
F
.54987 .29191 m .51539 .27825 L .52048 .27168 L F
0 g
.52048 .27168 m
.52647 .26752 L
s
.42168 .44091 m .42027 .44076 L .41777 .42909 L .964 .688 .462 r
F
.42478 .45225 m .42027 .44076 L .42168 .44091 L F
.57 .42788 m .55855 .43375 L .56794 .42384 L .914 .714 .618 r
F
.57 .42788 m .56165 .43983 L .55855 .43375 L F
.66422 .41283 m .67185 .44415 L .66295 .41339 L .977 .69 .409 r
F
.65375 .38276 m .66422 .41283 L .66295 .41339 L .975 .685 .405 r
F
.039 .916 .04 r
.66393 .39522 m
.70138 .38334 L
s
.66392 .39523 m
.66393 .39522 L
s
.64296 .35272 m .63449 .32184 L .64427 .35224 L .972 .675 .395 r
F
.64296 .35272 m .63186 .32273 L .63449 .32184 L F
.42027 .44076 m .41627 .42853 L .41777 .42909 L .964 .688 .462 r
F
.57163 .45445 m .5596 .4666 L .56825 .45028 L .918 .768 .68 r
F
.57163 .45445 m .56413 .47215 L .5596 .4666 L F
.46623 .40911 m .45286 .40652 L .45182 .39584 L .852 .598 .555 r
F
.46773 .41841 m .45286 .40652 L .46623 .40911 L .853 .613 .576 r
F
.6941 .36984 m .69009 .34272 L .69187 .34476 L .972 .662 .353 r
F
.56863 .47663 m .55357 .49088 L .56413 .47215 L .908 .801 .73 r
F
.56863 .47663 m .55924 .49642 L .55357 .49088 L F
.55959 .39637 m .54597 .39235 L .54523 .3858 L .889 .623 .53 r
F
.56038 .40092 m .54597 .39235 L .55959 .39637 L .89 .636 .548 r
F
.68516 .33946 m .67745 .31106 L .68671 .34004 L .959 .622 .312 r
F
.68516 .33946 m .67433 .30983 L .67745 .31106 L F
.4285 .46346 m .42348 .45252 L .42478 .45225 L .964 .688 .462 r
F
.4285 .46346 m .42734 .46415 L .42348 .45252 L F
.48912 .33077 m .51131 .28716 L .51539 .27825 L 0 0 0 r
F
.51018 .34798 m .48683 .33919 L .48912 .33077 L .775 .436 .413 r
F
.48683 .33919 m .51131 .28716 L .48912 .33077 L 0 0 0 r
F
0 g
.48912 .33077 m
.49225 .32397 L
s
.49844 .38413 m .48984 .37452 L .49023 .36559 L .969 .687 .442 r
F
.49874 .39195 m .48984 .37452 L .49844 .38413 L F
.42478 .45225 m .42348 .45252 L .42027 .44076 L .964 .688 .462 r
F
.67147 .30964 m .66162 .28098 L .67433 .30983 L .943 .583 .282 r
F
.67147 .30964 m .65728 .28057 L .66162 .28098 L F
.46177 .489 m .47327 .47394 L .45658 .47919 L .641 .625 .819 r
F
.46177 .489 m .47844 .48378 L .47327 .47394 L F
0 g
.46177 .489 m
.46725 .49789 L
s
.6476 .41062 m .64667 .43534 L .64636 .41024 L .987 .774 .53 r
F
.6476 .41062 m .64917 .43605 L .64667 .43534 L F
.65375 .38276 m .64296 .35272 L .64427 .35224 L .974 .68 .4 r
F
.56794 .42384 m .55566 .42723 L .56603 .41951 L .907 .7 .611 r
F
.56794 .42384 m .55855 .43375 L .55566 .42723 L F
.43177 .47542 m .42618 .46483 L .42734 .46415 L .964 .688 .462 r
F
.43177 .47542 m .43076 .47651 L .42618 .46483 L F
0 g
.43076 .47651 m
.43585 .48761 L
s
.54508 .37408 m .52863 .36469 L .52946 .35807 L .857 .549 .466 r
F
.54493 .37967 m .52863 .36469 L .54508 .37408 L .855 .566 .498 r
F
.56038 .40092 m .54714 .39921 L .54597 .39235 L .89 .636 .548 r
F
.56143 .40559 m .54714 .39921 L .56038 .40092 L .891 .648 .564 r
F
.6941 .36984 m .70672 .39325 L .70631 .39571 L .981 .692 .383 r
F
.039 .916 .04 r
.70353 .38266 m
.70368 .38261 L
s
.70351 .38267 m
.70353 .38266 L
s
.70349 .38267 m
.70351 .38267 L
s
.48319 .46509 m .46846 .46336 L .47921 .45631 L .874 .692 .652 r
F
.48319 .46509 m .47327 .47394 L .46846 .46336 L F
.63151 .36518 m .61841 .34272 L .63224 .36399 L .931 .592 .369 r
F
.72103 .49504 m .7166 .53122 L .7162 .49775 L 1 .821 .511 r
F
.71731 .46297 m .72103 .49504 L .7162 .49775 L .999 .792 .485 r
F
.16057 .47527 m .16434 .44742 L .15744 .44973 L .578 .422 .634 r
F
0 g
.15632 .4254 m
.15744 .44973 L
s
.65375 .38276 m .64184 .35372 L .64296 .35272 L .974 .68 .401 r
F
.65375 .38276 m .64091 .35523 L .64184 .35372 L F
.65375 .38276 m .6402 .35721 L .64091 .35523 L .974 .68 .402 r
F
.65375 .38276 m .63972 .35963 L .6402 .35721 L .974 .681 .403 r
F
.65375 .38276 m .63947 .36246 L .63972 .35963 L .974 .681 .404 r
F
.65375 .38276 m .63947 .36565 L .63947 .36246 L F
.65375 .38276 m .63972 .36914 L .63947 .36565 L .974 .681 .405 r
F
.65375 .38276 m .6402 .37287 L .63972 .36914 L .974 .682 .406 r
F
.65375 .38276 m .64092 .37677 L .6402 .37287 L F
.65375 .38276 m .64185 .38079 L .64092 .37677 L .974 .683 .407 r
F
.65375 .38276 m .64299 .38483 L .64185 .38079 L F
.65375 .38276 m .64432 .38885 L .64299 .38483 L F
.039 .916 .04 r
.64295 .38621 m
.6434 .38607 L
s
.65375 .38276 m .6458 .39276 L .64432 .38885 L .974 .684 .408 r
F
.65375 .38276 m .64742 .39649 L .6458 .39276 L F
.65375 .38276 m .64914 .39999 L .64742 .39649 L F
.65375 .38276 m .65094 .40318 L .64914 .39999 L .975 .684 .408 r
F
.65375 .38276 m .65278 .40602 L .65094 .40318 L .975 .685 .408 r
F
.65375 .38276 m .65463 .40845 L .65278 .40602 L F
.65375 .38276 m .65646 .41044 L .65463 .40845 L .975 .685 .407 r
F
.65375 .38276 m .65823 .41195 L .65646 .41044 L F
.65375 .38276 m .65993 .41295 L .65823 .41195 L .975 .685 .406 r
F
.65375 .38276 m .66151 .41343 L .65993 .41295 L F
.65375 .38276 m .66295 .41339 L .66151 .41343 L .975 .685 .405 r
F
.4839 .4927 m .51314 .48139 L .47844 .48378 L .494 .587 .876 r
F
.4839 .4927 m .51957 .49205 L .51314 .48139 L F
0 g
.4839 .4927 m
.48953 .50055 L
s
.64163 .49027 m .62453 .51812 L .6366 .48907 L .953 .907 .737 r
F
.64737 .46256 m .64163 .49027 L .6366 .48907 L .974 .867 .67 r
F
.42027 .44076 m .41886 .44062 L .41627 .42853 L .964 .688 .462 r
F
0 g
.41445 .41676 m
.41627 .42853 L
s
.42348 .45252 m .41886 .44062 L .42027 .44076 L .964 .688 .462 r
F
0 0 0 r
2 Mabswid
.70368 .38261 Mdot
.56603 .41951 m .55303 .42039 L .56429 .41497 L .902 .687 .602 r
F
.56603 .41951 m .55566 .42723 L .55303 .42039 L F
.53273 .49408 m .52621 .501 L .52722 .48751 L .969 .687 .442 r
F
.53273 .49408 m .53286 .50888 L .52621 .501 L F
.43624 .41194 m .45286 .40652 L .45182 .39584 L .568 .389 .598 r
F
.438 .42311 m .45286 .40652 L .43624 .41194 L .584 .43 .638 r
F
0 g
.5 Mabswid
.43524 .40128 m
.43624 .41194 L
s
.27253 .54364 m
.28167 .56276 L
s
.56143 .40559 m .54873 .40625 L .54714 .39921 L .891 .648 .564 r
F
.56275 .4103 m .54873 .40625 L .56143 .40559 L .894 .661 .578 r
F
.64917 .43605 m .64361 .46157 L .64667 .43534 L .984 .824 .602 r
F
.64917 .43605 m .64737 .46256 L .64361 .46157 L F
.52863 .36469 m .51018 .34798 L .52946 .35807 L .819 .51 .467 r
F
.63585 .25367 m .6229 .22474 L .64112 .25226 L .906 .507 .233 r
F
.63585 .25367 m .6162 .22632 L .6229 .22474 L F
.46773 .41841 m .45464 .41771 L .45286 .40652 L .853 .613 .576 r
F
.46982 .42795 m .45464 .41771 L .46773 .41841 L .855 .628 .595 r
F
.6941 .36984 m .68836 .34113 L .69009 .34272 L .972 .662 .356 r
F
.42734 .46415 m .42219 .4528 L .42348 .45252 L .964 .688 .462 r
F
.42734 .46415 m .42618 .46483 L .42219 .4528 L F
.56429 .41497 m .5507 .41335 L .56275 .4103 L .897 .674 .591 r
F
.56429 .41497 m .55303 .42039 L .5507 .41335 L F
.56275 .4103 m .5507 .41335 L .54873 .40625 L .894 .661 .578 r
F
.66295 .41339 m .66899 .44431 L .66151 .41343 L .977 .69 .411 r
F
.66295 .41339 m .67185 .44415 L .66899 .44431 L F
.64737 .46256 m .6366 .48907 L .64361 .46157 L .974 .867 .67 r
F
.42348 .45252 m .42219 .4528 L .41886 .44062 L .964 .688 .462 r
F
0 g
.41627 .42853 m
.41886 .44062 L
s
.52387 .46792 m .51646 .47093 L .51965 .46089 L .969 .687 .442 r
F
.52387 .46792 m .52176 .47975 L .51646 .47093 L F
.64636 .41024 m .644 .43381 L .64502 .40945 L .981 .769 .544 r
F
.64636 .41024 m .64667 .43534 L .644 .43381 L F
0 g
.42618 .46483 m
.43076 .47651 L
s
.67185 .44415 m .6762 .47538 L .66899 .44431 L .978 .696 .417 r
F
.67185 .44415 m .68047 .47501 L .6762 .47538 L F
.47921 .45631 m .46412 .45224 L .47561 .44707 L .868 .675 .64 r
F
.47921 .45631 m .46846 .46336 L .46412 .45224 L F
.45182 .39584 m .48131 .3764 L .48091 .36454 L .366 .202 .521 r
F
.45286 .40652 m .48131 .3764 L .45182 .39584 L .407 .271 .582 r
F
0 g
.45155 .38586 m
.45182 .39584 L
s
.56825 .45028 m .5551 .46008 L .56491 .44537 L .906 .749 .676 r
F
.56825 .45028 m .5596 .4666 L .5551 .46008 L F
.5769 .3081 m .55395 .28635 L .58006 .30359 L .795 .383 .269 r
F
.5769 .3081 m .54987 .29191 L .55395 .28635 L F
.55924 .49642 m .53893 .51092 L .55357 .49088 L .881 .81 .775 r
F
.55924 .49642 m .5458 .5175 L .53893 .51092 L F
.71361 .4292 m .71731 .46297 L .71154 .43141 L .995 .758 .436 r
F
.70484 .39929 m .71361 .4292 L .71154 .43141 L .989 .727 .417 r
F
.70569 .39773 m .71361 .4292 L .70484 .39929 L .989 .724 .402 r
F
.64184 .35372 m .63186 .32273 L .64296 .35272 L .972 .675 .397 r
F
.63151 .36518 m .61691 .34505 L .61841 .34272 L .931 .592 .369 r
F
.63094 .36673 m .61691 .34505 L .63151 .36518 L .929 .601 .395 r
F
.61691 .34505 m .6012 .32251 L .61841 .34272 L .894 .529 .34 r
F
0 g
.24755 .4603 m
.25178 .48134 L
s
.41886 .44062 m
.42219 .4528 L
s
.45658 .47919 m .46846 .46336 L .45177 .46865 L .634 .593 .79 r
F
.45658 .47919 m .47327 .47394 L .46846 .46336 L F
0 g
.45658 .47919 m
.46177 .489 L
s
.6941 .36984 m .70631 .39571 L .70569 .39773 L .981 .694 .388 r
F
.68047 .47501 m .68314 .50665 L .6762 .47538 L .979 .701 .422 r
F
.68047 .47501 m .68879 .50599 L .68314 .50665 L F
.46982 .42795 m .45715 .4292 L .45464 .41771 L .855 .628 .595 r
F
.47246 .43756 m .45715 .4292 L .46982 .42795 L .858 .644 .612 r
F
.16057 .47527 m .16749 .47298 L .16434 .44742 L .578 .422 .634 r
F
0 g
.16319 .42307 m
.16434 .44742 L
s
.49874 .39195 m .4902 .38433 L .48984 .37452 L .969 .687 .442 r
F
.49962 .40031 m .4902 .38433 L .49874 .39195 L F
.49023 .36559 m .48166 .35411 L .48303 .34462 L F
.48984 .37452 m .48166 .35411 L .49023 .36559 L F
.68879 .50599 m .6898 .5381 L .68314 .50665 L .981 .706 .427 r
F
.68879 .50599 m .69682 .53706 L .6898 .5381 L F
.47561 .44707 m .46032 .44078 L .47246 .43756 L .862 .659 .627 r
F
.47561 .44707 m .46412 .45224 L .46032 .44078 L F
0 g
.42219 .4528 m
.42618 .46483 L
s
.47246 .43756 m .46032 .44078 L .45715 .4292 L .858 .644 .612 r
F
.54493 .37967 m .52838 .37215 L .52863 .36469 L .855 .566 .498 r
F
.54523 .3858 m .52838 .37215 L .54493 .37967 L .854 .582 .526 r
F
.039 .916 .04 r
.53993 .3774 m
.54022 .37731 L
s
.50277 .38896 m
.53627 .37854 L
s
.6941 .36984 m .68671 .34004 L .68836 .34113 L .971 .662 .36 r
F
.44048 .43458 m .45464 .41771 L .438 .42311 L .597 .466 .673 r
F
.438 .42311 m .45464 .41771 L .45286 .40652 L .584 .43 .638 r
F
0 g
.43624 .41194 m
.438 .42311 L
s
.69682 .53706 m .69617 .56974 L .6898 .5381 L .982 .711 .433 r
F
.69682 .53706 m .70455 .56824 L .69617 .56974 L F
.64502 .40945 m .64119 .43149 L .64362 .40828 L .974 .762 .554 r
F
.64502 .40945 m .644 .43381 L .64119 .43149 L F
.5989 .32595 m .58006 .30359 L .6012 .32251 L .85 .46 .308 r
F
.5989 .32595 m .5769 .3081 L .58006 .30359 L F
.61691 .34505 m .5989 .32595 L .6012 .32251 L .894 .529 .34 r
F
.70455 .56824 m .70642 .56676 L .69617 .56974 L .265 .77 .756 r
F
.70455 .56824 m .71473 .56528 L .70642 .56676 L F
0 g
.70709 .56664 m
.71184 .56364 L
s
.4814 .35376 m
.48278 .34423 L
s
.66151 .41343 m .66584 .44342 L .65993 .41295 L .976 .69 .413 r
F
.66151 .41343 m .66899 .44431 L .66584 .44342 L F
.62957 .32466 m .62044 .29279 L .63186 .32273 L .97 .67 .394 r
F
.64184 .35372 m .62957 .32466 L .63186 .32273 L .972 .675 .397 r
F
.56413 .47215 m .54786 .48398 L .5596 .4666 L .893 .775 .725 r
F
.56413 .47215 m .55357 .49088 L .54786 .48398 L F
.5458 .5175 m .57883 .5303 L .53893 .51092 L 0 .4 .842 r
F
0 g
.53286 .50933 m
.53948 .51566 L
s
.5458 .5175 m .58788 .53908 L .57883 .5303 L 0 .4 .842 r
F
0 g
.5458 .5175 m
.55247 .52234 L
s
.71731 .46297 m .7162 .49775 L .71367 .46487 L .999 .792 .485 r
F
.71154 .43141 m .71731 .46297 L .71367 .46487 L .995 .761 .459 r
F
.68374 .3394 m .67433 .30983 L .68516 .33946 L .958 .625 .326 r
F
.68374 .3394 m .67147 .30964 L .67433 .30983 L F
.63094 .36673 m .61575 .34813 L .61691 .34505 L .929 .601 .395 r
F
.63056 .36863 m .61575 .34813 L .63094 .36673 L .927 .609 .419 r
F
.47844 .48378 m .50702 .46963 L .47327 .47394 L .5 .554 .843 r
F
.47844 .48378 m .51314 .48139 L .50702 .46963 L F
0 g
.47844 .48378 m
.4839 .4927 L
s
.6534 .28175 m .64112 .25226 L .65728 .28057 L .926 .55 .272 r
F
.6534 .28175 m .63585 .25367 L .64112 .25226 L F
.20314 .60281 m .19852 .57692 L .19156 .5791 L .63 .594 .794 r
F
.20314 .60281 m .2101 .60067 L .19852 .57692 L F
0 g
.20314 .60281 m
.21582 .62464 L
s
.2101 .60067 m
.22277 .62252 L
s
.51965 .46089 m .51142 .46122 L .51564 .45315 L .969 .687 .442 r
F
.51965 .46089 m .51646 .47093 L .51142 .46122 L F
.50907 .35624 m .48683 .33919 L .51018 .34798 L .776 .468 .466 r
F
.52863 .36469 m .50907 .35624 L .51018 .34798 L .819 .51 .467 r
F
.45177 .46865 m .46412 .45224 L .44743 .45756 L .627 .562 .762 r
F
.45177 .46865 m .46846 .46336 L .46412 .45224 L F
0 g
.45177 .46865 m
.45658 .47919 L
s
.26439 .52343 m
.27253 .54364 L
s
.64091 .35523 m .62957 .32466 L .64184 .35372 L .972 .676 .4 r
F
.6941 .36984 m .70569 .39773 L .70484 .39929 L .981 .695 .393 r
F
.64667 .43534 m .63958 .45935 L .644 .43381 L .974 .811 .619 r
F
.64667 .43534 m .64361 .46157 L .63958 .45935 L F
.56491 .44537 m .55073 .45268 L .56165 .43983 L .895 .73 .67 r
F
.56491 .44537 m .5551 .46008 L .55073 .45268 L F
.44048 .43458 m .45715 .4292 L .45464 .41771 L .597 .466 .673 r
F
.44364 .44613 m .45715 .4292 L .44048 .43458 L .609 .5 .705 r
F
0 g
.438 .42311 m
.44048 .43458 L
s
.64362 .40828 m .6383 .42842 L .64219 .40672 L .968 .753 .561 r
F
.64362 .40828 m .64119 .43149 L .6383 .42842 L F
.039 .916 .04 r
.54022 .37731 m
.54035 .37725 L
s
.49962 .40031 m .49128 .39483 L .4902 .38433 L .969 .687 .442 r
F
.50107 .40907 m .49128 .39483 L .49962 .40031 L F
.61696 .29557 m .6087 .2629 L .62044 .29279 L .969 .665 .39 r
F
.62957 .32466 m .61696 .29557 L .62044 .29279 L .97 .67 .394 r
F
.45286 .40652 m .48261 .38911 L .48131 .3764 L .407 .271 .582 r
F
.45464 .41771 m .48261 .38911 L .45286 .40652 L .437 .328 .632 r
F
0 g
.45182 .39584 m
.45286 .40652 L
s
.25178 .48134 m
.25743 .50252 L
s
.52838 .37215 m .50907 .35624 L .52863 .36469 L .818 .532 .505 r
F
.44743 .45756 m .46032 .44078 L .44364 .44613 L .618 .532 .734 r
F
.44743 .45756 m .46412 .45224 L .46032 .44078 L F
0 g
.44743 .45756 m
.45177 .46865 L
s
.62453 .51812 m .60495 .5494 L .59664 .54548 L .901 .9 .815 r
F
0 g
.60495 .5494 m
.61267 .55084 L
s
.6941 .36984 m .68516 .33946 L .68671 .34004 L .971 .662 .364 r
F
.63056 .36863 m .61496 .35191 L .61575 .34813 L .927 .609 .419 r
F
.63036 .37085 m .61496 .35191 L .63056 .36863 L .926 .618 .441 r
F
.54523 .3858 m .52875 .38034 L .52838 .37215 L .854 .582 .526 r
F
.54597 .39235 m .52875 .38034 L .54523 .3858 L .854 .597 .55 r
F
.44364 .44613 m .46032 .44078 L .45715 .4292 L .609 .5 .705 r
F
0 g
.44364 .44613 m
.44743 .45756 L
s
.44048 .43458 m
.44364 .44613 L
s
.52722 .48751 m .51963 .49168 L .52176 .47975 L .969 .687 .442 r
F
.52722 .48751 m .52621 .501 L .51963 .49168 L F
.65993 .41295 m .66246 .44148 L .65823 .41195 L .976 .69 .414 r
F
.65993 .41295 m .66584 .44342 L .66246 .44148 L F
.61575 .34813 m .5989 .32595 L .61691 .34505 L .892 .545 .382 r
F
.16565 .50151 m .16749 .47298 L .16057 .47527 L .592 .461 .671 r
F
0 g
.15744 .44973 m
.16057 .47527 L
s
.7166 .53122 m .71473 .56528 L .70642 .56676 L .996 .848 .576 r
F
0 g
.71473 .56528 m
.72195 .5607 L
s
.25743 .50252 m
.26439 .52343 L
s
.51564 .45315 m .50673 .45079 L .51192 .44484 L .969 .687 .442 r
F
.51564 .45315 m .51142 .46122 L .50673 .45079 L F
.64219 .40672 m .63537 .42463 L .64073 .40483 L .961 .745 .565 r
F
.64219 .40672 m .6383 .42842 L .63537 .42463 L F
.60399 .26645 m .59666 .23306 L .6087 .2629 L .967 .66 .387 r
F
.61696 .29557 m .60399 .26645 L .6087 .2629 L .969 .665 .39 r
F
.48683 .33919 m .50833 .29829 L .51131 .28716 L 0 0 0 r
F
.50907 .35624 m .48541 .34908 L .48683 .33919 L .776 .468 .466 r
F
.48541 .34908 m .50833 .29829 L .48683 .33919 L 0 0 .162 r
F
0 g
.48683 .33919 m
.48912 .33077 L
s
.66899 .44431 m .67149 .47417 L .66584 .44342 L .978 .696 .42 r
F
.66899 .44431 m .6762 .47538 L .67149 .47417 L F
.66892 .3105 m .65728 .28057 L .67147 .30964 L .943 .59 .308 r
F
.66892 .3105 m .6534 .28175 L .65728 .28057 L F
.64361 .46157 m .63119 .48621 L .63958 .45935 L .959 .846 .687 r
F
.64361 .46157 m .6366 .48907 L .63119 .48621 L F
.64091 .35523 m .62768 .3276 L .62957 .32466 L .972 .676 .4 r
F
.6402 .35721 m .62768 .3276 L .64091 .35523 L .972 .676 .402 r
F
.71154 .43141 m .71367 .46487 L .7091 .43259 L .995 .761 .459 r
F
.7038 .40036 m .71154 .43141 L .7091 .43259 L .989 .73 .431 r
F
.70484 .39929 m .71154 .43141 L .7038 .40036 L .989 .727 .417 r
F
.56165 .43983 m .54656 .44455 L .55855 .43375 L .885 .712 .661 r
F
.56165 .43983 m .55073 .45268 L .54656 .44455 L F
.6941 .36984 m .70484 .39929 L .7038 .40036 L .981 .696 .398 r
F
.47327 .47394 m .50132 .45699 L .46846 .46336 L .5 .522 .811 r
F
.47327 .47394 m .50702 .46963 L .50132 .45699 L F
0 g
.47327 .47394 m
.47844 .48378 L
s
.63036 .37085 m .61454 .35634 L .61496 .35191 L .926 .618 .441 r
F
.63036 .37334 m .61454 .35634 L .63036 .37085 L .925 .627 .461 r
F
.50107 .40907 m .49309 .40583 L .49128 .39483 L .969 .687 .442 r
F
.50306 .41807 m .49309 .40583 L .50107 .40907 L F
.48984 .37452 m .48117 .36484 L .48166 .35411 L F
.4902 .38433 m .48117 .36484 L .48984 .37452 L F
.54597 .39235 m .52972 .3891 L .52875 .38034 L .854 .597 .55 r
F
.54714 .39921 m .52972 .3891 L .54597 .39235 L .855 .613 .572 r
F
.62453 .51812 m .59664 .54548 L .6177 .51469 L .901 .9 .815 r
F
.6366 .48907 m .62453 .51812 L .6177 .51469 L .936 .875 .751 r
F
.039 .916 .04 r
.64328 .3702 m
.6433 .37019 L
s
.64328 .3702 m
.64328 .3702 L
s
.64328 .3702 m
.64328 .3702 L
s
.64327 .3702 m
.64328 .3702 L
s
.63118 .37407 m
.63999 .37125 L
s
.55357 .49088 m .53201 .50269 L .54786 .48398 L .864 .779 .765 r
F
.55357 .49088 m .53893 .51092 L .53201 .50269 L F
.45715 .4292 m .48479 .40245 L .45464 .41771 L .46 .375 .674 r
F
.45464 .41771 m .48479 .40245 L .48261 .38911 L .437 .328 .632 r
F
0 g
.45286 .40652 m
.45464 .41771 L
s
.6941 .36984 m .68374 .3394 L .68516 .33946 L .971 .662 .368 r
F
.64073 .40483 m .63246 .4202 L .63929 .40261 L .954 .735 .567 r
F
.64073 .40483 m .63537 .42463 L .63246 .4202 L F
.5596 .4666 m .54219 .47583 L .5551 .46008 L .879 .751 .717 r
F
.5596 .4666 m .54786 .48398 L .54219 .47583 L F
.6366 .48907 m .6177 .51469 L .63119 .48621 L .936 .875 .751 r
F
.59067 .23731 m .5843 .20328 L .59666 .23306 L .965 .655 .383 r
F
.60399 .26645 m .59067 .23731 L .59666 .23306 L .967 .66 .387 r
F
.51192 .44484 m .50247 .43983 L .50853 .43612 L .969 .687 .442 r
F
.51192 .44484 m .50673 .45079 L .50247 .43983 L F
.644 .43381 m .63534 .45593 L .64119 .43149 L .962 .797 .63 r
F
.644 .43381 m .63958 .45935 L .63534 .45593 L F
.16565 .50151 m .17259 .49925 L .16749 .47298 L .592 .461 .671 r
F
0 g
.16434 .44742 m
.16749 .47298 L
s
.65823 .41195 m .65889 .43852 L .65646 .41044 L .976 .69 .416 r
F
.65823 .41195 m .66246 .44148 L .65889 .43852 L F
.63036 .37334 m .6145 .36133 L .61454 .35634 L .925 .627 .461 r
F
.63054 .37607 m .6145 .36133 L .63036 .37334 L .924 .636 .479 r
F
.50306 .41807 m .49559 .41714 L .49309 .40583 L .969 .687 .442 r
F
.50557 .42714 m .49559 .41714 L .50306 .41807 L F
.7166 .53122 m .70642 .56676 L .70969 .53222 L .996 .848 .576 r
F
.7162 .49775 m .7166 .53122 L .70969 .53222 L .997 .82 .544 r
F
.62768 .3276 m .61696 .29557 L .62957 .32466 L .97 .671 .398 r
F
.55855 .43375 m .54268 .43582 L .55566 .42723 L .877 .694 .651 r
F
.55855 .43375 m .54656 .44455 L .54268 .43582 L F
.19156 .5791 m .18827 .55176 L .18131 .55396 L .623 .561 .765 r
F
.19156 .5791 m .19852 .57692 L .18827 .55176 L F
0 g
.19156 .5791 m
.20314 .60281 L
s
.19852 .57692 m
.2101 .60067 L
s
.68248 .33987 m .67147 .30964 L .68374 .3394 L .958 .628 .341 r
F
.68248 .33987 m .66892 .3105 L .67147 .30964 L F
.50853 .43612 m .49874 .42854 L .50557 .42714 L .969 .687 .442 r
F
.50853 .43612 m .50247 .43983 L .49874 .42854 L F
.5971 .33053 m .5769 .3081 L .5989 .32595 L .849 .487 .366 r
F
.61575 .34813 m .5971 .33053 L .5989 .32595 L .892 .545 .382 r
F
.46846 .46336 m .49616 .4437 L .46412 .45224 L .496 .489 .778 r
F
.46846 .46336 m .50132 .45699 L .49616 .4437 L F
0 g
.46846 .46336 m
.47327 .47394 L
s
.50557 .42714 m .49874 .42854 L .49559 .41714 L .969 .687 .442 r
F
.63929 .40261 m .62962 .41521 L .63788 .40012 L .948 .725 .566 r
F
.63929 .40261 m .63246 .4202 L .62962 .41521 L F
.6402 .35721 m .62622 .33151 L .62768 .3276 L .972 .676 .402 r
F
.63972 .35963 m .62622 .33151 L .6402 .35721 L .972 .677 .404 r
F
.59067 .23731 m .577 .20816 L .5843 .20328 L .965 .655 .383 r
F
.577 .20816 m .59433 .19977 L .5843 .20328 L 0 0 0 r
F
0 g
.58912 .20229 m
.59257 .20158 L
s
.54873 .40625 m .53127 .39828 L .54714 .39921 L .857 .629 .592 r
F
.54714 .39921 m .53127 .39828 L .52972 .3891 L .855 .613 .572 r
F
.7038 .40036 m .7091 .43259 L .70256 .40091 L .989 .73 .431 r
F
.6941 .36984 m .7038 .40036 L .70256 .40091 L .981 .697 .402 r
F
.039 .916 .04 r
.70373 .3826 m
.8836 .32164 L
s
.70368 .38261 m
.70373 .3826 L
s
.52838 .37215 m .50871 .36557 L .50907 .35624 L .818 .532 .505 r
F
.52875 .38034 m .50871 .36557 L .52838 .37215 L .818 .552 .537 r
F
.61496 .35191 m .5971 .33053 L .61575 .34813 L .889 .56 .419 r
F
.45715 .4292 m .48781 .41617 L .48479 .40245 L .46 .375 .674 r
F
.46032 .44078 m .48781 .41617 L .45715 .4292 L .476 .417 .711 r
F
0 g
.45464 .41771 m
.45715 .4292 L
s
.63054 .37607 m .61485 .36679 L .6145 .36133 L .924 .636 .479 r
F
.039 .916 .04 r
.55626 .38621 m
.61463 .36334 L
s
.6163 .36269 m
.61644 .36263 L
s
.61644 .36263 m
.61645 .36263 L
s
.63091 .37898 m .61485 .36679 L .63054 .37607 L .924 .645 .495 r
F
.54663 .2994 m .51539 .27825 L .54987 .29191 L .735 .348 .318 r
F
.54663 .2994 m .51131 .28716 L .51539 .27825 L F
0 g
.51539 .27825 m
.52048 .27168 L
s
.6762 .47538 m .67688 .50518 L .67149 .47417 L .979 .701 .426 r
F
.6762 .47538 m .68314 .50665 L .67688 .50518 L F
.55566 .42723 m .53914 .42666 L .55303 .42039 L .87 .677 .638 r
F
.55566 .42723 m .54268 .43582 L .53914 .42666 L F
.50871 .36557 m .48541 .34908 L .50907 .35624 L .778 .496 .509 r
F
.17261 .52793 m .17259 .49925 L .16565 .50151 L .604 .496 .704 r
F
0 g
.16057 .47527 m
.16565 .50151 L
s
.52176 .47975 m .51324 .48108 L .51646 .47093 L .969 .687 .442 r
F
.52176 .47975 m .51963 .49168 L .51324 .48108 L F
0 g
.48091 .36454 m
.4814 .35376 L
s
.46412 .45224 m .49163 .43 L .46032 .44078 L .488 .454 .746 r
F
.46412 .45224 m .49616 .4437 L .49163 .43 L F
0 g
.46412 .45224 m
.46846 .46336 L
s
.63788 .40012 m .6269 .40974 L .63653 .3974 L .943 .715 .564 r
F
.63788 .40012 m .62962 .41521 L .6269 .40974 L F
.7162 .49775 m .70969 .53222 L .71067 .49837 L .997 .82 .544 r
F
.71367 .46487 m .7162 .49775 L .71067 .49837 L .996 .791 .512 r
F
.54873 .40625 m .53339 .40772 L .53127 .39828 L .857 .629 .592 r
F
.5507 .41335 m .53339 .40772 L .54873 .40625 L .86 .644 .609 r
F
.46032 .44078 m .49163 .43 L .48781 .41617 L .476 .417 .711 r
F
0 g
.46032 .44078 m
.46412 .45224 L
s
.45715 .4292 m
.46032 .44078 L
s
.6941 .36984 m .68248 .33987 L .68374 .3394 L .97 .663 .373 r
F
.65646 .41044 m .65522 .43458 L .65463 .40845 L .975 .69 .417 r
F
.65646 .41044 m .65889 .43852 L .65522 .43458 L F
.63091 .37898 m .61558 .37265 L .61485 .36679 L .924 .645 .495 r
F
.63147 .38202 m .61558 .37265 L .63091 .37898 L .924 .655 .51 r
F
.55303 .42039 m .53603 .41724 L .5507 .41335 L .865 .66 .625 r
F
.55303 .42039 m .53914 .42666 L .53603 .41724 L F
.5507 .41335 m .53603 .41724 L .53339 .40772 L .86 .644 .609 r
F
.57442 .31415 m .54987 .29191 L .5769 .3081 L .799 .423 .345 r
F
.5971 .33053 m .57442 .31415 L .5769 .3081 L .849 .487 .366 r
F
.53893 .51092 m .56964 .51925 L .53201 .50269 L .078 .429 .872 r
F
.53893 .51092 m .57883 .5303 L .56964 .51925 L F
0 g
.53893 .51092 m
.5458 .5175 L
s
.63653 .3974 m .62435 .40388 L .63527 .39449 L .938 .705 .559 r
F
.63653 .3974 m .6269 .40974 L .62435 .40388 L F
.63219 .38515 m .61669 .37878 L .63147 .38202 L .926 .665 .523 r
F
.63147 .38202 m .61669 .37878 L .61558 .37265 L .924 .655 .51 r
F
.57442 .31415 m .54663 .2994 L .54987 .29191 L .799 .423 .345 r
F
.18131 .55396 m .17957 .52569 L .17261 .52793 L .614 .529 .735 r
F
.18131 .55396 m .18827 .55176 L .17957 .52569 L F
0 g
.18131 .55396 m
.19156 .5791 L
s
.18827 .55176 m
.19852 .57692 L
s
.63972 .35963 m .62522 .33633 L .62622 .33151 L .972 .677 .404 r
F
.63947 .36246 m .62522 .33633 L .63972 .35963 L .972 .678 .406 r
F
.71367 .46487 m .71067 .49837 L .70952 .46521 L .996 .791 .512 r
F
.7091 .43259 m .71367 .46487 L .70952 .46521 L .993 .762 .478 r
F
.6941 .36984 m .6814 .34086 L .68248 .33987 L .97 .664 .377 r
F
.6941 .36984 m .68052 .34236 L .6814 .34086 L .97 .665 .382 r
F
.6941 .36984 m .67986 .34434 L .68052 .34236 L .97 .667 .387 r
F
.6941 .36984 m .67942 .34676 L .67986 .34434 L .97 .669 .392 r
F
.6941 .36984 m .67921 .34959 L .67942 .34676 L .97 .67 .397 r
F
.6941 .36984 m .67925 .35279 L .67921 .34959 L .97 .672 .401 r
F
.6941 .36984 m .67953 .35629 L .67925 .35279 L .97 .674 .405 r
F
.6941 .36984 m .68004 .36003 L .67953 .35629 L .971 .676 .409 r
F
.039 .916 .04 r
.68331 .35727 m
.68336 .35725 L
s
.68322 .35729 m
.68326 .35728 L
s
.68319 .35731 m
.6832 .3573 L
s
.6433 .37019 m
.67982 .35839 L
s
.6832 .3573 m
.68322 .35729 L
s
.68326 .35728 m
.68331 .35727 L
s
.68336 .35725 m
.68337 .35725 L
s
.6941 .36984 m .68078 .36395 L .68004 .36003 L .971 .679 .413 r
F
.6941 .36984 m .68173 .36798 L .68078 .36395 L .971 .681 .416 r
F
.6941 .36984 m .68289 .37205 L .68173 .36798 L .972 .683 .419 r
F
.6941 .36984 m .68422 .37609 L .68289 .37205 L .973 .685 .421 r
F
.039 .916 .04 r
.65375 .38276 m
.6833 .3733 L
s
.6941 .36984 m .6857 .38003 L .68422 .37609 L .973 .687 .422 r
F
.6941 .36984 m .68731 .38379 L .6857 .38003 L .974 .689 .423 r
F
.6941 .36984 m .68902 .38731 L .68731 .38379 L .975 .691 .424 r
F
.6941 .36984 m .6908 .39053 L .68902 .38731 L .976 .693 .424 r
F
.6941 .36984 m .69262 .3934 L .6908 .39053 L .976 .694 .423 r
F
.6941 .36984 m .69444 .39586 L .69262 .3934 L .977 .695 .422 r
F
.6941 .36984 m .69624 .39787 L .69444 .39586 L .978 .696 .42 r
F
.6941 .36984 m .69798 .3994 L .69624 .39787 L .979 .697 .417 r
F
.6941 .36984 m .69963 .40043 L .69798 .3994 L .979 .698 .414 r
F
.6941 .36984 m .70117 .40093 L .69963 .40043 L .98 .698 .411 r
F
.6941 .36984 m .70256 .40091 L .70117 .40093 L .98 .698 .407 r
F
0 0 0 r
2 Mabswid
.6941 .36984 Mdot
.039 .916 .04 r
.5 Mabswid
.6941 .36984 m
.87649 .31145 L
s
.63527 .39449 m .62201 .39774 L .63411 .39144 L .934 .695 .553 r
F
.63527 .39449 m .62435 .40388 L .62201 .39774 L F
.66584 .44342 m .66641 .47136 L .66246 .44148 L .977 .696 .422 r
F
.66584 .44342 m .67149 .47417 L .66641 .47136 L F
.4902 .38433 m .48157 .37663 L .48117 .36484 L .969 .687 .442 r
F
.49128 .39483 m .48157 .37663 L .4902 .38433 L F
.5551 .46008 m .53668 .46659 L .55073 .45268 L .867 .728 .707 r
F
.5551 .46008 m .54219 .47583 L .53668 .46659 L F
.64119 .43149 m .63097 .45136 L .6383 .42842 L .951 .781 .636 r
F
.64119 .43149 m .63534 .45593 L .63097 .45136 L F
.63219 .38515 m .61815 .38508 L .61669 .37878 L .926 .665 .523 r
F
.63308 .38831 m .61815 .38508 L .63219 .38515 L .928 .674 .535 r
F
.17261 .52793 m .17957 .52569 L .17259 .49925 L .604 .496 .704 r
F
0 g
.17261 .52793 m
.18131 .55396 L
s
.16565 .50151 m
.17261 .52793 L
s
.16749 .47298 m
.17259 .49925 L
s
.63411 .39144 m .61993 .39144 L .63308 .38831 L .93 .684 .545 r
F
.63411 .39144 m .62201 .39774 L .61993 .39144 L F
.63308 .38831 m .61993 .39144 L .61815 .38508 L .928 .674 .535 r
F
.7091 .43259 m .70952 .46521 L .70632 .43273 L .993 .762 .478 r
F
.70256 .40091 m .7091 .43259 L .70632 .43273 L .988 .731 .444 r
F
.70256 .40091 m .70632 .43273 L .70117 .40093 L F
.61033 .23053 m .59433 .19977 L .6162 .22632 L .886 .485 .255 r
F
.61033 .23053 m .5871 .20462 L .59433 .19977 L F
.577 .20816 m .5871 .20462 L .59433 .19977 L 0 0 0 r
F
0 g
.59433 .19977 m
.60253 .1981 L
s
.17259 .49925 m
.17957 .52569 L
s
.63958 .45935 m .62549 .48174 L .63534 .45593 L .944 .823 .695 r
F
.63958 .45935 m .63119 .48621 L .62549 .48174 L F
.65463 .40845 m .65149 .42973 L .65278 .40602 L .975 .689 .418 r
F
.65463 .40845 m .65522 .43458 L .65149 .42973 L F
.61406 .29988 m .60399 .26645 L .61696 .29557 L .968 .666 .396 r
F
.62768 .3276 m .61406 .29988 L .61696 .29557 L .97 .671 .398 r
F
.68314 .50665 m .68199 .53647 L .67688 .50518 L .98 .706 .433 r
F
.68314 .50665 m .6898 .5381 L .68199 .53647 L F
.6814 .34086 m .66892 .3105 L .68248 .33987 L .958 .631 .356 r
F
.52875 .38034 m .50912 .37582 L .50871 .36557 L .818 .552 .537 r
F
.52972 .3891 m .50912 .37582 L .52875 .38034 L .818 .571 .565 r
F
.61496 .35191 m .59585 .33617 L .5971 .33053 L .889 .56 .419 r
F
.61454 .35634 m .59585 .33617 L .61496 .35191 L .887 .575 .451 r
F
.54786 .48398 m .52514 .49295 L .54219 .47583 L .85 .75 .753 r
F
.54786 .48398 m .53201 .50269 L .52514 .49295 L F
0 g
.52618 .50141 m
.53286 .50933 L
s
.63947 .36246 m .6247 .34198 L .62522 .33633 L .972 .678 .406 r
F
.63947 .36565 m .6247 .34198 L .63947 .36246 L .972 .679 .408 r
F
0 g
.17957 .52569 m
.18827 .55176 L
s
.62622 .33151 m .61406 .29988 L .62768 .3276 L .97 .672 .401 r
F
.63126 .25718 m .6162 .22632 L .63585 .25367 L .908 .524 .283 r
F
.63126 .25718 m .61033 .23053 L .6162 .22632 L F
.48541 .34908 m .50651 .31147 L .50833 .29829 L 0 0 .162 r
F
.50871 .36557 m .4849 .36029 L .48541 .34908 L .778 .496 .509 r
F
.4849 .36029 m .50651 .31147 L .48541 .34908 L 0 0 .315 r
F
0 g
.48541 .34908 m
.48683 .33919 L
s
.51646 .47093 m .50715 .46938 L .51142 .46122 L .969 .687 .442 r
F
.51646 .47093 m .51324 .48108 L .50715 .46938 L F
.66672 .3124 m .6534 .28175 L .66892 .3105 L .943 .597 .333 r
F
.6814 .34086 m .66672 .3124 L .66892 .3105 L .958 .631 .356 r
F
.65003 .28449 m .63585 .25367 L .6534 .28175 L .926 .562 .309 r
F
.65003 .28449 m .63126 .25718 L .63585 .25367 L F
.66672 .3124 m .65003 .28449 L .6534 .28175 L .943 .597 .333 r
F
.59585 .33617 m .57442 .31415 L .5971 .33053 L .847 .51 .415 r
F
.65278 .40602 m .64777 .42405 L .65094 .40318 L .975 .689 .418 r
F
.65278 .40602 m .65149 .42973 L .64777 .42405 L F
.70117 .40093 m .70325 .4318 L .69963 .40043 L .986 .73 .454 r
F
.70117 .40093 m .70632 .43273 L .70325 .4318 L F
.55073 .45268 m .53142 .4564 L .54656 .44455 L .856 .706 .695 r
F
.55073 .45268 m .53668 .46659 L .53142 .4564 L F
.6383 .42842 m .62654 .44571 L .63537 .42463 L .94 .765 .638 r
F
.6383 .42842 m .63097 .45136 L .62654 .44571 L F
.49128 .39483 m .48286 .38928 L .48157 .37663 L .969 .687 .442 r
F
.49309 .40583 m .48286 .38928 L .49128 .39483 L F
.63947 .36565 m .62467 .34837 L .6247 .34198 L .972 .679 .408 r
F
.63972 .36914 m .62467 .34837 L .63947 .36565 L .972 .679 .41 r
F
.50912 .37582 m .4849 .36029 L .50871 .36557 L .779 .521 .545 r
F
.63119 .48621 m .6105 .50923 L .62549 .48174 L .918 .843 .755 r
F
.63119 .48621 m .6177 .51469 L .6105 .50923 L F
.68052 .34236 m .66672 .3124 L .6814 .34086 L .957 .635 .37 r
F
.6898 .5381 m .68683 .56803 L .68199 .53647 L .981 .711 .439 r
F
.6898 .5381 m .69617 .56974 L .68683 .56803 L F
.52972 .3891 m .5103 .38681 L .50912 .37582 L .818 .571 .565 r
F
.53127 .39828 m .5103 .38681 L .52972 .3891 L .82 .59 .59 r
F
.65094 .40318 m .64414 .41763 L .64914 .39999 L .974 .688 .419 r
F
.65094 .40318 m .64777 .42405 L .64414 .41763 L F
0 g
.48091 .36454 m
.48131 .3764 L
s
.61454 .35634 m .59517 .3428 L .59585 .33617 L .887 .575 .451 r
F
.6145 .36133 m .59517 .3428 L .61454 .35634 L .885 .589 .48 r
F
.66246 .44148 m .66106 .467 L .65889 .43852 L .977 .695 .424 r
F
.66246 .44148 m .66641 .47136 L .66106 .467 L F
.6177 .51469 m .59664 .54548 L .58788 .53908 L .883 .859 .812 r
F
0 g
.59664 .54548 m
.60495 .5494 L
s
.63972 .36914 m .62514 .35538 L .62467 .34837 L .972 .679 .41 r
F
.6402 .37287 m .62514 .35538 L .63972 .36914 L .972 .68 .412 r
F
.60005 .27207 m .59067 .23731 L .60399 .26645 L .966 .662 .393 r
F
.61406 .29988 m .60005 .27207 L .60399 .26645 L .968 .666 .396 r
F
.51142 .46122 m .50148 .45681 L .50673 .45079 L .969 .687 .442 r
F
.51142 .46122 m .50715 .46938 L .50148 .45681 L F
.69963 .40043 m .69994 .42982 L .69798 .3994 L .984 .729 .464 r
F
.69963 .40043 m .70325 .4318 L .69994 .42982 L F
.6177 .51469 m .58788 .53908 L .6105 .50923 L .883 .859 .812 r
F
.70632 .43273 m .70491 .46394 L .70325 .4318 L .99 .76 .495 r
F
.70632 .43273 m .70952 .46521 L .70491 .46394 L F
.67149 .47417 m .6701 .50159 L .66641 .47136 L .978 .701 .43 r
F
.67149 .47417 m .67688 .50518 L .6701 .50159 L F
.54656 .44455 m .52653 .44546 L .54268 .43582 L .847 .685 .682 r
F
.54656 .44455 m .53142 .4564 L .52653 .44546 L F
.64914 .39999 m .64066 .41059 L .64742 .39649 L .974 .687 .419 r
F
.64914 .39999 m .64414 .41763 L .64066 .41059 L F
.53201 .50269 m .56049 .50612 L .52514 .49295 L .157 .433 .869 r
F
.53201 .50269 m .56964 .51925 L .56049 .50612 L F
0 g
.53201 .50269 m
.53893 .51092 L
s
.49309 .40583 m .48503 .40255 L .48286 .38928 L .969 .687 .442 r
F
.49559 .41714 m .48503 .40255 L .49309 .40583 L F
.63534 .45593 m .61961 .47571 L .63097 .45136 L .928 .8 .698 r
F
.63534 .45593 m .62549 .48174 L .61961 .47571 L F
.6402 .37287 m .6261 .36289 L .62514 .35538 L .972 .68 .412 r
F
.039 .916 .04 r
.61645 .36263 m
.62569 .35967 L
s
.63249 .35749 m
.6325 .35749 L
s
.6325 .35749 m
.63252 .35748 L
s
.63252 .35748 m
.63253 .35748 L
s
.64092 .37677 m .6261 .36289 L .6402 .37287 L .972 .681 .414 r
F
.63537 .42463 m .62213 .43907 L .63246 .4202 L .929 .749 .637 r
F
.63537 .42463 m .62654 .44571 L .62213 .43907 L F
.68052 .34236 m .66492 .31533 L .66672 .3124 L .957 .635 .37 r
F
.67986 .34434 m .66492 .31533 L .68052 .34236 L .957 .64 .385 r
F
.54219 .47583 m .51846 .48186 L .53668 .46659 L .836 .723 .739 r
F
.54219 .47583 m .52514 .49295 L .51846 .48186 L F
0 g
.51957 .49205 m
.52618 .50141 L
s
.53127 .39828 m .51222 .39834 L .5103 .38681 L .82 .59 .59 r
F
.53339 .40772 m .51222 .39834 L .53127 .39828 L .823 .609 .612 r
F
.62622 .33151 m .61181 .30567 L .61406 .29988 L .97 .672 .401 r
F
.62522 .33633 m .61181 .30567 L .62622 .33151 L .97 .673 .405 r
F
.57267 .32164 m .54663 .2994 L .57442 .31415 L .8 .457 .407 r
F
.59585 .33617 m .57267 .32164 L .57442 .31415 L .847 .51 .415 r
F
.64742 .39649 m .63739 .40306 L .6458 .39276 L .974 .686 .419 r
F
.64742 .39649 m .64066 .41059 L .63739 .40306 L F
.69617 .56974 m .69714 .56502 L .68683 .56803 L .464 .878 .94 r
F
.69617 .56974 m .70642 .56676 L .69714 .56502 L F
0 g
.69617 .56974 m
.70455 .56824 L
s
.64092 .37677 m .62753 .37077 L .6261 .36289 L .972 .681 .414 r
F
.64185 .38079 m .62753 .37077 L .64092 .37677 L .972 .682 .415 r
F
.50673 .45079 m .49634 .44358 L .50247 .43983 L .969 .687 .442 r
F
.50673 .45079 m .50148 .45681 L .49634 .44358 L F
.6145 .36133 m .59507 .35029 L .59517 .3428 L .885 .589 .48 r
F
.61485 .36679 m .59507 .35029 L .6145 .36133 L .884 .603 .506 r
F
.54268 .43582 m .52208 .43397 L .53914 .42666 L .839 .665 .667 r
F
.54268 .43582 m .52653 .44546 L .52208 .43397 L F
.66492 .31533 m .65003 .28449 L .66672 .3124 L .942 .605 .357 r
F
.70952 .46521 m .70453 .49686 L .70491 .46394 L .991 .788 .533 r
F
.70952 .46521 m .71067 .49837 L .70453 .49686 L F
.6458 .39276 m .63439 .39516 L .64432 .38885 L .973 .685 .418 r
F
.6458 .39276 m .63739 .40306 L .63439 .39516 L F
.49559 .41714 m .48804 .4162 L .48503 .40255 L .969 .687 .442 r
F
.49874 .42854 m .48804 .4162 L .49559 .41714 L F
.64185 .38079 m .62941 .37887 L .62753 .37077 L .972 .682 .415 r
F
.64299 .38483 m .62941 .37887 L .64185 .38079 L .973 .684 .416 r
F
.69798 .3994 m .69645 .42682 L .69624 .39787 L .981 .727 .471 r
F
.69798 .3994 m .69994 .42982 L .69645 .42682 L F
.53339 .40772 m .51486 .41019 L .51222 .39834 L .823 .609 .612 r
F
.53603 .41724 m .51486 .41019 L .53339 .40772 L .827 .627 .632 r
F
.59517 .3428 m .57267 .32164 L .59585 .33617 L .845 .531 .457 r
F
.64432 .38885 m .63171 .38705 L .64299 .38483 L .973 .685 .417 r
F
.64432 .38885 m .63439 .39516 L .63171 .38705 L F
.50912 .37582 m .48533 .37261 L .4849 .36029 L .779 .521 .545 r
F
.5103 .38681 m .48533 .37261 L .50912 .37582 L .782 .544 .577 r
F
.64299 .38483 m .63171 .38705 L .62941 .37887 L .973 .684 .416 r
F
.4849 .36029 m .50592 .32647 L .50651 .31147 L 0 0 .315 r
F
.48533 .37261 m .50592 .32647 L .4849 .36029 L .041 0 .429 r
F
0 g
.4849 .36029 m
.48541 .34908 L
s
.50247 .43983 m .49183 .42996 L .49874 .42854 L .969 .687 .442 r
F
.50247 .43983 m .49634 .44358 L .49183 .42996 L F
.53914 .42666 m .51817 .42214 L .53603 .41724 L .833 .646 .65 r
F
.53914 .42666 m .52208 .43397 L .51817 .42214 L F
.61181 .30567 m .60005 .27207 L .61406 .29988 L .968 .668 .401 r
F
.53603 .41724 m .51817 .42214 L .51486 .41019 L .827 .627 .632 r
F
.49874 .42854 m .49183 .42996 L .48804 .4162 L .969 .687 .442 r
F
.67986 .34434 m .66354 .31923 L .66492 .31533 L .957 .64 .385 r
F
.67942 .34676 m .66354 .31923 L .67986 .34434 L .956 .644 .398 r
F
.63246 .4202 m .61783 .43157 L .62962 .41521 L .92 .733 .633 r
F
.63246 .4202 m .62213 .43907 L .61783 .43157 L F
.71067 .49837 m .70199 .53055 L .70453 .49686 L .991 .814 .57 r
F
.71067 .49837 m .70969 .53222 L .70199 .53055 L F
.54431 .30872 m .51131 .28716 L .54663 .2994 L .743 .396 .395 r
F
.57267 .32164 m .54431 .30872 L .54663 .2994 L .8 .457 .407 r
F
.58565 .24417 m .577 .20816 L .59067 .23731 L .964 .657 .391 r
F
.60005 .27207 m .58565 .24417 L .59067 .23731 L .966 .662 .393 r
F
.54431 .30872 m .50833 .29829 L .51131 .28716 L .743 .396 .395 r
F
0 g
.51131 .28716 m
.51539 .27825 L
s
.65889 .43852 m .65551 .46115 L .65522 .43458 L .976 .695 .426 r
F
.65889 .43852 m .66106 .467 L .65551 .46115 L F
0 g
.48131 .3764 m
.48261 .38911 L
s
.61485 .36679 m .59556 .35852 L .59507 .35029 L .884 .603 .506 r
F
.039 .916 .04 r
.54035 .37725 m
.59525 .3533 L
s
.59814 .35204 m
.59836 .35194 L
s
.61558 .37265 m .59556 .35852 L .61485 .36679 L .884 .616 .528 r
F
.70969 .53222 m .69714 .56502 L .70199 .53055 L .988 .838 .605 r
F
.70969 .53222 m .70642 .56676 L .69714 .56502 L F
0 g
.70642 .56676 m
.71473 .56528 L
s
.69624 .39787 m .69283 .42283 L .69444 .39586 L .979 .724 .477 r
F
.69624 .39787 m .69645 .42682 L .69283 .42283 L F
.53668 .46659 m .5121 .46963 L .53142 .4564 L .825 .698 .724 r
F
.53668 .46659 m .51846 .48186 L .5121 .46963 L F
.64725 .28878 m .63126 .25718 L .65003 .28449 L .926 .573 .343 r
F
.66492 .31533 m .64725 .28878 L .65003 .28449 L .942 .605 .357 r
F
.70325 .4318 m .69994 .46109 L .69994 .42982 L .985 .757 .508 r
F
.70325 .4318 m .70491 .46394 L .69994 .46109 L F
.039 .916 .04 r
.68337 .35725 m
.86931 .30116 L
s
0 0 0 r
2 Mabswid
.68337 .35725 Mdot
.62549 .48174 m .60306 .50179 L .61961 .47571 L .9 .812 .752 r
F
.62549 .48174 m .6105 .50923 L .60306 .50179 L F
.62962 .41521 m .61371 .42333 L .6269 .40974 L .912 .717 .627 r
F
.62962 .41521 m .61783 .43157 L .61371 .42333 L F
.67942 .34676 m .66262 .32405 L .66354 .31923 L .956 .644 .398 r
F
.67921 .34959 m .66262 .32405 L .67942 .34676 L .956 .649 .411 r
F
.63097 .45136 m .61364 .46822 L .62654 .44571 L .914 .777 .696 r
F
.63097 .45136 m .61961 .47571 L .61364 .46822 L F
.62522 .33633 m .61025 .31286 L .61181 .30567 L .97 .673 .405 r
F
.6247 .34198 m .61025 .31286 L .62522 .33633 L .97 .674 .408 r
F
.67688 .50518 m .67352 .53216 L .6701 .50159 L .979 .705 .437 r
F
.67688 .50518 m .68199 .53647 L .67352 .53216 L F
.61558 .37265 m .59664 .36734 L .59556 .35852 L .884 .616 .528 r
F
.61669 .37878 m .59664 .36734 L .61558 .37265 L .884 .63 .549 r
F
.52514 .49295 m .55155 .49113 L .51846 .48186 L .209 .422 .851 r
F
0 g
.5 Mabswid
.51314 .48139 m
.51957 .49205 L
s
.52514 .49295 m .56049 .50612 L .55155 .49113 L .209 .422 .851 r
F
0 g
.52514 .49295 m
.53201 .50269 L
s
.5103 .38681 m .48669 .38583 L .48533 .37261 L .782 .544 .577 r
F
.51222 .39834 m .48669 .38583 L .5103 .38681 L .785 .566 .604 r
F
.69444 .39586 m .68916 .41793 L .69262 .3934 L .976 .72 .481 r
F
.69444 .39586 m .69283 .42283 L .68916 .41793 L F
0 g
.50702 .46963 m
.51314 .48139 L
s
.66354 .31923 m .64725 .28878 L .66492 .31533 L .941 .612 .38 r
F
.6269 .40974 m .60984 .41449 L .62435 .40388 L .904 .702 .618 r
F
.6269 .40974 m .61371 .42333 L .60984 .41449 L F
.59517 .3428 m .57168 .33046 L .57267 .32164 L .845 .531 .457 r
F
.59507 .35029 m .57168 .33046 L .59517 .3428 L .844 .551 .493 r
F
.62745 .26278 m .61033 .23053 L .63126 .25718 L .907 .541 .328 r
F
.64725 .28878 m .62745 .26278 L .63126 .25718 L .926 .573 .343 r
F
.66641 .47136 m .66294 .49589 L .66106 .467 L .977 .7 .433 r
F
.66641 .47136 m .6701 .50159 L .66294 .49589 L F
.58565 .24417 m .57084 .21619 L .577 .20816 L .964 .657 .391 r
F
.57084 .21619 m .5871 .20462 L .577 .20816 L .163 0 0 r
F
0 g
.577 .20816 m
.5843 .20328 L
s
.67921 .34959 m .66218 .32971 L .66262 .32405 L .956 .649 .411 r
F
.67925 .35279 m .66218 .32971 L .67921 .34959 L .956 .655 .423 r
F
.61669 .37878 m .59829 .37659 L .59664 .36734 L .884 .63 .549 r
F
.61815 .38508 m .59829 .37659 L .61669 .37878 L .886 .644 .566 r
F
.53142 .4564 m .50618 .45647 L .52653 .44546 L .815 .674 .708 r
F
.53142 .4564 m .5121 .46963 L .50618 .45647 L F
.65522 .43458 m .64987 .4539 L .65149 .42973 L .975 .694 .428 r
F
.65522 .43458 m .65551 .46115 L .64987 .4539 L F
.57168 .33046 m .54431 .30872 L .57267 .32164 L .8 .486 .458 r
F
.48533 .37261 m .50659 .34305 L .50592 .32647 L .041 0 .429 r
F
.48669 .38583 m .50659 .34305 L .48533 .37261 L .119 .064 .515 r
F
0 g
.4849 .36029 m
.48533 .37261 L
s
.62435 .40388 m .60631 .40523 L .62201 .39774 L .898 .687 .608 r
F
.62435 .40388 m .60984 .41449 L .60631 .40523 L F
0 g
.48261 .38911 m
.48479 .40245 L
s
.61815 .38508 m .60048 .38611 L .59829 .37659 L .886 .644 .566 r
F
.61993 .39144 m .60048 .38611 L .61815 .38508 L .889 .658 .582 r
F
.69262 .3934 m .68549 .41219 L .6908 .39053 L .973 .716 .484 r
F
.69262 .3934 m .68916 .41793 L .68549 .41219 L F
.6105 .50923 m .57883 .5303 L .60306 .50179 L .865 .82 .803 r
F
.6105 .50923 m .58788 .53908 L .57883 .5303 L F
0 g
.58788 .53908 m
.59664 .54548 L
s
.62201 .39774 m .60317 .39571 L .61993 .39144 L .893 .672 .596 r
F
.62201 .39774 m .60631 .40523 L .60317 .39571 L F
.51222 .39834 m .48897 .39971 L .48669 .38583 L .785 .566 .604 r
F
.51486 .41019 m .48897 .39971 L .51222 .39834 L .789 .588 .629 r
F
.61993 .39144 m .60317 .39571 L .60048 .38611 L .889 .658 .582 r
F
.60541 .23737 m .5871 .20462 L .61033 .23053 L .887 .507 .311 r
F
.62745 .26278 m .60541 .23737 L .61033 .23053 L .907 .541 .328 r
F
.67925 .35279 m .66222 .3361 L .66218 .32971 L .956 .655 .423 r
F
.67953 .35629 m .66222 .3361 L .67925 .35279 L .956 .66 .434 r
F
.59697 .27969 m .58565 .24417 L .60005 .27207 L .966 .663 .4 r
F
.61181 .30567 m .59697 .27969 L .60005 .27207 L .968 .668 .401 r
F
.6247 .34198 m .60942 .32132 L .61025 .31286 L .97 .674 .408 r
F
.62467 .34837 m .60942 .32132 L .6247 .34198 L .97 .676 .412 r
F
.70491 .46394 m .69787 .4932 L .69994 .46109 L .985 .782 .55 r
F
.70491 .46394 m .70453 .49686 L .69787 .4932 L F
.69994 .42982 m .69467 .45667 L .69645 .42682 L .981 .752 .519 r
F
.69994 .42982 m .69994 .46109 L .69467 .45667 L F
.62654 .44571 m .6077 .45939 L .62213 .43907 L .901 .755 .691 r
F
.62654 .44571 m .61364 .46822 L .6077 .45939 L F
.61025 .31286 m .59697 .27969 L .61181 .30567 L .968 .669 .406 r
F
.52653 .44546 m .50081 .44263 L .52208 .43397 L .807 .652 .69 r
F
.52653 .44546 m .50618 .45647 L .50081 .44263 L F
.6908 .39053 m .68189 .40572 L .68902 .38731 L .97 .711 .485 r
F
.6908 .39053 m .68549 .41219 L .68189 .40572 L F
.57084 .21619 m .58101 .21264 L .5871 .20462 L .163 0 0 r
F
.60541 .23737 m .58101 .21264 L .5871 .20462 L .887 .507 .311 r
F
0 g
.5871 .20462 m
.59433 .19977 L
s
.50132 .45699 m
.50702 .46963 L
s
.51486 .41019 m .49212 .41398 L .48897 .39971 L .789 .588 .629 r
F
.51817 .42214 m .49212 .41398 L .51486 .41019 L .794 .609 .651 r
F
.67953 .35629 m .66275 .34313 L .66222 .3361 L .956 .66 .434 r
F
.68004 .36003 m .66275 .34313 L .67953 .35629 L .956 .666 .445 r
F
.51846 .48186 m .54301 .47455 L .5121 .46963 L .241 .403 .824 r
F
.51846 .48186 m .55155 .49113 L .54301 .47455 L F
0 g
.51846 .48186 m
.52514 .49295 L
s
.68199 .53647 m .67666 .56307 L .67352 .53216 L .98 .71 .444 r
F
.68199 .53647 m .68683 .56803 L .67666 .56307 L F
.52208 .43397 m .49609 .42838 L .51817 .42214 L .8 .63 .671 r
F
.52208 .43397 m .50081 .44263 L .49609 .42838 L F
.59507 .35029 m .57148 .34046 L .57168 .33046 L .844 .551 .493 r
F
.59556 .35852 m .57148 .34046 L .59507 .35029 L .843 .569 .524 r
F
.51817 .42214 m .49609 .42838 L .49212 .41398 L .794 .609 .651 r
F
0 g
.48479 .40245 m
.48781 .41617 L
s
.68902 .38731 m .67843 .39863 L .68731 .38379 L .967 .706 .484 r
F
.68902 .38731 m .68189 .40572 L .67843 .39863 L F
.66354 .31923 m .64511 .29456 L .64725 .28878 L .941 .612 .38 r
F
.66262 .32405 m .64511 .29456 L .66354 .31923 L .94 .62 .402 r
F
.65149 .42973 m .64425 .44536 L .64777 .42405 L .975 .693 .429 r
F
.65149 .42973 m .64987 .4539 L .64425 .44536 L F
.61961 .47571 m .59552 .49249 L .61364 .46822 L .884 .783 .745 r
F
.61961 .47571 m .60306 .50179 L .59552 .49249 L F
.68004 .36003 m .66377 .35067 L .66275 .34313 L .956 .666 .445 r
F
.039 .916 .04 r
.63253 .35748 m
.66333 .34743 L
s
.67117 .34487 m
.67124 .34485 L
s
.67124 .34485 m
.67139 .3448 L
s
.67139 .3448 m
.67141 .34479 L
s
.68078 .36395 m .66377 .35067 L .68004 .36003 L .957 .671 .454 r
F
.54295 .31972 m .50833 .29829 L .54431 .30872 L .748 .436 .455 r
F
.57168 .33046 m .54295 .31972 L .54431 .30872 L .8 .486 .458 r
F
.64511 .29456 m .62745 .26278 L .64725 .28878 L .924 .584 .375 r
F
.48669 .38583 m .5085 .36089 L .50659 .34305 L .119 .064 .515 r
F
.48897 .39971 m .5085 .36089 L .48669 .38583 L .175 .145 .582 r
F
0 g
.48533 .37261 m
.48669 .38583 L
s
.68731 .38379 m .67517 .39105 L .6857 .38003 L .965 .7 .483 r
F
.68731 .38379 m .67843 .39863 L .67517 .39105 L F
0 g
.49616 .4437 m
.50132 .45699 L
s
.68078 .36395 m .66524 .35858 L .66377 .35067 L .957 .671 .454 r
F
.68173 .36798 m .66524 .35858 L .68078 .36395 L .958 .677 .462 r
F
.62467 .34837 m .60933 .33091 L .60942 .32132 L .97 .676 .412 r
F
.62514 .35538 m .60933 .33091 L .62467 .34837 L .97 .677 .415 r
F
.039 .916 .04 r
.59836 .35194 m
.6187 .34541 L
s
.6857 .38003 m .67217 .3831 L .68422 .37609 L .963 .695 .479 r
F
.6857 .38003 m .67517 .39105 L .67217 .3831 L F
.70453 .49686 m .69362 .52618 L .69787 .4932 L .982 .804 .588 r
F
.70453 .49686 m .70199 .53055 L .69362 .52618 L F
.68173 .36798 m .66716 .36672 L .66524 .35858 L .958 .677 .462 r
F
.68289 .37205 m .66716 .36672 L .68173 .36798 L .959 .683 .469 r
F
0 g
.48781 .41617 m
.49163 .43 L
s
.62213 .43907 m .6019 .44938 L .61783 .43157 L .889 .733 .683 r
F
.62213 .43907 m .6077 .45939 L .6019 .44938 L F
.68422 .37609 m .66948 .37495 L .68289 .37205 L .961 .689 .475 r
F
.68422 .37609 m .67217 .3831 L .66948 .37495 L F
.68289 .37205 m .66948 .37495 L .66716 .36672 L .959 .683 .469 r
F
.54295 .31972 m .50651 .31147 L .50833 .29829 L .748 .436 .455 r
F
0 g
.50833 .29829 m
.51131 .28716 L
s
.66106 .467 m .6555 .48816 L .65551 .46115 L .976 .699 .435 r
F
.66106 .467 m .66294 .49589 L .6555 .48816 L F
0 g
.49163 .43 m
.49616 .4437 L
s
.57148 .34046 m .54295 .31972 L .57168 .33046 L .801 .512 .5 r
F
.69645 .42682 m .68921 .45075 L .69283 .42283 L .976 .746 .526 r
F
.69645 .42682 m .69467 .45667 L .68921 .45075 L F
.5121 .46963 m .53503 .4567 L .50618 .45647 L .257 .377 .794 r
F
.5121 .46963 m .54301 .47455 L .53503 .4567 L F
0 g
.5121 .46963 m
.51846 .48186 L
s
.59556 .35852 m .57208 .35146 L .57148 .34046 L .843 .569 .524 r
F
.59664 .36734 m .57208 .35146 L .59556 .35852 L .844 .587 .551 r
F
.64777 .42405 m .63875 .4357 L .64414 .41763 L .974 .692 .429 r
F
.64777 .42405 m .64425 .44536 L .63875 .4357 L F
.6701 .50159 m .66454 .52518 L .66294 .49589 L .978 .705 .441 r
F
.6701 .50159 m .67352 .53216 L .66454 .52518 L F
.48897 .39971 m .51164 .37967 L .5085 .36089 L .175 .145 .582 r
F
.49212 .41398 m .51164 .37967 L .48897 .39971 L .215 .21 .637 r
F
0 g
.48669 .38583 m
.48897 .39971 L
s
.58168 .25357 m .57084 .21619 L .58565 .24417 L .964 .659 .399 r
F
.59697 .27969 m .58168 .25357 L .58565 .24417 L .966 .663 .4 r
F
.66262 .32405 m .64366 .30174 L .64511 .29456 L .94 .62 .402 r
F
.66218 .32971 m .64366 .30174 L .66262 .32405 L .939 .628 .422 r
F
.62514 .35538 m .61 .34148 L .60933 .33091 L .97 .677 .415 r
F
.6261 .36289 m .61 .34148 L .62514 .35538 L .97 .679 .418 r
F
.039 .916 .04 r
.62133 .34456 m
.62135 .34456 L
s
.67141 .34479 m
.86206 .29078 L
s
0 0 0 r
2 Mabswid
.67141 .34479 Mdot
.039 .916 .04 r
.5 Mabswid
.62136 .34456 m
.62141 .34454 L
s
.62135 .34456 m
.62136 .34456 L
s
.68683 .56803 m .68704 .56003 L .67666 .56307 L .572 .878 .993 r
F
.68683 .56803 m .69714 .56502 L .68704 .56003 L F
0 g
.68683 .56803 m
.69617 .56974 L
s
.61025 .31286 m .59481 .2892 L .59697 .27969 L .968 .669 .406 r
F
.60942 .32132 m .59481 .2892 L .61025 .31286 L .968 .671 .41 r
F
.69994 .46109 m .69081 .48744 L .69467 .45667 L .977 .773 .562 r
F
.69994 .46109 m .69787 .4932 L .69081 .48744 L F
.70199 .53055 m .68704 .56003 L .69362 .52618 L .977 .825 .624 r
F
.70199 .53055 m .69714 .56502 L .68704 .56003 L F
0 g
.69714 .56502 m
.70642 .56676 L
s
.61783 .43157 m .59634 .43835 L .61371 .42333 L .879 .713 .673 r
F
.61783 .43157 m .6019 .44938 L .59634 .43835 L F
.60306 .50179 m .56964 .51925 L .59552 .49249 L .847 .784 .79 r
F
.60306 .50179 m .57883 .5303 L .56964 .51925 L F
0 g
.57883 .5303 m
.58788 .53908 L
s
.50618 .45647 m .52776 .43791 L .50081 .44263 L .262 .345 .76 r
F
.50618 .45647 m .53503 .4567 L .52776 .43791 L F
0 g
.50618 .45647 m
.5121 .46963 L
s
.62449 .27038 m .60541 .23737 L .62745 .26278 L .906 .556 .368 r
F
.64511 .29456 m .62449 .27038 L .62745 .26278 L .924 .584 .375 r
F
.64414 .41763 m .63346 .42507 L .64066 .41059 L .973 .69 .429 r
F
.64414 .41763 m .63875 .4357 L .63346 .42507 L F
.49212 .41398 m .51595 .39901 L .51164 .37967 L .215 .21 .637 r
F
.49609 .42838 m .51595 .39901 L .49212 .41398 L .241 .263 .683 r
F
0 g
.48897 .39971 m
.49212 .41398 L
s
.61364 .46822 m .588 .48149 L .6077 .45939 L .869 .755 .735 r
F
.61364 .46822 m .59552 .49249 L .588 .48149 L F
.59664 .36734 m .57348 .36327 L .57208 .35146 L .844 .587 .551 r
F
.59829 .37659 m .57348 .36327 L .59664 .36734 L .845 .604 .575 r
F
.69283 .42283 m .68365 .44343 L .68916 .41793 L .97 .739 .531 r
F
.69283 .42283 m .68921 .45075 L .68365 .44343 L F
.50081 .44263 m .52136 .41856 L .49609 .42838 L .257 .307 .724 r
F
.50081 .44263 m .52776 .43791 L .52136 .41856 L F
0 g
.50081 .44263 m
.50618 .45647 L
s
.6261 .36289 m .61143 .35282 L .61 .34148 L .97 .679 .418 r
F
.62753 .37077 m .61143 .35282 L .6261 .36289 L .97 .681 .421 r
F
0 0 0 r
2 Mabswid
.89765 .34177 Mdot
.49609 .42838 m .52136 .41856 L .51595 .39901 L .241 .263 .683 r
F
0 g
.5 Mabswid
.49609 .42838 m
.50081 .44263 L
s
.49212 .41398 m
.49609 .42838 L
s
.59481 .2892 m .58168 .25357 L .59697 .27969 L .966 .665 .406 r
F
.61371 .42333 m .59114 .42652 L .60984 .41449 L .87 .694 .661 r
F
.61371 .42333 m .59634 .43835 L .59114 .42652 L F
.64366 .30174 m .62449 .27038 L .64511 .29456 L .923 .595 .404 r
F
.64066 .41059 m .6285 .41367 L .63739 .40306 L .973 .689 .429 r
F
.64066 .41059 m .63346 .42507 L .6285 .41367 L F
.57148 .34046 m .5426 .33222 L .54295 .31972 L .801 .512 .5 r
F
.57208 .35146 m .5426 .33222 L .57148 .34046 L .801 .535 .536 r
F
.5426 .33222 m .50651 .31147 L .54295 .31972 L .752 .469 .504 r
F
.66218 .32971 m .64293 .31021 L .64366 .30174 L .939 .628 .422 r
F
.66222 .3361 m .64293 .31021 L .66218 .32971 L .939 .636 .44 r
F
.59829 .37659 m .57565 .37567 L .57348 .36327 L .845 .604 .575 r
F
.60048 .38611 m .57565 .37567 L .59829 .37659 L .847 .622 .596 r
F
.62753 .37077 m .61357 .36474 L .61143 .35282 L .97 .681 .421 r
F
.62941 .37887 m .61357 .36474 L .62753 .37077 L .971 .682 .423 r
F
.65551 .46115 m .64793 .47853 L .64987 .4539 L .975 .698 .437 r
F
.65551 .46115 m .6555 .48816 L .64793 .47853 L F
.60984 .41449 m .58638 .4141 L .60631 .40523 L .862 .675 .647 r
F
.60984 .41449 m .59114 .42652 L .58638 .4141 L F
.63739 .40306 m .62394 .40171 L .63439 .39516 L .972 .687 .428 r
F
.63739 .40306 m .6285 .41367 L .62394 .40171 L F
.60048 .38611 m .57857 .38844 L .57565 .37567 L .847 .622 .596 r
F
.60317 .39571 m .57857 .38844 L .60048 .38611 L .851 .639 .615 r
F
.60156 .24675 m .58101 .21264 L .60541 .23737 L .886 .527 .36 r
F
.62449 .27038 m .60156 .24675 L .60541 .23737 L .906 .556 .368 r
F
.62941 .37887 m .61641 .37702 L .61357 .36474 L .971 .682 .423 r
F
.63171 .38705 m .61641 .37702 L .62941 .37887 L .971 .684 .425 r
F
.60631 .40523 m .58216 .40133 L .60317 .39571 L .856 .657 .632 r
F
.60631 .40523 m .58638 .4141 L .58216 .40133 L F
.63439 .39516 m .61989 .38941 L .63171 .38705 L .972 .686 .427 r
F
.63439 .39516 m .62394 .40171 L .61989 .38941 L F
.60317 .39571 m .58216 .40133 L .57857 .38844 L .851 .639 .615 r
F
.63171 .38705 m .61989 .38941 L .61641 .37702 L .971 .684 .425 r
F
.58168 .25357 m .56595 .2273 L .57084 .21619 L .964 .659 .399 r
F
.56595 .2273 m .58101 .21264 L .57084 .21619 L .314 0 .114 r
F
0 g
.57084 .21619 m
.577 .20816 L
s
.68916 .41793 m .67808 .43483 L .68549 .41219 L .965 .731 .534 r
F
.68916 .41793 m .68365 .44343 L .67808 .43483 L F
.60942 .32132 m .59362 .30046 L .59481 .2892 L .968 .671 .41 r
F
.60933 .33091 m .59362 .30046 L .60942 .32132 L .968 .673 .415 r
F
.6077 .45939 m .58066 .46898 L .6019 .44938 L .856 .729 .723 r
F
.6077 .45939 m .588 .48149 L .58066 .46898 L F
.69787 .4932 m .68473 .51915 L .69081 .48744 L .972 .792 .601 r
F
.69787 .4932 m .69362 .52618 L .68473 .51915 L F
.67352 .53216 m .66584 .55488 L .66454 .52518 L .978 .709 .449 r
F
.67352 .53216 m .67666 .56307 L .66584 .55488 L F
.5426 .33222 m .50592 .32647 L .50651 .31147 L .752 .469 .504 r
F
0 g
.50651 .31147 m
.50833 .29829 L
s
.69467 .45667 m .68347 .47965 L .68921 .45075 L .97 .764 .57 r
F
.69467 .45667 m .69081 .48744 L .68347 .47965 L F
.66222 .3361 m .64294 .31982 L .64293 .31021 L .939 .636 .44 r
F
.66275 .34313 m .64294 .31982 L .66222 .3361 L .938 .644 .457 r
F
.039 .916 .04 r
.62141 .34454 m
.65462 .33357 L
s
.59552 .49249 m .56049 .50612 L .588 .48149 L .832 .751 .774 r
F
.59552 .49249 m .56964 .51925 L .56049 .50612 L F
0 g
.56964 .51925 m
.57883 .5303 L
s
.66294 .49589 m .65519 .51562 L .6555 .48816 L .977 .703 .444 r
F
.66294 .49589 m .66454 .52518 L .65519 .51562 L F
.57208 .35146 m .54326 .34601 L .5426 .33222 L .801 .535 .536 r
F
.57348 .36327 m .54326 .34601 L .57208 .35146 L .803 .557 .567 r
F
.56595 .2273 m .57619 .22375 L .58101 .21264 L .314 0 .114 r
F
.60156 .24675 m .57619 .22375 L .58101 .21264 L .886 .527 .36 r
F
0 g
.58101 .21264 m
.5871 .20462 L
s
.68549 .41219 m .67263 .42509 L .68189 .40572 L .96 .723 .534 r
F
.68549 .41219 m .67808 .43483 L .67263 .42509 L F
.64366 .30174 m .62245 .27989 L .62449 .27038 L .923 .595 .404 r
F
.64293 .31021 m .62245 .27989 L .64366 .30174 L .921 .606 .43 r
F
.64987 .4539 m .64037 .46714 L .64425 .44536 L .974 .696 .438 r
F
.64987 .4539 m .64793 .47853 L .64037 .46714 L F
.66275 .34313 m .6437 .33042 L .64294 .31982 L .938 .644 .457 r
F
.66377 .35067 m .6437 .33042 L .66275 .34313 L .939 .653 .472 r
F
.039 .916 .04 r
.65793 .33248 m
.6581 .33242 L
s
.62245 .27989 m .60156 .24675 L .62449 .27038 L .904 .571 .404 r
F
.039 .916 .04 r
.6581 .33242 m
.65812 .33242 L
s
0 0 0 r
2 Mabswid
.6581 .33242 Mdot
.54326 .34601 m .50592 .32647 L .5426 .33222 L .755 .499 .544 r
F
.6019 .44938 m .57363 .45517 L .59634 .43835 L .844 .705 .709 r
F
.6019 .44938 m .58066 .46898 L .57363 .45517 L F
0 0 0 r
.89065 .33174 Mdot
.57888 .26538 m .56595 .2273 L .58168 .25357 L .964 .662 .407 r
F
.59481 .2892 m .57888 .26538 L .58168 .25357 L .966 .665 .406 r
F
.59362 .30046 m .57888 .26538 L .59481 .2892 L .966 .668 .412 r
F
.60933 .33091 m .59345 .31328 L .59362 .30046 L .968 .673 .415 r
F
.61 .34148 m .59345 .31328 L .60933 .33091 L .968 .675 .42 r
F
.68189 .40572 m .66737 .41439 L .67843 .39863 L .956 .714 .533 r
F
.68189 .40572 m .67263 .42509 L .66737 .41439 L F
.57348 .36327 m .54494 .36083 L .54326 .34601 L .803 .557 .567 r
F
.57565 .37567 m .54494 .36083 L .57348 .36327 L .805 .578 .594 r
F
.69362 .52618 m .67628 .55181 L .68473 .51915 L .965 .808 .637 r
F
.69362 .52618 m .68704 .56003 L .67628 .55181 L F
.66377 .35067 m .64519 .34179 L .6437 .33042 L .939 .653 .472 r
F
.039 .916 .04 r
.5 Mabswid
.65812 .33242 m
.85473 .28028 L
s
.66524 .35858 m .64519 .34179 L .66377 .35067 L .939 .661 .486 r
F
.68921 .45075 m .67598 .46994 L .68365 .44343 L .962 .753 .575 r
F
.68921 .45075 m .68347 .47965 L .67598 .46994 L F
.67843 .39863 m .66242 .40292 L .67517 .39105 L .952 .706 .529 r
F
.67843 .39863 m .66737 .41439 L .66242 .40292 L F
.59634 .43835 m .56706 .44033 L .59114 .42652 L .835 .683 .694 r
F
.59634 .43835 m .57363 .45517 L .56706 .44033 L F
.588 .48149 m .55155 .49113 L .58066 .46898 L .819 .722 .758 r
F
.588 .48149 m .56049 .50612 L .55155 .49113 L F
0 g
.56049 .50612 m
.56964 .51925 L
s
.64425 .44536 m .63295 .45419 L .63875 .4357 L .973 .695 .439 r
F
.64425 .44536 m .64037 .46714 L .63295 .45419 L F
.66524 .35858 m .6474 .35376 L .64519 .34179 L .939 .661 .486 r
F
.66716 .36672 m .6474 .35376 L .66524 .35858 L .941 .67 .498 r
F
.67666 .56307 m .67628 .55181 L .66584 .55488 L .62 .837 .983 r
F
.67666 .56307 m .68704 .56003 L .67628 .55181 L F
0 g
.67666 .56307 m
.68683 .56803 L
s
.68704 .56003 m
.69714 .56502 L
s
.57857 .38844 m .54762 .37641 L .57565 .37567 L .809 .599 .618 r
F
.57565 .37567 m .54762 .37641 L .54494 .36083 L .805 .578 .594 r
F
.67517 .39105 m .65787 .3909 L .67217 .3831 L .948 .697 .524 r
F
.67517 .39105 m .66242 .40292 L .65787 .3909 L F
.54326 .34601 m .50659 .34305 L .50592 .32647 L .755 .499 .544 r
F
0 g
.50592 .32647 m
.50651 .31147 L
s
.64293 .31021 m .62137 .29116 L .62245 .27989 L .921 .606 .43 r
F
.64294 .31982 m .62137 .29116 L .64293 .31021 L .92 .617 .453 r
F
.69081 .48744 m .67547 .50953 L .68347 .47965 L .962 .779 .609 r
F
.69081 .48744 m .68473 .51915 L .67547 .50953 L F
.66716 .36672 m .65029 .36608 L .6474 .35376 L .941 .67 .498 r
F
.66948 .37495 m .65029 .36608 L .66716 .36672 L .942 .679 .508 r
F
.61 .34148 m .5943 .32743 L .59345 .31328 L .968 .675 .42 r
F
.61143 .35282 m .5943 .32743 L .61 .34148 L .968 .677 .424 r
F
.67217 .3831 m .6538 .37854 L .66948 .37495 L .945 .688 .517 r
F
.67217 .3831 m .65787 .3909 L .6538 .37854 L F
.59114 .42652 m .56106 .42473 L .58638 .4141 L .826 .661 .678 r
F
.59114 .42652 m .56706 .44033 L .56106 .42473 L F
.66948 .37495 m .6538 .37854 L .65029 .36608 L .942 .679 .508 r
F
.6555 .48816 m .64565 .50362 L .64793 .47853 L .975 .702 .446 r
F
.6555 .48816 m .65519 .51562 L .64565 .50362 L F
.54494 .36083 m .50659 .34305 L .54326 .34601 L .759 .525 .579 r
F
.57857 .38844 m .55125 .39246 L .54762 .37641 L .809 .599 .618 r
F
.58216 .40133 m .55125 .39246 L .57857 .38844 L .814 .619 .64 r
F
.59886 .25856 m .57619 .22375 L .60156 .24675 L .885 .546 .402 r
F
.62245 .27989 m .59886 .25856 L .60156 .24675 L .904 .571 .404 r
F
.58638 .4141 m .55575 .40867 L .58216 .40133 L .819 .64 .66 r
F
.58638 .4141 m .56106 .42473 L .55575 .40867 L F
.58216 .40133 m .55575 .40867 L .55125 .39246 L .814 .619 .64 r
F
.66454 .52518 m .65456 .54353 L .65519 .51562 L .977 .708 .452 r
F
.66454 .52518 m .66584 .55488 L .65456 .54353 L F
.63875 .4357 m .62582 .43992 L .63346 .42507 L .973 .693 .439 r
F
.63875 .4357 m .63295 .45419 L .62582 .43992 L F
.68365 .44343 m .66848 .45847 L .67808 .43483 L .955 .742 .576 r
F
.68365 .44343 m .67598 .46994 L .66848 .45847 L F
.62137 .29116 m .59886 .25856 L .62245 .27989 L .902 .585 .435 r
F
.59362 .30046 m .5773 .27942 L .57888 .26538 L .966 .668 .412 r
F
.59345 .31328 m .5773 .27942 L .59362 .30046 L .966 .67 .418 r
F
0 0 0 r
2 Mabswid
.8836 .32164 Mdot
.58066 .46898 m .54301 .47455 L .57363 .45517 L .807 .694 .74 r
F
.58066 .46898 m .55155 .49113 L .54301 .47455 L F
.61143 .35282 m .59617 .34266 L .5943 .32743 L .968 .677 .424 r
F
.61357 .36474 m .59617 .34266 L .61143 .35282 L .968 .68 .427 r
F
0 g
.5 Mabswid
.55155 .49113 m
.56049 .50612 L
s
.57888 .26538 m .56245 .24137 L .56595 .2273 L .964 .662 .407 r
F
.56245 .24137 m .57619 .22375 L .56595 .2273 L .409 .073 .281 r
F
0 g
.56595 .2273 m
.57084 .21619 L
s
.64294 .31982 m .62131 .30399 L .62137 .29116 L .92 .617 .453 r
F
.6437 .33042 m .62131 .30399 L .64294 .31982 L .92 .628 .475 r
F
.54494 .36083 m .5085 .36089 L .50659 .34305 L .759 .525 .579 r
F
0 g
.50592 .32647 m
.50659 .34305 L
s
.54762 .37641 m .5085 .36089 L .54494 .36083 L .763 .55 .609 r
F
.63346 .42507 m .61912 .42459 L .6285 .41367 L .972 .691 .438 r
F
.63346 .42507 m .62582 .43992 L .61912 .42459 L F
.5773 .27942 m .56245 .24137 L .57888 .26538 L .963 .664 .414 r
F
.61641 .37702 m .59903 .35869 L .61357 .36474 L .969 .682 .431 r
F
.61357 .36474 m .59903 .35869 L .59617 .34266 L .968 .68 .427 r
F
.56245 .24137 m .57276 .23781 L .57619 .22375 L .409 .073 .281 r
F
.59886 .25856 m .57276 .23781 L .57619 .22375 L .885 .546 .402 r
F
0 g
.57619 .22375 m
.58101 .21264 L
s
.57363 .45517 m .53503 .4567 L .56706 .44033 L .797 .669 .722 r
F
.57363 .45517 m .54301 .47455 L .53503 .4567 L F
.68473 .51915 m .66505 .54043 L .67547 .50953 L .953 .791 .643 r
F
.68473 .51915 m .67628 .55181 L .66505 .54043 L F
.64793 .47853 m .63611 .48937 L .64037 .46714 L .974 .7 .448 r
F
.64793 .47853 m .64565 .50362 L .63611 .48937 L F
.67808 .43483 m .66111 .44544 L .67263 .42509 L .948 .731 .576 r
F
.67808 .43483 m .66848 .45847 L .66111 .44544 L F
.6285 .41367 m .61298 .40849 L .62394 .40171 L .971 .689 .437 r
F
.6285 .41367 m .61912 .42459 L .61298 .40849 L F
.68347 .47965 m .66601 .49746 L .67598 .46994 L .952 .764 .612 r
F
.68347 .47965 m .67547 .50953 L .66601 .49746 L F
.61641 .37702 m .60284 .37522 L .59903 .35869 L .969 .682 .431 r
F
.61989 .38941 m .60284 .37522 L .61641 .37702 L .969 .684 .433 r
F
.55125 .39246 m .51164 .37967 L .54762 .37641 L .768 .574 .636 r
F
.54762 .37641 m .51164 .37967 L .5085 .36089 L .763 .55 .609 r
F
0 g
.50659 .34305 m
.5085 .36089 L
s
.62394 .40171 m .60751 .39193 L .61989 .38941 L .97 .687 .436 r
F
.62394 .40171 m .61298 .40849 L .60751 .39193 L F
.61989 .38941 m .60751 .39193 L .60284 .37522 L .969 .684 .433 r
F
.6437 .33042 m .62225 .31817 L .62131 .30399 L .92 .628 .475 r
F
.64519 .34179 m .62225 .31817 L .6437 .33042 L .92 .639 .494 r
F
0 g
.54301 .47455 m
.55155 .49113 L
s
.59345 .31328 m .577 .29547 L .5773 .27942 L .966 .67 .418 r
F
.5943 .32743 m .577 .29547 L .59345 .31328 L .966 .673 .424 r
F
.56706 .44033 m .52776 .43791 L .56106 .42473 L .788 .644 .703 r
F
.56706 .44033 m .53503 .4567 L .52776 .43791 L F
.62137 .29116 m .59739 .2726 L .59886 .25856 L .902 .585 .435 r
F
.62131 .30399 m .59739 .2726 L .62137 .29116 L .901 .598 .464 r
F
.55125 .39246 m .51595 .39901 L .51164 .37967 L .768 .574 .636 r
F
.55575 .40867 m .51595 .39901 L .55125 .39246 L .774 .597 .66 r
F
.59739 .2726 m .57276 .23781 L .59886 .25856 L .883 .563 .439 r
F
.67263 .42509 m .65401 .43109 L .66737 .41439 L .942 .719 .572 r
F
.67263 .42509 m .66111 .44544 L .65401 .43109 L F
0 0 0 r
2 Mabswid
.87649 .31145 Mdot
.56106 .42473 m .52136 .41856 L .55575 .40867 L .78 .621 .682 r
F
.56106 .42473 m .52776 .43791 L .52136 .41856 L F
.66584 .55488 m .66505 .54043 L .65456 .54353 L .64 .788 .953 r
F
.66584 .55488 m .67628 .55181 L .66505 .54043 L F
0 g
.5 Mabswid
.66584 .55488 m
.67666 .56307 L
s
.67628 .55181 m
.68704 .56003 L
s
.5085 .36089 m
.51164 .37967 L
s
.55575 .40867 m .52136 .41856 L .51595 .39901 L .774 .597 .66 r
F
.65519 .51562 m .64303 .5292 L .64565 .50362 L .975 .706 .455 r
F
.65519 .51562 m .65456 .54353 L .64303 .5292 L F
.64519 .34179 m .6242 .33344 L .62225 .31817 L .92 .639 .494 r
F
.6474 .35376 m .6242 .33344 L .64519 .34179 L .92 .65 .511 r
F
.64037 .46714 m .62673 .47312 L .63295 .45419 L .973 .698 .449 r
F
.64037 .46714 m .63611 .48937 L .62673 .47312 L F
.66737 .41439 m .64733 .41568 L .66242 .40292 L .936 .707 .567 r
F
.66737 .41439 m .65401 .43109 L .64733 .41568 L F
0 g
.53503 .4567 m
.54301 .47455 L
s
.67598 .46994 m .65652 .48314 L .66848 .45847 L .943 .75 .613 r
F
.67598 .46994 m .66601 .49746 L .65652 .48314 L F
.65029 .36608 m .62713 .34952 L .6474 .35376 L .922 .661 .526 r
F
.6474 .35376 m .62713 .34952 L .6242 .33344 L .92 .65 .511 r
F
.5773 .27942 m .56044 .25819 L .56245 .24137 L .963 .664 .414 r
F
.577 .29547 m .56044 .25819 L .5773 .27942 L .963 .667 .421 r
F
.5943 .32743 m .57801 .31324 L .577 .29547 L .966 .673 .424 r
F
.59617 .34266 m .57801 .31324 L .5943 .32743 L .966 .676 .429 r
F
0 g
.51164 .37967 m
.51595 .39901 L
s
.56044 .25819 m .57276 .23781 L .56245 .24137 L .469 .183 .396 r
F
0 g
.56245 .24137 m
.56595 .2273 L
s
.66242 .40292 m .64119 .39951 L .65787 .3909 L .931 .695 .559 r
F
.66242 .40292 m .64733 .41568 L .64119 .39951 L F
.65029 .36608 m .63099 .36611 L .62713 .34952 L .922 .661 .526 r
F
.6538 .37854 m .63099 .36611 L .65029 .36608 L .924 .672 .539 r
F
.67547 .50953 m .65356 .52605 L .66601 .49746 L .941 .773 .646 r
F
.67547 .50953 m .66505 .54043 L .65356 .52605 L F
.62131 .30399 m .59719 .28867 L .59739 .2726 L .901 .598 .464 r
F
.62225 .31817 m .59719 .28867 L .62131 .30399 L .9 .611 .489 r
F
.65787 .3909 m .63571 .38288 L .6538 .37854 L .927 .684 .55 r
F
.65787 .3909 m .64119 .39951 L .63571 .38288 L F
0 g
.52776 .43791 m
.53503 .4567 L
s
.6538 .37854 m .63571 .38288 L .63099 .36611 L .924 .672 .539 r
F
0 g
.51595 .39901 m
.52136 .41856 L
s
.63295 .45419 m .61771 .45516 L .62582 .43992 L .972 .695 .449 r
F
.63295 .45419 m .62673 .47312 L .61771 .45516 L F
.56044 .25819 m .57081 .25463 L .57276 .23781 L .469 .183 .396 r
F
.59739 .2726 m .57081 .25463 L .57276 .23781 L .883 .563 .439 r
F
0 g
.57276 .23781 m
.57619 .22375 L
s
.52136 .41856 m
.52776 .43791 L
s
0 0 0 r
2 Mabswid
.86931 .30116 Mdot
.59617 .34266 m .58031 .33241 L .57801 .31324 L .966 .676 .429 r
F
.59903 .35869 m .58031 .33241 L .59617 .34266 L .966 .679 .434 r
F
.59719 .28867 m .57081 .25463 L .59739 .2726 L .881 .579 .472 r
F
.64565 .50362 m .63146 .51209 L .63611 .48937 L .974 .703 .457 r
F
.64565 .50362 m .64303 .5292 L .63146 .51209 L F
.66848 .45847 m .64719 .46682 L .66111 .44544 L .934 .735 .61 r
F
.66848 .45847 m .65652 .48314 L .64719 .46682 L F
.62582 .43992 m .60924 .43583 L .61912 .42459 L .97 .693 .448 r
F
.62582 .43992 m .61771 .45516 L .60924 .43583 L F
.62225 .31817 m .59828 .30647 L .59719 .28867 L .9 .611 .489 r
F
.6242 .33344 m .59828 .30647 L .62225 .31817 L .9 .625 .511 r
F
.65456 .54353 m .65356 .52605 L .64303 .5292 L .646 .741 .919 r
F
.65456 .54353 m .66505 .54043 L .65356 .52605 L F
0 g
.5 Mabswid
.65456 .54353 m
.66584 .55488 L
s
.66505 .54043 m
.67628 .55181 L
s
.59903 .35869 m .58389 .35263 L .58031 .33241 L .966 .679 .434 r
F
.60284 .37522 m .58389 .35263 L .59903 .35869 L .967 .681 .438 r
F
.577 .29547 m .55998 .27747 L .56044 .25819 L .963 .667 .421 r
F
.57801 .31324 m .55998 .27747 L .577 .29547 L .964 .671 .428 r
F
.61912 .42459 m .60147 .41551 L .61298 .40849 L .969 .69 .446 r
F
.61912 .42459 m .60924 .43583 L .60147 .41551 L F
.66111 .44544 m .63821 .44879 L .65401 .43109 L .926 .721 .605 r
F
.66111 .44544 m .64719 .46682 L .63821 .44879 L F
.66601 .49746 m .64203 .50889 L .65652 .48314 L .93 .755 .644 r
F
.66601 .49746 m .65356 .52605 L .64203 .50889 L F
.60284 .37522 m .58867 .37349 L .58389 .35263 L .967 .681 .438 r
F
.60751 .39193 m .58867 .37349 L .60284 .37522 L .968 .684 .441 r
F
.61298 .40849 m .59457 .39459 L .60751 .39193 L .968 .687 .444 r
F
.61298 .40849 m .60147 .41551 L .59457 .39459 L F
.60751 .39193 m .59457 .39459 L .58867 .37349 L .968 .684 .441 r
F
0 0 0 r
2 Mabswid
.86206 .29078 Mdot
.6242 .33344 m .60066 .32568 L .59828 .30647 L .9 .625 .511 r
F
.62713 .34952 m .60066 .32568 L .6242 .33344 L .901 .638 .531 r
F
.55998 .27747 m .57081 .25463 L .56044 .25819 L .51 .265 .479 r
F
0 g
.5 Mabswid
.56044 .25819 m
.56245 .24137 L
s
.63611 .48937 m .62009 .4925 L .62673 .47312 L .972 .701 .458 r
F
.63611 .48937 m .63146 .51209 L .62009 .4925 L F
.59719 .28867 m .57041 .27392 L .57081 .25463 L .881 .579 .472 r
F
.59828 .30647 m .57041 .27392 L .59719 .28867 L .88 .595 .5 r
F
.65401 .43109 m .62975 .42938 L .64733 .41568 L .92 .706 .598 r
F
.65401 .43109 m .63821 .44879 L .62975 .42938 L F
.55998 .27747 m .57041 .27392 L .57081 .25463 L .51 .265 .479 r
F
0 g
.57081 .25463 m
.57276 .23781 L
s
.57801 .31324 m .56112 .2989 L .55998 .27747 L .964 .671 .428 r
F
.58031 .33241 m .56112 .2989 L .57801 .31324 L .964 .674 .434 r
F
.62713 .34952 m .6043 .34593 L .60066 .32568 L .901 .638 .531 r
F
.63099 .36611 m .6043 .34593 L .62713 .34952 L .902 .651 .548 r
F
.64733 .41568 m .62198 .40899 L .64119 .39951 L .914 .692 .588 r
F
.64733 .41568 m .62975 .42938 L .62198 .40899 L F
.63099 .36611 m .60913 .36685 L .6043 .34593 L .902 .651 .548 r
F
.63571 .38288 m .60913 .36685 L .63099 .36611 L .905 .664 .564 r
F
.65652 .48314 m .63069 .48927 L .64719 .46682 L .92 .738 .64 r
F
.65652 .48314 m .64203 .50889 L .63069 .48927 L F
.64303 .5292 m .64203 .50889 L .63146 .51209 L .646 .699 .885 r
F
.64303 .5292 m .65356 .52605 L .64203 .50889 L F
0 g
.64303 .5292 m
.65456 .54353 L
s
.65356 .52605 m
.66505 .54043 L
s
.64119 .39951 m .61506 .38801 L .63571 .38288 L .909 .678 .577 r
F
.64119 .39951 m .62198 .40899 L .61506 .38801 L F
.63571 .38288 m .61506 .38801 L .60913 .36685 L .905 .664 .564 r
F
.62673 .47312 m .60914 .4708 L .61771 .45516 L .97 .698 .458 r
F
.62673 .47312 m .62009 .4925 L .60914 .4708 L F
0 0 0 r
2 Mabswid
.85473 .28028 Mdot
.59828 .30647 m .5716 .29537 L .57041 .27392 L .88 .595 .5 r
F
.60066 .32568 m .5716 .29537 L .59828 .30647 L .88 .61 .525 r
F
.58031 .33241 m .56384 .32207 L .56112 .2989 L .964 .674 .434 r
F
.58389 .35263 m .56384 .32207 L .58031 .33241 L .964 .677 .44 r
F
.56112 .2989 m .57041 .27392 L .55998 .27747 L .539 .328 .542 r
F
0 g
.5 Mabswid
.55998 .27747 m
.56044 .25819 L
s
.61771 .45516 m .59884 .44741 L .60924 .43583 L .969 .695 .457 r
F
.61771 .45516 m .60914 .4708 L .59884 .44741 L F
.64719 .46682 m .61976 .46752 L .63821 .44879 L .911 .72 .633 r
F
.64719 .46682 m .63069 .48927 L .61976 .46752 L F
.56112 .2989 m .5716 .29537 L .57041 .27392 L .539 .328 .542 r
F
0 g
.57041 .27392 m
.57081 .25463 L
s
.58867 .37349 m .56812 .34654 L .58389 .35263 L .965 .681 .445 r
F
.58389 .35263 m .56812 .34654 L .56384 .32207 L .964 .677 .44 r
F
.60066 .32568 m .57437 .31856 L .5716 .29537 L .88 .61 .525 r
F
.6043 .34593 m .57437 .31856 L .60066 .32568 L .881 .625 .547 r
F
.60924 .43583 m .5894 .42278 L .60147 .41551 L .968 .691 .455 r
F
.60924 .43583 m .59884 .44741 L .5894 .42278 L F
.63146 .51209 m .63069 .48927 L .62009 .4925 L .643 .661 .853 r
F
.63146 .51209 m .64203 .50889 L .63069 .48927 L F
0 g
.63146 .51209 m
.64303 .5292 L
s
.64203 .50889 m
.65356 .52605 L
s
.58867 .37349 m .57389 .37182 L .56812 .34654 L .965 .681 .445 r
F
.59457 .39459 m .57389 .37182 L .58867 .37349 L .966 .684 .449 r
F
.63821 .44879 m .60947 .44408 L .62975 .42938 L .903 .704 .624 r
F
.63821 .44879 m .61976 .46752 L .60947 .44408 L F
.60147 .41551 m .58103 .39741 L .59457 .39459 L .967 .688 .452 r
F
.60147 .41551 m .5894 .42278 L .58103 .39741 L F
.59457 .39459 m .58103 .39741 L .57389 .37182 L .966 .684 .449 r
F
.56384 .32207 m .5716 .29537 L .56112 .2989 L .561 .38 .593 r
F
0 g
.55998 .27747 m
.56112 .2989 L
s
.6043 .34593 m .57869 .34305 L .57437 .31856 L .881 .625 .547 r
F
.60913 .36685 m .57869 .34305 L .6043 .34593 L .883 .64 .567 r
F
.62975 .42938 m .60003 .4194 L .62198 .40899 L .896 .687 .612 r
F
.62975 .42938 m .60947 .44408 L .60003 .4194 L F
.56384 .32207 m .57437 .31856 L .5716 .29537 L .561 .38 .593 r
F
0 g
.57041 .27392 m
.5716 .29537 L
s
.60913 .36685 m .58449 .36837 L .57869 .34305 L .883 .64 .567 r
F
.61506 .38801 m .58449 .36837 L .60913 .36685 L .886 .656 .584 r
F
.62198 .40899 m .59165 .39399 L .61506 .38801 L .891 .671 .599 r
F
.62198 .40899 m .60003 .4194 L .59165 .39399 L F
.61506 .38801 m .59165 .39399 L .58449 .36837 L .886 .656 .584 r
F
.62009 .4925 m .61976 .46752 L .60914 .4708 L .638 .626 .823 r
F
.62009 .4925 m .63069 .48927 L .61976 .46752 L F
0 g
.62009 .4925 m
.63146 .51209 L
s
.63069 .48927 m
.64203 .50889 L
s
.56812 .34654 m .57437 .31856 L .56384 .32207 L .579 .424 .635 r
F
0 g
.56112 .2989 m
.56384 .32207 L
s
.56812 .34654 m .57869 .34305 L .57437 .31856 L .579 .424 .635 r
F
0 g
.5716 .29537 m
.57437 .31856 L
s
.60914 .4708 m .60947 .44408 L .59884 .44741 L .631 .593 .793 r
F
.60914 .4708 m .61976 .46752 L .60947 .44408 L F
0 g
.60914 .4708 m
.62009 .4925 L
s
.61976 .46752 m
.63069 .48927 L
s
.57389 .37182 m .57869 .34305 L .56812 .34654 L .593 .462 .672 r
F
0 g
.56384 .32207 m
.56812 .34654 L
s
.59884 .44741 m .60003 .4194 L .5894 .42278 L .623 .562 .764 r
F
.59884 .44741 m .60947 .44408 L .60003 .4194 L F
0 g
.59884 .44741 m
.60914 .4708 L
s
.60947 .44408 m
.61976 .46752 L
s
.57389 .37182 m .58449 .36837 L .57869 .34305 L .593 .462 .672 r
F
0 g
.57437 .31856 m
.57869 .34305 L
s
.58103 .39741 m .58449 .36837 L .57389 .37182 L .604 .497 .704 r
F
0 g
.56812 .34654 m
.57389 .37182 L
s
.5894 .42278 m .59165 .39399 L .58103 .39741 L .615 .53 .735 r
F
.5894 .42278 m .60003 .4194 L .59165 .39399 L F
0 g
.5894 .42278 m
.59884 .44741 L
s
.58103 .39741 m .59165 .39399 L .58449 .36837 L .604 .497 .704 r
F
0 g
.58103 .39741 m
.5894 .42278 L
s
.57389 .37182 m
.58103 .39741 L
s
.57869 .34305 m
.58449 .36837 L
s
.60003 .4194 m
.60947 .44408 L
s
.58449 .36837 m
.59165 .39399 L
s
.59165 .39399 m
.60003 .4194 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{626, 397.938},
  ImageMargins->{{58, 0}, {0, 1}},
  ImageRegion->{{-0.11335, 1.10076}, {-0.356612, 1.19416}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009b0001SB000`400?l00000o`00003oo`3ooooo
0?ooog@0oooo003o0?ooool0ooooM03oool00?l0ooooo`3ooomd0?ooo`00o`3ooooo0?ooog@0oooo
003o0?ooool0ooooM03oool00?l0ooooo`3ooomd0?ooo`00o`3ooooo0?ooog@0oooo003o0?ooool0
ooooM03oool00?l0ooooP03oool800000>/0oooo003o0?ooog`0oooo100000030>5e<0D0gfhN1000
003W0?ooo`00o`3ooomk0?ooo`030000003RO440hGD`00H0hGD`1P3OKQh20=YV2P<00000i03oool0
0?l0ooooN@3oool2000000<0hWa11`3QMC060=m^7P@0fVH:0P00003R0?ooo`00o`3ooomd0?ooo`D0
00001P3RO4470>5e<0H0gfhN1@3JIPX200000>00oooo003o0?ooog<0oooo1@0000080>9l@@H0hGD`
1P3OKQh50=YV2P80ded000<000000?ooo`3oool0g@3oool00?l0ooooL@3oool50000000302T00000
0000hWa100P0hWa11P3QMC060=m^7PD0fVH:0P3CG@000`000000oooo0?ooo`3L0?ooo`00o`3ooom`
0?ooo`<000000`0Y00000`000000hh5?0>9l@@080>9l@@L0hGD`1P3OKQh50=YV2P80ded00P00003L
0?ooo`00o`3ooom_0?ooo`030000000Y0000:@0000<0:@0000@000000>>1C`3SPDl0hh5?2@3RO447
0>5e<0H0gfhN103JIPX40==M00030000003oool0oooo0=T0oooo003o0?ooofl0oooo00<0000002T0
000Y00000`0Y00000`000000hh5?0>>1C`020>>1C`T0hWa11P3QMC060=m^7PD0fVH:103CG@000`00
0000oooo0?ooo`3H0?ooo`00o`3ooom^0?ooo`030000000Y0000:@0000<0:@0000<000000>>1C`3S
PDl0103SPDl90>9l@@H0hGD`1P3OKQh50=YV2P@0ded000<000000?ooo`3oool0e`3oool00?l0oooo
K@3oool00`000000:@0002T0000302T000030000003SPDl0hh5?00H0hh5?2@3RO4460>5e<0H0gfhN
103JIPX40==M00030<YC00000000oooo0=L0oooo003o0?ooofd0oooo00<0000002T0000Y00000P0Y
00000`1@01d000000>>1C`080>>1C`P0hWa11`3QMC050=m^7PD0fVH:103CG@000`3:D`0000000?oo
o`3F0?ooo`00o`3ooom/0?ooo`030000000Y0000:@0000<0D00M00<000000>:6G03SPDl02@3SPDl8
0>9l@@H0hGD`1P3OKQh50=YV2P@0ded000<0bU<00000003oool0e@3oool00?l0ooooJ`3oool00`00
0000D00M05007@0405007@030000003RQU`0hXIL00X0hh5?203RO4460>5e<0H0gfhN103JIPX40==M
0080bU<000<000000?ooo`3oool0d`3oool00?l0ooooJ`3oool00`000000D00M05007@0305007@03
0000003RQU`0hXIL0080hXIL2P3SPDl80>9l@@H0hGD`1@3OKQh50=YV2P@0ded00P3:D`000`000000
oooo0?ooo`3B0?ooo`00o`3ooomZ0?ooo`030000001@01d0D00M00@0D00M00<000000>:6G03RQU`0
0`3RQU`90>>1C`T0hWa11P3QMC050=m^7P@0fVH:103CG@030<YC00030000003oool0oooo0=40oooo
003o0?ooofX0oooo00<0000005007@1@01d00`1@01d00`000000hXIL0>:6G0050>:6G0T0hh5?203R
O4460>5e<0H0gfhN103JIPX40==M00<0bU<000<000000?ooo`3oool0d03oool00?l0ooooJ@3oool0
0`000000D00M05007@0405007@030000003RQU`0hXIL00H0hXIL2@3SPDl80>9l@@H0hGD`1P3OKQh4
0=YV2P@0ded00`3:D`000`000000oooo0?ooo`3?0?ooo`00o`3ooomY0?ooo`030000001@01d0D00M
00<0D00M00<000000>:6G03RQU`0203RQU`90>>1C`P0hWa11P3QMC050=m^7P@0fVH:103CG@030<YC
00030000003oool0oooo0<l0oooo003o0?ooofP0oooo00<0000005007@1@01d00`1@01d00`1X4TL0
00000>:;IP0:0>:6G0T0hh5?203RO4460>5e<0D0gfhN103JIPX40==M00<0bU<000<000000?ooo`3o
ool0cP3oool00?l0ooooJ03oool00`000000D00M05007@0406PBA`030000003RRfH0hX]V00X0hXIL
2@3SPDl80>9l@@<0hGD`0P3WPC/40>Il;@80gfhN103JIPX30==M00<0bU<000<0_dX00000003oool0
cP3oool00?l0ooooI`3oool00`000000J19706PBA`0406PBA`030000003RRfH0hX]V0080hX]V2P3R
QU`90>>1C`L0hWa11P3WPC/50>Il;@80i7LN0P3JIPX40==M00<0bU<000<0_dX00000003oool0c@3o
ool00?l0ooooI`3oool00`000000J19706PBA`0406PBA`030000003RRfH0hX]V00<0hX]V2P3RQU`9
0>>1C`D0hWa10P3XQTP60>N1>`D0iW`]0`3TMah00`3JIPX0ded00==M00020==M00<0bU<000<0_dX0
0000003oool0c03oool00?l0ooooI`3oool00`000000J19706PBA`0406PBA`030000003RRfH0hX]V
00@0hX]V2P3RQU`90>>1C`<0hWa1103XQTP50>N1>`H0iW`]103TMah30==M00<0bU<00P2oBP000`00
0000oooo0?ooo`3:0?ooo`00o`3ooomV0?ooo`030000001X4TL0J19700@0J19700<000000>:;IP3R
RfH01P3RRfH:0>:6G0T0hh5?00<0hWa10>R6B03XQTP0103XQTP50>N1>`D0iW`]103TMah20>1b3`80
ded00`3:D`020;m:00030000003oool0oooo0<T0oooo003o0?ooofH0oooo00<0000006PBA`1X4TL0
101X4TL00`000000hX]V0>:;IP070>:;IPX0hXIL203SPDl70>R6B0H0ih4k1@3VO2d40>Ag7P80h78?
00@0ded00<YC003:D`00bU<00`2oBP000`000000oooo0?ooo`380?ooo`00o`3ooomV0?ooo`030000
001X4TL0J19700@0J19700<000000>:;IP3RRfH0203RRfH:0>:6G0L0hh5?00<0j8YC0>R6B03XQTP0
1@3XQTP50>N1>`D0iW`]103TMah40>1b3`<0bU<00`2oBP000`000000oooo0?ooo`370?ooo`00o`3o
oomU0?ooo`030000001X4TL0J19700D0J19700<000000>:;IP3RRfH02@3RRfH:0>:6G0D0hh5?0`3X
RU<70>R6B0D0ih4k1@3VO2d40>Ag7P@0h78?0`3:D`020;m:00030000003oool0oooo0<L0oooo003o
0?ooofD0oooo00<0000006PBA`1X4TL0101X4TL00`000000hX]V0>:;IP0;0>:;IPX0hXIL0`3SPDl5
0>R:D`H0j8I81P3WPC/50>Il;@<0i7LN103PLPl00`3KK000bU<00<YC00030;m:00030000003oool0
oooo0<H0oooo003o0?ooofD0oooo00<0000006PBA`1X4TL0101X4TL00`000000hX]V0>:;IP0<0>:;
IPX0hXIL00<0hh5?0>R:D`3XRU<01@3XRU<60>R6B0D0ih4k1@3VO2d40>Ag7P@0h78?00<0ff`00<YC
003:D`000`2oBP000`000000oooo0?ooo`350?ooo`00o`3ooomU0?ooo`030000001X4TL0J19700<0
J19700<0N2iU0000003RT7003P3RRfH90>:6G0P0j8YC1`3XQTP50>N1>`D0iW`]103TMah30>1b3`80
ff`000H0bU<00;m:002oBP00_dX00;92000000360?ooo`00o`3ooomT0?ooo`040000001X4TL0J197
06PBA`@0N2iU00<000000>:@L03RT7003P3RRfH80>:6G0030>N>GP3XRU<0j8YC00H0j8YC1`3XQTP5
0>N1>`D0iW`]0`3TMah40>1b3`80ff`000D0bU<00;m:002oBP00_dX0000000360?ooo`00o`3ooomT
0?ooo`030000001h;VD0N2iU00D0N2iU00@000000>:@L03RT700hY1`3P3RRfH60>:6G0<0ihiN203X
RU<60>R6B0D0ih4k1@3VO2d40>Ag7P<0h78?0`3KK0001@3:D`00_dX00;m:002b@P0000000<D0oooo
003o0?ooof@0oooo00<0000007P^I@1h;VD01@1h;VD00`000000hY1`0>:@L0020>:@L0h0hX]V1@3R
QU`40>N>GPP0j8YC1P3XQTP50>N1>`D0iW`]0`3TMah40>1b3`<0ff`00`2oBP000`2b@P0000000?oo
o`330?ooo`00o`3ooomT0?ooo`030000001h;VD0N2iU00D0N2iU00<000000>:@L03RT700103RT70=
0>:;IP<0hXIL1P3WSUh80>R:D`H0j8I81@3WPC/40>Il;@@0i7LN0`3PLPl40=]/00<0_dX000<00000
0?ooo`3oool0`P3oool00?l0ooooI03oool00`000000N2iU07P^I@0507P^I@030000003RT700hY1`
00D0hY1`3@3RRfH20>:6G0L0ihiN1`3XRU<60>R6B0D0ih4k1@3VO2d30>Ag7P@0h78?0`3KK0001@3E
I`00_dX00;m:002b@P0000000<<0oooo003o0?ooof@0oooo00<0000007P^I@1h;VD0101h;VD00`00
0000hY1`0>:@L0070>:@L0d0hX]V00<0hXIL0>N>GP3WSUh01P3WSUh70>R:D`H0j8I81@3WPC/50>Il
;@<0i7LN0`3PLPl40=]/00050=EW002oBP00_dX00;9200000000`P3oool00?l0ooooI03oool00`00
0000N2iU07P^I@0407P^I@030000003RT700hY1`00P0hY1`303RRfH:0>N>GPL0j8YC1P3XQTP50>N1
>`@0iW`]0`3TMah40>1b3`<0ff`00P3EI`00102oBP00/T800;92000000310?ooo`00o`3ooomT0?oo
o`030000001h;VD0N2iU00@0N2iU00<000000>:@L03RT7002P3RT70:0>:;IP030>NBI`3WSUh0ihiN
00P0ihiN1`3XRU<60>R6B0@0ih4k1@3VO2d30>Ag7P@0h78?0`3KK0020=EW00030;m:002b@P000000
0<40oooo003o0?ooof<0oooo00<0000007P^I@1h;VD01@1h;VD00`000000hY1`0>:@L00;0>:@L0T0
hX]V0P3WTVL:0>N>GPL0j8YC1@3XQTP50>N1>`@0iW`]103TMah30>1b3`<0ff`00`3EI`000`2oBP00
/T80000000300?ooo`00o`3ooomS0?ooo`030000001h;VD0N2iU00D0N2iU00<000000>:@L03RT700
303RT7070>:;IP@0ii9W2@3WSUh70>R:D`H0j8I81@3WPC/40>Il;@<0i7LN103PLPl30=]/00<0eFL0
00<0/T800:Hk00000000_`3oool00?l0ooooH`3oool00`000000N2iU07P^I@0507P^I@030000003R
T700hY1`00d0hY1`1P3RRfH50>NBI`T0ihiN1`3XRU<60>R6B080ih4k0P3]S4D40>b9>`040>Il;@3T
Mah0i7LN0>Ag7P<0h78?0`3KK0040=EW00030;9200000000oooo0;h0oooo003o0?ooof<0oooo00<0
000007P^I@1h;VD01@1h;VD00`000000hY1`0>:@L00?0>:@L0@0hX]V1P3WTVL90>N>GPL0j8YC1@3X
QTP50>f<A@@0k8Tk0P3[QS400`3TMah0h78?0>1b3`020>1b3`<0ff`00`3EI`000`2b@P00YS/00000
002n0?ooo`00o`3ooomS0?ooo`030000001h;VD0N2iU00@0N2iU00<0PT=j0000003QU7P04@3RT703
0>:;IPL0ii9W2@3WSUh70>R:D`<0j8I80P3]Sdl40>f<A@D0k8Tk0`3[QS430>1b3`@0ff`00`3EI`00
0`2b@P0000000?ooo`2m0?ooo`00o`3ooomS0?ooo`040000001h;VD0N2iU07P^I@@0PT=j00<00000
0>6DN03QU7P04@3RT7020>:;IPP0ii9W2@3WSUh70>R:D`030>R6B03]Sdl0kHm?0080kHm?103]S4D4
0>b9>`<0jhHa0P3YPbH20>1b3`<0ff`00`3EI`000`3>HP00YS/00000002m0?ooo`00o`3ooomS0?oo
o`0300000022@gX0PT=j00D0PT=j00<000000>6DN03QU7P00P3QU7P@0>:@L0X0ii9W2@3WSUh60>R:
D`D0kHm?103]S4D50>b9>`<0jhHa0`3YPbH40=]/0080eFL000@0cV800;92002V>`000000_03oool0
0?l0ooooH`3oool00`000000PT=j0893NP050893NP030000003QU7P0hIAh00<0hIAh3`3RT7020>JE
K`T0ii9W2@3WSUh50>R:D`030>fBE`3]Sdl0kHm?00<0kHm?103]S4D40>b9>`<0jhHa103YPbH30=]/
00<0eFL000<0cV800:Hk00000000_03oool00?l0ooooH`3oool00`000000PT=j0893NP050893NP03
0000003QU7P0hIAh00D0hIAh3@3RT7030>JEK`T0ii9W2@3WSUh30>R:D`<0kI9G103]Sdl50>f<A@@0
k8Tk0`3[QS430>V39P80ih0L0P3KK0020=EW00040<iR002b@P00YS/000000;/0oooo003o0?ooof<0
oooo00<000000893NP22@gX01@22@gX00`000000hIAh0>6DN0060>6DN0`0hY1`103VUFl90>NBI`T0
ihiN00<0j8YC0>fBE`3]TUL00P3]TUL50>f?C`@0kHa5103/RC/30>^6<@@0jH<V0P3WP1`01`3KK000
eFL00=EW003EI`00cV800:Hk00000000^`3oool00?l0ooooH`3oool00`000000PT=j0893NP050893
NP030000003QU7P0hIAh00P0hIAh2P3RT7050>JEK`T0ii9W203WSUh60>fBE`D0kHm?103]S4D40>b9
>`<0jhHa0`3YPbH30>N070030=]/003EI`00eFL00080cV8000<0YS/00000003oool0^@3oool00?l0
ooooC@3oool500000140oooo00<000000893NP22@gX01022@gX00`000000hIAh0>6DN00;0>6DN0P0
hY1`1P3VUFl90>NBI`L0ihiN00<0k9EO0>fBE`3]TUL0103]TUL40>f?C`@0kHa5103/RC/30>^6<@@0
jH<V0`3WP1`30=EW00040<iR002V>`00YS/000000;T0oooo003o0?ooodX0oooo0`0000030:@J0080
S@001@00000<0?ooo`0300000022@gX0PT=j00@0PT=j00<000000>6DN03QU7P0303QU7P70>:@L0L0
iYE_2@3WTVL50>N>GP<0k9EO1P3]TUL40>f?C`@0kHa5103/RC/30>^6<@<0jH<V103WP1`20=EW0080
cV8000<0YS/00?ooo`3oool0^03oool00?l0ooooB03oool2000000P0Y1X0102=0000101X00000000
0000000000090?ooo`0300000022@gX0PT=j00@0PT=j00<000000>6DN03QU7P03P3QU7P40>:@L0T0
iYE_2@3WTVL40>N>GP@0k9EO1@3]TUL50>f?C`<0kHa51@3/RC/20>^6<@<0jH<V103WP1`20=EW0080
cV800P2V>`2i0?ooo`00o`3ooom70?ooo`040000002a=1H0/C@F0;4d5PT0Y1X0102=000206P00003
0000003oool0oooo00H0oooo00<000000893NP22@gX01022@gX00`000000hIAh0>6DN00?0>6DN0<0
hY1`2P3VUFl90>NBI`80ihiN1@3/UEl60>fBE`@0kHm?103]S4D40>b9>`<0jhHa0`3YPbH40>N07080
eFL00P3>HP000`2V>`00oooo0?ooo`2g0?ooo`00o`3ooom60?ooo`030000002a=1H0/C@F00@0/C@F
2@2T6P0408d00080J0001`3oool00`000000PT=j0893NP040893NP030000003QU7P0hIAh0140hIAh
00<0hY1`0>JEK`3VUFl02P3VUFl80>NBI`030>N>GP3/UEl0k9EO00@0k9EO1P3]TUL40>f?C`<0kHa5
1@3/RC/20>^6<@<0jH<V103WP1`01P3UOA80eFL00<iR003>HP00aeh00:Hk0;P0oooo003o0?ooodD0
oooo00<000000;4d5P2a=1H0202a=1H80:@J00@0S@000P1X00050?ooo`0300000022@gX0PT=j00@0
PT=j00<000000>6DN03QU7P04P3QU7P=0>JEK`L0ii9W203/UEl50>fBE`@0kHm?103]S4D40>b9>`<0
jhHa0`3YPbH30>N07080iGdB00@0eFL00<iR003>HP00YS/0^03oool00?l0ooooA@3oool00`000000
^4Tg0;4d5P0:0;4d5PP0Y1X0102=000206P000<0oooo00<000000893NP22@gX01022@gX00`000000
hIAh0>6DN00B0>6DN080iYUf303VUFl60>NBI`030>bHI`3/UEl0k9EO00H0k9EO1@3]TUL40>f?C`<0
kHa51@3/RC/20>^6<@<0jH<V103WP1`01P3UOA80eFL00<iR003>HP00aeh00:Hk0;L0oooo003o0?oo
od@0oooo00<000000;Q9=`2hBCL00P2hBCL;0;4d5PP0Y1X0102=000010000000J0000?ooo`000005
0893NP0308UCRP000000hIQo01<0hIAh0`3VVGH<0>JEK`D0ii9W0P3/V6L70>bEG`H0kI9G103]Sdl3
0>f<A@@0k8Tk0`3[QS430>V39P<0ih0L0P3UOA820<iR0080aeh0]`3oool00?l0oooo@`3oool00`00
0000^4Tg0;Q9=`060;Q9=`/0/C@F1`2T6P0408d0000406P000000000PT=j0893NP@0RE>:00@00000
0>6HO`3QV7l0hIQo4@3QU7P40>JIMP`0iYE_103WTVL30>bHI`L0k9EO1@3]TUL40>f?C`@0kHa5103/
RC/20>^6<@<0jH<V0`3WP1`30>Em4P80cV8000<0aeh00:Hk003oool0]@3oool00?l0oooo@P3oool0
0`000000^4Tg0;Q9=`090;Q9=`/0/C@F1`2T6P0308d0000300000029DhX0RE>:00@0RE>:00<00000
0>6HO`3QV7l00P3QV7l@0>6DN0D0iYUf303VUFl20>NBI`D0k9QW1`3/UEl50>fBE`@0kHm?0`3]S4D4
0>b9>`<0jhHa0`3YPbH30>N07080iGdB0P3>HP020<MN00030000003oool0oooo0;<0oooo003o0?oo
od40oooo00<000000;Q9=`2hBCL0302hBCL;0;4d5PL0Y1X000<0S@0000000029DhX01@29DhX00`00
0000hIQo0>6HO`040>6HO`h0hIAh1P3VVGH<0>JEK`030>NBI`3/V6L0k9QW00@0k9QW1`3/UEl50>fB
E`<0kHm?103]S4D40>b9>`80jhHa0`3YPbH30>N070<0iGdB0P3>HP000`37GP0000000?ooo`2d0?oo
o`00o`3ooom10?ooo`030000002lFE40^4Tg00l0^4Tg2P2a=1H60:@J000300000029DhX0RE>:00@0
RE>:00<000000>6HO`3QV7l01P3QV7l<0>6DN0P0iYUf2`3VUFl70>bHI`H0k9EO1P3]TUL30>f?C`<0
kHa5103/RC/30>^6<@<0jH<V0`3WP1`20>Em4P050>9k2@3>HP00aeh00<MN00000000P@3oool200WZ
2P800000;`3oool00?l0oooo@03oool00`000000_5UA0;aID@030;aID@l0^4Tg2`2a=1H30:@J0003
00000029DhX0RE>:00@0RE>:00<000000>6HO`3QV7l0203QV7l:0>6DN0T0iYUf2P3VUFl80>bHI`H0
k9EO1@3]TUL40>f?C`<0kHa5103/RC/20>^6<@<0jH<V0`3WP1`20>Em4P80hW/900@0cV800<MN0037
GP000000O03oool400WZ2P80oooo0P00000_0?ooo`00o`3ooom00?ooo`030000002lFE40_5UA00H0
_5UA3P2hBCL;0;4d5P030:@J00000000RE>:00D0RE>:00<000000>6HO`3QV7l02@3QV7l90>6DN0X0
iYUf2@3VUFl00`3[Vfh0k9QW0>bHI`060>bHI`H0k9EO1@3]TUL30>f?C`<0lIM>103aUDP30?6C@@80
jH<V0`3WP1`30>Em4P050>9k2@3>HP00aeh00<MN00000000N@3oool300WZ2SL0oooo003o0?ooocl0
oooo00<000000;aID@2lFE402@2lFE4>0;Q9=`P0/C@F0P38EB`00`000000RE>:08UCRP0408UCRP03
0000003QV7l0hIQo00/0hIQo1`3QU7P;0>JIMPP0iYE_0P3[Vfh70>bHI`L0k9EO1@3]TUL00`3]Sdl0
lIQE0?6HE@030?6GCP@0lIE80P3aTd420?2B>P040>V39P3WP1`0ih0L0>N07080iGdB0P3RN`T30<MN
00030000003oool0oooo0780oooo1009jPXj0?ooo`00o`3ooolo0?ooo`030000002lFE40_5UA00`0
_5UA3P2hBCL40;4d5P<0b5D/00<0000008UCRP29DhX01@29DhX00`000000hIQo0>6HO`0<0>6HO`D0
hIAh303VVGH70>JEK`<0ji]^1`3/V6L60>bEG`D0kI9G0`3aV5D30?6GCP@0lIE80`3aTd420?2B>P<0
ih0L0P3UOA830>9k2@80aeh000<000000?ooo`3oool0KP3oool400WZ2Sh0oooo003o0?ooocl0oooo
00<000000;aID@2lFE403P2lFE4>0;Q9=`030;4d5P38EB`0b5D/0080b5D/00<0000008UCRP29DhX0
1@29DhX00`000000hIQo0>6HO`0>0>6HO`<0hIAh3P3VVGH50>JEK`@0ji]^1`3/V6L60>bEG`@0kI9G
00@0lIYK0?6HE@3aV5D0lIQE0`3aUdh30?6EB0<0lI=10`3`TSX20>N070<0iGdB0P3RN`T20<MN0003
0<1K00000000oooo06/0oooo0`09jPY20?ooo`00o`3oooln0?ooo`030000002lFE40_5UA0180_5UA
2`2hBCL20<]RA0<0b5D/00<0000008UCRP29DhX01@29DhX00`000000hIQo0>6HO`0?0>6HO`80hIAh
3`3VVGH30>JEK`H0ji]^1`3/V6L60>bEG`80kI9G0P3aVU/30?6HE@<0lIM>103aUDP20?6C@@<0l98j
00<0l94d0>N0703WP1`00P3UOA830>9k2@80aeh000<000000?ooo`3oool0IP3oool400WZ2TD0oooo
003o0?oooch0oooo00<000000;iUI@2lFE405@2lFE480;Q9=`<0bf940P38EB`00`000000RE>:08UC
RP0508UCRP030000003QV7l0hIQo0140hIQo403VVGH20>JEK`L0ji]^1`3/V6L60>bEG`040>fBE`3a
VU/0lIYK0?6JF`<0lIQE0`3aUdh30?6EB0<0lI=10`3`TSX00`3`TC@0ih0L0>Em4P020>Em4P80hW/9
00@0gWX20<MN0030F`000000H`3oool400WZ2TT0oooo003o0?ooocd0oooo00<000000;iUI@2nIFD0
0`2nIFDE0;aID@D0^4Tg1P3;HT@00`000000RE>:08UCRP0508UCRP030000003QV7l0hIQo0140hIQo
0P3VW7d?0>JIMP030>JEK`3[Vfh0ji]^00H0ji]^1`3/V6L50>bEG`D0lIYK0`3aV5D20?6GCP@0lIE8
0P3aTd430?2B>P80l94d0`3UOA820>9k2@040=ij0P37GP00aeh00<1K05l0oooo1009jPXP0?ooo`03
00WZ2P000000000002X0oooo003o0?oooc`0oooo0P0000080;iUIAD0_5UA00<0^4Tg0<]RA03;HT@0
1@3;HT@00`000000RE>:08UCRP0508UCRP030000003QV7l0hIQo0140hIQo0`3VW7d?0>JIMPT0ji]^
1`3/V6L40>bEG`030?2LH@3aVU/0lIYK0080lIYK0`3aV5D30?6GCP<0lIE80`3aTd420?2B>P<0l94d
0P3UOA830>9k2@030=ij0P37GP00`5/005`0oooo0`09jPXQ0?ooo`<02NX:00<0oooo000000000000
:P3oool00?l0oooo?03oool2000000/0_VEU4P2lFE420<a/F0H0bf9400<0000008UCRP29DhX01@29
DhX00`000000hIQo0>6HO`0A0>6HO`D0iYam3@3VVGH20>^ML`P0ji]^1`3/V6L20>bEG`<0l9aQ103a
VU/30?6HE@80lIM>0`3aUDP30?6C@@<0l98j0P3`TC@00`3_T2h0iGdB0>Em4P020>9k2@80gWX200<0
aeh00<1K003oool0EP3oool400WZ2R00oooo1009jPX`0?ooo`00o`3ooolk0?ooo`8000003`2nIFD?
0;aID@@0c6aH103;HT@00`000000RE>:08UCRP0508UCRP030000003QV7l0hIQo0140hIQo1`3VW7d;
0>JIMP<0jiec203[Vfh70>bHI`040>bEG`3`W640l9aQ0?2LH@@0lIYK0`3aV5D30?6GCP<0lIE80P3a
Td430?2B>P80l94d0P3_T2h00`3UOA80hW/90>9k2@020=ij0P030<MN0030F`00oooo0580oooo1009
jPXQ0?ooo`<02NX:=03oool00?l0oooo>`3oool200000180_VEU2`2lFE460<a/F0<0bf9400<00000
08UCRP29DhX01@29DhX00`000000hIQo0>6HO`0A0>6HO`P0iYam2P3VVGH40>^ML`P0ji]^1P3/V6L5
0?2LH@@0lIYK0`3aV5D20?6GCP<0lIE80`3aTd420?2B>P<0l94d0P3_T2h30>9k2@80gWX20P30F`1>
0?ooo`@02NX:8@3oool400WZ2SL0oooo003o0?ooocX0oooo0`00000E0;iUI@P0_5UA203<K5P00`3;
HT@0000008UCRP0408UCRP80Sf6G00<000000>6LQP3QV7l04@3QV7l:0>JLO@P0iYUf1@3[WG<80>^K
KPD0k9QW00<0l9iV0?2LH@3`W6400`3`W6440?6JF`80lIQE0`3aUdh30?6EB080lI=10`3`TSX20?2A
=0<0ki0^0P3RN`T30=ij0P030<1K003oool0oooo04T0oooo0`09jPXR0?ooo`<02NX:>`3oool00?l0
oooo>P3oool2000001T0_VEU102lFE4:0<a/F00300000029DhX0Sf6G00D0Sf6G00<000000>6LQP3Q
W8H00P3QW8H@0>6HO`/0iYam1P3VVGH60>^ML`P0ji]^103/V6L20?2NIP@0l9aQ103aVU/30?6HE@80
lIM>0`3aUDP30?6C@@80l98j0P3`TC@30>n@;P80hW/90`3NNP820<1K04H0oooo1009jPXQ0?ooo`@0
2NX:?P3oool00?l0oooo>@3oool300000080_fmd6P2nIFD00`2lFE40c6aH0<a/F0080<a/F0030000
002?HIL0Sf6G00D0Sf6G00<000000>6LQP3QW8H01@3QW8H=0>6HO``0iYam1@3VVGH70>^ML`P0ji]^
0`3/V6L30?2NIP@0l9aQ103aVU/20?6HE@<0lIM>0`3aUDP20?6C@@80l98j0`3`TC@20>n@;P030>j?
:@3RN`T0hW/90080gWX200<0fgT00<1K003oool0@@3oool400WZ2R40oooo1009jPY20?ooo`00o`3o
ooli0?ooo`<000001@2oKg@G0;iUI@80c7AX2@3<K5P00`000000Sf6G08mQU`0508mQU`030000003Q
W8H0hIb600L0hIb62`3QV7l>0>JLO@<0iYUf203[WG<80>^KKP030>bHI`3`WVH0l9iV0080l9iV1@3`
W6430?6JF`<0lIQE0P3aUdh30?6EB0<0lI=10P3`TSX20?2A=0<0ki0^00<0kXlY0>9k2@3NNP800P3N
NP800`30F`00^U/00?ooo`0m0?ooo`<02NX:8P3oool300WZ2Qh0oooo0P09jPX2000002@0oooo003o
0?ooocP0oooo0P0000000`0002T000000;m_M0080;m_M1<0_VEU103<M6P70<a/F0030000002?HIL0
Sf6G00H0Sf6G00<000000>6LQP3QW8H02@3QW8H80>6HOa00iYam00<0iYUf0>^ML`3[WG<0203[WG<7
0>^KKPD0l9iV103`W6440?6JF`80lIQE0`3aUdh20?6EB0<0lI=10P3`TSX20?2A=0<0ki0^00<0kXlY
0>9k2@3NNP800P3NNP800`3KN@00`5/00?ooo`0i0?ooo`@02NX:8@3oool400WZ2Qh0oooo0`09jPX2
0?ooo`800000903oool00?l0oooo>03oool2000000030000:@000000_fmd00/0_fmd402nIFD60<ad
J0D0c6aH00<0000008mQU`2?HIL01P2?HIL00`000000hIb60>6LQP0;0>6LQPH0hIQo4@3VW7d;0>^M
L`H0ji]^1P3`WVH40?2LH@@0lIYK0P3aV5D20?6GCP<0lIE80P3aTd420?2B>P<0l94d0P3_T2h20>j?
:@030>9k2@3NNP80gWX20080fgT000<0^U/00?ooo`3oool0<`3oool400WZ2R80oooo0`09jPXO0?oo
o`<02NX::`3oool00?l0oooo=`3oool200000080000Y00<000000;m_M02oKg@03P2oKg@<0;iUI@P0
c7AX103<K5P00`000000Sf6G08mQU`0508mQU`030000003QW8H0hIb600h0hIb60`3QV7lA0>JLO@80
jj1i2P3[WG<50>^KKP030?2PK03`WVH0l9iV00@0l9iV0`3`W6440?6JF`<0lIQE0P3aUdh20?6EB0<0
lI=10P3`TSX20?2A=080ki0^0`3^SbT20=ij0P80fgT000<0`5/00?ooo`3oool0;`3oool400WZ2R80
oooo1009jPXO0?ooo`<02NX:;P3oool00?l0oooo=`3oool2000000030000:@000000_fmd01<0_fmd
202nIFD;0<adJ080c6aH00<0000008mQU`2?HIL01@2?HIL00`000000hIb60>6LQP0A0>6LQQ40iYam
0`3[X7T:0>^ML`@0ji]^0P3`X6`50?2NIP@0l9aQ103aVU/20?6HE@80lIM>0`3aUDP20?6C@@80l98j
0P3`TC@20>n@;P<0kXlY0`3NNP820=]i02h0oooo0`09jPXS0?ooo`<02NX:7`3oool400WZ2S40oooo
003o0?ooocH0oooo0P0000020000:@030000002oKg@0_fmd01H0_fmd102nIFD=0<adJ0030000002?
HIL0Sf6G00D0Sf6G00<000000>6LQP3QW8H04@3QW8H20>JOPPl0iYam103[X7T:0>^ML`<0ji]^0`3`
X6`50?2NIP@0l9aQ0`3aVU/30?6HE@80lIM>0P3aUDP30?6C@@040?2B>P3`TC@0l94d0?2A=080ki0^
0P3^SbT00`3]SbD0gWX20=ij0P020=]i00030;YK003oool0oooo02L0oooo1009jPXR0?ooo`@02NX:
7`3oool300WZ2SD0oooo003o0?ooocH0oooo0P0000020000:@030000002oKg@0_fmd01T0_fmd00<0
_VEU0<adJ03<M6P02`3<M6P00`000000Sf6G08mQU`0508mQU`030000003QW8H0hIb60140hIb6103V
Wh8=0>JLO@H0jj1i2@3[WG<00`3[Vfh0l:1/0?2PK0030?2PK0D0l9iV0`3`W6440?6JF`80lIQE0P3a
Udh20?6EB0<0lI=10P3`TSX20?2A=080ki0^0P3^SbT20>f?9@040=ij0P3KN@00fgT00=]i02D0oooo
1009jPXS0?ooo`<02NX:803oool300WZ2SP0oooo003o0?ooocD0oooo0P0000030000:@030000002o
Kg@0_fmd01X0_fmd0P3<O7D;0<adJ0030000002?HIL0Sf6G00D0Sf6G00<000000>6LQP3QW8H04@3Q
W8H60>JOPP/0iYam1`3[X7T90>^ML`H0l:1/103`WVH40?2LH@@0lIYK0P3aV5D20?6GCP80lIE80P3a
Td420?2B>P80l94d0P3_T2h30>j?:@030>f?9@3NNP80fgT00080fgT000<0^U/00?ooo`3oool07P3o
ool400WZ2R<0oooo1009jPXO0?ooo`@02NX:6P3oool2000001l0oooo003o0?ooocD0oooo0P000003
0000:@030000002oKg@0_fmd01X0_fmd103<O7D90<adJ0030000002?HIL0Sf6G00D0Sf6G00<00000
0>6LQP3QW8H04@3QW8H80>JOPPX0iYam1`3[X7T80>^ML`030?2RL03`X6`0l:1/00@0l:1/103`WVH4
0?2LH@<0lIYK0P3aV5D20?FPE`80mImC0`3eWdl01@3`TSX0l94d0?2A=03`TC@0ki0^00<0kXlY0P3]
SbD0103NNP80fgT00=]i003INP0M0?ooo`<02NX:903oool300WZ2R00oooo0`09jPXM0?ooo`0300WZ
2P000000000001l0oooo003o0?oooc@0oooo0P0000040000:@0300000030N840`7R101X0_fmd1P3<
O7D70<adJ0030000002?HIL0Sf6G00D0Sf6G00<000000>6LQP3QW8H04@3QW8H:0>JOPPP0iYam2@3[
X7T60>^ML`80l:9`1P3`X6`40?2NIP<0l9aQ103aVU/0103aV5D0mJ5K0?FPE`3eX5L20?FOD`80mIm?
0P3eWT`20?2A=080ki0^0P3^SbT30>f?9@80fgT000<0fGX00;YK003oool05`3oool400WZ2R<0oooo
1009jPXP0?ooo`<02NX:7@3oool300WZ2R80oooo003o0?oooc<0oooo0`0000040000:@0300000030
N840`7R100D0`7R15@2oKg@80<alM@D0c7AX00<0000008mQU`2?HIL01P2?HIL00`000000hIb60>6L
QP0@0>6LQP`0iYn21P3VW7d:0>^PN@D0jiec0`3`XW050?2PK0D0l9iV0`3`W6430?6JF`80mJ5K0P3e
X5L20?FOD`80mIm?0P3eWT`0103eWTT0l94d0>n@;P3_T2h20>j?:@<0kHlU0`3KN@000`3INP00oooo
0?ooo`0B0?ooo`@02NX:903oool300WZ2R40oooo0`09jPXM0?ooo`<02NX:9@3oool00?l0oooo<`3o
ool2000000@0000Y00<0001@00000030N8402`30N84@0;m_M0X0c7ae0`3<M6P00`000000Sf6G08mQ
U`0608mQU`030000003QW8H0hIb60100hIb63P3VWh840>JLO@/0jj1i103[WG<40?2RL0D0l:1/103`
WVH40?2LH@030?6JF`3dXUh0m:9N0080mJ5K00<0mJ1G0?FOD`3eWe<00`3eWdl01@3eWT`0mIi90?FN
B@3`TC@0ki0^0080kXlY0`3]SbD01@3/T240fgT00=]i003INP00^U/00100oooo0`09jPXT0?ooo`@0
2NX:803oool400WZ2Qd0oooo0`09jPXX0?ooo`00G03oool>00000<L0oooo0`0000040000:@030000
D0000000`7R100l0`7R12`2oKg@>0<alM@030<adJ0000000Sf6G00H0Sf6G00<000000>6LQP3QW8H0
4@3QW8H?0>JOPP80iYam3@3[X7T20>^ML`D0l:9`1@3`X6`40?2NIP<0l9aQ0`3dXUh20?FQF`80mJ1G
0P3eWe<20?FOC`80mIi<0P3eWTT0103_T2h0kXlY0>j?:@3^SbT20>f?9@030>b@8@3KN@00fgT00080
fGX0303oool400WZ2R<0oooo1009jPXQ0?ooo`<02NX:7P3oool300WZ2R/0oooo001G0?ooo`D00000
0P3f`I<90?C0UP<0lknH0`0000340?ooo`800000100002T20000D00300000030N840`7R101<0`7R1
1P2oKg@?0<alM@030000002?HIL0Sf6G00D0Sf6G00<000000>6LQP3QW8H04@3QW8HA0>JOPPh0jj1i
00<0jiec0?2RL03`XW00103`XW050?2PK0@0l9iV0P3`W640103dXf80m:9N0?BRGP3dXUh20?FQF`03
0?FPE`3eWe<0mImC0080mIm?0P3eWT`20?FNB@040>n@;P3^SbT0kXlY0>j?:@<0kHlU00D0k90Q0=]i
003INP00fGX00;YK00070?ooo`@02NX:903oool300WZ2R80oooo0`09jPXN0?ooo`<02NX:;P3oool0
05@0oooo0`0000070?K1T`030000003d`9H0m<2F00H0m<2F1P3c_iP300000<00oooo0`0000030000
:@<0001@00<000000<1hP@30N8406030N8400`2oKg@0c7ae0<alM@0=0<alM@030000002?HIL0Sf6G
00@0Sf6G00@0U6bR0000003QWh`0hIn<4@3QW8HA0>JOPP80jj=n3@3[X7T70?2RL0D0l:1/103`WVH3
0?BSHP80m:9N0P3eXE/20?FPE`80mImC0P3eWdl01@3eWT`0mIi90?FNB@3eWTH0ki0^0080kXlY0`3]
SbD00`3/T240fgT00=Uj00020=Uj00<0oooo1009jPXT0?ooo`@02NX:8@3oool400WZ2Qd0oooo1009
jPXa0?ooo`00C`3oool2000000040?ooo`00000000000?S2T0T0m/6C2@3d`9H00`000000lknH0?>o
V0060?>oV0<00000_@3oool2000000@0000Y0`0005000`000000`7R10<1hP@0I0<1hP@80cH=o3@3<
O7D010000000Sf6G08mQU`2?HIL409A/XP030000003QWh`0hIn<00<0hIn<3P3QW8HA0>JOPP@0jj=n
2`3[X7T20?2TM0H0l:9`1@3`X6`30?2NIP<0m:=R0`3dXUh00`3eXE/0mJ1G0?FPE`020?FOD`80mIm?
0P3eWT`20?FNB@030?FNAP3^SbT0kXlY00<0kHlU0P3/T2400`3KN@00fGX00=Uj000300WZ2RD0oooo
0`09jPXR0?ooo`<02NX:7P3oool300WZ2QX0oooo0P00000I0?ooo`00CP3oool4000000<0n<:@2@3f
`I<90?C0UPX0lknH0P3a_IT200000;X0oooo0P0000040000:@@0001@00<000000<1hP@30N8406@30
N8450<f3O`X0c7ae00<0000009A/XP2DK:801P2DK:800`000000hIn<0>6OS0050>6OS0/0hIb64@3V
Wh850>^SOPX0jj1i0`3`Y7@60?2RL0D0l:1/0P3`WVH0103dY6D0m:=R0?BSHP3dXf820?BRGP80mJ5K
00<0mJ1G0?FOD`3eWe<00P3eWdl20?FNC080mIi900<0mIi60>j?:@3^SbT00`3]SbD00`3/T2402NX:
00WZ2P0200WZ2P030=Uj003oool0oooo0240oooo1009jPXR0?ooo`<02NX:7P3oool300WZ2Q`0oooo
00<02NX:0000000000006@3oool004`0oooo100000060?S2T0T0m/6C203d`9H:0?>oV0@0lKfI0P00
002g0?ooo`<00000100002T40000D00300000030N840`7R101T0`7R1203=Pgl70<alM@030000002D
K:80U6bR00H0U6bR00<000000>6OS03QWh`02@3QWh`70>6LQQ40iYn21`3[Xgh80>^PN@@0l:Ad1P3`
XW050?2PK0<0m:AU0P3dXf830?BRGP030?FQF`3eX5L0mJ1G0080mImC0P3eWdl01P3eWT`0mIi90?FN
B@3eWTH0mIi30>j?:@@02NX:0P3/T2430=Uj0200oooo0`09jPXS0?ooo`<02NX:7P3oool300WZ2Q`0
oooo0`09jPXL0?ooo`00BP3oool4000000P0n<:@2@3f`I<80?C0UPX0lknH1P3a_IT200000;D0oooo
0P0000040000:@D0001@00<000000<1hP@30N8406@30N84:0<f3O`D0c7ae00<0000009A/XP2DK:80
1P2DK:800`000000hIn<0>6OS00<0>6OS0@0hIb64@3VWh890>^SOPH0jj1i1@3`Y7@60?2RL0@0l:1/
0`3dY6D30?BSHP80m:9N0P3eXE/00`3eX5L0mImC0?FOD`020?FOC`030?FNC03eWTT02NX:00<02NX:
00<0kXlY0>f?9@3]SbD00`3/T2430=Uj00030=Ml003oool0oooo01T0oooo1009jPXR0?ooo`@02NX:
7P3oool300WZ2Q`0oooo0`09jPXO0?ooo`00B@3oool4000000T0n<:@2@3f`I<90?C0UPT0lknH00<0
00000?6mV@3a_IT01@3a_IT200000;80oooo0`0000040000:@D0001@00<000000<1hP@30N8406@30
N84=0<f3O`<0c7ae00<0000009A/XP2DK:801@2DK:800`000000hIn<0>6OS00?0>6OS0030>6LQP3V
Wh80iYn200l0iYn22`3[Xgh50>^PN@D0l:Ad1P3`XW030?2PK0040?BVJ@3dY6D0m:AU0?BTI@<0m:=R
0P3dXUh00`3eXE/0mJ1G0?FPE`020?FOD`<02NX:00<0mIi90?FNAP3eWTH00P3eWT<20>f?9@<0k90Q
00@0k94O0=Uj003INP00eg`0603oool300WZ2R<0oooo0`09jPXO0?ooo`<02NX:703oool300WZ2R80
oooo00180?ooo`050000000W00009`000000003i`X`02@3h`Y090?K1T`T0m<2F2@3c_iP:0?6mV@80
0000[`3oool3000000@0000Y1P00050010000000`Gn;0<5oR`31Oh/H0<1hP@l0cH=o00<0c7ae0000
002DK:801P2DK:800`000000hIn<0>6OS00@0>6OS0<0iZ>73`3VWh8<0>^SOP<0jj1i1P3`Y7@60?2R
L080l:1/0P3dYVT20?BTI@<0m:=R0`3dXUh400WZ2P80mIm?00@0mIi<0?FNB@3eWTT0mIi60P3eWT<3
0>f?9@80k90Q00D0k94O0=Uj003INP00eg`00;IL000C0?ooo`@02NX:8`3oool300WZ2Ql0oooo0`09
jPXL0?ooo`<02NX:9@3oool004L0oooo00@0000002L0000W000000000`3i`X`80?S2T0T0m/6C2@3d
`9H90?>oV0X0lKfI0P3__9X00`000000oooo0?ooo`2[0?ooo`@000000`0002T70000D00300000031
Oh/0`Gn;00H0`Gn;4P30N84A0<f3O`030000002DK:80U6bR00H0U6bR00<000000>6OS03QWh`03`3Q
Wh`60>JSQ``0iYn23@3[Xgh20>^PN@P0l:Ad1@3`XW00103`X6`0m:IY0?BVJ@3dYVT20?BTI@030?BS
HP09jPX02NX:00802NX:00<0mJ5K0?FPE`3eX5L00P3eWe<01@3eWdl0mIi<0?FNB@3eWTT0mIi60080
mIi300<0mIi10>f?9@3]SbD00P3/T2420>bA7`80fGX000<0eg`00?ooo`3oool03P3oool300WZ2R<0
oooo1009jPXN0?ooo`@02NX:703oool300WZ2RP0oooo00160?ooo`040000000W00009`00000000@0
nL:<2@3h`Y080?K1T`T0m<2F2@3c_iP:0?6mV@<0kkbJ0P00002Z0?ooo`@00000100002T60000D003
00X0K@000000`Gn;00d0`Gn;3030N84A0<f3O`030000002DK:80U6bR00H0U6bR00<000000>6OS03Q
Wh`0403QWh`80>JSQ`T0iYn23`3[Xgh90?2TM0D0l:9`0`3dYVT300WZ2P80m:=R0`3dXUh01@3eXE/0
mJ1G0?FOD`3eWe<0mIm?0080mIi<00@0mIi90?FNAP3eWT<0mIi30P3eWT400`3]SbD0k90Q0>b@8@03
0>bA7`030=Uj003GO000oooo00/0oooo1009jPXS0?ooo`<02NX:7`3oool300WZ2Qd0oooo0`09jPX[
0?ooo`00A@3oool0100000009`0002L0000000050?W2S0T0n<:@203f`I<90?C0UPT0lknH2P3a_IT5
0>nlVP030000003oool0oooo0:H0oooo1@0000030000:@H0001@0P0:06d00`000000`Gn;0<5oR`0A
0<5oR`L0`7R14@3=Pgl00`000000U6bR09A/XP0609A/XP030000003QWh`0hIn<0100hIn<2`3VXhL6
0>JOPPl0jj=n0P3`YgP80?2TM080000000<0l:9`00WZ2P09jPX00P09jPX00`3dYVT0m:AU0?BTI@03
0?BSHP80m:9N00@0mJ5K0?FPE`3eWe<0mImC0P3eWdl01@3eWT`0mIi90?FNAP3eWTH0mIi300<0mIi1
0`3/T2420>bA7`030=Uj003GO000]U`000P0oooo0`09jPXT0?ooo`<02NX:7`3oool300WZ2Qd0oooo
0`09jPXG0?ooo`0300WZ2P000000000001@0oooo00140?ooo`040000000W00009`00000000H0nL:<
2@3h`Y080?K1T`T0m<2F2@3c_iP:0?6mV@H0kkbJ00<000000?ooo`3oool0Y03oool3000000030?R_
L@000000000Y00<0000Y1P00050200X0K@0300000031Oh/0`Gn;01H0`Gn;0P30N84B0<f3O`030000
002DK:80U6bR00D0U6bR00<000000>6OS03QWh`0403QWh`>0>JSQ`<0iYn23`3[Xgh30?2WN0L0l:Ad
00D0000000WZ2P09jPX0l:9`0?BWK0040?BVJ@80m:AU0`3dXf820?BRGP070?FQF`3eX5L0mImC0?FO
D`3eWdl0mIi<0?FNB@020?FNAP80mIi30P3eWT430>b@8@<0k94O0P3GO0040?ooo`@02NX:903oool3
00WZ2Ql0oooo0`09jPXM0?ooo`<02NX:5`3oool300WZ2P030?ooo`000000000001@0oooo00130?oo
o`040000000W00009`00000000P0nL:<203h`Y090?K1T`P0m<2F2@3c_iP:0?6mV@030000003__9X0
kkbJ00@0kkbJ0P00000;0?ooo``00000S03oool6000000<0000Y1P00050300X0K@0300000031Oh/0
`Gn;01P0`Gn;0`3=R8T?0<f3O`030000002DK:80U6bR00D0U6bR00<000000>6OS03QWh`0403QWh`A
0>JSQ`l0jj=n1@3`YgP30?2TM00400WZ2P3`Y7@0l:Ad0?2TM080l:9`0P3dYf`30?BVJ@<0m:AU0P3d
Xf820?BRGP060?FQF`3eX5L0mImC0?FOD`3eWdl0mIi<0P3eWTT00`3eWTH0mIi30?FN@`020?FN@@03
0?FO@03/T240k90Q00<0k94O0P3GO000102dH0002NX:00WZ2P09jPXT0?ooo`@02NX:7`3oool300WZ
2Qd0oooo0`09jPXG0?ooo`<02NX:6P3oool00480oooo00D0000002L0000W0000CP0K000000080?W2
S0P0n<:@2@3f`I<80?C0UPT0lknH2P3a_IT90>nlVP030000003oool0oooo00D0oooo0`0000030:HQ
00P0T`4000@0L`000000000000000000R03oool6000000@0000Y1P00050300X0K@0300000031Oh/0
`Gn;01P0`Gn;1`3=R8T;0<f3O`030000002DK:80U6bR00H0U6bR00<000000>6OS03QWh`03`3QWh`A
0>JSQ`80jjJ23@3[Xgh60?2WN0L0l:Ad00@0l:9`0?BWK03dYf`0m:M/0`3dYVT20?BTI@<0m:=R0P3d
XUh20?FPE`80mImC00@0mIm?0?FNC03eWTT0mIi60P3eWT<20?FN@@80mIm000<0k90Q0>bA7`3/TAl0
1009jPXT0?ooo`<02NX:803oool300WZ2Qd0oooo0`09jPXG0?ooo`<02NX:7@3oool00440oooo00D0
000004h06`1>01/0CP0K000000090?W2S0T0n<:@203f`I<80?C0UPT0lknH2P3a_IT:0>nlVP800000
0P3oool3000000P0YR40202C0@0207<000800000Q03oool00`2:h9d0000000000003000000030?R_
L@000000000Y0080000Y1P00050400X0K@0300000031Oh/0`Gn;01P0`Gn;2P3=R8T80<f3O`030000
002DK:80U6bR00H0U6bR00<000000>6OS03QWh`0403QWh`@0>JSQ`D0jjJ22`3[Xgh70?2WN0H0l:Ad
103dYf`30?BVJ@80m:AU0P3dXf820?BRGP070?FQF`3eX5L0mImC0?FOD`3eWdl0mIi<0?FNB@020?FN
AP040?FN@`3eWT40mIi10?FO@0@02NX:00@0k94O0>^C7`3GO000eg`08@3oool300WZ2Ql0oooo1009
jPXM0?ooo`<02NX:603oool200WZ2R00oooo00110?ooo`040000001>01/0CP0K00000080n/:8203i
`X`90?S2T0P0m/6C203d`9H90?>oV0T0lKfI2`3__9X0103^^Y/000000000000000030;0i90X0YR40
202C0@0307<00880oooo00<0R^2M0000000000000P0000000`0K02l00000000000030000:@H0001@
1@0:06d00`000000`Gn;0<5oR`0H0<5oR`h0cHR9103=Pgl00`000000U6bR09A/XP0609A/XP030000
003QWh`0hIn<0100hIn<403VXhL80>^VPPP0jj=n203`YgP50?2TM080m:Q_0`3dYf`30?BVJ@80m:AU
0P3dXf820?BRGP060?FPE`3eWe<0mImC0?FOC`3eWT`0mIi90P3eWTH0103eWT<02NX:00WZ2P09jPX2
0?FO@0<0k94O00@0ji<O0=Ml003GO000]6007@3oool300WZ2Ql0oooo0`09jPXN0?ooo`<02NX:603o
ool300WZ2R80oooo00100?ooo`050000001>01/0CP0K04h06`0000000P3j`XP90?W2S0P0n<:@203f
`I<80?C0UPT0lknH2@3a_IT:0>nlVP8000002@2`>B@:0:HQ00L0T`400`1c001o0?ooo`D0000000@0
6`0_0000003h[g4000000`0002T60000D0D02P1]00<000000<5oR`31Oh/06031Oh/B0<f8R@030<f3
O`000000U6bR00H0U6bR00<000000>6OS03QWh`0403QWh`A0>JSQ`T0jjJ21P3[Xgh:0?2WN0<0l:Ad
0`3dZ6l30?BWK080m:IY0P3dY6D30?BSHP030?BRGP3eXE/0mJ1G0080mImC00<0mIm?00WZ2P09jPX0
0P09jPX20?FN@@<0mIm00`3/TAl20>^C7`030=Ml003GO`00oooo01P0oooo1009jPXO0?ooo`<02NX:
7P3oool300WZ2QP0oooo0`09jPXU0?ooo`00?`3oool01@000000CP0K04h06`1>01/0000000<0n/:8
2@3i`X`80?S2T0P0m/6C203d`9H90?>oV0T0lKfI2@3__9X00`000000/3TT0;0i900;0;0i90X0YR40
1`2C0@0307<007`0oooo00<0R^2M0000000000000P00000201/0;`030000003h[g4000000080000Y
1P00050600X0K@0300000031Oh/0`Gn;01T0`Gn;4P3=R8T00`000000U6bR09A/XP0509A/XP030000
003QWh`0hIn<0100hIn<4@3VXhL<0>^VPP<0jj=n2`3`YgP30?2TM0<0m:Q_0`3dYf`20?BVJ@80m:AU
0P3dXf820?BRGP080?RYG`09jPX02NX:00WZ2P3eWT`0mIi90?FNAP3eWT<20?FN@@<0mIm000<0mJ0o
0>bA7`3[Tal00P3[Tal00`3GO000egl00000000E0?ooo`<02NX:803oool300WZ2Qh0oooo0`09jPXH
0?ooo`<02NX:5`3oool2000000l0oooo000o0?ooo`040000001>01/0CP0K000000D0n/:8203i`X`8
0?S2T0P0m/6C203d`9H90?>oV0T0lKfI2@3__9X00`000000]Ta30;0i900=0;0i90X0YR401`2C0@03
07<000800000M`3oool5000000<06`0_00<000000?R_L@0000000P0002T60000D0H02P1]00<00000
0<5oR`31Oh/06@31Oh/B0<f8R@030000002DK:80U6bR00H0U6bR00<000000>6OS03QWh`03`3QWh`A
0>JSQ`l0jjJ23@3`YgP00`3`Y7@0m:Q_0?BXK`020?BXK`80m:M/0`3dYVT00`3dY6D0m:=R00WZ2P03
00WZ2P070?RYG`3hZEh0n:UM0?RYG03eWTT0mIi60?FN@`020?FN@@<0mIm000<0mJ0o0>bA7`3[Tal0
0P3[Tal00`3GO000egl00;AP000B0?ooo`<02NX:803oool300WZ2Qh0oooo0`09jPXI0?ooo`802NX:
6P3oool2000000l0oooo000n0?ooo`050000001>01/0CP0K04h06`0000001@3j`XP80?W2S0T0n<:@
1`3f`I<90?C0UPP0lknH2@3a_IT80>nlVP030000002fC4<0]Ta300<0]Ta33P2`>B@90:HQ00P0T`40
0P1c00000`000000oooo0?ooo`1c0?ooo`D000000`0K02l01@000000n:ma0?R_L@000000000Y00H0
001@1`0:06d00`000000`Gn;0<5oR`0I0<5oRa80cHR900<0000009A/XP2DK:801P2DK:800`000000
hIn<0>6OS00@0>6OS100iZ>73`3[YX820?2YO0`0l:Mh1@3dZ6l20?BWK0040?BVJ@09jPX02NX:00WZ
2P80m:=R0P3hZV401@3hZEl0n:UN0?RYGP3hZE`0n:UK0080mIi600<0mIi30?FN@@3eWd000P3eWd00
0`3eX3l0k94O0>^C7`030>^C7`80egl03P3oool400WZ2R00oooo0`09jPXN0?ooo`<02NX:6@3oool3
00WZ2QT0oooo0`09jPXA0?ooo`00?@3oool01@000000CP0K04h06`1>01/0000000H0n/:82@3i`X`8
0?S2T0L0m/6C2@3d`9H80?>oV0T0lKfI1`3__9X00`000000]Ta30;I<@`060;I<@`h0/3TT2@2V8@08
09<10080L`00L`3oool4000000D06`0_00<000000?R_L@0000000P0002T50000D0P02P1]00<00000
0<:6U032QY@01@32QY@D0<5oRa80cHR900<0000009A/XP2DK:801@2DK:800`2GMZ`000000>:ST@04
0>:ST@d0hIn<403VXhL?0>^VPP@0l:Ul2P3`YgP20?BZL@@0m:Q_0P0000020?BVJ@80m:AU00@0m:=R
0?RZH`3hZV40n:UO0P3hZEh01P3hZEd0n:UK0?RYFP3hZEX0mIi30?FN@@<0mIm00P3eX3l40>^C7`80
egl000<000000?ooo`3oool0203oool300WZ2R00oooo1009jPXN0?ooo`<02NX:6@3oool300WZ2QT0
oooo0`09jPXD0?ooo`00?@3oool010000000CP0K04h06`0000080?[2R0P0nL:<203h`Y080?K1T`P0
m<2F203c_iP90?6mV@H0kkbJ00<000000;I<@`2fC4<02P2fC4<=0;0i90X0YR401`2C0@0307<006l0
oooo1000000501/0;`0503X0EP000000n:ma0000000002T01P00050800X0K@0300000032QY@0`XJD
01<0`XJD1P31Oh/C0<f8R@040000002DK:80U6bR09A/XP@0UgJ/00<000000>:ST@3RXi40303RXi44
0>6OS100iZ>7403[YX850?2YO0P0l:Mh0`3dZW430?BXK`80000000@0m:M/0?BVJ@3dYVT0m:AU0P3h
ZV<01P3hZV40n:UP0?RYG`3hZEh0n:UM0?RYG080n:UJ00<0mIi30?FN@@3eWd000P3eWd020?FP?`@0
ji<O0`3GO`070?ooo`<02NX:803oool300WZ2Ql0oooo0`09jPXI0?ooo`<02NX:6P3oool200WZ2QL0
oooo000l0?ooo`050000001>01/0CP0K06LAAP000000203j`XP80?W2S0P0n<:@203f`I<80?C0UPP0
lknH2@3a_IT50>nlVP030000002fC4<0]Ta300d0]Ta33P2`>B@90:HQ00L0T`400`1c001/0?ooo`@0
00001@0K02l203X0EP030000003h[g40000000H0001@200:06d00`0N48<000000<:6U00J0<:6U0@0
cHjA3`3=R8T00`000000UgJ/09Mf[00609Mf[0030000003RXi40hZ>A00l0hZ>A103VYX`=0>JSQ`l0
jjJ21`3`ZG`60?2WN00400WZ2P3dZW40m:Ya0?BZL@@0m:Q_0P3dYf`20?BVJ@080?R[I03hZV<0n:YS
0?RZH@3hZEl0n:UN0?RYG@3hZE`20?RYFP030?VYF@3eWT40mIm00080mIm00P3eX3l01@3fXSl0ji<O
0>^C7`3[Tal0k9DP0080egl000@000000?ooo`3oool0oooo0`09jPXP0?ooo`<02NX:7`3oool300WZ
2QX0oooo0P09jPXJ0?ooo`<02NX:6@3oool003/0oooo00H0000006LAAP1W4DH0Ia560000003k`H<8
0?[2R0P0nL:<203h`Y080?K1T`P0m<2F203c_iP90?6mV@@0kkbJ00<000000;I<@`2fC4<04@2fC4<=
0;0i90T0YR401`2C0@0307<006P0oooo1@00000501/0;`<0>P1F00<000000?R_L@0000001@000508
00X0K@<07Q2300<000000<:6U032QY@06032QY@90<f>T@X0cHR900<0000009Mf[02GMZ`01P2GMZ`0
0`000000hZ>A0>:ST@0?0>:ST@X0iZJ<1`3VXhL?0>^VPPT0l:Ul103`YgP50?BZL@@0m:Q_0P3dYf`0
1P3dYVT0n:]T0?RZH`3hZV<0n:YQ0?RYH080n:UN00D0n:UL0?RYF`3hZEX0nJUI0?FN@@020?FO@0<0
mJ0o00<0mZ8o0>^C7`3[Tal00P3/UB020=Mo00@02NX:803oool300WZ2Ql0oooo0`09jPXJ0?ooo`<0
2NX:6@3oool300WZ2Q`0oooo000k0?ooo`060000001W4DH0Ia5606LAAP000000nl632@3j`XP80?W2
S0P0n<:@1`3f`I<80?C0UPP0lknH2@3a_IT40>nlVP030000002hFUX0]Ta301<0]Ta33@2`>B@90:HQ
00L0T`400`1c001U0?ooo`0403fn/00000000000000000H06`0_0`0j05H010000000n:ma0?R_L@00
00050000D0L02P1]100N48<00`000000`XJD0<:6U00H0<:6U0l0cHjA103=R8T00`000000UgJ/09Mf
[00609Mf[0030000003RXi40hZ>A0100hZ>A3P3VYX`20>JSQ`l0jjJ22`3`ZG`20?2WN0H0m:Ya103d
Z6l20?BWK00:0?R[I@3hZf@0n:YS0?RZH`3hZV40n:UO0?RYGP3hZE`0n:UK0?RYFP80nJUI0P3eWd02
0?FP?`80mZ8o0P3[Tal01@3/UB002NX:00WZ2P09jPX0egl00200oooo0`09jPXO0?ooo`<02NX:6P3o
ool300WZ2QX0oooo0P09jPXO0?ooo`00>P3oool00`000000Ia5606LAAP0206LAAP030000003k`H<0
n/:800P0n/:8203i`X`80?S2T0D0m/6C0P3f_Y080?BmTP<0lkbD1@3c_iP90?6mV@<0kkbJ00<00000
0;QJFP2hFUX00`2hFUXD0;I<@`d0/3TT202V8@0709<100<0L`00H03oool203fn/00400<000000000
0000000000D06`0_1@0j05H010000000n:ma0?R_L@0000040000D0P02P1]100N48<00`000000`XJD
0<:6U00H0<:6U1@0cHjA00<0000009Mf[02GMZ`01@2GMZ`00`000000hZ>A0>:ST@0@0>:STA00iZJ<
103/ZHH;0>^VPPd0l:Ul203dZW430?BXK`0;0?BWK03hZfD0n:]U0?R[I03hZV<0n:YQ0?RYG`3hZEh0
n:UM0?RYF`3hZEX00P3iZET20?FO@080mJ0o0P3fXSl300WZ2P80k9DP0P3GO`000`000000oooo0?oo
o`0J0?ooo`<02NX:7`3oool300WZ2QX0oooo0`09jPXJ0?ooo`<02NX:8@3oool003X0oooo00D00000
06LAAP1W4DH0Ia56000000030?_1P`P0n/:8203i`X`80?S2T080m/6C1@3f_Y080?BmTPL0lkbD00<0
lknH0?6mV@3a_IT01P3a_IT30>nlVP030000002hFUX0^5YJ00L0^5YJ4`2fC4<=0;0i90T0YR401P2C
0@0307<005/0oooo0P0m_[0200<000@000001@0K02l603X0EP040000003h[g40n:ma000000@0001@
1`0:06d501h@P`0300000032QY@0`XJD01P0`XJD503=SY400`000000UgJ/09Mf[00509Mf[0030000
003RXi40hZ>A0100hZ>A403VYX`90>bYQPL0jjJ2303`ZG`20?B[M0L0m:Ya0`3dZ6l00`3h[6H0n:]U
0?R[I0020?RZH`050?RYH03hZEh0n:UM0?RYG03hZEX00P3iZET00`3iZUP0mIm000WZ2P0300WZ2P03
0?JR?`3/UB00k9DP0080k9DP0`3GO`0H0?ooo`@02NX:803oool200WZ2Q/0oooo0P09jPXJ0?ooo`<0
2NX:903oool003X0oooo00D0000006LAAP1W4DH0Ia56000000030?_1P`P0n/:8203i`X`70?S2T003
0?NnS@3f_Y00m[j@00D0m[j@203d_I880?>lU080lK^E1P3a_IT30>nlVP030000002hFUX0^5YJ00X0
^5YJ4`2fC4<=0;0i90P0YR401P2C0@0307<005H0oooo00<0000003fn/00300000P0300000`0h0000
000000000002000000D06`0_1`0j05H010000000n:ma0?R_L@0000030000D0L02P1]1P0N48<00`00
0000`XJD0<:6U00I0<:6U1<0cHjA00<0000009Mf[02GMZ`01P2GMZ`00`000000hZ>A0>:ST@0?0>:S
TA40iZJ<3@3/ZHH20>^VPP`0l:Ul103dZg@60?BZL@80m:Q_0P3h[6H02@3hZfD0n:]T0?RZH`3hZV40
n:UO0?RYGP3hZE`0n:UJ0?VYF@0300WZ2P80mJ0o0`3fXSl40>bE80<0egl05@3oool300WZ2R40oooo
0`09jPXJ0?ooo`<02NX:6P3oool200WZ2RL0oooo000i0?ooo`050000001W4DH0Ia5606LAAP000000
103k`H<90?[2R0P0nL:<0`3h`Y040?NnS@P0m[j@1`3d_I880?>lU0@0lK^E103a_IT20>nlVP030000
002hFUX0^5YJ00h0^5YJ4P2fC4<=0;0i90P0YR401P2C0@0307<004@0oooo200000040?ooo`800000
00@0?Kj`00<0000300000`000`0h0004000000D06`0_1`0j05H01@1?774000000?R_L@3h[g400000
0080001@200:06d601h@P`0300000032QY@0`XJD01T0`XJD4`3=SY400`000000UgJ/09Mf[00609Mf
[0030000003RXi40hZ>A0100hZ>A403VYX`?0>bYQP<0l:]o2@3`ZG`60?B[M0D0m:Ya00D0m:Q_0?R/
I`3h[6H0n:aV0?R[I@020?RZH`030?RYH03hZEh02NX:00802NX:00<0nJUI0?VZF03iZUP00P3eX3l3
0?JR?`030?JS@03/UB00k9DP0080k9DP00<0egl00=N4003GQ0004@3oool300WZ2R40oooo0`09jPXJ
0?ooo`<02NX:6P3oool300WZ2RT0oooo000i0?ooo`050000001W4DH0Ia5606LAAP0000001@3k`H<8
0?[2R0P0nL:<00<0n<:@0?NnS@3g_Xd01@3g_Xd70?JnT0L0m;fB203c_9@60?6kU@80lKfI0P3__9X0
0`000000^5YJ0;QJFP0A0;QJFQ80]Ta3302`>B@80:HQ00H0T`400`1c000o0?ooo`<00000203f/7H4
000000<00`001@0h0003000000H06`0_1`0j05H204lLL@040000003h[g40n:ma00000080001@1`0:
06d701h@P`0300000032QY@0`XJD01T0`XJD4`3=SY400`000000UgJ/09Mf[00609Mf[0030000003R
Xi40hZ>A0100hZ>A403VYX`?0>bYQPH0l:]o1`3`ZG`70?B[M0@0m:Ya0P3h[6L00`3h[6H000000000
000300WZ2P040?RYG@3hZEX0nJUI0?VYF@<0nJYH0`3fXSl30?JS@0<0k9DP0`3GQ00>0?ooo`<02NX:
8@3oool300WZ2QX0oooo0`09jPXK0?ooo`802NX:;03oool003P0oooo00D0000006LAAP1W4DH0Ia56
000000060?_1P`P0n/:8203i`X`80?NnS@L0m[j@1`3d_I880?>lU0P0lK^E00<0kkbJ0000002hFUX0
5P2hFUXB0;I<@``0/3TT1`2V8@0609<100<0L`00>`3oool2000000d0m[1f00<0000000<0000h0000
1P0h00000`1I02T000000000000501/0;`P0>P1F0`1?77401@000000n:ma0?R_L@000000001@00L0
2P1]2@0N48<00`000000`XJD0<:6U00H0<:6U1@0cHjA00<0000009Mf[02GMZ`01@2GMZ`00`000000
hZ>A0>:ST@0@0>:STA00iZJ<403/ZHH80?2[O`@0l:Ul203dZg@30?BZL@80n:eX00X0n:aW00000000
0000n:]T0?RZH@3hZEl0n:UN0?RYF`3hZEX0nJUI0`3iZUP30?JR?`<0mZ=00`3/UB000`3/V280eh@0
0=N4000;0?ooo`<02NX:8@3oool300WZ2Q/0oooo0P09jPXK0?ooo`<02NX:;P3oool003P0oooo00D0
000006LAAP1W4DH0Ia56000000060?_1P`T0n/:81P3i`X`00`3h_XX0mkj=0?NnS@060?NnS@L0m[j@
203d_I870?>lU0P0lK^E00<000000;QJFP2hFUX06@2hFUXA0;I<@``0/3TT202V8@0509<100<0L`00
>03oool00`000000m[1f0?J`MP0=0?J`MP030000000h0000>00000<0>0000`1I02T2000000D06`0_
1`0j05H504lLL@050000003h[g40n:ma0000000005001P0:06d:01h@P`0300000032QY@0`XJD01P0
`XJD503=SY400`000000UgJ/09Mf[00509Mf[0030000003RXi40hZ>A0100hZ>A4@3VYX`?0>bYQP/0
l:]o00<0l:Ul0?B[M03dZg@0203dZg@20?BZL@80n:eX00T0n:aW0?R/IP3hZfD0n:YS0?RZH@3hZEh0
n:UK0?RYFP3iZET00`3iZUP00`3iZeP0mZ8o0?JS@0040?JS@0030>bE803/V280k9PR00<0eh@01`3o
ool300WZ2R40oooo0`09jPXK0?ooo`<02NX:6P3oool300WZ2S40oooo000g0?ooo`030000001W4DH0
Ia560080Ia5600<000000?_1P`3k`H<01@3k`H<80?[2R0D0nL:<0`3h_XX70?NnS@L0m[j@203d_I87
0?>lU0P0lK^E00<000000;YVJ`2jIV/0702hFUXA0;I<@`/0/3TT202V8@0609<10080L`00=P3oool0
0`000000m[1f0?J`MP0<0?J`MP040000000h0000>00003P000H0F@0Y00<0000001/0;`0K02l00`0K
02l703X0EPH0Caaa00@000000?R_L@3h[g4000001`0:06d:01h@P`0300000032QY@0`XJD01P0`XJD
503=SY400`000000UgJ/09Mf[00609Mf[0030000003RXi40hZ>A0100hZ>A403VYX`?0>bYQP`0l:]o
0`3e[GH90?B[M0<0n:eX00P0n:aW0?R/IP3hZf@0n:YQ0?RYGP3hZE`0n:UJ0?VYF@80nJYH0P3iZeP0
0`3fXSl0mZ=00?JS@0020?JS@0040?JU@@3/V280k9PR0>bH8P<0eh@0103oool300WZ2R40oooo0`09
jPXK0?ooo`<02NX:6`3oool200WZ2S@0oooo000g0?ooo`050000001W4DH0Ia5606LAAP000000203k
`H<80?[2R0@0nL:<103h_XX70?NnS@L0m[j@203d_I870?>lU0L0lK^E00<000000;YVJ`2jIV/0102j
IV/L0;QJFQ00]Ta3302`>B@70:HQ00H0T`400P1c000c0?ooo`030000003f/7H0m[1f00`0m[1f00<0
000003P0001I02T01`1I02T00`0000006`0_01/0;`0301/0;`L0>P1F1`1?774010000000n:ma0?R_
L@00000600X0K@/07Q2300<000000<><V`33S9/06033S9/70<jCV0d0cHjA00<0000009Mf[02GMZ`0
1P2GMZ`00`000000hZ>A0>:ST@0@0>:STA00iZJ<3`3/ZHH=0?2[O`D0mJef1P3dZg@20?R]J@80n:eX
00H0n:aW0?R[I@3hZV<0n:UO0?RYG@3hZEX30?VZF080nJ]H103fXd030?JU@@<0k9PR0P3GQ00400WZ
2R40oooo0`09jPXK0?ooo`<02NX:6`3oool300WZ2SH0oooo000g0?ooo`050000001W4DH0Ia5607L]
I00000002@3k`H<80?[2R080nL:<1@3h_XX80?NnS@L0m[j@1`3d_I870?>lU0L0lK^E00<000000;YV
J`2jIV/0202jIV/K0;QJFQ00]Ta32`2`>B@70:HQ00H0T`400`1c000`0?ooo`030000003f/7H0m[1f
00`0m[1f00<0000005T0:@1I02T01P1I02T00`1^6dl0000001/0;`0201/0;`P0>P1F201?77401000
0000n:ma0?R_L@00000500X0K@`07Q2300<000000<><V`33S9/06033S9/B0<jCV080cHjA00<00000
09Mf[02GMZ`01P2GMZ`00`000000hZ>A0>:ST@0@0>:STA00iZJ<3`3/ZHH=0?2[O`P0mJef0`3dZg@3
0?R]J@80n:eX00D0n:aV0?R[I03hZV40n:UN0?RYFP030?VZF080nJ]H00<0nJ]I0?JS@03fXd00103f
YD420>bH8P<02NX:00<0eh@00?ooo`3oool07`3oool300WZ2Q/0oooo0`09jPXK0?ooo`<02NX:>@3o
ool003H0oooo00<0000007L]I01g;F@00P1g;F@00`000000nl630?_1P`070?_1P`P0n/:800<0nL:<
0?RnRP3h_XX01@3h_XX70?NnS@L0m[j@1`3d_I870?>lU0L0lK^E00<000000;YVJ`2jIV/02`2jIV/J
0;QJFQ00]Ta32`2`>B@70:HQ00H0T`400`1c000]0?ooo`030000003f/7H0m[1f00`0m[1f00<00000
05T0:@1I02T0101I02T406hKC`030000000K02l06`0_00L0>P1F2P1?774010000000n:ma0?R_L@00
000400X0K@`07Q2300<0;2FD00000033S9/06@33S9/E0<jCV0030000002GMZ`0UgJ/00D0UgJ/00<0
00000>:ST@3RXi40403RXi4A0>JVS0l0k:V6303`Zgl;0?F]MPD0n:eY00D0n:eX0?R/IP3hZV<0n:UN
0?RYFP020?VZF080nJ]H0P3iZeT00`3fXd00mZE10?JU@@020?JU@@<02NX:00@0k9PR0=N4003GQ000
eh@07P3oool300WZ2Q`0oooo0P09jPXL0?ooo`802NX:?03oool003H0oooo00H0000007L]I01g;F@0
MbeT0000003l_gh90?_1P`P0n/:8203h_XX70?NnS@L0m[j@1`3d_I870?>lU0H0lK^E00<000000;YV
J`2jIV/0402jIV/I0;QJFQ00]Ta32`2`>B@70:HQ00D0T`400`1c000[0?ooo`030000003f/7H0m[1f
00`0m[1f00@0000005T0:@1I02T0F@0Y1P1^6dl00`0000006`0_01/0;`0703X0EPX0Caaa00D0GC>5
0000003h[g40n:ma0000000400X0K@/07Q230P0/9I@00`000000`hbK0<><V`0I0<><Va@0cY>H00<0
000009Mf[02GMZ`01@2GMZ`00`000000hZ>A0>:ST@0A0>:STA00iZJ<3`3/ZHH=0?2[O`X0mJef0P3h
[VX40?R]J@040?R]J03hZfD0n:YQ0?RYFP80nJYH00@0nJ]H0?V[F@3iZeT0nJaI0P3fYD4300WZ2P80
mZE10`3/V2820=N401/0oooo0`09jPXL0?ooo`<02NX:6`3oool300WZ2Sh0oooo000f0?ooo`050000
001g;F@0MbeT07L]I00000000P3l_gh90?_1P`L0n/:800<0nKj60?RnRP3h_XX01@3h_XX70?NnS@L0
m[j@1`3d_I870?>lU0H0lK^E00<000000;YVJ`2jIV/04`2jIV/I0;QJFPl0]Ta32`2`>B@70:HQ00D0
T`400`1c000X0?ooo`030000003f/7H0m[1f00`0m[1f00<0000005T0:@1^6dl0201^6dl00`000000
6`0_03X0EP0603X0EPX0Caaa0P1M<hD010000000n:ma0?R_L@00000300X0K@/07Q23100/9I@00`00
0000`hbK0<><V`0H0<><Va@0cY>H00<0000009Mf[02GMZ`01P2GMZ`00`000000hZ>A0>:ST@0@0>:S
T@P0iZJ<203WZI0?0>b/R@P0lJf21@3`Zgl;0?F]MP@0n:iZ0P3h[FT01@3h[FP0n:]T0?RYG03iZUP0
nJ]H0080nJ]I00@0nJaI00WZ2P09jPX02NX:1@3fYD430>bH8P<0eh@05`3oool300WZ2Q`0oooo0`09
jPXK0?ooo`<02NX:@@3oool003D0oooo00<0000007L]I01g;F@00P1g;F@00`000000o;mn0?boOP09
0?_1P`H0n/:80P3i_XH70?RnRPL0mkj=1`3f_Y070?BmTPL0lkbD1P3a^iD00`000000^VI[0;YVJ`0G
0;YVJaP0^5YJ3`2fC4<:0;0i90D0YR402000000207<00280oooo1000000?0?J`MP030000001^6dl0
KQ]?00P0KQ]?00<0000003X0EP0j05H0100j05H:04lLL@@0GC>500@000000?R_L@3h[g4000000P0:
06d;01h@P`D0;2FD00<000000<><V`33S9/06033S9/D0<jCV0030000002GMZ`0UgJ/00H0UgJ/00<0
00000>:ST@3RXi401`3RXi490>:WUA00ijV@3`3/[8T=0?6]PPL0mJih103e[GH60?R^JP80n:eY00<0
n:UN0?VZF03iZeP00`09jPX20?V/F@<0mZE10`3gYd<30>fL9P<0fHT2503oool300WZ2Q`0oooo0`09
jPXL0?ooo`802NX:A03oool003D0oooo00D0000007L]I01g;F@0MbeT000000030?boOPT0nl631@3j
`XP30?VnQPP0n;j:1`3g_Xd60?JnT0L0m;fB203c_9@40?6kU@030000002jIV/0^VI[01/0^VI[602h
FUX>0;I<@`/0/3TT0P00000H03h00080<kCX0P05000=0?ooo`<000000P3f/7L00`000000m[1f0?J`
MP0=0?J`MP030000001^6dl0KQ]?00L0KQ]?0P1l=6X00`000000>P1F03X0EP0303X0EPX0Caaa1@1M
<hD010000000n:ma0?R_L@00000200X0K@X07Q231P0/9I@00`000000`hbK0<><V`0H0<><Va@0cY>H
00<0000009Mf[02GMZ`01@2GMZ`00`2JOk@000000>:WU@0A0>:WUA40ijV@3`3/[8T=0?6]PPX0mJih
1P3h[V/30?R^JP802NX:0P3i[5T30?Z/FPH0mjM3103]W2H20=V90Q40oooo0`09jPXM0?ooo`802NX:
703oool300WZ2TH0oooo000e0?ooo`050000001g;F@0MbeT07L]I0000000103l_gh90?_1P`@0n/:8
103i_XH70?RnRPL0mkj=1P3f_Y070?BmTPP0lkbD103a^iD00`000000^VI[0;YVJ`0O0;YVJaL0^5YJ
3P2fC4<70;0i90030000001W0000I`0001@0I`004`0n0002000000D0m[1g00<000000?J`MP3f/7H0
3@3f/7H00`000000KQ]?06hKC`0406hKC`D0O3AZ00<0000003X0EP0j05H00P0j05H:04lLL@H0GC>5
00D000000?R_L@3h[g40000000X0K@0:01h@P`L0;2FD00<000000<><V`33S9/06033S9/E0<jCV004
0000002GMZ`0UgJ/09Mf[0@0VWnd00<000000>:WU@3RYiD04@3RYiD@0>NYT0l0k:b93@3a[H8;0?F^
N0H0n:i[00D0nJm[0?V_K000000000000?Z]FP050?Z/FPD0mjM3103]W2H30=V90Pd0oooo0`09jPXM
0?ooo`<02NX:6`3oool300WZ2TT0oooo000d0?ooo`030000001g;F@0MbeT0080MbeT00<000000?bo
OP3l_gh00P3l_gh90?_1P`<0n/:81@3i_XH70?RnRPL0mkj=1`3f_Y060?BmTPP0lkbD0`3a^iD20000
0080^fmi8`2jIV/F0;QJFPd0]Ta3102`>B@00`000000I`0006L0000W06L0008000001P3f/7L00`00
0000m[1f0?J`MP0=0?J`MP040000001^6dl0KQ]?06hKC`P0O3AZ00@0000003X0EP0j05H0>P1F2@1?
774805dcQ@040000003h[g40n:ma000000X07Q23200/9I@00`000000`hbK0<><V`0H0<><VaD0cY>H
00<0000009Yo]02JOk@01P2JOk@00`000000hZNE0>:WU@0@0>:WUA00ijV@3`3/[8T=0?6]PP/0mJih
0P3h[V/40?V_J`80nJm/00@0nk9V0?Z^G03j[U`0nZiK0`3j[EX00`3j[5X0mjM30?NW@`040?NW@`<0
kI`V0`3IR@8:0?ooo`<02NX:7@3oool300WZ2Q`0oooo0P09jPY<0?ooo`00=03oool00`000000MbeT
07L]I00207L]I0030000003l_gh0o;mn00<0o;mn203k`H<30?[2R0D0nKj6203h_XX60?NnS@L0m[j@
1P3d_I880?>lU0<0lK^E0P0000060;]_NB80^VI[5P2hFUX<0;I<@`800000:@1W00000`000000>000
000000060?J`M`030000003f/7H0m[1f00X0m[1f0`0000000`1^6dl0O3AZ07`dJP0807`dJP030000
000j05H0>P1F00X0Caaa2@1M<hD010000000n:ma0?R_L@00000901h@P`T0;2FD00<000000<><V`33
S9/06@33S9/D0<jCV0030000002JOk@0VWnd00H0VWnd00<000000>:WU@3RYiD0403RYiDA0>NYT0l0
k:b93@3a[H880?F^N080m[1i00@02NX:0?V_J`3i[f/0nJm[0`3i[f`00`3i/6`0n[9Y0?Z`H0020?Z^
G080nZiK0P3j[EX30?RYAP<0mjM3103]W2H20=V90PL0oooo0`09jPXM0?ooo`<02NX:703oool300WZ
2Th0oooo000d0?ooo`050000001g;F@0MbeT07L]I00000001P3l_gh90?_1P`030?[2R03i_XH0nKj6
00D0nKj61`3h_XX60?NnS@L0m[j@1P3d_I880?>lU080lK^E0P00000;0;]_NB80^VI[5@2hFUX80;I<
@`03000000203Ad0P0dM02P0P0dM00<0000003P0000000001P3f/7L00`000000m[1f0?J`MP0:0?J`
MP040000002Vd?H00000000000/0O3AZ00<0000003X0EP1?7740201?774;05dcQ@040000003h[g40
n:ma000000P07Q232P0/9I@00`000000`hbK0<><V`0I0<><Va@0cY>H00<0000009Yo]02JOk@01P2J
Ok@00`000000hZNE0>:WU@0@0>:WUA40ijV@3`3/[8T=0?6]PP<0mJih203f/7T20?V_J`<0nJm/00D0
nK1/0?VaK03j/VT0nk5T0?Z`G`020?Z^G080nZiK0P3j[EX50?RYAP@0kI`V0P3IR@840?ooo`<02NX:
7P3oool200WZ2Q`0oooo0`09jPYA0?ooo`00=03oool01@000000MbeT07L]I01g;F@0000000L0o;mn
203k`H<80?VnQPL0n;j:1`3g_Xd60?JnT0L0m;fB1`3c_9@20?6kU@8000003`2kKgTQ0;YVJaD0^5YJ
102fC4<00`000000P0dM080=7@0X080=7@030000000h0000000000L0m[1g00<000000?J`MP3f/7H0
2@3f/7H01@000000m[1g0?J`M`2Vd?H0000000/0O3AZ00<0000004lLL@1?77401`1?774<05dcQ@04
0000003h[g40n:ma000000P07Q232`0/9I@00`000000`hbK0<><V`0H0<><VaD0cY>H00<0000009Yo
]02JOk@01P2JOk@00`000000hZNE0>:WU@0@0>:WUA00ijV@3`3/[8T;0?6]PP80lK242`3f/7T0103i
[f/0nJm/0?V_K03i[f`20?V`K0050?VaK03j/VX0nk9V0?^aHP3j[eh00P3j[U`30?Z^F`D0n:U60P3_
XB/20>fL9P<0fHT20`09jPXN0?ooo`<02NX:703oool200WZ2U@0oooo000c0?ooo`030000001g;F@0
MbeT0080MbeT00<000000?boOP3l_gh01@3l_gh80?_1P`030?ZnP`3i_XH0nKj600D0nKj6203h_XX6
0?NnS@H0m[j@1`3d_I870?>lU080lK^E00<000030000002kKgT04P2kKgTQ0;YVJa@0^5YJ00<00000
080=7@203Ad0:0203Ad010000000>00005T0:@0000070?J`M`030000003f/7H0m[1f00T0m[1f00D0
00000?J`M`3f/7L0m[1g0000000:07`dJP0308E7O@000000Caaa00H0Caaa3@1M<hD01@1XAI@00000
0?R_L@3h[g40000000L07Q23300/9I@00`000000`hbK0<><V`0D0<><V`@0a9:R5@3?VIh00`000000
VWnd09Yo]00609Yo]0030000003RYiD0hZNE0100hZNE4@3WZI0?0>b/R@H0lJf21`3a/8@90?J`N@03
0?JaNP3i[f`0nJm/0080nJm/0P3i/6`01P3i/F`0n[9[0?ZbJ03k/F<0n[1O0?Z_GP80nZiL0P3j[U/2
0?R/B@@0n:U60`3_XB/300WZ2Qh0oooo0`09jPXL0?ooo`<02NX:EP3oool003<0oooo00D0000007L]
I01g;F@0MbeT000000090?boOPH0nl630P3j_X<80?VnQPL0n;j:1P3g_Xd60?JnT0L0m;fB1`3c_9@0
0`3a^iD000000000000H0;]_NB00^VI[4@2hFUX00`000000SRa308h/@`0X08h/@`030000001I02T0
000000P0m[1g00<000000?J`MP3f/7H0203f/7H01@000000m[1g0?J`M`3f/7L0000000P0O3AZ1025
Agd00`000000Caaa04lLL@0404lLL@d0GC>50P1XAI@010000000n:ma0?R_L@00000601h@P`d0;2FD
00<000000<><V`33S9/02`33S9/=0<BBXQD0ciVN00<0000009Yo]02JOk@01P2JOk@00`000000hZNE
0>:WU@0@0>:WUA40ijV@3`3/[8T20?6]PP/0lK241`3f/7T40?JaNP80nJm/0P3i/6`20?VaK0060?Zb
J`3j/VT0nk5T0?^aHP3j/5l0nZmN0P3j[U`0103j[U/0n:a90?R/B@3h[4T30?RYAP<02NX:00<0kj4[
0=V90P3IR@806`3oool300WZ2Qd0oooo0P09jPYI0?ooo`00<`3oool01@000000MbeT07L]I01g;F@0
000000T0o;mn1P3k`H<20?ZnP`P0nKj61`3h_XX60?NnS@L0m[j@1P3d_I870?>lU0030?6kU@0000<0
000001`0^fmi802jIV/<0;QJFP030000002>;4<0SRa302P0SRa300@0000005T0:@1I02T00000203f
/7L00`000000m[1f0?J`MP070?J`MP030000003f/7L0m[1g0080m[1g00<0000007`dJP1l=6X00`1l
=6X708E7O@030000001?7740Caaa0080Caaa3@1M<hD406Q5U0050000003h[g40n:ma0?R_L@000000
100N48<>02`UU00300000033S9/0`hbK0080`hbK5`34TZ8E0<nIWP030000002JOk@0VWnd00H0VWnd
00<000000>:WU@3RYiD03`3RYiDA0>NYT0d0k:b90P3][h`=0?6`Q0D0m[1i1P3f/GX0103i[f`0nK1/
0?V`K03i/6`20?VaK0070?ZbJ`3j/VT0nk9V0?^aH`3j/600n[1O0?Z_GP020?Z^G0<0n:a90`09jPX4
0>nQ:`030=b@2@3IR@80oooo01P0oooo0P09jPXM0?ooo`<02NX:F`3oool00380oooo00H0000007L]
I01g;F@0MbeT0893NP00000:0?boOPD0nl630`3j_X<70?VnQPL0n;j:1P3g_Xd70?JnT0H0m;fB1`3c
_9@00`00000000030000000P0;]_NAl0^VI[2@2hFUX00`000000SRa308h/@`0X08h/@`030000001I
02T0000000T0m[1g00<000000?J`MP3f/7H01`3f/7H00`000000m[1g0?J`M`020?J`M`040000001l
=6X0O3AZ07`dJPP0QDMm00<0000004lLL@1?77400P1?774=05dcQ@D0J4FD00D000000?R_L@3h[g40
n:ma0000000301h@P`h0;2FD00<0=cFS00000034TZ806P34TZ8E0<nIWP030000002JOk@0VWnd00H0
VWnd00<000000>:WU@3RYiD0403RYiDA0>NYT0L0k:b9203][h`=0?6`Q0<0m[1i1`3f/GX40?V`K080
nK5/00D0n[9[0?ZbJ@3k/VH0nk5T0?^aHP020?Z`G`8000000`09jPX30?R/B@040?RYAP3_XB/0kj4[
0>nQ:`80g90900<0fHT20?ooo`3oool04`3oool300WZ2Q`0oooo0`09jPYN0?ooo`00<P3oool00`00
0000PT=j0893NP020893NP030000003l_gh0o;mn00P0o;mn103k`H<40?ZnP`P0nKj61`3h_XX60?Nn
S@H0m[j@1P3d_I870?>lU0030000000000<0000002@0^fmi7`2jIV/50;QJFP030000002>;4<0SRa3
02L0SRa300@0000005T0:@1^6dl00000203f/7L00`000000m[1f0?J`MP070?J`MP030000003f/7L0
m[1g00<0m[1g00<0000008E7O@25Agd02@25Agd010000000Caaa04lLL@1?774<05dcQ@L0J4FD00D0
00000?R_L@3h[g40n:ma0000000201h@P`h0;2FD0P0g=J<00`000000a9:R0<BBXP0I0<BBXQD0ciVN
00<0000009Yo]02JOk@01P2JOk@00`000000hZNE0>:WU@0@0>:WUA40ijV@0P3/[8T=0>f_S0d0lK24
00<0m[1i0?JaNP3f/GX01P3f/GX20?NcN`80nK1/0`3i/F`01@3j/V/0n[9Y0?ZbJ03k/F@0nk5S0080
2NX:00@0000000WZ2P3j[U`0nJi=1@3h[4T40>nQ:`80g9094P3oool300WZ2Qd0oooo0P09jPYQ0?oo
o`00<P3oool00`000000PT=j0893NP020893NP030000003l_gh0o;mn00P0o;mn103k`H<50?ZnP`L0
nKj61`3h_XX60?NnS@<0m[j@0`3e^hd60?BjSPD0lkZ@00@0lkbD0000000000<00000:@2kKgTN0;YV
J`030;QJFP000000SRa301@0SRa35@2G@Ul00`000000KQ]?000000090?J`M`030000003f/7H0m[1f
00L0m[1f00<000000?J`M`3f/7L00`3f/7L00`000000QDMm08E7O@0908E7O@030000001?7740GC>5
00`0GC>52@1XAI@01@000000n:ma0?R_L@0000007Q2300h0;2FD100g=J<00`000000a9:R0<BBXP0H
0<BBXQH0ciVN00<0000009Yo]02JOk@01@2JOk@00`000000hZNE0>:WU@0@0>:WU@l0ijV@0P3X[I<?
0>f_S0`0lK2400<0l[:60?JaNP3f/GX01P3f/GX30?NcN`80nK1/0P3i/F`20?ZaK080n[9Y00D0nk9V
0?^aI03k/F80n[1P0?Z`G`020?Z_GP80nJi=103h[4T40>nQ:`80g9093`3oool300WZ2Qd0oooo0`09
jPYS0?ooo`00<P3oool00`000000PT=j0893NP020893NP030000003l_WP0o;mn00T0o;mn0P3k`H<6
0?ZnP`L0nKj61`3h_XX50?NnS@030?JkR`3e^hd0mK^=00@0mK^=1P3d^Xh60?>jT0030000000000<0
000002d0^fmi6`2jIV/00`000000Ud9O09M2G`0X09M2G`030000001^6dl0000000T0m[1g00<00000
0?J`MP3f/7H01P3f/7H00`000000m[1g0?J`M`040?J`M`0300000025Agd0QDMm00T0QDMm00<00000
05dcQ@1M<hD02P1M<hD;06Q5U0040000003h[g40n:ma000000h0;2FD1@0g=J<00`000000a9:R0<BB
XP0I0<BBXQD0ciVN00<0000009Yo]02JOk@01P2JOk@00`000000hZNE0>:WU@0?0>:WU@/0ijV@1P3X
[I<@0>f_S0T0lK24103b/XH60?JaNP@0mk=k0P3i/6`20?VaK080n[5/00H0n[9Z0?ZbJ@3k/VH0nk5T
0?^aH`3j/6020?Z`G`040?Z_GP3i[Td0nJi=0?V^C@<0n:a900@0lJDa0>nQ:`3_XB/0kj4[0P3LT0T=
0?ooo`802NX:7@3oool300WZ2VH0oooo000b0?ooo`0500000022@gX0PT=j0893NP0000000`3l_WP9
0?boOP80nl631P3j_X<80?VnQPL0n;j:0P3g_Xd30?JkR`H0mK^=1P3d^Xh60?>jT080000300@00000
0;agQ@2lMhD0_7N5;P2kKgTG0;YVJ`030000002G@Ul0Ud9O02L0Ud9O00@0000006hKC`1^6dl00000
2@3f/7L00`000000m[1f0?J`MP060?J`MP030000003f/7L0m[1g00@0m[1g00<0000008E7O@25Agd0
2025Agd00`2<Ehd0000005dcQ@0:05dcQ@`0J4FD00@000000?R_L@3h[g4000003@0/9I@603LeX`03
00000034TZ80a9:R01T0a9:R5@3?VIh00`000000VWnd09Yo]00609Yo]0030000003RYiD0hZNE0100
hZNE1P3WZI0;0>R]T`l0kJn<1`3a/8@60?:bQPD0m[5j1@3g/g/0103g]7/0nK5/0?VaK03i/F`20?Za
K0070?ZbJP3j/VT0n[9X0?^aI03k/F<0nk5R0?Z`H0020?Z`G`040?Z`D@3i[Td0nJi=0?V^C@80n:a9
0P3aYC420>nQ:`<0g9092@3oool300WZ2Qd0oooo0P09jPYY0?ooo`00<P3oool01@000000PT=j0893
NP22@gX0000000<0o;ih2P3l_gh00`3k`H<0n[j30?ZnP`050?ZnP`L0nKj61`3h_XX00`3g_Xd0m[^;
0?JkR`030?JkR`H0mK^=1@3d^Xh50?>jT0040000000000<00003000000P0_7N5;@2kKgTB0;YVJ`03
0000002G@Ul0Ud9O02P0Ud9O00<0000006hKC`0000002P3f/7L00`000000m[1f0?J`MP060?J`MP03
0000003f/7L0m[1g00@0m[1g00<0000008E7O@25Agd01@25Agd408aGS@030000001M<hD0GC>500P0
GC>53@1XAI@010000000n:ma0?R_L@00000<02`UU0L0=cFS00<000000<BBXP34TZ806@34TZ8F0<nI
WP030000002JOk@0VWnd00D0VWnd00<000000>:WU@3RYiD0403RYiD20>NYT0l0j:fC3`3][h`60?6`
Q0L0l[:6103f/GX50?NcN`80mkAk0`3i/F`20?ZaK0070?ZbJP3j/VT0n[9X0?^bIP3k/F@0nk5S0?^a
HP020?Z`G`80n[1A0`3i[Td20?R/B@80lJDa00@0kj4[0=b@2@3LT0T0g9091P3oool300WZ2Qd0oooo
0`09jPY[0?ooo`00<@3oool00`000000PT=j0893NP020893NP030000003l_WP0o;ih0080o;ih2@3l
_gh80?ZnP`L0nKj61`3h_XX60?JkR`H0mK^=1P3d^Xh40?>jT080000300<0000c0000002lMhD0302l
MhD/0;]_N@h0^VI[00<0000009M2G`2G@Ul0:02G@Ul00`000000O3AZ0000000:0?J`M`030000003f
/7H0m[1f00D0m[1f00<000000?J`M`3f/7L01@3f/7L00`000000QDMm08E7O@0208E7O@L0S5N=00<0
000005dcQ@1M<hD01P1M<hD?06Q5U0040000003h[g40n:ma000000/0;2FD200g=J<00`000000a9:R
0<BBXP0I0<BBXQ<0ciVN0`3@WZ<00`000000VWnd09Yo]00609Yo]0030000003RYiD0hZNE00d0hZNE
0P3TZiTA0>R]Ta00kJn<0`3a/8@:0?:bQP80m[5j1@3g/g/30?NdN`030?RfO03i/F`0nK5/0080n[5/
00X0n[9Z0?ZbJ@3j/VT0nk9V0?^aI03k/F<0nk5R0?Z`H03j/5l0nk9E0P3j/5430?V^C@050?R/B@3a
YC40lJDa0?6U<@3_XB/00P3LT0T30?ooo`<02NX:7@3oool300WZ2Vh0oooo000a0?ooo`0300000022
@gX0PT=j0080PT=j00<000000?bnN03l_WP00P3l_WP90?boOP030?ZmO`3j_X<0n[j300H0n[j31`3i
_XH50?RnRP030?NkR03f^h/0m[^;00@0m[^;1P3e^hd60?BjSP<0lkZ@00D0000000000`0000<0000c
0000000C0;agQBX0^fmi2P2jIV/00`000000Ud9O09M2G`0Q09M2G`L0WE9c00<0000007`dJP000000
2@3f/7L00`000000m[1f0?J`MP060?J`MP030000003f/7L0m[1g00D0m[1g00<0000008E7O@2<Ehd0
2@2<Ehd00`000000GC>505dcQ@0505dcQ@l0J4FD00<0Ke>Q0000003h[g400P3h[g400`000000;2FD
02`UU00602`UU0/0=cFS00<000000<BBXP34TZ806@34TZ8;0<nIWPX0d9jS00<0000009Yo]02JOk@0
1P2JOk@00`000000hZNE0>:WU@0:0>:WU@H0i:^I4@3X[I<?0>f_S0030?6`Q03b/XH0l[:600X0l[:6
00<0m[5j0?NcN`3g/g/0103g/g/20?NdN`<0n;Il00@0nK5/0?ZaK03j/F`0n[9Z0P3j/VT01`3j/VP0
nk5T0?^aI03k/F<0nk5R0?Z`H03k/UD00P3j/5440?V^C@@0lJDa0P3LT0T00`2mM`002NX:00WZ2P0N
0?ooo`802NX:L@3oool00340oooo00<000000893NP22@gX00P22@gX00`000000o;ih0?bnN0030?bn
N0P0o;mn00<0n[eo0?ZnP`3j_X<01P3j_X<70?VnQP@0n;j:0`3g^hP50?JkR`H0mK^=1P3d^Xh30?>j
T08000030P0003<00`000000_7N50;agQ@0F0;agQBT0^fmi1@2jIV/00`000000Ud9O09M2G`0C09M2
GaH0WE9c00<0000007`dJP0000002@3f/7L00`000000m[1f0?J`MP060?J`MP030000003f/7L0m[1g
00D0m[1g00<0000008aGS@2<Ehd02P2<Ehd00`000000GC>505dcQ@0205dcQ@l0J4FD0`1_Dj401@00
0000n:ma0?R_L@3h[g40000000L0;2FD300g=J<00`000000a9:R0<BBXP0I0<BBXP@0ciVN4P3@WZ<0
0`000000VWnd09Yo]00509Yo]0030000003RYiD0hZNE00H0hZNE2P3TZiTA0>R]T`h0kJn<00<0k[6?
0?:bQP3b/XH02P3b/XH00`3c]8L0mk=k0?NcN`040?NcN`<0mkAk0`3h]W`0103i/F`0n[5/0?ZaK03j
/V/20?ZbJ@060?ZbJ03k/VH0nk5T0?^aH`3k/F80n[1P0P3k/UD20?Z`D@<0nJi=103aYC4300WZ2Qd0
oooo0`09jPYc0?ooo`00<@3oool00`000000PT=j0893NP020893NP030000003l_WP0o;ih00<0o;ih
1`3l_gh30?ZmO`P0n[j31P3i_XH30?RnRP@0mk^81P3f^h/50?FkS@H0m;Z>0P3c^Y000`0000000003
00000`020000<`030000002lMhD0_7N501/0_7N5:02kKgT00`2jIV/0000009M2G`0509M2GbD0WE9c
0P00000:0?J`M`030000003f/7H0m[1f00H0m[1f00<000000?J`M`3f/7L01@3f/7L00`000000S5N=
08aGS@0:08aGS@040000001M<hD0GC>505dcQ@l0J4FD1@1_Dj4010000000n:ma0?R_L@00000602`U
U0d0=cFS00<000000<BBXP34TZ805P34TZ830<JHZ1H0d9jS00<0000009Yo]02JOk@01P2JOk@00`00
0000hZNE0>:WU@020>:WU@d0i:^I4@3X[I<<0>f_S0@0k[6?2P3b/XH30?>dQ`@0mk=k103g]7/30?Rf
O0040?VgN`3j/F`0n[5/0?ZbJ`80n[9Y00L0n[9X0?^bIP3k/F@0nk5T0?^aH`3k/F80o;AJ0080nk9E
0P3j/5420?V^C@050?>Z>@09jPX02NX:00WZ2P3QV1<00P3LT0TJ0?ooo`<02NX:MP3oool00340oooo
00<000000893NP22@gX00P22@gX00`000000o;ih0?bnN0040?bnN0H0o;mn0`3j_Gl80?ZnP`L0nKj6
00<0n;j:0?NkR03g^hP00`3g^hP60?JkR`D0mK^=1P3d^Xh20?>jT0<0000300<0000c0000002lMhD0
8`2lMhDS0;]_N@030000002MDW<0WE9c02P0WE9c00<0000007`dJP0000002P3f/7L00`000000m[1f
0?J`MP050?J`MP030000003f/7L0m[1g00H0m[1g00<0000008aGS@2<Ehd02P2<Ehd00`000000GC>5
06Q5U00>06Q5U0L0Ke>Q00@000000?R_L@3h[g4000001@0/9I@>03LeX`0300000034TZ80a9:R0140
a9:R2036V:PF0=2NX`030000002JOk@0VWnd00H0VWnd00<000000>:WU@3TZiT0403TZiTA0>R]T`T0
kJn<1P3^/Hl90?:bQP@0lkB7103g/g/30?NdN`@0n;Il00@0nKMk0?VhN`3j/F`0n[9[0`3j/VT01P3k
/VH0nk5T0?^aI03k/F<0nk5R0?bdFP80nk9E0P00000300WZ2P060?>Z>@3aYC40lJDa0?6U<@3QV1<0
g909603oool200WZ2WT0oooo000a0?ooo`0500000022@gX0PT=j0893NP0000001`3l_WP60?boOP@0
n[eo1`3j_X<70?VnQPL0mk^81@3f^h/60?FkS@D0m;Z>0P3c^Y0200000`80000c00<000000;agQ@2l
MhD09`2lMhDN0;]_N@030000002MDW<0WE9c02P0WE9c00<0000007`dJP0000002P3f/7L00`000000
m[1f0?J`MP050?J`MP030000003f/7L0m[1g00H0m[1g00<0000008aGS@2<Ehd02P2<Ehd00`000000
J4FD06Q5U00<06Q5U0T0Ke>Q00@000000?R_L@3h[g400000100/9I@?03LeX`0300000034TZ80a9:R
00/0a9:R3`36V:PE0=2NX`030=VSW@000000VWnd00@0VWnd0P2MQk`00`000000i:^I0>B[V@0@0>B[
VA40j:fC1`3][h`80>jaS`P0l[:61@3c]8L30?NcN`@0mkAk0`3h]W`20?VgN`80nKQk00L0n[9[0?Zb
JP3j/VT0n[9Y0?ZbJ03k/VH0nk5T0080nk5S00H0o;IN0?bdFP3k/UD0000000WZ2P3j/5420?V^C@80
ljXi0P3aYC400`3QV1<0g9090;eg000D0?ooo`<02NX:N`3oool00340oooo00D000000893NP22@gX0
PT=j000000080?bnN0D0o;mn103j_Gl80?ZnP`H0nKj600<0n;^50?NkR03g^hP0103g^hP50?JkR`H0
mK^=1@3d^Xh0103c^Y00000000000`0000<20000<`030000002lMhD0_7N502`0_7N5602kKgT00`00
0000WE9c09eBL`0Y09eBL`0300000025B7d0000000X0m[1g00<000000?J`MP3f/7H01@3f/7H00`00
0000m[1g0?J`M`060?J`M`030000002<Ehd0S5N=00P0S5N=0P2AHiT00`000000J4FD06Q5U00:06Q5
U0/0Ke>Q00D000000?R_L@3h[g40n:ma0000000202`UU140=cFS00<000000<BBXP34TZ801@34TZ8D
0<JHZ1D0d9jS00<0fJ>M0000002JOk@01P2MQk`00`000000i:^I0>B[V@0@0>B[VA40j:fC1P3][h`:
0>jaS`H0l[:61`3c]8L20?NcN`@0mkAk0`3h]W`20?VgN`80nKQk00H0n[Uj0?ZbJP3j/VT0n[9Y0?Zb
J03k/VH20?^aI0030?^aH`3l]Uh0o;AJ0080nk9E0`3j/5400`3i[Td0ljXi0?>Z>@020?6U<@80hIPC
00<0g9090?ooo`3oool03`3oool300WZ2Wh0oooo000`0?ooo`0300000022@gX0PT=j0080PT=j00<0
00000?bnN03l_WP01`3l_WP30?boOPH0n[eo1`3j_X<50?VnQP80n;^51P3g^hP60?JkR`D0mK^=1@3d
^Xh00`3c^Y00000300000`030000<`030000002lMhD0_7N50340_7N54`2kKgT00`000000WE9c09eB
L`0S09eBL`H0XUn200<0000008E8O@0000002P3f/7L00`000000m[1f0?J`MP050?J`MP030000003f
/7L0m[1g00H0m[1g00<0000008aGS@2<Ehd01@2<Ehd5095SV@030000001XAI@0J4FD00P0J4FD3@1_
Dj401P000000n:ma0?R_L@3h[g40000002`UU180=cFS00<000000<BBXP34TZ806@36V:PF0=2NX`03
0000002MQk`0WHNl00H0WHNl00<000000>B[V@3TZiT0403TZiTA0>R]T`<0kJn<303^/Hl50?:bQPP0
lkB700<0mk=k0?NdN`3g]7/00P3g]7/40?RfO080nKMk0P3i^7/01P3j^GX0n[9Z0?ZbJ@3j/VT0n[9X
0?^bIP80nk5T0P3l^680103l]Uh0o;AJ0?^bE@3k/UD30?Z`D@<0ljXi00@0lJDa0>6H4`3QV1<0hIPC
3`3oool200WZ2X40oooo000`0?ooo`0300000022@gX0PT=j0080PT=j00<000000?bnN03l_WP01`3l
_WP30?boOPH0n[eo203j_X<40?VnQP80n;^51P3g^hP60?JkR`D0mK^=1P3d^Xh200000`<0000c00<0
00000;agQ@2lMhD0=`2lMhD=0;]_N@030000002MDW<0WE9c01P0WE9c4@2RGh800`000000QDQm0000
000:0?J`M`030000003f/7H0m[1f00D0m[1f00<000000?J`M`3f/7L01P3f/7L00`000000S5N=08aG
S@0208aGS@P0TF>I00<0000006Q5U01XAI@01`1XAI@?06mCX@040000003h[g40n:ma00000180=cFS
00<0?D>^00000036V:P06P36V:PF0=2NX`030000002MQk`0WHNl00H0WHNl00<000000>B[V@3TZiT0
403TZiTA0>R]T`030>f_S03^/Hl0k[6?00`0k[6?103b/XH90?>dQ`D0mkAk103h]W`20?VgN`80nKQk
00<0n[Uj0?^jN03j/VT00P3j/VT00`3j/VP0nk9V0?^aI0020?bhHP040?bfGP3l]5X0nk9E0?^bE@<0
n[1A103cZST00`3aYC40hIPC0>6H4`0<0?ooo`<02NX:P`3oool00300oooo00H000000893NP22@gX0
PT=j08UCRP00000:0?bnN080o;mn1`3j_Gl70?ZnP`<0nKj6103h^hD60?NkR0D0m[^;1@3e^hd50?Bj
SP800003100003<00`000000_7N50;agQ@0l0;agQ@L0^fmi00<0000009eBL`2MDW<03P2MDW<L0:9O
PP8000002`3f/7L00`000000m[1f0?J`MP050?J`MP030000003f/7L0m[1g00H0m[1g00<0000008aG
S@2AHiT02P2AHiT00`000000J4FD06Q5U00506Q5U140Ke>Q00@000000?R_L@3h[g4000004@0g=J<2
03e3[P0300000036V:P0aYRX01X0aYRX5@3@WZ<00`3IXid0000009f7_00609f7_0030000003TZiT0
i:^I0140i:^I3`3X[I<00`3Y/IH0k[6?0>jaS`0>0>jaS`80l[:62P3c]8L00`3d]XP0mkAk0?NdN`02
0?NdN`<0n;Il0`3i]g/20?VhN`030?ZiNP3k^WP0nkYf0080o;Yd00H0n[9X0?^bIP3m^FH0oKUV0?bh
HP3l]Uh20?bdFP80nk9E0P3j/5400`3f[d00ljXi0?>Z>@020?>Z>@80hIPC00<0a8<00?ooo`3oool0
1`3oool200WZ2XH0oooo000`0?ooo`0300000029DhX0RE>:0080RE>:00<000000?bnN03l_WP0203l
_WP20?boOPL0n[eo1`3j_X<20?VnQPD0n;^51P3g^hP50?JkR`D0mK^=1@3d^Xh200000`@0000c00<0
00000;agQ@2lMhD0@@2lMhD20;]_N@030000002MDW<0WE9c00<0WE9c9P2RGh800`000000QDQm0000
000;0?J`M`030000003f/7H0m[1f00@0m[1f00<000000?J`M`3f/7L01`3f/7L00`000000TF>I095S
V@0:095SV@030000001XAI@0J4FD00<0J4FD4`1_Dj4010000000n:ma0?R_L@00000?03LeX`D0?D>^
00<000000<JHZ036V:P06@36V:PC0=2NX`80dJ>X00<0fjRQ0000002MQk`01`2MQk`00`000000i:^I
0>B[V@0@0>B[V@d0j:fC103Y/IH?0>jaS`030?:bQP3c]8L0lkB700P0lkB70`3d]XP20?NdN`@0n;Il
0P3i]g/30?VhN`030?ZiNP3k^WP0nkYf0080o;Yd00@0o;]a0?fjKP3m^FH0oKUV0P3l^6800`3l]Uh0
o;AJ0?^bE@020?^bE@030?Z`D@3f[d00ljXi00<0ljXi0P3QV1<00`34P`00oooo0?ooo`040?ooo`<0
2NX:R03oool00300oooo00<0000008UCRP29DhX00P29DhX00`000000o;]c0?bnN0090?bnN0T0n[eo
1`3j_X<00`3i_XH0n;^50?RkQ@040?RkQ@D0mk^81P3f^h/50?FkS@@0m;Z>00<000030000<`0003<0
0`0003<00`000000_Gj>0;enSP020;enST40_7N500<000000:9OPP2RGh80:@2RGh800`000000QDQm
0000000;0?J`M`030000003f/7H0m[1f00@0m[1f00<000000?J`M`3f/7L01`3f/7L00`000000TF>I
095SV@0:095SV@040000001XAI@0J4FD06Q5U1@0Ke>Q00D0MEn/0000003h[g40n:ma0000000>03Le
X`H0?D>^00<000000<JHZ036V:P06@36V:P@0=2NX`H0dJ>X00<0000009f7_02MQk`01P2MQk`00`00
0000i:^I0>B[V@0@0>B[V@/0j:fC1P3Y/IH>0>jaS`030>ndT@3c]8L0lkB700P0lkB7103d]XP20?Nd
N`@0n;Il0P3i]g/30?VhN`030?ZiNP3k^WP0nkYf0080o;Yd00@0o;]a0?fjKP3m^Vh0oKUV0P3l^680
0`3l]Uh0o;AJ0?bdFP020?^bE@030?Z`D@3f[d00mZm000<0ljXi00<0iZ0N0>6H4`3QV1<00`3oool3
00WZ2X/0oooo000`0?ooo`0300000029DhX0RE>:0080RE>:00<000000?bkL`3l_WP02@3l_WP90?Zm
O`L0n[j31`3h^hD60?NkR0D0m[^;1@3e^hd30?BjSP8000031@0003<00`000000_Gj>0;enSP0;0;en
SSP0_7N500<000000:9OPP2RGh80:@2RGh800`000000QDQm0000000;0?J`M`030000003f/7H0m[1f
00@0m[1f00<000000?J`M`3f/7L01`3f/7L00`000000TF>I095SV@0:095SV@030000001XAI@0J4FD
01<0Ke>Q0`1eGj`01@000000n:ma0?R_L@3h[g40000000/0=cFS200m@jh00`000000aYRX0<JHZ00I
0<JHZ0d0d9jS2@3AXjP00`3KZ:40000009f7_00609f7_0030000003TZiT0i:^I0140i:^I203X[I<8
0>VaUPd0k[6?0`3_]9490?>dQ`D0m;J800<0mkAk0?RfO03h]W`00P3h]W`20?VgN`80nKQk0P3j^GX0
103k^WP0nkYf0?bjM03l^W@20?bkL@040?fjKP3m^FH0oKUV0?bhHP80o;IN00@0o;AJ0?^bE@3k/UD0
nk9E0P3f[d030?>Z>@040>JP7P3QV1<0hIPC0<B300802NX:SP3oool00300oooo00<0000008UCRP29
DhX00P29DhX00`000000o;]c0?bkL`090?bnN0030?^kN`3j_Gl0n[eo00L0n[eo1P3j_X<00`3h^X<0
n;^50?RkQ@040?RkQ@H0mk^81@3f^h/50?FkS@<0m;Z>00<000030000<`0003<00`0003<00`0005P0
00000;enSP0E0;enSRl0_7N500<000000:9OPP2RGh80:@2RGh800`000000S5N=0000000;0?J`M`03
0000003f/7H0m[1f00@0m[1f00<000000?J`M`3f/7L01`3f/7L00`000000TF>I095SV@0:095SV@03
0000001_Dj40Ke>Q0140Ke>Q1P1eGj`010000000n:ma0?R_L@00000:03LeX`T0?D>^00<000000<JH
Z036V:P06@36V:P90=2NX`d0dJ>X00<0fjRQ0000002MQk`01`2MQk`00`000000i:^I0>B[V@0@0>B[
V@H0j:fC2`3Y/IH;0>jaS`@0kkBA203c]8L60?BfR0@0n;Il0`3i]g/20?VhN`80n[Uj00<0nkYh0?^j
MP3k^WH00P3l^W@0103l^g40oKY^0?fiIP3m^FH20?bhHP030?bfGP3l]5X0o;AJ0080nk9E0`3f[d02
0?>Z>@040>JP7P09jPX02NX:00WZ2Y00oooo000`0?ooo`0300000029DhX0RE>:0080RE>:00@00000
0?bkL`3l^g<0o;]c203l_WP20?^kN`P0n[eo1@3j_X<20?RjP`L0n;^51@3g^hP50?JkR`D0mK^=0`3d
^Xh00`0000<0000c0000<`030000<`030000F0000000_Gj>01h0_Gj>9P2lMhD00`000000XUn20:9O
PP0U0:9OPP@0YF^>00<0000008aGS@0000002`3f/7L00`000000m[1f0?J`MP040?J`MP030000003f
/7L0m[1g00P0m[1g00<00000095SV@2AHiT0202AHiT00`2EKZ<0000006mCX@0@06mCX@P0MEn/00@0
00000?R_L@3h[g400000200g=J<<03e3[P0300000036V:P0aYRX01T0aYRX1@3@WZ<A0=6SZ0030000
002MQk`0WHNl00H0WHNl00<000000>B[V@3TZiT0403TZiT40>R]T`d0jK6F2P3^/Hl60>ndT@H0lkB7
1`3d]XP0103e^HP0n;Il0?RfO03h]W`30?VgN`80nKQk0P3j^GX00`3k^WP0nkYf0?^jMP020?bjM004
0?bkL@3m^Vh0oKYZ0?fiIP80o;QR0P3l]Uh0103l]5X0nk9E0?^bE@3h/dP2000000<02NX:00<0iZ0N
0>6H4`34P`00T03oool00300oooo00<0000008UCRP29DhX00P29DhX010000000o;]c0?bkL`3l^g<8
0?bnN080nk]k2@3j_Gl40?ZnP`<0n;Z31P3h^hD60?NkR0D0m[^;103e^hd30?BjSP0300000`0003<0
000c0080000c0P0005P00`000000_Gj>0;enSP0U0;enSQh0_7N500<000000:9OPP2RGh80702RGh8=
0:E[SP030000002<Ehd0000000/0m[1g00<000000?J`MP3f/7H0103f/7H00`000000m[1g0?J`M`08
0?J`M`030000002AHiT0TF>I00D0TF>I102EKZ<00`000000Ke>Q06mCX@0=06mCX@X0MEn/00@00000
0?R_L@3h[g4000001`0g=J<=03e3[P0300000036V:P0aYRX01T0aYRX0P3@WZ<D0=6SZ0030=^XX@00
0000WHNl00H0WHNl00<000000>B[V@3TZiT04@3TZiT00`3X[I<0jK6F0>VaUP0>0>VaUPP0k[6?1`3_
]9460?>dQ`H0m;J80`3e^HP20?RfO0<0nKMk0P3i^7/20?ZiNP80nkYh00@0nkYf0?bjM03l^W@0o;]a
0P3m^Vh20?fiIP030?bhHP3l]Uh0o;IN0080o;AJ00D0nk9E00WZ2P00000000000?J_@0020?>Z>@03
0>JP7P3QV1<0a8<00900oooo000`0?ooo`0300000029DhX0RE>:0080RE>:00<000000?bkL`3l^g<0
0P3l^g<70?bnN0<0nk]k203j_Gl40?ZnP`<0n;Z31`3h^hD50?NkR0D0m[^;103e^hd30?BjSPD0000c
0P0005P00`000000_Gj>0;enSP0^0;enSQD0_7N500<000000:9OPP2RGh804`2RGh8F0:E[SP040000
002<Ehd0S5N=000000X0m[1g00<000000?J`MP3f/7H01@3f/7H00`000000m[1g0?J`M`040?J`M`<0
2NX:00<00000095SV@2AHiT00P2AHiT809E^X`030000001_Dj40Ke>Q00X0Ke>Q301eGj`010000000
n:ma0?R_L@00000503LeX`l0?D>^00<000000<JHZ036V:P05`36V:P20<NN[QL0dJ>X00<0000009f7
_02MQk`01P2MQk`00`000000i:^I0>B[V@0?0>B[V@030>F_W03Y/IH0jK6F00l0jK6F1`3^/Hl80>nd
T@D0lkB71`3d]XP30?FiR080n;Il0`3i]g/20?VhN`80n[Uj0P3k^WP0103k^WH0o;Yd0?bjM03l^g42
0?fjKP80oKUV0P3l^6820?bfGP040?bdFP3k/UD0n;=80?RcB0<0mZm000@0ljXi0>JP7P3VX1h0hIPC
T03oool00300oooo00<0000008UCRP29DhX00P29DhX00`000000o;]c0?bkL`030?bkL`H0o;ih103k
^g/80?ZmO`80n[j31@3h^X<60?RkQ@D0mk^81@3f^h/50?FkS@030?BjSP0000<0000c00<0000c0`00
05P00`000000_Gj>0;enSP0g0;enSP`0_7N500<000000:9OPP2RGh802P2RGh8O0:E[SP040000002<
Ehd0S5N=000000/0m[1g00<000000?J`MP3f/7H0103f/7H01@000000m[1g0?J`M`3f/7L000000080
2NX:0`3f/7L00`000000TF>I09E^X`0:09E^X`030000001_Dj40Ke>Q00T0Ke>Q3@1eGj`01@000000
n:ma0?R_L@3h[g40000000<0=cFS4@0m@jh00`000000aYRX0<JHZ00B0<JHZ0L0aij^5P3AXjP00`00
0000WHNl09f7_00609f7_0030000003TZiT0i:^I00d0i:^I103U[i`A0>VaUPD0k[6?2P3_]9430?>d
Q`L0m;J81@3e^HP40?VgN`80nKQk0P3j^GX20?^jN0030?^jMP3l^W@0o;Yd0080o;]a00<0oKY^0?fj
JP3m^FH00P3l^6820?bfGP80o;AJ0P3h/dP30?J_@0050?>Z>@3VX1h0iZ0N0>6H4`34P`00S`3oool0
0300oooo00<0000008UCRP29DhX00P29DhX00`000000o;]c0?bkL`040?bkL`D0o;ih103k^g/80?Zm
O`80n[j31@3h^X<60?RkQ@D0mk^81@3f^h/50?FkS@030?BjSP0003<0000c00<0000c0`0005P00`00
0000_Gj>0;enSP100;enSP<0_7N500@000000:9OPP2RGh80XUn2:02UJhh010000000S5N=08aGS@00
000;0?J`M`030000003f/7H0m[1f00@0m[1f00@0000000WZ2P09jPX02NX:0P0000040?J`M`030000
002EKZ<0UFjS00X0UFjS00<0000006mCX@1_Dj401`1_Dj4@07EO[0050000003h[g40n:ma0000000g
=J<04`0m@jh00`000000aYRX0<JHZ00?0<JHZ0X0aij^5P3AXjP00`3KZ:40000009f7_00609f7_003
0000003TZiT0i:^I00/0i:^I1P3U[i`A0>VaUP@0k[6?2`3_]9430?>dQ`L0m;J81@3e^HP40?VgN`80
nKQk0P3j^GX20?^jN0030?^jMP3l^W@0o;Yd0080o;]a00D0oKY^0?fjJP3m^FH0oKUV0?bhHP020?bf
GP80o;AJ0P3h/dP40?J_@0<0iZ0N00<0a8<00?ooo`3oool0S@3oool002l0oooo00<0000008UCRP29
DhX00`29DhX00`000000o;]c0?bkL`040?bkL`@0o;ih1P3k^g/80?ZmO`030?ZnP`3h^X<0n;Z300@0
n;Z31P3h^hD50?NkR0D0m[^;103e^hd00`3d^Xh0000c0000<`020000<`@0001H00<000000;enSP2m
OXh0@`2mOXh00`000000YF^>0:E[SP0Y0:E[SP040000002<Ehd0S5N=000000/0m[1g00<000000?J`
MP3f/7H0103f/7H00`000000m[1g0?J`M`070?J`M`030000002EKZ<0UFjS00X0UFjS00<0000006mC
X@1_Dj401@1_Dj4B07EO[0040000003h[g40n:ma000001@0?D>^00<000000<JHZ036V:P02`36V:P>
0<NN[QL0dJ>X00<0000009f7_02MQk`01P2MQk`00`000000i:^I0>B[V@080>B[V@P0iJnL4@3Y/IH3
0>jaS`d0kkBA00<0lkB70?BfR03d]XP01@3d]XP60?FiR0030?NkR03i]g/0nKMk00<0nKQk0P3j^GX2
0?^jN0050?^jMP3l^W@0o;Yd0?bjM03l^g400P3m^Vh20?fiIP80o;QR0P3l]Uh0103l]5X0n[MA0?Rc
B03h/dP30?J_@0<0iZ0N00<0a8<00?ooo`3oool0S@3oool002l0oooo00<0000008UCRP29DhX00`29
DhX00`000000o;]c0?bkL`050?bkL`<0o;ih1`3k^g/70?ZmO`L0n;Z31P3h^hD50?NkR0D0m[^;0P3e
^hd20?BhR@040?>gR`0003<0000c0000<`D0001H00<000000;enSP2mOXh0@`2mOXh00`000000YF^>
0:E[SP0Y0:E[SP040000002<Ehd0TF>I000000/0m[1g00<000000?J`MP3f/7H0103f/7H00`000000
m[1g0?J`M`070?J`M`030000002EKZ<0UFjS00X0UFjS00<0000006mCX@1_Dj400`1_Dj4D07EO[004
0000003h[g40n:ma000001@0?D>^00<000000<JHZ036V:P01`36V:PC0<NN[QD0dJ>X00<0djV]0000
002MQk`01`2MQk`00`000000i:^I0>B[V@050>B[V@`0iJnL4@3Y/IH00`3^/Hl0kkBA0>ndT@0<0>nd
T@P0m;J81@3e^HP30?NkR0040?VgN`3i^7/0nKQk0?VhN`80n[Uj0P3k^WP01@3k^WH0o;Yd0?bjM03l
^W@0o;]a0080oKY^00@0oKYZ0?fiIP3l^680o;QR0P3l]Uh0103l]5X0n[MA0?RcB03h/dP30?J_@004
0>^Y:`3VX1h0iZ0N0<B308l0oooo000_0?ooo`0300000029DhX0RE>:00<0RE>:00<000000?bkL`3l
^g<01P3l^g<20?bnN0L0nk]k1`3j_Gl00`3i^X00n;Z30?RjP`050?RjP`D0n;^51@3g^hP40?JkR`03
0?FhR03d^8T0m;R90080m;R900@0lkN;0000<`0003<0000c1@0005P00`000000_Gj>0;enSP130;en
SP030000002UJhh0YF^>02H0YF^>0`2XM9T010000000TF>I095SV@0000070?J`M`80000000<0m[1g
00WZ2P0000001P3f/7H00`000000m[1g0?J`M`070?J`M`030000002EKZ<0UFjS00/0UFjS00<00000
06mCX@1_Dj405@1eGj`01@1iJ[H000000?R_L@3h[g40000001D0?D>^00<000000<JHZ036V:P00`36
V:PF0<NN[Q80dJ>X1@3CZJd00`000000WHNl09f7_00509f7_0030000003TZiT0i:^I00<0i:^I3P3U
[i`@0>VaUP030>^dV@3_]940kkBA00d0kkBA00<0lKRB0?BfR03d]XP0103d]XP60?FiR0<0mk^800@0
nKMk0?VhN`3i^7/0nKQk0P3j^GX20?^jN080nkYf0P3l^W@0103l^g40oKY^0?fjKP3m^VX20?fiIP04
0?bhHP3l]Uh0o;IN0?bfGP80n[MA0P3h/dP20?J_@0040>^Y:`3VX1h0iZ0N0<f?08l0oooo000_0?oo
o`0300000029DhX0RE>:00<0RE>:00<000000?bkL`3l^g<01P3l^g<20?bnN0P0nk]k1P3j_Gl00`3i
^X00n;Z30?RjP`050?RjP`H0n;^51@3g^hP20?JkR`80mKR8103d^8T00`000000000c0000<`060000
F0030000002mOXh0_Gj>04<0_Gj>00<000000:E[SP2UJhh0802UJhh90:QdV@040000002AHiT0TF>I
000000H0m[1g00H02NX:00000009jPX02NX:0?J`M`0000060?J`MP030000003f/7L0m[1g00P0m[1g
00<0000009E^X`2EKZ<02P2EKZ<00`000000MEn/07EO[00C07EO[0<0NFZf00D000000?R_L@3h[g40
n:ma0000000D03e3[P0300000036V:P0aij^01T0aij^403AXjP70=>Y[@030000002MQk`0WHNl00H0
WHNl00<000000>B[V@3TZiT0403U[i`?0>VaUP<0jkBI3@3_]9420?6hTPH0m;J81P3e^HP40?NkR080
nKQk0`3j^GX20?^jN080nkYf0P3l^W@20?bkL@040?fjKP3m^VX0oKUV0?fiIP80o;QR0P3l]Uh20?Zg
D@80n;=80P3f[d00103[ZB/0iZ0N0>JP7P3=S`2?0?ooo`00;`3oool00`000000RE>:08UCRP0308UC
RP030000003l^g<0o;]c00L0o;]c00<0o;ih0?^kN`3k^g/01P3k^g/50?ZmO`<0nKZ01P3h^X<60?Rk
Q@D0mk^800<0m[^;0?FhR03e^8P00P3e^8P30?BhR@030000000003<0000c00H0001H00<000000;en
SP2mOXh0@`2mOXh00`000000YF^>0:E[SP0I0:E[SQ00Z7BI00@00000095SV@2AHiT000002`3f/7L0
0`000000m[1f0?J`MP040?J`MP030000003f/7L0m[1g00P0m[1g00<0000009E^X`2EKZ<0202EKZ<2
09Qg[0030000001eGj`0MEn/0100MEn/1`1iJ[H010000000n:ma0?R_L@00000C03e3[P03045>^@00
0000aij^01/0aij^303AXjP:0=>Y[@030000002MQk`0WHNl00H0WHNl00<000000>F_W03U[i`04@3U
[i`<0>VaUPD0jkBI303_]9440?6hTPD0m;J81@3e^HP50?NkR080nKQk0`3j^GX20?^jN080nkYf0P3l
^W@20?bkL@80oKY^00@0oKYZ0?fiIP3l^680o;QR0P3l]Uh00`3l^eT0n[MA0?RcB0020?RcB0050?J_
@03[ZB/0jjT[0>JP7P3=S`00S`3oool002l0oooo00<0000008UCRP29DhX00`29DhX00`000000o;]c
0?bkL`080?bkL`T0nk]k103j_Gl40?VjP0H0n;Z31P3h^hD40?NkR0D0mKR80`3d^8T20000<`L0001H
00<000000;j5U`2nQIL01`2nQILl0;enSP030000002UJhh0YF^>01<0YF^>5P2XM9T010000000TF>I
095SV@00000<0?J`M`030000003f/7H0m[1f00<0m[1f00<000000?J`M`3f/7L0203f/7L00`000000
UFjS09E^X`0509E^X`D0V7N/00<0000007EO[01eGj`03P1eGj`907UZ]P040000003h[g40n:ma0000
0100?D>^1@11C[T00`000000aij^0<NN[P0I0<NN[PX0dJ>X3@3CZJd00`000000WHNl09f7_00309f7
_080Who300<000000>F_W03U[i`04@3U[i`;0>VaUPH0jkBI2`3_]9450?6hTP@0m;J81P3e^HP50?Nk
R0030?RmQ`3i^7/0n[Uj0080n[Uj0P3k^WP20?^jMP80o;Yd0P3l^g420?fjKP040?fjJP3m^FH0oKUV
0?bhHP80o;IN00<0o;]I0?ZgD@3j]e400P3h/dP00`3f[d00jjT[0>^Y:`020>JP7P030<B3003oool0
oooo08`0oooo000_0?ooo`0300000029DhX0RE>:00<0RE>:00<000000?bkL`3l^g<0203l^g<:0?^k
N`<0n[eo103i^X060?RjP`H0n;^5103g^hP00`3f^8H0mKR80?FhR0020?FhR0<0m;R90P0003<70000
F0030000002nQIL0_XFG01P0_XFG:`2mOXh00`000000YF^>0:E[SP0=0:E[SQd0Z7BI00<00000095S
V@000000303f/7L00`000000m[1f0?J`MP030?J`MP030000003f/7L0m[1g00P0m[1g00<0000009E^
X`2EKZ<00P2EKZ<909Qg[0030000001eGj`0MEn/00/0MEn/2`1iJ[H01@000000n:ma0?R_L@3h[g40
000000d0?D>^1`11C[T00`000000aij^0<NN[P0I0<NN[PL0dJ>X403CZJd00`000000WHNl09n?``06
09n?``030000003U[i`0iJnL0100iJnL2P3Y/IH80>^dV@X0kkBA1P3a^9830?BfR0H0mKV81@3g^hP2
0?RmQ`<0n[Uj0P3k^WP20?^jMP<0o;Yd00@0o;]a0?fjKP3m^Vh0oKYZ0P3m^FH20?bhHP80o;]I0P3j
]e420?RcB0030?J_@03[ZB/0jjT[0080iZ0N00<0a8<00?ooo`3oool0S03oool002l0oooo00<00000
08UCRP29DhX00`29DhX00`000000o;]c0?bkL`080?bkL`030?^iM`3k^g/0nk]k00L0nk]k0`3j_Gl5
0?VjP0H0n;Z31@3h^hD30?NkR080m[R61@3e^8P20?BhR@030000<`0005P0001H00D0001H00<0001d
0000002nQIL0:`2nQILI0;enSP030000002UJhh0YF^>00H0YF^>902XM9T00`000000TF>I0000000<
0?J`M`030000003f/7H0m[1f00<0m[1f00<000000?J`M`3f/7L01`3f/7L00`09jPX0000009E^X`0<
09Qg[0030000001eGj`0MEn/00P0MEn/3`1iJ[H010000000n:ma0?R_L@00000;03e3[PT0@Dji00<0
00000<NN[P37WZh06P37WZh40=6SZ180djV]00<0000009n?``2OSl<01P2OSl<00`000000iJnL0>F_
W00A0>F_W0L0jK6F2P3[]9T90>ndT@L0lKRB0P3d]XP60?FiR0D0mk^80`3h_HL00`3i_XH0n[Uj0?Zi
NP030?^jN0050?^jMP3l^W@0o;Yd0?bjM03l^g400P3m^Vh20?fjJP030?fiIP3l^680o;QR00<0o;]I
0P3j]e420?RcB0<0jjT[00<0iZ0N0<f?003oool0S@3oool002l0oooo00<0000008UCRP29DhX00`2?
H9L00`000000o;]c0?bkL`080?bkL`80nkUg2@3k^g/20?ZmO`D0nKZ01P3h^X<60?RkQ@040?NkR03f
^8H0m[R60?JhQPD0mKR800<0m;R90000000003<01`0005P00`0007@000000;j5U`0l0;j5U`P0_Gj>
00<000000:E[SP2UJhh0:P2XM9T00`000000TF>I0000000<0?J`M`030000003f/7H0m[1f00<0m[1f
00<000000?J`M`3f/7L0103f/7L300WZ2P030?J`M`000000V7N/00`0V7N/00<0000007EO[01eGj`0
1P1eGj`A07UZ]P040000003h[g40n:ma000000P0?D>^3@11C[T00`000000aij^0<NN[P0I0<NN[P03
0=6SZ03CZJd0djV]01@0djV]00<0000009n?``2OSl<01@2OSl<00`000000iJnL0>F_W00A0>F_W0H0
jK6F303[]9T70>ndT@T0lKRB00<0m;J80?FiR03e^HP0103e^HP50?NkR0<0n;f70P3i_XH01@3j^GX0
nkYh0?^jN03k^WP0nkYf00<0o;Yd0P3l^g420?fjKP040?fjJP3m^FH0oKUV0?bhHP<0o;]I0P3j]e42
0?RcB0<0jjT[00<0iZ0N0<f?003oool0S@3oool002l0oooo00<0000008mPU`2?H9L00`2?H9L00`00
0000o;]c0?bkL`080?bkL`<0nkUg2@3k^g/70?VjP0H0n;Z31@3h^hD50?JhQP@0mKR800<0m;R90000
000005P01P0005P20000M0030000002nQIL0_XFG04<0_XFG00<000000:QdV@2XM9T0:P2XM9T00`00
0000UFjS0000000<0?J`M`030000003f/7H0m[1f00<0m[1f00<000000?J`M`3f/7L01009jPX40?J`
M`030000002HMj`0V7N/00/0V7N/00<0000007EO[01eGj`0101eGj`C07UZ]P040000003h[g40n:ma
000000H0?D>^3`11C[T00`000000aij^0<NN[P0H0<NN[P030<VT/`3CZJd0djV]01D0djV]00<00000
09n?``2OSl<01P2OSl<00`000000iJnL0>F_W00@0>F_W0@0jK6F3P3[]9T60>ndT@X0lKRB1`3e^HP5
0?NkR0<0n;f70`3i_XH30?^jN0040?^jMP3l^W@0o;Yd0?bjM080o;]a0P3m^Vh00`3m^VX0oKUV0?fi
IP020?fnH@80o;]I0`3j]e401P3h/dP0l;4h0>^Y:`3[ZB/0iZ0N0<f?08h0oooo000_0?ooo`030000
002?H9L0Sf2G00<0Sf2G00<000000?biKP3l^g<0203l^g<30?^iM`T0nk]k1`3i^X060?RjP`D0n;^5
00<0m[R40?JhQP3f^8H00P3f^8H40?FhR0030?BhR@000000001H00D0001H0`0007@00`000000_XFG
0;j5U`130;j5U`030000002XM9T0Z7BI02L0Z7BI0`2ZO:800`000000UFjS0000000=0?J`M`030000
003f/7H0m[1f00<0m[1f00<0000000WZ2P3f/7L0203f/7L00`000000V7N/09Qg[00;09Qg[0030000
001eGj`0MEn/01H0NFZf00D000000?R_L@3h[g40n:ma0000000303e3[Q40@Dji00<000000<NN[P37
WZh05@37WZh50<VT/aD0djV]00<0eJja0000002OSl<01`2OSl<00`000000iJnL0>F_W00A0>F_W080
jK6F403[]9T40>ndT@/0lKRB00<0l[^C0?FiR03e^HP00`3e^HP60?NkR0<0n;f70`3i_XH00`3k`8@0
nkYh0?^jN0020?^jMP80o;Yd0P3l^g420?fjKP80oKYZ00<0oKUV0?fnH@3m_V400`3l^eT20?ZgD@03
0?RcB03`/CP0jjT[0080jjT[00<0cHl00000003oool0S03oool002l0oooo00<0000008mPU`2?H9L0
0`2?H9L00`000000o;U^0?biKP080?bkL`@0nkUg203k^g/00`3i^Gd0nKZ00?VjP0050?VjP0H0n;Z3
0`3h^hD20?JhQ0@0m[R61@3e^8P00`000000001H0000F0040000F0<0001d00<000000;j5U`2nQIL0
@`2nQIL00`000000Z7BI0:QdV@0R0:QdV@P0ZWbR00@0000009E^X`2EKZ<00000303f/7L00`000000
m[1f0?J`MP030?J`MP030000003f/7L0m[1g00P0m[1g00<0000009Qg[02HMj`02`2HMj`00`000000
NFZf07UZ]P0G07UZ]P040000003h[g40n:ma000001D0@Dji00<000000<NN[P37WZh04P37WZh70<VT
/a@0djV]0`3E[[400`000000Who309n?``0509n?``030000003U[i`0iJnL0140iJnL00<0jK6F0>^d
V@3[]9T03`3[]9T40>ndT@X0lKRB0P3b^i<50?FiR0D0mk^8103h_HL30?VnQP80nl2400<0nkYh0?^j
MP3k^WH00P3l^W@20?bkL@80oKY^0P3m^VX00`3m^FH0oKiQ0?fnH@030?bkF@80n[MA0P3h/dP30>^Y
:`030<f?00000000oooo08`0oooo000_0?ooo`030000002?H9L0Sf2G00<0Sf2G00@000000?biKP3l
^Fh0o;U^1`3l^g<50?^iM`L0nk]k0P3i^Gd60?VjP0H0n;Z30P3h^hD30?JhQ0D0m[R6103e^8P00`00
0000001H0000F0030000F0D0001d00<000000;j5U`2nQIL0@P2nQIL00`000000Z7BI0:QdV@0L0:Qd
V@h0ZWbR00@0000009E^X`2EKZ<00000303f/7L00`000000m[1f0?J`MP030?J`MP030000003f/7L0
m[1g00P0m[1g00<0000009Qg[02HMj`02@2HMj`209]o]0030000001iJ[H0NFZf01L0NFZf00@00000
0?R_L@3h[g4000005@11C[T00`000000aij^0<NN[P0?0<NN[PX0bJBc4P3CZJd50=F^/@030000002O
Sl<0Who300H0Who300<000000>F_W03U[i`03`3U[i`00`3W]9l0jkBI0>^dV@0@0>^dV@<0kkBA2`3a
^9830?:kT`@0mKV81@3g^hP40?RmQ`<0nKj60`3k`8@20?^jMP<0o;Yd00D0o;]a0?fjKP3m^Vh0oKY^
0?fjJP020?k0J080oKiQ0P3l^eT30?ZgD@040?RcB03`/CP0jjT[0>^Y:`80cHl0S@3oool002l0oooo
00<0000008mPU`2?H9L00`2?H9L00`000000o;U^0?biKP020?biKPH0o;]c1@3k^GL60?^kN`<0nKUm
1`3i^X060?RjP`030?RkQ@3f^8@0m[R40080m[R4103f^8H40?FhR00300007@0005P0001H00<0001H
1@0007@00`000000_XFG0;j5U`120;j5U`030000002XM9T0Z7BI01H0Z7BI502ZO:8010000000UFjS
09E^X`00000<0?J`M`030000003f/7H0m[1f00<0m[1f00<000000?J`M`3f/7L0203f/7L00`000000
V7N/09Qg[00609Qg[0D0Vgnd00<0000007UZ]P1iJ[H05P1iJ[H00`1lM;h000000?R_L@020?R_L@03
00000011C[T0@Dji0180@Dji00<000000<NN[P37WZh03@37WZh=0<VT/`l0djV]1`3E[[400`000000
Who309n?``0609n?``030000003U[i`0iJnL00h0iJnL0`3W]9lB0>^dV@030>ndT@3a^980lKRB00T0
lKRB103b^i<30?FiR0H0mk^80`3h_HL40?VnQP<0nl240P3l`H830?bjM080o;]a0P3m^Vh00`3m^VX0
o/1X0?k0J0020?fnH@<0o;]I0P3j]e401P3h/dP0l;4h0>^Y:`3[ZB/0ei`A0<f?08d0oooo000_0?oo
o`030000002?H9L0Sf2G00<0Sf2G00<000000?biKP3l^Fh00P3l^Fh50?bkL`L0nkUg1@3k^g/40?Vi
O@L0nKZ01@3h^X<50?JhQ0@0m[R60`3e^8P00`000000000M0000F0030000F0H0001d00<000000;j5
U`2nQIL0@P2nQIL00`000000Z7BI0:QdV@0A0:QdVAX0ZWbR00<0000009E^X`0000003@3f/7L00`00
0000m[1f0?J`MP020?J`MP030000003f/7L0m[1g00T0m[1g00<0000009Qg[02HMj`00P2HMj`909]o
]0030000001iJ[H0NFZf0180NFZf101lM;h01@000000n:ma0?R_L@3h[g40000001D0@Dji00<00000
0<NN[P37WZh02@37WZh@0<VT/`h0djV]2@3E[[400`000000Who309n?``0609n?``030000003U[i`0
iJnL00`0iJnL103W]9lB0>^dV@/0lKRB1P3b^i<20?FiR0D0mk^8103h_HL40?VnQP<0nl240P3l`H83
0?g2OP80o;]a00D0oKY^0?k2M@3n`Vl0o/9_0?k0J0020?fnH@<0o;]I0`3j]e420?2a>0030>^Y:`3G
W140cHl008d0oooo000_0?ooo`030000002?H9L0Sf2G00<0Sf2G00<000000?biKP3l^Fh00`3l^Fh4
0?bkL`P0nkUg103k^g/50?ViO@H0nKZ01@3h^X<00`3g]h80m[R40?JhQ0030?JhQ0@0m[R60P3e^8P0
0`000000000M0000F0030000F0H0001d00<000000;j5U`2nQIL0@P2nQIL00`000000Z7BI0:QdV@0;
0:QdVB00ZWbR00@0000009E^X`2EKZ<00000303f/7L00`000000m[1f0?J`MP020?J`MP030000003f
/7L0m[1g00T0m[1g00<0000009Qg[02KOk@02`2KOk@00`000000NFZf07UZ]P0?07UZ]PP0O7Bn00@0
00000?R_L@3h[g4000005@11C[T00`000000aij^0<NN[P070<NN[Q<0bJBc2`3CZJd;0=F^/@030000
002OSl<0Who300H0Who300<000000>F_W03U[i`02`3U[i`60>NdWa40jkBI00<0kKRJ0?6hTP3a^980
203a^9860?:kT`80mKV81@3g^hP40?RmQ`@0nKj60`3k`8@20?c1PP<0oL9n0P3n`gX20?k2M@80o/9_
0P3n`6P20?fnH@80o;]I0`3j]e420?2a>0040>^Y:`3GW140cHl0000008`0oooo000_0?ooo`030000
002?H9L0Sf2G00<0Sf2G00<000000?biKP3l^Fh0103l^Fh30?bkL`T0nkUg0`3k^g/50?ViO@L0nKZ0
0`3h^X<20?NgPPD0m[R4103f^8H20?FhR0030000000001d0001H0080001H1`0007@00`000000_XFG
0;j5U`120;j5U`030000002XM9T0Z7BI00D0Z7BI9P2ZO:8010000000UFjS09E^X`00000<0?J`M`03
0000003f/7H0m[1f00<0m[1f00<000000?J`M`3f/7L0203f/7L00`000000Vgnd09]o]00;09]o]003
0000001iJ[H0NFZf00`0NFZf2`1lM;h01@000000n:ma0?R_L@3h[g40000001@0@Dji00<000000<NN
[P37WZh01037WZhF0<VT/`T0djV]3P3E[[400`000000Who309n?``0509n?``030000003U[i`0iJnL
00T0iJnL203W]9l@0>^dV@80kKRJ2@3a^9880?:kT`H0mk^8103h_HL40?VnQP<0nl240P3l`H830?g2
OP80o/=j0P3n`WD20?k2K`80o/1X0P3m_V430?bkF@80n[MA0P3`/CP20>^Y:`030<f?00000000oooo
08/0oooo000_0?ooo`030000002?H9L0Sf2G00<0Sf2G00<000000?biKP3l^Fh01@3l^Fh20?bkL`T0
nkUg0`3k^g/60?ViO@H0nKZ00P3h^X<40?NgPP@0m[R4103f^8H20?FhR0030000000001d0001H0080
001H1`0007@00`000000_XFG0;j5U`120;j5U`030000002XM9T0Z7BI02/0ZWbR00@0000009E^X`2H
Mj`00000303f/7L00`000000m[1f0?J`MP030?J`MP030000003f/7L0m[1g00H0m[1g0P09jPX00`00
0000Vgnd09]o]00;09]o]0030000001iJ[H0NFZf00T0NFZf3P1lM;h01@000000n:ma0?R_L@3h[g40
000001D0@Dji00@000000<NN[P37WZh0aij^6@39Y;<70=>Y[@l0eJja00<0000009n?``2OSl<01P2O
Sl<00`000000iJnL0>F_W0070>F_W0X0ikBO3P3[]9T40>fhVPP0lKRB203b^i<60?NkR0@0n;f7103i
_XH30?_0Q080o<620`3m`Wh20?k3NP<0o/9e00<0o/9_0?k0J03n`6P00P3m_V430?bkF@80n[MA00H0
mKQ50?2a>03`/CP0jjT[0=NL4@00002<0?ooo`00<03oool00`000000Sf2G08mPU`0208mPU`030000
003l^Fh0o;U^00H0o;U^00<0o;]c0?^iM`3k^GL0203k^GL00`3k^g/0nKUm0?ViO@060?ViO@H0nKZ0
00<0n;Z30?NgPP3g]h800P3g]h850?JhQ0@0m[R600<0mKR800007@0001d00P0005P80000M0030000
002nQIL0_XFG0340_XFG4@2oRih00`000000ZWbR0:YlXP0Y0:YlXP80[8BY00@0000009Qg[02HMj`0
0000303f/7L00`000000m[1f0?J`MP030?J`MP030000003f/7L0m[1g00<0m[1g0`09jPX30?J`M`03
0000002KOk@0Vgnd00X0Vgnd00<0000007UZ]P1iJ[H01P1iJ[HB07ad_P050000003h[g40n:ma0?R_
L@0000005011C[T00`000000bJBc0<VT/`0J0<VT/`D0djV]4@3E[[400`000000Who309n?``0609n?
``030000003U[i`0iJnL00H0iJnL2`3W]9l=0>^dV@D0kKRJ1`3a^9890?:kT`030?BmT`3g^hP0mk^8
0080mk^81@3h_HL40?VnQP<0nl240P3l`H830?g2OP80o/=j0`3n`WD00`3n`Vl0o/1X0?k0J0020?fn
H@<0o;]I0P3j]e401P3e^4D0l;4h0?2a>03[ZB/0ei`A000008`0oooo000`0?ooo`030000002?H9L0
Sf2G0080Sf2G00<000000?biKP3l^Fh01`3l^Fh;0?^iM`T0nKUm1@3i^X060?NgPP@0m[R4103f^8H0
103e^8P0000M00007@0005P90000M0030000002nQIL0_XFG00h0_XFG=02oRih00`000000ZWbR0:Yl
XP0T0:YlXPL0[8BY00@0000009Qg[02HMj`000003@3f/7L00`000000m[1f0?J`MP020?J`MP030000
003f/7L0m[1g0080000000<02NX:0?J`M`3f/7L0103f/7L00`000000Vgnd09]o]00;09]o]0030000
001iJ[H0NFZf0080NFZf5@1lM;h01@000000n:ma0?R_L@3h[g4000000140@Dji0`13F<800`000000
bJBc0<VT/`0J0<VT/`<0djV]4`3E[[400`3H];D0000009n?``0609n?``030000003U[i`0iJnL00D0
iJnL3@3W]9l;0>^dV@L0kKRJ1P3a^9880?:kT`<0m;fC0`3g^hP50?RmQ`@0nKj60`3k`8@20?c1PP<0
oL9n0`3n`gX20?k2M@80o/9_0P3n`6P20?fnH@<0o;]I0P3e^4D20?2a>0030>^Y:`3GW140cHl008`0
oooo000`0?ooo`030000002?H9L0Sf2G0080Sf2G00<000000?biKP3l^Fh01`3l^Fh00`3k]g80nkUg
0?^iM`080?^iM`T0nKUm1@3i^X000`3g]h40mkN20?NgPP030?NgPPD0m[R40`3f^8H0103e^8P0000M
00007@0005P90000M0030000002oRih0_h^N04<0_h^N00<000000:YlXP2ZO:807`2ZO:8<0:b4Z@03
0000002HMj`0000000d0m[1g00<000000?J`MP3f/7H00`3f/7H010000000m[1g0000000000070?J`
M`030000002KOk@0Vgnd00/0Vgnd00<0000007UZ]P1lM;h05`1lM;h01@000000n:ma0?R_L@3h[g40
000000X0@Dji2`13F<800`000000bJBc0<VT/`0J0<VT/`030=>Y[@3E[[40eJja0140eJja0P3H];D0
0`000000Who309n?``0609n?``030000003U[i`0iJnL0080iJnL3`3W]9l:0>^dV@P0kKRJ1@3a^989
0?:kT`<0m;fC0`3g^hP50?RmQ`@0nKj60`3k`8@20?c1PP<0oL9n0`3n`gX20?k2M@80o/9_0P3n`6P2
0?fnH@<0o;]I0`3e^4D20?2a>0030=NL4@3=S`00oooo08/0oooo000`0?ooo`030000002?H9L0Sf2G
0080Sf2G00<000000?biKP3l^Fh01`3l^Fh20?^gLPT0nkUg00<0nKMj0?ViO@3i^Gd01`3i^Gd40?Vj
P080mkN11@3g]h840?JhQ0<0m[R600<0000000007@0001d02P0007@00`000000_h^N0;n;WP130;n;
WP030000002ZO:80ZWbR01/0ZWbR402/Q:T010000000V7N/09Qg[000000<0?J`M`030000003f/7H0
m[1f00<0m[1f00<000000?J`M`3f/7L0203f/7L00`000000Vgnd09]o]00909]o]080WXRk00<00000
07ad_P1lM;h0601lM;h01@000000n:ma0?R_L@3h[g4000000080@Dji4P13F<800`000000bJBc0<VT
/`0I0<VT/`030<b[^03E[[40eJja0140eJja0`3H];D00`000000Who309n?``0609n?``040000003U
[i`0iJnL0>F_W100ikBO2@3[]9T90>fhVPD0lKRB2@3b^i<40?BmT`80mk^81@3h_HL40?VnQP<0nl24
0P3l`H840?g2OP80o/=j0P3n`WD20?k2K`80o/1X0P3m_V430?bkF@<0mKQ50P3`/CP20=NL4@030000
003oool0oooo08T0oooo000`0?ooo`030000002?H9L0Sf2G0080Sf2G00<000000?biKP3l^Fh01`3l
^Fh30?^gLPP0nkUg0P3i]gX90?ViO@<0nKZ00P3g]h450?NgPPD0m[R40P3f^8H00`000000000M0000
7@090000M003018@R@000000_h^N04@0_h^N00<000000:YlXP2ZO:805P2ZO:8E0:b4Z@040000002H
Mj`0V7N/000000`0m[1g00<000000?J`MP3f/7H00`3f/7H00`000000m[1g0?J`M`080?J`M`030000
002KOk@0Vgnd00H0Vgnd1P2NR;/00`000000O7Bn07ad_P0G07ad_P050000003h[g40n:ma0?R_L@00
00005@13F<800`000000bJBc0<VT/`0F0<VT/`@0c:^h403E[[460=Rd]@030000002OSl<0Who300D0
Who300<000000>F_W03U[i`04P3W]9l70>^dV@/0kKRJ0`3a^9890?:kT`H0m;fC1P3h_HL30?VnQP@0
nl240P3l`H840?g2OP80o/=j0P3n`WD20?k2K`80o/1X0`3m_V420?bkF@<0mKQ50P3`/CP20=NL4@03
0000003oool0oooo08T0oooo000`0?ooo`030000002?H9L0Sf2G0080Sf2G00<000000?biKP3l^Fh0
1`3l^Fh40?^gLPL0nkUg0`3i]gX80?ViO@80nKZ0103g]h450?NgPP@0m[R40P3f^8H300007@P0001d
0P0B48T00`000000_h^N0;n;WP130;n;WP030000002ZO:80ZWbR0180ZWbR6@2/Q:T010000000V7N/
09Qg[000000=0?J`M`030000003f/7H0m[1f0080m[1f00<000000?J`M`3f/7L02@3f/7L00`000000
Vgnd09]o]00209]o]0T0WXRk00<0000007ad_P1lM;h05@1lM;h207ima`030000003h[g40n:ma0080
n:ma00<0000004=H`P13F<804P13F<800`000000bJBc0<VT/`0D0<VT/`H0c:^h3`3E[[470=Rd]@03
0000002OSl<0Who300H0Who300<000000>NdW`3W]9l04@3W]9l60>^dV@`0kKRJ0P3a^98:0?:kT`H0
m;fC1P3h_HL30?VnQP@0nl240P3l`H840?g2OP80o/=j0`3n`WD20?k2K`80o/1X0P3m_V420?bkF@08
0?VnDP3e^4D0mKQ50?FhA@3`/CP0hJTT0=NL4@00002;0?ooo`00<03oool00`000000Sf2G08mPU`02
08mPU`030000003l^Fh0o;U^00L0o;U^1@3k]g860?^iM`@0nKMj203i^Gd00`3i^X00mkN10?NgP@02
0?NgP@D0mkN2103f^8@20?JhQP80000M00<000100000M00007@01@0007@4018@R@030000002oRih0
_h^N0480_h^N00<000000:YlXP2ZO:803@2ZO:8N0:b4Z@040000002HMj`0V7N/000000d0m[1g00<0
00000?J`MP3f/7H00`3f/7H00`000000m[1g0?J`M`080?J`M`030000002KOk@0WXRk00/0WXRk00<0
000007ad_P1lM;h04P1lM;h607ima`050000003h[g40n:ma0?R_L@0000005013F<800`000000bJBc
0<VT/`0B0<VT/`T0c:^h3@3E[[480=Rd]@030000002OSl<0Who300@0Who30P2QUl/00`000000ikBO
0>NdW`0B0>NdW`@0jkBI3P3]^9X00`3a^980l[^C0?:kT`070?:kT`L0m;fC00<0m/2C0?RmQ`3h_HL0
0P3h_HL40?VnQP@0nl240P3l`H840?g2OP80o/=j0`3n`WD20?k2K`80o/1X0P3m_V420?bkF@080?Vn
DP3e^4D0mKQ50?FhA@3`/CP0hJTT0=NL4@00002;0?ooo`00<03oool00`000000Sf2G08mPU`0208mP
U`030000003l^Fh0o;U^00L0o;U^1P3k]g850?^iM`D0nKMj203i^Gd50?NgP@D0mkN2103f^8@0103f
^8H0000M00007@0004070000M0@04Q2900<000000;n;WP2oRih0@`2oRih00`000000ZWbR0:YlXP08
0:YlXR<0[8BY00<0000009Qg[00000003@3f/7L00`000000m[1f0?J`MP030?J`MP030000003f/7L0
m[1g00P0m[1g00<0000009j8^`2NR;/0302NR;/00`000000O7Bn07ad_P0=07ad_PX0OWg700D00000
0?R_L@3h[g40n:ma0000000E04=H`P0300000039Y;<0bJBc00l0bJBc2`3<ZkP;0=F^/@/0f;Be00<0
000009n?``2QUl/01P2QUl/00`000000ikBO0>NdW`0A0>NdW`<0jkBI3`3]^9X:0?:kT`L0m;fC0P3f
`9<30?RmQ`@0nKj6103k`8@20?c1PP@0oL9n0P3n`gX30?k2M@80o/9_0P3n`6P30?fnH@80nKiB0`3e
^4D0103`/CP0hJTT0=NL4@00002;0?ooo`00<03oool01`000000Sf2G08mPU`2?H9L0TfbR0000003l
]VP0203l^Fh70?^gLP@0nkUg1P3i]gX70?ViO@H0mkN1103g]h840?JhQ0040?JhQP0001d0000M0000
@0H0001d1@0B48T00`000000_h^N0;n;WP130;n;WP030000002ZO:80ZWbR00@0ZWbR9`2/Q:T00`00
0000Vgnd0000000=0?J`M`030000003f/7H0m[1f00<0m[1f00<000000?J`M`3f/7L02@3f/7L00`00
0000WXRk09j8^`0;09j8^`030000001lM;h0O7Bn00X0O7Bn3@1nOLL00`000000n:ma0?R_L@020?R_
L@0300000013F<80@eS20180@eS200<000000<VT/`39Y;<03@39Y;<>0<b[^0T0eJja303H];D00`00
0000XIO;0:6Gb`060:6Gb`030000003W]9l0ikBO0180ikBO00<0jkBI0>fhVP3]^9X03P3]^9X00`3_
_9`0l[^C0?:kT`060?:kT`L0m;fC103f`9<20?RmQ`@0nKj6103k`8@30?c1PP<0oL9n0P3n`gX30?k2
M@80o/9_0`3n`6P20?fnH@80nKiB103e^4D00`3`/CP0ei`A0=NL4@2;0?ooo`00<03oool00`000000
TfbR09=/XP0209=/XP030000003l]VP0o;IX00P0o;U^1`3k]g830?^iM`H0nKMj1`3i^Gd00`3g]Wh0
mkN10?NgP@030?NgP@D0mkN2103f^8@200007@030000@00007@0001d00<0001d1P0B48T00`000000
_h^N0;n;WP130;n;WP030000002ZO:80[8BY02T0[8BY0P2^Rk0010000000Vgnd09]o]000000<0?J`
M`030000003f/7H0m[1f00@0m[1f00<000000?J`M`3f/7L01@3f/7L20000000300WZ2P000000WXRk
00`0WXRk00<0000007ad_P1lM;h01`1lM;hA07ima`050000003h[g40n:ma0?R_L@0000005@13F<80
0`000000bJBc0<VT/`0:0<VT/a00c:^h203E[[4>0=Rd]@030000002QUl/0XIO;00H0XIO;00<00000
0>NdW`3W]9l04@3W]9l@0>fhVP<0kkbL1`3b^i<70?BmT`D0m/2C00<0n;f70?VnQP3i_XH00P3i_XH4
0?_0Q0<0o<620`3m`Wh30?k3NP80o/9e0P3n`Vl30?k0J080oKiQ0`3i_U830?FhA@030?2a>03QZB@0
ei`A08/0oooo000`0?ooo`030000002CK:80TfbR0080TfbR00@000000?bfJ03l]VP0o;IX1`3l^Fh8
0?^gLP80nkUg1`3i]gX60?ViO@80mkIn1@3g]h440?NgPP@0m[R400<0000M0000@0000400100007@7
018@R@030000002oRih0_h^N03l0_h^N1031TJ@00`000000[8BY0:b4Z@0U0:b4Z@H0[X^`00@00000
09]o]02KOk@000003@3f/7L00`000000m[1f0?J`MP030?J`MP030000003f/7L0m[1g00D0m[1g0P09
jPX00`3f/7L0000009j8^`0=09j8^`030000001lM;h0O7Bn0080O7Bn5@1nOLL01@000000n:ma0?R_
L@3h[g40000001D0@eS200<000000<VT/`39Y;<02039Y;<B0<b[^0L0eJja3`3H];D00`000000XIO;
0:6Gb`060:6Gb`030000003W]9l0ikBO0100ikBO0P3Y^:8>0>fhVP@0kkbL1`3b^i<70?BmT`H0m/2C
103i_XH40?_0Q0<0o<620`3m`Wh30?k3NP80o/9e0`3n`Vl20?k0J080oKiQ0`3i_U830?FhA@040?2a
>03QZB@0ei`A000008X0oooo000`0?ooo`030000002CK:80TfbR00<0TfbR00@000000?bfJ03l]VP0
o;IX1P3l^Fh90?^gLP030?^iM`3i]gX0nKMj00H0nKMj1@3i^Gd20?NfOPH0mkN1103g]h830?JhQ003
00007@000400001000<0001d200B48T00`000000_h^N0;n;WP0f0;n;WPd0`I6T00<000000:b4Z@2/
Q:T08@2/Q:T;0:j;/0030000002KOk@0000000d0m[1g00<000000?J`MP3f/7H00`3f/7H01@000000
m[1g0?J`M`3f/7L02NX:00L0m[1g00<0000009j8^`2NR;/02`2NR;/00`000000O7Bn07ima`0H07im
a`050000003h[g40n:ma0?R_L@0000005@13F<800`000000bJBc0<VT/`050<VT/aD0c:^h103E[[4@
0=Rd]@80fkZi00<000000:6Gb`2QUl/01P2QUl/00`000000ikBO0>NdW`0>0>NdW`<0jKRR3P3]^9X5
0>nlW0D0l[^C203d_I<60?K0T`040?S3T@3i_XH0nKj60?VnQP@0nl240`3l`H830?g2OP<0o/=j0`3n
`WD20?k2K`80o/1X0P3m_V400`3l`el0nKiB0?VnDP040?FhA@030>6Y903GW140000008X0oooo000`
0?ooo`030000002CK:80TfbR00<0TfbR00<000000?bfJ03l]VP00`3l]VP40?biKPX0nkMb2@3i]gX4
0?ViO@<0mkIn1@3g]h440?NgPP<0m[R400<0000M0000@00004000`0007@8018@R@030000002oRih0
_h^N02d0_h^N5`31TJ@00`000000[8BY0:b4Z@0L0:b4Z@l0[X^`00@0000009]o]02KOk@00000303f
/7L00`000000m[1f0?J`MP030?J`MP030000003f/7L0m[1g00T0m[1g00<0000009j8^`2NR;/02@2N
R;/20:2?``030000001nOLL0OWg701P0OWg700D000000?R_L@3h[g40n:ma0000000E04=H`P030000
0039Y;<0bJBc00<0bJBc5`3<ZkP30=F^/A00f;Be0`3K^[T00`000000XIO;0:6Gb`060:6Gb`030000
003W]9l0ikBO00d0ikBO1@3Y^:8<0>fhVPL0kkbL103b^i<70?BmT`L0m/2C0P3h`i420?VnQP@0nl24
0`3l`H830?g2OP<0o/=j0`3n`WD20?k2K`<0o/1X0P3l`el30?VnDP<0mKQ50P3QZB@00`000000oooo
0?ooo`280?ooo`00<@3oool00`000000TfbR09=/XP0209=/XP030000003l]VP0o;IX00@0o;IX0`3l
^Fh:0?^gLP030?VfM`3i]gX0nKMj00L0nKMj0P3i^Gd50?NfOPD0mkN1103g]h820?JhQ00300007@00
040000100080001d2@0B48T00`000000_h^N0;n;WP0U0;n;WQl0`I6T00<000000:b4Z@2/Q:T0602/
Q:TC0:j;/0040000002KOk@0Vgnd000000d0m[1g00<000000?J`MP3f/7H00`3f/7H00`000000m[1g
0?J`M`080?J`M`030000002NR;/0WXRk00H0WXRk1P2PSl<00`000000OWg707ima`0G07ima`050000
003h[g40n:ma0?R_L@0000005@13F<8010000000bJBc0<VT/`39Y;<J0<b[^0030=F^/@3H];D0f;Be
00h0f;Be103K^[T00`000000XIO;0:6Gb`070:6Gb`030000003W]9l0ikBO00/0ikBO1P3Y^:8<0>fh
VPL0kkbL0`3b^i<80?BmT`L0m/2C0`3h`i400`3i_XH0nl240?_0Q0020?_0Q0<0o<620`3m`Wh30?k3
NP<0o/9e0P3n`Vl30?k0J080o<=O0`3i_U830?FhA@80hJTT00<000000?ooo`3oool0R03oool00340
oooo00<0000009=/XP2CK:800P2CK:800`000000o;IX0?bfJ0050?bfJ080o;U^2P3k]g820?VfM`T0
nKMj00<0nKUm0?NfOP3g]Wh0103g]Wh50?NgP@<0mkN20P3f^8@0100001d000100000@00007@;018@
R@030000002oRih0_h^N01/0_h^N:031TJ@00`000000[8BY0:b4Z@0D0:b4ZAL0[X^`00@0000009]o
]02KOk@000003@3f/7L00`000000m[1f0?J`MP030?J`MP030000003f/7L0m[1g00T0m[1g00<00000
09j8^`2NR;/00P2NR;/90:2?``030000001nOLL0OWg701P0OWg700D000000?R_L@3h[g40n:ma0000
000E04=H`P030000003<ZkP0c:^h01T0c:^h00<0c[6m0=Rd]@3H];D03P3H];D60=^j^@030000002Q
Ul/0XIO;00H0XIO;00<000000>NdW`3W]9l02P3W]9l80>VhXPX0kKRJ2@3__9`20?:kT`P0m;fC1P3f
`9<50?S3T@@0nl240`3l`H830?g2OP<0o/=j0`3n`WD20?k2K`<0o/1X0P3l`el30?VnDP<0mKQ50P3Q
ZB@00`2iR000oooo0?ooo`280?ooo`00<@3oool00`000000TfbR09=/XP0209=/XP030000003l]VP0
o;IX00H0o;IX00<0o;U^0?^gLP3k]g80203k]g830?VfM`T0nKMj1P3g]Wh50?NgP@@0mkN200@0m[R4
0000@00004000010300B48T00`000000_h^N0;n;WP0C0;n;WS00`I6T00<000000:b4Z@2/Q:T0402/
Q:TL0:j;/0040000002KOk@0Vgnd000000`0m[1g00<000000?J`MP3f/7H00`3f/7H00`000000m[1g
0?J`M`090?J`M`030000002NR;/0X8o300/0X8o300<0000007ima`1nOLL05P1nOLL207n5c`050000
003h[g40n:ma0?R_L@0000005@11H</00`000000c:^h0<b[^00H0<b[^0<0c[6m3P3H];D70=^j^@03
0000002QUl/0XIO;00H0XIO;00<000000>NdW`3W]9l02@3W]9l90>VhXPT0kKRJ2`3__9`00`3b^i<0
m;fC0?BmT`060?BmT`H0m/2C1@3h`i420?[5S`80nl240`3l`H830?g2OP<0o/=j0`3n`WD30?k2K`80
o/1X0`3l`el20?VnDP<0mKQ50P3QZB@00`3GW140oooo0?ooo`280?ooo`00<@3oool00`000000TfbR
09=/XP0209=/XP030000003l]VP0o;IX00L0o;IX2P3k]g840?VfM`P0nKMj1`3g]Wh50?NgP@<0mkN2
00@0m;B30000@00004000010300B48T00`000000_h^N0;n;WP0:0;n;WST0`I6T00<000000:b4Z@2/
Q:T0302/Q:TP0:j;/0040000002KOk@0WXRk000000d0m[1g00<000000?J`MP3f/7H00`3f/7H00`00
0000m[1g0?J`M`080?J`M`030000002PSl<0X8o300`0X8o300<0000007ima`1nOLL0401nOLL807n5
c`050000003h[g40n:ma0?R_L@0000005@11H</00`000000c:^h0<b[^00E0<b[^0D0c[6m3@3H];D9
0=^j^@030000002QUl/0XIO;00H0XIO;00<000000>NdW`3W]9l01`3W]9l;0>VhXPP0kKRJ2`3__9`8
0?BmT`L0m/2C1@3h`i430?[5S`040?_0Q03l`H80o<620?c1PP@0oL9n0P3n`gX30?k2M@<0o/9_00<0
o/1X0?k7JP3l`el00P3l`el30?VnDP80mKQ500@0jkHg0>6Y903QZB@00000R@3oool00340oooo00<0
000009=/XP2CK:800`2CK:800`000000o;IX0?bfJ0060?bfJ080nkE^203k]g850?VfM`L0nKMj00<0
mkEl0?NfOP3g]Wh01@3g]Wh40?NgP@<0mkN200@0mKB20000@00004000010300B48T010000000_h^N
0;n;WP2oRii30<6AY0030000002/Q:T0[8BY00L0[8BY8P2^Rk020;6B]`040000002NR;/0WXRk0000
00d0m[1g00<000000?J`MP3f/7H00`3f/7H00`000000m[1g0?J`M`090?J`M`030000002PSl<0X8o3
00/0X8o300<0000007ima`1nOLL02`1nOLL=07n5c`050000003h[g40n:ma0?R_L@0000005@11H</0
0`000000c:^h0<b[^00D0<b[^0L0c[6m2P3H];D;0=^j^@030000002QUl/0XIO;00H0XIO;00<00000
0>NdW`3W]9l01P3W]9l<0>VhXPL0kKRJ303__9`00`3a_i`0m;fC0?BmT`050?BmT`L0m/2C1@3h`i44
0?[5S`<0o<62103m`Wh30?k3NP<0o/9e0P3n`Vl30?k7JP80o<=O0`3i_U820?FhA@040>^f=`3QZB@0
hJTT000008T0oooo000a0?ooo`030000002CK:80TfbR00<0TfbR00<000000?bfJ03l]VP01P3l]VP3
0?^eKPL0nkMb1P3i]WL60?VgNP80mkEl1P3g]Wh50?NgP@80mkN200D0mKB20000@000040000100000
G00;018@R@0300000031TJ@0`I6T04@0`I6T00<000000:b4Z@2/Q:T00`2/Q:TS0:j;/0H0/I:g00@0
000009j8^`2NR;/00000303f/7L00`000000m[1f0?J`MP030?J`MP030000003f/7L0m[1g00T0m[1g
00<000000:2?``2PSl<02`2PSl<00`000000OWg707ima`0607imaa80OhG?00D000000?R_L@3h[g40
n:ma0000000F045Pb`030000003<ZkP0c:^h0140c:^h2@3>/Kd90=Rd]@d0fkZi00<000000:6Gb`2Q
Ul/01P2QUl/00`000000ikBO0>NdW`040>NdW`h0jKRR1@3]^9X<0>nlW0<0lKnL1P3d_I<70?K0T`D0
n<>A103jaHl00`3lb8`0o<620?c1PP040?g2OP<0o/=j0`3n`WD20?k2K`<0o/MZ0P3l`el30?VnDP03
0?FhA@3[]SL0jkHg0080hJTT00<000000?ooo`3oool0Q`3oool00380oooo00<0000009=/XP2CK:80
0P2CK:800`000000o;IX0?bfJ0060?bfJ0@0nkE^1`3k]g860?VfM`D0nKMj0`3g]G`60?NfOPD0mkN1
0P3e]8820000@080001L2P0B48T00`0O99/000000<6AY0150<6AY0030000002/Q:T0[X^`02<0[X^`
2@2aT[L010000000WXRk09j8^`00000=0?J`M`030000003f/7H0m[1f00<0m[1f00<000000?J`M`3f
/7L0203f/7L00`000000X8o30:2?``0<0:2?``030000001nOLL0OWg701P0OhG?00D000000?R_L@3h
[g40n:ma0000000E045Pb`030000003<ZkP0c:^h0100c:^h2`3>/Kd70=Rd]@h0fkZi00<000000:6G
b`2QUl/01P2QUl/00`000000ikBO0>NdW`030>NdW`l0jKRR1@3]^9X<0>nlW0<0lKnL1P3d_I<60?K0
T`H0n<>A103jaHl20?c8S0030?c1PP3m`Wh0oL9n0080oL9n0`3n`gX30?k2M@030?k2K`3obG<0o/MZ
0080o/MZ0`3l`el20?VnDP030?FhA@3[]SL0jkHg0080hJTT00<000000?ooo`3oool0Q`3oool00380
oooo00<0000009=/XP2CK:800P2CK:800`000000o;IX0?bfJ0060?bfJ0D0nkE^1P3k]g870?VfM`@0
nKMj103g]G`60?NfOP@0mkN10P3e]8820000@080001L2@0B48T201lTV`0300000031TJ@0`I6T0480
`I6T0P32UjX00`000000[X^`0:j;/00P0:j;/0`0/I:g00@0000009j8^`2NR;/000003@3f/7L00`00
0000m[1f0?J`MP030?J`MP030000003f/7L0m[1g00T0m[1g00<000000:2?``2PSl<02@2PSl<20::G
bP030000001oQLl0OhG?01P0OhG?00D000000?R_L@3h[g40n:ma0000000E045Pb`030000003<ZkP0
c:^h00h0c:^h3@3>/Kd60=Rd]@l0fkZi00<0g/6l0000002QUl/01`2QUl/010000000ikBO0>NdW`3W
]9lA0>VhXP<0kKRJ303__9`50?6oW0@0m;fC1`3f`9<50?S3T@D0n/F?0`3lb8`40?g2OP<0o/=j0P3n
`WD0103obW`0olUc0?o9L`3obG<20?k7JP<0o<=O0`3i_U820>^f=`80hJTT00<000000?ooo`3oool0
Q`3oool00380oooo00<0000009=/XP2CK:800P2CK:800`000000o;IX0?bfJ0070?bfJ0H0nkE^103k
]g880?VfM`<0nKMj1@3g]G`60?NfOP030?NgP@09jPX02NX:00802NX:00@0mKB20000@00005`0001L
200B48T401lTV`0300000031TJ@0`I6T03`0`I6T1`32UjX00`000000[X^`0:j;/00M0:j;/100/I:g
00<0000009j8^`0000003@3f/7L00`000000m[1f0?J`MP040?J`MP030000003f/7L0m[1g00P0m[1g
00<000000:2?``2PSl<01P2PSl<60::GbP030000001oQLl0OhG?01P0OhG?00D000000?R_L@3h[g40
n:ma0000000E045Pb`030000003<ZkP0c:^h00/0c:^h403>/Kd40=Rd]@l0fkZi0P3N`K`00`000000
XIO;0:6Gb`060:6Gb`030000003W]9l0ikBO0180jKRR0`3]^9X<0>nlW0H0lKnL0`3d_I<70?K0T`D0
n<>A1@3jaHl30?c8S0<0oLV800@0oL9n0?k3NP3n`gX0o/Z30`3obW`30?o9L`80o/MZ0`3l`el30?Vn
DP<0jkHg00<0hJTT0000003oool0R03oool00380oooo00<0000009=/XP2CK:800P2CK:800`000000
o;IX0?bfJ0070?bfJ0L0nkE^0`3k]g890?VfM`80nKMj1P3g]G`30?NfOP<02NX:0P3g]h420?FdP@04
0?FdPP000400001L0000G0L04Q291@0O99/00`000000`I6T0<6AY00g0<6AY0d0`YNZ00<000000:j;
/02^Rk006@2^Rk0C0;6B]`030000002NR;/0000000h0m[1g00<000000?J`MP3f/7H00`3f/7H00`00
0000m[1g0?J`M`080?J`M`030000002PSl<0X8o300<0X8o32@2RUlX00`000000OhG?07n5c`0H07n5
c`050000003h[g40n:ma0?R_L@0000005@11H</00`000000c:^h0<b[^00:0<b[^140c[6m0`3H];D?
0=^j^@<0g/6l00<000000:6Gb`2QUl/01`2QUl/00`000000jKRR0>VhXP0B0>VhXP030>fhVP3__9`0
kkbL00X0kkbL1`3a_i`30?BmT`L0m/2C1@3h`i450?[5S`<0o<R<103mbHP30?k:P`<0olYl0`3obG<3
0?k7JP80o<=O0`3i_U830>^f=`030>6Y90000000oooo08P0oooo000b0?ooo`030000002CK:80TfbR
0080TfbR00<000000?bfJ03l]VP01`3l]VP80?^eKP80nkMb2P3i]WL00`3i]gX0mkEl0?NeO0040?Ne
O0030?NfOP09jPX02NX:00<0mkIn00H0mkN10?FdP@3e]840mKB10?FdPP0004020000G0H04Q291P0O
99/00`000000`I6T0<6AY00b0<6AY180`YNZ00<000000:j;/02^Rk005P2^Rk0F0;6B]`040000002N
R;/0WXRk000000d0m[1g00<000000?J`MP3f/7H00`3f/7H00`000000m[1g0?J`M`090?J`M`030000
002PSl<0XYO:00`0XYO:00<0000007n5c`1oQLl05`1oQLl01@000000n:ma0?R_L@3h[g40000001H0
@F3;00<000000<b[^03<ZkP01`3<ZkPD0<ja_@030=Rd]@3K^[T0fkZi00d0fkZi1@3N`K`00`000000
XIO;0:6Gb`050:6Gb`030:>PdP000000jKRR01<0jKRR3@3__9`80?6oW080m;fC1P3f`9<60?S3T@D0
n/F?0`3lb8`40?g9R0<0o/Z30`3obW`30?o9L`<0o/MZ0`3l`el20?VnDP<0jkHg00<0hJTT0000003o
ool0R03oool00380oooo00<0000009=/XP2CK:800`2CK:800`000000o;IX0?bfJ0060?bfJ0T0nkE^
00<0nkMb0?VfM`3i]WL02@3i]WL70?NeO0H0mkIn103e]8430000G0D04Q291`0O99/00`000000`I6T
0<6AY00]0<6AY1L0`YNZ00<000000:j;/02^Rk004`2^Rk0J0;6B]`030000002NR;/0000000h0m[1g
00<000000?J`MP3f/7H00`3f/7H00`000000m[1g0?J`M`080?J`M`030000002RUlX0XYO:00`0XYO:
00<0000007n5c`1oQLl0601oQLl01@000000n:ma0?R_L@3h[g40000001D0@F3;00<000000<b[^03<
ZkP01P3<ZkPD0<ja_@030=6h`P3K^[T0fkZi00d0fkZi1P3N`K`00`000000XIO;0:6Gb`020:6Gb`D0
Xj3B00<000000>VhXP3Y^:804@3Y^:800`3[_:<0kkbL0>nlW0090>nlW0X0lKnL1`3f`9<60?S3T@D0
n/F?0`3lb8`40?g9R0<0o/Z3103obW`20?o9L`<0o/MZ0`3l`el20?VnDP<0jkHg00<0hJTT0;V80000
0000R03oool00380oooo00<0000009=/XP2CK:800`2CK:800`000000o;IX0?bfJ0060?bfJ0X0nkE^
2`3i]WL200WZ2PH0mkEl1@3g]Wh40?FdP@@0001L0`0B48T801lTV`0300000031TJ@0`I6T02P0`I6T
7@32UjX00`000000[X^`0:j;/00?0:j;/1d0/I:g00<000000:2?``0000003P3f/7L00`000000m[1f
0?J`MP030?J`MP030000003f/7L0m[1g00T0m[1g00<000000::GbP2RUlX0302RUlX00`000000OhG?
07n5c`0C07n5c`@0OhgG00D000000?R_L@3h[g40n:ma0000000303eWdQ<0@F3;00<000000<b[^03<
ZkP00`3<ZkPE0<ja_@<0dKS23@3K^[T80=k1_0030000002SX=80Xj3B00H0Xj3B00<000000>VhXP3Y
^:80403Y^:820>^lX`/0kkbL2P3a_i`70?K0T`H0n<>A103jaHl40?c8S0@0oLV80`3nbX<40?o:O080
olUc0`3nafX30?c3G`80nKiB00H0ll190>^f=`3[]SL0hJTT0<VL2`0000280?ooo`00<`3oool00`00
0000TfbR09=/XP0209=/XP030000003l]VP0o;IX00H0o;IX2P3k]Fh20?VdM0T0nKIg0`3g]7X60?Ne
O0@0mkIn00@0mK>00?FdP@3e]840mKB1100005`2018@R@X07bBK00<000000<6AY031TJ@08P31TJ@R
0<:GZP030000002^Rk00[X^`00`0[X^`7`2aT[L01@2cVKd000000:2?``2PSl<0000000d0m[1g00<0
00000?J`MP3f/7H0103f/7H00`000000m[1g0?J`M`080?J`M`030000002RUlX0XYO:00`0XYO:00<0
000007n5c`1oQLl02P1oQLl>07n=e`050000003h[g40n:ma0?R_L@000000200mIm8=045Pb`030000
003<ZkP0c:^h0080c:^h5@3>/Kd50=6h`P/0fkZi2@3N`K`00`000000Xj3B0:>PdP070:>PdP030000
003Y^:80jKRR00h0jKRR103[_:<90>nlW0/0lKnL00<0ll>L0?K0T`3f`9<0103f`9<60?S3T@@0n/F?
103lb8`40?g9R0<0o/Z3103obW`30?o9L`80o/MZ0`3l`el00`3i_U80ll190??0B@030>^f=`030<VL
2`000000oooo08L0oooo000c0?ooo`070000002CK:80TfbR09=/XP2GMZ/000000?^bI0070?bfJ0X0
nkE^0`3i]7@80?VfM`@0mkAj1P3g]G`30?NfOP80mK>00P3e]8440000G003018@R@0O99/07bBK00T0
7bBK00<000000<6AY031TJ@07P31TJ@V0<:GZP030000002^Rk00[X^`00T0[X^`7`2aT[L50;>I_@03
0000002PSl<0000000h0m[1g00<000000?J`MP3f/7H00`3f/7H00`000000m[1g0?J`M`090?J`M`03
0000002RUlX0XYO:00`0XYO:00@0000007n5c`1oQLl0OhG?5P1oSML01@000000n:ma0?R_L@3h[g40
000000h0?FOB1`11H</00`000000c:^h0<b[^00E0<ja_@L0dKS22`3K^[T:0=k1_0030000002SX=80
Xj3B00H0Xj3B00<000000>VhXP3Y^:803@3Y^:860>^lX`P0kkbL2P3a_i`30??3W0@0m/2C1P3h`i45
0?[5S`@0o<R<103mbHP40?k:P`<0olYl0`3obG<20?k7JP@0o<=O0P3c`4T30>^f=`030<VL2`000000
oooo08L0oooo000c0?ooo`030000002GMZ/0UgJ[0080UgJ[00@000000?^bI03k/V@0nk9T1@3l]VP:
0?^eKP@0nKAd1`3i]WL50?NdNPH0mkEl00<0mkIn0?FcP03e/h000P3e/h000`3e]840001L0000G002
0000G0`07bBK00<000000<6AY031TJ@06@31TJ@[0<:GZP030000002^Rk00[X^`00H0[X^`7`2aT[L8
0;>I_@040000002PSl<0X8o3000000d0m[1g00<000000?J`MP3f/7H0103f/7H00`000000m[1g0?J`
M`080?J`M`030000002RUlX0XYO:00X0XYO:0P2TWm400`000000OhgG07n=e`0H07n=e`050000003h
[g40n:ma0?R_L@0000004`0mIm82045Pb`030000003>/Kd0c[6m01<0c[6m2@3A^<890=^j^@X0g/6l
00<0h/Rn0000002SX=80202SX=800`000000jKRR0>VhXP0<0>VhXPH0jkbS203__9`:0?6oW0<0ll>L
103f`9<60?S3T@D0n/F?103lb8`40?g9R0@0o/Z30`3obW`30?o9L`<0o/MZ0`3l`el20??0B@<0jkHg
00<0bI`;0000003oool0Q`3oool003<0oooo00<0000009MfZ`2GMZ/00`2GMZ/010000000nk9T0?^b
I03k/V@50?bfJ0T0nkE^1P3i]7@50?VfM`H0mkAj1P3g]G`50?FcP0@0001L300O99/00`000000`I6T
0<6AY00D0<6AY340`YNZ00<000000:j;/02^Rk000P2^Rk0O0;6B]`/0/iVm00@000000:2?``2PSl<0
00003P3f/7L00`000000m[1f0?J`MP030?J`MP030000003f/7L0m[1g00T0m[1g00<000000::GbP2R
UlX01P2RUlX60:BOd@030000001oSML0OhgG01P0OhgG00D000000?R_L@3h[g40n:ma0000000D03eW
dP030000003>/Kd0c[6m0180c[6m2P3A^<880=^j^@/0g/6l0P3Rb;h00`000000Xj3B0:>PdP060:>P
dP030000003Y^:80jKRR00/0jKRR203[_:<60>nlW0/0lKnL103c`i`30?K0T`H0n<>A1@3jaHl40?c8
S0@0oLV8103nbX<30?o:O0<0olUc0`3nafX30?c3G`80ll190`3[]SL00`39W0/000000?ooo`270?oo
o`00<`3oool00`000000UgJ[09MfZ`0309MfZ`030000003k/V@0nk9T00<0nk9T0`3l]VP90?^eKPL0
nKAd103i]WL80?NdNP@0mkEl1@3e/h030000G080001b2`0O99/00`000000`I6T0<6AY00?0<6AY3H0
`YNZ00<000000:j;/02aT[L07P2aT[L?0;>I_@040000002PSl<0X8o3000000d0m[1g00<000000?J`
MP3f/7H00`3f/7H00`000000m[1g0?J`M`090?J`M`030000002RUlX0XYO:00<0XYO:2@2TWm400`00
0000OhgG07n=e`0H07n=e`050000003h[g40n:ma0?R_L@0000005@0mIm800`000000c[6m0<ja_@0@
0<ja_@`0dKS21P3K^[T;0=k1_0<0h/Rn00<000000:>PdP2SX=801`2SX=800`000000jKRR0>VhXP09
0>VhXPT0jkbS1P3__9`:0?6oW0D0ll>L0`3f`9<60?S3T@D0n/F?103lb8`40?g9R0@0o/Z30`3obW`3
0?o9L`<0o/MZ0`3l`el20??0B@<0jkHg00<0bI`;0000003oool0Q`3oool003<0oooo00<0000009Mf
Z`2GMZ/00`2GMZ/00`000000nk9T0?^bI0050?^bI0030?bfJ03k]Fh0nkE^00L0nkE^2@3i]7@20?Vf
M`T0mkAj0`3g]G`00`3e/gl0mK>00?FcP0030?FcP080001L0P00078<01lTV`0300000031TJ@0`I6T
00T0`I6T>@32UjX20<BL/0030000002aT[L0/I:g01/0/I:g4P2cVKd010000000X8o30:2?``00000>
0?J`M`030000003f/7H0m[1f00<0m[1f00<000000?J`M`3f/7L02@3f/7L00`000000XYO:0:BOd@0<
0:BOd@030000001oSML0OhgG01P0OhgG00D000000?R_L@3h[g40n:ma0000000D03eWdP030000003>
/Kd0c[6m00h0c[6m3`3A^<840=^j^@/0g/6l1@3Rb;h00`000000Xj3B0:>PdP060:>PdP030000003Y
^:80jKRR00P0jKRR2`3[_:<40>nlW0/0lKnL1P3c`i`20?K0T`H0n<>A1@3jaHl40?c8S0@0oLV8103n
bX<30?o:O0<0olUc0`3nafX30?c3G`<0ll190P3[]SL00`39W0/000000?ooo`270?ooo`00=03oool0
0`000000UgJ[09MfZ`0209MfZ`030000003k/V@0nk9T00H0nk9T2P3k]Fh90?VdM0030?VfM`3g]7X0
mkAj00P0mkAj0P3g]G`20?FcO`@0mK>00P0005`20000LP`07bBK00<000000<6AY031TJ@01031TJ@k
0<:GZPD0a9b`00<000000;6B]`2aT[L0602aT[LE0;>I_@050000002PSl<0X8o30:2?``0000003@3f
/7L00`000000m[1f0?J`MP030?J`MP030000003f/7L0m[1g00T0m[1g00<000000:BOd@2TWm40302T
Wm400`000000OhgG07n=e`0H07n=e`050000003h[g40n:ma0?R_L@0000005@0mIm800`000000c[6m
0<ja_@0<0<ja_A00dKS20`3K^[T<0=k1_0D0h/Rn00<000000:>PdP2SX=801P2SX=800`000000jKRR
0>VhXP070>VhXPd0jkbS0`3__9`;0?6oW0L0ll>L1`3h`i450?[5S`@0o<R<103mbHP40?k:P`@0olYl
0`3obG<20?k7JP80o<=O0P3ib5/20??0B@80jkHg00<0bI`;0000003oool0Q`3oool003@0oooo00<0
000009MfZ`2GMZ/00P2GMZ/00`000000nk9T0?^bI0060?^bI080n[=[203k]Fh:0?VdM0/0mkAj00@0
mkEl0?FcO`3e/gl0mK=o0`3e/h00100005`0001b0000LP00078<01lTV`0300000031TJ@0`YNZ03/0
`YNZ2P34W;000`000000/I:g0;6B]`0D0;6B]aT0/iVm00@000000:2?``2RUlX000003@3f/7L00`00
0000m[1f0?J`MP040?J`MP030000003f/7L0m[1g00T0m[1g00<000000:BOd@2TWm40302TWm400`00
0000OhgG07n=e`0H07n=e`050000003h[g40n:ma0?R_L@000000500mIm800`000000c[6m0<ja_@0;
0<ja_A80dKS200<0fkZi0=k1_03N`K`02P3N`K`70>;8_P030000002SX=80Xj3B00H0Xj3B00<00000
0>VhXP3Y^:801P3Y^:8=0>^lX`80kkbL2`3a_i`80??3W080m/NK1@3h`i450?[5S`@0o<R<103mbHP4
0?k:P`@0olYl0`3obG<30?k7JP030?c3G`3ib5/0nLQK0080ll190P3[]SL00`39W0/000000?ooo`27
0?ooo`00=03oool00`000000UgJ[09MfZ`0309MfZ`030000003k/V@0nk9T00D0nk9T103j/f/60?^e
KPX0nKAd0P3g/gP:0?NdNP@0mK=o00<0mK>000WZ2P0005`01000078:01lTV`0302LcZ0000000`YNZ
03T0`YNZ3@34W;000`000000/I:g0;6B]`0B0;6B]aX0/iVm00<0]J740000002RUlX00P2RUlX00`00
0000m[1g0?J`M`0;0?J`M`030000003f/7H0m[1f00<0m[1f00<000000?J`M`3f/7L02@3f/7L00`00
0000Y9oA0:BOd@0<0:BOd@030000001oSML0OhgG0180OhgG1P1nU^001@000000n:ma0?R_L@3h[g40
00000080=FcI4`0mIm800`000000c[6m0<ja_@080<ja_A<0dKS200<0e<360=k1_03N`K`02P3N`K`8
0>;8_P030000002SX=80Xj3B00H0Xj3B00<000000>VhXP3Y^:801@3Y^:8?0>^lX`030>nlW03a_i`0
lKnL00T0lKnL203c`i`30?K7V`@0n<>A1@3jaHl40?c8S0D0oLV80`3nbX<40?o:O0<0olUc0`3nafX0
0`3l`el0nLQK0?W8F`020??0B@80jkHg00<0bI`;0000003oool0Q`3oool003@0oooo00<0000009Mf
Z`2GMZ/00`2GMZ/00`000000nk9T0?^bI0050?^bI0H0n[=[103k]Fh:0?VdM0@0mk=h203g]7X00`09
jPX0mK9n0?FcO`020?FcO`030?FcP00005`0001b00<0001b2@0O99/202LcZ00300000032UjX0`YNZ
03@0`YNZ4@34W;000`000000/I:g0;6B]`0?0;6B]aX0/iVm1@2eXL@010000000XYO:0::GbP00000=
0?J`M`030000003f/7H0m[1f00@0m[1f00<000000?J`M`3f/7L02@3f/7L00`000000Y9oA0:BOd@0<
0:BOd@030000001oSML0OhgG00@0OhgG501nU^001@000000n:ma0?R_L@3h[g40000000@0=FcI400m
Im800`000000c[6m0<ja_@070<ja_A<0dKS20`3D`<H:0=k1_0X0h/Rn00<000000:>PdP2SX=801P2S
X=800`000000jKRR0>VhXP030>VhXQ00jkbS2`3a_i`90??3W0@0m/NK0P3h`i460?[5S`@0o<R<1@3m
bHP30?k:P`@0olYl0`3obG<30?k7JP<0nLQK0P3c`4T0103[]SL0fJhU0<VL2`0000280?ooo`00<P3o
ool200WZ2P030000002GMZ/0UgJ[00<0UgJ[00<000000?^bI03k/V@01P3k/V@70?ZcJ`80nkE^2P3i
]7@50?NcN0L0mkAj0`3e/Wh30?FcO`D0001b1`0O99/502LcZ00300000032UjX0`YNZ0300`YNZ5@34
W;000`000000/I:g0;6B]`0;0;6B]aX0/iVm202eXL@010000000XYO:0::GbP00000=0?J`M`030000
003f/7H0m[1f00@0m[1f00<000000?J`M`3f/7L02@3f/7L00`000000Y9oA0:BOd@0:0:BOd@80YJSI
00<0000007jFh01nU^006@1nU^0010000000n:ma0?R_L@00000803E/f@d0?FOB00<000000<ja_@3>
/Kd01@3>/KdC0=6h`PD0e<362@3N`K`90>;8_P030>K?`0000000Xj3B00L0Xj3B00<000000>VhXP3Y
^:800P3Y^:8A0>^lX`030>k1Y03a_i`0lKnL00P0lKnL203c`i`60?K7V`030?S3T@3jaHl0n/F?00@0
n/F?103lb8`50?g9R0<0o/Z3103obW`30?o9L`<0o/MZ0`3ib5/20??0B@040>^f=`3I[RD0bI`;0000
08P0oooo000_0?ooo`<02NX:0P3oool00`000000UgJ[09MfZ`0309MfZ`030000003k/V@0nk9T00H0
nk9T2@3j/f/:0?VdM0L0mk=h1@3g]7X40?FbOP80mK=o1@00078601lTV`H09c>X00<000000<:GZP32
UjX0;032UjXI0<BL/0030000002aT[L0/I:g00P0/I:g6`2cVKd;0;FQa0040000002RUlX0XYO:0000
00d0m[1g00<000000?J`MP3f/7H0103f/7H00`000000m[1g0?J`M`090?J`M`030000002TWm40Y9oA
00H0Y9oA1P2UZ=T00`000000OYKP07jFh00H07jFh0050000003h[g40n:ma0?R_L@0000002`0eK=T9
03eWdP030000003>/Kd0c[6m00@0c[6m4`3A^<870=C0aPL0g/6l2P3Rb;h20>K?`0030000002SX=80
Xj3B00H0Xj3B00@000000>VhXP3Y^:80jKRR403[_:<30>k1Y0T0lKnL203c`i`70?K7V`H0n/F?103l
b8`50?g9R0<0o/Z3103obW`30?o9L`<0o/MZ0`3ib5/30??0B@80fJhU00<000000?ooo`3oool0QP3o
ool002`0oooo0`09jPX50?ooo`030000002GMZ/0UgJ[00<0UgJ[00<000000?^bI03k/V@01P3k/V@9
0?ZcJ`80nK9a2@3i]7@80?NcN0<0mkAj1@3e/Wh00`3e/gl0000T0000LP030000LPD07bBK1`0W<jP0
0`000000`YNZ0<:GZP0Y0<:GZQ`0a9b`00<000000;6B]`2aT[L01@2aT[LK0;>I_@l0]J7400<00000
0::GbP0000003@3f/7L00`000000m[1f0?J`MP040?J`MP030000003f/7L0m[1g00T0m[1g00<00000
0:BOd@2TWm400`2TWm4:0:FXf@030000001nU^00OYKP01P0OYKP00D000000?R_L@3h[g40n:ma0000
000=03E/f@L0?FOB00@000000<ja_@3>/Kd0c[6m503A^<880=C0aPH0g/6l2P3Rb;h30>K?`0030000
002SX=80Xj3B00H0Xj3B00<000000>VhXP3Y^:804@3[_:<30>k1Y0P0lKnL2@3c`i`70?K7V`030?S:
V@3jaHl0n/F?0080n/F?1@3lb8`50?g9R0<0o/Z3103obW`40?o9L`030?k7JP3mcF/0nLQK0080nLQK
0`3c`4T20=V^9@030000003oool0oooo08H0oooo000Y0?ooo`<02NX:2@3oool00`000000UgJ[09Mf
Z`0309MfZ`030000003k/V@0nk9T00D0nk9T2@3j/f/40?VbL@L0nKAd2@3g/gP20?NdNPH0mK9n00<0
mK=o0000LP0007800`00078201lTV`T09c>X00<000000<:GZP32UjX09@32UjXQ0<BL/0040000002a
T[L0/I:g0;6B]a`0/iVm4@2eXL@00`000000XYO:0000000=0?J`M`030000003f/7H0m[1f00D0m[1f
00<000000?J`M`3f/7L02@3f/7L00`000000Y9oA0:FXf@0<0:FXf@030000001nU^00OYKP01P0OYKP
00D000000?R_L@3h[g40n:ma0000000A03E/f@<0?FOB00<000000<ja_@3>/Kd0503A^<8:0=C0aPD0
g/6l2@3Rb;h50>K?`0030000002SX=80Xj3B00H0Xj3B00<000000>^lX`3[_:<03`3[_:<50>k1Y0L0
lKnL203c`i`80?K7V`80n<ZI0`3jaHl50?c8S0D0oLV80`3nbX<40?o:O0@0olUc00<0o/MZ0?g=J`3i
b5/00`3ib5/20??0B@80fJhU00<000000?ooo`3oool0QP3oool002L0oooo0P09jPX<0?ooo`030000
002GMZ/0UgJ[00<0UgJ[00<000000?^bI03k/V@01@3k/V@:0?ZcJ`H0nK9a103i]7@;0?NcN0L0mK9n
1@0007800`0O99/09c>X02LcZ00902LcZ00300000032UjX0`YNZ0200`YNZ9@34W;000`000000/iVm
0;>I_@0J0;>I_AD0]J7400<000000::GbP0000003@3f/7L00`000000m[1f0?J`MP050?J`MP030000
003f/7L0m[1g00P0m[1g00<000000:FXf@2UZ=T03@2UZ=T00`000000OYKP07jFh00H07jFh0050000
003h[g40n:ma0?R_L@0000004`0eK=T00`0mIm8000000=6h`P0C0=6h`P`0e<360`3N`K`90>;8_PH0
i/o000<000000:>PdP2SX=80102SX=820:BYfP030000003[_:<0jkbS00l0jkbS1P3^`J@50?6oW0T0
ll>L203fai/30?S:V@80n/F?1@3lb8`50?g9R0@0o/Z3103obW`30?o9L`030?k7JP3mcF/0oLe[00<0
nLQK0P3c`4T20=V^9@030000003oool0oooo08H0oooo000T0?ooo`<02NX:3P3oool00`000000UgJ[
09MfZ`0309MfZ`030000003k/V@0nk9T00H0nk9T2@3j/f/80?VbL@80nKAd2`3g/gP20?FaO@D0mK9n
1@00078<02LcZ00300000032UjX0`YNZ01d0`YNZ9`34W;000`36X[D000000;>I_@0H0;>I_AL0]J74
00@0]jS:0000002TWm4000003P3f/7L00`000000m[1f0?J`MP040?J`MP030000003f/7L0m[1g00T0
m[1g00<000000:FXf@2UZ=T03@2UZ=T00`000000OYKP07jFh00H07jFh0040000003h[g40n:ma0000
01@0=FcI00<000000=6h`P3A^<804@3A^<8>0=C0aP030=k1_03Rb;h0h/Rn00P0h/Rn1`3Vcl000`00
0000Xj3B0:BYfP060:BYfP030000003[_:<0jkbS00d0jkbS1`3^`J@50?6oW0T0ll>L1`3fai/50?S:
V@030?[5S`3lb8`0o<R<00<0o<R<1@3mbHP40?k:P`@0olYl0`3obG<30?g=J`<0nLQK0P3c`4T20=V^
9@030000003oool0oooo08H0oooo000Q0?ooo`<02NX:4@3oool00`000000UgJ[09MfZ`0309MfZ`03
0000003k/V@0nk9T00H0nk9T2@3j/f/:0?VbL@/0mk=h0`3e/Gd40?FbOPD0001b300W<jP00`000000
`YNZ0<:GZP0I0<:GZRP0a9b`1@36X[D00`000000/iVm0;>I_@0D0;>I_AL0]J74102gZ<X00`000000
Y9oA0000000>0?J`M`030000003f/7H0m[1f00@0m[1f00<000000?J`M`3f/7L02@3f/7L00`000000
YJSI0:FXf@0:0:FXf@80Y[7P00<0000007ZNj01jW^P0601jW^P01@000000n:ma0?R_L@3h[g400000
01@0=FcI00<000000=6h`P3A^<803`3A^<8?0=C0aPX0h/Rn203Vcl000`000000Y:WJ0:BYfP070:BY
fP030000003[_:<0jkbS00/0jkbS2@3^`J@40?6oW0T0ll>L1`3fai/60?S:V@D0o<R<1@3mbHP40?k:
P`@0olYl0P3obG<0103odGP0oLe[0?g=J`3mcF/30?W8F`80ll190P3I[RD00`000000oooo0?ooo`26
0?ooo`007P3oool300WZ2Q@0oooo00<0000009MfZ`2GMZ/00`2GMZ/00`000000nk9T0?^bI0060?^b
I0T0n[=[2P3i/W430?NbM`P0mk=h1@3e/Gd20?FbOP04000090000780001b0000LP8000232`0W<jP0
0`000000`YNZ0<:GZP0F0<:GZRP0a9b`2036X[D00`000000/iVm0;>I_@0A0;>I_AL0]J741`2gZ<X0
0`000000Y9oA0000000>0?J`M`030000003f/7H0m[1f00D0m[1f00<000000?J`M`3f/7L0203f/7L0
0`000000YJSI0:FXf@070:FXf@H0Y[7P00<0000007ZNj01jW^P0601jW^P01@000000n:ma0?R_L@00
0000:6kN01<0=FcI00<000000=6h`P3A^<803@3A^<8A0=C0aP030=S8bP3Rb;h0h/Rn00H0h/Rn2@3V
cl000`3[el4000000:BYfP070:BYfP030000003[_:<0jkbS00/0jkbS2@3^`J@30?6oW0T0ll>L203f
ai/60?S:V@80nlfF0`3lb8`50?g9R0@0o/Z3103obW`00`3obG<0om5h0?oAN0030?g=J`<0nLQK0P3c
`4T20=V^9@030000003oool0oooo08H0oooo000K0?ooo`<02NX:5`3oool00`000000UgJ[09MfZ`04
09MfZ`030000003k/V@0nk9T00D0nk9T2P3j/f/90?VbL@H0mk9g1P3g/gP60?FaO@030?FbOP000780
001b00<00023300W<jP00`000000`YNZ0<:GZP0A0<:GZRX0a9b`2`36X[D00`000000/iVm0;>I_@0=
0;>I_AP0]J742P2gZ<X00`000000Y9oA0000000>0?J`M`030000003f/7H0m[1f00@0m[1f00<00000
0?J`M`3f/7L02@3f/7L00`000000YJSI0:FXf@030:FXf@X0Y[7P00<0000007ZNj01jW^P0601jW^P0
10000000n:ma0?R_L@00000302Q^gQ40=FcI00<000000=6h`P3A^<802`3A^<8A0=C0aP<0f<S:1`3R
b;h80>K?`0<0jmO100<000000:BYfP2TZMX01P2TZMX00`000000jkbS0>^lX`090>^lX`/0k/6T0P3a
_i`90??3W0P0m/NK1P3hbYT40?_=UP030?c8S03mbHP0oLV800<0oLV8103nbX<30?o:O0040?oBPP3o
dGP0om5h0?oAN0<0oLe[0`3ib5/20??0B@80fJhU00<000000?ooo`3oool0QP3oool001T0oooo0P09
jPXJ0?ooo`030000002GMZ/0UgJ[00@0UgJ[00<000000?^bI03k/V@01@3k/V@:0?ZcJ`X0nK9a203g
/WL30?NcN0L0mK5m00<0001b0000P`0008<00P0008<<02LcZ00300000032UjX0`YNZ00h0`YNZ:P34
W;0>0<JR]@030000002cVKd0/iVm00/0/iVm602eXL@<0;NXbP040000002TWm40Y9oA000000h0m[1g
00<000000?J`MP3f/7H0103f/7H00`000000m[1g0?J`M`090?J`M`030000002UZ=T0Y[7P00`0Y[7P
00<0000007ZNj01jW^P06@1jW^P010000000n:ma0?R_L@00000502Q^gPl0=FcI00<000000=6h`P3A
^<802@3A^<8A0=C0aPD0f<S:1@3Rb;h80>K?`0@0jmO100<000000:BYfP2TZMX01P2TZMX00`000000
jkbS0>^lX`090>^lX``0k/6T00<0lKnL0??3W03c`i`01`3c`i`80?K7V`H0n<ZI1@3kcIH50?g9R0@0
o/Z300@0olYl0?oBPP3odX80om:20`3odGP30?g=J`<0nLQK0P3c`4T00`3W_Sh0fJhU000000280?oo
o`005P3oool300WZ2Qd0oooo00<0000009MfZ`2GMZ/00`2GMZ/00`000000nk9T0?^bI0060?^bI0T0
n[=[2P3i/W4;0?NbM`L0mK5m1@0008<<02LcZ00300000032UjX0`YNZ00X0`YNZ;034W;0@0<JR]@03
0000002cVKd0/iVm00P0/iVm6@2eXL@?0;NXbP030000002TWm40000000h0m[1g00<000000?J`MP3f
/7H01@3f/7H00`000000m[1g0?J`M`080?J`M`030000002V/N00Y[7P00d0Y[7P00<0000007ZNj01j
W^P0601jW^P01@000000n:ma0?R_L@3h[g40000000H0:6kN3@0eK=T00`000000dKS20=6h`P080=6h
`Q40e<361P3Hb<X40>;8_PT0i/o01@3[el400`000000Y:WJ0:BYfP060:BYfP030000003[_:<0jkbS
00L0jkbS3@3^`J@:0??3W0L0m/NK1`3hbYT50?_=UP@0oM2A00<0oLV80?k:P`3nbX<00P3odH/40?oB
PP<0om5h0`3mcF/40?W8F`80ikhn00<0fJhU0000003oool0Q`3oool001<0oooo0`09jPXP0?ooo`03
0000002GMZ/0UgJ[0080UgJ[00@0VWjd0000003j[f00nZmP1P3k/V@90?ZcJ`X0nK9a2`3g/WL20?Fa
O0D0mK5m1P0008<;02LcZ00300000032UjX0`YNZ00L0`YNZ;034W;0D0<JR]@030000002cVKd0/iVm
00D0/iVm6@2eXL@A0;NXbP040000002TWm40Y9oA000000h0m[1g00<000000?J`MP3f/7H01@3f/7H0
0`000000m[1g0?J`M`080?J`M`030000002V/N00Y[7P00d0Y[7P00<0000007ZNj01jW^P0601jW^P0
10000000n:ma0?R_L@00000902Q^gP/0=FcI00<000000=6h`P3A^<801P3A^<8A0=C0aPP0f<S:0`3R
b;h80>K?`0H0jmO100<000000:BYfP2TZMX01`2TZMX00`000000jkbS0>^lX`060>^lX`d0k/6T00<0
l<FU0??3W03c`i`01P3c`i`80?K7V`L0n<ZI1@3kcIH50?g@T@@0om6;103odX840?oAN0<0oLe[0`3i
b5/20>Nn?P030=V^9@000000oooo08L0oooo000@0?ooo`<02NX:8`3oool00`000000UgJ[09Yn]003
09Yn]0030000003j[f00nZmP00D0nZmP00<0nk9T0?ZcJ`3j/f/01`3j/f/:0?VbL@/0mk9g1@3e/G`3
0?FaO@D00023300W<jP00`000000`YNZ0<:GZP020<:GZRd0a9b`5`36X[D00`000000/iVm0;>I_@02
0;>I_AT0]J745@2gZ<X00`000000YJSI0000000>0?J`M`030000003f/7H0m[1f00H0m[1f00<00000
0?J`M`3f/7L0203f/7L00`000000Y[7P0:Jah00;0:Jah0030:Jlj@000000M:Ka00d0M:Ka3@1jW^P0
10000000n:ma0?R_L@00000;02Q^gPP0=FcI00<000000=6h`P3A^<801@3A^<8A0=C0aPX0f<S:00<0
h/Rn0>K?`03Vcl001`3Vcl070>_G`@030000002TZMX0Y:WJ00H0Y:WJ00<000000>^lX`3[_:<01@3[
_:<=0>k1Y0<0l<FU1`3c`i`80?K7V`H0n<ZI1P3kcIH50?g@T@@0om6;103odX840?oAN0<0oLe[0`3i
b5/20>Nn?P030=V^9@000000oooo08L0oooo000?0?ooo`0300WZ2P3oool0oooo02@0oooo00<00000
09Yn]02JO[@0102JO[@00`000000nZmP0?Z_H0050?Z_H0@0n[1X1P3j/f/90?VbL@/0mk9g1`3e/G`0
0`3e/Gd000230000P`030000P``09c>X00<000000<:GZP34W;00;@34W;0J0<JR]@030000002eXL@0
]J7401P0]J745P2gZ<X01@2j/=0000000:FXf@2UZ=T0000000h0m[1g00<000000?J`MP3f/7H01@3f
/7H00`000000m[1g0?J`M`090?J`M`030000002V/N00Y[7P00L0Y[7P1@2V_>T00`000000M:Ka07BV
l@0H07BVl@050000003h[g40n:ma0?R_L@0000003@0XK]h603E/f@030000003A^<80dKS200<0dKS2
4@3D`<H;0=S8bP030=gAc@3Vcl00i/o000H0i/o01`3[el420>oO`0030000002TZMX0Y:WJ00H0Y:WJ
00<000000>^lX`3[_:<0103[_:<=0>k1Y0@0l<FU1P3c`i`80?K7V`H0n<ZI1P3kcIH50?g@T@@0om6;
103odX840?oAN0<0oLe[0`3ib5/20>Nn?P030=V^9@000000oooo08L0oooo000c0?ooo`<02NX:00<0
000009Yn]02JO[@0102JO[@00`000000nZmP0?Z_H0050?Z_H0T0n[1X00<0n[=[0?VbL@3i/W40203i
/W4;0?NbM`L0mK5l1@0008<;02LcZ00302a1]0000000a9b`02/0a9b`7036X[D00`38Z;X000000;FQ
a00G0;FQa1H0]jS:102j/=0010000000YJSI0:FXf@00000>0?J`M`030000003f/7H0m[1f00D0m[1f
00<000000?J`M`3f/7L02@3f/7L00`000000Y[7P0:Jah0030:Jah0T0Y[cY00<0000007BVl@1dY_40
601dY_401@000000n:ma0?R_L@3h[g40000000h0:6kN1@0eK=T010000000dKS20=6h`P3A^<8A0=C0
aP`0f<S:0P3MdLd70>K?`0L0jmO10P3_gl000`000000Y:WJ0:BYfP060:BYfP030000003[_:<0jkbS
00<0jkbS3P3^`J@50?35Y@@0ll>L2@3fai/60?S:V@H0nlfF1@3md9440?oAR`@0om:2103odGP30?g=
J`<0nLQK0P3W_Sh00`3I[RD000000?ooo`270?ooo`00<03oool300WZ2P@0oooo00<0000009Yn]02J
O[@00`2JO[@00`000000nZmP0?Z_H0060?Z_H0T0n[1X103i/6l60?VbL@/0mk9g1`3e/G`00`0003@0
00230000P`020000P`P09c>X100/@K@00`000000a9b`0<BL/00X0<BL/1`0aZ:e1038Z;X00`000000
]J740;FQa00C0;FQa1H0]jS:1`2j/=000`000000YJSI0000000>0?J`M`030000003f/7H0m[1f00H0
m[1f00<000000?J`M`3f/7L02@3f/7L00`000000Y[7P0:Jlj@0<0:Jlj@030000001dY_40M:Ka01P0
M:Ka00H000000?R_L@3h[g40n:ma0000000CKMl?02Q^gP80=FcI00<000000=6h`P3A^<804@3D`<H<
0=S8bP@0gM7=1@3Vcl070>_G`@@0kmo000<000000:BYfP2TZMX01P2TZMX010000000jkbS0>^lX`3[
_:<>0>k1Y0H0l<FU103c`i`80?K7V`L0n<ZI1P3kcIH50?g@T@@0om6;103odX840?oAN0<0oLe[0`3i
b5/20>Nn?P030=V^9@000000oooo08L0oooo000]0?ooo`<02NX:1`3oool00`000000VWjd09Yn]003
09Yn]0030000003j[f00nZmP00H0nZmP2@3j/6P90?V`K`030?VbL@3g/WL0mk9g00T0mk9g203e/G`5
0000P`@09c>X200/@K@00`000000a9b`0<BL/00T0<BL/1d0aZ:e1P38Z;X00`000000]J740;FQa00A
0;FQa1D0]jS:2P2j/=0010000000YJSI0:FXf@00000>0?J`M`030000003f/7H0m[1f00H0m[1f0P00
00090?J`M`030000002V_>T0Y[cY00d0Y[cY0P00000I07BVl@050000003h[g40n:ma0?R_L@000000
0`0CKMl?02Q^gP030000003D`<H0e<3600l0e<36303Hb<X60=gAc@@0i/o01`3[el440>oO`0030000
002TZMX0Y:WJ00L0Y:WJ00<000000>^lX`3[_:<03P3^`J@70?35Y@<0ll>L203fai/70?S:V@H0nlfF
1@3md9440?oAR`@0om:2103odGP30?g=J`<0nLQK0P3W_Sh00`3I[RD000000?ooo`270?ooo`00:`3o
ool200WZ2PX0oooo00<0000009Yn]02JO[@0102JO[@00`000000nZmP0?Z_H0050?Z_H0X0n[1X2@3i
/6l70?N`M@@0mk9g203e/G`50000P`0302LcZ00/@K@0;46d00T0;46d00<000000<BL/034W;008@34
W;0N0<JR]@P0b:Rj00<000000;FQa02eXL@03P2eXL@F0;NXbPd0^[3@00@000000:FXf@2UZ=T00000
3@3f/7L00`000000m[1f0?J`MP080?J`MP030000003f/7L0m[1g00L0m[1g00<000000:Jlj@2V_>T0
2`2V_>T30:G7l@030000001X[_P0J:kh00<0J:kh501dY_401@000000n:ma0?R_L@3h[g40000000@0
4fgO3@0XK]h00`000000e<360=C0aP0>0=C0aP`0f<S:203MdLd20>K?`0L0jmO11P3_gl000`000000
Y:WJ0:BYfP060:BYfP030000003[_:<0k/6T00d0k/6T2@3`aJD20??3W0P0m/NK1`3hbYT50?_=UPH0
oM2A103odH/40?oBPP@0om5h0`3mcF/20?W8F`050?;:E@3W_Sh0ikhn0=V^9@000000R03oool002P0
oooo0`09jPX=0?ooo`030000002JO[@0VWjd00<0VWjd00<000000?Z_H03j[f001@3j[f0:0?Z`J0X0
nK1_2P3g/7D70?F`N`030?FaO00008<000230080002300<0002A02a1]00/@K@02P0/@K@00`000000
a9b`0<BL/00O0<BL/1h0aZ:e2`38Z;X00`000000]J740;FQa00;0;FQa1H0]jS:402j/=000`000000
Y[7P0000000>0?J`M`030000003f/7H0m[1f00P0m[1f00<000000?J`M`3f/7L01`3f/7L00`000000
Y[cY0:Jlj@070:Jlj@L0YLOa00<0000006R^n01X[_P04@1X[_P607BVl@050000003h[g40n:ma0?R_
L@0000001@0CKMl<02Q^gP030000003D`<H0e<3600`0e<36303Hb<X:0=gAc@030>K?`03[el40jmO1
00D0jmO11P3_gl000`3cj;`000000:BYfP070:BYfP030000003^`J@0k/6T00`0k/6T2P3`aJD90?K7
V`L0n<ZI1@3kcIH60?g@T@@0om6;103odX840?oAN0@0oLe[00<0nLQK0?;:E@3W_Sh00P3W_Sh00`00
0000oooo0?ooo`260?ooo`009@3oool300WZ2Q00oooo00<0000009Yn]02JO[@00`2JO[@00`000000
nZmP0?Z_H0060?Z_H0T0n[1X2P3i/6l;0?N`M@L0mK1k00<0000d0000P`0008<00P00094=02a1]003
00000034W;00a9b`01/0a9b`7`36X[D=0<RX^P030000002eXL@0]J7400T0]J745P2gZ<XA0;Z`d005
0;bieP000000Y[7P0:Jah00000003P3f/7L00`000000m[1f0?J`MP080?J`MP800000203f/7L00`00
0000Y[cY0:Jlj@030:Jlj@/0YLOa00<0000006R^n01X[_P05`1X[_P01@000000n:ma0?R_L@3h[g40
000000H04fgO2`0XK]h00`000000e<360=C0aP0:0=C0aP`0f<S:2`3MdLd20>;Kc`D0jmO11`3_gl00
0`3cj;`000000:BYfP050:BYfP80YK;R00<000000>k1Y03^`J@0303^`J@:0?35Y@030??:Y03fai/0
m/NK00H0m/NK1`3hbYT50?_=UPH0oM2A103odH/40?oBPP@0om5h103mcF/00`3ib5/0l/YE0>Nn?P02
0>Nn?P030000003oool0oooo08H0oooo000R0?ooo`<02NX:4`3oool00`000000VWjd09Yn]00309Yn
]0030000003j[f00nZmP00H0nZmP2@3j/6P:0?V`K`/0mk1e203e/7/00`0008<0002A0000T@020000
T@`0;46d00<000000<BL/034W;006@34W;0O0<JR]A00b:Rj00<000000;FQa02eXL@01P2eXL@F0;NX
bQ40^[3@102l^MH010000000Y[7P0:Jah000000>0?J`M`030000003f/7H0m[1f00T0m[1f00<00000
0?J`M`3f/7L01P3f/7L00`000000Y[cY0:G7l@0>0:G7l@800000601X[_P01@000000n:ma0?R_L@3h
[g40000000P04fgO200XK]h00`000000e<360=C0aP090=C0aPd0f<S:2`3MdLd30>;Kc`@0jmO11`3_
gl020??X_0030000002TZMX0YK;R00H0YK;R00<000000>k1Y03^`J@02P3^`J@;0?35Y@80llZT1P3f
ai/70?S:V@H0nlfF1P3md9440?oAR`D0om:20`3odGP40?g=J`030?W8F`3bbUD0ikhn0080ikhn00<0
00000?ooo`3oool0QP3oool001l0oooo0`09jPXG0?ooo`030000002JO[@0VWjd00<0VWjd00<00000
0?Z_H03j[f001@3j[f0:0?Z`J0X0nK1_2P3g/7D80?F`N`D0002A300/@K@00`000000a9b`0<BL/00F
0<BL/200aZ:e4P38Z;X00`000000]J740;FQa0040;FQa1H0]jS:4@2j/=070;bieP030000002V/N00
000000h0m[1g00<000000?J`MP3f/7H02P3f/7H00`000000m[1g0?J`M`040?J`M`030000003f/7L0
000000d0YLOa102Re?T010000000Dk7k05>an`1C/O/E06R^n0060000003h[g40n:ma0?R_L@000000
06KG200CKMl702Q^gP030000003D`<H0e<3600L0e<363@3Hb<X;0=gAc@D0h]_?0P3[el470>oO`0<0
lnRl00<000000:FbhP2U/^801`2U/^800`000000k/6T0>k1Y0090>k1Y0X0l<FU103cbZ@50?K7V`L0
n<ZI1P3kcIH60?g@T@@0om6;1@3odX830?oAN0@0oLe[0P3bbUD30>Nn?P030000003oool0oooo08H0
oooo000L0?ooo`<02NX:6P3oool00`000000VWjd09Yn]00309Yn]0030000003j[f00nZmP00D0nZmP
2P3j/6P:0?V`K`/0mk1e1`3e/7/50000T@d0;46d00<000000<BL/034W;004P34W;0Q0<JR]A@0b:Rj
00@000000;FQa02eXL@0]J745P2gZ<XB0;Z`d0T0_;WF00@000000:Jah02V/N0000003P3f/7L00`00
0000m[1f0?J`MP0:0?J`MP<000000`3f/7L010000000m[1g07LXF`0000090:G7l@P0X]Ci00<00000
05>an`1C/O/02P1C/O/<06R^n0050000003h[g40n:ma0?R_L@0000000P00I]L801=]g`H0:6kN00<0
00000=C0aP3D`<H01@3D`<H=0=S8bP/0gM7=1`3Rfll00`3[el40kmo00>oO`0050>oO`0@0lnRl00<0
00000:FbhP2U/^801P2U/^800`000000k/6T0>k1Y0080>k1Y0/0l<FU1@3cbZ@40?K7V`L0n<ZI1P3k
cIH60?g@T@@0om6;1@3odX840?oAN0<0oLe[0P3bbUD30>Nn?P030000003oool0oooo08H0oooo000K
0?ooo`0300WZ2P3oool0oooo01/0oooo00<0000009Yn]02JO[@00`2JO[@00`000000nZmP0?Z_H005
0?Z_H0X0n[1X2P3i/6l;0?N`M@<0mK1k103e[gX00`000440002A0000T@030000T@`0;46d00<00000
0<BL/034W;004034W;0Q0<JR]AL0b:Rj00<000000;NXbP2gZ<X0502gZ<XB0;Z`d0`0_;WF00@00000
0:Jah02V/N0000003P3f/7L00`000000m[1f0?J`MP0<0?J`MP<000000P3f/7L00`000000oooo0000
00050:G7l@`0X]Ci0P00000C05>an`@0J:kh0P0000020?R_L@0400000000I]L006KG001Ve`P04fgO
1@0XK]h00`000000e<360=C0aP030=C0aPd0f<S:2`3MdLd80>;Kc`80i^K@1@3_gl050??X_0030?K^
]0000000YK;R00L0YK;R00<000000>k1Y03^`J@01`3^`J@;0?35Y@H0llZT0`3fai/70?S:V@H0nlfF
1P3md9440?oAR`D0om:2103odGP30?g=J`80l/YE0`3W_Sh00`000000oooo0?ooo`260?ooo`00>@3o
ool00`000000VWjd09Yn]00309Yn]0030000003j[f00nZmP00H0nZmP2@3j/6P;0?V`K`P0mk1e0P3g
[g@80?F_NPD0002A300/@K@00`000000a9b`0<BL/00=0<BL/280aZ:e6038Z;X00`3:[kh000000;NX
bP0C0;NXbQ<0^[3@3P2l^MH010000000Y[cY0:Jlj@00000=0?J`M`030000003f/7H0m[1f00l0m[1f
100000000`3f/7H000000000000=0:;Dn@@0V=on0P000002036[kQD0Dk7k0P0000000`3h[g400000
00000003001Ve`P04fgO0`0XK]h00`000000e<360=C0aP020=C0aPd0f<S:303MdLd80>;Kc`@0i^K@
0`3_gl040??X_080m^jd00<000000:FbhP2U/^801`2U/^800`000000k/6T0>k1Y0050>k1Y0/0l<FU
203cbZ@20?K7V`L0n<ZI1P3kcIH50?g@T@D0om6;1@3odX840?oAN080oLe[00@0nM=Z0?;:E@3bbUD0
l/YE0P3W_Sh00`000000oooo0?ooo`260?ooo`00>P3oool00`000000VWjd09Yn]00309Yn]0030000
003j[f00nZmP00D0nZmP2@3j/6P;0?V`K`<0mk1e1`3g[g@80?F_NPD0002A3@0/@K@00`000000a9b`
0<BL/00:0<BL/280aZ:e6038Z;X40<Z__P030000002gZ<X0]jS:00l0]jS:4`2j/=0?0;bieP030;o3
g@000000Y[cY0080Y[cY00<000000?J`M`3f/7L02`3f/7L00`000000m[1f0?J`MP0E0?J`MP030000
002Re?T0X]Ci00L0X]Ci2@2Hgoh3000000T0<J_^3@1C/O/010000000n:ma0?R_L@000004001Ve`T0
4fgO00@0:6kN0000003D`<H0e<363P3Hb<X;0=gAc@P0h]_?1`3Vi]000`3_gl00lnRl0??X_0020??X
_0<0m^jd00<000000:FbhP2U/^801`2U/^800`000000k/6T0>k1Y0040>k1Y0/0l<FU2@3cbZ@80?S:
V@H0nlfF1@3md9450?oAR`D0om:2103odGP20?g=J`040?WCJP3bbUD0l/YE0?;:E@80ikhn00<00000
0?ooo`3oool0QP3oool003X0oooo00<0000009Yn]02JO[@00`2JO[@00`000000nZmP0?Z_H0050?Z_
H0X0n[1X203i/6l20?R_K@/0mjmd1`3e[gX00`000440002A0000T@030000T@`0;46d00<000000<BL
/034W;001`34W;0S0<JR]AT0b:Rj1P3:[kh00`000000]jS:0;NXbP0<0;NXbQ<0^[3@3`2l^MH40;o3
g@050000002V_>T0Y[cY0:Jlj@0000003@3f/7L00`000000m[1f0?J`MP0E0?J`MP030000002Re?T0
X]Ci00<0X]Ci2P2Hgoh508;TmP8000004@0aZnh405>an`80000000<0n:ma00000000I]L01000I]L9
01=]g`030000003Hb<X0f<S:00`0f<S:2`3MdLd80>;Kc`P0i^K@0`3ZlLh20??X_080m^jd0P3[nLD0
0`000000YK;R0:FbhP060:FbhP030000003^`J@0k/6T00@0k/6T2`3`aJD90??:Y080mljS1P3hbYT6
0?_=UPD0oM2A1@3odH/50?oBPP@0om5h00<0oLe[0?WCJP3idfX00`3bbUD00`3W_Sh000000?ooo`28
0?ooo`00=`3oool300WZ2P030000002JO[@0VWjd00<0VWjd00<000000?Z_H03j[f001@3j[f0:0?Z`
J0<0nK1_1`3h[fd;0?N_M0H0mJmj0P3d[gX50000T@`0;46d00<000000<BL/034W;001034W;0T0<JR
]AT0b:Rj203:[kh00`000000]jS:0;NXbP0:0;NXbQ<0^[3@402l^MH60;o3g@050000002V_>T0Y[cY
0:Jlj@0000003@3f/7L00`000000m[1f0?J`MP0E0?J`MP8000002P2Hgoh708;TmP0305KAdP000000
000000@0oooo00@008o60?ooo`3oool0oooo3`0aZnh300000003001E`@00I]L006KG00<006KG1`0C
KMl00`000000f<S:0=S8bP0;0=S8bP/0gM7=2@3Rfll80>KVd0@0j_7>1@3[nLD00`3Sn[4000000:Fb
hP070:FbhP030000003^`J@0k/6T0080k/6T2`3`aJD:0??:Y0<0mljS1@3hbYT60?_=UPD0oM2A1@3o
dH/50?oBPP@0om5h00<0oLe[0?WCJP3idfX00`3bbUD00`3W_Sh000000?ooo`280?ooo`00=03oool3
00WZ2P@0oooo00<0000009Yn]02JO[@00P2JO[@00`000000nZmP0?Z_H0060?Z_H0L0n[1X0P3i[VD;
0?R_K@X0mjmd1@3e[gX30?B_NPD0002A3@0/@K@010000000a9b`0<BL/034W;0T0<JR]AT0b:Rj2`3:
[kh00`000000]jS:0;NXbP070;NXbQ<0^[3@402l^MH90;o3g@050000002V_>T0Y[cY0:Jlj@000000
3@3f/7L2000001L0m[1f0P00000509SOoPL0P^Cf00<0E]7B0000003oool0403oool2002?aPX0<J_^
0P000002001E`@D006KG1P0CKMl00`000000f<S:0=S8bP090=S8bP`0gM7=203Rfll80>KVd0D0j_7>
103[nLD20>?j/@030000002U/^80YK;R00L0YK;R00@000000>k1Y03^`J@0k/6T2`3`aJD:0??:Y0@0
mljS103hbYT60?_=UPD0oM2A1@3odH/50?oBPP@0om5h0`3idfX30?;:E@030>Nn?P000000oooo08P0
oooo000a0?ooo`<02NX:1`3oool00`000000VWjd09Yn]00309Yn]0030000003j[f00nZmP00D0nZmP
0P3j/6P80?V^I@X0n:m]2`3g[g@20?F_NPD0m:mj00<000110000T@0009400`00094<02a1]0030000
0036X[D0aZ:e02<0aZ:e6P38Z;X<0<Z__P030000002gZ<X0]jS:00@0]jS:502j/=0@0;bieP`0_l?M
0P0000020:G7l@030000003f/7L0m[1g00`0m[1g00<000000?J`MP3f/7H05P3f/7H3000000<0P^Cf
0`0000000`1FdM80oooo0?ooo`0L0?ooo`04002?aP0aZnh0<J_^036[kP8000000P00EL46001Ve`D0
4fgO00<000000=S8bP3Hb<X01`3Hb<X<0=gAc@P0h]_?203Vi]050>[acPD0joW50`3Sn[400`000000
YK;R0:FbhP060:FbhP030000003^`J@0k/6T00`0l<FU2@3cbZ@60?O>X`80n<ZI1`3kcIH50?g@T@D0
om6;1@3odX840?oAN0<0nM=Z0`3bbUD00`3W_Sh000000?ooo`280?ooo`00;P3oool300WZ2PX0oooo
00<0000009Yn]02JO[@00`2JO[@010000000nZmP0?Z_H03j[f040?V/G0X0nJiU2P3h[fd;0?N_M003
0?F_NP3d[gX0m:mj00D0m:mj1@00094602a1]0H0;D^n00<000000<JR]@36X[D08@36X[DJ0<RX^Pl0
bZnn00@000000;NXbP2gZ<X0]jS:502j/=0@0;biePd0_l?M0`32c^<2000000030:G7l@000000m[1g
00d0m[1g00<000000?J`MP3f/7H0603f/7H3000002X0oooo0P00EL46001Ve`@04fgO00<000000=S8
bP3Hb<X01@3Hb<X<0=gAc@P0h]_?2@3Vi]050>[acP@0joW50`3Sn[400`3>kHd0Y/]H000000080:Fb
hP030000003^`J@0l<FU00X0l<FU2P3cbZ@70?O>X`030?S:V@3kcIH0nlfF00@0nlfF1P3md9450?oA
R`D0om:20`3odGP0103mf7/0nM=Z0?WCJP3idfX30?;:E@030>Nn?P000000oooo08P0oooo000[0?oo
o`<02NX:3P3oool01P000000VWjd09Yn]02JO[@0WHNl000000P0nJaL2@3i[VD;0?R_K@T0mjmd00<0
mZic0?B_NP3d[gX01P3d[gX5000:VPd0;D^n00<000000<JR]@36X[D07P36X[DJ0<RX^Q80bZnn00<0
00000;Z`d02j/=004P2j/=0@0;biePh0_l?M1P32c^<00`000000YLOa0000000>0?J`M`030000003f
/7H0m[1f01H0m[1f00<000000?ooo`3oool0;@3oool2001E`@H006KG0`0CKMl00`000000f<S:0=S8
bP040=S8bP/0gM7=2@3Rfll80>KVd0D0j_7>1@3[nLD30>?j/@030<k]S@3oool0000000T0YK;R00<0
00000?35Y@3`aJD02@3`aJD:0??:Y0P0mljS1P3kcIH60?g@T@D0om6;1@3odX820?oAN080oMQk0`3i
dfX30?;:E@030>Nn?P000000oooo08P0oooo000X0?ooo`<02NX:4@3oool00`000000WHNl09f7_003
09f7_0030000003i[5`0nJaL00D0nJaL2P3i[VD:0?R_K@L0mjmd103f[W<60?B_NP030?B^N@0004P0
00ZJ00@000ZJ300]Bkh00`000000aZ:e0<JR]@0L0<JR]A/0b:Rj4P3:[kh00`3=]/<000000;Z`d00A
0;Z`d140_;WF3@2o`md90<;>h`@000003@3f/7L2000001H0m[1f00<000000?ooo`3oool0;`3oool2
001E`@H006KG0P0CKMl00`000000f<S:0=S8bP020=S8bP`0gM7=203Rfll80>KVd0H0j_7>103[nLD3
0>?j/@80c^f=0P3oool00`000000YK;R0:FbhP040:FbhP80YKg[00<000000?35Y@3`aJD02@3`aJD:
0??:Y0P0mljS0P3jdil40?_=UPH0oM2A1@3odH/50?oBPP040?oAN03mf7/0oMQk0?gHN`<0nM=Z0`3b
bUD00`000000oooo0?ooo`280?ooo`009P3oool200WZ2Q@0oooo00<0000009f7_02MQk`00`2MQk`0
0`000000nJaL0?V/G0050?V/G0X0nJiU2P3h[fd50?N_M0H0mZic1@3d[gX30?B^N@D000ZJ3@0]Bkh0
0`000000aZ:e0<JR]@0I0<JR]A/0b:Rj4`3:[kh30<ff``030000002j/=00^[3@00d0^[3@4@2l^MH=
0;o3g@X0`/kS0P34f^X0101Y000000000:;Dn@00000>0?J`M`030000003f/7H0m[1f0180m[1f00<0
00000?ooo`3oool0<P3oool2001E`@H006KG00@04fgO0000003Hb<X0f<S:303MdLd80>;Kc`T0i^K@
1@3ZlLh40>_ia@@0hoZa00<0c^f=0?ooo`3oool00P3oool00`000000YK;R0:Fmj`060:Fmj`030000
003`aJD0l<FU00L0l<FU2P3cbZ@90?O>X`@0n]>O0P3kcIH60?g@T@D0om6;103odX800`3ofHT0oMQk
0?gHN`020?gHN`@0nM=Z0P3bbUD00`000000oooo0?ooo`280?ooo`00?03oool00`000000WHNl09f7
_00309f7_0030000003i[5`0nJaL00H0nJaL2P3i[VD:0?R_K@<0mjmd1`3f[W<40?B_NP@0m:ii1@00
2YX=02e;_P0300000036X[D0aZ:e01L0aZ:e6`38Z;XD0<Z__PD0cKK300<000000;Z`d02j/=002P2j
/=0A0;biePh0_l?M2P32c^<50<CJjP030000002Re?T0000000h0m[1g00<000000?J`MP3f/7H0403f
/7H00`000000oooo0?ooo`0e0?ooo`8005G11P00I]L00`000000gM7=0=gAc@0:0=gAc@T0h]_?203V
i]050>[acPD0joW50`3Sn[420<k]S@@0oooo00<000000:Fmj`2U_N/01`2U_N/00`000000l<FU0?35
Y@060?35Y@X0llZT2@3gcZ<60?[CW`H0oM2A1@3odH/20?oBPP<0omV9103mf7/40?WCJP80l/YE00<0
00000?ooo`3oool0R03oool003d0oooo00<0000009f7_02MQk`00`2MQk`00`000000nJaL0?V/G005
0?V/G0X0nJiU2P3h[fd00`3g[g@0mZic0?J^L`080?J^L`80m:mj1@3d[WT00`0004P000ZJ000:VP03
000:VPd0;D^n00<000000<JR]@36X[D05036X[DL0<RX^Q<0bZnn1`3=]/<00`000000^[3@0;Z`d009
0;Z`d100_;WF3P2o`md:0<;>h`P0a=[Z1@00000;0?J`M`<000003`3f/7H00`000000oooo0?ooo`0h
0?ooo`8005G11@00I]L00`000000gM7=0=gAc@090=gAc@P0h]_?203Vi]060>[acP@0joW5103Sn[40
0`3>kHd0oooo0?ooo`040?ooo`030000002U_N/0YKg[00L0YKg[00<000000?35Y@3`aJD01@3`aJD:
0??:Y0P0mljS1`3jdil40?cFVP80oM2A1@3odH/00`3odX80omV90?oIR@020?oIR@@0oMQk103idfX2
0?;:E@030000003oool0oooo08P0oooo000m0?ooo`030000002MQk`0WHNl00<0WHNl00<000000?V/
G03i[5`01@3i[5`:0?V^I@T0n:m]00<0mje/0?J^L`3f[W<02@3f[W<00`3d[gX0m:ii0?B^N@040?B^
N@030?B]N@002YX000ZJ00<000ZJ3@0]Bkh00`000000aZ:e0<JR]@0B0<JR]A`0b:Rj503:[kh90<ff
``030000002j/=00^[3@00H0^[3@4@2l^MH=0;o3g@/0`/kS2034f^X30<GXk`80000000<0V=on0000
000000000P0000040?J`M`<000000`3oool3000000T0m[1f0`00000m0?ooo`8005G11000I]L00`00
0000gM7=0=gAc@070=gAc@P0h]_?2@3Vi]050>[acPD0joW50`3Sn[400`3>kHd000000?ooo`060?oo
o`030000002U_N/0YKg[00H0YKg[00<000000?35Y@3`aJD0103`aJD;0??:Y0P0mljS1`3jdil60?cF
VPD0o]VC1@3ofHT40?gHN`@0nM=Z0P3bbUD00`000000oooo0?ooo`280?ooo`00?@3oool00`000000
WHNl09f7_00309f7_0030000003i[5`0nJaL00H0nJaL2P3i[VD70?R_K@<0mje/2P3f[W<60?B^N@80
m:ei00<00018000:VP002YX00`002YX=02e;_P0300000036X[D0aZ:e00l0aZ:e7038Z;XD0<Z__P/0
cKK300<000000;Z`d02j/=00102j/=0A0;biePh0_l?M2P32c^<90<CJjPH0aNS_0`00000208?TmPD0
0000203oool3000000<0m[1f0`0000120?ooo`8005G10`00I]L00`000000gM7=0=gAc@050=gAc@T0
h]_?203Vi]060>[acP@0joW50`3Sn[420<k]S@030000003oool0oooo00H0oooo00<000000:Fmj`2U
_N/01P2U_N/00`000000l<FU0?35Y@030?35Y@X0llZT2@3gcZ<70?[CW`H0o=JJ1@3nfI<50?oIR@@0
oMQk103idfX00`3bbUD000000?ooo`2:0?ooo`00?03oool200WZ2P030000002MQk`0WHNl00<0WHNl
00<000000?V/G03i[5`01@3i[5`:0?V^I@D0n:m]1@3g[F`:0?J^L`030?J]LP3d[WT0m:ii00<0m:ii
0`3d[GT5000:VPd0;D^n00<000000<JR]@36X[D03@36X[DM0<RX^Q@0bZnn3@3=]/<010000000^[3@
0;Z`d02j/=0A0;biePh0_l?M2`32c^<80<CJjPL0aNS_1032mNl3000000<0T>^l303oool3000004H0
oooo0P00EL43001Ve`030000003MdLd0gM7=00<0gM7=2@3Rfll80>KVd0H0j_7>1@3[nLD30>?j/@03
0<k]S@000000oooo00P0oooo00<000000:Fmj`2U_N/01`2U_N/00`000000l<FU0?35Y@020?35Y@X0
llZT2@3gcZ<70?[CW`H0o=JJ1@3nfI<50?oIR@@0oMQk103idfX00`3bbUD000000?ooo`2:0?ooo`00
>@3oool300WZ2P80oooo00<0000009f7_02MQk`00`2MQk`00`000000nJaL0?V/G0060?V/G0T0nJiU
0`3h[fd80?N]K0P0mZic0`3f[G830?B^N@@0m:ei1@002YX=02e;_P0300000036X[D0aZ:e00/0aZ:e
7@38Z;XE0<Z__Pl0cKK300<000000;bieP2l^MH03`2l^MH>0;o3g@/0`/kS2@34f^X70<GXk`D0`_G_
0P2cnn<2093[_5T0oooo0P00EL42001Ve`030000003MdLd0gM7=0080gM7=203Rfll90>KVd0H0j_7>
103[nLD30>?j/@80c^f=00<000000?ooo`3oool0203oool00`000000YKg[0:Fmj`060:Fmj`040000
003`aJD0l<FU0?35Y@/0llZT2@3gcZ<70?[CW`H0o=JJ1@3nfI<50?oIR@@0oMQk103idfX00`3bbUD0
00000?ooo`2:0?ooo`00=P3oool300WZ2PD0oooo00<0000009f7_02MQk`00`2MQk`00`000000nJaL
0?V/G0060?V/G0X0nJiU00<0n:m]0?N]K03g[F`01`3g[F`70?J^L`@0mZeb0`3d[WT50?B]N@D000ZJ
3@0]Bkh00`000000aZ:e0<JR]@080<JR]Ad0b:Rj5@3:[kh@0<ff``030=2ma`000000_;WF00l0_;WF
3P2o`md:0<;>h`X0a=[Z1P35j>l60<;ek`80/o_S0P2@jkaL0?ooo`8005G100@006KG0000003MdLd0
gM7=2@3Rfll80>KVd0H0j_7>1@3[nLD30>?j/@030<k]S@000000oooo00/0oooo00<000000:Fmj`2U
_N/01P2U_N/00`000000l<FU0?35Y@0;0??:Y0P0mljS1`3jdil70?cFVPD0o]VC1@3ofHT40?gHN`@0
nM=Z00<0l/YE0000003oool0RP3oool003<0oooo0`09jPX90?ooo`030000002MQk`0WHNl00<0WHNl
00<000000?V/G03i[5`01@3i[5`90?V^I@030?R[H`3g[F`0mje/00P0mje/1P3f[W<60?J]LP030?B^
N@3d[GT0m:ei00@0m:ei0P004:43000:VPd0;D^n00<000000<JR]@36X[D01P36X[DN0<RX^QD0bZnn
403=]/<30=2ma`030000002l^MH0_;WF00/0_;WF3P2o`md;0<;>h`T0a=[Z1`35j>l50<;ek`80/o_S
0`2@jkaO0?ooo`8005G10P0000080>;Kc`T0i^K@1P3ZlLh40>_ia@<0hoZa0P3>kHd00`000000oooo
0?ooo`0:0?ooo`030000002U_N/0YKg[00L0YKg[00<000000?35Y@3cbZ@02P3cbZ@80?O>X`L0n]>O
1`3leYX50?kIT`D0omV9103mf7/40?WCJP030?;:E@000000oooo08X0oooo000a0?ooo`802NX:303o
ool00`000000WHNl09f7_00309f7_0030000003i[5`0nJaL00H0nJaL1`3i[VD30?R[H`X0mje/103f
[W<70?J]LPP0m:ei0`004:400`002YX0;D^n02e;_P0<02e;_P0300000036X[D0aZ:e00<0aZ:e7P38
Z;XE0<Z__Q40cKK31@3@_LL00`000000_;WF0;bieP080;biePh0_l?M2`32c^<:0<CJjPL0aNS_1@32
mNl20;?kh`80T>^lH`3oool2001E`@030000003Rfll0h]_?00@0h]_?2@3Vi]060>[acPD0joW50`3S
n[400`3>kHd000000?ooo`0=0?ooo`030000002U_N/0YKg[00L0YKg[0P0000090??:Y0T0mljS1`3j
dil70?cFVPD0o]VC1@3ofHT40?gHN`@0nM=Z00<000000?ooo`3oool0RP3oool003l0oooo00<00000
09f7_02MQk`00`2MQk`00`000000nJaL0?V/G0060?V/G0D0nJiU1@3hZf<:0?N]K0<0mZic203f[G80
0`3e[780m:ei0?B]N@050?B]N@D0012Q3@0]Bkh010000000aZ:e0<JR]@36X[DN0<RX^QH0bZnn4@3=
]/<70=2ma`030000002l^MH0_;WF00D0_;WF3`2o`md;0<;>h`T0a=[Z1`35j>l60<;ek`80/o_S0P2@
jkaV0?ooo`03001E`@000000000000<0h]_?2@3Vi]070>[acP@0joW50`3Sn[400`3>kHd000000?oo
o`0?0?ooo`030000002U_N/0YKg[00@0YKg[102SbO<00`000000llZT0??:Y0060??:Y0T0mljS1`3j
dil70?cFVPD0o]VC1@3ofHT40?gHN`@0nM=Z00<000000?ooo`3oool0RP3oool003l0oooo00<00000
09f7_02MQk`0102MQk`00`000000nJaL0?V/G0050?V/G0<0nJiU1`3hZf<;0?N]K0030?J^L`3f[G80
mZeb00H0mZeb0P3e[7880?B]N@@0012Q200[DlL602e;_P0300000038Z;X0b:Rj01d0b:Rj5P3:[khA
0<ff``P0d;g700<000000;bieP2l^MH00`2l^MH?0;o3g@/0`/kS2P34f^X70<GXk`D0`_G_0P2cnn<2
093[_6X0oooo00@005G10000003Rfll0h]_?2@3Vi]060>[acPD0joW50`3Sn[400`000000oooo0?oo
o`0@0?ooo`030000002U_N/0XlWc00P0XlWc00<000000??:Y03cbZ@01@3cbZ@90?O>X`L0n]>O1P3l
eYX60?kIT`D0omV9103mf7/40?WCJP030000003oool0oooo08X0oooo00100?ooo`030000002MQk`0
WHNl00<0WHNl00<000000?V/G03i[5`01P3i[5`00`3i[VD0n:]S0?R[H`070?R[H`X0mje/2@3f[G83
0?F/LPH0m:ei0P3c[7T4000@X@d0:e?700<000000<RX^P38Z;X06`38Z;XF0<Z__Q40cKK32`3@_LL0
10000000_;WF0;bieP2l^MH>0;o3g@`0`/kS2@34f^X70<GXk`H0`_G_0P2cnn<2093[_6d0oooo0P00
00080>KVd0L0j_7>103[nLD30>?j/@030000003oool0oooo0180oooo00<000000:?9l`2SbO<0202S
bO<00`000000llZT0??:Y0040??:Y0P0mljS203jdil60?cFVPH0o]VC1@3ofHT40?gHN`<0nM=Z00<0
00000?ooo`3oool0R`3oool00400oooo00<0000009f7_02MQk`00`2MQk`00`000000nJaL0?V/G005
0?V/G0030?RYFP3hZf<0n:]S00P0n:]S2P3g[F`00`3gZf/0mZeb0?J]LP050?J]LP@0mJab1P3d[GT2
0?>/N@@0012Q3P0[DlL00`000000b:Rj0<RX^P0H0<RX^QL0bZnn4@3=]/<=0=2ma`030000002o`md0
_l?M00d0_l?M2`32c^<:0<CJjPL0aNS_1@32mNl30;?kh`80T>^lL03oool3000000@0i^K@1`3ZlLh4
0>_ia@80hoZa0P00000F0?ooo`030000002SbO<0XlWc00P0XlWc00<000000??:Y03cbZ@00P3cbZ@9
0?O>X`P0n]>O1P3leYX60?kIT`@0omV91@3mf7/30?WCJP030000003oool0oooo08/0oooo00100?oo
o`030000002MQk`0WHNl00@0WHNl00<000000?V/G03i[5`00`3i[5`30?RYFPX0n:]S203g[F`20?N[
J`L0mZeb1@3e[7850?B]N@<0ljai10004:4=02]Ca`0300000038Z;X0b:Rj01L0b:Rj5P3:[khB0<ff
``d0d;g700<0e<G;0000002o`md0302o`md<0<;>h`T0a=[Z2035j>l50<;ek`80/o_S0P2@jkae0?oo
o`8000000P3Vi]060>[acPD0joW50P00000I0?ooo`030000002SbO<0XlWc00P0XlWc00@000000??:
Y03cbZ@0llZT2@3gcZ<80?[CW`H0o=JJ1P3nfI<40?oIR@D0oMQk0P3idfX00`000000oooo0?ooo`2<
0?ooo`00@@3oool00`000000WHNl09f7_00309f7_0040000003i[5`0nJaL0?V/G0D0n:UJ2P3hZf<7
0?N]K0@0mj][1@3f[G860?F/LPD0m:ei0`3c[7T4000@X@d0:e?700<000000<RX^P38Z;X05@38Z;XG
0<Z__Q80cKK33@3@_LL30=C5b`030000002o`md0_l?M00P0_l?M3032c^<:0<CJjPL0aNS_1P32mNl2
0;?kh`80T>^lN03oool3000000D0j_7>103[nLD00`000000oooo0?ooo`0J0?ooo`030000002SbO<0
XlWc00P0XlWc00<000000??:Y03cbZ@02@3gcZ<80?[CW`H0o=JJ1P3nfI<40?oIR@D0oMQk0P3idfX0
0`000000oooo0?ooo`2<0?ooo`00@@3oool00`000000WHNl09f7_00309f7_0030000003i[5`0nJaL
00H0n:UJ2P3hZf<60?N]K0D0mj][1@3f[G860?F/LP030?B[LP3d[GT0m:ei0080m:ei103c[7T4000@
X@d0:e?700<000000<RX^P38Z;X04P38Z;XH0<Z__Q80cKK33@3@_LL50=C5b`030000002o`md0_l?M
00H0_l?M3032c^<:0<CJjPL0aNS_1@32mNl30;?kh`80T>^lO03oool3000000030>[acP3[nLD0joW5
00<000007P3oool00`000000XlWc0:?9l`080:?9l`030000003cbZ@0mljS00P0mljS1`3jdil70?cF
VPD0o]VC1@3ofHT50?gHN`030?WCJP000000oooo08h0oooo00110?ooo`030000002MQk`0WHNl00@0
WHNl00<000000?RYFP3hZEX01P3hZEX:0?R[H`@0mje/1P3gZf/40?J]LPL0mJab0P3dZg830?B]N@@0
ljai0P004j<2000@X@d0:e?700<000000<RX^P38Z;X04@38Z;XG0<Z__Q80cKK33P3@_LL70=C5b`03
0000002o`md0_l?M00<0_l?M3032c^<:0<CJjPL0aNS_1P32mNl20;?kh`80T>^lP@3oool300000280
oooo00<000000:?9l`2SbO<0202SbO<2000000L0mljS203jdil70?cFVPD0o]VC1@3ofHT50?gHN`03
0?WCJP000000oooo08h0oooo000n0?ooo`<02NX:00<0oooo0000002MQk`00`2MQk`00`2OSl<00000
0?RYFP070?RYFPX0n:]S103g[F`70?N[J`<0mZeb1P3e[7840?B[LP030?B]N@3c[7T0ljai00@0ljai
0P004j<2000@X@d0:e?700<000000<RX^P38Z;X03P38Z;XH0<Z__Q80cKK33P3@_LL90=C5b`030000
002o`md0_l?M00`0`/kS2`34f^X70<GXk`D0`_G_0`2cnn<2093[_:P0oooo00<000000:?9l`2SbO<0
1P2SbO<309kFn`030000003gcZ<0mljS00@0mljS203jdil70?cFVPD0o]VC1@3ofHT50?gHN`030000
003oool0oooo08h0oooo000l0?ooo`802NX:103oool00`000000WHNl09n?``0409n?``030000003h
ZEX0n:UJ00D0n:UJ2P3hZf<30?N]K0P0mj][0P3f[G870?F/LPD0m:]b1P3c[7T3000CX`03000@X@0[
DlL0:e?700/0:e?700<000000<RX^P38Z;X03038Z;XH0<Z__Q<0cKK33P3@_LL;0=C5b`8000002`32
c^<:0<CJjPP0aNS_1@32mNl30;?kh`80T>^lZP3oool00`000000XlWc0:?9l`020:?9l`L0W]Kk00<0
00000?O>X`3gcZ<00`3gcZ<80?[CW`L0o=JJ1@3nfI<50?oIR@D0oMQk00<000000?ooo`3oool0SP3o
ool00480oooo00<0000009n?``2OSl<0102OSl<00`000000n:UJ0?RYFP060?RYFPX0n:]S00<0mje/
0?N[J`3gZf/0203gZf/00`3f[G80mJab0?F/LP050?F/LPD0m:]b1P3c[7T01@3bZgX001>S000CX`00
4j<0012Q00`0:e?700<000000<RX^P38Z;X02`38Z;XH0<Z__Q<0cKK33P3@_LL<0=C5b`80f<g?00<0
00000<;>h`32c^<01P32c^<;0<CJjPL0aNS_1@32mNl40;?kh`03093[_03oool0oooo0:/0oooo0P00
000:09kFn`8000000`3gcZ<80?[CW`L0o=JJ1@3nfI<50?oIR@@0oMQk00<000000?ooo`3oool0S`3o
ool004<0oooo00<0000009n?``2OSl<00`2OSl<00`000000n:UJ0?RYFP060?RYFPX0n:]S2`3gZf/7
0?F/LPH0m:]b00<0m:Yb0?>/N@3c[7T00`3c[7T20?:[NP<001>S3@0[DlL00`000000b:Rj0<RX^P08
0<RX^QT0bZnn4`3=]/<>0=2ma`d0e<G;0`3HcLl2000000D0`/kS2P34f^X80<GXk`D0`_G_0`2cnn<2
093[_;00oooo00<0000009kFn`2Ne_/02@2Ne_/00`000000mljS0?O>X`080?[CW`L0o=JJ1@3nfI<5
0?oIR@<0oMQk00<000000?ooo`3oool0T03oool004<0oooo00<0000009n?``2OSl<0102OSl<00`00
0000n:UJ0?RYFP060?RYFPT0n:]S00<0mjUR0?N[J`3gZf/0203gZf/00`3fZFX0mJab0?F/LP040?F/
LPH0m:]b0P3dZW840?>/N@80lZ]j10004j<<02]Ca`0300000038Z;X0b:Rj00H0b:Rj6@3:[khC0<ff
``l0d;g73@3DaL/60=S=c`0300000032c^<0`/kS00/0a=[Z1`35j>l60<;ek`<0/o_S00<0T>^l0?oo
o`3oool0/@3oool00`000000W]Kk09kFn`0909kFn`030000003jdil0n]>O00L0n]>O1`3leYX50?kI
T`D0omV90P3mf7/00`000000oooo0?ooo`2A0?ooo`00@`3oool00`000000Who309n?``0409n?``03
0000003hZEX0n:UJ00H0n:UJ203hZf<20?NYHPT0mj][0`3fZFX50?F/LPH0m:]b0`3dZW830?>/N@<0
lZ]j0`004j<302EJc`X0:e?700<000000<RX^P38Z;X01038Z;XI0<Z__Q<0cKK33`3@_LL=0=C5b`P0
f<g?0P0000090<CJjPP0aNS_1@32mNl40;?kh`03093[_03oool0oooo0;<0oooo0P00000:09kFn`80
00001`3jdil70?cFVPD0o]VC1@3ofHT00`3mf7/000000?ooo`2C0?ooo`00A03oool00`000000Who3
09n?``0309n?``030000003hZEX0n:UJ00H0n:UJ1`3hZf<40?NYHPP0mj][0`3fZFX50?F/LPD0m:]b
103dZW800`3cZG<0ljai0?>/N@030?:[NP@001>S1@0UF/l702]Ca`0300000038Z;X0b:Rj0080b:Rj
6P3:[khC0<ff``l0d;g73@3DaL/90=S=c`80g=OB00<000000<CJjP34f^X01@34f^X80<GXk`D0`_G_
0`2cnn<2093[_;P0oooo00<0000009kFn`2Ne_/01P2Ne_/309;PoP8000001@3jdil60?cFVPH0o]VC
103ofHT2000009D0oooo00140?ooo`030000002OSl<0Who300@0Who300<000000?RYFP3hZEX01P3h
ZEX50?R[H`D0mjUR1`3gZf/50?JYJP<0mJab1P3dZg840?BZLP80ljUc00<0ljai0?:[NP3bZgX00P3b
ZgX3000CX`T09E[?0`0[DlL00`000000b:Rj0<RX^P0J0<Z__Q@0cKK33`3@_LL=0=C5b`X0f<g?0`3L
em800`000000a=[Z0<CJjP030<CJjPL0aNS_1@32mNl40;?kh`03093[_02eg7<0oooo0;T0oooo00<0
000009kFn`2Ne_/00P2Ne_/809;PoP8000000P3jdil70?cFVPH0o]VC0P3ofHT2000009L0oooo0015
0?ooo`030000002OSl<0Who300<0Who300<000000?RYFP3hZEX01P3hZEX40?R[H`L0mjUR1P3gZf/5
0?JYJP<0mJab1P3dZg840?BZLP<0ljUc103bZgX010004Il001>S000CX`004j<;02EJc`0302]Ca`00
0000bZnn01T0bZnn503=]/<?0=2ma`d0e<G;2P3HcLl50=cGdP0300000034f^X0a=[Z00P0aNS_1@32
mNl40;?kh`03093[_03Fmj<0oooo0;/0oooo0P00000<09;PoP8000001`3leYX60?kIT`030?oIR@00
0000oooo09P0oooo00150?ooo`030000002OSl<0Who300@0Who300<000000?RYFP3hZEX01@3hZEX3
0?R[H`P0mjUR1@3gZf/70?JYJP80mJab1P3dZg840?BZLP<0ljUc0P3bZ7<30?:[NP03000AW`004j<0
01>S00`09E[?00<000000<Z__P3:[kh05P3:[khD0<ff`a00d;g73@3DaL/:0=S=c`L0g=OB0P000006
0<GXk`H0`_G_0`2cnn<2000000030=KgX`2eg7<0oooo0;d0oooo0P00000<09;PoP<00000103leYX5
0?kIT`800000VP3oool004H0oooo00<0000009n?``2OSl<00`2OSl<00`000000n:UJ0?RYFP060?RY
FP030?R[H`3gZF80mjUR00L0mjUR103gZf/90?JYJPL0m:]b103dZW830?>YL`<0lZQc0`3bZgX00`00
4Il001>S000CX`0<02EJc`030000003:[kh0bZnn01@0bZnn503=]/<@0=2ma`d0e<G;2P3HcLl80=cG
dP80hN;D0`0000020<GXk`D0`_G_0`2cnn<2000000030>Gl`03Fmj<0e_NS0<40oooo0P00000909;P
oP@0M^3`0`0000000`3leYX0o]VC0?kIT`03000009`0oooo00160?ooo`030000002OSl<0Who300<0
Who300<000000?RYFP3hZEX01P3hZEX;0?NYHP<0mj][2@3fZFX60?B[LPD0m:Yb0`3cZG<40?:XL`80
lZ]j0P004Il2000CX``09E[?00<000000<Z__P3:[kh04P3:[khD0<ff`a00d;g73@3DaL/:0=S=c`T0
g=OB1@3Qh]@:000000<0iOc000<0e_NS0;GLL`3oool0`P3oool2000000@0T^3n2P1fh?03000009l0
oooo00160?ooo`030000002OSl<0Who300@0Who300<000000?RYFP3hZEX01@3hZEX00`3gYUT0mjUR
0?NYHP080?NYHP80mj][2P3fZFX00`3eZ6/0m:]b0?B[LP030?B[LPD0m:Yb0`3cZG<40?:XL`80lZMd
00@0lZ]j000AW`004Il001>S300UF/l00`000000bZnn0<Z__P0@0<Z__QD0cKK33`3@_LL>0=C5b`X0
f<g?2@3Lem860>7Re0D0i^gC103Xmlh30>Gl`080e_NSaP3oool5000000D0M^3`1000002R0?ooo`00
A`3oool00`000000Who309n?``0309n?``030000003hZEX0n:UJ00@0n:UJ0P3gYUT;0?NYHP030?N[
J`3fZFX0mZUZ00P0mZUZ0P3eZ6/40?B[LPD0m:Yb0`3cZG<40?:XL`<0lZMd0`004Il00`004j<09E[?
02EJc`0:02EJc`030000003:[kh0bZnn00h0bZnn5@3=]/<?0=2ma`h0e<G;2`3HcLl80=cGdPL0hN;D
1@3VkM<40>SgcP<0iOc000<0e_NS0;GLL`3oool0bP3oool500000:H0oooo00170?ooo`030000002O
Sl<0Who300<0Who300<000000?RYFP3hZEX00`3hZEX40?NVF@X0mjUR2P3fZFX40?FXJ`<0m:]b1@3d
ZW830?>YL`@0lZQc0`3bYg@0103aYgH0016O000AW`004Il<02EJc`030000003:[kh0bZnn00`0bZnn
5@3=]/<@0=2ma`h0e<G;2`3HcLl80=cGdPL0hN;D1@3VkM<40>SgcP<0iOc000<0e_NS0;GLL`3oool0
o`3ooomg0?ooo`00B03oool00`000000Who309n?``0309n?``040000003hZEX0n:UJ0?RYFPD0mjII
2P3gZF800`3fYf80mZUZ0?JYJP070?JYJP@0mJQ[0`3dZg850?BZLP<0ljUc103bZ7<30?:WM080lJMf
0`004Il<02EJc`030000003:[kh0bZnn00X0bZnn5@3=]/<@0=2ma`h0e<G;2`3HcLl90=cGdPH0hN;D
1@3VkM<40>SgcP<0iOc00P3Fmj?o0?ooogT0oooo00180?ooo`030000002OSl<0Who300<0Who300@0
00000?RYFP3hZEX0n:UJ1P3gYUT80?NYHP<0mZMR203fZFX50?FXJ`030?B[LP3dZW80m:Yb00<0m:Yb
103cZG<40?:XL`@0lZMd00@0lJMf000:T`004Il0016O0P0IG]@;02EJc`030000003:[kh0bZnn00P0
bZnn5@3=]/<@0=2ma`l0e<G;2P3HcLl90=cGdPL0hN;D1@3VkM<40>SgcP<0iOc000<0e_NS0;GLL`3o
ool0o`3ooomh0?ooo`00B@3oool00`000000Who309n?``0209n?``030000003hZEX0n:UJ00L0mjII
203gZF830?JWHPL0mZUZ1`3eZ6/50?BZLP@0ljUc1@3bZ7<30?:WM080lJMf00<000ZC000AW`004Il0
100IG]@802EJc`030000003:[kh0bZnn00H0bZnn5P3=]/<@0=2ma`l0e<G;2P3HcLl90=cGdPL0hN;D
1@3VkM<40>SgcP<0iOc00P3Fmj?o0?ooogX0oooo00190?ooo`030000002OSl<0Who300<0Who300<0
00000?NVF@3gYUT01`3gYUT70?NYHP@0mZMR1P3fZFX70?FXJ`D0m:Yb103cZG<50?:XL`<0lZMd0`3a
YgH00`002Y<0016O000AW`0601UNe0H09E[?00<000000<Z__P3:[kh0103:[khF0<ff`a00d;g73`3D
aL/:0=S=c`T0g=OB1`3Qh]@50>K]d`D0j?O>0`3Uo<000`3Fmj<0]Mac0?ooo`3o0?ooogT0oooo0019
0?ooo`030000002OSl<0Who30080Who300<0XIS;0000003gYUT0203gYUT60?NYHPH0mZMR1@3fZFX7
0?FXJ`030?BWJ`3dZW80m:Yb0080m:Yb1@3cZG<40?:XL`<0lZMd103aYgH00`002Y<0016O01UNe007
01UNe0@09E[?00<000000<Z__P3:[kh00P3:[khF0<ff`a40d;g73`3DaL/;0=S=c`T0g=OB1`3Qh]@5
0>K]d`@0j?O>0`3Uo<020=KgXol0ooooN`3oool004X0oooo00<000000:6Hb`2QV</00`2QV</00`00
0000mjII0?NVF@060?NVF@H0mjUR1P3fYf850?JYJPL0mJQ[0P3dYf/30?BZLPD0ljUc103bZ7<30?:W
M0@0lJMf00<0l:Mg000:T`004Il02P0IG]@202EJc`030000003:[kh0bZnn01H0cKK34@3@_LL?0=C5
b`/0f<g?2@3Lem870>7Re0D0i^gC103Xmlh40>Gl`0030=KgX`2eg7<0oooo0?l0ooooNP3oool004X0
oooo00<000000:6Hb`2QV</00`2QV</00`000000mjII0?NVF@070?NVF@@0mjUR203fYf830?JYJPP0
mJQ[0`3dYf/20?BZLPD0ljUc103bZ7<40?:WM0<0lJMf0P3`YgL00`002Y<0016O01UNe00;01UNe003
0000003=]/<0cKK301@0cKK34@3@_LL?0=C5b`/0f<g?2@3Lem870>7Re0H0i^gC103Xmlh30>Gl`080
e_NSo`3oooml0?ooo`00B`3oool00`000000XIS;0:6Hb`030:6Hb`030000003gYUT0mjII00H0mjII
103gZF880?JWHP<0mZUZ1`3eZ6/40?BWJ`80m:Yb1@3cZG<40?:XL`@0lZMd103aYgH20?2WM`03000:
T`004Il06EkD00X06EkD00<000000<ff``3=]/<04`3=]/<A0=2ma`l0e<G;2`3HcLl90=cGdPP0hN;D
1@3VkM<40>SgcP<0iOc00P3Fmj<00`2eg7<0oooo0?ooo`3o0?ooogX0oooo001;0?ooo`030000002Q
V</0XIS;00<0XIS;00<000000?NVF@3gYUT01`3gYUT20?NYHPX0mZMR0P3fZFX70?FXJ`D0m:M[00<0
m:Yb0?>YL`3cZG<00`3cZG<40?:XL`@0lZMd103aYgH20?2WM`8000ZC300IG]@00`000000cKK30<ff
``0A0<ff`a40d;g73`3DaL/;0=S=c`X0g=OB1`3Qh]@50>K]d`D0j?O>0`3Uo<020=KgXol0ooooO@3o
ool004`0oooo00<000000:6Hb`2QV</00`2QV</00`000000mjII0?NVF@060?NVF@80mjUR2`3fYf88
0?FXJ`H0m:M[1@3cZG<40?:XL`@0lZMd103aYgH30?2WM`8000ZC300IG]@00`000000cKK30<ff``0>
0<ff`a80d;g73`3DaL/;0=S=c`X0g=OB1`3Qh]@60>K]d`@0j?O>0`3Uo<020=KgX`030;GLL`3oool0
oooo0?l0ooooN`3oool004`0oooo00<000000:6Hb`2QV</00`2QV</00`000000mjII0?NVF@070?NV
F@030?NYHP3fYf80mZMR00T0mZMR203eZ6/60?BWJ`030?>VK03cZG<0ljUc0080ljUc103bZ7<50?:W
M0<0lJMf103`YgL2000:T`/06EkD00<000000<ff``3=]/<03@3=]/<B0=2ma`l0e<G;303HcLl90=cG
dPP0hN;D1@3VkM<40>SgcP@0iOc00P3Fmj?o0?ooogh0oooo001=0?ooo`030000002QV</0XIS;00<0
XIS;00<000000?NVF@3gYUT01P3gYUT<0?JWHP030?FUHP3eZ6/0mJQ[00D0mJQ[1P3dYf/20?>VK0<0
ljUc103bZ7<50?:WM0@0lJMf103`YgL00`002Y<01ekF00MNeP0:01UNe0030000003=]/<0cKK300/0
cKK34P3@_LL?0=C5b``0f<g?2@3Lem880>7Re0D0i^gC1@3Xmlh30>Gl`080e_NS00<0]Mac0?ooo`3o
ool0o`3oooml0?ooo`00C@3oool00`000000XIS;0:6Hb`030:6Hb`030000003gYUT0mjII00H0mjII
00<0mZ=H0?JWHP3fYf802@3fYf820?FUHPD0mJQ[1`3dYf/30?>VK080ljUc103bZ7<50?:WM0@0lJMf
103`YgL00`3`YgT000ZC00MNeP0200MNePT06EkD00<000000<ff``3=]/<02@3=]/<B0=2ma`l0e<G;
303HcLl:0=cGdPL0hN;D1P3VkM<40>SgcP@0iOc000<0e_NS0;GLL`3oool0o`3ooomn0?ooo`00CP3o
ool00`000000XIS;0:6Hb`030:6Hb`030000003gYUT0mjII00@0mjII0P3fXeP:0?JWHP<0mJER1@3e
Z6/70?BWJ`@0ljI/00<0ljUc0?:XL`3bZ7<00`3bZ7<40?:WM0@0lJMf103`YgL20?2WN@03000:T`07
G]H01ekF00801ekF1`0IG]@00`000000cKK30<ff``080<ff`a40d;g7403DaL/<0=S=c`X0g=OB1`3Q
h]@60>K]d`D0j?O>0`3Uo<020=KgX`030;GLL`3oool0oooo0?l0ooooO@3oool004h0oooo00<00000
0:6Hb`2QV</00`2QV</00`000000mjII0?NVF@040?NVF@<0mZ=H2@3fYf840?FUHP@0mJQ[1`3dYf/5
0?>VK0D0lZQc103bYg@50?6WMP@0l:Mg0P3`YgT00`002Y<01ekF00MNeP0300MNePH06EkD00<00000
0<ff``3=]/<01@3=]/<B0=2maa40e<G;2`3HcLl:0=cGdPP0hN;D1@3VkM<50>SgcP<0iOc00P3Fmj<0
0`2eg7<0oooo0?ooo`3o0?ooogh0oooo001?0?ooo`030000002QV</0XIS;00<0XIS;00<000000?NV
F@3gYUT00`3gYUT40?JSF0P0mZMR103eYF840?FXJ`L0m:M[1@3cYV`20?:UK@<0lZQc1@3bYg@40?6W
MP@0l:Mg0`3`YgT00`002Y<01ekF00MNeP0500MNeP@06EkD00<000000<ff``3=]/<00`3=]/<B0=2m
aa40e<G;2`3HcLl:0=cGdPP0hN;D1P3VkM<40>SgcP@0iOc00P3Fmj<00`2eg7<0oooo0?ooo`3o0?oo
ogh0oooo001?0?ooo`030000002QV</0XIS;00<0XIS;00<000000?NVF@3gYUT00P3gYUT50?JSF0P0
mZMR1@3eYF830?FXJ`L0m:M[1@3cYV`30?:UK@80lZQc1@3bYg@40?6WMP@0l:Mg103`YgT900MNeP80
6EkD00<000000<ff``3=]/<00P3=]/<B0=2maa40e<G;303HcLl:0=cGdPL0hN;D1P3VkM<50>SgcP<0
iOc00P3Fmj<00`2eg7<0oooo0?ooo`3o0?ooogl0oooo001@0?ooo`030000002QV</0XIS;00<0XIS;
00@000000?NVF@3gYUT0mjII1P3fXeP60?JWHPL0mJER0P3eZ6/70?BWJ`D0ljI/103bYFd00`3bZ7<0
lZMd0?:WM0030?:WM0@0lJMf1@3`YgL30?2WN@030>nWNP07G]H01ekF00P01ekF00@06EkD0000003=
]/<0cKK34P3@_LLA0=C5b``0f<g?2P3Lem880>7Re0D0i^gC1@3Xmlh40>Gl`080e_NS00<0]Mac0?oo
o`3oool0o`3ooomo0?ooo`00D03oool00`000000XIS;0:6Hb`030:6Hb`040000003gYUT0mjII0?NV
F@H0mZ=H1P3fYf870?FUHP030?FXJ`3dYf/0m:M[00H0m:M[1@3cYV`50?:UK@D0lZMd1@3aYgH40?2W
M`@0l:Mi00<0kjMj00MNeP07G]H02@07G]H00`000000d;g70=2ma`0@0=2maa40e<G;303HcLl:0=cG
dPP0hN;D1P3VkM<50>SgcP<0iOc00P3Fmj<00`2eg7<0oooo0?ooo`3o0?oooh00oooo001A0?ooo`03
0000002QV</0XIS;00<0XIS;00<000000?NVF@3fXeP01`3fXeP50?JWHPP0mJER203dYf/50?>VK0D0
lZE]0P3aY6l30?:WM0D0lJMf103`YgL40?2WN@80kjMj2P07G]H00`000000d;g70=2ma`0?0=2maa40
e<G;303HcLl:0=cGdPP0hN;D1P3VkM<50>SgcP@0iOc00P3Fmj<00`2eg7<0oooo0?ooo`3o0?oooh00
oooo001A0?ooo`030000002QV</0XIS;00<0XIS;00<000000?NVF@3fXeP01`3fXeP40?JWHPT0mJER
1`3dYf/60?>VK0D0lZE]103aY6l20?:WM0@0lJMf1@3`YgL40?2WN@80kjMj00<005S@00MNeP07G]H0
1`07G]H00`000000d;g70=2ma`0=0=2maa40e<G;303HcLl;0=cGdPP0hN;D1P3VkM<40>SgcP@0iOc0
0P3Fmj<00`2eg7<0oooo0?ooo`3o0?oooh40oooo001B0?ooo`030000002QV</0XIS;00<0XIS;00<0
00000?JSF03fXeP01`3fXeP30?JWHPT0mJER00<0m:=S0?BWJ`3dYf/0103dYf/60?>VK0D0lZE]1P3a
Y6l40?6WMPD0l:Mg103`YgT30>nWNP8005S@2007G]H00`000000d;g70=2ma`0;0=2maa40e<G;303H
cLl;0=cGdPP0hN;D1P3VkM<50>SgcP<0iOc00`3Fmj<00`2eg7<0oooo0?ooo`3o0?oooh40oooo001B
0?ooo`030000002QV</0XIS;0080XIS;00<0Xj3B0000003fXeP02@3fXeP20?JWHPT0mJER0P3dXf<5
0?BWJ`H0ljI/1P3bYFd50?6TK`80l:=a0`3aYgH40?2WM`@0l:Mi103_YgX3001Hd0L01ekF00<00000
0=2ma`3@_LL02@3@_LLA0=C5b`d0f<g?2P3Lem880>7Re0H0i^gC1@3Xmlh40>Gl`080e_NS00<0]Mac
0?ooo`3oool0o`3ooon20?ooo`00D`3oool00`000000Xj3B0:>PdP030:>PdP030000003fXeP0mZ=H
00L0mZ=H0P3fYf890?FUHP<0m:=S103dYf/60?>VK0H0lZE]1@3aY6l50?2SL@D0l:Mg103`YgT0103_
YgX0kZ=g0>jSM`3^XgL4001Hd0H01ekF00<000000=2ma`3@_LL01`3@_LLA0=C5b`d0f<g?2P3Lem89
0>7Re0H0i^gC1@3Xmlh30>Gl`0<0e_NS00<0]Mac0?ooo`3oool0o`3ooon20?ooo`00D`3oool00`00
0000Xj3B0:>PdP030:>PdP030000003fXeP0mZ=H00P0mZ=H2P3eYF840?BSH`<0m:M[1P3cYV`60?:U
K@H0lJA_103`Xg440>nSL`030?2WM`3`YgT0l:Mi0080kj=e1@3^XgL5001Hd0@01ekF00<000000=2m
a`3@_LL01P3@_LLA0=C5b`d0f<g?2`3Lem880>7Re0H0i^gC1@3Xmlh40>Gl`080e_NS00<0]Mac0?oo
o`3oool0o`3ooon30?ooo`00E03oool00`000000Xj3B0:>PdP030:>PdP030000003fXeP0mZ=H00L0
mZ=H2P3eYF850?BSH`80m:M[1`3cYV`50?:UK@H0lJA_103`Xg450>nSL`D0kj=e1@3^XgL6001Hd0<0
1ekF00<000000=2ma`3@_LL0103@_LLA0=C5b`d0f<g?2`3Lem880>7Re0H0i^gC1@3Xmlh40>Gl`080
e_NS00<0]Mac0?ooo`3oool0o`3ooon40?ooo`00E@3oool00`000000Xj3B0:>PdP030:>PdP030000
003fXeP0mZ=H00H0mZ=H00<0mJ5I0?FUHP3eYF801`3eYF860?BSH`030?BWJ`3cYV`0ljI/00D0ljI/
1@3bYFd60?6TK`D0l:=a1@3_Xg<40>nSM@D0kZ=g00<0kJ=j001Hd000F=001@00F=0200MNeP030000
003@_LL0d;g70080d;g74P3DaL/<0=S=c`/0g=OB2@3Qh]@60>K]d`D0j?O>0`3Uo<030=KgX`030;GL
L`3oool0oooo0?l0ooooQ03oool005D0oooo00<000000:>PdP2SX=800`2SX=800`000000mZ=H0?JS
F0060?JSF080mJ5I203eYF870?BSH`L0ljI/1P3bYFd50?6TK`D0l:=a1@3_Xg<50>nSM@D0kZ=g0P3]
XgX7001Hd00400MNeP000000d;g70=2maa80e<G;303HcLl<0=cGdPP0hN;D1P3VkM<50>SgcP@0iOc0
0P3Fmj<00`2eg7<0oooo0?ooo`3o0?ooohD0oooo001F0?ooo`030000002SX=80Xj3B00<0Xj3B00<0
00000?JSF03fXeP01@3fXeP30?FQF@L0mJER1`3dXf<70?>VK0H0lZE]1@3aY6l50?2SL@D0kj=c1@3_
XgD50>jSM`<0kJ=j00<004Zm001Hd000F=001@00F=000`000000e<G;0=C5b`0@0=C5b`d0f<g?2`3L
em880>7Re0H0i^gC1P3Xmlh30>Gl`0<0e_NS00<0]Mac0?ooo`3oool0o`3ooon50?ooo`00EP3oool0
0`000000Xj3B0:>PdP030:>PdP030000003fXeP0mZ=H00@0mZ=H103eXET60?FUHPP0m:=S00<0lj9T
0?>VK03cYV`0103cYV`60?:UK@H0lJA_103`Xg460>nSL`@0kj=e1P3^XgL40>fSNP03001:_@00F=00
05S@00@005S@00<000000=C5b`3DaL/03P3DaL/=0=S=c`/0g=OB2@3Qh]@60>K]d`D0j?O>103Uo<02
0=KgX`030;GLL`3oool0oooo0?l0ooooQP3oool005L0oooo00<000000:>PdP2SX=800`2SX=800`00
0000mZ=H0?JSF0030?JSF0D0mJ5I1@3eYF880?BSH`80lj9T1@3cYV`60?:UK@H0lJA_1@3`Xg450>nS
L`D0kj=e1@3^XgL50>fSNP03001:_@00F=0005S@00@005S@00<000000=C5b`3DaL/0303DaL/=0=S=
c`/0g=OB2@3Qh]@60>K]d`D0j?O>103Uo<030=KgX`030;GLL`3oool0oooo0?l0ooooQP3oool005P0
oooo00<000000:>PdP2SX=800`2SX=800`000000mZ=H0?JSF0020?JSF0H0mJ5I103eYF880?BSH`<0
lj9T103cYV`60?:UK@H0lJA_1@3`Xg450>nSL`D0kj=e1P3^XgL50>fSNP8004Zm1@00F=000`000000
e<G;0=C5b`0:0=C5b`d0f<g?303Lem880>7Re0H0i^gC1P3Xmlh40>Gl`080e_NS00<0]Mac0?ooo`3o
ool0o`3ooon70?ooo`00F03oool00`000000Xj3B0:>PdP030:>PdP030000003fXeP0mZ=H0080mZ=H
1`3eXET30?FUHPP0m:=S103cXV@30?>VK0H0lZE]1P3aY6l50?2SL@H0kj=c1@3_XgD50>jSM`L0kJ=j
0P00B[d4001Hd0030000003DaL/0e<G;00P0e<G;3@3HcLl<0=cGdPT0hN;D1P3VkM<50>SgcP@0iOc0
0`3Fmj<00`2eg7<0oooo0?ooo`3o0?ooohL0oooo001I0?ooo`030000002SX=80Xj3B00<0Xj3B00@0
00000?JSF03fXeP0mZ=H1`3eXET30?FUHPP0m:=S1@3cXV@20?>VK0L0lZE]1P3aY6l40?2SL@H0kj=c
1@3_XgD60>jSM`H0kJ=j00@0k:Al001:_@00B[d004Zm0`00F=000`000000e<G;0=C5b`060=C5b`d0
f<g?303Lem890>7Re0H0i^gC1P3Xmlh30>Gl`0<0e_NS00<0]Mac0?ooo`3oool0o`3ooon80?ooo`00
FP3oool00`000000Xj3B0:>PdP020:>PdP040000003fXeP0mZ=H0?JSF0P0mJ5I0P3eYF880?BSH`H0
lj9T00<0ljI/0?:UK@3bYFd01@3bYFd60?6TK`D0l:=a1@3_Xg<60>nSM@D0kZ=g1`3]XgX20>bTO0<0
04Zm0P00F=000`000000e<G;0=C5b`040=C5b`h0f<g?2`3Lem890>7Re0L0i^gC1@3Xmlh40>Gl`0<0
e_NS00<0]Mac0?ooo`3oool0o`3ooon80?ooo`00FP3oool00`000000Xj3B0:>PdP030:>PdP030000
003fXeP0mZ=H00T0mJ5I00<0mJER0?BSH`3dXf<01P3dXf<70?>RI0L0lZE]1P3aY6l50?2SL@H0kj=c
1@3_XgD60>jSM`H0kJ=j103/Y7`2001:_@8005S@00<000000=C5b`3DaL/00P3DaL/>0=S=c``0g=OB
2@3Qh]@60>K]d`D0j?O>103Uo<030=KgX`030;GLL`3oool0oooo0?l0ooooR@3oool005/0oooo00<0
00000:>PdP2SX=800`2SX=800`000000mJ5I0?FQF@090?FQF@P0m:=S1`3cXV@20?:QIPD0lZE]1P3a
Y6l50?2SL@H0kj=c1@3_XgD60>jSM`L0kJ=j103/Y7`3001:_@04001Hd0000000e<G;0=C5b`h0f<g?
303Lem890>7Re0H0i^gC1P3Xmlh40>Gl`0<0e_NS00<000000?ooo`3oool0o`3ooon90?ooo`00F`3o
ool00`000000Xj3B0:>PdP030:>PdP030000003eXET0mJ5I00T0mJ5I2@3dXf<60?>RI0<0lZ5V103b
YFd60?6TK`H0l:=a1@3_Xg<60>nSM@H0kZ=g1`3]XgX30>bTO080jZ1k0`00B[d2000000d0f<g?303L
em890>7Re0L0i^gC1@3Xmlh40>Gl`0<0e_NS00<0]Mac0000003oool0o`3ooon:0?ooo`00G03oool0
0`000000Xj3B0:>PdP030:>PdP030000003eXET0mJ5I00P0mJ5I00<0m9mJ0?BSH`3dXf<01P3dXf<6
0?>RI0D0lZ5V0`3bYFd60?6TK`D0l:=a1P3_Xg<50>nSM@H0kZ=g1`3]XgX30>bTO0@0jZ1k0`00B[d0
0`000000f<g?0=S=c`090=S=c``0g=OB2P3Qh]@60>K]d`H0j?O>103Uo<020=KgX`030;GLL`000000
oooo0?l0ooooR`3oool005d0oooo00<000000:>PdP2SX=800P2TZMX00`000000mJ5I0?FQF@080?FQ
F@80m9mJ1`3dXf<70?>RI0H0lZ5V00<0lZE]0?6TK`3aY6l0103aY6l50?2SL@H0kj=c1P3_XgD60>jS
M`L0kJ=j00<0k:Al0>ZPN`3ZX7/0103ZX7/3001:_@030000003HcLl0f<g?00L0f<g?3@3Lem890>7R
e0H0i^gC1P3Xmlh40>Gl`0<0e_NS00<000000?ooo`3oool0o`3ooon;0?ooo`00G@3oool00`000000
Y:WJ0:BYfP030:BYfP030000003eXET0mJ5I00L0mJ5I0`3dWeX60?BSH`L0lj9T1`3bXFH60?6TK`D0
l:=a1P3_Xg<60>nSM@H0kZ=g1P3]XgX00`3[X7P0jZ1k0>ZPN`070>ZPN`8004Zm00<000000=S=c`3H
cLl01P3HcLl<0=cGdPT0hN;D1`3VkM<50>SgcP@0iOc00`3Fmj<00`000000oooo0?ooo`3o0?oooh`0
oooo001N0?ooo`030000002TZMX0Y:WJ00<0Y:WJ00<000000?FQF@3eXET01P3eXET40?BOFPD0m:=S
1`3cXV@70?:QIP80lJ1X103aY6l60?2SL@H0kj=c1P3_XgD60>jSM`@0kJ=j0`3[X7P80>ZPN`040>VQ
OP00B[d004Zm000000H0f<g?303Lem890>7Re0L0i^gC1P3Xmlh40>Gl`0<0e_NS00<000000?ooo`3o
ool0o`3ooon<0?ooo`00G`3oool00`000000Y:WJ0:BYfP020:BYfP030000003eXET0mJ5I00H0mJ5I
1@3dWeX40?BSH`L0lj9T1`3bXFH40?6PJ080lJA_1P3`Xg460>nSL`H0kj=e1P3^XgL30>fSNPD0jj1h
203ZX7/20>VQOP03001:_@000000f<g?00<0f<g?303Lem8:0>7Re0H0i^gC1P3Xmlh40>Gl`0<0e_NS
00<000000?ooo`3oool0o`3ooon=0?ooo`00G`3oool00`000000Y:WJ0:BYfP030:BYfP030000003e
XET0mJ5I00D0mJ5I1P3dWeX30?BSH`L0lj9T1`3bXFH50?6PJ080lJA_1@3`Xg460>nSL`H0kj=e1`3^
XgL00`3]XgX0jj1h0>^PN0040>^PN0T0jZ1k0`3YXGh00`000000f<g?0=S=c`0=0=cGdPT0hN;D1`3V
kM<60>SgcP@0iOc000<0e_NS000000000000o`3ooon@0?ooo`00H03oool00`000000Y:WJ0:BYfP03
0:BYfP030000003eXET0mJ5I00@0mJ5I1`3dWeX20?BSH`L0lj9T203bXFH60?6PJ0D0l:=a1`3_Xg<6
0>nSM@D0kZ=g00<0k9md0>^PN03[X7P01P3[X7P80>ZPN`@0jJ5n0P00000<0=cGdPT0hN;D1`3VkM<6
0>SgcP@0iOc000<0e_NS0000003oool0o`3ooonA0?ooo`00H@3oool00`000000Y:WJ0:BYfP020:BY
fP030000003eXET0mJ5I00@0mJ5I203dWeX00`3dXf<0lj9T0?>RI0050?>RI0P0lZ5V1P3aX6P30?2O
J`<0l:=a1P3_Xg<60>nSM@<0kZ=g103/Wg@70>^PN0T0jZ1k1@3YXGh2000000T0g=OB2P3Qh]@60>K]
d`H0j?O>1@3Uo<000`000000oooo0?ooo`3o0?oooi40oooo001Q0?ooo`030000002TZMX0Y:WJ00<0
Y:WJ00<000000?FQF@3eXET00P3eXET:0?BOFPP0lj9T1`3bXFH60?6PJ0H0l9m[1P3_Xg<70>nSM@03
0>jSM`3/Wg@0k9md00<0k9md203[X7P90>ZPN`H0jJ5n0P0000060=cGdPX0hN;D1`3VkM<60>SgcP@0
iOc000<000000?ooo`3oool0o`3ooonB0?ooo`00HP3oool00`000000Y:WJ0:BYfP030:BYfP040000
003eXET0mJ5I0?FQF@X0m9mJ00<0lYiL0?>RI03cXV@01@3cXV@70?:QIPL0lJ1X1@3`Wf/50>jOKP80
kj=c0`3_XgD30>fOL@L0k9md203[X7P80>ZPN`P0jJ5n00<000000=cGdP3Lem800`3Lem890>7Re0L0
i^gC1P3Xmlh40>Gl`0030000003oool0oooo0?l0ooooT`3oool006<0oooo00<000000:BYfP2TZMX0
0P2TZMX010000000mJ5I0?FQF@3eXET:0?BOFP80lYiL1P3cXV@70?:QIPL0lJ1X1P3`Wf/60>jOKPL0
kIma1P3/Wg@80>^PN0T0jZ1k1`3YXGh00`3WWWd00000000000020=cGdPX0hN;D1`3VkM<60>SgcP80
iOc00P00003o0?oooiH0oooo001S0?ooo`030000002TZMX0Y:WJ00<0Y:WJ00<000000?FQF@3eXET0
2P3dWeX30?:NG0D0lj9T203bXFH60?6PJ0H0l9m[1`3^Wfh60>fOL@L0k9md203[X7P90>ZPN`D0jJ5n
103WWWd2000000T0hN;D1`3VkM<60>SgcP030>Gl`000000000000?l0ooooV03oool006@0oooo00<0
00000:BYfP2TZMX00`2TZMX00`000000mJ5I0?BOFP090?BOFP@0lYiL103cXV@80?:QIPH0lJ1X1P3`
Wf/70>jOKPL0kIma1`3/Wg@80>^PN0T0jZ1k103YXGh60>NNO@<000001@3Qh]@70>K]d`H0j?O>0P00
003o0?oooiX0oooo001U0?ooo`030000002TZMX0Y:WJ0080Y:WJ00<000000?FQF@3dWeX02@3dWeX5
0?:NG0<0lj9T203bXFH60?6PJ0L0l9m[1P3^Wfh70>fOL@L0k9md203[X7P90>ZPN`@0jJ5n203WWWd0
103VWh4000000000000000020>7Re0L0i^gC0P3Xmlh400000?l0ooooW03oool006D0oooo00<00000
0:BYfP2TZMX00`2TZMX00`000000m9mJ0?BOFP080?BOFPH0lYiL0P3cXV@80?:QIPL0lJ1X1P3`Wf/7
0>jOKPH0kIma203/Wg@80>^PN0T0jZ1k0P3YXGh:0>NNO@<0iYn12`00003o0?oooj00oooo001V0?oo
o`030000002TZMX0Y:WJ00<0Y:WJ00<000000?BOFP3dWeX01`3dWeX70?:NG080lj9T1`3bXFH70?6P
J0H0l9m[1`3^Wfh70>fOL@L0k9md203[X7P:0>ZPN`030>VQOP3WWWd0iiim00T0iiim2P3VWh400`00
0000oooo0?ooo`3o0?oooj00oooo001W0?ooo`030000002TZMX0Y:WJ0080YK?R00<000000?BOFP3d
WeX01`3dWeX80?:NG0030?>RI03bXFH0lZ5V00D0lZ5V1`3aX6P70?2OJ`L0kYm^1P3]Wg480>bOM0P0
jj1h2@3ZX7/<0>NNO@T0iYn100<000000?ooo`3oool0o`3ooonQ0?ooo`00I`3oool00`000000YK?R
0:FchP030:FchP030000003dWeX0m9mJ00H0m9mJ2@3bWU`80?:QIPH0lJ1X1`3`Wf/70>jOKPL0kIma
1`3/Wg@90>^PN0P0jZ1k00<0j9ei0>NNO@3WWWd02P3WWWd80>JOP@030000003oool0oooo0?l0oooo
X@3oool006P0oooo00<000000:FchP2U/n800`2U/n800`000000m9mJ0?BOFP050?BOFPT0lYiL0P3a
WEl60?:QIPL0lJ1X1P3`Wf/70>jOKPL0kIma203/Wg@80>^PN0L0jZ1k0`3XWGT<0>NNO@L0iYn100<0
00000?ooo`3oool0o`3ooonQ0?ooo`00J@3oool00`000000YK?R0:FchP030:FchP030000003dWeX0
m9mJ00D0m9mJ203bWU`30?6MG`D0lZ5V1`3aX6P70?2OJ`L0kYm^1`3]Wg470>bOM0T0jj1h1@3ZX7/5
0>RMN@`0iiim00<0iYn10000003VWh400P3VWh400`000000oooo0?ooo`3o0?oooj80oooo001Z0?oo
o`030000002U/n80YK?R00<0YK?R00<000000?BOFP3dWeX0103dWeX80?:NG0@0lIeO103bXFH70?6P
J0L0l9m[1`3^Wfh70>fOL@P0k9md203[X7P40>ZPN`L0j9ei303WWWd01@000000iYn10>JOP@3VWh40
00000?l0ooooY03oool006X0oooo00<000000:FchP2U/n80102U/n800`000000m9mJ0?BOFP030?BO
FPT0lYiL1@3aWEl20?:QIPL0lJ1X1`3`Wf/80>jOKPH0kIma203/Wg@90>^PN0<0jZ1k1`3XWGT=0>NN
O@<0iYn100<000000?ooo`3oool0o`3ooonR0?ooo`00J`3oool00`000000YK?R0:FchP040:FchP03
0000003dWeX0m9mJ0080m9mJ2@3bWU`60?6MG`80lZ5V1P3aX6P80?2OJ`L0kYm^1`3]Wg480>bOM0T0
jj1h00<0jZ1k0>RMN@3XWGT01`3XWGT=0>NNO@030>JOP@000000oooo0?l0ooooY03oool006`0oooo
00<000000:FchP2U/n800`2U/n800`000000m9mJ0?BOFP020?BOFPT0lYiL1`3aWEl00`3bXFH0lJ1X
0?6PJ0050?6PJ0L0l9m[1`3^Wfh70>fOL@T0k9md1`3[X7P00`3YW7D0j9ei0>RMN@090>RMN@d0iiim
00<000000?ooo`3oool0o`3ooonS0?ooo`00K@3oool00`000000YK?R0:FchP030:FchP040000003d
WeX0m9mJ0?BOFPT0lYiL203aWEl70?6PJ0L0l9m[203^Wfh70>fOL@P0k9md1P3[X7P30>VLM@/0j9ei
303WWWd00`000000oooo0?ooo`3o0?oooj<0oooo001^0?ooo`030000002U/n80YK?R00<0YK?R00<0
00000?BOFP3dWeX02@3bWU`80?6MG`80l9aR1@3aX6P80?2OJ`L0kYm^1`3]Wg490>bOM0@0jj1h1@3Y
W7D;0>RMN@X0iiim00<000000?ooo`3oool0o`3ooonT0?ooo`00KP3oool00`000000YK?R0:FchP04
0:FchP030000003dWeX0lYiL00P0lYiL203aWEl30?2LHP@0lJ1X203`Wf/70>jOKPP0kIma203/Wg@3
0>^PN0H0jIae2`3XWGT:0>NNO@030000003oool0oooo0?l0ooooY03oool006l0oooo00<000000:Fc
hP2U/n80102U/n800`000000lYiL0?:NG0070?:NG0P0lIeO1@3`W6820?6PJ0P0l9m[203^Wfh70>fO
L@T0k9md00<0jj1h0>VLM@3YW7D01P3YW7D;0>RMN@T0iiim00<000000?ooo`3oool0o`3ooonT0?oo
o`00L03oool00`000000YK?R0:FchP040:FchP800000203bWU`80?6MG`H0l9aR00<0lJ1X0?2OJ`3`
Wf/01P3`Wf/70>jOKPL0kIma203/Wg@00`3[W740jIae0>VLM@080>VLM@/0j9ei1`3WWWd00`000000
oooo0?ooo`3o0?ooojD0oooo001a0?ooo`030000002U/n80YK?R00D0YKg[00<000000?:NG03bWU`0
1@3bWU`80?6MG`L0l9aR203`Wf/80>jOKPL0kIma1@3/Wg@40>^LL@T0jIae303XWGT60>NNO@030000
003oool0oooo0?l0ooooY@3oool00780oooo00<000000:Fmj`2U_N/01@2U_N/00`000000lYiL0?:N
G0040?:NG0P0lIeO1`3`W6830>nKIPD0l9m[203^Wfh70>fOL@@0k9md1@3[W74:0>VLM@/0j9ei00<0
iiim0000003WWWd00`3WWWd00`000000oooo0?ooo`3o0?ooojD0oooo001c0?ooo`030000002U_N/0
YKg[00D0YKg[00<000000?:NG03bWU`00`3bWU`80?6MG`L0l9aR1P3_VfH30?2OJ`L0kYm^203]Wg40
0`3/Wg@0jiaa0>^LL@060>^LL@X0jIae2`3XWGT01@000000iiim0>NNO@3WWWd000000?l0ooooZ03o
ool007@0oooo00<000000:Fmj`2U_N/01@2U_N/00`000000lYiL0?:NG0020?:NG0P0lIeO203`W688
0>nKIPP0kYm^103]Wg430>bKK@X0jiaa2@3YW7D<0>RMN@<0iiim00<000000?ooo`3oool0o`3ooonV
0?ooo`00M@3oool00`000000YKg[0:Fmj`050:Fmj`040000003bWU`0lYiL0?:NG0T0lIeO1`3`W688
0>nKIPP0kI]Y203/Vfd90>^LL@X0jIae303XWGT20>NNO@030000003oool0oooo0?l0ooooYP3oool0
07H0oooo00<000000:Fmj`2U_N/01@2U_N/00`000000lYiL0?:NG0090?6MG`L0l9aR2@3_VfH80>fK
J@L0k9]]2P3[W74:0>VLM@`0j9ei00<000000?ooo`3oool0o`3ooonW0?ooo`00M`3oool00`000000
YKg[0:Fmj`050:Fmj`030000003bWU`0lYiL00P0lIeO203`W6880>nKIPP0kI]Y203/Vfd90>^LL@X0
jIae303XWGT00`000000oooo0?ooo`3o0?ooojL0oooo001h0?ooo`030000002U_N/0YKg[00D0YKg[
00<000000?:NG03aWEl01`3aWEl80?2LHPP0ki]V203]VfT80>bKK@X0jiaa2P3YW7D:0>RMN@030000
003oool0oooo0?l0ooooZ03oool007T0oooo00<000000:Fmj`2U_N/01@2U_N/00`000000lIeO0?6M
G`060?6MG`P0l9aR2@3_VfH80>fKJ@P0k9]]2P3[W74:0>VLM@P0j9ei00<000000?ooo`3oool0o`3o
oonY0?ooo`00NP3oool00`000000YKg[0:Fmj`050:Fmj`8000001P3aWEl90?2LHPP0ki]V203]VfT8
0>bKK@X0jiaa2P3YW7D80>RMN@030000003oool0oooo0?l0ooooZ@3oool007/0oooo00<000000:Fm
j`2U_N/00`2U_N/30:?9m0030000003aWEl0lIeO00@0lIeO203`W6880>nKIPT0kI]Y203/Vfd:0>^L
L@X0jIae1P3XWGT00`000000oooo0?ooo`3o0?ooojX0oooo001l0?ooo`8000001`2SbO@00`000000
lIeO0?6MG`030?6MG`P0l9aR2@3_VfH80>fKJ@P0k9]]2P3[W74;0>VLM@050000003XWGT0j9ei0>RM
N@000000o`3ooon]0?ooo`00OP3oool00`000000XlWd0:?9m0050:?9m0030000003aWEl0lIeO0080
lIeO2@3`W6880>nKIPT0kI]Y203/Vfd:0>^LL@X0jIae00D000000>RMN@3XWGT0j9ei0000003o0?oo
ojd0oooo001o0?ooo`030000002SbO@0XlWd00D0XlWd0P0000020?6MG`T0l9aR203_VfH90>fKJ@P0
k9]]2`3[W74:0>VLM@80j9ei00<000000?ooo`3oool0o`3ooon/0?ooo`00P03oool2000000L0XlWd
00<000000?6MG`3`W680203`W6890>nKIPP0kI]Y2@3/Vfd:0>^LL@X0jIae0P00003o0?ooojl0oooo
00220?ooo`030000002SbO@0XlWd00D0XlWd00<000000?6MG`3`W6801`3`W6890>nKIPT0kI]Y2@3/
Vfd:0>^LL@P0jIae00<000000?ooo`3oool0o`3ooon_0?ooo`00P`3oool2000000H0XlWd00<00000
0?2LHP3`W6801`3`W6880>nKIPT0kI]Y2@3/Vfd:0>^LL@L0jIae00<000000?ooo`3oool0o`3ooon`
0?ooo`00Q@3oool00`000000XlWd0:?9m0040:?9m08000001`3`W6890>nKIPT0kI]Y2@3/Vfd:0>^L
L@D0jIae00<000000?ooo`3oool0o`3ooona0?ooo`00QP3oool00`000000XlWd0:?9m0020:?9m0<0
W]Kk0P0000050?2LHPT0ki]V2@3]VfT90>bKK@/0jiaa0`3YW7D00`000000oooo0?ooo`3o0?oook80
oooo00270?ooo`8000001`2Ne_/2000000@0l9aR203_VfH90>fKJ@X0k9]]2P3[W7420>VLM@030000
003oool0oooo0?l0oooo/`3oool008T0oooo0P00000709kFn`040000003`W680l9aR0?2LHPT0ki]V
2@3]VfT90>bKK@X0jiaa0P00003o0?oookH0oooo002;0?ooo`<000001@2Ne_/2000000030?2LHP3_
VfH0ki]V00L0ki]V2@3]VfT:0>bKK@P0jiaa00<000000?ooo`3oool0o`3ooonf0?ooo`00SP3oool2
000000D0W]Kk0P0000080>nKIPX0kI]Y2@3/Vfd60>^LL@800000o`3oooni0?ooo`00T03oool20000
00D0W]Kk0`0000060>nKIPT0kI]Y2P3/Vfd30>^LL@800000o`3ooonk0?ooo`00TP3oool200000003
09kFn`2AhOh0TN7n00<0TN7n0`0000030>nKIPX0kI]Y2@3/Vfd20>^LL@030000003oool0oooo0?l0
oooo^`3oool009@0oooo0`000006097QoP<000002P3]VfT80>bKK@<00000o`3ooonn0?ooo`00U`3o
ool2000000L0TN7n1`0000030>fKJ@<0k9]]1@00003o0?oool40oooo002I0?ooo`<00000102AhOh7
07COk`H00000o`3oooo60?ooo`00W03oool<0000000307COk`3oool0oooo0?l0oooob03oool00?l0
ooooo`3ooomd0?ooo`00o`3ooooo0?ooog@0oooo003o0?ooool0ooooM03oool00?l0ooooo`3ooomd
0?ooo`00o`3ooooo0?ooog@0oooo003o0?ooool0ooooM03oool00?l0ooooo`3ooomd0?ooo`00o`3o
oooo0?ooog@0oooo003o0?ooool0ooooM03oool00001\
\>"],
  ImageRangeCache->{{{-70.9375, 688.062}, {538.812, -77.25}} -> {0.0972829, \
-0.0321446, 0.00131244, 0.00131244}},
  CellTags->"CompoundLens"]
}, Open  ]],

Cell[TextData[{
  "Once the ray-trace has been calculated, you can use ",
  StyleBox["ShowSystem", "Input"],
  " to render the information in different formats. In the next case, we will \
 use ",
  StyleBox["PlotType->RealTime3D", "Input"],
  " in order to rotate the graphical information in real-time with the \
mouse."
}], "Text",
  CellTags->"CompoundLens"],

Cell["ShowSystem[result, PlotType->RealTime3D];", "Input",
  CellTags->"CompoundLens"],

Cell[BoxData[
  Graphics3D[{
    Polygon[{{10.000000, 0.000000, 0.000000},{10.685966, 8.353050, 0.000000},{
      10.685966, 8.068427, 2.161929},{10.000000, 0.000000, 0.000000},{
      10.000000, 0.000000, 0.000000}}],
    Polygon[{{10.685966, 8.353050, 0.000000},{
      12.802159, 16.706100, 0.000000},{12.802159, 16.136854, 4.323857},{
      10.685966, 8.068427, 2.161929},{10.685966, 8.353050, 0.000000}}],
    Polygon[{{12.802159, 16.706100, 0.000000},{
      16.551481, 25.059153, 0.000000},{16.551481, 24.205282, 6.485786},{
      12.802159, 16.136854, 4.323857},{12.802159, 16.706100, 0.000000}}],
    Polygon[{{10.000000, 0.000000, 0.000000},{10.685966, 8.068427, 2.161929},{
      10.685966, 7.233954, 4.176525},{10.000000, 0.000000, 0.000000},{
      10.000000, 0.000000, 0.000000}}],
    Polygon[{{10.685966, 8.068427, 2.161929},{
      12.802159, 16.136854, 4.323857},{12.802159, 14.467908, 8.353050},{
      10.685966, 7.233954, 4.176525},{10.685966, 8.068427, 2.161929}}],
    Polygon[{{12.802159, 16.136854, 4.323857},{
      16.551481, 24.205282, 6.485786},{16.551481, 21.701862, 12.529576},{
      12.802159, 14.467908, 8.353050},{12.802159, 16.136854, 4.323857}}],
    Polygon[{{10.000000, 0.000000, 0.000000},{10.685966, 7.233954, 4.176525},{
      10.685966, 5.906499, 5.906499},{10.000000, 0.000000, 0.000000},{
      10.000000, 0.000000, 0.000000}}],
    Polygon[{{10.685966, 7.233954, 4.176525},{
      12.802159, 14.467908, 8.353050},{12.802159, 11.812998, 11.812998},{
      10.685966, 5.906499, 5.906499},{10.685966, 7.233954, 4.176525}}],
    Polygon[{{12.802159, 14.467908, 8.353050},{
      16.551481, 21.701862, 12.529576},{16.551481, 17.719496, 17.719496},{
      12.802159, 11.812998, 11.812998},{12.802159, 14.467908, 8.353050}}],
    Polygon[{{10.000000, 0.000000, 0.000000},{10.685966, 5.906499, 5.906499},{
      10.685966, 4.176525, 7.233954},{10.000000, 0.000000, 0.000000},{
      10.000000, 0.000000, 0.000000}}],
    Polygon[{{10.685966, 5.906499, 5.906499},{
      12.802159, 11.812998, 11.812998},{12.802159, 8.353050, 14.467908},{
      10.685966, 4.176525, 7.233954},{10.685966, 5.906499, 5.906499}}],
    Polygon[{{12.802159, 11.812998, 11.812998},{
      16.551481, 17.719496, 17.719496},{16.551481, 12.529576, 21.701862},{
      12.802159, 8.353050, 14.467908},{12.802159, 11.812998, 11.812998}}],
    Polygon[{{10.000000, 0.000000, 0.000000},{10.685966, 4.176525, 7.233954},{
      10.685966, 2.161929, 8.068427},{10.000000, 0.000000, 0.000000},{
      10.000000, 0.000000, 0.000000}}],
    Polygon[{{10.685966, 4.176525, 7.233954},{
      12.802159, 8.353050, 14.467908},{12.802159, 4.323857, 16.136854},{
      10.685966, 2.161929, 8.068427},{10.685966, 4.176525, 7.233954}}],
    Polygon[{{12.802159, 8.353050, 14.467908},{
      16.551481, 12.529576, 21.701862},{16.551481, 6.485786, 24.205282},{
      12.802159, 4.323857, 16.136854},{12.802159, 8.353050, 14.467908}}],
    Polygon[{{10.000000, 0.000000, 0.000000},{10.685966, 2.161929, 8.068427},{
      10.685966, 0.000000, 8.353050},{10.000000, 0.000000, 0.000000},{
      10.000000, 0.000000, 0.000000}}],
    Polygon[{{10.685966, 2.161929, 8.068427},{
      12.802159, 4.323857, 16.136854},{12.802159, 0.000000, 16.706100},{
      10.685966, 0.000000, 8.353050},{10.685966, 2.161929, 8.068427}}],
    Polygon[{{12.802159, 4.323857, 16.136854},{
      16.551481, 6.485786, 24.205282},{16.551481, 0.000000, 25.059153},{
      12.802159, 0.000000, 16.706100},{12.802159, 4.323857, 16.136854}}],
    Polygon[{{10.000000, 0.000000, 0.000000},{10.685966, 0.000000, 8.353050},{
      10.685966, -2.161929, 8.068427},{10.000000, -0.000000, 0.000000},{
      10.000000, 0.000000, 0.000000}}],
    Polygon[{{10.685966, 0.000000, 8.353050},{
      12.802159, 0.000000, 16.706100},{12.802159, -4.323857, 16.136854},{
      10.685966, -2.161929, 8.068427},{10.685966, 0.000000, 8.353050}}],
    Polygon[{{12.802159, 0.000000, 16.706100},{
      16.551481, 0.000000, 25.059153},{16.551481, -6.485786, 24.205282},{
      12.802159, -4.323857, 16.136854},{12.802159, 0.000000, 16.706100}}],
    Polygon[{{10.000000, -0.000000, 0.000000},{
      10.685966, -2.161929, 8.068427},{10.685966, -4.176525, 7.233954},{
      10.000000, -0.000000, 0.000000},{10.000000, -0.000000, 0.000000}}],
    Polygon[{{10.685966, -2.161929, 8.068427},{
      12.802159, -4.323857, 16.136854},{12.802159, -8.353050, 14.467908},{
      10.685966, -4.176525, 7.233954},{10.685966, -2.161929, 8.068427}}],
    Polygon[{{12.802159, -4.323857, 16.136854},{
      16.551481, -6.485786, 24.205282},{16.551481, -12.529576, 21.701862},{
      12.802159, -8.353050, 14.467908},{12.802159, -4.323857, 16.136854}}],
    Polygon[{{10.000000, -0.000000, 0.000000},{
      10.685966, -4.176525, 7.233954},{10.685966, -5.906499, 5.906499},{
      10.000000, -0.000000, 0.000000},{10.000000, -0.000000, 0.000000}}],
    Polygon[{{10.685966, -4.176525, 7.233954},{
      12.802159, -8.353050, 14.467908},{12.802159, -11.812998, 11.812998},{
      10.685966, -5.906499, 5.906499},{10.685966, -4.176525, 7.233954}}],
    Polygon[{{12.802159, -8.353050, 14.467908},{
      16.551481, -12.529576, 21.701862},{16.551481, -17.719496, 17.719496},{
      12.802159, -11.812998, 11.812998},{12.802159, -8.353050, 14.467908}}],
    Polygon[{{10.000000, -0.000000, 0.000000},{
      10.685966, -5.906499, 5.906499},{10.685966, -7.233954, 4.176525},{
      10.000000, -0.000000, 0.000000},{10.000000, -0.000000, 0.000000}}],
    Polygon[{{10.685966, -5.906499, 5.906499},{
      12.802159, -11.812998, 11.812998},{12.802159, -14.467908, 8.353050},{
      10.685966, -7.233954, 4.176525},{10.685966, -5.906499, 5.906499}}],
    Polygon[{{12.802159, -11.812998, 11.812998},{
      16.551481, -17.719496, 17.719496},{16.551481, -21.701862, 12.529576},{
      12.802159, -14.467908, 8.353050},{12.802159, -11.812998, 11.812998}}],
    Polygon[{{10.000000, -0.000000, 0.000000},{
      10.685966, -7.233954, 4.176525},{10.685966, -8.068427, 2.161929},{
      10.000000, -0.000000, 0.000000},{10.000000, -0.000000, 0.000000}}],
    Polygon[{{10.685966, -7.233954, 4.176525},{
      12.802159, -14.467908, 8.353050},{12.802159, -16.136854, 4.323857},{
      10.685966, -8.068427, 2.161929},{10.685966, -7.233954, 4.176525}}],
    Polygon[{{12.802159, -14.467908, 8.353050},{
      16.551481, -21.701862, 12.529576},{16.551481, -24.205282, 6.485786},{
      12.802159, -16.136854, 4.323857},{12.802159, -14.467908, 8.353050}}],
    Polygon[{{10.000000, -0.000000, 0.000000},{
      10.685966, -8.068427, 2.161929},{10.685966, -8.353050, 0.000000},{
      10.000000, -0.000000, 0.000000},{10.000000, -0.000000, 0.000000}}],
    Polygon[{{10.685966, -8.068427, 2.161929},{
      12.802159, -16.136854, 4.323857},{12.802159, -16.706100, 0.000000},{
      10.685966, -8.353050, 0.000000},{10.685966, -8.068427, 2.161929}}],
    Polygon[{{12.802159, -16.136854, 4.323857},{
      16.551481, -24.205282, 6.485786},{16.551481, -25.059153, 0.000000},{
      12.802159, -16.706100, 0.000000},{12.802159, -16.136854, 4.323857}}],
    Polygon[{{10.000000, -0.000000, 0.000000},{
      10.685966, -8.353050, 0.000000},{10.685966, -8.068427, -2.161929},{
      10.000000, -0.000000, -0.000000},{10.000000, -0.000000, 0.000000}}],
    Polygon[{{10.685966, -8.353050, 0.000000},{
      12.802159, -16.706100, 0.000000},{12.802159, -16.136854, -4.323857},{
      10.685966, -8.068427, -2.161929},{10.685966, -8.353050, 0.000000}}],
    Polygon[{{12.802159, -16.706100, 0.000000},{
      16.551481, -25.059153, 0.000000},{16.551481, -24.205282, -6.485786},{
      12.802159, -16.136854, -4.323857},{12.802159, -16.706100, 0.000000}}],
    Polygon[{{10.000000, -0.000000, -0.000000},{
      10.685966, -8.068427, -2.161929},{10.685966, -7.233954, -4.176525},{
      10.000000, -0.000000, -0.000000},{10.000000, -0.000000, -0.000000}}],
    Polygon[{{10.685966, -8.068427, -2.161929},{
      12.802159, -16.136854, -4.323857},{12.802159, -14.467908, -8.353050},{
      10.685966, -7.233954, -4.176525},{10.685966, -8.068427, -2.161929}}],
    Polygon[{{12.802159, -16.136854, -4.323857},{
      16.551481, -24.205282, -6.485786},{16.551481, -21.701862, -12.529576},{
      12.802159, -14.467908, -8.353050},{12.802159, -16.136854, -4.323857}}],
    Polygon[{{10.000000, -0.000000, -0.000000},{
      10.685966, -7.233954, -4.176525},{10.685966, -5.906499, -5.906499},{
      10.000000, -0.000000, -0.000000},{10.000000, -0.000000, -0.000000}}],
    Polygon[{{10.685966, -7.233954, -4.176525},{
      12.802159, -14.467908, -8.353050},{12.802159, -11.812998, -11.812998},{
      10.685966, -5.906499, -5.906499},{10.685966, -7.233954, -4.176525}}],
    Polygon[{{12.802159, -14.467908, -8.353050},{
      16.551481, -21.701862, -12.529576},{16.551481, -17.719496, -17.719496},{
      12.802159, -11.812998, -11.812998},{12.802159, -14.467908, -8.353050}}],
    
    Polygon[{{10.000000, -0.000000, -0.000000},{
      10.685966, -5.906499, -5.906499},{10.685966, -4.176525, -7.233954},{
      10.000000, -0.000000, -0.000000},{10.000000, -0.000000, -0.000000}}],
    Polygon[{{10.685966, -5.906499, -5.906499},{
      12.802159, -11.812998, -11.812998},{12.802159, -8.353050, -14.467908},{
      10.685966, -4.176525, -7.233954},{10.685966, -5.906499, -5.906499}}],
    Polygon[{{12.802159, -11.812998, -11.812998},{
      16.551481, -17.719496, -17.719496},{16.551481, -12.529576, -21.701862},{
      12.802159, -8.353050, -14.467908},{12.802159, -11.812998, -11.812998}}],
    
    Polygon[{{10.000000, -0.000000, -0.000000},{
      10.685966, -4.176525, -7.233954},{10.685966, -2.161929, -8.068427},{
      10.000000, -0.000000, -0.000000},{10.000000, -0.000000, -0.000000}}],
    Polygon[{{10.685966, -4.176525, -7.233954},{
      12.802159, -8.353050, -14.467908},{12.802159, -4.323857, -16.136854},{
      10.685966, -2.161929, -8.068427},{10.685966, -4.176525, -7.233954}}],
    Polygon[{{12.802159, -8.353050, -14.467908},{
      16.551481, -12.529576, -21.701862},{16.551481, -6.485786, -24.205282},{
      12.802159, -4.323857, -16.136854},{12.802159, -8.353050, -14.467908}}],
    Polygon[{{10.000000, -0.000000, -0.000000},{
      10.685966, -2.161929, -8.068427},{10.685966, -0.000000, -8.353050},{
      10.000000, -0.000000, -0.000000},{10.000000, -0.000000, -0.000000}}],
    Polygon[{{10.685966, -2.161929, -8.068427},{
      12.802159, -4.323857, -16.136854},{12.802159, -0.000000, -16.706100},{
      10.685966, -0.000000, -8.353050},{10.685966, -2.161929, -8.068427}}],
    Polygon[{{12.802159, -4.323857, -16.136854},{
      16.551481, -6.485786, -24.205282},{16.551481, -0.000000, -25.059153},{
      12.802159, -0.000000, -16.706100},{12.802159, -4.323857, -16.136854}}],
    Polygon[{{10.000000, -0.000000, -0.000000},{
      10.685966, -0.000000, -8.353050},{10.685966, 2.161929, -8.068427},{
      10.000000, 0.000000, -0.000000},{10.000000, -0.000000, -0.000000}}],
    Polygon[{{10.685966, -0.000000, -8.353050},{
      12.802159, -0.000000, -16.706100},{12.802159, 4.323857, -16.136854},{
      10.685966, 2.161929, -8.068427},{10.685966, -0.000000, -8.353050}}],
    Polygon[{{12.802159, -0.000000, -16.706100},{
      16.551481, -0.000000, -25.059153},{16.551481, 6.485786, -24.205282},{
      12.802159, 4.323857, -16.136854},{12.802159, -0.000000, -16.706100}}],
    Polygon[{{10.000000, 0.000000, -0.000000},{
      10.685966, 2.161929, -8.068427},{10.685966, 4.176525, -7.233954},{
      10.000000, 0.000000, -0.000000},{10.000000, 0.000000, -0.000000}}],
    Polygon[{{10.685966, 2.161929, -8.068427},{
      12.802159, 4.323857, -16.136854},{12.802159, 8.353050, -14.467908},{
      10.685966, 4.176525, -7.233954},{10.685966, 2.161929, -8.068427}}],
    Polygon[{{12.802159, 4.323857, -16.136854},{
      16.551481, 6.485786, -24.205282},{16.551481, 12.529576, -21.701862},{
      12.802159, 8.353050, -14.467908},{12.802159, 4.323857, -16.136854}}],
    Polygon[{{10.000000, 0.000000, -0.000000},{
      10.685966, 4.176525, -7.233954},{10.685966, 5.906499, -5.906499},{
      10.000000, 0.000000, -0.000000},{10.000000, 0.000000, -0.000000}}],
    Polygon[{{10.685966, 4.176525, -7.233954},{
      12.802159, 8.353050, -14.467908},{12.802159, 11.812998, -11.812998},{
      10.685966, 5.906499, -5.906499},{10.685966, 4.176525, -7.233954}}],
    Polygon[{{12.802159, 8.353050, -14.467908},{
      16.551481, 12.529576, -21.701862},{16.551481, 17.719496, -17.719496},{
      12.802159, 11.812998, -11.812998},{12.802159, 8.353050, -14.467908}}],
    Polygon[{{10.000000, 0.000000, -0.000000},{
      10.685966, 5.906499, -5.906499},{10.685966, 7.233954, -4.176525},{
      10.000000, 0.000000, -0.000000},{10.000000, 0.000000, -0.000000}}],
    Polygon[{{10.685966, 5.906499, -5.906499},{
      12.802159, 11.812998, -11.812998},{12.802159, 14.467908, -8.353050},{
      10.685966, 7.233954, -4.176525},{10.685966, 5.906499, -5.906499}}],
    Polygon[{{12.802159, 11.812998, -11.812998},{
      16.551481, 17.719496, -17.719496},{16.551481, 21.701862, -12.529576},{
      12.802159, 14.467908, -8.353050},{12.802159, 11.812998, -11.812998}}],
    Polygon[{{10.000000, 0.000000, -0.000000},{
      10.685966, 7.233954, -4.176525},{10.685966, 8.068427, -2.161929},{
      10.000000, 0.000000, -0.000000},{10.000000, 0.000000, -0.000000}}],
    Polygon[{{10.685966, 7.233954, -4.176525},{
      12.802159, 14.467908, -8.353050},{12.802159, 16.136854, -4.323857},{
      10.685966, 8.068427, -2.161929},{10.685966, 7.233954, -4.176525}}],
    Polygon[{{12.802159, 14.467908, -8.353050},{
      16.551481, 21.701862, -12.529576},{16.551481, 24.205282, -6.485786},{
      12.802159, 16.136854, -4.323857},{12.802159, 14.467908, -8.353050}}],
    Polygon[{{10.000000, 0.000000, -0.000000},{
      10.685966, 8.068427, -2.161929},{10.685966, 8.353050, -0.000000},{
      10.000000, 0.000000, -0.000000},{10.000000, 0.000000, -0.000000}}],
    Polygon[{{10.685966, 8.068427, -2.161929},{
      12.802159, 16.136854, -4.323857},{12.802159, 16.706100, -0.000000},{
      10.685966, 8.353050, -0.000000},{10.685966, 8.068427, -2.161929}}],
    Polygon[{{12.802159, 16.136854, -4.323857},{
      16.551481, 24.205282, -6.485786},{16.551481, 25.059153, -0.000000},{
      12.802159, 16.706100, -0.000000},{12.802159, 16.136854, -4.323857}}],
    Line[{{16.551481, 25.059153, 0.000000},{16.551481, 24.205282, 6.485786},{
      16.551481, 21.701862, 12.529576},{16.551481, 17.719496, 17.719496},{
      16.551481, 12.529576, 21.701862},{16.551481, 6.485786, 24.205282},{
      16.551481, 0.000000, 25.059153},{16.551481, -6.485786, 24.205282},{
      16.551481, -12.529576, 21.701862},{16.551481, -17.719496, 17.719496},{
      16.551481, -21.701862, 12.529576},{16.551481, -24.205282, 6.485786},{
      16.551481, -25.059153, 0.000000},{16.551481, -24.205282, -6.485786},{
      16.551481, -21.701862, -12.529576},{16.551481, -17.719496, -17.719496},{
      16.551481, -12.529576, -21.701862},{16.551481, -6.485786, -24.205282},{
      16.551481, -0.000000, -25.059153},{16.551481, 6.485786, -24.205282},{
      16.551481, 12.529576, -21.701862},{16.551481, 17.719496, -17.719496},{
      16.551481, 21.701862, -12.529576},{16.551481, 24.205282, -6.485786},{
      16.551481, 25.059153, -0.000000}}],
    Polygon[{{14.941665, 0.000000, 0.000000},{15.227986, 8.353050, 0.000000},{
      15.227986, 8.068427, 2.161929},{14.941665, 0.000000, 0.000000},{
      14.941665, 0.000000, 0.000000}}],
    Polygon[{{15.227986, 8.353050, 0.000000},{
      16.091019, 16.706100, 0.000000},{16.091019, 16.136854, 4.323857},{
      15.227986, 8.068427, 2.161929},{15.227986, 8.353050, 0.000000}}],
    Polygon[{{16.091019, 16.706100, 0.000000},{
      17.543272, 25.059153, 0.000000},{17.543272, 24.205282, 6.485786},{
      16.091019, 16.136854, 4.323857},{16.091019, 16.706100, 0.000000}}],
    Polygon[{{14.941665, 0.000000, 0.000000},{15.227986, 8.068427, 2.161929},{
      15.227986, 7.233954, 4.176525},{14.941665, 0.000000, 0.000000},{
      14.941665, 0.000000, 0.000000}}],
    Polygon[{{15.227986, 8.068427, 2.161929},{
      16.091019, 16.136854, 4.323857},{16.091019, 14.467908, 8.353050},{
      15.227986, 7.233954, 4.176525},{15.227986, 8.068427, 2.161929}}],
    Polygon[{{16.091019, 16.136854, 4.323857},{
      17.543272, 24.205282, 6.485786},{17.543272, 21.701862, 12.529576},{
      16.091019, 14.467908, 8.353050},{16.091019, 16.136854, 4.323857}}],
    Polygon[{{14.941665, 0.000000, 0.000000},{15.227986, 7.233954, 4.176525},{
      15.227986, 5.906499, 5.906499},{14.941665, 0.000000, 0.000000},{
      14.941665, 0.000000, 0.000000}}],
    Polygon[{{15.227986, 7.233954, 4.176525},{
      16.091019, 14.467908, 8.353050},{16.091019, 11.812998, 11.812998},{
      15.227986, 5.906499, 5.906499},{15.227986, 7.233954, 4.176525}}],
    Polygon[{{16.091019, 14.467908, 8.353050},{
      17.543272, 21.701862, 12.529576},{17.543272, 17.719496, 17.719496},{
      16.091019, 11.812998, 11.812998},{16.091019, 14.467908, 8.353050}}],
    Polygon[{{14.941665, 0.000000, 0.000000},{15.227986, 5.906499, 5.906499},{
      15.227986, 4.176525, 7.233954},{14.941665, 0.000000, 0.000000},{
      14.941665, 0.000000, 0.000000}}],
    Polygon[{{15.227986, 5.906499, 5.906499},{
      16.091019, 11.812998, 11.812998},{16.091019, 8.353050, 14.467908},{
      15.227986, 4.176525, 7.233954},{15.227986, 5.906499, 5.906499}}],
    Polygon[{{16.091019, 11.812998, 11.812998},{
      17.543272, 17.719496, 17.719496},{17.543272, 12.529576, 21.701862},{
      16.091019, 8.353050, 14.467908},{16.091019, 11.812998, 11.812998}}],
    Polygon[{{14.941665, 0.000000, 0.000000},{15.227986, 4.176525, 7.233954},{
      15.227986, 2.161929, 8.068427},{14.941665, 0.000000, 0.000000},{
      14.941665, 0.000000, 0.000000}}],
    Polygon[{{15.227986, 4.176525, 7.233954},{
      16.091019, 8.353050, 14.467908},{16.091019, 4.323857, 16.136854},{
      15.227986, 2.161929, 8.068427},{15.227986, 4.176525, 7.233954}}],
    Polygon[{{16.091019, 8.353050, 14.467908},{
      17.543272, 12.529576, 21.701862},{17.543272, 6.485786, 24.205282},{
      16.091019, 4.323857, 16.136854},{16.091019, 8.353050, 14.467908}}],
    Polygon[{{14.941665, 0.000000, 0.000000},{15.227986, 2.161929, 8.068427},{
      15.227986, 0.000000, 8.353050},{14.941665, 0.000000, 0.000000},{
      14.941665, 0.000000, 0.000000}}],
    Polygon[{{15.227986, 2.161929, 8.068427},{
      16.091019, 4.323857, 16.136854},{16.091019, 0.000000, 16.706100},{
      15.227986, 0.000000, 8.353050},{15.227986, 2.161929, 8.068427}}],
    Polygon[{{16.091019, 4.323857, 16.136854},{
      17.543272, 6.485786, 24.205282},{17.543272, 0.000000, 25.059153},{
      16.091019, 0.000000, 16.706100},{16.091019, 4.323857, 16.136854}}],
    Polygon[{{14.941665, 0.000000, 0.000000},{15.227986, 0.000000, 8.353050},{
      15.227986, -2.161929, 8.068427},{14.941665, -0.000000, 0.000000},{
      14.941665, 0.000000, 0.000000}}],
    Polygon[{{15.227986, 0.000000, 8.353050},{
      16.091019, 0.000000, 16.706100},{16.091019, -4.323857, 16.136854},{
      15.227986, -2.161929, 8.068427},{15.227986, 0.000000, 8.353050}}],
    Polygon[{{16.091019, 0.000000, 16.706100},{
      17.543272, 0.000000, 25.059153},{17.543272, -6.485786, 24.205282},{
      16.091019, -4.323857, 16.136854},{16.091019, 0.000000, 16.706100}}],
    Polygon[{{14.941665, -0.000000, 0.000000},{
      15.227986, -2.161929, 8.068427},{15.227986, -4.176525, 7.233954},{
      14.941665, -0.000000, 0.000000},{14.941665, -0.000000, 0.000000}}],
    Polygon[{{15.227986, -2.161929, 8.068427},{
      16.091019, -4.323857, 16.136854},{16.091019, -8.353050, 14.467908},{
      15.227986, -4.176525, 7.233954},{15.227986, -2.161929, 8.068427}}],
    Polygon[{{16.091019, -4.323857, 16.136854},{
      17.543272, -6.485786, 24.205282},{17.543272, -12.529576, 21.701862},{
      16.091019, -8.353050, 14.467908},{16.091019, -4.323857, 16.136854}}],
    Polygon[{{14.941665, -0.000000, 0.000000},{
      15.227986, -4.176525, 7.233954},{15.227986, -5.906499, 5.906499},{
      14.941665, -0.000000, 0.000000},{14.941665, -0.000000, 0.000000}}],
    Polygon[{{15.227986, -4.176525, 7.233954},{
      16.091019, -8.353050, 14.467908},{16.091019, -11.812998, 11.812998},{
      15.227986, -5.906499, 5.906499},{15.227986, -4.176525, 7.233954}}],
    Polygon[{{16.091019, -8.353050, 14.467908},{
      17.543272, -12.529576, 21.701862},{17.543272, -17.719496, 17.719496},{
      16.091019, -11.812998, 11.812998},{16.091019, -8.353050, 14.467908}}],
    Polygon[{{14.941665, -0.000000, 0.000000},{
      15.227986, -5.906499, 5.906499},{15.227986, -7.233954, 4.176525},{
      14.941665, -0.000000, 0.000000},{14.941665, -0.000000, 0.000000}}],
    Polygon[{{15.227986, -5.906499, 5.906499},{
      16.091019, -11.812998, 11.812998},{16.091019, -14.467908, 8.353050},{
      15.227986, -7.233954, 4.176525},{15.227986, -5.906499, 5.906499}}],
    Polygon[{{16.091019, -11.812998, 11.812998},{
      17.543272, -17.719496, 17.719496},{17.543272, -21.701862, 12.529576},{
      16.091019, -14.467908, 8.353050},{16.091019, -11.812998, 11.812998}}],
    Polygon[{{14.941665, -0.000000, 0.000000},{
      15.227986, -7.233954, 4.176525},{15.227986, -8.068427, 2.161929},{
      14.941665, -0.000000, 0.000000},{14.941665, -0.000000, 0.000000}}],
    Polygon[{{15.227986, -7.233954, 4.176525},{
      16.091019, -14.467908, 8.353050},{16.091019, -16.136854, 4.323857},{
      15.227986, -8.068427, 2.161929},{15.227986, -7.233954, 4.176525}}],
    Polygon[{{16.091019, -14.467908, 8.353050},{
      17.543272, -21.701862, 12.529576},{17.543272, -24.205282, 6.485786},{
      16.091019, -16.136854, 4.323857},{16.091019, -14.467908, 8.353050}}],
    Polygon[{{14.941665, -0.000000, 0.000000},{
      15.227986, -8.068427, 2.161929},{15.227986, -8.353050, 0.000000},{
      14.941665, -0.000000, 0.000000},{14.941665, -0.000000, 0.000000}}],
    Polygon[{{15.227986, -8.068427, 2.161929},{
      16.091019, -16.136854, 4.323857},{16.091019, -16.706100, 0.000000},{
      15.227986, -8.353050, 0.000000},{15.227986, -8.068427, 2.161929}}],
    Polygon[{{16.091019, -16.136854, 4.323857},{
      17.543272, -24.205282, 6.485786},{17.543272, -25.059153, 0.000000},{
      16.091019, -16.706100, 0.000000},{16.091019, -16.136854, 4.323857}}],
    Polygon[{{14.941665, -0.000000, 0.000000},{
      15.227986, -8.353050, 0.000000},{15.227986, -8.068427, -2.161929},{
      14.941665, -0.000000, -0.000000},{14.941665, -0.000000, 0.000000}}],
    Polygon[{{15.227986, -8.353050, 0.000000},{
      16.091019, -16.706100, 0.000000},{16.091019, -16.136854, -4.323857},{
      15.227986, -8.068427, -2.161929},{15.227986, -8.353050, 0.000000}}],
    Polygon[{{16.091019, -16.706100, 0.000000},{
      17.543272, -25.059153, 0.000000},{17.543272, -24.205282, -6.485786},{
      16.091019, -16.136854, -4.323857},{16.091019, -16.706100, 0.000000}}],
    Polygon[{{14.941665, -0.000000, -0.000000},{
      15.227986, -8.068427, -2.161929},{15.227986, -7.233954, -4.176525},{
      14.941665, -0.000000, -0.000000},{14.941665, -0.000000, -0.000000}}],
    Polygon[{{15.227986, -8.068427, -2.161929},{
      16.091019, -16.136854, -4.323857},{16.091019, -14.467908, -8.353050},{
      15.227986, -7.233954, -4.176525},{15.227986, -8.068427, -2.161929}}],
    Polygon[{{16.091019, -16.136854, -4.323857},{
      17.543272, -24.205282, -6.485786},{17.543272, -21.701862, -12.529576},{
      16.091019, -14.467908, -8.353050},{16.091019, -16.136854, -4.323857}}],
    Polygon[{{14.941665, -0.000000, -0.000000},{
      15.227986, -7.233954, -4.176525},{15.227986, -5.906499, -5.906499},{
      14.941665, -0.000000, -0.000000},{14.941665, -0.000000, -0.000000}}],
    Polygon[{{15.227986, -7.233954, -4.176525},{
      16.091019, -14.467908, -8.353050},{16.091019, -11.812998, -11.812998},{
      15.227986, -5.906499, -5.906499},{15.227986, -7.233954, -4.176525}}],
    Polygon[{{16.091019, -14.467908, -8.353050},{
      17.543272, -21.701862, -12.529576},{17.543272, -17.719496, -17.719496},{
      16.091019, -11.812998, -11.812998},{16.091019, -14.467908, -8.353050}}],
    
    Polygon[{{14.941665, -0.000000, -0.000000},{
      15.227986, -5.906499, -5.906499},{15.227986, -4.176525, -7.233954},{
      14.941665, -0.000000, -0.000000},{14.941665, -0.000000, -0.000000}}],
    Polygon[{{15.227986, -5.906499, -5.906499},{
      16.091019, -11.812998, -11.812998},{16.091019, -8.353050, -14.467908},{
      15.227986, -4.176525, -7.233954},{15.227986, -5.906499, -5.906499}}],
    Polygon[{{16.091019, -11.812998, -11.812998},{
      17.543272, -17.719496, -17.719496},{17.543272, -12.529576, -21.701862},{
      16.091019, -8.353050, -14.467908},{16.091019, -11.812998, -11.812998}}],
    
    Polygon[{{14.941665, -0.000000, -0.000000},{
      15.227986, -4.176525, -7.233954},{15.227986, -2.161929, -8.068427},{
      14.941665, -0.000000, -0.000000},{14.941665, -0.000000, -0.000000}}],
    Polygon[{{15.227986, -4.176525, -7.233954},{
      16.091019, -8.353050, -14.467908},{16.091019, -4.323857, -16.136854},{
      15.227986, -2.161929, -8.068427},{15.227986, -4.176525, -7.233954}}],
    Polygon[{{16.091019, -8.353050, -14.467908},{
      17.543272, -12.529576, -21.701862},{17.543272, -6.485786, -24.205282},{
      16.091019, -4.323857, -16.136854},{16.091019, -8.353050, -14.467908}}],
    Polygon[{{14.941665, -0.000000, -0.000000},{
      15.227986, -2.161929, -8.068427},{15.227986, -0.000000, -8.353050},{
      14.941665, -0.000000, -0.000000},{14.941665, -0.000000, -0.000000}}],
    Polygon[{{15.227986, -2.161929, -8.068427},{
      16.091019, -4.323857, -16.136854},{16.091019, -0.000000, -16.706100},{
      15.227986, -0.000000, -8.353050},{15.227986, -2.161929, -8.068427}}],
    Polygon[{{16.091019, -4.323857, -16.136854},{
      17.543272, -6.485786, -24.205282},{17.543272, -0.000000, -25.059153},{
      16.091019, -0.000000, -16.706100},{16.091019, -4.323857, -16.136854}}],
    Polygon[{{14.941665, -0.000000, -0.000000},{
      15.227986, -0.000000, -8.353050},{15.227986, 2.161929, -8.068427},{
      14.941665, 0.000000, -0.000000},{14.941665, -0.000000, -0.000000}}],
    Polygon[{{15.227986, -0.000000, -8.353050},{
      16.091019, -0.000000, -16.706100},{16.091019, 4.323857, -16.136854},{
      15.227986, 2.161929, -8.068427},{15.227986, -0.000000, -8.353050}}],
    Polygon[{{16.091019, -0.000000, -16.706100},{
      17.543272, -0.000000, -25.059153},{17.543272, 6.485786, -24.205282},{
      16.091019, 4.323857, -16.136854},{16.091019, -0.000000, -16.706100}}],
    Polygon[{{14.941665, 0.000000, -0.000000},{
      15.227986, 2.161929, -8.068427},{15.227986, 4.176525, -7.233954},{
      14.941665, 0.000000, -0.000000},{14.941665, 0.000000, -0.000000}}],
    Polygon[{{15.227986, 2.161929, -8.068427},{
      16.091019, 4.323857, -16.136854},{16.091019, 8.353050, -14.467908},{
      15.227986, 4.176525, -7.233954},{15.227986, 2.161929, -8.068427}}],
    Polygon[{{16.091019, 4.323857, -16.136854},{
      17.543272, 6.485786, -24.205282},{17.543272, 12.529576, -21.701862},{
      16.091019, 8.353050, -14.467908},{16.091019, 4.323857, -16.136854}}],
    Polygon[{{14.941665, 0.000000, -0.000000},{
      15.227986, 4.176525, -7.233954},{15.227986, 5.906499, -5.906499},{
      14.941665, 0.000000, -0.000000},{14.941665, 0.000000, -0.000000}}],
    Polygon[{{15.227986, 4.176525, -7.233954},{
      16.091019, 8.353050, -14.467908},{16.091019, 11.812998, -11.812998},{
      15.227986, 5.906499, -5.906499},{15.227986, 4.176525, -7.233954}}],
    Polygon[{{16.091019, 8.353050, -14.467908},{
      17.543272, 12.529576, -21.701862},{17.543272, 17.719496, -17.719496},{
      16.091019, 11.812998, -11.812998},{16.091019, 8.353050, -14.467908}}],
    Polygon[{{14.941665, 0.000000, -0.000000},{
      15.227986, 5.906499, -5.906499},{15.227986, 7.233954, -4.176525},{
      14.941665, 0.000000, -0.000000},{14.941665, 0.000000, -0.000000}}],
    Polygon[{{15.227986, 5.906499, -5.906499},{
      16.091019, 11.812998, -11.812998},{16.091019, 14.467908, -8.353050},{
      15.227986, 7.233954, -4.176525},{15.227986, 5.906499, -5.906499}}],
    Polygon[{{16.091019, 11.812998, -11.812998},{
      17.543272, 17.719496, -17.719496},{17.543272, 21.701862, -12.529576},{
      16.091019, 14.467908, -8.353050},{16.091019, 11.812998, -11.812998}}],
    Polygon[{{14.941665, 0.000000, -0.000000},{
      15.227986, 7.233954, -4.176525},{15.227986, 8.068427, -2.161929},{
      14.941665, 0.000000, -0.000000},{14.941665, 0.000000, -0.000000}}],
    Polygon[{{15.227986, 7.233954, -4.176525},{
      16.091019, 14.467908, -8.353050},{16.091019, 16.136854, -4.323857},{
      15.227986, 8.068427, -2.161929},{15.227986, 7.233954, -4.176525}}],
    Polygon[{{16.091019, 14.467908, -8.353050},{
      17.543272, 21.701862, -12.529576},{17.543272, 24.205282, -6.485786},{
      16.091019, 16.136854, -4.323857},{16.091019, 14.467908, -8.353050}}],
    Polygon[{{14.941665, 0.000000, -0.000000},{
      15.227986, 8.068427, -2.161929},{15.227986, 8.353050, -0.000000},{
      14.941665, 0.000000, -0.000000},{14.941665, 0.000000, -0.000000}}],
    Polygon[{{15.227986, 8.068427, -2.161929},{
      16.091019, 16.136854, -4.323857},{16.091019, 16.706100, -0.000000},{
      15.227986, 8.353050, -0.000000},{15.227986, 8.068427, -2.161929}}],
    Polygon[{{16.091019, 16.136854, -4.323857},{
      17.543272, 24.205282, -6.485786},{17.543272, 25.059153, -0.000000},{
      16.091019, 16.706100, -0.000000},{16.091019, 16.136854, -4.323857}}],
    Line[{{17.543272, 25.059153, 0.000000},{17.543272, 24.205282, 6.485786},{
      17.543272, 21.701862, 12.529576},{17.543272, 17.719496, 17.719496},{
      17.543272, 12.529576, 21.701862},{17.543272, 6.485786, 24.205282},{
      17.543272, 0.000000, 25.059153},{17.543272, -6.485786, 24.205282},{
      17.543272, -12.529576, 21.701862},{17.543272, -17.719496, 17.719496},{
      17.543272, -21.701862, 12.529576},{17.543272, -24.205282, 6.485786},{
      17.543272, -25.059153, 0.000000},{17.543272, -24.205282, -6.485786},{
      17.543272, -21.701862, -12.529576},{17.543272, -17.719496, -17.719496},{
      17.543272, -12.529576, -21.701862},{17.543272, -6.485786, -24.205282},{
      17.543272, -0.000000, -25.059153},{17.543272, 6.485786, -24.205282},{
      17.543272, 12.529576, -21.701862},{17.543272, 17.719496, -17.719496},{
      17.543272, 21.701862, -12.529576},{17.543272, 24.205282, -6.485786},{
      17.543272, 25.059153, -0.000000}}],
    Polygon[{{16.551481, 25.059153, 0.000000},{
      17.543272, 25.059153, 0.000000},{17.543272, 24.205282, 6.485786},{
      16.551481, 24.205282, 6.485786},{16.551481, 25.059153, 0.000000}}],
    Polygon[{{16.551481, 24.205282, 6.485786},{
      17.543272, 24.205282, 6.485786},{17.543272, 21.701862, 12.529576},{
      16.551481, 21.701862, 12.529576},{16.551481, 24.205282, 6.485786}}],
    Polygon[{{16.551481, 21.701862, 12.529576},{
      17.543272, 21.701862, 12.529576},{17.543272, 17.719496, 17.719496},{
      16.551481, 17.719496, 17.719496},{16.551481, 21.701862, 12.529576}}],
    Polygon[{{16.551481, 17.719496, 17.719496},{
      17.543272, 17.719496, 17.719496},{17.543272, 12.529576, 21.701862},{
      16.551481, 12.529576, 21.701862},{16.551481, 17.719496, 17.719496}}],
    Polygon[{{16.551481, 12.529576, 21.701862},{
      17.543272, 12.529576, 21.701862},{17.543272, 6.485786, 24.205282},{
      16.551481, 6.485786, 24.205282},{16.551481, 12.529576, 21.701862}}],
    Polygon[{{16.551481, 6.485786, 24.205282},{
      17.543272, 6.485786, 24.205282},{17.543272, 0.000000, 25.059153},{
      16.551481, 0.000000, 25.059153},{16.551481, 6.485786, 24.205282}}],
    Polygon[{{16.551481, 0.000000, 25.059153},{
      17.543272, 0.000000, 25.059153},{17.543272, -6.485786, 24.205282},{
      16.551481, -6.485786, 24.205282},{16.551481, 0.000000, 25.059153}}],
    Polygon[{{16.551481, -6.485786, 24.205282},{
      17.543272, -6.485786, 24.205282},{17.543272, -12.529576, 21.701862},{
      16.551481, -12.529576, 21.701862},{16.551481, -6.485786, 24.205282}}],
    Polygon[{{16.551481, -12.529576, 21.701862},{
      17.543272, -12.529576, 21.701862},{17.543272, -17.719496, 17.719496},{
      16.551481, -17.719496, 17.719496},{16.551481, -12.529576, 21.701862}}],
    Polygon[{{16.551481, -17.719496, 17.719496},{
      17.543272, -17.719496, 17.719496},{17.543272, -21.701862, 12.529576},{
      16.551481, -21.701862, 12.529576},{16.551481, -17.719496, 17.719496}}],
    Polygon[{{16.551481, -21.701862, 12.529576},{
      17.543272, -21.701862, 12.529576},{17.543272, -24.205282, 6.485786},{
      16.551481, -24.205282, 6.485786},{16.551481, -21.701862, 12.529576}}],
    Polygon[{{16.551481, -24.205282, 6.485786},{
      17.543272, -24.205282, 6.485786},{17.543272, -25.059153, 0.000000},{
      16.551481, -25.059153, 0.000000},{16.551481, -24.205282, 6.485786}}],
    Polygon[{{16.551481, -25.059153, 0.000000},{
      17.543272, -25.059153, 0.000000},{17.543272, -24.205282, -6.485786},{
      16.551481, -24.205282, -6.485786},{16.551481, -25.059153, 0.000000}}],
    Polygon[{{16.551481, -24.205282, -6.485786},{
      17.543272, -24.205282, -6.485786},{17.543272, -21.701862, -12.529576},{
      16.551481, -21.701862, -12.529576},{16.551481, -24.205282, -6.485786}}],
    
    Polygon[{{16.551481, -21.701862, -12.529576},{
      17.543272, -21.701862, -12.529576},{17.543272, -17.719496, -17.719496},{
      16.551481, -17.719496, -17.719496},{
      16.551481, -21.701862, -12.529576}}],
    Polygon[{{16.551481, -17.719496, -17.719496},{
      17.543272, -17.719496, -17.719496},{17.543272, -12.529576, -21.701862},{
      16.551481, -12.529576, -21.701862},{
      16.551481, -17.719496, -17.719496}}],
    Polygon[{{16.551481, -12.529576, -21.701862},{
      17.543272, -12.529576, -21.701862},{17.543272, -6.485786, -24.205282},{
      16.551481, -6.485786, -24.205282},{16.551481, -12.529576, -21.701862}}],
    
    Polygon[{{16.551481, -6.485786, -24.205282},{
      17.543272, -6.485786, -24.205282},{17.543272, -0.000000, -25.059153},{
      16.551481, -0.000000, -25.059153},{16.551481, -6.485786, -24.205282}}],
    Polygon[{{16.551481, -0.000000, -25.059153},{
      17.543272, -0.000000, -25.059153},{17.543272, 6.485786, -24.205282},{
      16.551481, 6.485786, -24.205282},{16.551481, -0.000000, -25.059153}}],
    Polygon[{{16.551481, 6.485786, -24.205282},{
      17.543272, 6.485786, -24.205282},{17.543272, 12.529576, -21.701862},{
      16.551481, 12.529576, -21.701862},{16.551481, 6.485786, -24.205282}}],
    Polygon[{{16.551481, 12.529576, -21.701862},{
      17.543272, 12.529576, -21.701862},{17.543272, 17.719496, -17.719496},{
      16.551481, 17.719496, -17.719496},{16.551481, 12.529576, -21.701862}}],
    Polygon[{{16.551481, 17.719496, -17.719496},{
      17.543272, 17.719496, -17.719496},{17.543272, 21.701862, -12.529576},{
      16.551481, 21.701862, -12.529576},{16.551481, 17.719496, -17.719496}}],
    Polygon[{{16.551481, 21.701862, -12.529576},{
      17.543272, 21.701862, -12.529576},{17.543272, 24.205282, -6.485786},{
      16.551481, 24.205282, -6.485786},{16.551481, 21.701862, -12.529576}}],
    Polygon[{{16.551481, 24.205282, -6.485786},{
      17.543272, 24.205282, -6.485786},{17.543272, 25.059153, -0.000000},{
      16.551481, 25.059153, -0.000000},{16.551481, 24.205282, -6.485786}}],
    Polygon[{{15.352635, 0.000000, 0.000000},{16.289419, 6.722335, 0.000000},{
      16.289419, 6.493277, 1.739868},{15.352635, 0.000000, 0.000000},{
      15.352635, 0.000000, 0.000000}}],
    Polygon[{{16.289419, 6.722335, 0.000000},{
      19.353966, 13.444670, 0.000000},{19.353966, 12.986553, 3.479737},{
      16.289419, 6.493277, 1.739868},{16.289419, 6.722335, 0.000000}}],
    Polygon[{{19.353966, 13.444670, 0.000000},{
      25.874273, 20.167004, 0.000000},{25.874273, 19.479830, 5.219604},{
      19.353966, 12.986553, 3.479737},{19.353966, 13.444670, 0.000000}}],
    Polygon[{{15.352635, 0.000000, 0.000000},{16.289419, 6.493277, 1.739868},{
      16.289419, 5.821712, 3.361167},{15.352635, 0.000000, 0.000000},{
      15.352635, 0.000000, 0.000000}}],
    Polygon[{{16.289419, 6.493277, 1.739868},{
      19.353966, 12.986553, 3.479737},{19.353966, 11.643425, 6.722335},{
      16.289419, 5.821712, 3.361167},{16.289419, 6.493277, 1.739868}}],
    Polygon[{{19.353966, 12.986553, 3.479737},{
      25.874273, 19.479830, 5.219604},{25.874273, 17.465137, 10.083502},{
      19.353966, 11.643425, 6.722335},{19.353966, 12.986553, 3.479737}}],
    Polygon[{{15.352635, 0.000000, 0.000000},{16.289419, 5.821712, 3.361167},{
      16.289419, 4.753408, 4.753408},{15.352635, 0.000000, 0.000000},{
      15.352635, 0.000000, 0.000000}}],
    Polygon[{{16.289419, 5.821712, 3.361167},{
      19.353966, 11.643425, 6.722335},{19.353966, 9.506817, 9.506817},{
      16.289419, 4.753408, 4.753408},{16.289419, 5.821712, 3.361167}}],
    Polygon[{{19.353966, 11.643425, 6.722335},{
      25.874273, 17.465137, 10.083502},{25.874273, 14.260225, 14.260225},{
      19.353966, 9.506817, 9.506817},{19.353966, 11.643425, 6.722335}}],
    Polygon[{{15.352635, 0.000000, 0.000000},{16.289419, 4.753408, 4.753408},{
      16.289419, 3.361167, 5.821712},{15.352635, 0.000000, 0.000000},{
      15.352635, 0.000000, 0.000000}}],
    Polygon[{{16.289419, 4.753408, 4.753408},{19.353966, 9.506817, 9.506817},{
      19.353966, 6.722335, 11.643425},{16.289419, 3.361167, 5.821712},{
      16.289419, 4.753408, 4.753408}}],
    Polygon[{{19.353966, 9.506817, 9.506817},{
      25.874273, 14.260225, 14.260225},{25.874273, 10.083502, 17.465137},{
      19.353966, 6.722335, 11.643425},{19.353966, 9.506817, 9.506817}}],
    Polygon[{{15.352635, 0.000000, 0.000000},{16.289419, 3.361167, 5.821712},{
      16.289419, 1.739868, 6.493277},{15.352635, 0.000000, 0.000000},{
      15.352635, 0.000000, 0.000000}}],
    Polygon[{{16.289419, 3.361167, 5.821712},{
      19.353966, 6.722335, 11.643425},{19.353966, 3.479737, 12.986553},{
      16.289419, 1.739868, 6.493277},{16.289419, 3.361167, 5.821712}}],
    Polygon[{{19.353966, 6.722335, 11.643425},{
      25.874273, 10.083502, 17.465137},{25.874273, 5.219604, 19.479830},{
      19.353966, 3.479737, 12.986553},{19.353966, 6.722335, 11.643425}}],
    Polygon[{{15.352635, 0.000000, 0.000000},{16.289419, 1.739868, 6.493277},{
      16.289419, 0.000000, 6.722335},{15.352635, 0.000000, 0.000000},{
      15.352635, 0.000000, 0.000000}}],
    Polygon[{{16.289419, 1.739868, 6.493277},{
      19.353966, 3.479737, 12.986553},{19.353966, 0.000000, 13.444670},{
      16.289419, 0.000000, 6.722335},{16.289419, 1.739868, 6.493277}}],
    Polygon[{{19.353966, 3.479737, 12.986553},{
      25.874273, 5.219604, 19.479830},{25.874273, 0.000000, 20.167004},{
      19.353966, 0.000000, 13.444670},{19.353966, 3.479737, 12.986553}}],
    Polygon[{{15.352635, 0.000000, 0.000000},{16.289419, 0.000000, 6.722335},{
      16.289419, -1.739868, 6.493277},{15.352635, -0.000000, 0.000000},{
      15.352635, 0.000000, 0.000000}}],
    Polygon[{{16.289419, 0.000000, 6.722335},{
      19.353966, 0.000000, 13.444670},{19.353966, -3.479737, 12.986553},{
      16.289419, -1.739868, 6.493277},{16.289419, 0.000000, 6.722335}}],
    Polygon[{{19.353966, 0.000000, 13.444670},{
      25.874273, 0.000000, 20.167004},{25.874273, -5.219604, 19.479830},{
      19.353966, -3.479737, 12.986553},{19.353966, 0.000000, 13.444670}}],
    Polygon[{{15.352635, -0.000000, 0.000000},{
      16.289419, -1.739868, 6.493277},{16.289419, -3.361167, 5.821712},{
      15.352635, -0.000000, 0.000000},{15.352635, -0.000000, 0.000000}}],
    Polygon[{{16.289419, -1.739868, 6.493277},{
      19.353966, -3.479737, 12.986553},{19.353966, -6.722335, 11.643425},{
      16.289419, -3.361167, 5.821712},{16.289419, -1.739868, 6.493277}}],
    Polygon[{{19.353966, -3.479737, 12.986553},{
      25.874273, -5.219604, 19.479830},{25.874273, -10.083502, 17.465137},{
      19.353966, -6.722335, 11.643425},{19.353966, -3.479737, 12.986553}}],
    Polygon[{{15.352635, -0.000000, 0.000000},{
      16.289419, -3.361167, 5.821712},{16.289419, -4.753408, 4.753408},{
      15.352635, -0.000000, 0.000000},{15.352635, -0.000000, 0.000000}}],
    Polygon[{{16.289419, -3.361167, 5.821712},{
      19.353966, -6.722335, 11.643425},{19.353966, -9.506817, 9.506817},{
      16.289419, -4.753408, 4.753408},{16.289419, -3.361167, 5.821712}}],
    Polygon[{{19.353966, -6.722335, 11.643425},{
      25.874273, -10.083502, 17.465137},{25.874273, -14.260225, 14.260225},{
      19.353966, -9.506817, 9.506817},{19.353966, -6.722335, 11.643425}}],
    Polygon[{{15.352635, -0.000000, 0.000000},{
      16.289419, -4.753408, 4.753408},{16.289419, -5.821712, 3.361167},{
      15.352635, -0.000000, 0.000000},{15.352635, -0.000000, 0.000000}}],
    Polygon[{{16.289419, -4.753408, 4.753408},{
      19.353966, -9.506817, 9.506817},{19.353966, -11.643425, 6.722335},{
      16.289419, -5.821712, 3.361167},{16.289419, -4.753408, 4.753408}}],
    Polygon[{{19.353966, -9.506817, 9.506817},{
      25.874273, -14.260225, 14.260225},{25.874273, -17.465137, 10.083502},{
      19.353966, -11.643425, 6.722335},{19.353966, -9.506817, 9.506817}}],
    Polygon[{{15.352635, -0.000000, 0.000000},{
      16.289419, -5.821712, 3.361167},{16.289419, -6.493277, 1.739868},{
      15.352635, -0.000000, 0.000000},{15.352635, -0.000000, 0.000000}}],
    Polygon[{{16.289419, -5.821712, 3.361167},{
      19.353966, -11.643425, 6.722335},{19.353966, -12.986553, 3.479737},{
      16.289419, -6.493277, 1.739868},{16.289419, -5.821712, 3.361167}}],
    Polygon[{{19.353966, -11.643425, 6.722335},{
      25.874273, -17.465137, 10.083502},{25.874273, -19.479830, 5.219604},{
      19.353966, -12.986553, 3.479737},{19.353966, -11.643425, 6.722335}}],
    Polygon[{{15.352635, -0.000000, 0.000000},{
      16.289419, -6.493277, 1.739868},{16.289419, -6.722335, 0.000000},{
      15.352635, -0.000000, 0.000000},{15.352635, -0.000000, 0.000000}}],
    Polygon[{{16.289419, -6.493277, 1.739868},{
      19.353966, -12.986553, 3.479737},{19.353966, -13.444670, 0.000000},{
      16.289419, -6.722335, 0.000000},{16.289419, -6.493277, 1.739868}}],
    Polygon[{{19.353966, -12.986553, 3.479737},{
      25.874273, -19.479830, 5.219604},{25.874273, -20.167004, 0.000000},{
      19.353966, -13.444670, 0.000000},{19.353966, -12.986553, 3.479737}}],
    Polygon[{{15.352635, -0.000000, 0.000000},{
      16.289419, -6.722335, 0.000000},{16.289419, -6.493277, -1.739868},{
      15.352635, -0.000000, -0.000000},{15.352635, -0.000000, 0.000000}}],
    Polygon[{{16.289419, -6.722335, 0.000000},{
      19.353966, -13.444670, 0.000000},{19.353966, -12.986553, -3.479737},{
      16.289419, -6.493277, -1.739868},{16.289419, -6.722335, 0.000000}}],
    Polygon[{{19.353966, -13.444670, 0.000000},{
      25.874273, -20.167004, 0.000000},{25.874273, -19.479830, -5.219604},{
      19.353966, -12.986553, -3.479737},{19.353966, -13.444670, 0.000000}}],
    Polygon[{{15.352635, -0.000000, -0.000000},{
      16.289419, -6.493277, -1.739868},{16.289419, -5.821712, -3.361167},{
      15.352635, -0.000000, -0.000000},{15.352635, -0.000000, -0.000000}}],
    Polygon[{{16.289419, -6.493277, -1.739868},{
      19.353966, -12.986553, -3.479737},{19.353966, -11.643425, -6.722335},{
      16.289419, -5.821712, -3.361167},{16.289419, -6.493277, -1.739868}}],
    Polygon[{{19.353966, -12.986553, -3.479737},{
      25.874273, -19.479830, -5.219604},{25.874273, -17.465137, -10.083502},{
      19.353966, -11.643425, -6.722335},{19.353966, -12.986553, -3.479737}}],
    Polygon[{{15.352635, -0.000000, -0.000000},{
      16.289419, -5.821712, -3.361167},{16.289419, -4.753408, -4.753408},{
      15.352635, -0.000000, -0.000000},{15.352635, -0.000000, -0.000000}}],
    Polygon[{{16.289419, -5.821712, -3.361167},{
      19.353966, -11.643425, -6.722335},{19.353966, -9.506817, -9.506817},{
      16.289419, -4.753408, -4.753408},{16.289419, -5.821712, -3.361167}}],
    Polygon[{{19.353966, -11.643425, -6.722335},{
      25.874273, -17.465137, -10.083502},{25.874273, -14.260225, -14.260225},{
      19.353966, -9.506817, -9.506817},{19.353966, -11.643425, -6.722335}}],
    Polygon[{{15.352635, -0.000000, -0.000000},{
      16.289419, -4.753408, -4.753408},{16.289419, -3.361167, -5.821712},{
      15.352635, -0.000000, -0.000000},{15.352635, -0.000000, -0.000000}}],
    Polygon[{{16.289419, -4.753408, -4.753408},{
      19.353966, -9.506817, -9.506817},{19.353966, -6.722335, -11.643425},{
      16.289419, -3.361167, -5.821712},{16.289419, -4.753408, -4.753408}}],
    Polygon[{{19.353966, -9.506817, -9.506817},{
      25.874273, -14.260225, -14.260225},{25.874273, -10.083502, -17.465137},{
      19.353966, -6.722335, -11.643425},{19.353966, -9.506817, -9.506817}}],
    Polygon[{{15.352635, -0.000000, -0.000000},{
      16.289419, -3.361167, -5.821712},{16.289419, -1.739868, -6.493277},{
      15.352635, -0.000000, -0.000000},{15.352635, -0.000000, -0.000000}}],
    Polygon[{{16.289419, -3.361167, -5.821712},{
      19.353966, -6.722335, -11.643425},{19.353966, -3.479737, -12.986553},{
      16.289419, -1.739868, -6.493277},{16.289419, -3.361167, -5.821712}}],
    Polygon[{{19.353966, -6.722335, -11.643425},{
      25.874273, -10.083502, -17.465137},{25.874273, -5.219604, -19.479830},{
      19.353966, -3.479737, -12.986553},{19.353966, -6.722335, -11.643425}}],
    Polygon[{{15.352635, -0.000000, -0.000000},{
      16.289419, -1.739868, -6.493277},{16.289419, -0.000000, -6.722335},{
      15.352635, -0.000000, -0.000000},{15.352635, -0.000000, -0.000000}}],
    Polygon[{{16.289419, -1.739868, -6.493277},{
      19.353966, -3.479737, -12.986553},{19.353966, -0.000000, -13.444670},{
      16.289419, -0.000000, -6.722335},{16.289419, -1.739868, -6.493277}}],
    Polygon[{{19.353966, -3.479737, -12.986553},{
      25.874273, -5.219604, -19.479830},{25.874273, -0.000000, -20.167004},{
      19.353966, -0.000000, -13.444670},{19.353966, -3.479737, -12.986553}}],
    Polygon[{{15.352635, -0.000000, -0.000000},{
      16.289419, -0.000000, -6.722335},{16.289419, 1.739868, -6.493277},{
      15.352635, 0.000000, -0.000000},{15.352635, -0.000000, -0.000000}}],
    Polygon[{{16.289419, -0.000000, -6.722335},{
      19.353966, -0.000000, -13.444670},{19.353966, 3.479737, -12.986553},{
      16.289419, 1.739868, -6.493277},{16.289419, -0.000000, -6.722335}}],
    Polygon[{{19.353966, -0.000000, -13.444670},{
      25.874273, -0.000000, -20.167004},{25.874273, 5.219604, -19.479830},{
      19.353966, 3.479737, -12.986553},{19.353966, -0.000000, -13.444670}}],
    Polygon[{{15.352635, 0.000000, -0.000000},{
      16.289419, 1.739868, -6.493277},{16.289419, 3.361167, -5.821712},{
      15.352635, 0.000000, -0.000000},{15.352635, 0.000000, -0.000000}}],
    Polygon[{{16.289419, 1.739868, -6.493277},{
      19.353966, 3.479737, -12.986553},{19.353966, 6.722335, -11.643425},{
      16.289419, 3.361167, -5.821712},{16.289419, 1.739868, -6.493277}}],
    Polygon[{{19.353966, 3.479737, -12.986553},{
      25.874273, 5.219604, -19.479830},{25.874273, 10.083502, -17.465137},{
      19.353966, 6.722335, -11.643425},{19.353966, 3.479737, -12.986553}}],
    Polygon[{{15.352635, 0.000000, -0.000000},{
      16.289419, 3.361167, -5.821712},{16.289419, 4.753408, -4.753408},{
      15.352635, 0.000000, -0.000000},{15.352635, 0.000000, -0.000000}}],
    Polygon[{{16.289419, 3.361167, -5.821712},{
      19.353966, 6.722335, -11.643425},{19.353966, 9.506817, -9.506817},{
      16.289419, 4.753408, -4.753408},{16.289419, 3.361167, -5.821712}}],
    Polygon[{{19.353966, 6.722335, -11.643425},{
      25.874273, 10.083502, -17.465137},{25.874273, 14.260225, -14.260225},{
      19.353966, 9.506817, -9.506817},{19.353966, 6.722335, -11.643425}}],
    Polygon[{{15.352635, 0.000000, -0.000000},{
      16.289419, 4.753408, -4.753408},{16.289419, 5.821712, -3.361167},{
      15.352635, 0.000000, -0.000000},{15.352635, 0.000000, -0.000000}}],
    Polygon[{{16.289419, 4.753408, -4.753408},{
      19.353966, 9.506817, -9.506817},{19.353966, 11.643425, -6.722335},{
      16.289419, 5.821712, -3.361167},{16.289419, 4.753408, -4.753408}}],
    Polygon[{{19.353966, 9.506817, -9.506817},{
      25.874273, 14.260225, -14.260225},{25.874273, 17.465137, -10.083502},{
      19.353966, 11.643425, -6.722335},{19.353966, 9.506817, -9.506817}}],
    Polygon[{{15.352635, 0.000000, -0.000000},{
      16.289419, 5.821712, -3.361167},{16.289419, 6.493277, -1.739868},{
      15.352635, 0.000000, -0.000000},{15.352635, 0.000000, -0.000000}}],
    Polygon[{{16.289419, 5.821712, -3.361167},{
      19.353966, 11.643425, -6.722335},{19.353966, 12.986553, -3.479737},{
      16.289419, 6.493277, -1.739868},{16.289419, 5.821712, -3.361167}}],
    Polygon[{{19.353966, 11.643425, -6.722335},{
      25.874273, 17.465137, -10.083502},{25.874273, 19.479830, -5.219604},{
      19.353966, 12.986553, -3.479737},{19.353966, 11.643425, -6.722335}}],
    Polygon[{{15.352635, 0.000000, -0.000000},{
      16.289419, 6.493277, -1.739868},{16.289419, 6.722335, -0.000000},{
      15.352635, 0.000000, -0.000000},{15.352635, 0.000000, -0.000000}}],
    Polygon[{{16.289419, 6.493277, -1.739868},{
      19.353966, 12.986553, -3.479737},{19.353966, 13.444670, -0.000000},{
      16.289419, 6.722335, -0.000000},{16.289419, 6.493277, -1.739868}}],
    Polygon[{{19.353966, 12.986553, -3.479737},{
      25.874273, 19.479830, -5.219604},{25.874273, 20.167004, -0.000000},{
      19.353966, 13.444670, -0.000000},{19.353966, 12.986553, -3.479737}}],
    Line[{{25.874273, 20.167004, 0.000000},{25.874273, 19.479830, 5.219604},{
      25.874273, 17.465137, 10.083502},{25.874273, 14.260225, 14.260225},{
      25.874273, 10.083502, 17.465137},{25.874273, 5.219604, 19.479830},{
      25.874273, 0.000000, 20.167004},{25.874273, -5.219604, 19.479830},{
      25.874273, -10.083502, 17.465137},{25.874273, -14.260225, 14.260225},{
      25.874273, -17.465137, 10.083502},{25.874273, -19.479830, 5.219604},{
      25.874273, -20.167004, 0.000000},{25.874273, -19.479830, -5.219604},{
      25.874273, -17.465137, -10.083502},{25.874273, -14.260225, -14.260225},{
      25.874273, -10.083502, -17.465137},{25.874273, -5.219604, -19.479830},{
      25.874273, -0.000000, -20.167004},{25.874273, 5.219604, -19.479830},{
      25.874273, 10.083502, -17.465137},{25.874273, 14.260225, -14.260225},{
      25.874273, 17.465137, -10.083502},{25.874273, 19.479830, -5.219604},{
      25.874273, 20.167004, -0.000000}}],
    Polygon[{{28.353323, 0.000000, 0.000000},{28.922642, 4.331157, 0.000000},{
      28.922642, 4.183577, 1.120986},{28.353323, 0.000000, 0.000000},{
      28.353323, 0.000000, 0.000000}}],
    Polygon[{{28.922642, 4.331157, 0.000000},{30.765509, 8.662314, 0.000000},{
      30.765509, 8.367153, 2.241972},{28.922642, 4.183577, 1.120986},{
      28.922642, 4.331157, 0.000000}}],
    Polygon[{{30.765509, 8.662314, 0.000000},{
      34.527393, 12.993471, 0.000000},{34.527393, 12.550729, 3.362958},{
      30.765509, 8.367153, 2.241972},{30.765509, 8.662314, 0.000000}}],
    Polygon[{{28.353323, 0.000000, 0.000000},{28.922642, 4.183577, 1.120986},{
      28.922642, 3.750892, 2.165579},{28.353323, 0.000000, 0.000000},{
      28.353323, 0.000000, 0.000000}}],
    Polygon[{{28.922642, 4.183577, 1.120986},{30.765509, 8.367153, 2.241972},{
      30.765509, 7.501784, 4.331157},{28.922642, 3.750892, 2.165579},{
      28.922642, 4.183577, 1.120986}}],
    Polygon[{{30.765509, 8.367153, 2.241972},{
      34.527393, 12.550729, 3.362958},{34.527393, 11.252676, 6.496736},{
      30.765509, 7.501784, 4.331157},{30.765509, 8.367153, 2.241972}}],
    Polygon[{{28.353323, 0.000000, 0.000000},{28.922642, 3.750892, 2.165579},{
      28.922642, 3.062591, 3.062591},{28.353323, 0.000000, 0.000000},{
      28.353323, 0.000000, 0.000000}}],
    Polygon[{{28.922642, 3.750892, 2.165579},{30.765509, 7.501784, 4.331157},{
      30.765509, 6.125181, 6.125181},{28.922642, 3.062591, 3.062591},{
      28.922642, 3.750892, 2.165579}}],
    Polygon[{{30.765509, 7.501784, 4.331157},{
      34.527393, 11.252676, 6.496736},{34.527393, 9.187772, 9.187772},{
      30.765509, 6.125181, 6.125181},{30.765509, 7.501784, 4.331157}}],
    Polygon[{{28.353323, 0.000000, 0.000000},{28.922642, 3.062591, 3.062591},{
      28.922642, 2.165579, 3.750892},{28.353323, 0.000000, 0.000000},{
      28.353323, 0.000000, 0.000000}}],
    Polygon[{{28.922642, 3.062591, 3.062591},{30.765509, 6.125181, 6.125181},{
      30.765509, 4.331157, 7.501784},{28.922642, 2.165579, 3.750892},{
      28.922642, 3.062591, 3.062591}}],
    Polygon[{{30.765509, 6.125181, 6.125181},{34.527393, 9.187772, 9.187772},{
      34.527393, 6.496736, 11.252676},{30.765509, 4.331157, 7.501784},{
      30.765509, 6.125181, 6.125181}}],
    Polygon[{{28.353323, 0.000000, 0.000000},{28.922642, 2.165579, 3.750892},{
      28.922642, 1.120986, 4.183577},{28.353323, 0.000000, 0.000000},{
      28.353323, 0.000000, 0.000000}}],
    Polygon[{{28.922642, 2.165579, 3.750892},{30.765509, 4.331157, 7.501784},{
      30.765509, 2.241972, 8.367153},{28.922642, 1.120986, 4.183577},{
      28.922642, 2.165579, 3.750892}}],
    Polygon[{{30.765509, 4.331157, 7.501784},{
      34.527393, 6.496736, 11.252676},{34.527393, 3.362958, 12.550729},{
      30.765509, 2.241972, 8.367153},{30.765509, 4.331157, 7.501784}}],
    Polygon[{{28.353323, 0.000000, 0.000000},{28.922642, 1.120986, 4.183577},{
      28.922642, 0.000000, 4.331157},{28.353323, 0.000000, 0.000000},{
      28.353323, 0.000000, 0.000000}}],
    Polygon[{{28.922642, 1.120986, 4.183577},{30.765509, 2.241972, 8.367153},{
      30.765509, 0.000000, 8.662314},{28.922642, 0.000000, 4.331157},{
      28.922642, 1.120986, 4.183577}}],
    Polygon[{{30.765509, 2.241972, 8.367153},{
      34.527393, 3.362958, 12.550729},{34.527393, 0.000000, 12.993471},{
      30.765509, 0.000000, 8.662314},{30.765509, 2.241972, 8.367153}}],
    Polygon[{{28.353323, 0.000000, 0.000000},{28.922642, 0.000000, 4.331157},{
      28.922642, -1.120986, 4.183577},{28.353323, -0.000000, 0.000000},{
      28.353323, 0.000000, 0.000000}}],
    Polygon[{{28.922642, 0.000000, 4.331157},{30.765509, 0.000000, 8.662314},{
      30.765509, -2.241972, 8.367153},{28.922642, -1.120986, 4.183577},{
      28.922642, 0.000000, 4.331157}}],
    Polygon[{{30.765509, 0.000000, 8.662314},{
      34.527393, 0.000000, 12.993471},{34.527393, -3.362958, 12.550729},{
      30.765509, -2.241972, 8.367153},{30.765509, 0.000000, 8.662314}}],
    Polygon[{{28.353323, -0.000000, 0.000000},{
      28.922642, -1.120986, 4.183577},{28.922642, -2.165579, 3.750892},{
      28.353323, -0.000000, 0.000000},{28.353323, -0.000000, 0.000000}}],
    Polygon[{{28.922642, -1.120986, 4.183577},{
      30.765509, -2.241972, 8.367153},{30.765509, -4.331157, 7.501784},{
      28.922642, -2.165579, 3.750892},{28.922642, -1.120986, 4.183577}}],
    Polygon[{{30.765509, -2.241972, 8.367153},{
      34.527393, -3.362958, 12.550729},{34.527393, -6.496736, 11.252676},{
      30.765509, -4.331157, 7.501784},{30.765509, -2.241972, 8.367153}}],
    Polygon[{{28.353323, -0.000000, 0.000000},{
      28.922642, -2.165579, 3.750892},{28.922642, -3.062591, 3.062591},{
      28.353323, -0.000000, 0.000000},{28.353323, -0.000000, 0.000000}}],
    Polygon[{{28.922642, -2.165579, 3.750892},{
      30.765509, -4.331157, 7.501784},{30.765509, -6.125181, 6.125181},{
      28.922642, -3.062591, 3.062591},{28.922642, -2.165579, 3.750892}}],
    Polygon[{{30.765509, -4.331157, 7.501784},{
      34.527393, -6.496736, 11.252676},{34.527393, -9.187772, 9.187772},{
      30.765509, -6.125181, 6.125181},{30.765509, -4.331157, 7.501784}}],
    Polygon[{{28.353323, -0.000000, 0.000000},{
      28.922642, -3.062591, 3.062591},{28.922642, -3.750892, 2.165579},{
      28.353323, -0.000000, 0.000000},{28.353323, -0.000000, 0.000000}}],
    Polygon[{{28.922642, -3.062591, 3.062591},{
      30.765509, -6.125181, 6.125181},{30.765509, -7.501784, 4.331157},{
      28.922642, -3.750892, 2.165579},{28.922642, -3.062591, 3.062591}}],
    Polygon[{{30.765509, -6.125181, 6.125181},{
      34.527393, -9.187772, 9.187772},{34.527393, -11.252676, 6.496736},{
      30.765509, -7.501784, 4.331157},{30.765509, -6.125181, 6.125181}}],
    Polygon[{{28.353323, -0.000000, 0.000000},{
      28.922642, -3.750892, 2.165579},{28.922642, -4.183577, 1.120986},{
      28.353323, -0.000000, 0.000000},{28.353323, -0.000000, 0.000000}}],
    Polygon[{{28.922642, -3.750892, 2.165579},{
      30.765509, -7.501784, 4.331157},{30.765509, -8.367153, 2.241972},{
      28.922642, -4.183577, 1.120986},{28.922642, -3.750892, 2.165579}}],
    Polygon[{{30.765509, -7.501784, 4.331157},{
      34.527393, -11.252676, 6.496736},{34.527393, -12.550729, 3.362958},{
      30.765509, -8.367153, 2.241972},{30.765509, -7.501784, 4.331157}}],
    Polygon[{{28.353323, -0.000000, 0.000000},{
      28.922642, -4.183577, 1.120986},{28.922642, -4.331157, 0.000000},{
      28.353323, -0.000000, 0.000000},{28.353323, -0.000000, 0.000000}}],
    Polygon[{{28.922642, -4.183577, 1.120986},{
      30.765509, -8.367153, 2.241972},{30.765509, -8.662314, 0.000000},{
      28.922642, -4.331157, 0.000000},{28.922642, -4.183577, 1.120986}}],
    Polygon[{{30.765509, -8.367153, 2.241972},{
      34.527393, -12.550729, 3.362958},{34.527393, -12.993471, 0.000000},{
      30.765509, -8.662314, 0.000000},{30.765509, -8.367153, 2.241972}}],
    Polygon[{{28.353323, -0.000000, 0.000000},{
      28.922642, -4.331157, 0.000000},{28.922642, -4.183577, -1.120986},{
      28.353323, -0.000000, -0.000000},{28.353323, -0.000000, 0.000000}}],
    Polygon[{{28.922642, -4.331157, 0.000000},{
      30.765509, -8.662314, 0.000000},{30.765509, -8.367153, -2.241972},{
      28.922642, -4.183577, -1.120986},{28.922642, -4.331157, 0.000000}}],
    Polygon[{{30.765509, -8.662314, 0.000000},{
      34.527393, -12.993471, 0.000000},{34.527393, -12.550729, -3.362958},{
      30.765509, -8.367153, -2.241972},{30.765509, -8.662314, 0.000000}}],
    Polygon[{{28.353323, -0.000000, -0.000000},{
      28.922642, -4.183577, -1.120986},{28.922642, -3.750892, -2.165579},{
      28.353323, -0.000000, -0.000000},{28.353323, -0.000000, -0.000000}}],
    Polygon[{{28.922642, -4.183577, -1.120986},{
      30.765509, -8.367153, -2.241972},{30.765509, -7.501784, -4.331157},{
      28.922642, -3.750892, -2.165579},{28.922642, -4.183577, -1.120986}}],
    Polygon[{{30.765509, -8.367153, -2.241972},{
      34.527393, -12.550729, -3.362958},{34.527393, -11.252676, -6.496736},{
      30.765509, -7.501784, -4.331157},{30.765509, -8.367153, -2.241972}}],
    Polygon[{{28.353323, -0.000000, -0.000000},{
      28.922642, -3.750892, -2.165579},{28.922642, -3.062591, -3.062591},{
      28.353323, -0.000000, -0.000000},{28.353323, -0.000000, -0.000000}}],
    Polygon[{{28.922642, -3.750892, -2.165579},{
      30.765509, -7.501784, -4.331157},{30.765509, -6.125181, -6.125181},{
      28.922642, -3.062591, -3.062591},{28.922642, -3.750892, -2.165579}}],
    Polygon[{{30.765509, -7.501784, -4.331157},{
      34.527393, -11.252676, -6.496736},{34.527393, -9.187772, -9.187772},{
      30.765509, -6.125181, -6.125181},{30.765509, -7.501784, -4.331157}}],
    Polygon[{{28.353323, -0.000000, -0.000000},{
      28.922642, -3.062591, -3.062591},{28.922642, -2.165579, -3.750892},{
      28.353323, -0.000000, -0.000000},{28.353323, -0.000000, -0.000000}}],
    Polygon[{{28.922642, -3.062591, -3.062591},{
      30.765509, -6.125181, -6.125181},{30.765509, -4.331157, -7.501784},{
      28.922642, -2.165579, -3.750892},{28.922642, -3.062591, -3.062591}}],
    Polygon[{{30.765509, -6.125181, -6.125181},{
      34.527393, -9.187772, -9.187772},{34.527393, -6.496736, -11.252676},{
      30.765509, -4.331157, -7.501784},{30.765509, -6.125181, -6.125181}}],
    Polygon[{{28.353323, -0.000000, -0.000000},{
      28.922642, -2.165579, -3.750892},{28.922642, -1.120986, -4.183577},{
      28.353323, -0.000000, -0.000000},{28.353323, -0.000000, -0.000000}}],
    Polygon[{{28.922642, -2.165579, -3.750892},{
      30.765509, -4.331157, -7.501784},{30.765509, -2.241972, -8.367153},{
      28.922642, -1.120986, -4.183577},{28.922642, -2.165579, -3.750892}}],
    Polygon[{{30.765509, -4.331157, -7.501784},{
      34.527393, -6.496736, -11.252676},{34.527393, -3.362958, -12.550729},{
      30.765509, -2.241972, -8.367153},{30.765509, -4.331157, -7.501784}}],
    Polygon[{{28.353323, -0.000000, -0.000000},{
      28.922642, -1.120986, -4.183577},{28.922642, -0.000000, -4.331157},{
      28.353323, -0.000000, -0.000000},{28.353323, -0.000000, -0.000000}}],
    Polygon[{{28.922642, -1.120986, -4.183577},{
      30.765509, -2.241972, -8.367153},{30.765509, -0.000000, -8.662314},{
      28.922642, -0.000000, -4.331157},{28.922642, -1.120986, -4.183577}}],
    Polygon[{{30.765509, -2.241972, -8.367153},{
      34.527393, -3.362958, -12.550729},{34.527393, -0.000000, -12.993471},{
      30.765509, -0.000000, -8.662314},{30.765509, -2.241972, -8.367153}}],
    Polygon[{{28.353323, -0.000000, -0.000000},{
      28.922642, -0.000000, -4.331157},{28.922642, 1.120986, -4.183577},{
      28.353323, 0.000000, -0.000000},{28.353323, -0.000000, -0.000000}}],
    Polygon[{{28.922642, -0.000000, -4.331157},{
      30.765509, -0.000000, -8.662314},{30.765509, 2.241972, -8.367153},{
      28.922642, 1.120986, -4.183577},{28.922642, -0.000000, -4.331157}}],
    Polygon[{{30.765509, -0.000000, -8.662314},{
      34.527393, -0.000000, -12.993471},{34.527393, 3.362958, -12.550729},{
      30.765509, 2.241972, -8.367153},{30.765509, -0.000000, -8.662314}}],
    Polygon[{{28.353323, 0.000000, -0.000000},{
      28.922642, 1.120986, -4.183577},{28.922642, 2.165579, -3.750892},{
      28.353323, 0.000000, -0.000000},{28.353323, 0.000000, -0.000000}}],
    Polygon[{{28.922642, 1.120986, -4.183577},{
      30.765509, 2.241972, -8.367153},{30.765509, 4.331157, -7.501784},{
      28.922642, 2.165579, -3.750892},{28.922642, 1.120986, -4.183577}}],
    Polygon[{{30.765509, 2.241972, -8.367153},{
      34.527393, 3.362958, -12.550729},{34.527393, 6.496736, -11.252676},{
      30.765509, 4.331157, -7.501784},{30.765509, 2.241972, -8.367153}}],
    Polygon[{{28.353323, 0.000000, -0.000000},{
      28.922642, 2.165579, -3.750892},{28.922642, 3.062591, -3.062591},{
      28.353323, 0.000000, -0.000000},{28.353323, 0.000000, -0.000000}}],
    Polygon[{{28.922642, 2.165579, -3.750892},{
      30.765509, 4.331157, -7.501784},{30.765509, 6.125181, -6.125181},{
      28.922642, 3.062591, -3.062591},{28.922642, 2.165579, -3.750892}}],
    Polygon[{{30.765509, 4.331157, -7.501784},{
      34.527393, 6.496736, -11.252676},{34.527393, 9.187772, -9.187772},{
      30.765509, 6.125181, -6.125181},{30.765509, 4.331157, -7.501784}}],
    Polygon[{{28.353323, 0.000000, -0.000000},{
      28.922642, 3.062591, -3.062591},{28.922642, 3.750892, -2.165579},{
      28.353323, 0.000000, -0.000000},{28.353323, 0.000000, -0.000000}}],
    Polygon[{{28.922642, 3.062591, -3.062591},{
      30.765509, 6.125181, -6.125181},{30.765509, 7.501784, -4.331157},{
      28.922642, 3.750892, -2.165579},{28.922642, 3.062591, -3.062591}}],
    Polygon[{{30.765509, 6.125181, -6.125181},{
      34.527393, 9.187772, -9.187772},{34.527393, 11.252676, -6.496736},{
      30.765509, 7.501784, -4.331157},{30.765509, 6.125181, -6.125181}}],
    Polygon[{{28.353323, 0.000000, -0.000000},{
      28.922642, 3.750892, -2.165579},{28.922642, 4.183577, -1.120986},{
      28.353323, 0.000000, -0.000000},{28.353323, 0.000000, -0.000000}}],
    Polygon[{{28.922642, 3.750892, -2.165579},{
      30.765509, 7.501784, -4.331157},{30.765509, 8.367153, -2.241972},{
      28.922642, 4.183577, -1.120986},{28.922642, 3.750892, -2.165579}}],
    Polygon[{{30.765509, 7.501784, -4.331157},{
      34.527393, 11.252676, -6.496736},{34.527393, 12.550729, -3.362958},{
      30.765509, 8.367153, -2.241972},{30.765509, 7.501784, -4.331157}}],
    Polygon[{{28.353323, 0.000000, -0.000000},{
      28.922642, 4.183577, -1.120986},{28.922642, 4.331157, -0.000000},{
      28.353323, 0.000000, -0.000000},{28.353323, 0.000000, -0.000000}}],
    Polygon[{{28.922642, 4.183577, -1.120986},{
      30.765509, 8.367153, -2.241972},{30.765509, 8.662314, -0.000000},{
      28.922642, 4.331157, -0.000000},{28.922642, 4.183577, -1.120986}}],
    Polygon[{{30.765509, 8.367153, -2.241972},{
      34.527393, 12.550729, -3.362958},{34.527393, 12.993471, -0.000000},{
      30.765509, 8.662314, -0.000000},{30.765509, 8.367153, -2.241972}}],
    Line[{{34.527393, 12.993471, 0.000000},{34.527393, 12.550729, 3.362958},{
      34.527393, 11.252676, 6.496736},{34.527393, 9.187772, 9.187772},{
      34.527393, 6.496736, 11.252676},{34.527393, 3.362958, 12.550729},{
      34.527393, 0.000000, 12.993471},{34.527393, -3.362958, 12.550729},{
      34.527393, -6.496736, 11.252676},{34.527393, -9.187772, 9.187772},{
      34.527393, -11.252676, 6.496736},{34.527393, -12.550729, 3.362958},{
      34.527393, -12.993471, 0.000000},{34.527393, -12.550729, -3.362958},{
      34.527393, -11.252676, -6.496736},{34.527393, -9.187772, -9.187772},{
      34.527393, -6.496736, -11.252676},{34.527393, -3.362958, -12.550729},{
      34.527393, -0.000000, -12.993471},{34.527393, 3.362958, -12.550729},{
      34.527393, 6.496736, -11.252676},{34.527393, 9.187772, -9.187772},{
      34.527393, 11.252676, -6.496736},{34.527393, 12.550729, -3.362958},{
      34.527393, 12.993471, -0.000000}}],
    Polygon[{{25.874273, 20.167004, 0.000000},{
      34.527393, 12.993471, 0.000000},{34.527393, 12.550729, 3.362958},{
      25.874273, 19.479830, 5.219604},{25.874273, 20.167004, 0.000000}}],
    Polygon[{{25.874273, 19.479830, 5.219604},{
      34.527393, 12.550729, 3.362958},{34.527393, 11.252676, 6.496736},{
      25.874273, 17.465137, 10.083502},{25.874273, 19.479830, 5.219604}}],
    Polygon[{{25.874273, 17.465137, 10.083502},{
      34.527393, 11.252676, 6.496736},{34.527393, 9.187772, 9.187772},{
      25.874273, 14.260225, 14.260225},{25.874273, 17.465137, 10.083502}}],
    Polygon[{{25.874273, 14.260225, 14.260225},{
      34.527393, 9.187772, 9.187772},{34.527393, 6.496736, 11.252676},{
      25.874273, 10.083502, 17.465137},{25.874273, 14.260225, 14.260225}}],
    Polygon[{{25.874273, 10.083502, 17.465137},{
      34.527393, 6.496736, 11.252676},{34.527393, 3.362958, 12.550729},{
      25.874273, 5.219604, 19.479830},{25.874273, 10.083502, 17.465137}}],
    Polygon[{{25.874273, 5.219604, 19.479830},{
      34.527393, 3.362958, 12.550729},{34.527393, 0.000000, 12.993471},{
      25.874273, 0.000000, 20.167004},{25.874273, 5.219604, 19.479830}}],
    Polygon[{{25.874273, 0.000000, 20.167004},{
      34.527393, 0.000000, 12.993471},{34.527393, -3.362958, 12.550729},{
      25.874273, -5.219604, 19.479830},{25.874273, 0.000000, 20.167004}}],
    Polygon[{{25.874273, -5.219604, 19.479830},{
      34.527393, -3.362958, 12.550729},{34.527393, -6.496736, 11.252676},{
      25.874273, -10.083502, 17.465137},{25.874273, -5.219604, 19.479830}}],
    Polygon[{{25.874273, -10.083502, 17.465137},{
      34.527393, -6.496736, 11.252676},{34.527393, -9.187772, 9.187772},{
      25.874273, -14.260225, 14.260225},{25.874273, -10.083502, 17.465137}}],
    Polygon[{{25.874273, -14.260225, 14.260225},{
      34.527393, -9.187772, 9.187772},{34.527393, -11.252676, 6.496736},{
      25.874273, -17.465137, 10.083502},{25.874273, -14.260225, 14.260225}}],
    Polygon[{{25.874273, -17.465137, 10.083502},{
      34.527393, -11.252676, 6.496736},{34.527393, -12.550729, 3.362958},{
      25.874273, -19.479830, 5.219604},{25.874273, -17.465137, 10.083502}}],
    Polygon[{{25.874273, -19.479830, 5.219604},{
      34.527393, -12.550729, 3.362958},{34.527393, -12.993471, 0.000000},{
      25.874273, -20.167004, 0.000000},{25.874273, -19.479830, 5.219604}}],
    Polygon[{{25.874273, -20.167004, 0.000000},{
      34.527393, -12.993471, 0.000000},{34.527393, -12.550729, -3.362958},{
      25.874273, -19.479830, -5.219604},{25.874273, -20.167004, 0.000000}}],
    Polygon[{{25.874273, -19.479830, -5.219604},{
      34.527393, -12.550729, -3.362958},{34.527393, -11.252676, -6.496736},{
      25.874273, -17.465137, -10.083502},{25.874273, -19.479830, -5.219604}}],
    
    Polygon[{{25.874273, -17.465137, -10.083502},{
      34.527393, -11.252676, -6.496736},{34.527393, -9.187772, -9.187772},{
      25.874273, -14.260225, -14.260225},{
      25.874273, -17.465137, -10.083502}}],
    Polygon[{{25.874273, -14.260225, -14.260225},{
      34.527393, -9.187772, -9.187772},{34.527393, -6.496736, -11.252676},{
      25.874273, -10.083502, -17.465137},{
      25.874273, -14.260225, -14.260225}}],
    Polygon[{{25.874273, -10.083502, -17.465137},{
      34.527393, -6.496736, -11.252676},{34.527393, -3.362958, -12.550729},{
      25.874273, -5.219604, -19.479830},{25.874273, -10.083502, -17.465137}}],
    
    Polygon[{{25.874273, -5.219604, -19.479830},{
      34.527393, -3.362958, -12.550729},{34.527393, -0.000000, -12.993471},{
      25.874273, -0.000000, -20.167004},{25.874273, -5.219604, -19.479830}}],
    Polygon[{{25.874273, -0.000000, -20.167004},{
      34.527393, -0.000000, -12.993471},{34.527393, 3.362958, -12.550729},{
      25.874273, 5.219604, -19.479830},{25.874273, -0.000000, -20.167004}}],
    Polygon[{{25.874273, 5.219604, -19.479830},{
      34.527393, 3.362958, -12.550729},{34.527393, 6.496736, -11.252676},{
      25.874273, 10.083502, -17.465137},{25.874273, 5.219604, -19.479830}}],
    Polygon[{{25.874273, 10.083502, -17.465137},{
      34.527393, 6.496736, -11.252676},{34.527393, 9.187772, -9.187772},{
      25.874273, 14.260225, -14.260225},{25.874273, 10.083502, -17.465137}}],
    Polygon[{{25.874273, 14.260225, -14.260225},{
      34.527393, 9.187772, -9.187772},{34.527393, 11.252676, -6.496736},{
      25.874273, 17.465137, -10.083502},{25.874273, 14.260225, -14.260225}}],
    Polygon[{{25.874273, 17.465137, -10.083502},{
      34.527393, 11.252676, -6.496736},{34.527393, 12.550729, -3.362958},{
      25.874273, 19.479830, -5.219604},{25.874273, 17.465137, -10.083502}}],
    Polygon[{{25.874273, 19.479830, -5.219604},{
      34.527393, 12.550729, -3.362958},{34.527393, 12.993471, -0.000000},{
      25.874273, 20.167004, -0.000000},{25.874273, 19.479830, -5.219604}}],
    Polygon[{{34.527897, 0.000000, 0.000000},{34.527897, 4.331023, 0.000000},{
      34.527897, 4.183447, 1.120951},{34.527897, 0.000000, 0.000000},{
      34.527897, 0.000000, 0.000000}}],
    Polygon[{{34.527897, 4.331023, 0.000000},{34.527897, 8.662046, 0.000000},{
      34.527897, 8.366895, 2.241903},{34.527897, 4.183447, 1.120951},{
      34.527897, 4.331023, 0.000000}}],
    Polygon[{{34.527897, 8.662046, 0.000000},{
      34.527897, 12.993070, 0.000000},{34.527897, 12.550342, 3.362854},{
      34.527897, 8.366895, 2.241903},{34.527897, 8.662046, 0.000000}}],
    Polygon[{{34.527897, 0.000000, 0.000000},{34.527897, 4.183447, 1.120951},{
      34.527897, 3.750776, 2.165512},{34.527897, 0.000000, 0.000000},{
      34.527897, 0.000000, 0.000000}}],
    Polygon[{{34.527897, 4.183447, 1.120951},{34.527897, 8.366895, 2.241903},{
      34.527897, 7.501553, 4.331023},{34.527897, 3.750776, 2.165512},{
      34.527897, 4.183447, 1.120951}}],
    Polygon[{{34.527897, 8.366895, 2.241903},{
      34.527897, 12.550342, 3.362854},{34.527897, 11.252329, 6.496535},{
      34.527897, 7.501553, 4.331023},{34.527897, 8.366895, 2.241903}}],
    Polygon[{{34.527897, 0.000000, 0.000000},{34.527897, 3.750776, 2.165512},{
      34.527897, 3.062496, 3.062496},{34.527897, 0.000000, 0.000000},{
      34.527897, 0.000000, 0.000000}}],
    Polygon[{{34.527897, 3.750776, 2.165512},{34.527897, 7.501553, 4.331023},{
      34.527897, 6.124992, 6.124992},{34.527897, 3.062496, 3.062496},{
      34.527897, 3.750776, 2.165512}}],
    Polygon[{{34.527897, 7.501553, 4.331023},{
      34.527897, 11.252329, 6.496535},{34.527897, 9.187488, 9.187488},{
      34.527897, 6.124992, 6.124992},{34.527897, 7.501553, 4.331023}}],
    Polygon[{{34.527897, 0.000000, 0.000000},{34.527897, 3.062496, 3.062496},{
      34.527897, 2.165512, 3.750776},{34.527897, 0.000000, 0.000000},{
      34.527897, 0.000000, 0.000000}}],
    Polygon[{{34.527897, 3.062496, 3.062496},{34.527897, 6.124992, 6.124992},{
      34.527897, 4.331023, 7.501553},{34.527897, 2.165512, 3.750776},{
      34.527897, 3.062496, 3.062496}}],
    Polygon[{{34.527897, 6.124992, 6.124992},{34.527897, 9.187488, 9.187488},{
      34.527897, 6.496535, 11.252329},{34.527897, 4.331023, 7.501553},{
      34.527897, 6.124992, 6.124992}}],
    Polygon[{{34.527897, 0.000000, 0.000000},{34.527897, 2.165512, 3.750776},{
      34.527897, 1.120951, 4.183447},{34.527897, 0.000000, 0.000000},{
      34.527897, 0.000000, 0.000000}}],
    Polygon[{{34.527897, 2.165512, 3.750776},{34.527897, 4.331023, 7.501553},{
      34.527897, 2.241903, 8.366895},{34.527897, 1.120951, 4.183447},{
      34.527897, 2.165512, 3.750776}}],
    Polygon[{{34.527897, 4.331023, 7.501553},{
      34.527897, 6.496535, 11.252329},{34.527897, 3.362854, 12.550342},{
      34.527897, 2.241903, 8.366895},{34.527897, 4.331023, 7.501553}}],
    Polygon[{{34.527897, 0.000000, 0.000000},{34.527897, 1.120951, 4.183447},{
      34.527897, 0.000000, 4.331023},{34.527897, 0.000000, 0.000000},{
      34.527897, 0.000000, 0.000000}}],
    Polygon[{{34.527897, 1.120951, 4.183447},{34.527897, 2.241903, 8.366895},{
      34.527897, 0.000000, 8.662046},{34.527897, 0.000000, 4.331023},{
      34.527897, 1.120951, 4.183447}}],
    Polygon[{{34.527897, 2.241903, 8.366895},{
      34.527897, 3.362854, 12.550342},{34.527897, 0.000000, 12.993070},{
      34.527897, 0.000000, 8.662046},{34.527897, 2.241903, 8.366895}}],
    Polygon[{{34.527897, 0.000000, 0.000000},{34.527897, 0.000000, 4.331023},{
      34.527897, -1.120951, 4.183447},{34.527897, -0.000000, 0.000000},{
      34.527897, 0.000000, 0.000000}}],
    Polygon[{{34.527897, 0.000000, 4.331023},{34.527897, 0.000000, 8.662046},{
      34.527897, -2.241903, 8.366895},{34.527897, -1.120951, 4.183447},{
      34.527897, 0.000000, 4.331023}}],
    Polygon[{{34.527897, 0.000000, 8.662046},{
      34.527897, 0.000000, 12.993070},{34.527897, -3.362854, 12.550342},{
      34.527897, -2.241903, 8.366895},{34.527897, 0.000000, 8.662046}}],
    Polygon[{{34.527897, -0.000000, 0.000000},{
      34.527897, -1.120951, 4.183447},{34.527897, -2.165512, 3.750776},{
      34.527897, -0.000000, 0.000000},{34.527897, -0.000000, 0.000000}}],
    Polygon[{{34.527897, -1.120951, 4.183447},{
      34.527897, -2.241903, 8.366895},{34.527897, -4.331023, 7.501553},{
      34.527897, -2.165512, 3.750776},{34.527897, -1.120951, 4.183447}}],
    Polygon[{{34.527897, -2.241903, 8.366895},{
      34.527897, -3.362854, 12.550342},{34.527897, -6.496535, 11.252329},{
      34.527897, -4.331023, 7.501553},{34.527897, -2.241903, 8.366895}}],
    Polygon[{{34.527897, -0.000000, 0.000000},{
      34.527897, -2.165512, 3.750776},{34.527897, -3.062496, 3.062496},{
      34.527897, -0.000000, 0.000000},{34.527897, -0.000000, 0.000000}}],
    Polygon[{{34.527897, -2.165512, 3.750776},{
      34.527897, -4.331023, 7.501553},{34.527897, -6.124992, 6.124992},{
      34.527897, -3.062496, 3.062496},{34.527897, -2.165512, 3.750776}}],
    Polygon[{{34.527897, -4.331023, 7.501553},{
      34.527897, -6.496535, 11.252329},{34.527897, -9.187488, 9.187488},{
      34.527897, -6.124992, 6.124992},{34.527897, -4.331023, 7.501553}}],
    Polygon[{{34.527897, -0.000000, 0.000000},{
      34.527897, -3.062496, 3.062496},{34.527897, -3.750776, 2.165512},{
      34.527897, -0.000000, 0.000000},{34.527897, -0.000000, 0.000000}}],
    Polygon[{{34.527897, -3.062496, 3.062496},{
      34.527897, -6.124992, 6.124992},{34.527897, -7.501553, 4.331023},{
      34.527897, -3.750776, 2.165512},{34.527897, -3.062496, 3.062496}}],
    Polygon[{{34.527897, -6.124992, 6.124992},{
      34.527897, -9.187488, 9.187488},{34.527897, -11.252329, 6.496535},{
      34.527897, -7.501553, 4.331023},{34.527897, -6.124992, 6.124992}}],
    Polygon[{{34.527897, -0.000000, 0.000000},{
      34.527897, -3.750776, 2.165512},{34.527897, -4.183447, 1.120951},{
      34.527897, -0.000000, 0.000000},{34.527897, -0.000000, 0.000000}}],
    Polygon[{{34.527897, -3.750776, 2.165512},{
      34.527897, -7.501553, 4.331023},{34.527897, -8.366895, 2.241903},{
      34.527897, -4.183447, 1.120951},{34.527897, -3.750776, 2.165512}}],
    Polygon[{{34.527897, -7.501553, 4.331023},{
      34.527897, -11.252329, 6.496535},{34.527897, -12.550342, 3.362854},{
      34.527897, -8.366895, 2.241903},{34.527897, -7.501553, 4.331023}}],
    Polygon[{{34.527897, -0.000000, 0.000000},{
      34.527897, -4.183447, 1.120951},{34.527897, -4.331023, 0.000000},{
      34.527897, -0.000000, 0.000000},{34.527897, -0.000000, 0.000000}}],
    Polygon[{{34.527897, -4.183447, 1.120951},{
      34.527897, -8.366895, 2.241903},{34.527897, -8.662046, 0.000000},{
      34.527897, -4.331023, 0.000000},{34.527897, -4.183447, 1.120951}}],
    Polygon[{{34.527897, -8.366895, 2.241903},{
      34.527897, -12.550342, 3.362854},{34.527897, -12.993070, 0.000000},{
      34.527897, -8.662046, 0.000000},{34.527897, -8.366895, 2.241903}}],
    Polygon[{{34.527897, -0.000000, 0.000000},{
      34.527897, -4.331023, 0.000000},{34.527897, -4.183447, -1.120951},{
      34.527897, -0.000000, -0.000000},{34.527897, -0.000000, 0.000000}}],
    Polygon[{{34.527897, -4.331023, 0.000000},{
      34.527897, -8.662046, 0.000000},{34.527897, -8.366895, -2.241903},{
      34.527897, -4.183447, -1.120951},{34.527897, -4.331023, 0.000000}}],
    Polygon[{{34.527897, -8.662046, 0.000000},{
      34.527897, -12.993070, 0.000000},{34.527897, -12.550342, -3.362854},{
      34.527897, -8.366895, -2.241903},{34.527897, -8.662046, 0.000000}}],
    Polygon[{{34.527897, -0.000000, -0.000000},{
      34.527897, -4.183447, -1.120951},{34.527897, -3.750776, -2.165512},{
      34.527897, -0.000000, -0.000000},{34.527897, -0.000000, -0.000000}}],
    Polygon[{{34.527897, -4.183447, -1.120951},{
      34.527897, -8.366895, -2.241903},{34.527897, -7.501553, -4.331023},{
      34.527897, -3.750776, -2.165512},{34.527897, -4.183447, -1.120951}}],
    Polygon[{{34.527897, -8.366895, -2.241903},{
      34.527897, -12.550342, -3.362854},{34.527897, -11.252329, -6.496535},{
      34.527897, -7.501553, -4.331023},{34.527897, -8.366895, -2.241903}}],
    Polygon[{{34.527897, -0.000000, -0.000000},{
      34.527897, -3.750776, -2.165512},{34.527897, -3.062496, -3.062496},{
      34.527897, -0.000000, -0.000000},{34.527897, -0.000000, -0.000000}}],
    Polygon[{{34.527897, -3.750776, -2.165512},{
      34.527897, -7.501553, -4.331023},{34.527897, -6.124992, -6.124992},{
      34.527897, -3.062496, -3.062496},{34.527897, -3.750776, -2.165512}}],
    Polygon[{{34.527897, -7.501553, -4.331023},{
      34.527897, -11.252329, -6.496535},{34.527897, -9.187488, -9.187488},{
      34.527897, -6.124992, -6.124992},{34.527897, -7.501553, -4.331023}}],
    Polygon[{{34.527897, -0.000000, -0.000000},{
      34.527897, -3.062496, -3.062496},{34.527897, -2.165512, -3.750776},{
      34.527897, -0.000000, -0.000000},{34.527897, -0.000000, -0.000000}}],
    Polygon[{{34.527897, -3.062496, -3.062496},{
      34.527897, -6.124992, -6.124992},{34.527897, -4.331023, -7.501553},{
      34.527897, -2.165512, -3.750776},{34.527897, -3.062496, -3.062496}}],
    Polygon[{{34.527897, -6.124992, -6.124992},{
      34.527897, -9.187488, -9.187488},{34.527897, -6.496535, -11.252329},{
      34.527897, -4.331023, -7.501553},{34.527897, -6.124992, -6.124992}}],
    Polygon[{{34.527897, -0.000000, -0.000000},{
      34.527897, -2.165512, -3.750776},{34.527897, -1.120951, -4.183447},{
      34.527897, -0.000000, -0.000000},{34.527897, -0.000000, -0.000000}}],
    Polygon[{{34.527897, -2.165512, -3.750776},{
      34.527897, -4.331023, -7.501553},{34.527897, -2.241903, -8.366895},{
      34.527897, -1.120951, -4.183447},{34.527897, -2.165512, -3.750776}}],
    Polygon[{{34.527897, -4.331023, -7.501553},{
      34.527897, -6.496535, -11.252329},{34.527897, -3.362854, -12.550342},{
      34.527897, -2.241903, -8.366895},{34.527897, -4.331023, -7.501553}}],
    Polygon[{{34.527897, -0.000000, -0.000000},{
      34.527897, -1.120951, -4.183447},{34.527897, -0.000000, -4.331023},{
      34.527897, -0.000000, -0.000000},{34.527897, -0.000000, -0.000000}}],
    Polygon[{{34.527897, -1.120951, -4.183447},{
      34.527897, -2.241903, -8.366895},{34.527897, -0.000000, -8.662046},{
      34.527897, -0.000000, -4.331023},{34.527897, -1.120951, -4.183447}}],
    Polygon[{{34.527897, -2.241903, -8.366895},{
      34.527897, -3.362854, -12.550342},{34.527897, -0.000000, -12.993070},{
      34.527897, -0.000000, -8.662046},{34.527897, -2.241903, -8.366895}}],
    Polygon[{{34.527897, -0.000000, -0.000000},{
      34.527897, -0.000000, -4.331023},{34.527897, 1.120951, -4.183447},{
      34.527897, 0.000000, -0.000000},{34.527897, -0.000000, -0.000000}}],
    Polygon[{{34.527897, -0.000000, -4.331023},{
      34.527897, -0.000000, -8.662046},{34.527897, 2.241903, -8.366895},{
      34.527897, 1.120951, -4.183447},{34.527897, -0.000000, -4.331023}}],
    Polygon[{{34.527897, -0.000000, -8.662046},{
      34.527897, -0.000000, -12.993070},{34.527897, 3.362854, -12.550342},{
      34.527897, 2.241903, -8.366895},{34.527897, -0.000000, -8.662046}}],
    Polygon[{{34.527897, 0.000000, -0.000000},{
      34.527897, 1.120951, -4.183447},{34.527897, 2.165512, -3.750776},{
      34.527897, 0.000000, -0.000000},{34.527897, 0.000000, -0.000000}}],
    Polygon[{{34.527897, 1.120951, -4.183447},{
      34.527897, 2.241903, -8.366895},{34.527897, 4.331023, -7.501553},{
      34.527897, 2.165512, -3.750776},{34.527897, 1.120951, -4.183447}}],
    Polygon[{{34.527897, 2.241903, -8.366895},{
      34.527897, 3.362854, -12.550342},{34.527897, 6.496535, -11.252329},{
      34.527897, 4.331023, -7.501553},{34.527897, 2.241903, -8.366895}}],
    Polygon[{{34.527897, 0.000000, -0.000000},{
      34.527897, 2.165512, -3.750776},{34.527897, 3.062496, -3.062496},{
      34.527897, 0.000000, -0.000000},{34.527897, 0.000000, -0.000000}}],
    Polygon[{{34.527897, 2.165512, -3.750776},{
      34.527897, 4.331023, -7.501553},{34.527897, 6.124992, -6.124992},{
      34.527897, 3.062496, -3.062496},{34.527897, 2.165512, -3.750776}}],
    Polygon[{{34.527897, 4.331023, -7.501553},{
      34.527897, 6.496535, -11.252329},{34.527897, 9.187488, -9.187488},{
      34.527897, 6.124992, -6.124992},{34.527897, 4.331023, -7.501553}}],
    Polygon[{{34.527897, 0.000000, -0.000000},{
      34.527897, 3.062496, -3.062496},{34.527897, 3.750776, -2.165512},{
      34.527897, 0.000000, -0.000000},{34.527897, 0.000000, -0.000000}}],
    Polygon[{{34.527897, 3.062496, -3.062496},{
      34.527897, 6.124992, -6.124992},{34.527897, 7.501553, -4.331023},{
      34.527897, 3.750776, -2.165512},{34.527897, 3.062496, -3.062496}}],
    Polygon[{{34.527897, 6.124992, -6.124992},{
      34.527897, 9.187488, -9.187488},{34.527897, 11.252329, -6.496535},{
      34.527897, 7.501553, -4.331023},{34.527897, 6.124992, -6.124992}}],
    Polygon[{{34.527897, 0.000000, -0.000000},{
      34.527897, 3.750776, -2.165512},{34.527897, 4.183447, -1.120951},{
      34.527897, 0.000000, -0.000000},{34.527897, 0.000000, -0.000000}}],
    Polygon[{{34.527897, 3.750776, -2.165512},{
      34.527897, 7.501553, -4.331023},{34.527897, 8.366895, -2.241903},{
      34.527897, 4.183447, -1.120951},{34.527897, 3.750776, -2.165512}}],
    Polygon[{{34.527897, 7.501553, -4.331023},{
      34.527897, 11.252329, -6.496535},{34.527897, 12.550342, -3.362854},{
      34.527897, 8.366895, -2.241903},{34.527897, 7.501553, -4.331023}}],
    Polygon[{{34.527897, 0.000000, -0.000000},{
      34.527897, 4.183447, -1.120951},{34.527897, 4.331023, -0.000000},{
      34.527897, 0.000000, -0.000000},{34.527897, 0.000000, -0.000000}}],
    Polygon[{{34.527897, 4.183447, -1.120951},{
      34.527897, 8.366895, -2.241903},{34.527897, 8.662046, -0.000000},{
      34.527897, 4.331023, -0.000000},{34.527897, 4.183447, -1.120951}}],
    Polygon[{{34.527897, 8.366895, -2.241903},{
      34.527897, 12.550342, -3.362854},{34.527897, 12.993070, -0.000000},{
      34.527897, 8.662046, -0.000000},{34.527897, 8.366895, -2.241903}}],
    Line[{{34.527897, 12.993070, 0.000000},{34.527897, 12.550342, 3.362854},{
      34.527897, 11.252329, 6.496535},{34.527897, 9.187488, 9.187488},{
      34.527897, 6.496535, 11.252329},{34.527897, 3.362854, 12.550342},{
      34.527897, 0.000000, 12.993070},{34.527897, -3.362854, 12.550342},{
      34.527897, -6.496535, 11.252329},{34.527897, -9.187488, 9.187488},{
      34.527897, -11.252329, 6.496535},{34.527897, -12.550342, 3.362854},{
      34.527897, -12.993070, 0.000000},{34.527897, -12.550342, -3.362854},{
      34.527897, -11.252329, -6.496535},{34.527897, -9.187488, -9.187488},{
      34.527897, -6.496535, -11.252329},{34.527897, -3.362854, -12.550342},{
      34.527897, -0.000000, -12.993070},{34.527897, 3.362854, -12.550342},{
      34.527897, 6.496535, -11.252329},{34.527897, 9.187488, -9.187488},{
      34.527897, 11.252329, -6.496535},{34.527897, 12.550342, -3.362854},{
      34.527897, 12.993070, -0.000000}}],
    Polygon[{{36.582748, 0.000000, 0.000000},{37.041870, 3.580819, 0.000000},{
      37.041870, 3.458806, 0.926784},{36.582748, 0.000000, 0.000000},{
      36.582748, 0.000000, 0.000000}}],
    Polygon[{{37.041870, 3.580819, 0.000000},{38.522011, 7.161639, 0.000000},{
      38.522011, 6.917612, 1.853568},{37.041870, 3.458806, 0.926784},{
      37.041870, 3.580819, 0.000000}}],
    Polygon[{{38.522011, 7.161639, 0.000000},{
      41.499660, 10.742458, 0.000000},{41.499660, 10.376417, 2.780353},{
      38.522011, 6.917612, 1.853568},{38.522011, 7.161639, 0.000000}}],
    Polygon[{{36.582748, 0.000000, 0.000000},{37.041870, 3.458806, 0.926784},{
      37.041870, 3.101080, 1.790410},{36.582748, 0.000000, 0.000000},{
      36.582748, 0.000000, 0.000000}}],
    Polygon[{{37.041870, 3.458806, 0.926784},{38.522011, 6.917612, 1.853568},{
      38.522011, 6.202161, 3.580819},{37.041870, 3.101080, 1.790410},{
      37.041870, 3.458806, 0.926784}}],
    Polygon[{{38.522011, 6.917612, 1.853568},{
      41.499660, 10.376417, 2.780353},{41.499660, 9.303242, 5.371229},{
      38.522011, 6.202161, 3.580819},{38.522011, 6.917612, 1.853568}}],
    Polygon[{{36.582748, 0.000000, 0.000000},{37.041870, 3.101080, 1.790410},{
      37.041870, 2.532022, 2.532022},{36.582748, 0.000000, 0.000000},{
      36.582748, 0.000000, 0.000000}}],
    Polygon[{{37.041870, 3.101080, 1.790410},{38.522011, 6.202161, 3.580819},{
      38.522011, 5.064043, 5.064043},{37.041870, 2.532022, 2.532022},{
      37.041870, 3.101080, 1.790410}}],
    Polygon[{{38.522011, 6.202161, 3.580819},{41.499660, 9.303242, 5.371229},{
      41.499660, 7.596065, 7.596065},{38.522011, 5.064043, 5.064043},{
      38.522011, 6.202161, 3.580819}}],
    Polygon[{{36.582748, 0.000000, 0.000000},{37.041870, 2.532022, 2.532022},{
      37.041870, 1.790410, 3.101080},{36.582748, 0.000000, 0.000000},{
      36.582748, 0.000000, 0.000000}}],
    Polygon[{{37.041870, 2.532022, 2.532022},{38.522011, 5.064043, 5.064043},{
      38.522011, 3.580819, 6.202161},{37.041870, 1.790410, 3.101080},{
      37.041870, 2.532022, 2.532022}}],
    Polygon[{{38.522011, 5.064043, 5.064043},{41.499660, 7.596065, 7.596065},{
      41.499660, 5.371229, 9.303242},{38.522011, 3.580819, 6.202161},{
      38.522011, 5.064043, 5.064043}}],
    Polygon[{{36.582748, 0.000000, 0.000000},{37.041870, 1.790410, 3.101080},{
      37.041870, 0.926784, 3.458806},{36.582748, 0.000000, 0.000000},{
      36.582748, 0.000000, 0.000000}}],
    Polygon[{{37.041870, 1.790410, 3.101080},{38.522011, 3.580819, 6.202161},{
      38.522011, 1.853568, 6.917612},{37.041870, 0.926784, 3.458806},{
      37.041870, 1.790410, 3.101080}}],
    Polygon[{{38.522011, 3.580819, 6.202161},{41.499660, 5.371229, 9.303242},{
      41.499660, 2.780353, 10.376417},{38.522011, 1.853568, 6.917612},{
      38.522011, 3.580819, 6.202161}}],
    Polygon[{{36.582748, 0.000000, 0.000000},{37.041870, 0.926784, 3.458806},{
      37.041870, 0.000000, 3.580819},{36.582748, 0.000000, 0.000000},{
      36.582748, 0.000000, 0.000000}}],
    Polygon[{{37.041870, 0.926784, 3.458806},{38.522011, 1.853568, 6.917612},{
      38.522011, 0.000000, 7.161639},{37.041870, 0.000000, 3.580819},{
      37.041870, 0.926784, 3.458806}}],
    Polygon[{{38.522011, 1.853568, 6.917612},{
      41.499660, 2.780353, 10.376417},{41.499660, 0.000000, 10.742458},{
      38.522011, 0.000000, 7.161639},{38.522011, 1.853568, 6.917612}}],
    Polygon[{{36.582748, 0.000000, 0.000000},{37.041870, 0.000000, 3.580819},{
      37.041870, -0.926784, 3.458806},{36.582748, -0.000000, 0.000000},{
      36.582748, 0.000000, 0.000000}}],
    Polygon[{{37.041870, 0.000000, 3.580819},{38.522011, 0.000000, 7.161639},{
      38.522011, -1.853568, 6.917612},{37.041870, -0.926784, 3.458806},{
      37.041870, 0.000000, 3.580819}}],
    Polygon[{{38.522011, 0.000000, 7.161639},{
      41.499660, 0.000000, 10.742458},{41.499660, -2.780353, 10.376417},{
      38.522011, -1.853568, 6.917612},{38.522011, 0.000000, 7.161639}}],
    Polygon[{{36.582748, -0.000000, 0.000000},{
      37.041870, -0.926784, 3.458806},{37.041870, -1.790410, 3.101080},{
      36.582748, -0.000000, 0.000000},{36.582748, -0.000000, 0.000000}}],
    Polygon[{{37.041870, -0.926784, 3.458806},{
      38.522011, -1.853568, 6.917612},{38.522011, -3.580819, 6.202161},{
      37.041870, -1.790410, 3.101080},{37.041870, -0.926784, 3.458806}}],
    Polygon[{{38.522011, -1.853568, 6.917612},{
      41.499660, -2.780353, 10.376417},{41.499660, -5.371229, 9.303242},{
      38.522011, -3.580819, 6.202161},{38.522011, -1.853568, 6.917612}}],
    Polygon[{{36.582748, -0.000000, 0.000000},{
      37.041870, -1.790410, 3.101080},{37.041870, -2.532022, 2.532022},{
      36.582748, -0.000000, 0.000000},{36.582748, -0.000000, 0.000000}}],
    Polygon[{{37.041870, -1.790410, 3.101080},{
      38.522011, -3.580819, 6.202161},{38.522011, -5.064043, 5.064043},{
      37.041870, -2.532022, 2.532022},{37.041870, -1.790410, 3.101080}}],
    Polygon[{{38.522011, -3.580819, 6.202161},{
      41.499660, -5.371229, 9.303242},{41.499660, -7.596065, 7.596065},{
      38.522011, -5.064043, 5.064043},{38.522011, -3.580819, 6.202161}}],
    Polygon[{{36.582748, -0.000000, 0.000000},{
      37.041870, -2.532022, 2.532022},{37.041870, -3.101080, 1.790410},{
      36.582748, -0.000000, 0.000000},{36.582748, -0.000000, 0.000000}}],
    Polygon[{{37.041870, -2.532022, 2.532022},{
      38.522011, -5.064043, 5.064043},{38.522011, -6.202161, 3.580819},{
      37.041870, -3.101080, 1.790410},{37.041870, -2.532022, 2.532022}}],
    Polygon[{{38.522011, -5.064043, 5.064043},{
      41.499660, -7.596065, 7.596065},{41.499660, -9.303242, 5.371229},{
      38.522011, -6.202161, 3.580819},{38.522011, -5.064043, 5.064043}}],
    Polygon[{{36.582748, -0.000000, 0.000000},{
      37.041870, -3.101080, 1.790410},{37.041870, -3.458806, 0.926784},{
      36.582748, -0.000000, 0.000000},{36.582748, -0.000000, 0.000000}}],
    Polygon[{{37.041870, -3.101080, 1.790410},{
      38.522011, -6.202161, 3.580819},{38.522011, -6.917612, 1.853568},{
      37.041870, -3.458806, 0.926784},{37.041870, -3.101080, 1.790410}}],
    Polygon[{{38.522011, -6.202161, 3.580819},{
      41.499660, -9.303242, 5.371229},{41.499660, -10.376417, 2.780353},{
      38.522011, -6.917612, 1.853568},{38.522011, -6.202161, 3.580819}}],
    Polygon[{{36.582748, -0.000000, 0.000000},{
      37.041870, -3.458806, 0.926784},{37.041870, -3.580819, 0.000000},{
      36.582748, -0.000000, 0.000000},{36.582748, -0.000000, 0.000000}}],
    Polygon[{{37.041870, -3.458806, 0.926784},{
      38.522011, -6.917612, 1.853568},{38.522011, -7.161639, 0.000000},{
      37.041870, -3.580819, 0.000000},{37.041870, -3.458806, 0.926784}}],
    Polygon[{{38.522011, -6.917612, 1.853568},{
      41.499660, -10.376417, 2.780353},{41.499660, -10.742458, 0.000000},{
      38.522011, -7.161639, 0.000000},{38.522011, -6.917612, 1.853568}}],
    Polygon[{{36.582748, -0.000000, 0.000000},{
      37.041870, -3.580819, 0.000000},{37.041870, -3.458806, -0.926784},{
      36.582748, -0.000000, -0.000000},{36.582748, -0.000000, 0.000000}}],
    Polygon[{{37.041870, -3.580819, 0.000000},{
      38.522011, -7.161639, 0.000000},{38.522011, -6.917612, -1.853568},{
      37.041870, -3.458806, -0.926784},{37.041870, -3.580819, 0.000000}}],
    Polygon[{{38.522011, -7.161639, 0.000000},{
      41.499660, -10.742458, 0.000000},{41.499660, -10.376417, -2.780353},{
      38.522011, -6.917612, -1.853568},{38.522011, -7.161639, 0.000000}}],
    Polygon[{{36.582748, -0.000000, -0.000000},{
      37.041870, -3.458806, -0.926784},{37.041870, -3.101080, -1.790410},{
      36.582748, -0.000000, -0.000000},{36.582748, -0.000000, -0.000000}}],
    Polygon[{{37.041870, -3.458806, -0.926784},{
      38.522011, -6.917612, -1.853568},{38.522011, -6.202161, -3.580819},{
      37.041870, -3.101080, -1.790410},{37.041870, -3.458806, -0.926784}}],
    Polygon[{{38.522011, -6.917612, -1.853568},{
      41.499660, -10.376417, -2.780353},{41.499660, -9.303242, -5.371229},{
      38.522011, -6.202161, -3.580819},{38.522011, -6.917612, -1.853568}}],
    Polygon[{{36.582748, -0.000000, -0.000000},{
      37.041870, -3.101080, -1.790410},{37.041870, -2.532022, -2.532022},{
      36.582748, -0.000000, -0.000000},{36.582748, -0.000000, -0.000000}}],
    Polygon[{{37.041870, -3.101080, -1.790410},{
      38.522011, -6.202161, -3.580819},{38.522011, -5.064043, -5.064043},{
      37.041870, -2.532022, -2.532022},{37.041870, -3.101080, -1.790410}}],
    Polygon[{{38.522011, -6.202161, -3.580819},{
      41.499660, -9.303242, -5.371229},{41.499660, -7.596065, -7.596065},{
      38.522011, -5.064043, -5.064043},{38.522011, -6.202161, -3.580819}}],
    Polygon[{{36.582748, -0.000000, -0.000000},{
      37.041870, -2.532022, -2.532022},{37.041870, -1.790410, -3.101080},{
      36.582748, -0.000000, -0.000000},{36.582748, -0.000000, -0.000000}}],
    Polygon[{{37.041870, -2.532022, -2.532022},{
      38.522011, -5.064043, -5.064043},{38.522011, -3.580819, -6.202161},{
      37.041870, -1.790410, -3.101080},{37.041870, -2.532022, -2.532022}}],
    Polygon[{{38.522011, -5.064043, -5.064043},{
      41.499660, -7.596065, -7.596065},{41.499660, -5.371229, -9.303242},{
      38.522011, -3.580819, -6.202161},{38.522011, -5.064043, -5.064043}}],
    Polygon[{{36.582748, -0.000000, -0.000000},{
      37.041870, -1.790410, -3.101080},{37.041870, -0.926784, -3.458806},{
      36.582748, -0.000000, -0.000000},{36.582748, -0.000000, -0.000000}}],
    Polygon[{{37.041870, -1.790410, -3.101080},{
      38.522011, -3.580819, -6.202161},{38.522011, -1.853568, -6.917612},{
      37.041870, -0.926784, -3.458806},{37.041870, -1.790410, -3.101080}}],
    Polygon[{{38.522011, -3.580819, -6.202161},{
      41.499660, -5.371229, -9.303242},{41.499660, -2.780353, -10.376417},{
      38.522011, -1.853568, -6.917612},{38.522011, -3.580819, -6.202161}}],
    Polygon[{{36.582748, -0.000000, -0.000000},{
      37.041870, -0.926784, -3.458806},{37.041870, -0.000000, -3.580819},{
      36.582748, -0.000000, -0.000000},{36.582748, -0.000000, -0.000000}}],
    Polygon[{{37.041870, -0.926784, -3.458806},{
      38.522011, -1.853568, -6.917612},{38.522011, -0.000000, -7.161639},{
      37.041870, -0.000000, -3.580819},{37.041870, -0.926784, -3.458806}}],
    Polygon[{{38.522011, -1.853568, -6.917612},{
      41.499660, -2.780353, -10.376417},{41.499660, -0.000000, -10.742458},{
      38.522011, -0.000000, -7.161639},{38.522011, -1.853568, -6.917612}}],
    Polygon[{{36.582748, -0.000000, -0.000000},{
      37.041870, -0.000000, -3.580819},{37.041870, 0.926784, -3.458806},{
      36.582748, 0.000000, -0.000000},{36.582748, -0.000000, -0.000000}}],
    Polygon[{{37.041870, -0.000000, -3.580819},{
      38.522011, -0.000000, -7.161639},{38.522011, 1.853568, -6.917612},{
      37.041870, 0.926784, -3.458806},{37.041870, -0.000000, -3.580819}}],
    Polygon[{{38.522011, -0.000000, -7.161639},{
      41.499660, -0.000000, -10.742458},{41.499660, 2.780353, -10.376417},{
      38.522011, 1.853568, -6.917612},{38.522011, -0.000000, -7.161639}}],
    Polygon[{{36.582748, 0.000000, -0.000000},{
      37.041870, 0.926784, -3.458806},{37.041870, 1.790410, -3.101080},{
      36.582748, 0.000000, -0.000000},{36.582748, 0.000000, -0.000000}}],
    Polygon[{{37.041870, 0.926784, -3.458806},{
      38.522011, 1.853568, -6.917612},{38.522011, 3.580819, -6.202161},{
      37.041870, 1.790410, -3.101080},{37.041870, 0.926784, -3.458806}}],
    Polygon[{{38.522011, 1.853568, -6.917612},{
      41.499660, 2.780353, -10.376417},{41.499660, 5.371229, -9.303242},{
      38.522011, 3.580819, -6.202161},{38.522011, 1.853568, -6.917612}}],
    Polygon[{{36.582748, 0.000000, -0.000000},{
      37.041870, 1.790410, -3.101080},{37.041870, 2.532022, -2.532022},{
      36.582748, 0.000000, -0.000000},{36.582748, 0.000000, -0.000000}}],
    Polygon[{{37.041870, 1.790410, -3.101080},{
      38.522011, 3.580819, -6.202161},{38.522011, 5.064043, -5.064043},{
      37.041870, 2.532022, -2.532022},{37.041870, 1.790410, -3.101080}}],
    Polygon[{{38.522011, 3.580819, -6.202161},{
      41.499660, 5.371229, -9.303242},{41.499660, 7.596065, -7.596065},{
      38.522011, 5.064043, -5.064043},{38.522011, 3.580819, -6.202161}}],
    Polygon[{{36.582748, 0.000000, -0.000000},{
      37.041870, 2.532022, -2.532022},{37.041870, 3.101080, -1.790410},{
      36.582748, 0.000000, -0.000000},{36.582748, 0.000000, -0.000000}}],
    Polygon[{{37.041870, 2.532022, -2.532022},{
      38.522011, 5.064043, -5.064043},{38.522011, 6.202161, -3.580819},{
      37.041870, 3.101080, -1.790410},{37.041870, 2.532022, -2.532022}}],
    Polygon[{{38.522011, 5.064043, -5.064043},{
      41.499660, 7.596065, -7.596065},{41.499660, 9.303242, -5.371229},{
      38.522011, 6.202161, -3.580819},{38.522011, 5.064043, -5.064043}}],
    Polygon[{{36.582748, 0.000000, -0.000000},{
      37.041870, 3.101080, -1.790410},{37.041870, 3.458806, -0.926784},{
      36.582748, 0.000000, -0.000000},{36.582748, 0.000000, -0.000000}}],
    Polygon[{{37.041870, 3.101080, -1.790410},{
      38.522011, 6.202161, -3.580819},{38.522011, 6.917612, -1.853568},{
      37.041870, 3.458806, -0.926784},{37.041870, 3.101080, -1.790410}}],
    Polygon[{{38.522011, 6.202161, -3.580819},{
      41.499660, 9.303242, -5.371229},{41.499660, 10.376417, -2.780353},{
      38.522011, 6.917612, -1.853568},{38.522011, 6.202161, -3.580819}}],
    Polygon[{{36.582748, 0.000000, -0.000000},{
      37.041870, 3.458806, -0.926784},{37.041870, 3.580819, -0.000000},{
      36.582748, 0.000000, -0.000000},{36.582748, 0.000000, -0.000000}}],
    Polygon[{{37.041870, 3.458806, -0.926784},{
      38.522011, 6.917612, -1.853568},{38.522011, 7.161639, -0.000000},{
      37.041870, 3.580819, -0.000000},{37.041870, 3.458806, -0.926784}}],
    Polygon[{{38.522011, 6.917612, -1.853568},{
      41.499660, 10.376417, -2.780353},{41.499660, 10.742458, -0.000000},{
      38.522011, 7.161639, -0.000000},{38.522011, 6.917612, -1.853568}}],
    Line[{{41.499660, 10.742458, 0.000000},{41.499660, 10.376417, 2.780353},{
      41.499660, 9.303242, 5.371229},{41.499660, 7.596065, 7.596065},{
      41.499660, 5.371229, 9.303242},{41.499660, 2.780353, 10.376417},{
      41.499660, 0.000000, 10.742458},{41.499660, -2.780353, 10.376417},{
      41.499660, -5.371229, 9.303242},{41.499660, -7.596065, 7.596065},{
      41.499660, -9.303242, 5.371229},{41.499660, -10.376417, 2.780353},{
      41.499660, -10.742458, 0.000000},{41.499660, -10.376417, -2.780353},{
      41.499660, -9.303242, -5.371229},{41.499660, -7.596065, -7.596065},{
      41.499660, -5.371229, -9.303242},{41.499660, -2.780353, -10.376417},{
      41.499660, -0.000000, -10.742458},{41.499660, 2.780353, -10.376417},{
      41.499660, 5.371229, -9.303242},{41.499660, 7.596065, -7.596065},{
      41.499660, 9.303242, -5.371229},{41.499660, 10.376417, -2.780353},{
      41.499660, 10.742458, -0.000000}}],
    Polygon[{{41.935383, 0.000000, 0.000000},{41.935383, 3.562915, 0.000000},{
      41.935383, 3.441512, 0.922150},{41.935383, 0.000000, 0.000000},{
      41.935383, 0.000000, 0.000000}}],
    Polygon[{{41.935383, 3.562915, 0.000000},{41.935383, 7.125831, 0.000000},{
      41.935383, 6.883024, 1.844301},{41.935383, 3.441512, 0.922150},{
      41.935383, 3.562915, 0.000000}}],
    Polygon[{{41.935383, 7.125831, 0.000000},{
      41.935383, 10.688745, 0.000000},{41.935383, 10.324535, 2.766451},{
      41.935383, 6.883024, 1.844301},{41.935383, 7.125831, 0.000000}}],
    Polygon[{{41.935383, 0.000000, 0.000000},{41.935383, 3.441512, 0.922150},{
      41.935383, 3.085575, 1.781458},{41.935383, 0.000000, 0.000000},{
      41.935383, 0.000000, 0.000000}}],
    Polygon[{{41.935383, 3.441512, 0.922150},{41.935383, 6.883024, 1.844301},{
      41.935383, 6.171150, 3.562915},{41.935383, 3.085575, 1.781458},{
      41.935383, 3.441512, 0.922150}}],
    Polygon[{{41.935383, 6.883024, 1.844301},{
      41.935383, 10.324535, 2.766451},{41.935383, 9.256725, 5.344373},{
      41.935383, 6.171150, 3.562915},{41.935383, 6.883024, 1.844301}}],
    Polygon[{{41.935383, 0.000000, 0.000000},{41.935383, 3.085575, 1.781458},{
      41.935383, 2.519361, 2.519361},{41.935383, 0.000000, 0.000000},{
      41.935383, 0.000000, 0.000000}}],
    Polygon[{{41.935383, 3.085575, 1.781458},{41.935383, 6.171150, 3.562915},{
      41.935383, 5.038723, 5.038723},{41.935383, 2.519361, 2.519361},{
      41.935383, 3.085575, 1.781458}}],
    Polygon[{{41.935383, 6.171150, 3.562915},{41.935383, 9.256725, 5.344373},{
      41.935383, 7.558084, 7.558084},{41.935383, 5.038723, 5.038723},{
      41.935383, 6.171150, 3.562915}}],
    Polygon[{{41.935383, 0.000000, 0.000000},{41.935383, 2.519361, 2.519361},{
      41.935383, 1.781458, 3.085575},{41.935383, 0.000000, 0.000000},{
      41.935383, 0.000000, 0.000000}}],
    Polygon[{{41.935383, 2.519361, 2.519361},{41.935383, 5.038723, 5.038723},{
      41.935383, 3.562915, 6.171150},{41.935383, 1.781458, 3.085575},{
      41.935383, 2.519361, 2.519361}}],
    Polygon[{{41.935383, 5.038723, 5.038723},{41.935383, 7.558084, 7.558084},{
      41.935383, 5.344373, 9.256725},{41.935383, 3.562915, 6.171150},{
      41.935383, 5.038723, 5.038723}}],
    Polygon[{{41.935383, 0.000000, 0.000000},{41.935383, 1.781458, 3.085575},{
      41.935383, 0.922150, 3.441512},{41.935383, 0.000000, 0.000000},{
      41.935383, 0.000000, 0.000000}}],
    Polygon[{{41.935383, 1.781458, 3.085575},{41.935383, 3.562915, 6.171150},{
      41.935383, 1.844301, 6.883024},{41.935383, 0.922150, 3.441512},{
      41.935383, 1.781458, 3.085575}}],
    Polygon[{{41.935383, 3.562915, 6.171150},{41.935383, 5.344373, 9.256725},{
      41.935383, 2.766451, 10.324535},{41.935383, 1.844301, 6.883024},{
      41.935383, 3.562915, 6.171150}}],
    Polygon[{{41.935383, 0.000000, 0.000000},{41.935383, 0.922150, 3.441512},{
      41.935383, 0.000000, 3.562915},{41.935383, 0.000000, 0.000000},{
      41.935383, 0.000000, 0.000000}}],
    Polygon[{{41.935383, 0.922150, 3.441512},{41.935383, 1.844301, 6.883024},{
      41.935383, 0.000000, 7.125831},{41.935383, 0.000000, 3.562915},{
      41.935383, 0.922150, 3.441512}}],
    Polygon[{{41.935383, 1.844301, 6.883024},{
      41.935383, 2.766451, 10.324535},{41.935383, 0.000000, 10.688745},{
      41.935383, 0.000000, 7.125831},{41.935383, 1.844301, 6.883024}}],
    Polygon[{{41.935383, 0.000000, 0.000000},{41.935383, 0.000000, 3.562915},{
      41.935383, -0.922150, 3.441512},{41.935383, -0.000000, 0.000000},{
      41.935383, 0.000000, 0.000000}}],
    Polygon[{{41.935383, 0.000000, 3.562915},{41.935383, 0.000000, 7.125831},{
      41.935383, -1.844301, 6.883024},{41.935383, -0.922150, 3.441512},{
      41.935383, 0.000000, 3.562915}}],
    Polygon[{{41.935383, 0.000000, 7.125831},{
      41.935383, 0.000000, 10.688745},{41.935383, -2.766451, 10.324535},{
      41.935383, -1.844301, 6.883024},{41.935383, 0.000000, 7.125831}}],
    Polygon[{{41.935383, -0.000000, 0.000000},{
      41.935383, -0.922150, 3.441512},{41.935383, -1.781458, 3.085575},{
      41.935383, -0.000000, 0.000000},{41.935383, -0.000000, 0.000000}}],
    Polygon[{{41.935383, -0.922150, 3.441512},{
      41.935383, -1.844301, 6.883024},{41.935383, -3.562915, 6.171150},{
      41.935383, -1.781458, 3.085575},{41.935383, -0.922150, 3.441512}}],
    Polygon[{{41.935383, -1.844301, 6.883024},{
      41.935383, -2.766451, 10.324535},{41.935383, -5.344373, 9.256725},{
      41.935383, -3.562915, 6.171150},{41.935383, -1.844301, 6.883024}}],
    Polygon[{{41.935383, -0.000000, 0.000000},{
      41.935383, -1.781458, 3.085575},{41.935383, -2.519361, 2.519361},{
      41.935383, -0.000000, 0.000000},{41.935383, -0.000000, 0.000000}}],
    Polygon[{{41.935383, -1.781458, 3.085575},{
      41.935383, -3.562915, 6.171150},{41.935383, -5.038723, 5.038723},{
      41.935383, -2.519361, 2.519361},{41.935383, -1.781458, 3.085575}}],
    Polygon[{{41.935383, -3.562915, 6.171150},{
      41.935383, -5.344373, 9.256725},{41.935383, -7.558084, 7.558084},{
      41.935383, -5.038723, 5.038723},{41.935383, -3.562915, 6.171150}}],
    Polygon[{{41.935383, -0.000000, 0.000000},{
      41.935383, -2.519361, 2.519361},{41.935383, -3.085575, 1.781458},{
      41.935383, -0.000000, 0.000000},{41.935383, -0.000000, 0.000000}}],
    Polygon[{{41.935383, -2.519361, 2.519361},{
      41.935383, -5.038723, 5.038723},{41.935383, -6.171150, 3.562915},{
      41.935383, -3.085575, 1.781458},{41.935383, -2.519361, 2.519361}}],
    Polygon[{{41.935383, -5.038723, 5.038723},{
      41.935383, -7.558084, 7.558084},{41.935383, -9.256725, 5.344373},{
      41.935383, -6.171150, 3.562915},{41.935383, -5.038723, 5.038723}}],
    Polygon[{{41.935383, -0.000000, 0.000000},{
      41.935383, -3.085575, 1.781458},{41.935383, -3.441512, 0.922150},{
      41.935383, -0.000000, 0.000000},{41.935383, -0.000000, 0.000000}}],
    Polygon[{{41.935383, -3.085575, 1.781458},{
      41.935383, -6.171150, 3.562915},{41.935383, -6.883024, 1.844301},{
      41.935383, -3.441512, 0.922150},{41.935383, -3.085575, 1.781458}}],
    Polygon[{{41.935383, -6.171150, 3.562915},{
      41.935383, -9.256725, 5.344373},{41.935383, -10.324535, 2.766451},{
      41.935383, -6.883024, 1.844301},{41.935383, -6.171150, 3.562915}}],
    Polygon[{{41.935383, -0.000000, 0.000000},{
      41.935383, -3.441512, 0.922150},{41.935383, -3.562915, 0.000000},{
      41.935383, -0.000000, 0.000000},{41.935383, -0.000000, 0.000000}}],
    Polygon[{{41.935383, -3.441512, 0.922150},{
      41.935383, -6.883024, 1.844301},{41.935383, -7.125831, 0.000000},{
      41.935383, -3.562915, 0.000000},{41.935383, -3.441512, 0.922150}}],
    Polygon[{{41.935383, -6.883024, 1.844301},{
      41.935383, -10.324535, 2.766451},{41.935383, -10.688745, 0.000000},{
      41.935383, -7.125831, 0.000000},{41.935383, -6.883024, 1.844301}}],
    Polygon[{{41.935383, -0.000000, 0.000000},{
      41.935383, -3.562915, 0.000000},{41.935383, -3.441512, -0.922150},{
      41.935383, -0.000000, -0.000000},{41.935383, -0.000000, 0.000000}}],
    Polygon[{{41.935383, -3.562915, 0.000000},{
      41.935383, -7.125831, 0.000000},{41.935383, -6.883024, -1.844301},{
      41.935383, -3.441512, -0.922150},{41.935383, -3.562915, 0.000000}}],
    Polygon[{{41.935383, -7.125831, 0.000000},{
      41.935383, -10.688745, 0.000000},{41.935383, -10.324535, -2.766451},{
      41.935383, -6.883024, -1.844301},{41.935383, -7.125831, 0.000000}}],
    Polygon[{{41.935383, -0.000000, -0.000000},{
      41.935383, -3.441512, -0.922150},{41.935383, -3.085575, -1.781458},{
      41.935383, -0.000000, -0.000000},{41.935383, -0.000000, -0.000000}}],
    Polygon[{{41.935383, -3.441512, -0.922150},{
      41.935383, -6.883024, -1.844301},{41.935383, -6.171150, -3.562915},{
      41.935383, -3.085575, -1.781458},{41.935383, -3.441512, -0.922150}}],
    Polygon[{{41.935383, -6.883024, -1.844301},{
      41.935383, -10.324535, -2.766451},{41.935383, -9.256725, -5.344373},{
      41.935383, -6.171150, -3.562915},{41.935383, -6.883024, -1.844301}}],
    Polygon[{{41.935383, -0.000000, -0.000000},{
      41.935383, -3.085575, -1.781458},{41.935383, -2.519361, -2.519361},{
      41.935383, -0.000000, -0.000000},{41.935383, -0.000000, -0.000000}}],
    Polygon[{{41.935383, -3.085575, -1.781458},{
      41.935383, -6.171150, -3.562915},{41.935383, -5.038723, -5.038723},{
      41.935383, -2.519361, -2.519361},{41.935383, -3.085575, -1.781458}}],
    Polygon[{{41.935383, -6.171150, -3.562915},{
      41.935383, -9.256725, -5.344373},{41.935383, -7.558084, -7.558084},{
      41.935383, -5.038723, -5.038723},{41.935383, -6.171150, -3.562915}}],
    Polygon[{{41.935383, -0.000000, -0.000000},{
      41.935383, -2.519361, -2.519361},{41.935383, -1.781458, -3.085575},{
      41.935383, -0.000000, -0.000000},{41.935383, -0.000000, -0.000000}}],
    Polygon[{{41.935383, -2.519361, -2.519361},{
      41.935383, -5.038723, -5.038723},{41.935383, -3.562915, -6.171150},{
      41.935383, -1.781458, -3.085575},{41.935383, -2.519361, -2.519361}}],
    Polygon[{{41.935383, -5.038723, -5.038723},{
      41.935383, -7.558084, -7.558084},{41.935383, -5.344373, -9.256725},{
      41.935383, -3.562915, -6.171150},{41.935383, -5.038723, -5.038723}}],
    Polygon[{{41.935383, -0.000000, -0.000000},{
      41.935383, -1.781458, -3.085575},{41.935383, -0.922150, -3.441512},{
      41.935383, -0.000000, -0.000000},{41.935383, -0.000000, -0.000000}}],
    Polygon[{{41.935383, -1.781458, -3.085575},{
      41.935383, -3.562915, -6.171150},{41.935383, -1.844301, -6.883024},{
      41.935383, -0.922150, -3.441512},{41.935383, -1.781458, -3.085575}}],
    Polygon[{{41.935383, -3.562915, -6.171150},{
      41.935383, -5.344373, -9.256725},{41.935383, -2.766451, -10.324535},{
      41.935383, -1.844301, -6.883024},{41.935383, -3.562915, -6.171150}}],
    Polygon[{{41.935383, -0.000000, -0.000000},{
      41.935383, -0.922150, -3.441512},{41.935383, -0.000000, -3.562915},{
      41.935383, -0.000000, -0.000000},{41.935383, -0.000000, -0.000000}}],
    Polygon[{{41.935383, -0.922150, -3.441512},{
      41.935383, -1.844301, -6.883024},{41.935383, -0.000000, -7.125831},{
      41.935383, -0.000000, -3.562915},{41.935383, -0.922150, -3.441512}}],
    Polygon[{{41.935383, -1.844301, -6.883024},{
      41.935383, -2.766451, -10.324535},{41.935383, -0.000000, -10.688745},{
      41.935383, -0.000000, -7.125831},{41.935383, -1.844301, -6.883024}}],
    Polygon[{{41.935383, -0.000000, -0.000000},{
      41.935383, -0.000000, -3.562915},{41.935383, 0.922150, -3.441512},{
      41.935383, 0.000000, -0.000000},{41.935383, -0.000000, -0.000000}}],
    Polygon[{{41.935383, -0.000000, -3.562915},{
      41.935383, -0.000000, -7.125831},{41.935383, 1.844301, -6.883024},{
      41.935383, 0.922150, -3.441512},{41.935383, -0.000000, -3.562915}}],
    Polygon[{{41.935383, -0.000000, -7.125831},{
      41.935383, -0.000000, -10.688745},{41.935383, 2.766451, -10.324535},{
      41.935383, 1.844301, -6.883024},{41.935383, -0.000000, -7.125831}}],
    Polygon[{{41.935383, 0.000000, -0.000000},{
      41.935383, 0.922150, -3.441512},{41.935383, 1.781458, -3.085575},{
      41.935383, 0.000000, -0.000000},{41.935383, 0.000000, -0.000000}}],
    Polygon[{{41.935383, 0.922150, -3.441512},{
      41.935383, 1.844301, -6.883024},{41.935383, 3.562915, -6.171150},{
      41.935383, 1.781458, -3.085575},{41.935383, 0.922150, -3.441512}}],
    Polygon[{{41.935383, 1.844301, -6.883024},{
      41.935383, 2.766451, -10.324535},{41.935383, 5.344373, -9.256725},{
      41.935383, 3.562915, -6.171150},{41.935383, 1.844301, -6.883024}}],
    Polygon[{{41.935383, 0.000000, -0.000000},{
      41.935383, 1.781458, -3.085575},{41.935383, 2.519361, -2.519361},{
      41.935383, 0.000000, -0.000000},{41.935383, 0.000000, -0.000000}}],
    Polygon[{{41.935383, 1.781458, -3.085575},{
      41.935383, 3.562915, -6.171150},{41.935383, 5.038723, -5.038723},{
      41.935383, 2.519361, -2.519361},{41.935383, 1.781458, -3.085575}}],
    Polygon[{{41.935383, 3.562915, -6.171150},{
      41.935383, 5.344373, -9.256725},{41.935383, 7.558084, -7.558084},{
      41.935383, 5.038723, -5.038723},{41.935383, 3.562915, -6.171150}}],
    Polygon[{{41.935383, 0.000000, -0.000000},{
      41.935383, 2.519361, -2.519361},{41.935383, 3.085575, -1.781458},{
      41.935383, 0.000000, -0.000000},{41.935383, 0.000000, -0.000000}}],
    Polygon[{{41.935383, 2.519361, -2.519361},{
      41.935383, 5.038723, -5.038723},{41.935383, 6.171150, -3.562915},{
      41.935383, 3.085575, -1.781458},{41.935383, 2.519361, -2.519361}}],
    Polygon[{{41.935383, 5.038723, -5.038723},{
      41.935383, 7.558084, -7.558084},{41.935383, 9.256725, -5.344373},{
      41.935383, 6.171150, -3.562915},{41.935383, 5.038723, -5.038723}}],
    Polygon[{{41.935383, 0.000000, -0.000000},{
      41.935383, 3.085575, -1.781458},{41.935383, 3.441512, -0.922150},{
      41.935383, 0.000000, -0.000000},{41.935383, 0.000000, -0.000000}}],
    Polygon[{{41.935383, 3.085575, -1.781458},{
      41.935383, 6.171150, -3.562915},{41.935383, 6.883024, -1.844301},{
      41.935383, 3.441512, -0.922150},{41.935383, 3.085575, -1.781458}}],
    Polygon[{{41.935383, 6.171150, -3.562915},{
      41.935383, 9.256725, -5.344373},{41.935383, 10.324535, -2.766451},{
      41.935383, 6.883024, -1.844301},{41.935383, 6.171150, -3.562915}}],
    Polygon[{{41.935383, 0.000000, -0.000000},{
      41.935383, 3.441512, -0.922150},{41.935383, 3.562915, -0.000000},{
      41.935383, 0.000000, -0.000000},{41.935383, 0.000000, -0.000000}}],
    Polygon[{{41.935383, 3.441512, -0.922150},{
      41.935383, 6.883024, -1.844301},{41.935383, 7.125831, -0.000000},{
      41.935383, 3.562915, -0.000000},{41.935383, 3.441512, -0.922150}}],
    Polygon[{{41.935383, 6.883024, -1.844301},{
      41.935383, 10.324535, -2.766451},{41.935383, 10.688745, -0.000000},{
      41.935383, 7.125831, -0.000000},{41.935383, 6.883024, -1.844301}}],
    Line[{{41.935383, 10.742458, 0.000000},{41.935383, 10.376417, 2.780353},{
      41.935383, 9.303242, 5.371229},{41.935383, 7.596065, 7.596065},{
      41.935383, 5.371229, 9.303242},{41.935383, 2.780353, 10.376417},{
      41.935383, 0.000000, 10.742458},{41.935383, -2.780353, 10.376417},{
      41.935383, -5.371229, 9.303242},{41.935383, -7.596065, 7.596065},{
      41.935383, -9.303242, 5.371229},{41.935383, -10.376417, 2.780353},{
      41.935383, -10.742458, 0.000000},{41.935383, -10.376417, -2.780353},{
      41.935383, -9.303242, -5.371229},{41.935383, -7.596065, -7.596065},{
      41.935383, -5.371229, -9.303242},{41.935383, -2.780353, -10.376417},{
      41.935383, -0.000000, -10.742458},{41.935383, 2.780353, -10.376417},{
      41.935383, 5.371229, -9.303242},{41.935383, 7.596065, -7.596065},{
      41.935383, 9.303242, -5.371229},{41.935383, 10.376417, -2.780353},{
      41.935383, 10.742458, -0.000000}}],
    Polygon[{{34.527897, 12.993070, 0.000000},{
      41.499660, 10.742458, 0.000000},{41.499660, 10.376417, 2.780353},{
      34.527897, 12.550342, 3.362854},{34.527897, 12.993070, 0.000000}}],
    Polygon[{{34.527897, 12.550342, 3.362854},{
      41.499660, 10.376417, 2.780353},{41.499660, 9.303242, 5.371229},{
      34.527897, 11.252329, 6.496535},{34.527897, 12.550342, 3.362854}}],
    Polygon[{{34.527897, 11.252329, 6.496535},{
      41.499660, 9.303242, 5.371229},{41.499660, 7.596065, 7.596065},{
      34.527897, 9.187488, 9.187488},{34.527897, 11.252329, 6.496535}}],
    Polygon[{{34.527897, 9.187488, 9.187488},{41.499660, 7.596065, 7.596065},{
      41.499660, 5.371229, 9.303242},{34.527897, 6.496535, 11.252329},{
      34.527897, 9.187488, 9.187488}}],
    Polygon[{{34.527897, 6.496535, 11.252329},{
      41.499660, 5.371229, 9.303242},{41.499660, 2.780353, 10.376417},{
      34.527897, 3.362854, 12.550342},{34.527897, 6.496535, 11.252329}}],
    Polygon[{{34.527897, 3.362854, 12.550342},{
      41.499660, 2.780353, 10.376417},{41.499660, 0.000000, 10.742458},{
      34.527897, 0.000000, 12.993070},{34.527897, 3.362854, 12.550342}}],
    Polygon[{{34.527897, 0.000000, 12.993070},{
      41.499660, 0.000000, 10.742458},{41.499660, -2.780353, 10.376417},{
      34.527897, -3.362854, 12.550342},{34.527897, 0.000000, 12.993070}}],
    Polygon[{{34.527897, -3.362854, 12.550342},{
      41.499660, -2.780353, 10.376417},{41.499660, -5.371229, 9.303242},{
      34.527897, -6.496535, 11.252329},{34.527897, -3.362854, 12.550342}}],
    Polygon[{{34.527897, -6.496535, 11.252329},{
      41.499660, -5.371229, 9.303242},{41.499660, -7.596065, 7.596065},{
      34.527897, -9.187488, 9.187488},{34.527897, -6.496535, 11.252329}}],
    Polygon[{{34.527897, -9.187488, 9.187488},{
      41.499660, -7.596065, 7.596065},{41.499660, -9.303242, 5.371229},{
      34.527897, -11.252329, 6.496535},{34.527897, -9.187488, 9.187488}}],
    Polygon[{{34.527897, -11.252329, 6.496535},{
      41.499660, -9.303242, 5.371229},{41.499660, -10.376417, 2.780353},{
      34.527897, -12.550342, 3.362854},{34.527897, -11.252329, 6.496535}}],
    Polygon[{{34.527897, -12.550342, 3.362854},{
      41.499660, -10.376417, 2.780353},{41.499660, -10.742458, 0.000000},{
      34.527897, -12.993070, 0.000000},{34.527897, -12.550342, 3.362854}}],
    Polygon[{{34.527897, -12.993070, 0.000000},{
      41.499660, -10.742458, 0.000000},{41.499660, -10.376417, -2.780353},{
      34.527897, -12.550342, -3.362854},{34.527897, -12.993070, 0.000000}}],
    Polygon[{{34.527897, -12.550342, -3.362854},{
      41.499660, -10.376417, -2.780353},{41.499660, -9.303242, -5.371229},{
      34.527897, -11.252329, -6.496535},{34.527897, -12.550342, -3.362854}}],
    Polygon[{{34.527897, -11.252329, -6.496535},{
      41.499660, -9.303242, -5.371229},{41.499660, -7.596065, -7.596065},{
      34.527897, -9.187488, -9.187488},{34.527897, -11.252329, -6.496535}}],
    Polygon[{{34.527897, -9.187488, -9.187488},{
      41.499660, -7.596065, -7.596065},{41.499660, -5.371229, -9.303242},{
      34.527897, -6.496535, -11.252329},{34.527897, -9.187488, -9.187488}}],
    Polygon[{{34.527897, -6.496535, -11.252329},{
      41.499660, -5.371229, -9.303242},{41.499660, -2.780353, -10.376417},{
      34.527897, -3.362854, -12.550342},{34.527897, -6.496535, -11.252329}}],
    Polygon[{{34.527897, -3.362854, -12.550342},{
      41.499660, -2.780353, -10.376417},{41.499660, -0.000000, -10.742458},{
      34.527897, -0.000000, -12.993070},{34.527897, -3.362854, -12.550342}}],
    Polygon[{{34.527897, -0.000000, -12.993070},{
      41.499660, -0.000000, -10.742458},{41.499660, 2.780353, -10.376417},{
      34.527897, 3.362854, -12.550342},{34.527897, -0.000000, -12.993070}}],
    Polygon[{{34.527897, 3.362854, -12.550342},{
      41.499660, 2.780353, -10.376417},{41.499660, 5.371229, -9.303242},{
      34.527897, 6.496535, -11.252329},{34.527897, 3.362854, -12.550342}}],
    Polygon[{{34.527897, 6.496535, -11.252329},{
      41.499660, 5.371229, -9.303242},{41.499660, 7.596065, -7.596065},{
      34.527897, 9.187488, -9.187488},{34.527897, 6.496535, -11.252329}}],
    Polygon[{{34.527897, 9.187488, -9.187488},{
      41.499660, 7.596065, -7.596065},{41.499660, 9.303242, -5.371229},{
      34.527897, 11.252329, -6.496535},{34.527897, 9.187488, -9.187488}}],
    Polygon[{{34.527897, 11.252329, -6.496535},{
      41.499660, 9.303242, -5.371229},{41.499660, 10.376417, -2.780353},{
      34.527897, 12.550342, -3.362854},{34.527897, 11.252329, -6.496535}}],
    Polygon[{{34.527897, 12.550342, -3.362854},{
      41.499660, 10.376417, -2.780353},{41.499660, 10.742458, -0.000000},{
      34.527897, 12.993070, -0.000000},{34.527897, 12.550342, -3.362854}}],
    Polygon[{{41.499660, 10.742458, 0.000000},{
      41.935383, 10.742458, 0.000000},{41.935383, 10.376417, 2.780353},{
      41.499660, 10.376417, 2.780353},{41.499660, 10.742458, 0.000000}}],
    Polygon[{{41.499660, 10.376417, 2.780353},{
      41.935383, 10.376417, 2.780353},{41.935383, 9.303242, 5.371229},{
      41.499660, 9.303242, 5.371229},{41.499660, 10.376417, 2.780353}}],
    Polygon[{{41.499660, 9.303242, 5.371229},{41.935383, 9.303242, 5.371229},{
      41.935383, 7.596065, 7.596065},{41.499660, 7.596065, 7.596065},{
      41.499660, 9.303242, 5.371229}}],
    Polygon[{{41.499660, 7.596065, 7.596065},{41.935383, 7.596065, 7.596065},{
      41.935383, 5.371229, 9.303242},{41.499660, 5.371229, 9.303242},{
      41.499660, 7.596065, 7.596065}}],
    Polygon[{{41.499660, 5.371229, 9.303242},{41.935383, 5.371229, 9.303242},{
      41.935383, 2.780353, 10.376417},{41.499660, 2.780353, 10.376417},{
      41.499660, 5.371229, 9.303242}}],
    Polygon[{{41.499660, 2.780353, 10.376417},{
      41.935383, 2.780353, 10.376417},{41.935383, 0.000000, 10.742458},{
      41.499660, 0.000000, 10.742458},{41.499660, 2.780353, 10.376417}}],
    Polygon[{{41.499660, 0.000000, 10.742458},{
      41.935383, 0.000000, 10.742458},{41.935383, -2.780353, 10.376417},{
      41.499660, -2.780353, 10.376417},{41.499660, 0.000000, 10.742458}}],
    Polygon[{{41.499660, -2.780353, 10.376417},{
      41.935383, -2.780353, 10.376417},{41.935383, -5.371229, 9.303242},{
      41.499660, -5.371229, 9.303242},{41.499660, -2.780353, 10.376417}}],
    Polygon[{{41.499660, -5.371229, 9.303242},{
      41.935383, -5.371229, 9.303242},{41.935383, -7.596065, 7.596065},{
      41.499660, -7.596065, 7.596065},{41.499660, -5.371229, 9.303242}}],
    Polygon[{{41.499660, -7.596065, 7.596065},{
      41.935383, -7.596065, 7.596065},{41.935383, -9.303242, 5.371229},{
      41.499660, -9.303242, 5.371229},{41.499660, -7.596065, 7.596065}}],
    Polygon[{{41.499660, -9.303242, 5.371229},{
      41.935383, -9.303242, 5.371229},{41.935383, -10.376417, 2.780353},{
      41.499660, -10.376417, 2.780353},{41.499660, -9.303242, 5.371229}}],
    Polygon[{{41.499660, -10.376417, 2.780353},{
      41.935383, -10.376417, 2.780353},{41.935383, -10.742458, 0.000000},{
      41.499660, -10.742458, 0.000000},{41.499660, -10.376417, 2.780353}}],
    Polygon[{{41.499660, -10.742458, 0.000000},{
      41.935383, -10.742458, 0.000000},{41.935383, -10.376417, -2.780353},{
      41.499660, -10.376417, -2.780353},{41.499660, -10.742458, 0.000000}}],
    Polygon[{{41.499660, -10.376417, -2.780353},{
      41.935383, -10.376417, -2.780353},{41.935383, -9.303242, -5.371229},{
      41.499660, -9.303242, -5.371229},{41.499660, -10.376417, -2.780353}}],
    Polygon[{{41.499660, -9.303242, -5.371229},{
      41.935383, -9.303242, -5.371229},{41.935383, -7.596065, -7.596065},{
      41.499660, -7.596065, -7.596065},{41.499660, -9.303242, -5.371229}}],
    Polygon[{{41.499660, -7.596065, -7.596065},{
      41.935383, -7.596065, -7.596065},{41.935383, -5.371229, -9.303242},{
      41.499660, -5.371229, -9.303242},{41.499660, -7.596065, -7.596065}}],
    Polygon[{{41.499660, -5.371229, -9.303242},{
      41.935383, -5.371229, -9.303242},{41.935383, -2.780353, -10.376417},{
      41.499660, -2.780353, -10.376417},{41.499660, -5.371229, -9.303242}}],
    Polygon[{{41.499660, -2.780353, -10.376417},{
      41.935383, -2.780353, -10.376417},{41.935383, -0.000000, -10.742458},{
      41.499660, -0.000000, -10.742458},{41.499660, -2.780353, -10.376417}}],
    Polygon[{{41.499660, -0.000000, -10.742458},{
      41.935383, -0.000000, -10.742458},{41.935383, 2.780353, -10.376417},{
      41.499660, 2.780353, -10.376417},{41.499660, -0.000000, -10.742458}}],
    Polygon[{{41.499660, 2.780353, -10.376417},{
      41.935383, 2.780353, -10.376417},{41.935383, 5.371229, -9.303242},{
      41.499660, 5.371229, -9.303242},{41.499660, 2.780353, -10.376417}}],
    Polygon[{{41.499660, 5.371229, -9.303242},{
      41.935383, 5.371229, -9.303242},{41.935383, 7.596065, -7.596065},{
      41.499660, 7.596065, -7.596065},{41.499660, 5.371229, -9.303242}}],
    Polygon[{{41.499660, 7.596065, -7.596065},{
      41.935383, 7.596065, -7.596065},{41.935383, 9.303242, -5.371229},{
      41.499660, 9.303242, -5.371229},{41.499660, 7.596065, -7.596065}}],
    Polygon[{{41.499660, 9.303242, -5.371229},{
      41.935383, 9.303242, -5.371229},{41.935383, 10.376417, -2.780353},{
      41.499660, 10.376417, -2.780353},{41.499660, 9.303242, -5.371229}}],
    Polygon[{{41.499660, 10.376417, -2.780353},{
      41.935383, 10.376417, -2.780353},{41.935383, 10.742458, -0.000000},{
      41.499660, 10.742458, -0.000000},{41.499660, 10.376417, -2.780353}}],
    Polygon[{{44.611702, 9.304864, 0.000000},{
      44.611702, 10.080269, 0.000000},{44.611702, 9.736793, 2.608966},{
      44.611702, 8.987808, 2.408276},{44.611702, 9.304864, 0.000000}}],
    Polygon[{{44.611702, 8.987808, 2.408276},{44.611702, 9.736793, 2.608966},{
      44.611702, 8.729770, 5.040134},{44.611702, 8.058249, 4.652432},{
      44.611702, 8.987808, 2.408276}}],
    Polygon[{{44.611702, 8.058249, 4.652432},{44.611702, 8.729770, 5.040134},{
      44.611702, 7.127827, 7.127827},{44.611702, 6.579533, 6.579533},{
      44.611702, 8.058249, 4.652432}}],
    Polygon[{{44.611702, 6.579533, 6.579533},{44.611702, 7.127827, 7.127827},{
      44.611702, 5.040134, 8.729770},{44.611702, 4.652432, 8.058249},{
      44.611702, 6.579533, 6.579533}}],
    Polygon[{{44.611702, 4.652432, 8.058249},{44.611702, 5.040134, 8.729770},{
      44.611702, 2.608966, 9.736793},{44.611702, 2.408276, 8.987808},{
      44.611702, 4.652432, 8.058249}}],
    Polygon[{{44.611702, 2.408276, 8.987808},{44.611702, 2.608966, 9.736793},{
      44.611702, 0.000000, 10.080269},{44.611702, 0.000000, 9.304864},{
      44.611702, 2.408276, 8.987808}}],
    Polygon[{{44.611702, 0.000000, 9.304864},{
      44.611702, 0.000000, 10.080269},{44.611702, -2.608966, 9.736793},{
      44.611702, -2.408276, 8.987808},{44.611702, 0.000000, 9.304864}}],
    Polygon[{{44.611702, -2.408276, 8.987808},{
      44.611702, -2.608966, 9.736793},{44.611702, -5.040134, 8.729770},{
      44.611702, -4.652432, 8.058249},{44.611702, -2.408276, 8.987808}}],
    Polygon[{{44.611702, -4.652432, 8.058249},{
      44.611702, -5.040134, 8.729770},{44.611702, -7.127827, 7.127827},{
      44.611702, -6.579533, 6.579533},{44.611702, -4.652432, 8.058249}}],
    Polygon[{{44.611702, -6.579533, 6.579533},{
      44.611702, -7.127827, 7.127827},{44.611702, -8.729770, 5.040134},{
      44.611702, -8.058249, 4.652432},{44.611702, -6.579533, 6.579533}}],
    Polygon[{{44.611702, -8.058249, 4.652432},{
      44.611702, -8.729770, 5.040134},{44.611702, -9.736793, 2.608966},{
      44.611702, -8.987808, 2.408276},{44.611702, -8.058249, 4.652432}}],
    Polygon[{{44.611702, -8.987808, 2.408276},{
      44.611702, -9.736793, 2.608966},{44.611702, -10.080269, 0.000000},{
      44.611702, -9.304864, 0.000000},{44.611702, -8.987808, 2.408276}}],
    Polygon[{{44.611702, -9.304864, 0.000000},{
      44.611702, -10.080269, 0.000000},{44.611702, -9.736793, -2.608966},{
      44.611702, -8.987808, -2.408276},{44.611702, -9.304864, 0.000000}}],
    Polygon[{{44.611702, -8.987808, -2.408276},{
      44.611702, -9.736793, -2.608966},{44.611702, -8.729770, -5.040134},{
      44.611702, -8.058249, -4.652432},{44.611702, -8.987808, -2.408276}}],
    Polygon[{{44.611702, -8.058249, -4.652432},{
      44.611702, -8.729770, -5.040134},{44.611702, -7.127827, -7.127827},{
      44.611702, -6.579533, -6.579533},{44.611702, -8.058249, -4.652432}}],
    Polygon[{{44.611702, -6.579533, -6.579533},{
      44.611702, -7.127827, -7.127827},{44.611702, -5.040134, -8.729770},{
      44.611702, -4.652432, -8.058249},{44.611702, -6.579533, -6.579533}}],
    Polygon[{{44.611702, -4.652432, -8.058249},{
      44.611702, -5.040134, -8.729770},{44.611702, -2.608966, -9.736793},{
      44.611702, -2.408276, -8.987808},{44.611702, -4.652432, -8.058249}}],
    Polygon[{{44.611702, -2.408276, -8.987808},{
      44.611702, -2.608966, -9.736793},{44.611702, -0.000000, -10.080269},{
      44.611702, -0.000000, -9.304864},{44.611702, -2.408276, -8.987808}}],
    Polygon[{{44.611702, -0.000000, -9.304864},{
      44.611702, -0.000000, -10.080269},{44.611702, 2.608966, -9.736793},{
      44.611702, 2.408276, -8.987808},{44.611702, -0.000000, -9.304864}}],
    Polygon[{{44.611702, 2.408276, -8.987808},{
      44.611702, 2.608966, -9.736793},{44.611702, 5.040134, -8.729770},{
      44.611702, 4.652432, -8.058249},{44.611702, 2.408276, -8.987808}}],
    Polygon[{{44.611702, 4.652432, -8.058249},{
      44.611702, 5.040134, -8.729770},{44.611702, 7.127827, -7.127827},{
      44.611702, 6.579533, -6.579533},{44.611702, 4.652432, -8.058249}}],
    Polygon[{{44.611702, 6.579533, -6.579533},{
      44.611702, 7.127827, -7.127827},{44.611702, 8.729770, -5.040134},{
      44.611702, 8.058249, -4.652432},{44.611702, 6.579533, -6.579533}}],
    Polygon[{{44.611702, 8.058249, -4.652432},{
      44.611702, 8.729770, -5.040134},{44.611702, 9.736793, -2.608966},{
      44.611702, 8.987808, -2.408276},{44.611702, 8.058249, -4.652432}}],
    Polygon[{{44.611702, 8.987808, -2.408276},{
      44.611702, 9.736793, -2.608966},{44.611702, 10.080269, -0.000000},{
      44.611702, 9.304864, -0.000000},{44.611702, 8.987808, -2.408276}}],
    Polygon[{{44.611702, 10.080269, 0.000000},{
      44.611702, 10.855675, 0.000000},{44.611702, 10.485777, 2.809655},{
      44.611702, 9.736793, 2.608966},{44.611702, 10.080269, 0.000000}}],
    Polygon[{{44.611702, 9.736793, 2.608966},{
      44.611702, 10.485777, 2.809655},{44.611702, 9.401290, 5.427837},{
      44.611702, 8.729770, 5.040134},{44.611702, 9.736793, 2.608966}}],
    Polygon[{{44.611702, 8.729770, 5.040134},{44.611702, 9.401290, 5.427837},{
      44.611702, 7.676121, 7.676121},{44.611702, 7.127827, 7.127827},{
      44.611702, 8.729770, 5.040134}}],
    Polygon[{{44.611702, 7.127827, 7.127827},{44.611702, 7.676121, 7.676121},{
      44.611702, 5.427837, 9.401290},{44.611702, 5.040134, 8.729770},{
      44.611702, 7.127827, 7.127827}}],
    Polygon[{{44.611702, 5.040134, 8.729770},{44.611702, 5.427837, 9.401290},{
      44.611702, 2.809655, 10.485777},{44.611702, 2.608966, 9.736793},{
      44.611702, 5.040134, 8.729770}}],
    Polygon[{{44.611702, 2.608966, 9.736793},{
      44.611702, 2.809655, 10.485777},{44.611702, 0.000000, 10.855675},{
      44.611702, 0.000000, 10.080269},{44.611702, 2.608966, 9.736793}}],
    Polygon[{{44.611702, 0.000000, 10.080269},{
      44.611702, 0.000000, 10.855675},{44.611702, -2.809655, 10.485777},{
      44.611702, -2.608966, 9.736793},{44.611702, 0.000000, 10.080269}}],
    Polygon[{{44.611702, -2.608966, 9.736793},{
      44.611702, -2.809655, 10.485777},{44.611702, -5.427837, 9.401290},{
      44.611702, -5.040134, 8.729770},{44.611702, -2.608966, 9.736793}}],
    Polygon[{{44.611702, -5.040134, 8.729770},{
      44.611702, -5.427837, 9.401290},{44.611702, -7.676121, 7.676121},{
      44.611702, -7.127827, 7.127827},{44.611702, -5.040134, 8.729770}}],
    Polygon[{{44.611702, -7.127827, 7.127827},{
      44.611702, -7.676121, 7.676121},{44.611702, -9.401290, 5.427837},{
      44.611702, -8.729770, 5.040134},{44.611702, -7.127827, 7.127827}}],
    Polygon[{{44.611702, -8.729770, 5.040134},{
      44.611702, -9.401290, 5.427837},{44.611702, -10.485777, 2.809655},{
      44.611702, -9.736793, 2.608966},{44.611702, -8.729770, 5.040134}}],
    Polygon[{{44.611702, -9.736793, 2.608966},{
      44.611702, -10.485777, 2.809655},{44.611702, -10.855675, 0.000000},{
      44.611702, -10.080269, 0.000000},{44.611702, -9.736793, 2.608966}}],
    Polygon[{{44.611702, -10.080269, 0.000000},{
      44.611702, -10.855675, 0.000000},{44.611702, -10.485777, -2.809655},{
      44.611702, -9.736793, -2.608966},{44.611702, -10.080269, 0.000000}}],
    Polygon[{{44.611702, -9.736793, -2.608966},{
      44.611702, -10.485777, -2.809655},{44.611702, -9.401290, -5.427837},{
      44.611702, -8.729770, -5.040134},{44.611702, -9.736793, -2.608966}}],
    Polygon[{{44.611702, -8.729770, -5.040134},{
      44.611702, -9.401290, -5.427837},{44.611702, -7.676121, -7.676121},{
      44.611702, -7.127827, -7.127827},{44.611702, -8.729770, -5.040134}}],
    Polygon[{{44.611702, -7.127827, -7.127827},{
      44.611702, -7.676121, -7.676121},{44.611702, -5.427837, -9.401290},{
      44.611702, -5.040134, -8.729770},{44.611702, -7.127827, -7.127827}}],
    Polygon[{{44.611702, -5.040134, -8.729770},{
      44.611702, -5.427837, -9.401290},{44.611702, -2.809655, -10.485777},{
      44.611702, -2.608966, -9.736793},{44.611702, -5.040134, -8.729770}}],
    Polygon[{{44.611702, -2.608966, -9.736793},{
      44.611702, -2.809655, -10.485777},{44.611702, -0.000000, -10.855675},{
      44.611702, -0.000000, -10.080269},{44.611702, -2.608966, -9.736793}}],
    Polygon[{{44.611702, -0.000000, -10.080269},{
      44.611702, -0.000000, -10.855675},{44.611702, 2.809655, -10.485777},{
      44.611702, 2.608966, -9.736793},{44.611702, -0.000000, -10.080269}}],
    Polygon[{{44.611702, 2.608966, -9.736793},{
      44.611702, 2.809655, -10.485777},{44.611702, 5.427837, -9.401290},{
      44.611702, 5.040134, -8.729770},{44.611702, 2.608966, -9.736793}}],
    Polygon[{{44.611702, 5.040134, -8.729770},{
      44.611702, 5.427837, -9.401290},{44.611702, 7.676121, -7.676121},{
      44.611702, 7.127827, -7.127827},{44.611702, 5.040134, -8.729770}}],
    Polygon[{{44.611702, 7.127827, -7.127827},{
      44.611702, 7.676121, -7.676121},{44.611702, 9.401290, -5.427837},{
      44.611702, 8.729770, -5.040134},{44.611702, 7.127827, -7.127827}}],
    Polygon[{{44.611702, 8.729770, -5.040134},{
      44.611702, 9.401290, -5.427837},{44.611702, 10.485777, -2.809655},{
      44.611702, 9.736793, -2.608966},{44.611702, 8.729770, -5.040134}}],
    Polygon[{{44.611702, 9.736793, -2.608966},{
      44.611702, 10.485777, -2.809655},{44.611702, 10.855675, -0.000000},{
      44.611702, 10.080269, -0.000000},{44.611702, 9.736793, -2.608966}}],
    Polygon[{{44.611702, 10.855675, 0.000000},{
      44.611702, 11.631080, 0.000000},{44.611702, 11.234760, 3.010345},{
      44.611702, 10.485777, 2.809655},{44.611702, 10.855675, 0.000000}}],
    Polygon[{{44.611702, 10.485777, 2.809655},{
      44.611702, 11.234760, 3.010345},{44.611702, 10.072811, 5.815540},{
      44.611702, 9.401290, 5.427837},{44.611702, 10.485777, 2.809655}}],
    Polygon[{{44.611702, 9.401290, 5.427837},{
      44.611702, 10.072811, 5.815540},{44.611702, 8.224416, 8.224416},{
      44.611702, 7.676121, 7.676121},{44.611702, 9.401290, 5.427837}}],
    Polygon[{{44.611702, 7.676121, 7.676121},{44.611702, 8.224416, 8.224416},{
      44.611702, 5.815540, 10.072811},{44.611702, 5.427837, 9.401290},{
      44.611702, 7.676121, 7.676121}}],
    Polygon[{{44.611702, 5.427837, 9.401290},{
      44.611702, 5.815540, 10.072811},{44.611702, 3.010345, 11.234760},{
      44.611702, 2.809655, 10.485777},{44.611702, 5.427837, 9.401290}}],
    Polygon[{{44.611702, 2.809655, 10.485777},{
      44.611702, 3.010345, 11.234760},{44.611702, 0.000000, 11.631080},{
      44.611702, 0.000000, 10.855675},{44.611702, 2.809655, 10.485777}}],
    Polygon[{{44.611702, 0.000000, 10.855675},{
      44.611702, 0.000000, 11.631080},{44.611702, -3.010345, 11.234760},{
      44.611702, -2.809655, 10.485777},{44.611702, 0.000000, 10.855675}}],
    Polygon[{{44.611702, -2.809655, 10.485777},{
      44.611702, -3.010345, 11.234760},{44.611702, -5.815540, 10.072811},{
      44.611702, -5.427837, 9.401290},{44.611702, -2.809655, 10.485777}}],
    Polygon[{{44.611702, -5.427837, 9.401290},{
      44.611702, -5.815540, 10.072811},{44.611702, -8.224416, 8.224416},{
      44.611702, -7.676121, 7.676121},{44.611702, -5.427837, 9.401290}}],
    Polygon[{{44.611702, -7.676121, 7.676121},{
      44.611702, -8.224416, 8.224416},{44.611702, -10.072811, 5.815540},{
      44.611702, -9.401290, 5.427837},{44.611702, -7.676121, 7.676121}}],
    Polygon[{{44.611702, -9.401290, 5.427837},{
      44.611702, -10.072811, 5.815540},{44.611702, -11.234760, 3.010345},{
      44.611702, -10.485777, 2.809655},{44.611702, -9.401290, 5.427837}}],
    Polygon[{{44.611702, -10.485777, 2.809655},{
      44.611702, -11.234760, 3.010345},{44.611702, -11.631080, 0.000000},{
      44.611702, -10.855675, 0.000000},{44.611702, -10.485777, 2.809655}}],
    Polygon[{{44.611702, -10.855675, 0.000000},{
      44.611702, -11.631080, 0.000000},{44.611702, -11.234760, -3.010345},{
      44.611702, -10.485777, -2.809655},{44.611702, -10.855675, 0.000000}}],
    Polygon[{{44.611702, -10.485777, -2.809655},{
      44.611702, -11.234760, -3.010345},{44.611702, -10.072811, -5.815540},{
      44.611702, -9.401290, -5.427837},{44.611702, -10.485777, -2.809655}}],
    Polygon[{{44.611702, -9.401290, -5.427837},{
      44.611702, -10.072811, -5.815540},{44.611702, -8.224416, -8.224416},{
      44.611702, -7.676121, -7.676121},{44.611702, -9.401290, -5.427837}}],
    Polygon[{{44.611702, -7.676121, -7.676121},{
      44.611702, -8.224416, -8.224416},{44.611702, -5.815540, -10.072811},{
      44.611702, -5.427837, -9.401290},{44.611702, -7.676121, -7.676121}}],
    Polygon[{{44.611702, -5.427837, -9.401290},{
      44.611702, -5.815540, -10.072811},{44.611702, -3.010345, -11.234760},{
      44.611702, -2.809655, -10.485777},{44.611702, -5.427837, -9.401290}}],
    Polygon[{{44.611702, -2.809655, -10.485777},{
      44.611702, -3.010345, -11.234760},{44.611702, -0.000000, -11.631080},{
      44.611702, -0.000000, -10.855675},{44.611702, -2.809655, -10.485777}}],
    Polygon[{{44.611702, -0.000000, -10.855675},{
      44.611702, -0.000000, -11.631080},{44.611702, 3.010345, -11.234760},{
      44.611702, 2.809655, -10.485777},{44.611702, -0.000000, -10.855675}}],
    Polygon[{{44.611702, 2.809655, -10.485777},{
      44.611702, 3.010345, -11.234760},{44.611702, 5.815540, -10.072811},{
      44.611702, 5.427837, -9.401290},{44.611702, 2.809655, -10.485777}}],
    Polygon[{{44.611702, 5.427837, -9.401290},{
      44.611702, 5.815540, -10.072811},{44.611702, 8.224416, -8.224416},{
      44.611702, 7.676121, -7.676121},{44.611702, 5.427837, -9.401290}}],
    Polygon[{{44.611702, 7.676121, -7.676121},{
      44.611702, 8.224416, -8.224416},{44.611702, 10.072811, -5.815540},{
      44.611702, 9.401290, -5.427837},{44.611702, 7.676121, -7.676121}}],
    Polygon[{{44.611702, 9.401290, -5.427837},{
      44.611702, 10.072811, -5.815540},{44.611702, 11.234760, -3.010345},{
      44.611702, 10.485777, -2.809655},{44.611702, 9.401290, -5.427837}}],
    Polygon[{{44.611702, 10.485777, -2.809655},{
      44.611702, 11.234760, -3.010345},{44.611702, 11.631080, -0.000000},{
      44.611702, 10.855675, -0.000000},{44.611702, 10.485777, -2.809655}}],
    Line[{{44.611702, 9.304864, 0.000000},{44.611702, 8.987808, 2.408276},{
      44.611702, 8.058249, 4.652432},{44.611702, 6.579533, 6.579533},{
      44.611702, 4.652432, 8.058249},{44.611702, 2.408276, 8.987808},{
      44.611702, 0.000000, 9.304864},{44.611702, -2.408276, 8.987808},{
      44.611702, -4.652432, 8.058249},{44.611702, -6.579533, 6.579533},{
      44.611702, -8.058249, 4.652432},{44.611702, -8.987808, 2.408276},{
      44.611702, -9.304864, 0.000000},{44.611702, -8.987808, -2.408276},{
      44.611702, -8.058249, -4.652432},{44.611702, -6.579533, -6.579533},{
      44.611702, -4.652432, -8.058249},{44.611702, -2.408276, -8.987808},{
      44.611702, -0.000000, -9.304864},{44.611702, 2.408276, -8.987808},{
      44.611702, 4.652432, -8.058249},{44.611702, 6.579533, -6.579533},{
      44.611702, 8.058249, -4.652432},{44.611702, 8.987808, -2.408276},{
      44.611702, 9.304864, -0.000000}}],
    Line[{{44.611702, 11.631080, 0.000000},{44.611702, 11.234760, 3.010345},{
      44.611702, 10.072811, 5.815540},{44.611702, 8.224416, 8.224416},{
      44.611702, 5.815540, 10.072811},{44.611702, 3.010345, 11.234760},{
      44.611702, 0.000000, 11.631080},{44.611702, -3.010345, 11.234760},{
      44.611702, -5.815540, 10.072811},{44.611702, -8.224416, 8.224416},{
      44.611702, -10.072811, 5.815540},{44.611702, -11.234760, 3.010345},{
      44.611702, -11.631080, 0.000000},{44.611702, -11.234760, -3.010345},{
      44.611702, -10.072811, -5.815540},{44.611702, -8.224416, -8.224416},{
      44.611702, -5.815540, -10.072811},{44.611702, -3.010345, -11.234760},{
      44.611702, -0.000000, -11.631080},{44.611702, 3.010345, -11.234760},{
      44.611702, 5.815540, -10.072811},{44.611702, 8.224416, -8.224416},{
      44.611702, 10.072811, -5.815540},{44.611702, 11.234760, -3.010345},{
      44.611702, 11.631080, -0.000000}}],
    Polygon[{{47.288017, 0.000000, 0.000000},{47.288017, 3.675342, 0.000000},{
      47.288017, 3.550108, 0.951249},{47.288017, 0.000000, 0.000000},{
      47.288017, 0.000000, 0.000000}}],
    Polygon[{{47.288017, 3.675342, 0.000000},{47.288017, 7.350685, 0.000000},{
      47.288017, 7.100216, 1.902497},{47.288017, 3.550108, 0.951249},{
      47.288017, 3.675342, 0.000000}}],
    Polygon[{{47.288017, 7.350685, 0.000000},{
      47.288017, 11.026027, 0.000000},{47.288017, 10.650324, 2.853746},{
      47.288017, 7.100216, 1.902497},{47.288017, 7.350685, 0.000000}}],
    Polygon[{{47.288017, 0.000000, 0.000000},{47.288017, 3.550108, 0.951249},{
      47.288017, 3.182940, 1.837671},{47.288017, 0.000000, 0.000000},{
      47.288017, 0.000000, 0.000000}}],
    Polygon[{{47.288017, 3.550108, 0.951249},{47.288017, 7.100216, 1.902497},{
      47.288017, 6.365880, 3.675342},{47.288017, 3.182940, 1.837671},{
      47.288017, 3.550108, 0.951249}}],
    Polygon[{{47.288017, 7.100216, 1.902497},{
      47.288017, 10.650324, 2.853746},{47.288017, 9.548820, 5.513013},{
      47.288017, 6.365880, 3.675342},{47.288017, 7.100216, 1.902497}}],
    Polygon[{{47.288017, 0.000000, 0.000000},{47.288017, 3.182940, 1.837671},{
      47.288017, 2.598860, 2.598860},{47.288017, 0.000000, 0.000000},{
      47.288017, 0.000000, 0.000000}}],
    Polygon[{{47.288017, 3.182940, 1.837671},{47.288017, 6.365880, 3.675342},{
      47.288017, 5.197719, 5.197719},{47.288017, 2.598860, 2.598860},{
      47.288017, 3.182940, 1.837671}}],
    Polygon[{{47.288017, 6.365880, 3.675342},{47.288017, 9.548820, 5.513013},{
      47.288017, 7.796578, 7.796578},{47.288017, 5.197719, 5.197719},{
      47.288017, 6.365880, 3.675342}}],
    Polygon[{{47.288017, 0.000000, 0.000000},{47.288017, 2.598860, 2.598860},{
      47.288017, 1.837671, 3.182940},{47.288017, 0.000000, 0.000000},{
      47.288017, 0.000000, 0.000000}}],
    Polygon[{{47.288017, 2.598860, 2.598860},{47.288017, 5.197719, 5.197719},{
      47.288017, 3.675342, 6.365880},{47.288017, 1.837671, 3.182940},{
      47.288017, 2.598860, 2.598860}}],
    Polygon[{{47.288017, 5.197719, 5.197719},{47.288017, 7.796578, 7.796578},{
      47.288017, 5.513013, 9.548820},{47.288017, 3.675342, 6.365880},{
      47.288017, 5.197719, 5.197719}}],
    Polygon[{{47.288017, 0.000000, 0.000000},{47.288017, 1.837671, 3.182940},{
      47.288017, 0.951249, 3.550108},{47.288017, 0.000000, 0.000000},{
      47.288017, 0.000000, 0.000000}}],
    Polygon[{{47.288017, 1.837671, 3.182940},{47.288017, 3.675342, 6.365880},{
      47.288017, 1.902497, 7.100216},{47.288017, 0.951249, 3.550108},{
      47.288017, 1.837671, 3.182940}}],
    Polygon[{{47.288017, 3.675342, 6.365880},{47.288017, 5.513013, 9.548820},{
      47.288017, 2.853746, 10.650324},{47.288017, 1.902497, 7.100216},{
      47.288017, 3.675342, 6.365880}}],
    Polygon[{{47.288017, 0.000000, 0.000000},{47.288017, 0.951249, 3.550108},{
      47.288017, 0.000000, 3.675342},{47.288017, 0.000000, 0.000000},{
      47.288017, 0.000000, 0.000000}}],
    Polygon[{{47.288017, 0.951249, 3.550108},{47.288017, 1.902497, 7.100216},{
      47.288017, 0.000000, 7.350685},{47.288017, 0.000000, 3.675342},{
      47.288017, 0.951249, 3.550108}}],
    Polygon[{{47.288017, 1.902497, 7.100216},{
      47.288017, 2.853746, 10.650324},{47.288017, 0.000000, 11.026027},{
      47.288017, 0.000000, 7.350685},{47.288017, 1.902497, 7.100216}}],
    Polygon[{{47.288017, 0.000000, 0.000000},{47.288017, 0.000000, 3.675342},{
      47.288017, -0.951249, 3.550108},{47.288017, -0.000000, 0.000000},{
      47.288017, 0.000000, 0.000000}}],
    Polygon[{{47.288017, 0.000000, 3.675342},{47.288017, 0.000000, 7.350685},{
      47.288017, -1.902497, 7.100216},{47.288017, -0.951249, 3.550108},{
      47.288017, 0.000000, 3.675342}}],
    Polygon[{{47.288017, 0.000000, 7.350685},{
      47.288017, 0.000000, 11.026027},{47.288017, -2.853746, 10.650324},{
      47.288017, -1.902497, 7.100216},{47.288017, 0.000000, 7.350685}}],
    Polygon[{{47.288017, -0.000000, 0.000000},{
      47.288017, -0.951249, 3.550108},{47.288017, -1.837671, 3.182940},{
      47.288017, -0.000000, 0.000000},{47.288017, -0.000000, 0.000000}}],
    Polygon[{{47.288017, -0.951249, 3.550108},{
      47.288017, -1.902497, 7.100216},{47.288017, -3.675342, 6.365880},{
      47.288017, -1.837671, 3.182940},{47.288017, -0.951249, 3.550108}}],
    Polygon[{{47.288017, -1.902497, 7.100216},{
      47.288017, -2.853746, 10.650324},{47.288017, -5.513013, 9.548820},{
      47.288017, -3.675342, 6.365880},{47.288017, -1.902497, 7.100216}}],
    Polygon[{{47.288017, -0.000000, 0.000000},{
      47.288017, -1.837671, 3.182940},{47.288017, -2.598860, 2.598860},{
      47.288017, -0.000000, 0.000000},{47.288017, -0.000000, 0.000000}}],
    Polygon[{{47.288017, -1.837671, 3.182940},{
      47.288017, -3.675342, 6.365880},{47.288017, -5.197719, 5.197719},{
      47.288017, -2.598860, 2.598860},{47.288017, -1.837671, 3.182940}}],
    Polygon[{{47.288017, -3.675342, 6.365880},{
      47.288017, -5.513013, 9.548820},{47.288017, -7.796578, 7.796578},{
      47.288017, -5.197719, 5.197719},{47.288017, -3.675342, 6.365880}}],
    Polygon[{{47.288017, -0.000000, 0.000000},{
      47.288017, -2.598860, 2.598860},{47.288017, -3.182940, 1.837671},{
      47.288017, -0.000000, 0.000000},{47.288017, -0.000000, 0.000000}}],
    Polygon[{{47.288017, -2.598860, 2.598860},{
      47.288017, -5.197719, 5.197719},{47.288017, -6.365880, 3.675342},{
      47.288017, -3.182940, 1.837671},{47.288017, -2.598860, 2.598860}}],
    Polygon[{{47.288017, -5.197719, 5.197719},{
      47.288017, -7.796578, 7.796578},{47.288017, -9.548820, 5.513013},{
      47.288017, -6.365880, 3.675342},{47.288017, -5.197719, 5.197719}}],
    Polygon[{{47.288017, -0.000000, 0.000000},{
      47.288017, -3.182940, 1.837671},{47.288017, -3.550108, 0.951249},{
      47.288017, -0.000000, 0.000000},{47.288017, -0.000000, 0.000000}}],
    Polygon[{{47.288017, -3.182940, 1.837671},{
      47.288017, -6.365880, 3.675342},{47.288017, -7.100216, 1.902497},{
      47.288017, -3.550108, 0.951249},{47.288017, -3.182940, 1.837671}}],
    Polygon[{{47.288017, -6.365880, 3.675342},{
      47.288017, -9.548820, 5.513013},{47.288017, -10.650324, 2.853746},{
      47.288017, -7.100216, 1.902497},{47.288017, -6.365880, 3.675342}}],
    Polygon[{{47.288017, -0.000000, 0.000000},{
      47.288017, -3.550108, 0.951249},{47.288017, -3.675342, 0.000000},{
      47.288017, -0.000000, 0.000000},{47.288017, -0.000000, 0.000000}}],
    Polygon[{{47.288017, -3.550108, 0.951249},{
      47.288017, -7.100216, 1.902497},{47.288017, -7.350685, 0.000000},{
      47.288017, -3.675342, 0.000000},{47.288017, -3.550108, 0.951249}}],
    Polygon[{{47.288017, -7.100216, 1.902497},{
      47.288017, -10.650324, 2.853746},{47.288017, -11.026027, 0.000000},{
      47.288017, -7.350685, 0.000000},{47.288017, -7.100216, 1.902497}}],
    Polygon[{{47.288017, -0.000000, 0.000000},{
      47.288017, -3.675342, 0.000000},{47.288017, -3.550108, -0.951249},{
      47.288017, -0.000000, -0.000000},{47.288017, -0.000000, 0.000000}}],
    Polygon[{{47.288017, -3.675342, 0.000000},{
      47.288017, -7.350685, 0.000000},{47.288017, -7.100216, -1.902497},{
      47.288017, -3.550108, -0.951249},{47.288017, -3.675342, 0.000000}}],
    Polygon[{{47.288017, -7.350685, 0.000000},{
      47.288017, -11.026027, 0.000000},{47.288017, -10.650324, -2.853746},{
      47.288017, -7.100216, -1.902497},{47.288017, -7.350685, 0.000000}}],
    Polygon[{{47.288017, -0.000000, -0.000000},{
      47.288017, -3.550108, -0.951249},{47.288017, -3.182940, -1.837671},{
      47.288017, -0.000000, -0.000000},{47.288017, -0.000000, -0.000000}}],
    Polygon[{{47.288017, -3.550108, -0.951249},{
      47.288017, -7.100216, -1.902497},{47.288017, -6.365880, -3.675342},{
      47.288017, -3.182940, -1.837671},{47.288017, -3.550108, -0.951249}}],
    Polygon[{{47.288017, -7.100216, -1.902497},{
      47.288017, -10.650324, -2.853746},{47.288017, -9.548820, -5.513013},{
      47.288017, -6.365880, -3.675342},{47.288017, -7.100216, -1.902497}}],
    Polygon[{{47.288017, -0.000000, -0.000000},{
      47.288017, -3.182940, -1.837671},{47.288017, -2.598860, -2.598860},{
      47.288017, -0.000000, -0.000000},{47.288017, -0.000000, -0.000000}}],
    Polygon[{{47.288017, -3.182940, -1.837671},{
      47.288017, -6.365880, -3.675342},{47.288017, -5.197719, -5.197719},{
      47.288017, -2.598860, -2.598860},{47.288017, -3.182940, -1.837671}}],
    Polygon[{{47.288017, -6.365880, -3.675342},{
      47.288017, -9.548820, -5.513013},{47.288017, -7.796578, -7.796578},{
      47.288017, -5.197719, -5.197719},{47.288017, -6.365880, -3.675342}}],
    Polygon[{{47.288017, -0.000000, -0.000000},{
      47.288017, -2.598860, -2.598860},{47.288017, -1.837671, -3.182940},{
      47.288017, -0.000000, -0.000000},{47.288017, -0.000000, -0.000000}}],
    Polygon[{{47.288017, -2.598860, -2.598860},{
      47.288017, -5.197719, -5.197719},{47.288017, -3.675342, -6.365880},{
      47.288017, -1.837671, -3.182940},{47.288017, -2.598860, -2.598860}}],
    Polygon[{{47.288017, -5.197719, -5.197719},{
      47.288017, -7.796578, -7.796578},{47.288017, -5.513013, -9.548820},{
      47.288017, -3.675342, -6.365880},{47.288017, -5.197719, -5.197719}}],
    Polygon[{{47.288017, -0.000000, -0.000000},{
      47.288017, -1.837671, -3.182940},{47.288017, -0.951249, -3.550108},{
      47.288017, -0.000000, -0.000000},{47.288017, -0.000000, -0.000000}}],
    Polygon[{{47.288017, -1.837671, -3.182940},{
      47.288017, -3.675342, -6.365880},{47.288017, -1.902497, -7.100216},{
      47.288017, -0.951249, -3.550108},{47.288017, -1.837671, -3.182940}}],
    Polygon[{{47.288017, -3.675342, -6.365880},{
      47.288017, -5.513013, -9.548820},{47.288017, -2.853746, -10.650324},{
      47.288017, -1.902497, -7.100216},{47.288017, -3.675342, -6.365880}}],
    Polygon[{{47.288017, -0.000000, -0.000000},{
      47.288017, -0.951249, -3.550108},{47.288017, -0.000000, -3.675342},{
      47.288017, -0.000000, -0.000000},{47.288017, -0.000000, -0.000000}}],
    Polygon[{{47.288017, -0.951249, -3.550108},{
      47.288017, -1.902497, -7.100216},{47.288017, -0.000000, -7.350685},{
      47.288017, -0.000000, -3.675342},{47.288017, -0.951249, -3.550108}}],
    Polygon[{{47.288017, -1.902497, -7.100216},{
      47.288017, -2.853746, -10.650324},{47.288017, -0.000000, -11.026027},{
      47.288017, -0.000000, -7.350685},{47.288017, -1.902497, -7.100216}}],
    Polygon[{{47.288017, -0.000000, -0.000000},{
      47.288017, -0.000000, -3.675342},{47.288017, 0.951249, -3.550108},{
      47.288017, 0.000000, -0.000000},{47.288017, -0.000000, -0.000000}}],
    Polygon[{{47.288017, -0.000000, -3.675342},{
      47.288017, -0.000000, -7.350685},{47.288017, 1.902497, -7.100216},{
      47.288017, 0.951249, -3.550108},{47.288017, -0.000000, -3.675342}}],
    Polygon[{{47.288017, -0.000000, -7.350685},{
      47.288017, -0.000000, -11.026027},{47.288017, 2.853746, -10.650324},{
      47.288017, 1.902497, -7.100216},{47.288017, -0.000000, -7.350685}}],
    Polygon[{{47.288017, 0.000000, -0.000000},{
      47.288017, 0.951249, -3.550108},{47.288017, 1.837671, -3.182940},{
      47.288017, 0.000000, -0.000000},{47.288017, 0.000000, -0.000000}}],
    Polygon[{{47.288017, 0.951249, -3.550108},{
      47.288017, 1.902497, -7.100216},{47.288017, 3.675342, -6.365880},{
      47.288017, 1.837671, -3.182940},{47.288017, 0.951249, -3.550108}}],
    Polygon[{{47.288017, 1.902497, -7.100216},{
      47.288017, 2.853746, -10.650324},{47.288017, 5.513013, -9.548820},{
      47.288017, 3.675342, -6.365880},{47.288017, 1.902497, -7.100216}}],
    Polygon[{{47.288017, 0.000000, -0.000000},{
      47.288017, 1.837671, -3.182940},{47.288017, 2.598860, -2.598860},{
      47.288017, 0.000000, -0.000000},{47.288017, 0.000000, -0.000000}}],
    Polygon[{{47.288017, 1.837671, -3.182940},{
      47.288017, 3.675342, -6.365880},{47.288017, 5.197719, -5.197719},{
      47.288017, 2.598860, -2.598860},{47.288017, 1.837671, -3.182940}}],
    Polygon[{{47.288017, 3.675342, -6.365880},{
      47.288017, 5.513013, -9.548820},{47.288017, 7.796578, -7.796578},{
      47.288017, 5.197719, -5.197719},{47.288017, 3.675342, -6.365880}}],
    Polygon[{{47.288017, 0.000000, -0.000000},{
      47.288017, 2.598860, -2.598860},{47.288017, 3.182940, -1.837671},{
      47.288017, 0.000000, -0.000000},{47.288017, 0.000000, -0.000000}}],
    Polygon[{{47.288017, 2.598860, -2.598860},{
      47.288017, 5.197719, -5.197719},{47.288017, 6.365880, -3.675342},{
      47.288017, 3.182940, -1.837671},{47.288017, 2.598860, -2.598860}}],
    Polygon[{{47.288017, 5.197719, -5.197719},{
      47.288017, 7.796578, -7.796578},{47.288017, 9.548820, -5.513013},{
      47.288017, 6.365880, -3.675342},{47.288017, 5.197719, -5.197719}}],
    Polygon[{{47.288017, 0.000000, -0.000000},{
      47.288017, 3.182940, -1.837671},{47.288017, 3.550108, -0.951249},{
      47.288017, 0.000000, -0.000000},{47.288017, 0.000000, -0.000000}}],
    Polygon[{{47.288017, 3.182940, -1.837671},{
      47.288017, 6.365880, -3.675342},{47.288017, 7.100216, -1.902497},{
      47.288017, 3.550108, -0.951249},{47.288017, 3.182940, -1.837671}}],
    Polygon[{{47.288017, 6.365880, -3.675342},{
      47.288017, 9.548820, -5.513013},{47.288017, 10.650324, -2.853746},{
      47.288017, 7.100216, -1.902497},{47.288017, 6.365880, -3.675342}}],
    Polygon[{{47.288017, 0.000000, -0.000000},{
      47.288017, 3.550108, -0.951249},{47.288017, 3.675342, -0.000000},{
      47.288017, 0.000000, -0.000000},{47.288017, 0.000000, -0.000000}}],
    Polygon[{{47.288017, 3.550108, -0.951249},{
      47.288017, 7.100216, -1.902497},{47.288017, 7.350685, -0.000000},{
      47.288017, 3.675342, -0.000000},{47.288017, 3.550108, -0.951249}}],
    Polygon[{{47.288017, 7.100216, -1.902497},{
      47.288017, 10.650324, -2.853746},{47.288017, 11.026027, -0.000000},{
      47.288017, 7.350685, -0.000000},{47.288017, 7.100216, -1.902497}}],
    Line[{{47.288017, 11.026027, 0.000000},{47.288017, 10.650324, 2.853746},{
      47.288017, 9.548820, 5.513013},{47.288017, 7.796578, 7.796578},{
      47.288017, 5.513013, 9.548820},{47.288017, 2.853746, 10.650324},{
      47.288017, 0.000000, 11.026027},{47.288017, -2.853746, 10.650324},{
      47.288017, -5.513013, 9.548820},{47.288017, -7.796578, 7.796578},{
      47.288017, -9.548820, 5.513013},{47.288017, -10.650324, 2.853746},{
      47.288017, -11.026027, 0.000000},{47.288017, -10.650324, -2.853746},{
      47.288017, -9.548820, -5.513013},{47.288017, -7.796578, -7.796578},{
      47.288017, -5.513013, -9.548820},{47.288017, -2.853746, -10.650324},{
      47.288017, -0.000000, -11.026027},{47.288017, 2.853746, -10.650324},{
      47.288017, 5.513013, -9.548820},{47.288017, 7.796578, -7.796578},{
      47.288017, 9.548820, -5.513013},{47.288017, 10.650324, -2.853746},{
      47.288017, 11.026027, -0.000000}}],
    Polygon[{{52.229683, 0.000000, 0.000000},{51.949047, 3.675342, 0.000000},{
      51.949047, 3.550108, 0.951249},{52.229683, 0.000000, 0.000000},{
      52.229683, 0.000000, 0.000000}}],
    Polygon[{{51.949047, 3.675342, 0.000000},{51.086651, 7.350685, 0.000000},{
      51.086651, 7.100216, 1.902497},{51.949047, 3.550108, 0.951249},{
      51.949047, 3.675342, 0.000000}}],
    Polygon[{{51.086651, 7.350685, 0.000000},{
      49.572773, 11.026027, 0.000000},{49.572773, 10.650324, 2.853746},{
      51.086651, 7.100216, 1.902497},{51.086651, 7.350685, 0.000000}}],
    Polygon[{{52.229683, 0.000000, 0.000000},{51.949047, 3.550108, 0.951249},{
      51.949047, 3.182940, 1.837671},{52.229683, 0.000000, 0.000000},{
      52.229683, 0.000000, 0.000000}}],
    Polygon[{{51.949047, 3.550108, 0.951249},{51.086651, 7.100216, 1.902497},{
      51.086651, 6.365880, 3.675342},{51.949047, 3.182940, 1.837671},{
      51.949047, 3.550108, 0.951249}}],
    Polygon[{{51.086651, 7.100216, 1.902497},{
      49.572773, 10.650324, 2.853746},{49.572773, 9.548820, 5.513013},{
      51.086651, 6.365880, 3.675342},{51.086651, 7.100216, 1.902497}}],
    Polygon[{{52.229683, 0.000000, 0.000000},{51.949047, 3.182940, 1.837671},{
      51.949047, 2.598860, 2.598860},{52.229683, 0.000000, 0.000000},{
      52.229683, 0.000000, 0.000000}}],
    Polygon[{{51.949047, 3.182940, 1.837671},{51.086651, 6.365880, 3.675342},{
      51.086651, 5.197719, 5.197719},{51.949047, 2.598860, 2.598860},{
      51.949047, 3.182940, 1.837671}}],
    Polygon[{{51.086651, 6.365880, 3.675342},{49.572773, 9.548820, 5.513013},{
      49.572773, 7.796578, 7.796578},{51.086651, 5.197719, 5.197719},{
      51.086651, 6.365880, 3.675342}}],
    Polygon[{{52.229683, 0.000000, 0.000000},{51.949047, 2.598860, 2.598860},{
      51.949047, 1.837671, 3.182940},{52.229683, 0.000000, 0.000000},{
      52.229683, 0.000000, 0.000000}}],
    Polygon[{{51.949047, 2.598860, 2.598860},{51.086651, 5.197719, 5.197719},{
      51.086651, 3.675342, 6.365880},{51.949047, 1.837671, 3.182940},{
      51.949047, 2.598860, 2.598860}}],
    Polygon[{{51.086651, 5.197719, 5.197719},{49.572773, 7.796578, 7.796578},{
      49.572773, 5.513013, 9.548820},{51.086651, 3.675342, 6.365880},{
      51.086651, 5.197719, 5.197719}}],
    Polygon[{{52.229683, 0.000000, 0.000000},{51.949047, 1.837671, 3.182940},{
      51.949047, 0.951249, 3.550108},{52.229683, 0.000000, 0.000000},{
      52.229683, 0.000000, 0.000000}}],
    Polygon[{{51.949047, 1.837671, 3.182940},{51.086651, 3.675342, 6.365880},{
      51.086651, 1.902497, 7.100216},{51.949047, 0.951249, 3.550108},{
      51.949047, 1.837671, 3.182940}}],
    Polygon[{{51.086651, 3.675342, 6.365880},{49.572773, 5.513013, 9.548820},{
      49.572773, 2.853746, 10.650324},{51.086651, 1.902497, 7.100216},{
      51.086651, 3.675342, 6.365880}}],
    Polygon[{{52.229683, 0.000000, 0.000000},{51.949047, 0.951249, 3.550108},{
      51.949047, 0.000000, 3.675342},{52.229683, 0.000000, 0.000000},{
      52.229683, 0.000000, 0.000000}}],
    Polygon[{{51.949047, 0.951249, 3.550108},{51.086651, 1.902497, 7.100216},{
      51.086651, 0.000000, 7.350685},{51.949047, 0.000000, 3.675342},{
      51.949047, 0.951249, 3.550108}}],
    Polygon[{{51.086651, 1.902497, 7.100216},{
      49.572773, 2.853746, 10.650324},{49.572773, 0.000000, 11.026027},{
      51.086651, 0.000000, 7.350685},{51.086651, 1.902497, 7.100216}}],
    Polygon[{{52.229683, 0.000000, 0.000000},{51.949047, 0.000000, 3.675342},{
      51.949047, -0.951249, 3.550108},{52.229683, -0.000000, 0.000000},{
      52.229683, 0.000000, 0.000000}}],
    Polygon[{{51.949047, 0.000000, 3.675342},{51.086651, 0.000000, 7.350685},{
      51.086651, -1.902497, 7.100216},{51.949047, -0.951249, 3.550108},{
      51.949047, 0.000000, 3.675342}}],
    Polygon[{{51.086651, 0.000000, 7.350685},{
      49.572773, 0.000000, 11.026027},{49.572773, -2.853746, 10.650324},{
      51.086651, -1.902497, 7.100216},{51.086651, 0.000000, 7.350685}}],
    Polygon[{{52.229683, -0.000000, 0.000000},{
      51.949047, -0.951249, 3.550108},{51.949047, -1.837671, 3.182940},{
      52.229683, -0.000000, 0.000000},{52.229683, -0.000000, 0.000000}}],
    Polygon[{{51.949047, -0.951249, 3.550108},{
      51.086651, -1.902497, 7.100216},{51.086651, -3.675342, 6.365880},{
      51.949047, -1.837671, 3.182940},{51.949047, -0.951249, 3.550108}}],
    Polygon[{{51.086651, -1.902497, 7.100216},{
      49.572773, -2.853746, 10.650324},{49.572773, -5.513013, 9.548820},{
      51.086651, -3.675342, 6.365880},{51.086651, -1.902497, 7.100216}}],
    Polygon[{{52.229683, -0.000000, 0.000000},{
      51.949047, -1.837671, 3.182940},{51.949047, -2.598860, 2.598860},{
      52.229683, -0.000000, 0.000000},{52.229683, -0.000000, 0.000000}}],
    Polygon[{{51.949047, -1.837671, 3.182940},{
      51.086651, -3.675342, 6.365880},{51.086651, -5.197719, 5.197719},{
      51.949047, -2.598860, 2.598860},{51.949047, -1.837671, 3.182940}}],
    Polygon[{{51.086651, -3.675342, 6.365880},{
      49.572773, -5.513013, 9.548820},{49.572773, -7.796578, 7.796578},{
      51.086651, -5.197719, 5.197719},{51.086651, -3.675342, 6.365880}}],
    Polygon[{{52.229683, -0.000000, 0.000000},{
      51.949047, -2.598860, 2.598860},{51.949047, -3.182940, 1.837671},{
      52.229683, -0.000000, 0.000000},{52.229683, -0.000000, 0.000000}}],
    Polygon[{{51.949047, -2.598860, 2.598860},{
      51.086651, -5.197719, 5.197719},{51.086651, -6.365880, 3.675342},{
      51.949047, -3.182940, 1.837671},{51.949047, -2.598860, 2.598860}}],
    Polygon[{{51.086651, -5.197719, 5.197719},{
      49.572773, -7.796578, 7.796578},{49.572773, -9.548820, 5.513013},{
      51.086651, -6.365880, 3.675342},{51.086651, -5.197719, 5.197719}}],
    Polygon[{{52.229683, -0.000000, 0.000000},{
      51.949047, -3.182940, 1.837671},{51.949047, -3.550108, 0.951249},{
      52.229683, -0.000000, 0.000000},{52.229683, -0.000000, 0.000000}}],
    Polygon[{{51.949047, -3.182940, 1.837671},{
      51.086651, -6.365880, 3.675342},{51.086651, -7.100216, 1.902497},{
      51.949047, -3.550108, 0.951249},{51.949047, -3.182940, 1.837671}}],
    Polygon[{{51.086651, -6.365880, 3.675342},{
      49.572773, -9.548820, 5.513013},{49.572773, -10.650324, 2.853746},{
      51.086651, -7.100216, 1.902497},{51.086651, -6.365880, 3.675342}}],
    Polygon[{{52.229683, -0.000000, 0.000000},{
      51.949047, -3.550108, 0.951249},{51.949047, -3.675342, 0.000000},{
      52.229683, -0.000000, 0.000000},{52.229683, -0.000000, 0.000000}}],
    Polygon[{{51.949047, -3.550108, 0.951249},{
      51.086651, -7.100216, 1.902497},{51.086651, -7.350685, 0.000000},{
      51.949047, -3.675342, 0.000000},{51.949047, -3.550108, 0.951249}}],
    Polygon[{{51.086651, -7.100216, 1.902497},{
      49.572773, -10.650324, 2.853746},{49.572773, -11.026027, 0.000000},{
      51.086651, -7.350685, 0.000000},{51.086651, -7.100216, 1.902497}}],
    Polygon[{{52.229683, -0.000000, 0.000000},{
      51.949047, -3.675342, 0.000000},{51.949047, -3.550108, -0.951249},{
      52.229683, -0.000000, -0.000000},{52.229683, -0.000000, 0.000000}}],
    Polygon[{{51.949047, -3.675342, 0.000000},{
      51.086651, -7.350685, 0.000000},{51.086651, -7.100216, -1.902497},{
      51.949047, -3.550108, -0.951249},{51.949047, -3.675342, 0.000000}}],
    Polygon[{{51.086651, -7.350685, 0.000000},{
      49.572773, -11.026027, 0.000000},{49.572773, -10.650324, -2.853746},{
      51.086651, -7.100216, -1.902497},{51.086651, -7.350685, 0.000000}}],
    Polygon[{{52.229683, -0.000000, -0.000000},{
      51.949047, -3.550108, -0.951249},{51.949047, -3.182940, -1.837671},{
      52.229683, -0.000000, -0.000000},{52.229683, -0.000000, -0.000000}}],
    Polygon[{{51.949047, -3.550108, -0.951249},{
      51.086651, -7.100216, -1.902497},{51.086651, -6.365880, -3.675342},{
      51.949047, -3.182940, -1.837671},{51.949047, -3.550108, -0.951249}}],
    Polygon[{{51.086651, -7.100216, -1.902497},{
      49.572773, -10.650324, -2.853746},{49.572773, -9.548820, -5.513013},{
      51.086651, -6.365880, -3.675342},{51.086651, -7.100216, -1.902497}}],
    Polygon[{{52.229683, -0.000000, -0.000000},{
      51.949047, -3.182940, -1.837671},{51.949047, -2.598860, -2.598860},{
      52.229683, -0.000000, -0.000000},{52.229683, -0.000000, -0.000000}}],
    Polygon[{{51.949047, -3.182940, -1.837671},{
      51.086651, -6.365880, -3.675342},{51.086651, -5.197719, -5.197719},{
      51.949047, -2.598860, -2.598860},{51.949047, -3.182940, -1.837671}}],
    Polygon[{{51.086651, -6.365880, -3.675342},{
      49.572773, -9.548820, -5.513013},{49.572773, -7.796578, -7.796578},{
      51.086651, -5.197719, -5.197719},{51.086651, -6.365880, -3.675342}}],
    Polygon[{{52.229683, -0.000000, -0.000000},{
      51.949047, -2.598860, -2.598860},{51.949047, -1.837671, -3.182940},{
      52.229683, -0.000000, -0.000000},{52.229683, -0.000000, -0.000000}}],
    Polygon[{{51.949047, -2.598860, -2.598860},{
      51.086651, -5.197719, -5.197719},{51.086651, -3.675342, -6.365880},{
      51.949047, -1.837671, -3.182940},{51.949047, -2.598860, -2.598860}}],
    Polygon[{{51.086651, -5.197719, -5.197719},{
      49.572773, -7.796578, -7.796578},{49.572773, -5.513013, -9.548820},{
      51.086651, -3.675342, -6.365880},{51.086651, -5.197719, -5.197719}}],
    Polygon[{{52.229683, -0.000000, -0.000000},{
      51.949047, -1.837671, -3.182940},{51.949047, -0.951249, -3.550108},{
      52.229683, -0.000000, -0.000000},{52.229683, -0.000000, -0.000000}}],
    Polygon[{{51.949047, -1.837671, -3.182940},{
      51.086651, -3.675342, -6.365880},{51.086651, -1.902497, -7.100216},{
      51.949047, -0.951249, -3.550108},{51.949047, -1.837671, -3.182940}}],
    Polygon[{{51.086651, -3.675342, -6.365880},{
      49.572773, -5.513013, -9.548820},{49.572773, -2.853746, -10.650324},{
      51.086651, -1.902497, -7.100216},{51.086651, -3.675342, -6.365880}}],
    Polygon[{{52.229683, -0.000000, -0.000000},{
      51.949047, -0.951249, -3.550108},{51.949047, -0.000000, -3.675342},{
      52.229683, -0.000000, -0.000000},{52.229683, -0.000000, -0.000000}}],
    Polygon[{{51.949047, -0.951249, -3.550108},{
      51.086651, -1.902497, -7.100216},{51.086651, -0.000000, -7.350685},{
      51.949047, -0.000000, -3.675342},{51.949047, -0.951249, -3.550108}}],
    Polygon[{{51.086651, -1.902497, -7.100216},{
      49.572773, -2.853746, -10.650324},{49.572773, -0.000000, -11.026027},{
      51.086651, -0.000000, -7.350685},{51.086651, -1.902497, -7.100216}}],
    Polygon[{{52.229683, -0.000000, -0.000000},{
      51.949047, -0.000000, -3.675342},{51.949047, 0.951249, -3.550108},{
      52.229683, 0.000000, -0.000000},{52.229683, -0.000000, -0.000000}}],
    Polygon[{{51.949047, -0.000000, -3.675342},{
      51.086651, -0.000000, -7.350685},{51.086651, 1.902497, -7.100216},{
      51.949047, 0.951249, -3.550108},{51.949047, -0.000000, -3.675342}}],
    Polygon[{{51.086651, -0.000000, -7.350685},{
      49.572773, -0.000000, -11.026027},{49.572773, 2.853746, -10.650324},{
      51.086651, 1.902497, -7.100216},{51.086651, -0.000000, -7.350685}}],
    Polygon[{{52.229683, 0.000000, -0.000000},{
      51.949047, 0.951249, -3.550108},{51.949047, 1.837671, -3.182940},{
      52.229683, 0.000000, -0.000000},{52.229683, 0.000000, -0.000000}}],
    Polygon[{{51.949047, 0.951249, -3.550108},{
      51.086651, 1.902497, -7.100216},{51.086651, 3.675342, -6.365880},{
      51.949047, 1.837671, -3.182940},{51.949047, 0.951249, -3.550108}}],
    Polygon[{{51.086651, 1.902497, -7.100216},{
      49.572773, 2.853746, -10.650324},{49.572773, 5.513013, -9.548820},{
      51.086651, 3.675342, -6.365880},{51.086651, 1.902497, -7.100216}}],
    Polygon[{{52.229683, 0.000000, -0.000000},{
      51.949047, 1.837671, -3.182940},{51.949047, 2.598860, -2.598860},{
      52.229683, 0.000000, -0.000000},{52.229683, 0.000000, -0.000000}}],
    Polygon[{{51.949047, 1.837671, -3.182940},{
      51.086651, 3.675342, -6.365880},{51.086651, 5.197719, -5.197719},{
      51.949047, 2.598860, -2.598860},{51.949047, 1.837671, -3.182940}}],
    Polygon[{{51.086651, 3.675342, -6.365880},{
      49.572773, 5.513013, -9.548820},{49.572773, 7.796578, -7.796578},{
      51.086651, 5.197719, -5.197719},{51.086651, 3.675342, -6.365880}}],
    Polygon[{{52.229683, 0.000000, -0.000000},{
      51.949047, 2.598860, -2.598860},{51.949047, 3.182940, -1.837671},{
      52.229683, 0.000000, -0.000000},{52.229683, 0.000000, -0.000000}}],
    Polygon[{{51.949047, 2.598860, -2.598860},{
      51.086651, 5.197719, -5.197719},{51.086651, 6.365880, -3.675342},{
      51.949047, 3.182940, -1.837671},{51.949047, 2.598860, -2.598860}}],
    Polygon[{{51.086651, 5.197719, -5.197719},{
      49.572773, 7.796578, -7.796578},{49.572773, 9.548820, -5.513013},{
      51.086651, 6.365880, -3.675342},{51.086651, 5.197719, -5.197719}}],
    Polygon[{{52.229683, 0.000000, -0.000000},{
      51.949047, 3.182940, -1.837671},{51.949047, 3.550108, -0.951249},{
      52.229683, 0.000000, -0.000000},{52.229683, 0.000000, -0.000000}}],
    Polygon[{{51.949047, 3.182940, -1.837671},{
      51.086651, 6.365880, -3.675342},{51.086651, 7.100216, -1.902497},{
      51.949047, 3.550108, -0.951249},{51.949047, 3.182940, -1.837671}}],
    Polygon[{{51.086651, 6.365880, -3.675342},{
      49.572773, 9.548820, -5.513013},{49.572773, 10.650324, -2.853746},{
      51.086651, 7.100216, -1.902497},{51.086651, 6.365880, -3.675342}}],
    Polygon[{{52.229683, 0.000000, -0.000000},{
      51.949047, 3.550108, -0.951249},{51.949047, 3.675342, -0.000000},{
      52.229683, 0.000000, -0.000000},{52.229683, 0.000000, -0.000000}}],
    Polygon[{{51.949047, 3.550108, -0.951249},{
      51.086651, 7.100216, -1.902497},{51.086651, 7.350685, -0.000000},{
      51.949047, 3.675342, -0.000000},{51.949047, 3.550108, -0.951249}}],
    Polygon[{{51.086651, 7.100216, -1.902497},{
      49.572773, 10.650324, -2.853746},{49.572773, 11.026027, -0.000000},{
      51.086651, 7.350685, -0.000000},{51.086651, 7.100216, -1.902497}}],
    Line[{{49.572773, 11.026027, 0.000000},{49.572773, 10.650324, 2.853746},{
      49.572773, 9.548820, 5.513013},{49.572773, 7.796578, 7.796578},{
      49.572773, 5.513013, 9.548820},{49.572773, 2.853746, 10.650324},{
      49.572773, 0.000000, 11.026027},{49.572773, -2.853746, 10.650324},{
      49.572773, -5.513013, 9.548820},{49.572773, -7.796578, 7.796578},{
      49.572773, -9.548820, 5.513013},{49.572773, -10.650324, 2.853746},{
      49.572773, -11.026027, 0.000000},{49.572773, -10.650324, -2.853746},{
      49.572773, -9.548820, -5.513013},{49.572773, -7.796578, -7.796578},{
      49.572773, -5.513013, -9.548820},{49.572773, -2.853746, -10.650324},{
      49.572773, -0.000000, -11.026027},{49.572773, 2.853746, -10.650324},{
      49.572773, 5.513013, -9.548820},{49.572773, 7.796578, -7.796578},{
      49.572773, 9.548820, -5.513013},{49.572773, 10.650324, -2.853746},{
      49.572773, 11.026027, -0.000000}}],
    Polygon[{{54.695503, 0.000000, 0.000000},{54.695503, 4.321868, 0.000000},{
      54.695503, 4.174604, 1.118582},{54.695503, 0.000000, 0.000000},{
      54.695503, 0.000000, 0.000000}}],
    Polygon[{{54.695503, 4.321868, 0.000000},{54.695503, 8.643737, 0.000000},{
      54.695503, 8.349209, 2.237164},{54.695503, 4.174604, 1.118582},{
      54.695503, 4.321868, 0.000000}}],
    Polygon[{{54.695503, 8.643737, 0.000000},{
      54.695503, 12.965605, 0.000000},{54.695503, 12.523813, 3.355746},{
      54.695503, 8.349209, 2.237164},{54.695503, 8.643737, 0.000000}}],
    Polygon[{{54.695503, 0.000000, 0.000000},{54.695503, 4.174604, 1.118582},{
      54.695503, 3.742848, 2.160934},{54.695503, 0.000000, 0.000000},{
      54.695503, 0.000000, 0.000000}}],
    Polygon[{{54.695503, 4.174604, 1.118582},{54.695503, 8.349209, 2.237164},{
      54.695503, 7.485696, 4.321868},{54.695503, 3.742848, 2.160934},{
      54.695503, 4.174604, 1.118582}}],
    Polygon[{{54.695503, 8.349209, 2.237164},{
      54.695503, 12.523813, 3.355746},{54.695503, 11.228543, 6.482802},{
      54.695503, 7.485696, 4.321868},{54.695503, 8.349209, 2.237164}}],
    Polygon[{{54.695503, 0.000000, 0.000000},{54.695503, 3.742848, 2.160934},{
      54.695503, 3.056022, 3.056022},{54.695503, 0.000000, 0.000000},{
      54.695503, 0.000000, 0.000000}}],
    Polygon[{{54.695503, 3.742848, 2.160934},{54.695503, 7.485696, 4.321868},{
      54.695503, 6.112045, 6.112045},{54.695503, 3.056022, 3.056022},{
      54.695503, 3.742848, 2.160934}}],
    Polygon[{{54.695503, 7.485696, 4.321868},{
      54.695503, 11.228543, 6.482802},{54.695503, 9.168067, 9.168067},{
      54.695503, 6.112045, 6.112045},{54.695503, 7.485696, 4.321868}}],
    Polygon[{{54.695503, 0.000000, 0.000000},{54.695503, 3.056022, 3.056022},{
      54.695503, 2.160934, 3.742848},{54.695503, 0.000000, 0.000000},{
      54.695503, 0.000000, 0.000000}}],
    Polygon[{{54.695503, 3.056022, 3.056022},{54.695503, 6.112045, 6.112045},{
      54.695503, 4.321868, 7.485696},{54.695503, 2.160934, 3.742848},{
      54.695503, 3.056022, 3.056022}}],
    Polygon[{{54.695503, 6.112045, 6.112045},{54.695503, 9.168067, 9.168067},{
      54.695503, 6.482802, 11.228543},{54.695503, 4.321868, 7.485696},{
      54.695503, 6.112045, 6.112045}}],
    Polygon[{{54.695503, 0.000000, 0.000000},{54.695503, 2.160934, 3.742848},{
      54.695503, 1.118582, 4.174604},{54.695503, 0.000000, 0.000000},{
      54.695503, 0.000000, 0.000000}}],
    Polygon[{{54.695503, 2.160934, 3.742848},{54.695503, 4.321868, 7.485696},{
      54.695503, 2.237164, 8.349209},{54.695503, 1.118582, 4.174604},{
      54.695503, 2.160934, 3.742848}}],
    Polygon[{{54.695503, 4.321868, 7.485696},{
      54.695503, 6.482802, 11.228543},{54.695503, 3.355746, 12.523813},{
      54.695503, 2.237164, 8.349209},{54.695503, 4.321868, 7.485696}}],
    Polygon[{{54.695503, 0.000000, 0.000000},{54.695503, 1.118582, 4.174604},{
      54.695503, 0.000000, 4.321868},{54.695503, 0.000000, 0.000000},{
      54.695503, 0.000000, 0.000000}}],
    Polygon[{{54.695503, 1.118582, 4.174604},{54.695503, 2.237164, 8.349209},{
      54.695503, 0.000000, 8.643737},{54.695503, 0.000000, 4.321868},{
      54.695503, 1.118582, 4.174604}}],
    Polygon[{{54.695503, 2.237164, 8.349209},{
      54.695503, 3.355746, 12.523813},{54.695503, 0.000000, 12.965605},{
      54.695503, 0.000000, 8.643737},{54.695503, 2.237164, 8.349209}}],
    Polygon[{{54.695503, 0.000000, 0.000000},{54.695503, 0.000000, 4.321868},{
      54.695503, -1.118582, 4.174604},{54.695503, -0.000000, 0.000000},{
      54.695503, 0.000000, 0.000000}}],
    Polygon[{{54.695503, 0.000000, 4.321868},{54.695503, 0.000000, 8.643737},{
      54.695503, -2.237164, 8.349209},{54.695503, -1.118582, 4.174604},{
      54.695503, 0.000000, 4.321868}}],
    Polygon[{{54.695503, 0.000000, 8.643737},{
      54.695503, 0.000000, 12.965605},{54.695503, -3.355746, 12.523813},{
      54.695503, -2.237164, 8.349209},{54.695503, 0.000000, 8.643737}}],
    Polygon[{{54.695503, -0.000000, 0.000000},{
      54.695503, -1.118582, 4.174604},{54.695503, -2.160934, 3.742848},{
      54.695503, -0.000000, 0.000000},{54.695503, -0.000000, 0.000000}}],
    Polygon[{{54.695503, -1.118582, 4.174604},{
      54.695503, -2.237164, 8.349209},{54.695503, -4.321868, 7.485696},{
      54.695503, -2.160934, 3.742848},{54.695503, -1.118582, 4.174604}}],
    Polygon[{{54.695503, -2.237164, 8.349209},{
      54.695503, -3.355746, 12.523813},{54.695503, -6.482802, 11.228543},{
      54.695503, -4.321868, 7.485696},{54.695503, -2.237164, 8.349209}}],
    Polygon[{{54.695503, -0.000000, 0.000000},{
      54.695503, -2.160934, 3.742848},{54.695503, -3.056022, 3.056022},{
      54.695503, -0.000000, 0.000000},{54.695503, -0.000000, 0.000000}}],
    Polygon[{{54.695503, -2.160934, 3.742848},{
      54.695503, -4.321868, 7.485696},{54.695503, -6.112045, 6.112045},{
      54.695503, -3.056022, 3.056022},{54.695503, -2.160934, 3.742848}}],
    Polygon[{{54.695503, -4.321868, 7.485696},{
      54.695503, -6.482802, 11.228543},{54.695503, -9.168067, 9.168067},{
      54.695503, -6.112045, 6.112045},{54.695503, -4.321868, 7.485696}}],
    Polygon[{{54.695503, -0.000000, 0.000000},{
      54.695503, -3.056022, 3.056022},{54.695503, -3.742848, 2.160934},{
      54.695503, -0.000000, 0.000000},{54.695503, -0.000000, 0.000000}}],
    Polygon[{{54.695503, -3.056022, 3.056022},{
      54.695503, -6.112045, 6.112045},{54.695503, -7.485696, 4.321868},{
      54.695503, -3.742848, 2.160934},{54.695503, -3.056022, 3.056022}}],
    Polygon[{{54.695503, -6.112045, 6.112045},{
      54.695503, -9.168067, 9.168067},{54.695503, -11.228543, 6.482802},{
      54.695503, -7.485696, 4.321868},{54.695503, -6.112045, 6.112045}}],
    Polygon[{{54.695503, -0.000000, 0.000000},{
      54.695503, -3.742848, 2.160934},{54.695503, -4.174604, 1.118582},{
      54.695503, -0.000000, 0.000000},{54.695503, -0.000000, 0.000000}}],
    Polygon[{{54.695503, -3.742848, 2.160934},{
      54.695503, -7.485696, 4.321868},{54.695503, -8.349209, 2.237164},{
      54.695503, -4.174604, 1.118582},{54.695503, -3.742848, 2.160934}}],
    Polygon[{{54.695503, -7.485696, 4.321868},{
      54.695503, -11.228543, 6.482802},{54.695503, -12.523813, 3.355746},{
      54.695503, -8.349209, 2.237164},{54.695503, -7.485696, 4.321868}}],
    Polygon[{{54.695503, -0.000000, 0.000000},{
      54.695503, -4.174604, 1.118582},{54.695503, -4.321868, 0.000000},{
      54.695503, -0.000000, 0.000000},{54.695503, -0.000000, 0.000000}}],
    Polygon[{{54.695503, -4.174604, 1.118582},{
      54.695503, -8.349209, 2.237164},{54.695503, -8.643737, 0.000000},{
      54.695503, -4.321868, 0.000000},{54.695503, -4.174604, 1.118582}}],
    Polygon[{{54.695503, -8.349209, 2.237164},{
      54.695503, -12.523813, 3.355746},{54.695503, -12.965605, 0.000000},{
      54.695503, -8.643737, 0.000000},{54.695503, -8.349209, 2.237164}}],
    Polygon[{{54.695503, -0.000000, 0.000000},{
      54.695503, -4.321868, 0.000000},{54.695503, -4.174604, -1.118582},{
      54.695503, -0.000000, -0.000000},{54.695503, -0.000000, 0.000000}}],
    Polygon[{{54.695503, -4.321868, 0.000000},{
      54.695503, -8.643737, 0.000000},{54.695503, -8.349209, -2.237164},{
      54.695503, -4.174604, -1.118582},{54.695503, -4.321868, 0.000000}}],
    Polygon[{{54.695503, -8.643737, 0.000000},{
      54.695503, -12.965605, 0.000000},{54.695503, -12.523813, -3.355746},{
      54.695503, -8.349209, -2.237164},{54.695503, -8.643737, 0.000000}}],
    Polygon[{{54.695503, -0.000000, -0.000000},{
      54.695503, -4.174604, -1.118582},{54.695503, -3.742848, -2.160934},{
      54.695503, -0.000000, -0.000000},{54.695503, -0.000000, -0.000000}}],
    Polygon[{{54.695503, -4.174604, -1.118582},{
      54.695503, -8.349209, -2.237164},{54.695503, -7.485696, -4.321868},{
      54.695503, -3.742848, -2.160934},{54.695503, -4.174604, -1.118582}}],
    Polygon[{{54.695503, -8.349209, -2.237164},{
      54.695503, -12.523813, -3.355746},{54.695503, -11.228543, -6.482802},{
      54.695503, -7.485696, -4.321868},{54.695503, -8.349209, -2.237164}}],
    Polygon[{{54.695503, -0.000000, -0.000000},{
      54.695503, -3.742848, -2.160934},{54.695503, -3.056022, -3.056022},{
      54.695503, -0.000000, -0.000000},{54.695503, -0.000000, -0.000000}}],
    Polygon[{{54.695503, -3.742848, -2.160934},{
      54.695503, -7.485696, -4.321868},{54.695503, -6.112045, -6.112045},{
      54.695503, -3.056022, -3.056022},{54.695503, -3.742848, -2.160934}}],
    Polygon[{{54.695503, -7.485696, -4.321868},{
      54.695503, -11.228543, -6.482802},{54.695503, -9.168067, -9.168067},{
      54.695503, -6.112045, -6.112045},{54.695503, -7.485696, -4.321868}}],
    Polygon[{{54.695503, -0.000000, -0.000000},{
      54.695503, -3.056022, -3.056022},{54.695503, -2.160934, -3.742848},{
      54.695503, -0.000000, -0.000000},{54.695503, -0.000000, -0.000000}}],
    Polygon[{{54.695503, -3.056022, -3.056022},{
      54.695503, -6.112045, -6.112045},{54.695503, -4.321868, -7.485696},{
      54.695503, -2.160934, -3.742848},{54.695503, -3.056022, -3.056022}}],
    Polygon[{{54.695503, -6.112045, -6.112045},{
      54.695503, -9.168067, -9.168067},{54.695503, -6.482802, -11.228543},{
      54.695503, -4.321868, -7.485696},{54.695503, -6.112045, -6.112045}}],
    Polygon[{{54.695503, -0.000000, -0.000000},{
      54.695503, -2.160934, -3.742848},{54.695503, -1.118582, -4.174604},{
      54.695503, -0.000000, -0.000000},{54.695503, -0.000000, -0.000000}}],
    Polygon[{{54.695503, -2.160934, -3.742848},{
      54.695503, -4.321868, -7.485696},{54.695503, -2.237164, -8.349209},{
      54.695503, -1.118582, -4.174604},{54.695503, -2.160934, -3.742848}}],
    Polygon[{{54.695503, -4.321868, -7.485696},{
      54.695503, -6.482802, -11.228543},{54.695503, -3.355746, -12.523813},{
      54.695503, -2.237164, -8.349209},{54.695503, -4.321868, -7.485696}}],
    Polygon[{{54.695503, -0.000000, -0.000000},{
      54.695503, -1.118582, -4.174604},{54.695503, -0.000000, -4.321868},{
      54.695503, -0.000000, -0.000000},{54.695503, -0.000000, -0.000000}}],
    Polygon[{{54.695503, -1.118582, -4.174604},{
      54.695503, -2.237164, -8.349209},{54.695503, -0.000000, -8.643737},{
      54.695503, -0.000000, -4.321868},{54.695503, -1.118582, -4.174604}}],
    Polygon[{{54.695503, -2.237164, -8.349209},{
      54.695503, -3.355746, -12.523813},{54.695503, -0.000000, -12.965605},{
      54.695503, -0.000000, -8.643737},{54.695503, -2.237164, -8.349209}}],
    Polygon[{{54.695503, -0.000000, -0.000000},{
      54.695503, -0.000000, -4.321868},{54.695503, 1.118582, -4.174604},{
      54.695503, 0.000000, -0.000000},{54.695503, -0.000000, -0.000000}}],
    Polygon[{{54.695503, -0.000000, -4.321868},{
      54.695503, -0.000000, -8.643737},{54.695503, 2.237164, -8.349209},{
      54.695503, 1.118582, -4.174604},{54.695503, -0.000000, -4.321868}}],
    Polygon[{{54.695503, -0.000000, -8.643737},{
      54.695503, -0.000000, -12.965605},{54.695503, 3.355746, -12.523813},{
      54.695503, 2.237164, -8.349209},{54.695503, -0.000000, -8.643737}}],
    Polygon[{{54.695503, 0.000000, -0.000000},{
      54.695503, 1.118582, -4.174604},{54.695503, 2.160934, -3.742848},{
      54.695503, 0.000000, -0.000000},{54.695503, 0.000000, -0.000000}}],
    Polygon[{{54.695503, 1.118582, -4.174604},{
      54.695503, 2.237164, -8.349209},{54.695503, 4.321868, -7.485696},{
      54.695503, 2.160934, -3.742848},{54.695503, 1.118582, -4.174604}}],
    Polygon[{{54.695503, 2.237164, -8.349209},{
      54.695503, 3.355746, -12.523813},{54.695503, 6.482802, -11.228543},{
      54.695503, 4.321868, -7.485696},{54.695503, 2.237164, -8.349209}}],
    Polygon[{{54.695503, 0.000000, -0.000000},{
      54.695503, 2.160934, -3.742848},{54.695503, 3.056022, -3.056022},{
      54.695503, 0.000000, -0.000000},{54.695503, 0.000000, -0.000000}}],
    Polygon[{{54.695503, 2.160934, -3.742848},{
      54.695503, 4.321868, -7.485696},{54.695503, 6.112045, -6.112045},{
      54.695503, 3.056022, -3.056022},{54.695503, 2.160934, -3.742848}}],
    Polygon[{{54.695503, 4.321868, -7.485696},{
      54.695503, 6.482802, -11.228543},{54.695503, 9.168067, -9.168067},{
      54.695503, 6.112045, -6.112045},{54.695503, 4.321868, -7.485696}}],
    Polygon[{{54.695503, 0.000000, -0.000000},{
      54.695503, 3.056022, -3.056022},{54.695503, 3.742848, -2.160934},{
      54.695503, 0.000000, -0.000000},{54.695503, 0.000000, -0.000000}}],
    Polygon[{{54.695503, 3.056022, -3.056022},{
      54.695503, 6.112045, -6.112045},{54.695503, 7.485696, -4.321868},{
      54.695503, 3.742848, -2.160934},{54.695503, 3.056022, -3.056022}}],
    Polygon[{{54.695503, 6.112045, -6.112045},{
      54.695503, 9.168067, -9.168067},{54.695503, 11.228543, -6.482802},{
      54.695503, 7.485696, -4.321868},{54.695503, 6.112045, -6.112045}}],
    Polygon[{{54.695503, 0.000000, -0.000000},{
      54.695503, 3.742848, -2.160934},{54.695503, 4.174604, -1.118582},{
      54.695503, 0.000000, -0.000000},{54.695503, 0.000000, -0.000000}}],
    Polygon[{{54.695503, 3.742848, -2.160934},{
      54.695503, 7.485696, -4.321868},{54.695503, 8.349209, -2.237164},{
      54.695503, 4.174604, -1.118582},{54.695503, 3.742848, -2.160934}}],
    Polygon[{{54.695503, 7.485696, -4.321868},{
      54.695503, 11.228543, -6.482802},{54.695503, 12.523813, -3.355746},{
      54.695503, 8.349209, -2.237164},{54.695503, 7.485696, -4.321868}}],
    Polygon[{{54.695503, 0.000000, -0.000000},{
      54.695503, 4.174604, -1.118582},{54.695503, 4.321868, -0.000000},{
      54.695503, 0.000000, -0.000000},{54.695503, 0.000000, -0.000000}}],
    Polygon[{{54.695503, 4.174604, -1.118582},{
      54.695503, 8.349209, -2.237164},{54.695503, 8.643737, -0.000000},{
      54.695503, 4.321868, -0.000000},{54.695503, 4.174604, -1.118582}}],
    Polygon[{{54.695503, 8.349209, -2.237164},{
      54.695503, 12.523813, -3.355746},{54.695503, 12.965605, -0.000000},{
      54.695503, 8.643737, -0.000000},{54.695503, 8.349209, -2.237164}}],
    Line[{{54.695503, 13.030759, 0.000000},{54.695503, 12.586746, 3.372609},{
      54.695503, 11.284968, 6.515379},{54.695503, 9.214138, 9.214138},{
      54.695503, 6.515379, 11.284968},{54.695503, 3.372609, 12.586746},{
      54.695503, 0.000000, 13.030759},{54.695503, -3.372609, 12.586746},{
      54.695503, -6.515379, 11.284968},{54.695503, -9.214138, 9.214138},{
      54.695503, -11.284968, 6.515379},{54.695503, -12.586746, 3.372609},{
      54.695503, -13.030759, 0.000000},{54.695503, -12.586746, -3.372609},{
      54.695503, -11.284968, -6.515379},{54.695503, -9.214138, -9.214138},{
      54.695503, -6.515379, -11.284968},{54.695503, -3.372609, -12.586746},{
      54.695503, -0.000000, -13.030759},{54.695503, 3.372609, -12.586746},{
      54.695503, 6.515379, -11.284968},{54.695503, 9.214138, -9.214138},{
      54.695503, 11.284968, -6.515379},{54.695503, 12.586746, -3.372609},{
      54.695503, 13.030759, -0.000000}}],
    Polygon[{{47.288017, 11.026027, 0.000000},{
      49.572773, 11.026027, 0.000000},{49.572773, 10.650324, 2.853746},{
      47.288017, 10.650324, 2.853746},{47.288017, 11.026027, 0.000000}}],
    Polygon[{{47.288017, 10.650324, 2.853746},{
      49.572773, 10.650324, 2.853746},{49.572773, 9.548820, 5.513013},{
      47.288017, 9.548820, 5.513013},{47.288017, 10.650324, 2.853746}}],
    Polygon[{{47.288017, 9.548820, 5.513013},{49.572773, 9.548820, 5.513013},{
      49.572773, 7.796578, 7.796578},{47.288017, 7.796578, 7.796578},{
      47.288017, 9.548820, 5.513013}}],
    Polygon[{{47.288017, 7.796578, 7.796578},{49.572773, 7.796578, 7.796578},{
      49.572773, 5.513013, 9.548820},{47.288017, 5.513013, 9.548820},{
      47.288017, 7.796578, 7.796578}}],
    Polygon[{{47.288017, 5.513013, 9.548820},{49.572773, 5.513013, 9.548820},{
      49.572773, 2.853746, 10.650324},{47.288017, 2.853746, 10.650324},{
      47.288017, 5.513013, 9.548820}}],
    Polygon[{{47.288017, 2.853746, 10.650324},{
      49.572773, 2.853746, 10.650324},{49.572773, 0.000000, 11.026027},{
      47.288017, 0.000000, 11.026027},{47.288017, 2.853746, 10.650324}}],
    Polygon[{{47.288017, 0.000000, 11.026027},{
      49.572773, 0.000000, 11.026027},{49.572773, -2.853746, 10.650324},{
      47.288017, -2.853746, 10.650324},{47.288017, 0.000000, 11.026027}}],
    Polygon[{{47.288017, -2.853746, 10.650324},{
      49.572773, -2.853746, 10.650324},{49.572773, -5.513013, 9.548820},{
      47.288017, -5.513013, 9.548820},{47.288017, -2.853746, 10.650324}}],
    Polygon[{{47.288017, -5.513013, 9.548820},{
      49.572773, -5.513013, 9.548820},{49.572773, -7.796578, 7.796578},{
      47.288017, -7.796578, 7.796578},{47.288017, -5.513013, 9.548820}}],
    Polygon[{{47.288017, -7.796578, 7.796578},{
      49.572773, -7.796578, 7.796578},{49.572773, -9.548820, 5.513013},{
      47.288017, -9.548820, 5.513013},{47.288017, -7.796578, 7.796578}}],
    Polygon[{{47.288017, -9.548820, 5.513013},{
      49.572773, -9.548820, 5.513013},{49.572773, -10.650324, 2.853746},{
      47.288017, -10.650324, 2.853746},{47.288017, -9.548820, 5.513013}}],
    Polygon[{{47.288017, -10.650324, 2.853746},{
      49.572773, -10.650324, 2.853746},{49.572773, -11.026027, 0.000000},{
      47.288017, -11.026027, 0.000000},{47.288017, -10.650324, 2.853746}}],
    Polygon[{{47.288017, -11.026027, 0.000000},{
      49.572773, -11.026027, 0.000000},{49.572773, -10.650324, -2.853746},{
      47.288017, -10.650324, -2.853746},{47.288017, -11.026027, 0.000000}}],
    Polygon[{{47.288017, -10.650324, -2.853746},{
      49.572773, -10.650324, -2.853746},{49.572773, -9.548820, -5.513013},{
      47.288017, -9.548820, -5.513013},{47.288017, -10.650324, -2.853746}}],
    Polygon[{{47.288017, -9.548820, -5.513013},{
      49.572773, -9.548820, -5.513013},{49.572773, -7.796578, -7.796578},{
      47.288017, -7.796578, -7.796578},{47.288017, -9.548820, -5.513013}}],
    Polygon[{{47.288017, -7.796578, -7.796578},{
      49.572773, -7.796578, -7.796578},{49.572773, -5.513013, -9.548820},{
      47.288017, -5.513013, -9.548820},{47.288017, -7.796578, -7.796578}}],
    Polygon[{{47.288017, -5.513013, -9.548820},{
      49.572773, -5.513013, -9.548820},{49.572773, -2.853746, -10.650324},{
      47.288017, -2.853746, -10.650324},{47.288017, -5.513013, -9.548820}}],
    Polygon[{{47.288017, -2.853746, -10.650324},{
      49.572773, -2.853746, -10.650324},{49.572773, -0.000000, -11.026027},{
      47.288017, -0.000000, -11.026027},{47.288017, -2.853746, -10.650324}}],
    Polygon[{{47.288017, -0.000000, -11.026027},{
      49.572773, -0.000000, -11.026027},{49.572773, 2.853746, -10.650324},{
      47.288017, 2.853746, -10.650324},{47.288017, -0.000000, -11.026027}}],
    Polygon[{{47.288017, 2.853746, -10.650324},{
      49.572773, 2.853746, -10.650324},{49.572773, 5.513013, -9.548820},{
      47.288017, 5.513013, -9.548820},{47.288017, 2.853746, -10.650324}}],
    Polygon[{{47.288017, 5.513013, -9.548820},{
      49.572773, 5.513013, -9.548820},{49.572773, 7.796578, -7.796578},{
      47.288017, 7.796578, -7.796578},{47.288017, 5.513013, -9.548820}}],
    Polygon[{{47.288017, 7.796578, -7.796578},{
      49.572773, 7.796578, -7.796578},{49.572773, 9.548820, -5.513013},{
      47.288017, 9.548820, -5.513013},{47.288017, 7.796578, -7.796578}}],
    Polygon[{{47.288017, 9.548820, -5.513013},{
      49.572773, 9.548820, -5.513013},{49.572773, 10.650324, -2.853746},{
      47.288017, 10.650324, -2.853746},{47.288017, 9.548820, -5.513013}}],
    Polygon[{{47.288017, 10.650324, -2.853746},{
      49.572773, 10.650324, -2.853746},{49.572773, 11.026027, -0.000000},{
      47.288017, 11.026027, -0.000000},{47.288017, 10.650324, -2.853746}}],
    Polygon[{{49.572773, 11.026027, 0.000000},{
      54.695503, 13.030759, 0.000000},{54.695503, 12.586746, 3.372609},{
      49.572773, 10.650324, 2.853746},{49.572773, 11.026027, 0.000000}}],
    Polygon[{{49.572773, 10.650324, 2.853746},{
      54.695503, 12.586746, 3.372609},{54.695503, 11.284968, 6.515379},{
      49.572773, 9.548820, 5.513013},{49.572773, 10.650324, 2.853746}}],
    Polygon[{{49.572773, 9.548820, 5.513013},{
      54.695503, 11.284968, 6.515379},{54.695503, 9.214138, 9.214138},{
      49.572773, 7.796578, 7.796578},{49.572773, 9.548820, 5.513013}}],
    Polygon[{{49.572773, 7.796578, 7.796578},{54.695503, 9.214138, 9.214138},{
      54.695503, 6.515379, 11.284968},{49.572773, 5.513013, 9.548820},{
      49.572773, 7.796578, 7.796578}}],
    Polygon[{{49.572773, 5.513013, 9.548820},{
      54.695503, 6.515379, 11.284968},{54.695503, 3.372609, 12.586746},{
      49.572773, 2.853746, 10.650324},{49.572773, 5.513013, 9.548820}}],
    Polygon[{{49.572773, 2.853746, 10.650324},{
      54.695503, 3.372609, 12.586746},{54.695503, 0.000000, 13.030759},{
      49.572773, 0.000000, 11.026027},{49.572773, 2.853746, 10.650324}}],
    Polygon[{{49.572773, 0.000000, 11.026027},{
      54.695503, 0.000000, 13.030759},{54.695503, -3.372609, 12.586746},{
      49.572773, -2.853746, 10.650324},{49.572773, 0.000000, 11.026027}}],
    Polygon[{{49.572773, -2.853746, 10.650324},{
      54.695503, -3.372609, 12.586746},{54.695503, -6.515379, 11.284968},{
      49.572773, -5.513013, 9.548820},{49.572773, -2.853746, 10.650324}}],
    Polygon[{{49.572773, -5.513013, 9.548820},{
      54.695503, -6.515379, 11.284968},{54.695503, -9.214138, 9.214138},{
      49.572773, -7.796578, 7.796578},{49.572773, -5.513013, 9.548820}}],
    Polygon[{{49.572773, -7.796578, 7.796578},{
      54.695503, -9.214138, 9.214138},{54.695503, -11.284968, 6.515379},{
      49.572773, -9.548820, 5.513013},{49.572773, -7.796578, 7.796578}}],
    Polygon[{{49.572773, -9.548820, 5.513013},{
      54.695503, -11.284968, 6.515379},{54.695503, -12.586746, 3.372609},{
      49.572773, -10.650324, 2.853746},{49.572773, -9.548820, 5.513013}}],
    Polygon[{{49.572773, -10.650324, 2.853746},{
      54.695503, -12.586746, 3.372609},{54.695503, -13.030759, 0.000000},{
      49.572773, -11.026027, 0.000000},{49.572773, -10.650324, 2.853746}}],
    Polygon[{{49.572773, -11.026027, 0.000000},{
      54.695503, -13.030759, 0.000000},{54.695503, -12.586746, -3.372609},{
      49.572773, -10.650324, -2.853746},{49.572773, -11.026027, 0.000000}}],
    Polygon[{{49.572773, -10.650324, -2.853746},{
      54.695503, -12.586746, -3.372609},{54.695503, -11.284968, -6.515379},{
      49.572773, -9.548820, -5.513013},{49.572773, -10.650324, -2.853746}}],
    Polygon[{{49.572773, -9.548820, -5.513013},{
      54.695503, -11.284968, -6.515379},{54.695503, -9.214138, -9.214138},{
      49.572773, -7.796578, -7.796578},{49.572773, -9.548820, -5.513013}}],
    Polygon[{{49.572773, -7.796578, -7.796578},{
      54.695503, -9.214138, -9.214138},{54.695503, -6.515379, -11.284968},{
      49.572773, -5.513013, -9.548820},{49.572773, -7.796578, -7.796578}}],
    Polygon[{{49.572773, -5.513013, -9.548820},{
      54.695503, -6.515379, -11.284968},{54.695503, -3.372609, -12.586746},{
      49.572773, -2.853746, -10.650324},{49.572773, -5.513013, -9.548820}}],
    Polygon[{{49.572773, -2.853746, -10.650324},{
      54.695503, -3.372609, -12.586746},{54.695503, -0.000000, -13.030759},{
      49.572773, -0.000000, -11.026027},{49.572773, -2.853746, -10.650324}}],
    Polygon[{{49.572773, -0.000000, -11.026027},{
      54.695503, -0.000000, -13.030759},{54.695503, 3.372609, -12.586746},{
      49.572773, 2.853746, -10.650324},{49.572773, -0.000000, -11.026027}}],
    Polygon[{{49.572773, 2.853746, -10.650324},{
      54.695503, 3.372609, -12.586746},{54.695503, 6.515379, -11.284968},{
      49.572773, 5.513013, -9.548820},{49.572773, 2.853746, -10.650324}}],
    Polygon[{{49.572773, 5.513013, -9.548820},{
      54.695503, 6.515379, -11.284968},{54.695503, 9.214138, -9.214138},{
      49.572773, 7.796578, -7.796578},{49.572773, 5.513013, -9.548820}}],
    Polygon[{{49.572773, 7.796578, -7.796578},{
      54.695503, 9.214138, -9.214138},{54.695503, 11.284968, -6.515379},{
      49.572773, 9.548820, -5.513013},{49.572773, 7.796578, -7.796578}}],
    Polygon[{{49.572773, 9.548820, -5.513013},{
      54.695503, 11.284968, -6.515379},{54.695503, 12.586746, -3.372609},{
      49.572773, 10.650324, -2.853746},{49.572773, 9.548820, -5.513013}}],
    Polygon[{{49.572773, 10.650324, -2.853746},{
      54.695503, 12.586746, -3.372609},{54.695503, 13.030759, -0.000000},{
      49.572773, 11.026027, -0.000000},{49.572773, 10.650324, -2.853746}}],
    Polygon[{{61.281048, 0.000000, 0.000000},{60.730534, 4.510647, 0.000000},{
      60.730534, 4.356951, 1.167441},{61.281048, 0.000000, 0.000000},{
      61.281048, 0.000000, 0.000000}}],
    Polygon[{{60.730534, 4.510647, 0.000000},{58.968765, 9.021295, 0.000000},{
      58.968765, 8.713902, 2.334883},{60.730534, 4.356951, 1.167441},{
      60.730534, 4.510647, 0.000000}}],
    Polygon[{{58.968765, 9.021295, 0.000000},{
      55.511738, 13.531942, 0.000000},{55.511738, 13.070852, 3.502324},{
      58.968765, 8.713902, 2.334883},{58.968765, 9.021295, 0.000000}}],
    Polygon[{{61.281048, 0.000000, 0.000000},{60.730534, 4.356951, 1.167441},{
      60.730534, 3.906335, 2.255324},{61.281048, 0.000000, 0.000000},{
      61.281048, 0.000000, 0.000000}}],
    Polygon[{{60.730534, 4.356951, 1.167441},{58.968765, 8.713902, 2.334883},{
      58.968765, 7.812670, 4.510647},{60.730534, 3.906335, 2.255324},{
      60.730534, 4.356951, 1.167441}}],
    Polygon[{{58.968765, 8.713902, 2.334883},{
      55.511738, 13.070852, 3.502324},{55.511738, 11.719006, 6.765971},{
      58.968765, 7.812670, 4.510647},{58.968765, 8.713902, 2.334883}}],
    Polygon[{{61.281048, 0.000000, 0.000000},{60.730534, 3.906335, 2.255324},{
      60.730534, 3.189509, 3.189509},{61.281048, 0.000000, 0.000000},{
      61.281048, 0.000000, 0.000000}}],
    Polygon[{{60.730534, 3.906335, 2.255324},{58.968765, 7.812670, 4.510647},{
      58.968765, 6.379019, 6.379019},{60.730534, 3.189509, 3.189509},{
      60.730534, 3.906335, 2.255324}}],
    Polygon[{{58.968765, 7.812670, 4.510647},{
      55.511738, 11.719006, 6.765971},{55.511738, 9.568528, 9.568528},{
      58.968765, 6.379019, 6.379019},{58.968765, 7.812670, 4.510647}}],
    Polygon[{{61.281048, 0.000000, 0.000000},{60.730534, 3.189509, 3.189509},{
      60.730534, 2.255324, 3.906335},{61.281048, 0.000000, 0.000000},{
      61.281048, 0.000000, 0.000000}}],
    Polygon[{{60.730534, 3.189509, 3.189509},{58.968765, 6.379019, 6.379019},{
      58.968765, 4.510647, 7.812670},{60.730534, 2.255324, 3.906335},{
      60.730534, 3.189509, 3.189509}}],
    Polygon[{{58.968765, 6.379019, 6.379019},{55.511738, 9.568528, 9.568528},{
      55.511738, 6.765971, 11.719006},{58.968765, 4.510647, 7.812670},{
      58.968765, 6.379019, 6.379019}}],
    Polygon[{{61.281048, 0.000000, 0.000000},{60.730534, 2.255324, 3.906335},{
      60.730534, 1.167441, 4.356951},{61.281048, 0.000000, 0.000000},{
      61.281048, 0.000000, 0.000000}}],
    Polygon[{{60.730534, 2.255324, 3.906335},{58.968765, 4.510647, 7.812670},{
      58.968765, 2.334883, 8.713902},{60.730534, 1.167441, 4.356951},{
      60.730534, 2.255324, 3.906335}}],
    Polygon[{{58.968765, 4.510647, 7.812670},{
      55.511738, 6.765971, 11.719006},{55.511738, 3.502324, 13.070852},{
      58.968765, 2.334883, 8.713902},{58.968765, 4.510647, 7.812670}}],
    Polygon[{{61.281048, 0.000000, 0.000000},{60.730534, 1.167441, 4.356951},{
      60.730534, 0.000000, 4.510647},{61.281048, 0.000000, 0.000000},{
      61.281048, 0.000000, 0.000000}}],
    Polygon[{{60.730534, 1.167441, 4.356951},{58.968765, 2.334883, 8.713902},{
      58.968765, 0.000000, 9.021295},{60.730534, 0.000000, 4.510647},{
      60.730534, 1.167441, 4.356951}}],
    Polygon[{{58.968765, 2.334883, 8.713902},{
      55.511738, 3.502324, 13.070852},{55.511738, 0.000000, 13.531942},{
      58.968765, 0.000000, 9.021295},{58.968765, 2.334883, 8.713902}}],
    Polygon[{{61.281048, 0.000000, 0.000000},{60.730534, 0.000000, 4.510647},{
      60.730534, -1.167441, 4.356951},{61.281048, -0.000000, 0.000000},{
      61.281048, 0.000000, 0.000000}}],
    Polygon[{{60.730534, 0.000000, 4.510647},{58.968765, 0.000000, 9.021295},{
      58.968765, -2.334883, 8.713902},{60.730534, -1.167441, 4.356951},{
      60.730534, 0.000000, 4.510647}}],
    Polygon[{{58.968765, 0.000000, 9.021295},{
      55.511738, 0.000000, 13.531942},{55.511738, -3.502324, 13.070852},{
      58.968765, -2.334883, 8.713902},{58.968765, 0.000000, 9.021295}}],
    Polygon[{{61.281048, -0.000000, 0.000000},{
      60.730534, -1.167441, 4.356951},{60.730534, -2.255324, 3.906335},{
      61.281048, -0.000000, 0.000000},{61.281048, -0.000000, 0.000000}}],
    Polygon[{{60.730534, -1.167441, 4.356951},{
      58.968765, -2.334883, 8.713902},{58.968765, -4.510647, 7.812670},{
      60.730534, -2.255324, 3.906335},{60.730534, -1.167441, 4.356951}}],
    Polygon[{{58.968765, -2.334883, 8.713902},{
      55.511738, -3.502324, 13.070852},{55.511738, -6.765971, 11.719006},{
      58.968765, -4.510647, 7.812670},{58.968765, -2.334883, 8.713902}}],
    Polygon[{{61.281048, -0.000000, 0.000000},{
      60.730534, -2.255324, 3.906335},{60.730534, -3.189509, 3.189509},{
      61.281048, -0.000000, 0.000000},{61.281048, -0.000000, 0.000000}}],
    Polygon[{{60.730534, -2.255324, 3.906335},{
      58.968765, -4.510647, 7.812670},{58.968765, -6.379019, 6.379019},{
      60.730534, -3.189509, 3.189509},{60.730534, -2.255324, 3.906335}}],
    Polygon[{{58.968765, -4.510647, 7.812670},{
      55.511738, -6.765971, 11.719006},{55.511738, -9.568528, 9.568528},{
      58.968765, -6.379019, 6.379019},{58.968765, -4.510647, 7.812670}}],
    Polygon[{{61.281048, -0.000000, 0.000000},{
      60.730534, -3.189509, 3.189509},{60.730534, -3.906335, 2.255324},{
      61.281048, -0.000000, 0.000000},{61.281048, -0.000000, 0.000000}}],
    Polygon[{{60.730534, -3.189509, 3.189509},{
      58.968765, -6.379019, 6.379019},{58.968765, -7.812670, 4.510647},{
      60.730534, -3.906335, 2.255324},{60.730534, -3.189509, 3.189509}}],
    Polygon[{{58.968765, -6.379019, 6.379019},{
      55.511738, -9.568528, 9.568528},{55.511738, -11.719006, 6.765971},{
      58.968765, -7.812670, 4.510647},{58.968765, -6.379019, 6.379019}}],
    Polygon[{{61.281048, -0.000000, 0.000000},{
      60.730534, -3.906335, 2.255324},{60.730534, -4.356951, 1.167441},{
      61.281048, -0.000000, 0.000000},{61.281048, -0.000000, 0.000000}}],
    Polygon[{{60.730534, -3.906335, 2.255324},{
      58.968765, -7.812670, 4.510647},{58.968765, -8.713902, 2.334883},{
      60.730534, -4.356951, 1.167441},{60.730534, -3.906335, 2.255324}}],
    Polygon[{{58.968765, -7.812670, 4.510647},{
      55.511738, -11.719006, 6.765971},{55.511738, -13.070852, 3.502324},{
      58.968765, -8.713902, 2.334883},{58.968765, -7.812670, 4.510647}}],
    Polygon[{{61.281048, -0.000000, 0.000000},{
      60.730534, -4.356951, 1.167441},{60.730534, -4.510647, 0.000000},{
      61.281048, -0.000000, 0.000000},{61.281048, -0.000000, 0.000000}}],
    Polygon[{{60.730534, -4.356951, 1.167441},{
      58.968765, -8.713902, 2.334883},{58.968765, -9.021295, 0.000000},{
      60.730534, -4.510647, 0.000000},{60.730534, -4.356951, 1.167441}}],
    Polygon[{{58.968765, -8.713902, 2.334883},{
      55.511738, -13.070852, 3.502324},{55.511738, -13.531942, 0.000000},{
      58.968765, -9.021295, 0.000000},{58.968765, -8.713902, 2.334883}}],
    Polygon[{{61.281048, -0.000000, 0.000000},{
      60.730534, -4.510647, 0.000000},{60.730534, -4.356951, -1.167441},{
      61.281048, -0.000000, -0.000000},{61.281048, -0.000000, 0.000000}}],
    Polygon[{{60.730534, -4.510647, 0.000000},{
      58.968765, -9.021295, 0.000000},{58.968765, -8.713902, -2.334883},{
      60.730534, -4.356951, -1.167441},{60.730534, -4.510647, 0.000000}}],
    Polygon[{{58.968765, -9.021295, 0.000000},{
      55.511738, -13.531942, 0.000000},{55.511738, -13.070852, -3.502324},{
      58.968765, -8.713902, -2.334883},{58.968765, -9.021295, 0.000000}}],
    Polygon[{{61.281048, -0.000000, -0.000000},{
      60.730534, -4.356951, -1.167441},{60.730534, -3.906335, -2.255324},{
      61.281048, -0.000000, -0.000000},{61.281048, -0.000000, -0.000000}}],
    Polygon[{{60.730534, -4.356951, -1.167441},{
      58.968765, -8.713902, -2.334883},{58.968765, -7.812670, -4.510647},{
      60.730534, -3.906335, -2.255324},{60.730534, -4.356951, -1.167441}}],
    Polygon[{{58.968765, -8.713902, -2.334883},{
      55.511738, -13.070852, -3.502324},{55.511738, -11.719006, -6.765971},{
      58.968765, -7.812670, -4.510647},{58.968765, -8.713902, -2.334883}}],
    Polygon[{{61.281048, -0.000000, -0.000000},{
      60.730534, -3.906335, -2.255324},{60.730534, -3.189509, -3.189509},{
      61.281048, -0.000000, -0.000000},{61.281048, -0.000000, -0.000000}}],
    Polygon[{{60.730534, -3.906335, -2.255324},{
      58.968765, -7.812670, -4.510647},{58.968765, -6.379019, -6.379019},{
      60.730534, -3.189509, -3.189509},{60.730534, -3.906335, -2.255324}}],
    Polygon[{{58.968765, -7.812670, -4.510647},{
      55.511738, -11.719006, -6.765971},{55.511738, -9.568528, -9.568528},{
      58.968765, -6.379019, -6.379019},{58.968765, -7.812670, -4.510647}}],
    Polygon[{{61.281048, -0.000000, -0.000000},{
      60.730534, -3.189509, -3.189509},{60.730534, -2.255324, -3.906335},{
      61.281048, -0.000000, -0.000000},{61.281048, -0.000000, -0.000000}}],
    Polygon[{{60.730534, -3.189509, -3.189509},{
      58.968765, -6.379019, -6.379019},{58.968765, -4.510647, -7.812670},{
      60.730534, -2.255324, -3.906335},{60.730534, -3.189509, -3.189509}}],
    Polygon[{{58.968765, -6.379019, -6.379019},{
      55.511738, -9.568528, -9.568528},{55.511738, -6.765971, -11.719006},{
      58.968765, -4.510647, -7.812670},{58.968765, -6.379019, -6.379019}}],
    Polygon[{{61.281048, -0.000000, -0.000000},{
      60.730534, -2.255324, -3.906335},{60.730534, -1.167441, -4.356951},{
      61.281048, -0.000000, -0.000000},{61.281048, -0.000000, -0.000000}}],
    Polygon[{{60.730534, -2.255324, -3.906335},{
      58.968765, -4.510647, -7.812670},{58.968765, -2.334883, -8.713902},{
      60.730534, -1.167441, -4.356951},{60.730534, -2.255324, -3.906335}}],
    Polygon[{{58.968765, -4.510647, -7.812670},{
      55.511738, -6.765971, -11.719006},{55.511738, -3.502324, -13.070852},{
      58.968765, -2.334883, -8.713902},{58.968765, -4.510647, -7.812670}}],
    Polygon[{{61.281048, -0.000000, -0.000000},{
      60.730534, -1.167441, -4.356951},{60.730534, -0.000000, -4.510647},{
      61.281048, -0.000000, -0.000000},{61.281048, -0.000000, -0.000000}}],
    Polygon[{{60.730534, -1.167441, -4.356951},{
      58.968765, -2.334883, -8.713902},{58.968765, -0.000000, -9.021295},{
      60.730534, -0.000000, -4.510647},{60.730534, -1.167441, -4.356951}}],
    Polygon[{{58.968765, -2.334883, -8.713902},{
      55.511738, -3.502324, -13.070852},{55.511738, -0.000000, -13.531942},{
      58.968765, -0.000000, -9.021295},{58.968765, -2.334883, -8.713902}}],
    Polygon[{{61.281048, -0.000000, -0.000000},{
      60.730534, -0.000000, -4.510647},{60.730534, 1.167441, -4.356951},{
      61.281048, 0.000000, -0.000000},{61.281048, -0.000000, -0.000000}}],
    Polygon[{{60.730534, -0.000000, -4.510647},{
      58.968765, -0.000000, -9.021295},{58.968765, 2.334883, -8.713902},{
      60.730534, 1.167441, -4.356951},{60.730534, -0.000000, -4.510647}}],
    Polygon[{{58.968765, -0.000000, -9.021295},{
      55.511738, -0.000000, -13.531942},{55.511738, 3.502324, -13.070852},{
      58.968765, 2.334883, -8.713902},{58.968765, -0.000000, -9.021295}}],
    Polygon[{{61.281048, 0.000000, -0.000000},{
      60.730534, 1.167441, -4.356951},{60.730534, 2.255324, -3.906335},{
      61.281048, 0.000000, -0.000000},{61.281048, 0.000000, -0.000000}}],
    Polygon[{{60.730534, 1.167441, -4.356951},{
      58.968765, 2.334883, -8.713902},{58.968765, 4.510647, -7.812670},{
      60.730534, 2.255324, -3.906335},{60.730534, 1.167441, -4.356951}}],
    Polygon[{{58.968765, 2.334883, -8.713902},{
      55.511738, 3.502324, -13.070852},{55.511738, 6.765971, -11.719006},{
      58.968765, 4.510647, -7.812670},{58.968765, 2.334883, -8.713902}}],
    Polygon[{{61.281048, 0.000000, -0.000000},{
      60.730534, 2.255324, -3.906335},{60.730534, 3.189509, -3.189509},{
      61.281048, 0.000000, -0.000000},{61.281048, 0.000000, -0.000000}}],
    Polygon[{{60.730534, 2.255324, -3.906335},{
      58.968765, 4.510647, -7.812670},{58.968765, 6.379019, -6.379019},{
      60.730534, 3.189509, -3.189509},{60.730534, 2.255324, -3.906335}}],
    Polygon[{{58.968765, 4.510647, -7.812670},{
      55.511738, 6.765971, -11.719006},{55.511738, 9.568528, -9.568528},{
      58.968765, 6.379019, -6.379019},{58.968765, 4.510647, -7.812670}}],
    Polygon[{{61.281048, 0.000000, -0.000000},{
      60.730534, 3.189509, -3.189509},{60.730534, 3.906335, -2.255324},{
      61.281048, 0.000000, -0.000000},{61.281048, 0.000000, -0.000000}}],
    Polygon[{{60.730534, 3.189509, -3.189509},{
      58.968765, 6.379019, -6.379019},{58.968765, 7.812670, -4.510647},{
      60.730534, 3.906335, -2.255324},{60.730534, 3.189509, -3.189509}}],
    Polygon[{{58.968765, 6.379019, -6.379019},{
      55.511738, 9.568528, -9.568528},{55.511738, 11.719006, -6.765971},{
      58.968765, 7.812670, -4.510647},{58.968765, 6.379019, -6.379019}}],
    Polygon[{{61.281048, 0.000000, -0.000000},{
      60.730534, 3.906335, -2.255324},{60.730534, 4.356951, -1.167441},{
      61.281048, 0.000000, -0.000000},{61.281048, 0.000000, -0.000000}}],
    Polygon[{{60.730534, 3.906335, -2.255324},{
      58.968765, 7.812670, -4.510647},{58.968765, 8.713902, -2.334883},{
      60.730534, 4.356951, -1.167441},{60.730534, 3.906335, -2.255324}}],
    Polygon[{{58.968765, 7.812670, -4.510647},{
      55.511738, 11.719006, -6.765971},{55.511738, 13.070852, -3.502324},{
      58.968765, 8.713902, -2.334883},{58.968765, 7.812670, -4.510647}}],
    Polygon[{{61.281048, 0.000000, -0.000000},{
      60.730534, 4.356951, -1.167441},{60.730534, 4.510647, -0.000000},{
      61.281048, 0.000000, -0.000000},{61.281048, 0.000000, -0.000000}}],
    Polygon[{{60.730534, 4.356951, -1.167441},{
      58.968765, 8.713902, -2.334883},{58.968765, 9.021295, -0.000000},{
      60.730534, 4.510647, -0.000000},{60.730534, 4.356951, -1.167441}}],
    Polygon[{{58.968765, 8.713902, -2.334883},{
      55.511738, 13.070852, -3.502324},{55.511738, 13.531942, -0.000000},{
      58.968765, 9.021295, -0.000000},{58.968765, 8.713902, -2.334883}}],
    Line[{{55.511738, 13.531942, 0.000000},{55.511738, 13.070852, 3.502324},{
      55.511738, 11.719006, 6.765971},{55.511738, 9.568528, 9.568528},{
      55.511738, 6.765971, 11.719006},{55.511738, 3.502324, 13.070852},{
      55.511738, 0.000000, 13.531942},{55.511738, -3.502324, 13.070852},{
      55.511738, -6.765971, 11.719006},{55.511738, -9.568528, 9.568528},{
      55.511738, -11.719006, 6.765971},{55.511738, -13.070852, 3.502324},{
      55.511738, -13.531942, 0.000000},{55.511738, -13.070852, -3.502324},{
      55.511738, -11.719006, -6.765971},{55.511738, -9.568528, -9.568528},{
      55.511738, -6.765971, -11.719006},{55.511738, -3.502324, -13.070852},{
      55.511738, -0.000000, -13.531942},{55.511738, 3.502324, -13.070852},{
      55.511738, 6.765971, -11.719006},{55.511738, 9.568528, -9.568528},{
      55.511738, 11.719006, -6.765971},{55.511738, 13.070852, -3.502324},{
      55.511738, 13.531942, -0.000000}}],
    Polygon[{{69.781113, 0.000000, 0.000000},{68.965561, 6.014197, 0.000000},{
      68.965561, 5.809268, 1.556589},{69.781113, 0.000000, 0.000000},{
      69.781113, 0.000000, 0.000000}}],
    Polygon[{{68.965561, 6.014197, 0.000000},{
      66.311249, 12.028394, 0.000000},{66.311249, 11.618536, 3.113177},{
      68.965561, 5.809268, 1.556589},{68.965561, 6.014197, 0.000000}}],
    Polygon[{{66.311249, 12.028394, 0.000000},{
      60.779808, 18.042589, 0.000000},{60.779808, 17.427803, 4.669766},{
      66.311249, 11.618536, 3.113177},{66.311249, 12.028394, 0.000000}}],
    Polygon[{{69.781113, 0.000000, 0.000000},{68.965561, 5.809268, 1.556589},{
      68.965561, 5.208447, 3.007098},{69.781113, 0.000000, 0.000000},{
      69.781113, 0.000000, 0.000000}}],
    Polygon[{{68.965561, 5.809268, 1.556589},{
      66.311249, 11.618536, 3.113177},{66.311249, 10.416894, 6.014197},{
      68.965561, 5.208447, 3.007098},{68.965561, 5.809268, 1.556589}}],
    Polygon[{{66.311249, 11.618536, 3.113177},{
      60.779808, 17.427803, 4.669766},{60.779808, 15.625341, 9.021295},{
      66.311249, 10.416894, 6.014197},{66.311249, 11.618536, 3.113177}}],
    Polygon[{{69.781113, 0.000000, 0.000000},{68.965561, 5.208447, 3.007098},{
      68.965561, 4.252679, 4.252679},{69.781113, 0.000000, 0.000000},{
      69.781113, 0.000000, 0.000000}}],
    Polygon[{{68.965561, 5.208447, 3.007098},{
      66.311249, 10.416894, 6.014197},{66.311249, 8.505359, 8.505359},{
      68.965561, 4.252679, 4.252679},{68.965561, 5.208447, 3.007098}}],
    Polygon[{{66.311249, 10.416894, 6.014197},{
      60.779808, 15.625341, 9.021295},{60.779808, 12.758038, 12.758038},{
      66.311249, 8.505359, 8.505359},{66.311249, 10.416894, 6.014197}}],
    Polygon[{{69.781113, 0.000000, 0.000000},{68.965561, 4.252679, 4.252679},{
      68.965561, 3.007098, 5.208447},{69.781113, 0.000000, 0.000000},{
      69.781113, 0.000000, 0.000000}}],
    Polygon[{{68.965561, 4.252679, 4.252679},{66.311249, 8.505359, 8.505359},{
      66.311249, 6.014197, 10.416894},{68.965561, 3.007098, 5.208447},{
      68.965561, 4.252679, 4.252679}}],
    Polygon[{{66.311249, 8.505359, 8.505359},{
      60.779808, 12.758038, 12.758038},{60.779808, 9.021295, 15.625341},{
      66.311249, 6.014197, 10.416894},{66.311249, 8.505359, 8.505359}}],
    Polygon[{{69.781113, 0.000000, 0.000000},{68.965561, 3.007098, 5.208447},{
      68.965561, 1.556589, 5.809268},{69.781113, 0.000000, 0.000000},{
      69.781113, 0.000000, 0.000000}}],
    Polygon[{{68.965561, 3.007098, 5.208447},{
      66.311249, 6.014197, 10.416894},{66.311249, 3.113177, 11.618536},{
      68.965561, 1.556589, 5.809268},{68.965561, 3.007098, 5.208447}}],
    Polygon[{{66.311249, 6.014197, 10.416894},{
      60.779808, 9.021295, 15.625341},{60.779808, 4.669766, 17.427803},{
      66.311249, 3.113177, 11.618536},{66.311249, 6.014197, 10.416894}}],
    Polygon[{{69.781113, 0.000000, 0.000000},{68.965561, 1.556589, 5.809268},{
      68.965561, 0.000000, 6.014197},{69.781113, 0.000000, 0.000000},{
      69.781113, 0.000000, 0.000000}}],
    Polygon[{{68.965561, 1.556589, 5.809268},{
      66.311249, 3.113177, 11.618536},{66.311249, 0.000000, 12.028394},{
      68.965561, 0.000000, 6.014197},{68.965561, 1.556589, 5.809268}}],
    Polygon[{{66.311249, 3.113177, 11.618536},{
      60.779808, 4.669766, 17.427803},{60.779808, 0.000000, 18.042589},{
      66.311249, 0.000000, 12.028394},{66.311249, 3.113177, 11.618536}}],
    Polygon[{{69.781113, 0.000000, 0.000000},{68.965561, 0.000000, 6.014197},{
      68.965561, -1.556589, 5.809268},{69.781113, -0.000000, 0.000000},{
      69.781113, 0.000000, 0.000000}}],
    Polygon[{{68.965561, 0.000000, 6.014197},{
      66.311249, 0.000000, 12.028394},{66.311249, -3.113177, 11.618536},{
      68.965561, -1.556589, 5.809268},{68.965561, 0.000000, 6.014197}}],
    Polygon[{{66.311249, 0.000000, 12.028394},{
      60.779808, 0.000000, 18.042589},{60.779808, -4.669766, 17.427803},{
      66.311249, -3.113177, 11.618536},{66.311249, 0.000000, 12.028394}}],
    Polygon[{{69.781113, -0.000000, 0.000000},{
      68.965561, -1.556589, 5.809268},{68.965561, -3.007098, 5.208447},{
      69.781113, -0.000000, 0.000000},{69.781113, -0.000000, 0.000000}}],
    Polygon[{{68.965561, -1.556589, 5.809268},{
      66.311249, -3.113177, 11.618536},{66.311249, -6.014197, 10.416894},{
      68.965561, -3.007098, 5.208447},{68.965561, -1.556589, 5.809268}}],
    Polygon[{{66.311249, -3.113177, 11.618536},{
      60.779808, -4.669766, 17.427803},{60.779808, -9.021295, 15.625341},{
      66.311249, -6.014197, 10.416894},{66.311249, -3.113177, 11.618536}}],
    Polygon[{{69.781113, -0.000000, 0.000000},{
      68.965561, -3.007098, 5.208447},{68.965561, -4.252679, 4.252679},{
      69.781113, -0.000000, 0.000000},{69.781113, -0.000000, 0.000000}}],
    Polygon[{{68.965561, -3.007098, 5.208447},{
      66.311249, -6.014197, 10.416894},{66.311249, -8.505359, 8.505359},{
      68.965561, -4.252679, 4.252679},{68.965561, -3.007098, 5.208447}}],
    Polygon[{{66.311249, -6.014197, 10.416894},{
      60.779808, -9.021295, 15.625341},{60.779808, -12.758038, 12.758038},{
      66.311249, -8.505359, 8.505359},{66.311249, -6.014197, 10.416894}}],
    Polygon[{{69.781113, -0.000000, 0.000000},{
      68.965561, -4.252679, 4.252679},{68.965561, -5.208447, 3.007098},{
      69.781113, -0.000000, 0.000000},{69.781113, -0.000000, 0.000000}}],
    Polygon[{{68.965561, -4.252679, 4.252679},{
      66.311249, -8.505359, 8.505359},{66.311249, -10.416894, 6.014197},{
      68.965561, -5.208447, 3.007098},{68.965561, -4.252679, 4.252679}}],
    Polygon[{{66.311249, -8.505359, 8.505359},{
      60.779808, -12.758038, 12.758038},{60.779808, -15.625341, 9.021295},{
      66.311249, -10.416894, 6.014197},{66.311249, -8.505359, 8.505359}}],
    Polygon[{{69.781113, -0.000000, 0.000000},{
      68.965561, -5.208447, 3.007098},{68.965561, -5.809268, 1.556589},{
      69.781113, -0.000000, 0.000000},{69.781113, -0.000000, 0.000000}}],
    Polygon[{{68.965561, -5.208447, 3.007098},{
      66.311249, -10.416894, 6.014197},{66.311249, -11.618536, 3.113177},{
      68.965561, -5.809268, 1.556589},{68.965561, -5.208447, 3.007098}}],
    Polygon[{{66.311249, -10.416894, 6.014197},{
      60.779808, -15.625341, 9.021295},{60.779808, -17.427803, 4.669766},{
      66.311249, -11.618536, 3.113177},{66.311249, -10.416894, 6.014197}}],
    Polygon[{{69.781113, -0.000000, 0.000000},{
      68.965561, -5.809268, 1.556589},{68.965561, -6.014197, 0.000000},{
      69.781113, -0.000000, 0.000000},{69.781113, -0.000000, 0.000000}}],
    Polygon[{{68.965561, -5.809268, 1.556589},{
      66.311249, -11.618536, 3.113177},{66.311249, -12.028394, 0.000000},{
      68.965561, -6.014197, 0.000000},{68.965561, -5.809268, 1.556589}}],
    Polygon[{{66.311249, -11.618536, 3.113177},{
      60.779808, -17.427803, 4.669766},{60.779808, -18.042589, 0.000000},{
      66.311249, -12.028394, 0.000000},{66.311249, -11.618536, 3.113177}}],
    Polygon[{{69.781113, -0.000000, 0.000000},{
      68.965561, -6.014197, 0.000000},{68.965561, -5.809268, -1.556589},{
      69.781113, -0.000000, -0.000000},{69.781113, -0.000000, 0.000000}}],
    Polygon[{{68.965561, -6.014197, 0.000000},{
      66.311249, -12.028394, 0.000000},{66.311249, -11.618536, -3.113177},{
      68.965561, -5.809268, -1.556589},{68.965561, -6.014197, 0.000000}}],
    Polygon[{{66.311249, -12.028394, 0.000000},{
      60.779808, -18.042589, 0.000000},{60.779808, -17.427803, -4.669766},{
      66.311249, -11.618536, -3.113177},{66.311249, -12.028394, 0.000000}}],
    Polygon[{{69.781113, -0.000000, -0.000000},{
      68.965561, -5.809268, -1.556589},{68.965561, -5.208447, -3.007098},{
      69.781113, -0.000000, -0.000000},{69.781113, -0.000000, -0.000000}}],
    Polygon[{{68.965561, -5.809268, -1.556589},{
      66.311249, -11.618536, -3.113177},{66.311249, -10.416894, -6.014197},{
      68.965561, -5.208447, -3.007098},{68.965561, -5.809268, -1.556589}}],
    Polygon[{{66.311249, -11.618536, -3.113177},{
      60.779808, -17.427803, -4.669766},{60.779808, -15.625341, -9.021295},{
      66.311249, -10.416894, -6.014197},{66.311249, -11.618536, -3.113177}}],
    Polygon[{{69.781113, -0.000000, -0.000000},{
      68.965561, -5.208447, -3.007098},{68.965561, -4.252679, -4.252679},{
      69.781113, -0.000000, -0.000000},{69.781113, -0.000000, -0.000000}}],
    Polygon[{{68.965561, -5.208447, -3.007098},{
      66.311249, -10.416894, -6.014197},{66.311249, -8.505359, -8.505359},{
      68.965561, -4.252679, -4.252679},{68.965561, -5.208447, -3.007098}}],
    Polygon[{{66.311249, -10.416894, -6.014197},{
      60.779808, -15.625341, -9.021295},{60.779808, -12.758038, -12.758038},{
      66.311249, -8.505359, -8.505359},{66.311249, -10.416894, -6.014197}}],
    Polygon[{{69.781113, -0.000000, -0.000000},{
      68.965561, -4.252679, -4.252679},{68.965561, -3.007098, -5.208447},{
      69.781113, -0.000000, -0.000000},{69.781113, -0.000000, -0.000000}}],
    Polygon[{{68.965561, -4.252679, -4.252679},{
      66.311249, -8.505359, -8.505359},{66.311249, -6.014197, -10.416894},{
      68.965561, -3.007098, -5.208447},{68.965561, -4.252679, -4.252679}}],
    Polygon[{{66.311249, -8.505359, -8.505359},{
      60.779808, -12.758038, -12.758038},{60.779808, -9.021295, -15.625341},{
      66.311249, -6.014197, -10.416894},{66.311249, -8.505359, -8.505359}}],
    Polygon[{{69.781113, -0.000000, -0.000000},{
      68.965561, -3.007098, -5.208447},{68.965561, -1.556589, -5.809268},{
      69.781113, -0.000000, -0.000000},{69.781113, -0.000000, -0.000000}}],
    Polygon[{{68.965561, -3.007098, -5.208447},{
      66.311249, -6.014197, -10.416894},{66.311249, -3.113177, -11.618536},{
      68.965561, -1.556589, -5.809268},{68.965561, -3.007098, -5.208447}}],
    Polygon[{{66.311249, -6.014197, -10.416894},{
      60.779808, -9.021295, -15.625341},{60.779808, -4.669766, -17.427803},{
      66.311249, -3.113177, -11.618536},{66.311249, -6.014197, -10.416894}}],
    Polygon[{{69.781113, -0.000000, -0.000000},{
      68.965561, -1.556589, -5.809268},{68.965561, -0.000000, -6.014197},{
      69.781113, -0.000000, -0.000000},{69.781113, -0.000000, -0.000000}}],
    Polygon[{{68.965561, -1.556589, -5.809268},{
      66.311249, -3.113177, -11.618536},{66.311249, -0.000000, -12.028394},{
      68.965561, -0.000000, -6.014197},{68.965561, -1.556589, -5.809268}}],
    Polygon[{{66.311249, -3.113177, -11.618536},{
      60.779808, -4.669766, -17.427803},{60.779808, -0.000000, -18.042589},{
      66.311249, -0.000000, -12.028394},{66.311249, -3.113177, -11.618536}}],
    Polygon[{{69.781113, -0.000000, -0.000000},{
      68.965561, -0.000000, -6.014197},{68.965561, 1.556589, -5.809268},{
      69.781113, 0.000000, -0.000000},{69.781113, -0.000000, -0.000000}}],
    Polygon[{{68.965561, -0.000000, -6.014197},{
      66.311249, -0.000000, -12.028394},{66.311249, 3.113177, -11.618536},{
      68.965561, 1.556589, -5.809268},{68.965561, -0.000000, -6.014197}}],
    Polygon[{{66.311249, -0.000000, -12.028394},{
      60.779808, -0.000000, -18.042589},{60.779808, 4.669766, -17.427803},{
      66.311249, 3.113177, -11.618536},{66.311249, -0.000000, -12.028394}}],
    Polygon[{{69.781113, 0.000000, -0.000000},{
      68.965561, 1.556589, -5.809268},{68.965561, 3.007098, -5.208447},{
      69.781113, 0.000000, -0.000000},{69.781113, 0.000000, -0.000000}}],
    Polygon[{{68.965561, 1.556589, -5.809268},{
      66.311249, 3.113177, -11.618536},{66.311249, 6.014197, -10.416894},{
      68.965561, 3.007098, -5.208447},{68.965561, 1.556589, -5.809268}}],
    Polygon[{{66.311249, 3.113177, -11.618536},{
      60.779808, 4.669766, -17.427803},{60.779808, 9.021295, -15.625341},{
      66.311249, 6.014197, -10.416894},{66.311249, 3.113177, -11.618536}}],
    Polygon[{{69.781113, 0.000000, -0.000000},{
      68.965561, 3.007098, -5.208447},{68.965561, 4.252679, -4.252679},{
      69.781113, 0.000000, -0.000000},{69.781113, 0.000000, -0.000000}}],
    Polygon[{{68.965561, 3.007098, -5.208447},{
      66.311249, 6.014197, -10.416894},{66.311249, 8.505359, -8.505359},{
      68.965561, 4.252679, -4.252679},{68.965561, 3.007098, -5.208447}}],
    Polygon[{{66.311249, 6.014197, -10.416894},{
      60.779808, 9.021295, -15.625341},{60.779808, 12.758038, -12.758038},{
      66.311249, 8.505359, -8.505359},{66.311249, 6.014197, -10.416894}}],
    Polygon[{{69.781113, 0.000000, -0.000000},{
      68.965561, 4.252679, -4.252679},{68.965561, 5.208447, -3.007098},{
      69.781113, 0.000000, -0.000000},{69.781113, 0.000000, -0.000000}}],
    Polygon[{{68.965561, 4.252679, -4.252679},{
      66.311249, 8.505359, -8.505359},{66.311249, 10.416894, -6.014197},{
      68.965561, 5.208447, -3.007098},{68.965561, 4.252679, -4.252679}}],
    Polygon[{{66.311249, 8.505359, -8.505359},{
      60.779808, 12.758038, -12.758038},{60.779808, 15.625341, -9.021295},{
      66.311249, 10.416894, -6.014197},{66.311249, 8.505359, -8.505359}}],
    Polygon[{{69.781113, 0.000000, -0.000000},{
      68.965561, 5.208447, -3.007098},{68.965561, 5.809268, -1.556589},{
      69.781113, 0.000000, -0.000000},{69.781113, 0.000000, -0.000000}}],
    Polygon[{{68.965561, 5.208447, -3.007098},{
      66.311249, 10.416894, -6.014197},{66.311249, 11.618536, -3.113177},{
      68.965561, 5.809268, -1.556589},{68.965561, 5.208447, -3.007098}}],
    Polygon[{{66.311249, 10.416894, -6.014197},{
      60.779808, 15.625341, -9.021295},{60.779808, 17.427803, -4.669766},{
      66.311249, 11.618536, -3.113177},{66.311249, 10.416894, -6.014197}}],
    Polygon[{{69.781113, 0.000000, -0.000000},{
      68.965561, 5.809268, -1.556589},{68.965561, 6.014197, -0.000000},{
      69.781113, 0.000000, -0.000000},{69.781113, 0.000000, -0.000000}}],
    Polygon[{{68.965561, 5.809268, -1.556589},{
      66.311249, 11.618536, -3.113177},{66.311249, 12.028394, -0.000000},{
      68.965561, 6.014197, -0.000000},{68.965561, 5.809268, -1.556589}}],
    Polygon[{{66.311249, 11.618536, -3.113177},{
      60.779808, 17.427803, -4.669766},{60.779808, 18.042589, -0.000000},{
      66.311249, 12.028394, -0.000000},{66.311249, 11.618536, -3.113177}}],
    Line[{{60.779808, 18.042589, 0.000000},{60.779808, 17.427803, 4.669766},{
      60.779808, 15.625341, 9.021295},{60.779808, 12.758038, 12.758038},{
      60.779808, 9.021295, 15.625341},{60.779808, 4.669766, 17.427803},{
      60.779808, 0.000000, 18.042589},{60.779808, -4.669766, 17.427803},{
      60.779808, -9.021295, 15.625341},{60.779808, -12.758038, 12.758038},{
      60.779808, -15.625341, 9.021295},{60.779808, -17.427803, 4.669766},{
      60.779808, -18.042589, 0.000000},{60.779808, -17.427803, -4.669766},{
      60.779808, -15.625341, -9.021295},{60.779808, -12.758038, -12.758038},{
      60.779808, -9.021295, -15.625341},{60.779808, -4.669766, -17.427803},{
      60.779808, -0.000000, -18.042589},{60.779808, 4.669766, -17.427803},{
      60.779808, 9.021295, -15.625341},{60.779808, 12.758038, -12.758038},{
      60.779808, 15.625341, -9.021295},{60.779808, 17.427803, -4.669766},{
      60.779808, 18.042589, -0.000000}}],
    Polygon[{{55.511738, 13.531942, 0.000000},{
      60.779808, 18.042589, 0.000000},{60.779808, 17.427803, 4.669766},{
      55.511738, 13.070852, 3.502324},{55.511738, 13.531942, 0.000000}}],
    Polygon[{{55.511738, 13.070852, 3.502324},{
      60.779808, 17.427803, 4.669766},{60.779808, 15.625341, 9.021295},{
      55.511738, 11.719006, 6.765971},{55.511738, 13.070852, 3.502324}}],
    Polygon[{{55.511738, 11.719006, 6.765971},{
      60.779808, 15.625341, 9.021295},{60.779808, 12.758038, 12.758038},{
      55.511738, 9.568528, 9.568528},{55.511738, 11.719006, 6.765971}}],
    Polygon[{{55.511738, 9.568528, 9.568528},{
      60.779808, 12.758038, 12.758038},{60.779808, 9.021295, 15.625341},{
      55.511738, 6.765971, 11.719006},{55.511738, 9.568528, 9.568528}}],
    Polygon[{{55.511738, 6.765971, 11.719006},{
      60.779808, 9.021295, 15.625341},{60.779808, 4.669766, 17.427803},{
      55.511738, 3.502324, 13.070852},{55.511738, 6.765971, 11.719006}}],
    Polygon[{{55.511738, 3.502324, 13.070852},{
      60.779808, 4.669766, 17.427803},{60.779808, 0.000000, 18.042589},{
      55.511738, 0.000000, 13.531942},{55.511738, 3.502324, 13.070852}}],
    Polygon[{{55.511738, 0.000000, 13.531942},{
      60.779808, 0.000000, 18.042589},{60.779808, -4.669766, 17.427803},{
      55.511738, -3.502324, 13.070852},{55.511738, 0.000000, 13.531942}}],
    Polygon[{{55.511738, -3.502324, 13.070852},{
      60.779808, -4.669766, 17.427803},{60.779808, -9.021295, 15.625341},{
      55.511738, -6.765971, 11.719006},{55.511738, -3.502324, 13.070852}}],
    Polygon[{{55.511738, -6.765971, 11.719006},{
      60.779808, -9.021295, 15.625341},{60.779808, -12.758038, 12.758038},{
      55.511738, -9.568528, 9.568528},{55.511738, -6.765971, 11.719006}}],
    Polygon[{{55.511738, -9.568528, 9.568528},{
      60.779808, -12.758038, 12.758038},{60.779808, -15.625341, 9.021295},{
      55.511738, -11.719006, 6.765971},{55.511738, -9.568528, 9.568528}}],
    Polygon[{{55.511738, -11.719006, 6.765971},{
      60.779808, -15.625341, 9.021295},{60.779808, -17.427803, 4.669766},{
      55.511738, -13.070852, 3.502324},{55.511738, -11.719006, 6.765971}}],
    Polygon[{{55.511738, -13.070852, 3.502324},{
      60.779808, -17.427803, 4.669766},{60.779808, -18.042589, 0.000000},{
      55.511738, -13.531942, 0.000000},{55.511738, -13.070852, 3.502324}}],
    Polygon[{{55.511738, -13.531942, 0.000000},{
      60.779808, -18.042589, 0.000000},{60.779808, -17.427803, -4.669766},{
      55.511738, -13.070852, -3.502324},{55.511738, -13.531942, 0.000000}}],
    Polygon[{{55.511738, -13.070852, -3.502324},{
      60.779808, -17.427803, -4.669766},{60.779808, -15.625341, -9.021295},{
      55.511738, -11.719006, -6.765971},{55.511738, -13.070852, -3.502324}}],
    Polygon[{{55.511738, -11.719006, -6.765971},{
      60.779808, -15.625341, -9.021295},{60.779808, -12.758038, -12.758038},{
      55.511738, -9.568528, -9.568528},{55.511738, -11.719006, -6.765971}}],
    Polygon[{{55.511738, -9.568528, -9.568528},{
      60.779808, -12.758038, -12.758038},{60.779808, -9.021295, -15.625341},{
      55.511738, -6.765971, -11.719006},{55.511738, -9.568528, -9.568528}}],
    Polygon[{{55.511738, -6.765971, -11.719006},{
      60.779808, -9.021295, -15.625341},{60.779808, -4.669766, -17.427803},{
      55.511738, -3.502324, -13.070852},{55.511738, -6.765971, -11.719006}}],
    Polygon[{{55.511738, -3.502324, -13.070852},{
      60.779808, -4.669766, -17.427803},{60.779808, -0.000000, -18.042589},{
      55.511738, -0.000000, -13.531942},{55.511738, -3.502324, -13.070852}}],
    Polygon[{{55.511738, -0.000000, -13.531942},{
      60.779808, -0.000000, -18.042589},{60.779808, 4.669766, -17.427803},{
      55.511738, 3.502324, -13.070852},{55.511738, -0.000000, -13.531942}}],
    Polygon[{{55.511738, 3.502324, -13.070852},{
      60.779808, 4.669766, -17.427803},{60.779808, 9.021295, -15.625341},{
      55.511738, 6.765971, -11.719006},{55.511738, 3.502324, -13.070852}}],
    Polygon[{{55.511738, 6.765971, -11.719006},{
      60.779808, 9.021295, -15.625341},{60.779808, 12.758038, -12.758038},{
      55.511738, 9.568528, -9.568528},{55.511738, 6.765971, -11.719006}}],
    Polygon[{{55.511738, 9.568528, -9.568528},{
      60.779808, 12.758038, -12.758038},{60.779808, 15.625341, -9.021295},{
      55.511738, 11.719006, -6.765971},{55.511738, 9.568528, -9.568528}}],
    Polygon[{{55.511738, 11.719006, -6.765971},{
      60.779808, 15.625341, -9.021295},{60.779808, 17.427803, -4.669766},{
      55.511738, 13.070852, -3.502324},{55.511738, 11.719006, -6.765971}}],
    Polygon[{{55.511738, 13.070852, -3.502324},{
      60.779808, 17.427803, -4.669766},{60.779808, 18.042589, -0.000000},{
      55.511738, 13.531942, -0.000000},{55.511738, 13.070852, -3.502324}}],
    Polygon[{{71.224518, 0.000000, 0.000000},{71.145531, 7.684807, 0.000000},{
      71.145531, 7.422953, 1.988974},{71.224518, 0.000000, 0.000000},{
      71.224518, 0.000000, 0.000000}}],
    Polygon[{{71.145531, 7.684807, 0.000000},{
      70.908447, 15.369614, 0.000000},{70.908447, 14.845906, 3.977949},{
      71.145531, 7.422953, 1.988974},{71.145531, 7.684807, 0.000000}}],
    Polygon[{{70.908447, 15.369614, 0.000000},{
      70.512978, 23.054420, 0.000000},{70.512978, 22.268860, 5.966923},{
      70.908447, 14.845906, 3.977949},{70.908447, 15.369614, 0.000000}}],
    Polygon[{{71.224518, 0.000000, 0.000000},{71.145531, 7.422953, 1.988974},{
      71.145531, 6.655238, 3.842403},{71.224518, 0.000000, 0.000000},{
      71.224518, 0.000000, 0.000000}}],
    Polygon[{{71.145531, 7.422953, 1.988974},{
      70.908447, 14.845906, 3.977949},{70.908447, 13.310475, 7.684807},{
      71.145531, 6.655238, 3.842403},{71.145531, 7.422953, 1.988974}}],
    Polygon[{{70.908447, 14.845906, 3.977949},{
      70.512978, 22.268860, 5.966923},{70.512978, 19.965714, 11.527210},{
      70.908447, 13.310475, 7.684807},{70.908447, 14.845906, 3.977949}}],
    Polygon[{{71.224518, 0.000000, 0.000000},{71.145531, 6.655238, 3.842403},{
      71.145531, 5.433979, 5.433979},{71.224518, 0.000000, 0.000000},{
      71.224518, 0.000000, 0.000000}}],
    Polygon[{{71.145531, 6.655238, 3.842403},{
      70.908447, 13.310475, 7.684807},{70.908447, 10.867958, 10.867958},{
      71.145531, 5.433979, 5.433979},{71.145531, 6.655238, 3.842403}}],
    Polygon[{{70.908447, 13.310475, 7.684807},{
      70.512978, 19.965714, 11.527210},{70.512978, 16.301937, 16.301937},{
      70.908447, 10.867958, 10.867958},{70.908447, 13.310475, 7.684807}}],
    Polygon[{{71.224518, 0.000000, 0.000000},{71.145531, 5.433979, 5.433979},{
      71.145531, 3.842403, 6.655238},{71.224518, 0.000000, 0.000000},{
      71.224518, 0.000000, 0.000000}}],
    Polygon[{{71.145531, 5.433979, 5.433979},{
      70.908447, 10.867958, 10.867958},{70.908447, 7.684807, 13.310475},{
      71.145531, 3.842403, 6.655238},{71.145531, 5.433979, 5.433979}}],
    Polygon[{{70.908447, 10.867958, 10.867958},{
      70.512978, 16.301937, 16.301937},{70.512978, 11.527210, 19.965714},{
      70.908447, 7.684807, 13.310475},{70.908447, 10.867958, 10.867958}}],
    Polygon[{{71.224518, 0.000000, 0.000000},{71.145531, 3.842403, 6.655238},{
      71.145531, 1.988974, 7.422953},{71.224518, 0.000000, 0.000000},{
      71.224518, 0.000000, 0.000000}}],
    Polygon[{{71.145531, 3.842403, 6.655238},{
      70.908447, 7.684807, 13.310475},{70.908447, 3.977949, 14.845906},{
      71.145531, 1.988974, 7.422953},{71.145531, 3.842403, 6.655238}}],
    Polygon[{{70.908447, 7.684807, 13.310475},{
      70.512978, 11.527210, 19.965714},{70.512978, 5.966923, 22.268860},{
      70.908447, 3.977949, 14.845906},{70.908447, 7.684807, 13.310475}}],
    Polygon[{{71.224518, 0.000000, 0.000000},{71.145531, 1.988974, 7.422953},{
      71.145531, 0.000000, 7.684807},{71.224518, 0.000000, 0.000000},{
      71.224518, 0.000000, 0.000000}}],
    Polygon[{{71.145531, 1.988974, 7.422953},{
      70.908447, 3.977949, 14.845906},{70.908447, 0.000000, 15.369614},{
      71.145531, 0.000000, 7.684807},{71.145531, 1.988974, 7.422953}}],
    Polygon[{{70.908447, 3.977949, 14.845906},{
      70.512978, 5.966923, 22.268860},{70.512978, 0.000000, 23.054420},{
      70.908447, 0.000000, 15.369614},{70.908447, 3.977949, 14.845906}}],
    Polygon[{{71.224518, 0.000000, 0.000000},{71.145531, 0.000000, 7.684807},{
      71.145531, -1.988974, 7.422953},{71.224518, -0.000000, 0.000000},{
      71.224518, 0.000000, 0.000000}}],
    Polygon[{{71.145531, 0.000000, 7.684807},{
      70.908447, 0.000000, 15.369614},{70.908447, -3.977949, 14.845906},{
      71.145531, -1.988974, 7.422953},{71.145531, 0.000000, 7.684807}}],
    Polygon[{{70.908447, 0.000000, 15.369614},{
      70.512978, 0.000000, 23.054420},{70.512978, -5.966923, 22.268860},{
      70.908447, -3.977949, 14.845906},{70.908447, 0.000000, 15.369614}}],
    Polygon[{{71.224518, -0.000000, 0.000000},{
      71.145531, -1.988974, 7.422953},{71.145531, -3.842403, 6.655238},{
      71.224518, -0.000000, 0.000000},{71.224518, -0.000000, 0.000000}}],
    Polygon[{{71.145531, -1.988974, 7.422953},{
      70.908447, -3.977949, 14.845906},{70.908447, -7.684807, 13.310475},{
      71.145531, -3.842403, 6.655238},{71.145531, -1.988974, 7.422953}}],
    Polygon[{{70.908447, -3.977949, 14.845906},{
      70.512978, -5.966923, 22.268860},{70.512978, -11.527210, 19.965714},{
      70.908447, -7.684807, 13.310475},{70.908447, -3.977949, 14.845906}}],
    Polygon[{{71.224518, -0.000000, 0.000000},{
      71.145531, -3.842403, 6.655238},{71.145531, -5.433979, 5.433979},{
      71.224518, -0.000000, 0.000000},{71.224518, -0.000000, 0.000000}}],
    Polygon[{{71.145531, -3.842403, 6.655238},{
      70.908447, -7.684807, 13.310475},{70.908447, -10.867958, 10.867958},{
      71.145531, -5.433979, 5.433979},{71.145531, -3.842403, 6.655238}}],
    Polygon[{{70.908447, -7.684807, 13.310475},{
      70.512978, -11.527210, 19.965714},{70.512978, -16.301937, 16.301937},{
      70.908447, -10.867958, 10.867958},{70.908447, -7.684807, 13.310475}}],
    Polygon[{{71.224518, -0.000000, 0.000000},{
      71.145531, -5.433979, 5.433979},{71.145531, -6.655238, 3.842403},{
      71.224518, -0.000000, 0.000000},{71.224518, -0.000000, 0.000000}}],
    Polygon[{{71.145531, -5.433979, 5.433979},{
      70.908447, -10.867958, 10.867958},{70.908447, -13.310475, 7.684807},{
      71.145531, -6.655238, 3.842403},{71.145531, -5.433979, 5.433979}}],
    Polygon[{{70.908447, -10.867958, 10.867958},{
      70.512978, -16.301937, 16.301937},{70.512978, -19.965714, 11.527210},{
      70.908447, -13.310475, 7.684807},{70.908447, -10.867958, 10.867958}}],
    Polygon[{{71.224518, -0.000000, 0.000000},{
      71.145531, -6.655238, 3.842403},{71.145531, -7.422953, 1.988974},{
      71.224518, -0.000000, 0.000000},{71.224518, -0.000000, 0.000000}}],
    Polygon[{{71.145531, -6.655238, 3.842403},{
      70.908447, -13.310475, 7.684807},{70.908447, -14.845906, 3.977949},{
      71.145531, -7.422953, 1.988974},{71.145531, -6.655238, 3.842403}}],
    Polygon[{{70.908447, -13.310475, 7.684807},{
      70.512978, -19.965714, 11.527210},{70.512978, -22.268860, 5.966923},{
      70.908447, -14.845906, 3.977949},{70.908447, -13.310475, 7.684807}}],
    Polygon[{{71.224518, -0.000000, 0.000000},{
      71.145531, -7.422953, 1.988974},{71.145531, -7.684807, 0.000000},{
      71.224518, -0.000000, 0.000000},{71.224518, -0.000000, 0.000000}}],
    Polygon[{{71.145531, -7.422953, 1.988974},{
      70.908447, -14.845906, 3.977949},{70.908447, -15.369614, 0.000000},{
      71.145531, -7.684807, 0.000000},{71.145531, -7.422953, 1.988974}}],
    Polygon[{{70.908447, -14.845906, 3.977949},{
      70.512978, -22.268860, 5.966923},{70.512978, -23.054420, 0.000000},{
      70.908447, -15.369614, 0.000000},{70.908447, -14.845906, 3.977949}}],
    Polygon[{{71.224518, -0.000000, 0.000000},{
      71.145531, -7.684807, 0.000000},{71.145531, -7.422953, -1.988974},{
      71.224518, -0.000000, -0.000000},{71.224518, -0.000000, 0.000000}}],
    Polygon[{{71.145531, -7.684807, 0.000000},{
      70.908447, -15.369614, 0.000000},{70.908447, -14.845906, -3.977949},{
      71.145531, -7.422953, -1.988974},{71.145531, -7.684807, 0.000000}}],
    Polygon[{{70.908447, -15.369614, 0.000000},{
      70.512978, -23.054420, 0.000000},{70.512978, -22.268860, -5.966923},{
      70.908447, -14.845906, -3.977949},{70.908447, -15.369614, 0.000000}}],
    Polygon[{{71.224518, -0.000000, -0.000000},{
      71.145531, -7.422953, -1.988974},{71.145531, -6.655238, -3.842403},{
      71.224518, -0.000000, -0.000000},{71.224518, -0.000000, -0.000000}}],
    Polygon[{{71.145531, -7.422953, -1.988974},{
      70.908447, -14.845906, -3.977949},{70.908447, -13.310475, -7.684807},{
      71.145531, -6.655238, -3.842403},{71.145531, -7.422953, -1.988974}}],
    Polygon[{{70.908447, -14.845906, -3.977949},{
      70.512978, -22.268860, -5.966923},{70.512978, -19.965714, -11.527210},{
      70.908447, -13.310475, -7.684807},{70.908447, -14.845906, -3.977949}}],
    Polygon[{{71.224518, -0.000000, -0.000000},{
      71.145531, -6.655238, -3.842403},{71.145531, -5.433979, -5.433979},{
      71.224518, -0.000000, -0.000000},{71.224518, -0.000000, -0.000000}}],
    Polygon[{{71.145531, -6.655238, -3.842403},{
      70.908447, -13.310475, -7.684807},{70.908447, -10.867958, -10.867958},{
      71.145531, -5.433979, -5.433979},{71.145531, -6.655238, -3.842403}}],
    Polygon[{{70.908447, -13.310475, -7.684807},{
      70.512978, -19.965714, -11.527210},{70.512978, -16.301937, -16.301937},{
      70.908447, -10.867958, -10.867958},{70.908447, -13.310475, -7.684807}}],
    
    Polygon[{{71.224518, -0.000000, -0.000000},{
      71.145531, -5.433979, -5.433979},{71.145531, -3.842403, -6.655238},{
      71.224518, -0.000000, -0.000000},{71.224518, -0.000000, -0.000000}}],
    Polygon[{{71.145531, -5.433979, -5.433979},{
      70.908447, -10.867958, -10.867958},{70.908447, -7.684807, -13.310475},{
      71.145531, -3.842403, -6.655238},{71.145531, -5.433979, -5.433979}}],
    Polygon[{{70.908447, -10.867958, -10.867958},{
      70.512978, -16.301937, -16.301937},{70.512978, -11.527210, -19.965714},{
      70.908447, -7.684807, -13.310475},{70.908447, -10.867958, -10.867958}}],
    
    Polygon[{{71.224518, -0.000000, -0.000000},{
      71.145531, -3.842403, -6.655238},{71.145531, -1.988974, -7.422953},{
      71.224518, -0.000000, -0.000000},{71.224518, -0.000000, -0.000000}}],
    Polygon[{{71.145531, -3.842403, -6.655238},{
      70.908447, -7.684807, -13.310475},{70.908447, -3.977949, -14.845906},{
      71.145531, -1.988974, -7.422953},{71.145531, -3.842403, -6.655238}}],
    Polygon[{{70.908447, -7.684807, -13.310475},{
      70.512978, -11.527210, -19.965714},{70.512978, -5.966923, -22.268860},{
      70.908447, -3.977949, -14.845906},{70.908447, -7.684807, -13.310475}}],
    Polygon[{{71.224518, -0.000000, -0.000000},{
      71.145531, -1.988974, -7.422953},{71.145531, -0.000000, -7.684807},{
      71.224518, -0.000000, -0.000000},{71.224518, -0.000000, -0.000000}}],
    Polygon[{{71.145531, -1.988974, -7.422953},{
      70.908447, -3.977949, -14.845906},{70.908447, -0.000000, -15.369614},{
      71.145531, -0.000000, -7.684807},{71.145531, -1.988974, -7.422953}}],
    Polygon[{{70.908447, -3.977949, -14.845906},{
      70.512978, -5.966923, -22.268860},{70.512978, -0.000000, -23.054420},{
      70.908447, -0.000000, -15.369614},{70.908447, -3.977949, -14.845906}}],
    Polygon[{{71.224518, -0.000000, -0.000000},{
      71.145531, -0.000000, -7.684807},{71.145531, 1.988974, -7.422953},{
      71.224518, 0.000000, -0.000000},{71.224518, -0.000000, -0.000000}}],
    Polygon[{{71.145531, -0.000000, -7.684807},{
      70.908447, -0.000000, -15.369614},{70.908447, 3.977949, -14.845906},{
      71.145531, 1.988974, -7.422953},{71.145531, -0.000000, -7.684807}}],
    Polygon[{{70.908447, -0.000000, -15.369614},{
      70.512978, -0.000000, -23.054420},{70.512978, 5.966923, -22.268860},{
      70.908447, 3.977949, -14.845906},{70.908447, -0.000000, -15.369614}}],
    Polygon[{{71.224518, 0.000000, -0.000000},{
      71.145531, 1.988974, -7.422953},{71.145531, 3.842403, -6.655238},{
      71.224518, 0.000000, -0.000000},{71.224518, 0.000000, -0.000000}}],
    Polygon[{{71.145531, 1.988974, -7.422953},{
      70.908447, 3.977949, -14.845906},{70.908447, 7.684807, -13.310475},{
      71.145531, 3.842403, -6.655238},{71.145531, 1.988974, -7.422953}}],
    Polygon[{{70.908447, 3.977949, -14.845906},{
      70.512978, 5.966923, -22.268860},{70.512978, 11.527210, -19.965714},{
      70.908447, 7.684807, -13.310475},{70.908447, 3.977949, -14.845906}}],
    Polygon[{{71.224518, 0.000000, -0.000000},{
      71.145531, 3.842403, -6.655238},{71.145531, 5.433979, -5.433979},{
      71.224518, 0.000000, -0.000000},{71.224518, 0.000000, -0.000000}}],
    Polygon[{{71.145531, 3.842403, -6.655238},{
      70.908447, 7.684807, -13.310475},{70.908447, 10.867958, -10.867958},{
      71.145531, 5.433979, -5.433979},{71.145531, 3.842403, -6.655238}}],
    Polygon[{{70.908447, 7.684807, -13.310475},{
      70.512978, 11.527210, -19.965714},{70.512978, 16.301937, -16.301937},{
      70.908447, 10.867958, -10.867958},{70.908447, 7.684807, -13.310475}}],
    Polygon[{{71.224518, 0.000000, -0.000000},{
      71.145531, 5.433979, -5.433979},{71.145531, 6.655238, -3.842403},{
      71.224518, 0.000000, -0.000000},{71.224518, 0.000000, -0.000000}}],
    Polygon[{{71.145531, 5.433979, -5.433979},{
      70.908447, 10.867958, -10.867958},{70.908447, 13.310475, -7.684807},{
      71.145531, 6.655238, -3.842403},{71.145531, 5.433979, -5.433979}}],
    Polygon[{{70.908447, 10.867958, -10.867958},{
      70.512978, 16.301937, -16.301937},{70.512978, 19.965714, -11.527210},{
      70.908447, 13.310475, -7.684807},{70.908447, 10.867958, -10.867958}}],
    Polygon[{{71.224518, 0.000000, -0.000000},{
      71.145531, 6.655238, -3.842403},{71.145531, 7.422953, -1.988974},{
      71.224518, 0.000000, -0.000000},{71.224518, 0.000000, -0.000000}}],
    Polygon[{{71.145531, 6.655238, -3.842403},{
      70.908447, 13.310475, -7.684807},{70.908447, 14.845906, -3.977949},{
      71.145531, 7.422953, -1.988974},{71.145531, 6.655238, -3.842403}}],
    Polygon[{{70.908447, 13.310475, -7.684807},{
      70.512978, 19.965714, -11.527210},{70.512978, 22.268860, -5.966923},{
      70.908447, 14.845906, -3.977949},{70.908447, 13.310475, -7.684807}}],
    Polygon[{{71.224518, 0.000000, -0.000000},{
      71.145531, 7.422953, -1.988974},{71.145531, 7.684807, -0.000000},{
      71.224518, 0.000000, -0.000000},{71.224518, 0.000000, -0.000000}}],
    Polygon[{{71.145531, 7.422953, -1.988974},{
      70.908447, 14.845906, -3.977949},{70.908447, 15.369614, -0.000000},{
      71.145531, 7.684807, -0.000000},{71.145531, 7.422953, -1.988974}}],
    Polygon[{{70.908447, 14.845906, -3.977949},{
      70.512978, 22.268860, -5.966923},{70.512978, 23.054420, -0.000000},{
      70.908447, 15.369614, -0.000000},{70.908447, 14.845906, -3.977949}}],
    Line[{{70.512978, 23.054420, 0.000000},{70.512978, 22.268860, 5.966923},{
      70.512978, 19.965714, 11.527210},{70.512978, 16.301937, 16.301937},{
      70.512978, 11.527210, 19.965714},{70.512978, 5.966923, 22.268860},{
      70.512978, 0.000000, 23.054420},{70.512978, -5.966923, 22.268860},{
      70.512978, -11.527210, 19.965714},{70.512978, -16.301937, 16.301937},{
      70.512978, -19.965714, 11.527210},{70.512978, -22.268860, 5.966923},{
      70.512978, -23.054420, 0.000000},{70.512978, -22.268860, -5.966923},{
      70.512978, -19.965714, -11.527210},{70.512978, -16.301937, -16.301937},{
      70.512978, -11.527210, -19.965714},{70.512978, -5.966923, -22.268860},{
      70.512978, -0.000000, -23.054420},{70.512978, 5.966923, -22.268860},{
      70.512978, 11.527210, -19.965714},{70.512978, 16.301937, -16.301937},{
      70.512978, 19.965714, -11.527210},{70.512978, 22.268860, -5.966923},{
      70.512978, 23.054420, -0.000000}}],
    Polygon[{{76.577156, 0.000000, 0.000000},{76.071587, 7.684807, 0.000000},{
      76.071587, 7.422953, 1.988974},{76.577156, 0.000000, 0.000000},{
      76.577156, 0.000000, 0.000000}}],
    Polygon[{{76.071587, 7.684807, 0.000000},{
      74.527794, 15.369614, 0.000000},{74.527794, 14.845906, 3.977949},{
      76.071587, 7.422953, 1.988974},{76.071587, 7.684807, 0.000000}}],
    Polygon[{{74.527794, 15.369614, 0.000000},{
      71.856705, 23.054420, 0.000000},{71.856705, 22.268860, 5.966923},{
      74.527794, 14.845906, 3.977949},{74.527794, 15.369614, 0.000000}}],
    Polygon[{{76.577156, 0.000000, 0.000000},{76.071587, 7.422953, 1.988974},{
      76.071587, 6.655238, 3.842403},{76.577156, 0.000000, 0.000000},{
      76.577156, 0.000000, 0.000000}}],
    Polygon[{{76.071587, 7.422953, 1.988974},{
      74.527794, 14.845906, 3.977949},{74.527794, 13.310475, 7.684807},{
      76.071587, 6.655238, 3.842403},{76.071587, 7.422953, 1.988974}}],
    Polygon[{{74.527794, 14.845906, 3.977949},{
      71.856705, 22.268860, 5.966923},{71.856705, 19.965714, 11.527210},{
      74.527794, 13.310475, 7.684807},{74.527794, 14.845906, 3.977949}}],
    Polygon[{{76.577156, 0.000000, 0.000000},{76.071587, 6.655238, 3.842403},{
      76.071587, 5.433979, 5.433979},{76.577156, 0.000000, 0.000000},{
      76.577156, 0.000000, 0.000000}}],
    Polygon[{{76.071587, 6.655238, 3.842403},{
      74.527794, 13.310475, 7.684807},{74.527794, 10.867958, 10.867958},{
      76.071587, 5.433979, 5.433979},{76.071587, 6.655238, 3.842403}}],
    Polygon[{{74.527794, 13.310475, 7.684807},{
      71.856705, 19.965714, 11.527210},{71.856705, 16.301937, 16.301937},{
      74.527794, 10.867958, 10.867958},{74.527794, 13.310475, 7.684807}}],
    Polygon[{{76.577156, 0.000000, 0.000000},{76.071587, 5.433979, 5.433979},{
      76.071587, 3.842403, 6.655238},{76.577156, 0.000000, 0.000000},{
      76.577156, 0.000000, 0.000000}}],
    Polygon[{{76.071587, 5.433979, 5.433979},{
      74.527794, 10.867958, 10.867958},{74.527794, 7.684807, 13.310475},{
      76.071587, 3.842403, 6.655238},{76.071587, 5.433979, 5.433979}}],
    Polygon[{{74.527794, 10.867958, 10.867958},{
      71.856705, 16.301937, 16.301937},{71.856705, 11.527210, 19.965714},{
      74.527794, 7.684807, 13.310475},{74.527794, 10.867958, 10.867958}}],
    Polygon[{{76.577156, 0.000000, 0.000000},{76.071587, 3.842403, 6.655238},{
      76.071587, 1.988974, 7.422953},{76.577156, 0.000000, 0.000000},{
      76.577156, 0.000000, 0.000000}}],
    Polygon[{{76.071587, 3.842403, 6.655238},{
      74.527794, 7.684807, 13.310475},{74.527794, 3.977949, 14.845906},{
      76.071587, 1.988974, 7.422953},{76.071587, 3.842403, 6.655238}}],
    Polygon[{{74.527794, 7.684807, 13.310475},{
      71.856705, 11.527210, 19.965714},{71.856705, 5.966923, 22.268860},{
      74.527794, 3.977949, 14.845906},{74.527794, 7.684807, 13.310475}}],
    Polygon[{{76.577156, 0.000000, 0.000000},{76.071587, 1.988974, 7.422953},{
      76.071587, 0.000000, 7.684807},{76.577156, 0.000000, 0.000000},{
      76.577156, 0.000000, 0.000000}}],
    Polygon[{{76.071587, 1.988974, 7.422953},{
      74.527794, 3.977949, 14.845906},{74.527794, 0.000000, 15.369614},{
      76.071587, 0.000000, 7.684807},{76.071587, 1.988974, 7.422953}}],
    Polygon[{{74.527794, 3.977949, 14.845906},{
      71.856705, 5.966923, 22.268860},{71.856705, 0.000000, 23.054420},{
      74.527794, 0.000000, 15.369614},{74.527794, 3.977949, 14.845906}}],
    Polygon[{{76.577156, 0.000000, 0.000000},{76.071587, 0.000000, 7.684807},{
      76.071587, -1.988974, 7.422953},{76.577156, -0.000000, 0.000000},{
      76.577156, 0.000000, 0.000000}}],
    Polygon[{{76.071587, 0.000000, 7.684807},{
      74.527794, 0.000000, 15.369614},{74.527794, -3.977949, 14.845906},{
      76.071587, -1.988974, 7.422953},{76.071587, 0.000000, 7.684807}}],
    Polygon[{{74.527794, 0.000000, 15.369614},{
      71.856705, 0.000000, 23.054420},{71.856705, -5.966923, 22.268860},{
      74.527794, -3.977949, 14.845906},{74.527794, 0.000000, 15.369614}}],
    Polygon[{{76.577156, -0.000000, 0.000000},{
      76.071587, -1.988974, 7.422953},{76.071587, -3.842403, 6.655238},{
      76.577156, -0.000000, 0.000000},{76.577156, -0.000000, 0.000000}}],
    Polygon[{{76.071587, -1.988974, 7.422953},{
      74.527794, -3.977949, 14.845906},{74.527794, -7.684807, 13.310475},{
      76.071587, -3.842403, 6.655238},{76.071587, -1.988974, 7.422953}}],
    Polygon[{{74.527794, -3.977949, 14.845906},{
      71.856705, -5.966923, 22.268860},{71.856705, -11.527210, 19.965714},{
      74.527794, -7.684807, 13.310475},{74.527794, -3.977949, 14.845906}}],
    Polygon[{{76.577156, -0.000000, 0.000000},{
      76.071587, -3.842403, 6.655238},{76.071587, -5.433979, 5.433979},{
      76.577156, -0.000000, 0.000000},{76.577156, -0.000000, 0.000000}}],
    Polygon[{{76.071587, -3.842403, 6.655238},{
      74.527794, -7.684807, 13.310475},{74.527794, -10.867958, 10.867958},{
      76.071587, -5.433979, 5.433979},{76.071587, -3.842403, 6.655238}}],
    Polygon[{{74.527794, -7.684807, 13.310475},{
      71.856705, -11.527210, 19.965714},{71.856705, -16.301937, 16.301937},{
      74.527794, -10.867958, 10.867958},{74.527794, -7.684807, 13.310475}}],
    Polygon[{{76.577156, -0.000000, 0.000000},{
      76.071587, -5.433979, 5.433979},{76.071587, -6.655238, 3.842403},{
      76.577156, -0.000000, 0.000000},{76.577156, -0.000000, 0.000000}}],
    Polygon[{{76.071587, -5.433979, 5.433979},{
      74.527794, -10.867958, 10.867958},{74.527794, -13.310475, 7.684807},{
      76.071587, -6.655238, 3.842403},{76.071587, -5.433979, 5.433979}}],
    Polygon[{{74.527794, -10.867958, 10.867958},{
      71.856705, -16.301937, 16.301937},{71.856705, -19.965714, 11.527210},{
      74.527794, -13.310475, 7.684807},{74.527794, -10.867958, 10.867958}}],
    Polygon[{{76.577156, -0.000000, 0.000000},{
      76.071587, -6.655238, 3.842403},{76.071587, -7.422953, 1.988974},{
      76.577156, -0.000000, 0.000000},{76.577156, -0.000000, 0.000000}}],
    Polygon[{{76.071587, -6.655238, 3.842403},{
      74.527794, -13.310475, 7.684807},{74.527794, -14.845906, 3.977949},{
      76.071587, -7.422953, 1.988974},{76.071587, -6.655238, 3.842403}}],
    Polygon[{{74.527794, -13.310475, 7.684807},{
      71.856705, -19.965714, 11.527210},{71.856705, -22.268860, 5.966923},{
      74.527794, -14.845906, 3.977949},{74.527794, -13.310475, 7.684807}}],
    Polygon[{{76.577156, -0.000000, 0.000000},{
      76.071587, -7.422953, 1.988974},{76.071587, -7.684807, 0.000000},{
      76.577156, -0.000000, 0.000000},{76.577156, -0.000000, 0.000000}}],
    Polygon[{{76.071587, -7.422953, 1.988974},{
      74.527794, -14.845906, 3.977949},{74.527794, -15.369614, 0.000000},{
      76.071587, -7.684807, 0.000000},{76.071587, -7.422953, 1.988974}}],
    Polygon[{{74.527794, -14.845906, 3.977949},{
      71.856705, -22.268860, 5.966923},{71.856705, -23.054420, 0.000000},{
      74.527794, -15.369614, 0.000000},{74.527794, -14.845906, 3.977949}}],
    Polygon[{{76.577156, -0.000000, 0.000000},{
      76.071587, -7.684807, 0.000000},{76.071587, -7.422953, -1.988974},{
      76.577156, -0.000000, -0.000000},{76.577156, -0.000000, 0.000000}}],
    Polygon[{{76.071587, -7.684807, 0.000000},{
      74.527794, -15.369614, 0.000000},{74.527794, -14.845906, -3.977949},{
      76.071587, -7.422953, -1.988974},{76.071587, -7.684807, 0.000000}}],
    Polygon[{{74.527794, -15.369614, 0.000000},{
      71.856705, -23.054420, 0.000000},{71.856705, -22.268860, -5.966923},{
      74.527794, -14.845906, -3.977949},{74.527794, -15.369614, 0.000000}}],
    Polygon[{{76.577156, -0.000000, -0.000000},{
      76.071587, -7.422953, -1.988974},{76.071587, -6.655238, -3.842403},{
      76.577156, -0.000000, -0.000000},{76.577156, -0.000000, -0.000000}}],
    Polygon[{{76.071587, -7.422953, -1.988974},{
      74.527794, -14.845906, -3.977949},{74.527794, -13.310475, -7.684807},{
      76.071587, -6.655238, -3.842403},{76.071587, -7.422953, -1.988974}}],
    Polygon[{{74.527794, -14.845906, -3.977949},{
      71.856705, -22.268860, -5.966923},{71.856705, -19.965714, -11.527210},{
      74.527794, -13.310475, -7.684807},{74.527794, -14.845906, -3.977949}}],
    Polygon[{{76.577156, -0.000000, -0.000000},{
      76.071587, -6.655238, -3.842403},{76.071587, -5.433979, -5.433979},{
      76.577156, -0.000000, -0.000000},{76.577156, -0.000000, -0.000000}}],
    Polygon[{{76.071587, -6.655238, -3.842403},{
      74.527794, -13.310475, -7.684807},{74.527794, -10.867958, -10.867958},{
      76.071587, -5.433979, -5.433979},{76.071587, -6.655238, -3.842403}}],
    Polygon[{{74.527794, -13.310475, -7.684807},{
      71.856705, -19.965714, -11.527210},{71.856705, -16.301937, -16.301937},{
      74.527794, -10.867958, -10.867958},{74.527794, -13.310475, -7.684807}}],
    
    Polygon[{{76.577156, -0.000000, -0.000000},{
      76.071587, -5.433979, -5.433979},{76.071587, -3.842403, -6.655238},{
      76.577156, -0.000000, -0.000000},{76.577156, -0.000000, -0.000000}}],
    Polygon[{{76.071587, -5.433979, -5.433979},{
      74.527794, -10.867958, -10.867958},{74.527794, -7.684807, -13.310475},{
      76.071587, -3.842403, -6.655238},{76.071587, -5.433979, -5.433979}}],
    Polygon[{{74.527794, -10.867958, -10.867958},{
      71.856705, -16.301937, -16.301937},{71.856705, -11.527210, -19.965714},{
      74.527794, -7.684807, -13.310475},{74.527794, -10.867958, -10.867958}}],
    
    Polygon[{{76.577156, -0.000000, -0.000000},{
      76.071587, -3.842403, -6.655238},{76.071587, -1.988974, -7.422953},{
      76.577156, -0.000000, -0.000000},{76.577156, -0.000000, -0.000000}}],
    Polygon[{{76.071587, -3.842403, -6.655238},{
      74.527794, -7.684807, -13.310475},{74.527794, -3.977949, -14.845906},{
      76.071587, -1.988974, -7.422953},{76.071587, -3.842403, -6.655238}}],
    Polygon[{{74.527794, -7.684807, -13.310475},{
      71.856705, -11.527210, -19.965714},{71.856705, -5.966923, -22.268860},{
      74.527794, -3.977949, -14.845906},{74.527794, -7.684807, -13.310475}}],
    Polygon[{{76.577156, -0.000000, -0.000000},{
      76.071587, -1.988974, -7.422953},{76.071587, -0.000000, -7.684807},{
      76.577156, -0.000000, -0.000000},{76.577156, -0.000000, -0.000000}}],
    Polygon[{{76.071587, -1.988974, -7.422953},{
      74.527794, -3.977949, -14.845906},{74.527794, -0.000000, -15.369614},{
      76.071587, -0.000000, -7.684807},{76.071587, -1.988974, -7.422953}}],
    Polygon[{{74.527794, -3.977949, -14.845906},{
      71.856705, -5.966923, -22.268860},{71.856705, -0.000000, -23.054420},{
      74.527794, -0.000000, -15.369614},{74.527794, -3.977949, -14.845906}}],
    Polygon[{{76.577156, -0.000000, -0.000000},{
      76.071587, -0.000000, -7.684807},{76.071587, 1.988974, -7.422953},{
      76.577156, 0.000000, -0.000000},{76.577156, -0.000000, -0.000000}}],
    Polygon[{{76.071587, -0.000000, -7.684807},{
      74.527794, -0.000000, -15.369614},{74.527794, 3.977949, -14.845906},{
      76.071587, 1.988974, -7.422953},{76.071587, -0.000000, -7.684807}}],
    Polygon[{{74.527794, -0.000000, -15.369614},{
      71.856705, -0.000000, -23.054420},{71.856705, 5.966923, -22.268860},{
      74.527794, 3.977949, -14.845906},{74.527794, -0.000000, -15.369614}}],
    Polygon[{{76.577156, 0.000000, -0.000000},{
      76.071587, 1.988974, -7.422953},{76.071587, 3.842403, -6.655238},{
      76.577156, 0.000000, -0.000000},{76.577156, 0.000000, -0.000000}}],
    Polygon[{{76.071587, 1.988974, -7.422953},{
      74.527794, 3.977949, -14.845906},{74.527794, 7.684807, -13.310475},{
      76.071587, 3.842403, -6.655238},{76.071587, 1.988974, -7.422953}}],
    Polygon[{{74.527794, 3.977949, -14.845906},{
      71.856705, 5.966923, -22.268860},{71.856705, 11.527210, -19.965714},{
      74.527794, 7.684807, -13.310475},{74.527794, 3.977949, -14.845906}}],
    Polygon[{{76.577156, 0.000000, -0.000000},{
      76.071587, 3.842403, -6.655238},{76.071587, 5.433979, -5.433979},{
      76.577156, 0.000000, -0.000000},{76.577156, 0.000000, -0.000000}}],
    Polygon[{{76.071587, 3.842403, -6.655238},{
      74.527794, 7.684807, -13.310475},{74.527794, 10.867958, -10.867958},{
      76.071587, 5.433979, -5.433979},{76.071587, 3.842403, -6.655238}}],
    Polygon[{{74.527794, 7.684807, -13.310475},{
      71.856705, 11.527210, -19.965714},{71.856705, 16.301937, -16.301937},{
      74.527794, 10.867958, -10.867958},{74.527794, 7.684807, -13.310475}}],
    Polygon[{{76.577156, 0.000000, -0.000000},{
      76.071587, 5.433979, -5.433979},{76.071587, 6.655238, -3.842403},{
      76.577156, 0.000000, -0.000000},{76.577156, 0.000000, -0.000000}}],
    Polygon[{{76.071587, 5.433979, -5.433979},{
      74.527794, 10.867958, -10.867958},{74.527794, 13.310475, -7.684807},{
      76.071587, 6.655238, -3.842403},{76.071587, 5.433979, -5.433979}}],
    Polygon[{{74.527794, 10.867958, -10.867958},{
      71.856705, 16.301937, -16.301937},{71.856705, 19.965714, -11.527210},{
      74.527794, 13.310475, -7.684807},{74.527794, 10.867958, -10.867958}}],
    Polygon[{{76.577156, 0.000000, -0.000000},{
      76.071587, 6.655238, -3.842403},{76.071587, 7.422953, -1.988974},{
      76.577156, 0.000000, -0.000000},{76.577156, 0.000000, -0.000000}}],
    Polygon[{{76.071587, 6.655238, -3.842403},{
      74.527794, 13.310475, -7.684807},{74.527794, 14.845906, -3.977949},{
      76.071587, 7.422953, -1.988974},{76.071587, 6.655238, -3.842403}}],
    Polygon[{{74.527794, 13.310475, -7.684807},{
      71.856705, 19.965714, -11.527210},{71.856705, 22.268860, -5.966923},{
      74.527794, 14.845906, -3.977949},{74.527794, 13.310475, -7.684807}}],
    Polygon[{{76.577156, 0.000000, -0.000000},{
      76.071587, 7.422953, -1.988974},{76.071587, 7.684807, -0.000000},{
      76.577156, 0.000000, -0.000000},{76.577156, 0.000000, -0.000000}}],
    Polygon[{{76.071587, 7.422953, -1.988974},{
      74.527794, 14.845906, -3.977949},{74.527794, 15.369614, -0.000000},{
      76.071587, 7.684807, -0.000000},{76.071587, 7.422953, -1.988974}}],
    Polygon[{{74.527794, 14.845906, -3.977949},{
      71.856705, 22.268860, -5.966923},{71.856705, 23.054420, -0.000000},{
      74.527794, 15.369614, -0.000000},{74.527794, 14.845906, -3.977949}}],
    Line[{{71.856705, 23.054420, 0.000000},{71.856705, 22.268860, 5.966923},{
      71.856705, 19.965714, 11.527210},{71.856705, 16.301937, 16.301937},{
      71.856705, 11.527210, 19.965714},{71.856705, 5.966923, 22.268860},{
      71.856705, 0.000000, 23.054420},{71.856705, -5.966923, 22.268860},{
      71.856705, -11.527210, 19.965714},{71.856705, -16.301937, 16.301937},{
      71.856705, -19.965714, 11.527210},{71.856705, -22.268860, 5.966923},{
      71.856705, -23.054420, 0.000000},{71.856705, -22.268860, -5.966923},{
      71.856705, -19.965714, -11.527210},{71.856705, -16.301937, -16.301937},{
      71.856705, -11.527210, -19.965714},{71.856705, -5.966923, -22.268860},{
      71.856705, -0.000000, -23.054420},{71.856705, 5.966923, -22.268860},{
      71.856705, 11.527210, -19.965714},{71.856705, 16.301937, -16.301937},{
      71.856705, 19.965714, -11.527210},{71.856705, 22.268860, -5.966923},{
      71.856705, 23.054420, -0.000000}}],
    Polygon[{{70.512978, 23.054420, 0.000000},{
      71.856705, 23.054420, 0.000000},{71.856705, 22.268860, 5.966923},{
      70.512978, 22.268860, 5.966923},{70.512978, 23.054420, 0.000000}}],
    Polygon[{{70.512978, 22.268860, 5.966923},{
      71.856705, 22.268860, 5.966923},{71.856705, 19.965714, 11.527210},{
      70.512978, 19.965714, 11.527210},{70.512978, 22.268860, 5.966923}}],
    Polygon[{{70.512978, 19.965714, 11.527210},{
      71.856705, 19.965714, 11.527210},{71.856705, 16.301937, 16.301937},{
      70.512978, 16.301937, 16.301937},{70.512978, 19.965714, 11.527210}}],
    Polygon[{{70.512978, 16.301937, 16.301937},{
      71.856705, 16.301937, 16.301937},{71.856705, 11.527210, 19.965714},{
      70.512978, 11.527210, 19.965714},{70.512978, 16.301937, 16.301937}}],
    Polygon[{{70.512978, 11.527210, 19.965714},{
      71.856705, 11.527210, 19.965714},{71.856705, 5.966923, 22.268860},{
      70.512978, 5.966923, 22.268860},{70.512978, 11.527210, 19.965714}}],
    Polygon[{{70.512978, 5.966923, 22.268860},{
      71.856705, 5.966923, 22.268860},{71.856705, 0.000000, 23.054420},{
      70.512978, 0.000000, 23.054420},{70.512978, 5.966923, 22.268860}}],
    Polygon[{{70.512978, 0.000000, 23.054420},{
      71.856705, 0.000000, 23.054420},{71.856705, -5.966923, 22.268860},{
      70.512978, -5.966923, 22.268860},{70.512978, 0.000000, 23.054420}}],
    Polygon[{{70.512978, -5.966923, 22.268860},{
      71.856705, -5.966923, 22.268860},{71.856705, -11.527210, 19.965714},{
      70.512978, -11.527210, 19.965714},{70.512978, -5.966923, 22.268860}}],
    Polygon[{{70.512978, -11.527210, 19.965714},{
      71.856705, -11.527210, 19.965714},{71.856705, -16.301937, 16.301937},{
      70.512978, -16.301937, 16.301937},{70.512978, -11.527210, 19.965714}}],
    Polygon[{{70.512978, -16.301937, 16.301937},{
      71.856705, -16.301937, 16.301937},{71.856705, -19.965714, 11.527210},{
      70.512978, -19.965714, 11.527210},{70.512978, -16.301937, 16.301937}}],
    Polygon[{{70.512978, -19.965714, 11.527210},{
      71.856705, -19.965714, 11.527210},{71.856705, -22.268860, 5.966923},{
      70.512978, -22.268860, 5.966923},{70.512978, -19.965714, 11.527210}}],
    Polygon[{{70.512978, -22.268860, 5.966923},{
      71.856705, -22.268860, 5.966923},{71.856705, -23.054420, 0.000000},{
      70.512978, -23.054420, 0.000000},{70.512978, -22.268860, 5.966923}}],
    Polygon[{{70.512978, -23.054420, 0.000000},{
      71.856705, -23.054420, 0.000000},{71.856705, -22.268860, -5.966923},{
      70.512978, -22.268860, -5.966923},{70.512978, -23.054420, 0.000000}}],
    Polygon[{{70.512978, -22.268860, -5.966923},{
      71.856705, -22.268860, -5.966923},{71.856705, -19.965714, -11.527210},{
      70.512978, -19.965714, -11.527210},{70.512978, -22.268860, -5.966923}}],
    
    Polygon[{{70.512978, -19.965714, -11.527210},{
      71.856705, -19.965714, -11.527210},{71.856705, -16.301937, -16.301937},{
      70.512978, -16.301937, -16.301937},{
      70.512978, -19.965714, -11.527210}}],
    Polygon[{{70.512978, -16.301937, -16.301937},{
      71.856705, -16.301937, -16.301937},{71.856705, -11.527210, -19.965714},{
      70.512978, -11.527210, -19.965714},{
      70.512978, -16.301937, -16.301937}}],
    Polygon[{{70.512978, -11.527210, -19.965714},{
      71.856705, -11.527210, -19.965714},{71.856705, -5.966923, -22.268860},{
      70.512978, -5.966923, -22.268860},{70.512978, -11.527210, -19.965714}}],
    
    Polygon[{{70.512978, -5.966923, -22.268860},{
      71.856705, -5.966923, -22.268860},{71.856705, -0.000000, -23.054420},{
      70.512978, -0.000000, -23.054420},{70.512978, -5.966923, -22.268860}}],
    Polygon[{{70.512978, -0.000000, -23.054420},{
      71.856705, -0.000000, -23.054420},{71.856705, 5.966923, -22.268860},{
      70.512978, 5.966923, -22.268860},{70.512978, -0.000000, -23.054420}}],
    Polygon[{{70.512978, 5.966923, -22.268860},{
      71.856705, 5.966923, -22.268860},{71.856705, 11.527210, -19.965714},{
      70.512978, 11.527210, -19.965714},{70.512978, 5.966923, -22.268860}}],
    Polygon[{{70.512978, 11.527210, -19.965714},{
      71.856705, 11.527210, -19.965714},{71.856705, 16.301937, -16.301937},{
      70.512978, 16.301937, -16.301937},{70.512978, 11.527210, -19.965714}}],
    Polygon[{{70.512978, 16.301937, -16.301937},{
      71.856705, 16.301937, -16.301937},{71.856705, 19.965714, -11.527210},{
      70.512978, 19.965714, -11.527210},{70.512978, 16.301937, -16.301937}}],
    Polygon[{{70.512978, 19.965714, -11.527210},{
      71.856705, 19.965714, -11.527210},{71.856705, 22.268860, -5.966923},{
      70.512978, 22.268860, -5.966923},{70.512978, 19.965714, -11.527210}}],
    Polygon[{{70.512978, 22.268860, -5.966923},{
      71.856705, 22.268860, -5.966923},{71.856705, 23.054420, -0.000000},{
      70.512978, 23.054420, -0.000000},{70.512978, 22.268860, -5.966923}}],
    Line[{{-0.166528, -9.994449, 0.000000},{
      11.060874, -10.368696, 0.000000}}],
    Point[{11.060874, -10.368696, 0.000000}],
    Line[{{-0.074047, -6.665021, 0.000000},{10.466964, -6.899266, 0.000000}}],
    
    Point[{10.466964, -6.899266, 0.000000}],
    Line[{{-0.018517, -3.333127, 0.000000},{10.116077, -3.445734, 0.000000}}],
    
    Point[{10.116077, -3.445734, 0.000000}],
    Line[{{0.000000, 0.000000, 0.000000},{10.000000, 0.000000, 0.000000}}],
    Point[{10.000000, 0.000000, 0.000000}],
    Line[{{-0.018517, 3.333127, 0.000000},{10.116077, 3.445734, 0.000000}}],
    Point[{10.116077, 3.445734, 0.000000}],
    Line[{{-0.074047, 6.665021, 0.000000},{10.466964, 6.899266, 0.000000}}],
    Point[{10.466964, 6.899266, 0.000000}],
    Line[{{-0.166528, 9.994449, 0.000000},{11.060874, 10.368696, 0.000000}}],
    Point[{11.060874, 10.368696, 0.000000}],
    Line[{{11.060874, -10.368696, 0.000000},{
      15.362083, -10.119059, 0.000000}}],
    Point[{15.362083, -10.119059, 0.000000}],
    Line[{{10.466964, -6.899266, 0.000000},{15.127008, -6.721983, 0.000000}}],
    
    Point[{15.127008, -6.721983, 0.000000}],
    Line[{{10.116077, -3.445734, 0.000000},{14.987782, -3.353990, 0.000000}}],
    
    Point[{14.987782, -3.353990, 0.000000}],
    Line[{{10.000000, 0.000000, 0.000000},{14.941665, 0.000000, 0.000000}}],
    Point[{14.941665, 0.000000, 0.000000}],
    Line[{{10.116077, 3.445734, 0.000000},{14.987782, 3.353990, 0.000000}}],
    Point[{14.987782, 3.353990, 0.000000}],
    Line[{{10.466964, 6.899266, 0.000000},{15.127008, 6.721983, 0.000000}}],
    Point[{15.127008, 6.721983, 0.000000}],
    Line[{{11.060874, 10.368696, 0.000000},{15.362083, 10.119059, 0.000000}}],
    
    Point[{15.362083, 10.119059, 0.000000}],
    Line[{{15.362083, -10.119059, 0.000000},{
      17.490707, -10.028495, 0.000000}}],
    Point[{17.490707, -10.028495, 0.000000}],
    Line[{{15.127008, -6.721983, 0.000000},{16.280331, -6.690278, 0.000000}}],
    
    Point[{16.280331, -6.690278, 0.000000}],
    Line[{{14.987782, -3.353990, 0.000000},{15.581363, -3.345982, 0.000000}}],
    
    Point[{15.581363, -3.345982, 0.000000}],
    Line[{{14.941665, 0.000000, 0.000000},{15.352635, 0.000000, 0.000000}}],
    Point[{15.352635, 0.000000, 0.000000}],
    Line[{{14.987782, 3.353990, 0.000000},{15.581363, 3.345982, 0.000000}}],
    Point[{15.581363, 3.345982, 0.000000}],
    Line[{{15.127008, 6.721983, 0.000000},{16.280331, 6.690278, 0.000000}}],
    Point[{16.280331, 6.690278, 0.000000}],
    Line[{{15.362083, 10.119059, 0.000000},{17.490707, 10.028495, 0.000000}}],
    
    Point[{17.490707, 10.028495, 0.000000}],
    Line[{{17.490707, -10.028495, 0.000000},{
      30.264528, -7.772335, 0.000000}}],
    Point[{30.264528, -7.772335, 0.000000}],
    Line[{{16.280331, -6.690278, 0.000000},{29.188242, -5.223852, 0.000000}}],
    
    Point[{29.188242, -5.223852, 0.000000}],
    Line[{{15.581363, -3.345982, 0.000000},{28.559965, -2.623690, 0.000000}}],
    
    Point[{28.559965, -2.623690, 0.000000}],
    Line[{{15.352635, 0.000000, 0.000000},{28.353323, 0.000000, 0.000000}}],
    Point[{28.353323, 0.000000, 0.000000}],
    Line[{{15.581363, 3.345982, 0.000000},{28.559965, 2.623690, 0.000000}}],
    Point[{28.559965, 2.623690, 0.000000}],
    Line[{{16.280331, 6.690278, 0.000000},{29.188242, 5.223852, 0.000000}}],
    Point[{29.188242, 5.223852, 0.000000}],
    Line[{{17.490707, 10.028495, 0.000000},{30.264528, 7.772335, 0.000000}}],
    Point[{30.264528, 7.772335, 0.000000}],
    Line[{{30.264528, -7.772335, 0.000000},{34.527897, -7.751399, 0.000000}}],
    
    Point[{34.527897, -7.751399, 0.000000}],
    Line[{{29.188242, -5.223852, 0.000000},{34.527897, -5.199494, 0.000000}}],
    
    Point[{34.527897, -5.199494, 0.000000}],
    Line[{{28.559965, -2.623690, 0.000000},{34.527897, -2.608212, 0.000000}}],
    
    Point[{34.527897, -2.608212, 0.000000}],
    Line[{{28.353323, 0.000000, 0.000000},{34.527897, 0.000000, 0.000000}}],
    Point[{34.527897, 0.000000, 0.000000}],
    Line[{{28.559965, 2.623690, 0.000000},{34.527897, 2.608212, 0.000000}}],
    Point[{34.527897, 2.608212, 0.000000}],
    Line[{{29.188242, 5.223852, 0.000000},{34.527897, 5.199494, 0.000000}}],
    Point[{34.527897, 5.199494, 0.000000}],
    Line[{{30.264528, 7.772335, 0.000000},{34.527897, 7.751399, 0.000000}}],
    Point[{34.527897, 7.751399, 0.000000}],
    Line[{{34.527897, -7.751399, 0.000000},{38.877594, -7.738053, 0.000000}}],
    
    Point[{38.877594, -7.738053, 0.000000}],
    Line[{{34.527897, -5.199494, 0.000000},{37.565998, -5.190835, 0.000000}}],
    
    Point[{37.565998, -5.190835, 0.000000}],
    Line[{{34.527897, -2.608212, 0.000000},{36.823757, -2.604491, 0.000000}}],
    
    Point[{36.823757, -2.604491, 0.000000}],
    Line[{{34.527897, 0.000000, 0.000000},{36.582748, 0.000000, 0.000000}}],
    Point[{36.582748, 0.000000, 0.000000}],
    Line[{{34.527897, 2.608212, 0.000000},{36.823757, 2.604491, 0.000000}}],
    Point[{36.823757, 2.604491, 0.000000}],
    Line[{{34.527897, 5.199494, 0.000000},{37.565998, 5.190835, 0.000000}}],
    Point[{37.565998, 5.190835, 0.000000}],
    Line[{{34.527897, 7.751399, 0.000000},{38.877594, 7.738053, 0.000000}}],
    Point[{38.877594, 7.738053, 0.000000}],
    Line[{{38.877594, -7.738053, 0.000000},{41.935383, -7.709827, 0.000000}}],
    
    Point[{41.935383, -7.709827, 0.000000}],
    Line[{{37.565998, -5.190835, 0.000000},{41.935383, -5.162119, 0.000000}}],
    
    Point[{41.935383, -5.162119, 0.000000}],
    Line[{{36.823757, -2.604491, 0.000000},{41.935383, -2.587171, 0.000000}}],
    
    Point[{41.935383, -2.587171, 0.000000}],
    Line[{{36.582748, 0.000000, 0.000000},{41.935383, 0.000000, 0.000000}}],
    Point[{41.935383, 0.000000, 0.000000}],
    Line[{{36.823757, 2.604491, 0.000000},{41.935383, 2.587171, 0.000000}}],
    Point[{41.935383, 2.587171, 0.000000}],
    Line[{{37.565998, 5.190835, 0.000000},{41.935383, 5.162119, 0.000000}}],
    Point[{41.935383, 5.162119, 0.000000}],
    Line[{{38.877594, 7.738053, 0.000000},{41.935383, 7.709827, 0.000000}}],
    Point[{41.935383, 7.709827, 0.000000}],
    Line[{{41.935383, -7.709827, 0.000000},{44.611702, -7.669903, 0.000000}}],
    
    Point[{44.611702, -7.669903, 0.000000}],
    Line[{{41.935383, -5.162119, 0.000000},{44.611702, -5.133696, 0.000000}}],
    
    Point[{44.611702, -5.133696, 0.000000}],
    Line[{{41.935383, -2.587171, 0.000000},{44.611702, -2.572516, 0.000000}}],
    
    Point[{44.611702, -2.572516, 0.000000}],
    Line[{{41.935383, 0.000000, 0.000000},{44.611702, 0.000000, 0.000000}}],
    Point[{44.611702, 0.000000, 0.000000}],
    Line[{{41.935383, 2.587171, 0.000000},{44.611702, 2.572516, 0.000000}}],
    Point[{44.611702, 2.572516, 0.000000}],
    Line[{{41.935383, 5.162119, 0.000000},{44.611702, 5.133696, 0.000000}}],
    Point[{44.611702, 5.133696, 0.000000}],
    Line[{{41.935383, 7.709827, 0.000000},{44.611702, 7.669903, 0.000000}}],
    Point[{44.611702, 7.669903, 0.000000}],
    Line[{{44.611702, -7.669903, 0.000000},{47.288017, -7.629978, 0.000000}}],
    
    Point[{47.288017, -7.629978, 0.000000}],
    Line[{{44.611702, -5.133696, 0.000000},{47.288017, -5.105271, 0.000000}}],
    
    Point[{47.288017, -5.105271, 0.000000}],
    Line[{{44.611702, -2.572516, 0.000000},{47.288017, -2.557862, 0.000000}}],
    
    Point[{47.288017, -2.557862, 0.000000}],
    Line[{{44.611702, 0.000000, 0.000000},{47.288017, 0.000000, 0.000000}}],
    Point[{47.288017, 0.000000, 0.000000}],
    Line[{{44.611702, 2.572516, 0.000000},{47.288017, 2.557862, 0.000000}}],
    Point[{47.288017, 2.557862, 0.000000}],
    Line[{{44.611702, 5.133696, 0.000000},{47.288017, 5.105271, 0.000000}}],
    Point[{47.288017, 5.105271, 0.000000}],
    Line[{{44.611702, 7.669903, 0.000000},{47.288017, 7.629978, 0.000000}}],
    Point[{47.288017, 7.629978, 0.000000}],
    Line[{{47.288017, -7.629978, 0.000000},{51.007141, -7.595648, 0.000000}}],
    
    Point[{51.007141, -7.595648, 0.000000}],
    Line[{{47.288017, -5.105271, 0.000000},{51.691437, -5.076332, 0.000000}}],
    
    Point[{51.691437, -5.076332, 0.000000}],
    Line[{{47.288017, -2.557862, 0.000000},{52.095890, -2.541571, 0.000000}}],
    
    Point[{52.095890, -2.541571, 0.000000}],
    Line[{{47.288017, 0.000000, 0.000000},{52.229683, 0.000000, 0.000000}}],
    Point[{52.229683, 0.000000, 0.000000}],
    Line[{{47.288017, 2.557862, 0.000000},{52.095890, 2.541571, 0.000000}}],
    Point[{52.095890, 2.541571, 0.000000}],
    Line[{{47.288017, 5.105271, 0.000000},{51.691437, 5.076332, 0.000000}}],
    Point[{51.691437, 5.076332, 0.000000}],
    Line[{{47.288017, 7.629978, 0.000000},{51.007141, 7.595648, 0.000000}}],
    Point[{51.007141, 7.595648, 0.000000}],
    Line[{{51.007141, -7.595648, 0.000000},{54.695503, -7.549465, 0.000000}}],
    
    Point[{54.695503, -7.549465, 0.000000}],
    Line[{{51.691437, -5.076332, 0.000000},{54.695503, -5.050170, 0.000000}}],
    
    Point[{54.695503, -5.050170, 0.000000}],
    Line[{{52.095890, -2.541571, 0.000000},{54.695503, -2.530027, 0.000000}}],
    
    Point[{54.695503, -2.530027, 0.000000}],
    Line[{{52.229683, 0.000000, 0.000000},{54.695503, 0.000000, 0.000000}}],
    Point[{54.695503, 0.000000, 0.000000}],
    Line[{{52.095890, 2.541571, 0.000000},{54.695503, 2.530027, 0.000000}}],
    Point[{54.695503, 2.530027, 0.000000}],
    Line[{{51.691437, 5.076332, 0.000000},{54.695503, 5.050170, 0.000000}}],
    Point[{54.695503, 5.050170, 0.000000}],
    Line[{{51.007141, 7.595648, 0.000000},{54.695503, 7.549465, 0.000000}}],
    Point[{54.695503, 7.549465, 0.000000}],
    Line[{{54.695503, -7.549465, 0.000000},{59.738525, -7.448387, 0.000000}}],
    
    Point[{59.738525, -7.448387, 0.000000}],
    Line[{{54.695503, -5.050170, 0.000000},{60.611153, -4.967708, 0.000000}}],
    
    Point[{60.611153, -4.967708, 0.000000}],
    Line[{{54.695503, -2.530027, 0.000000},{61.115765, -2.484397, 0.000000}}],
    
    Point[{61.115765, -2.484397, 0.000000}],
    Line[{{54.695503, 0.000000, 0.000000},{61.281048, 0.000000, 0.000000}}],
    Point[{61.281048, 0.000000, 0.000000}],
    Line[{{54.695503, 2.530027, 0.000000},{61.115765, 2.484397, 0.000000}}],
    Point[{61.115765, 2.484397, 0.000000}],
    Line[{{54.695503, 5.050170, 0.000000},{60.611153, 4.967708, 0.000000}}],
    Point[{60.611153, 4.967708, 0.000000}],
    Line[{{54.695503, 7.549465, 0.000000},{59.738525, 7.448387, 0.000000}}],
    Point[{59.738525, 7.448387, 0.000000}],
    Line[{{59.738525, -7.448387, 0.000000},{68.099266, -8.551883, 0.000000}}],
    
    Point[{68.099266, -8.551883, 0.000000}],
    Line[{{60.611153, -4.967708, 0.000000},{69.056053, -5.676507, 0.000000}}],
    
    Point[{69.056053, -5.676507, 0.000000}],
    Line[{{61.115765, -2.484397, 0.000000},{69.602943, -2.831208, 0.000000}}],
    
    Point[{69.602943, -2.831208, 0.000000}],
    Line[{{61.281048, 0.000000, 0.000000},{69.781113, 0.000000, 0.000000}}],
    Point[{69.781113, 0.000000, 0.000000}],
    Line[{{61.115765, 2.484397, 0.000000},{69.602943, 2.831208, 0.000000}}],
    Point[{69.602943, 2.831208, 0.000000}],
    Line[{{60.611153, 4.967708, 0.000000},{69.056053, 5.676507, 0.000000}}],
    Point[{69.056053, 5.676507, 0.000000}],
    Line[{{59.738525, 7.448387, 0.000000},{68.099266, 8.551883, 0.000000}}],
    Point[{68.099266, 8.551883, 0.000000}],
    Line[{{68.099266, -8.551883, 0.000000},{71.127251, -8.527523, 0.000000}}],
    
    Point[{71.127251, -8.527523, 0.000000}],
    Line[{{69.056053, -5.676507, 0.000000},{71.181625, -5.663279, 0.000000}}],
    
    Point[{71.181625, -5.663279, 0.000000}],
    Line[{{69.602943, -2.831208, 0.000000},{71.213844, -2.825830, 0.000000}}],
    
    Point[{71.213844, -2.825830, 0.000000}],
    Line[{{69.781113, 0.000000, 0.000000},{71.224518, 0.000000, 0.000000}}],
    Point[{71.224518, 0.000000, 0.000000}],
    Line[{{69.602943, 2.831208, 0.000000},{71.213844, 2.825830, 0.000000}}],
    Point[{71.213844, 2.825830, 0.000000}],
    Line[{{69.056053, 5.676507, 0.000000},{71.181625, 5.663279, 0.000000}}],
    Point[{71.181625, 5.663279, 0.000000}],
    Line[{{68.099266, 8.551883, 0.000000},{71.127251, 8.527523, 0.000000}}],
    Point[{71.127251, 8.527523, 0.000000}],
    Line[{{71.127251, -8.527523, 0.000000},{75.951408, -8.545128, 0.000000}}],
    
    Point[{75.951408, -8.545128, 0.000000}],
    Line[{{71.181625, -5.663279, 0.000000},{76.302200, -5.672884, 0.000000}}],
    
    Point[{76.302200, -5.672884, 0.000000}],
    Line[{{71.213844, -2.825830, 0.000000},{76.508850, -2.830017, 0.000000}}],
    
    Point[{76.508850, -2.830017, 0.000000}],
    Line[{{71.224518, 0.000000, 0.000000},{76.577156, 0.000000, 0.000000}}],
    Point[{76.577156, 0.000000, 0.000000}],
    Line[{{71.213844, 2.825830, 0.000000},{76.508850, 2.830017, 0.000000}}],
    Point[{76.508850, 2.830017, 0.000000}],
    Line[{{71.181625, 5.663279, 0.000000},{76.302200, 5.672884, 0.000000}}],
    Point[{76.302200, 5.672884, 0.000000}],
    Line[{{71.127251, 8.527523, 0.000000},{75.951408, 8.545128, 0.000000}}],
    Point[{75.951408, 8.545128, 0.000000}],
    Line[{{75.951408, -8.545128, 0.000000},{
      100.000000, -6.506194, 0.000000}}],
    Point[{100.000000, -6.506194, 0.000000}],
    Line[{{76.302200, -5.672884, 0.000000},{
      100.000000, -4.333889, 0.000000}}],
    Point[{100.000000, -4.333889, 0.000000}],
    Line[{{76.508850, -2.830017, 0.000000},{
      100.000000, -2.166977, 0.000000}}],
    Point[{100.000000, -2.166977, 0.000000}],
    Line[{{76.577156, 0.000000, 0.000000},{100.000000, 0.000000, 0.000000}}],
    Point[{100.000000, 0.000000, 0.000000}],
    Line[{{76.508850, 2.830017, 0.000000},{100.000000, 2.166977, 0.000000}}],
    Point[{100.000000, 2.166977, 0.000000}],
    Line[{{76.302200, 5.672884, 0.000000},{100.000000, 4.333889, 0.000000}}],
    Point[{100.000000, 4.333889, 0.000000}],
    Line[{{75.951408, 8.545128, 0.000000},{100.000000, 6.506194, 0.000000}}],
    Point[{100.000000, 6.506194, 0.000000}]},
    ViewPoint -> {-0.553279, -2.995482, -0.569082}
  ]
], "Boxed",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ImageSize->{816.062, 506.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {-0.357332, 1.25387}},
  CellTags->"CompoundLens"],

Cell[TextData[{
  "Once ",
  StyleBox["DataToRayica", "Input"],
  " has generated a new lens from the database information. You can copy and \
paste the generated text output from ",
  StyleBox["DataToRayica", "Input"],
  " to simply future creation of the same object. Below, we have pasted the \
",
  StyleBox["CompoundLens", "Input"],
  " definition from ",
  StyleBox["DataToRayica", "Input"],
  " in order to generate the same ",
  StyleBox["CompoundLens", "Input"],
  " information more directly in the future."
}], "Text",
  CellTags->"CompoundLens"],

Cell["\<\
compoundlens = CompoundLens[{51.2009,121.988,24.588,16.7596,\
\[Infinity],14.1935,\[Infinity],\[Infinity],\[Infinity],-24.2071,\[Infinity],-\
18.7543,-22.5833,-373.842,-58.6585},{50.1183,50.1183,40.334,25.9869,25.9861,\
21.4849,21.4849,18.6097,22.0521,22.0521,26.0615,27.0639,36.0852,46.1088,46.\
1088},{4.94166,0.41097,13.0007,6.17458,2.05485,5.35263,2.67632,2.67632,4.\
94166,2.46582,6.58555,8.50006,1.44341,5.35263},{{1.613,57.2999},\
IntrinsicMedium,{1.516,64.},IntrinsicMedium,{1.596,39.2},{1.613,58.5997},\
IntrinsicMedium,IntrinsicMedium,{1.613,58.5997},{1.596,39.2},IntrinsicMedium,{\
1.516,64.},IntrinsicMedium,{1.606,43.9}}];\
\>", "Input",
  CellTags->"CompoundLens"],

Cell[CellGroupData[{

Cell["\<\
result = AnalyzeSystem[{
\tWedgeOfRays[20,NumberOfRays->7,BirthPoint->{-300,0,0},StartAtBirthPoint->\
False],
\tMove[compoundlens,10],
\tBoundary[177,GraphicDesign->Off]},PlotPoints->30];\
\>", "Input",
  CellTags->"CompoundLens"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .63355 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.0278079 1.02781 -0.177578 1.02781 [
[ 0 0 0 0 ]
[ 1 .63355 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .63355 L
0 .63355 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.23328 .4387 m
.22925 .42362 L
s
.22925 .42362 m
.23328 .42233 L
s
.22925 .42362 m
.2243 .40875 L
s
.2243 .40875 m
.22833 .40745 L
s
.2243 .40875 m
.2185 .39433 L
s
.23632 .45377 m
.23328 .4387 L
s
.23328 .4387 m
.23731 .43742 L
s
.23328 .42233 m
.23731 .43742 L
s
.22833 .40745 m
.23328 .42233 L
s
.22253 .39303 m
.22833 .40745 L
s
.2185 .39433 m
.22253 .39303 L
s
.2185 .39433 m
.21195 .38058 L
s
.23731 .43742 m
.24036 .4525 L
s
.21597 .37927 m
.22253 .39303 L
s
.23833 .46859 m
.23632 .45377 L
s
.23632 .45377 m
.24036 .4525 L
s
.21195 .38058 m
.21597 .37927 L
s
.21195 .38058 m
.20473 .36771 L
s
.24036 .4525 m
.24237 .46733 L
s
.20876 .36639 m
.21597 .37927 L
s
.23926 .48294 m
.23833 .46859 L
s
.23833 .46859 m
.24237 .46733 L
s
.24237 .46733 m
.24332 .48168 L
s
.20473 .36771 m
.20876 .36639 L
s
.20473 .36771 m
.19696 .35594 L
s
.201 .3546 m
.20876 .36639 L
s
.23926 .48294 m
.24332 .48168 L
s
.19696 .35594 m
.201 .3546 L
s
.19696 .35594 m
.18876 .34544 L
s
.1928 .3441 m
.201 .3546 L
s
.21977 .48945 m .24317 .49532 L .2391 .49657 L .656 .751 .92 r
F
0 g
.23784 .50928 m
.2391 .49657 L
s
.23913 .4943 m
.23926 .48294 L
s
.21977 .48945 m .22917 .48653 L .24317 .49532 L .656 .751 .92 r
F
0 g
.24192 .50803 m
.24317 .49532 L
s
.24317 .49532 m
.24332 .48168 L
s
.2391 .49657 m
.24317 .49532 L
s
.18876 .34544 m
.1928 .3441 L
s
.2355 .52086 m
.23784 .50928 L
s
.23784 .50928 m
.24192 .50803 L
s
.20216 .48171 m .22917 .48653 L .21977 .48945 L .656 .751 .92 r
F
0 g
.21977 .48945 m
.2391 .49657 L
s
.24192 .50803 m
.23959 .51961 L
s
.26017 .42611 m
.25688 .41383 L
s
.25688 .41383 m
.27749 .40581 L
s
.25688 .41383 m
.25285 .40172 L
s
.25285 .40172 m
.27486 .39789 L
s
.25285 .40172 m
.24814 .38998 L
s
.18025 .33641 m .1799 .35252 L .17053 .35562 L .544 .324 .532 r
F
.18025 .33641 m .1843 .33506 L .1799 .35252 L F
0 g
.18317 .33952 m
.18876 .34544 L
s
.18025 .33641 m
.1843 .33506 L
s
.1843 .33506 m
.1928 .3441 L
s
.17156 .32899 m
.18025 .33641 L
s
.26267 .43837 m
.26017 .42611 L
s
.26017 .42611 m
.27965 .41383 L
s
.20216 .48171 m .21568 .47748 L .22917 .48653 L .656 .751 .92 r
F
0 g
.22917 .48653 m
.24317 .49532 L
s
.24814 .38998 m
.27179 .39021 L
s
.24814 .38998 m
.24284 .37878 L
s
.17562 .32763 m
.1843 .33506 L
s
.26434 .45042 m
.26267 .43837 L
s
.26267 .43837 m
.28129 .42184 L
s
.24284 .37878 m
.26834 .38289 L
s
.24284 .37878 m
.23701 .3683 L
s
.23208 .5311 m
.2355 .52086 L
s
.2355 .52086 m
.23959 .51961 L
s
.26514 .46206 m
.26434 .45042 L
s
.18609 .47338 m .21568 .47748 L .20216 .48171 L .656 .751 .92 r
F
0 g
.20216 .48171 m
.21977 .48945 L
s
.17053 .35562 m .17609 .36989 L .16261 .37433 L .544 .324 .532 r
F
.17053 .35562 m .1799 .35252 L .17609 .36989 L F
0 g
.17053 .35562 m
.18025 .33641 L
s
.1799 .35252 m
.1843 .33506 L
s
.23959 .51961 m
.23619 .52985 L
s
.23701 .3683 m
.23075 .35872 L
s
.17156 .32899 m
.17562 .32763 L
s
.17156 .32899 m
.16284 .32333 L
s
.18609 .47338 m .20268 .46817 L .21568 .47748 L .656 .751 .92 r
F
0 g
.21568 .47748 m
.22917 .48653 L
s
.16691 .32196 m
.17562 .32763 L
s
.23075 .35872 m
.22416 .3502 L
s
.16261 .37433 m .17286 .38717 L .1563 .39259 L .544 .324 .532 r
F
.16261 .37433 m .17609 .36989 L .17286 .38717 L F
0 g
.16261 .37433 m
.17053 .35562 L
s
.17609 .36989 m
.1799 .35252 L
s
.17143 .46451 m .20268 .46817 L .18609 .47338 L .656 .751 .92 r
F
0 g
.18609 .47338 m
.20216 .48171 L
s
.039 .916 .04 r
.13145 .48245 m
.17833 .46886 L
s
0 g
.22765 .53982 m
.23208 .5311 L
s
.23208 .5311 m
.23619 .52985 L
s
.24032 .4701 m .28292 .44445 L .26507 .4731 L .656 .751 .92 r
F
0 g
.26411 .48338 m
.26507 .4731 L
s
.23619 .52985 m
.23177 .53857 L
s
.24032 .4701 m .26804 .44207 L .28292 .44445 L .656 .751 .92 r
F
0 g
.27118 .44257 m
.2824 .4297 L
s
.27832 .44371 m
.28295 .43727 L
s
.22066 .46547 m .26804 .44207 L .24032 .4701 L .656 .751 .92 r
F
0 g
.24032 .4701 m
.26507 .4731 L
s
.16284 .32333 m
.16691 .32196 L
s
.16284 .32333 m
.15422 .31954 L
s
.15831 .31816 m
.16691 .32196 L
s
.1563 .39259 m .17021 .40438 L .15149 .41047 L .544 .324 .532 r
F
.1563 .39259 m .17286 .38717 L .17021 .40438 L F
0 g
.1563 .39259 m
.16261 .37433 L
s
.17286 .38717 m
.17609 .36989 L
s
.17143 .46451 m .19018 .45858 L .20268 .46817 L .656 .751 .92 r
F
0 g
.20268 .46817 m
.21568 .47748 L
s
.26228 .4927 m
.26411 .48338 L
s
.20423 .45977 m .25587 .43882 L .22066 .46547 L .656 .751 .92 r
F
.22066 .46547 m .25587 .43882 L .26804 .44207 L F
0 g
.22066 .46547 m
.24032 .4701 L
s
.26411 .48338 m
.28233 .4511 L
s
.26507 .4731 m
.28292 .44445 L
s
.21733 .34287 m .2421 .37124 L .20044 .36148 L .544 .324 .532 r
F
.21733 .34287 m .25186 .35951 L .2421 .37124 L F
0 g
.24311 .37002 m
.26455 .37605 L
s
.24736 .36491 m
.2605 .3698 L
s
.25013 .36158 m
.25625 .36426 L
s
.21733 .34287 m
.25186 .35951 L
s
.21039 .33687 m
.21733 .34287 L
s
.15813 .45511 m .19018 .45858 L .17143 .46451 L .656 .751 .92 r
F
0 g
.17143 .46451 m
.18609 .47338 L
s
.039 .916 .04 r
.17833 .46886 m
.19541 .46267 L
s
.12286 .47442 m
.16665 .4613 L
s
0 g
.22226 .54686 m
.22765 .53982 L
s
.22765 .53982 m
.23177 .53857 L
s
.20044 .36148 m .23508 .38209 L .18866 .37843 L .544 .324 .532 r
F
.20044 .36148 m .2421 .37124 L .23508 .38209 L F
0 g
.20044 .36148 m
.21733 .34287 L
s
.23177 .53857 m
.22639 .54561 L
s
0 0 0 r
2 Mabswid
.16665 .4613 Mdot
.15149 .41047 m .16814 .42152 L .14812 .42798 L .544 .324 .532 r
F
.15149 .41047 m .17021 .40438 L .16814 .42152 L F
0 g
.5 Mabswid
.15149 .41047 m
.1563 .39259 L
s
.17021 .40438 m
.17286 .38717 L
s
.25959 .50093 m
.26228 .4927 L
s
.26228 .4927 m
.28117 .45711 L
s
.15422 .31954 m
.15831 .31816 L
s
.15422 .31954 m
.14586 .3177 L
s
.18866 .37843 m .22995 .39235 L .18015 .39436 L .544 .324 .532 r
F
.18866 .37843 m .23508 .38209 L .22995 .39235 L F
0 g
.18866 .37843 m
.20044 .36148 L
s
.20423 .45977 m .24557 .43496 L .25587 .43882 L .656 .751 .92 r
F
.19025 .45324 m .24557 .43496 L .20423 .45977 L F
0 g
.20423 .45977 m
.22066 .46547 L
s
.039 .916 .04 r
.19541 .46267 m
.20398 .45967 L
s
0 g
.14995 .31631 m
.15831 .31816 L
s
.15813 .45511 m .17817 .44873 L .19018 .45858 L .656 .751 .92 r
F
0 g
.19018 .45858 m
.20268 .46817 L
s
.21039 .33687 m
.2474 .35563 L
s
.21039 .33687 m
.20344 .3323 L
s
.18015 .39436 m .22632 .40214 L .17415 .40953 L .544 .324 .532 r
F
.18015 .39436 m .22995 .39235 L .22632 .40214 L F
0 g
.18015 .39436 m
.18866 .37843 L
s
.14614 .44516 m .17817 .44873 L .15813 .45511 L .656 .751 .92 r
F
0 g
.15813 .45511 m
.17143 .46451 L
s
.039 .916 .04 r
.16665 .4613 m
.18543 .45477 L
s
.11404 .46638 m
.15594 .4534 L
s
0 g
.21598 .55208 m
.22226 .54686 L
s
.22226 .54686 m
.22639 .54561 L
s
.27749 .40581 m
.27965 .41383 L
s
.27486 .39789 m
.27749 .40581 L
s
.27965 .41383 m
.27749 .40581 L
s
.27749 .40581 m
.3021 .39748 L
s
.27749 .40581 m
.27486 .39789 L
s
.25609 .5079 m
.25959 .50093 L
s
.25959 .50093 m
.27946 .46239 L
s
.27179 .39021 m
.27486 .39789 L
s
.27486 .39789 m
.29991 .39088 L
s
.27486 .39789 m
.27179 .39021 L
s
.14812 .42798 m .16665 .4386 L .14614 .44516 L .544 .324 .532 r
F
.14812 .42798 m .16814 .42152 L .16665 .4386 L F
0 g
.14812 .42798 m
.15149 .41047 L
s
.16814 .42152 m
.17021 .40438 L
s
.27965 .41383 m
.28129 .42184 L
s
.2813 .42184 m
.27965 .41383 L
s
.27965 .41383 m
.3039 .40416 L
s
.19025 .45324 m .23676 .4306 L .24557 .43496 L .656 .751 .92 r
F
.17835 .44599 m .23676 .4306 L .19025 .45324 L F
0 g
.19025 .45324 m
.20423 .45977 L
s
.039 .916 .04 r
.18543 .45477 m
.19013 .45318 L
s
0 g
.26834 .38289 m
.27179 .39021 L
s
.27179 .39021 m
.29736 .38448 L
s
.27179 .39021 m
.26834 .38289 L
s
.22639 .54561 m
.22013 .55083 L
s
.28129 .42184 m
.2824 .4297 L
s
.2824 .4297 m
.2813 .42184 L
s
.2813 .42184 m
.30529 .41082 L
s
.26455 .37605 m
.26834 .38289 L
s
.26834 .38289 m
.2945 .37839 L
s
.26834 .38289 m
.26456 .37605 L
s
.20344 .3323 m
.24296 .3527 L
s
.20344 .3323 m
.19659 .32925 L
s
.17415 .40953 m .224 .41155 L .17027 .42407 L .544 .324 .532 r
F
.17415 .40953 m .22632 .40214 L .224 .41155 L F
0 g
.17415 .40953 m
.18015 .39436 L
s
.2824 .4297 m
.28295 .43727 L
s
.28295 .43727 m
.2824 .4297 L
s
.14586 .3177 m
.14995 .31631 L
s
.14586 .3177 m
.13789 .31787 L
s
.2605 .3698 m
.26455 .37605 L
s
.26456 .37605 m
.2605 .3698 L
s
.142 .31648 m
.14995 .31631 L
s
.14614 .44516 m .16665 .4386 L .17817 .44873 L .656 .751 .92 r
F
0 g
.17817 .44873 m
.19018 .45858 L
s
.039 .916 .04 r
.15594 .4534 m
.17586 .44676 L
s
0 g
.28292 .44445 m
.28295 .43727 L
s
.25625 .36426 m
.2605 .3698 L
s
.2605 .3698 m
.25625 .36426 L
s
.25182 .51349 m
.25609 .5079 L
s
.25609 .5079 m
.27723 .46684 L
s
.16836 .43805 m .22924 .4258 L .17835 .44599 L .656 .751 .92 r
F
.039 .916 .04 r
.17586 .44676 m
.1783 .44595 L
s
.17835 .44599 m .22924 .4258 L .23676 .4306 L .656 .751 .92 r
F
0 g
.17835 .44599 m
.19025 .45324 L
s
.14614 .44516 m .16574 .45561 L .14558 .46202 L .544 .324 .532 r
F
.14614 .44516 m .16665 .4386 L .16574 .45561 L F
.13547 .43468 m .16665 .4386 L .14614 .44516 L .656 .751 .92 r
F
0 0 0 r
2 Mabswid
.14614 .44516 Mdot
.039 .916 .04 r
.5 Mabswid
.10501 .45833 m
.14614 .44516 L
s
0 g
.14718 .43615 m
.14812 .42798 L
s
.17027 .42407 m .2229 .42059 L .16836 .43805 L .544 .324 .532 r
F
.17027 .42407 m .224 .41155 L .2229 .42059 L F
0 g
.17027 .42407 m
.17415 .40953 L
s
.28233 .4511 m
.28292 .44445 L
s
.27735 .43914 m .30671 .4296 L .28292 .44445 L .656 .751 .92 r
F
0 g
.28233 .4511 m
.28292 .44445 L
s
.26804 .44207 m
.28292 .44445 L
s
.28295 .43732 m
.28295 .43727 L
s
.20892 .55537 m
.21598 .55208 L
s
.21598 .55208 m
.22013 .55083 L
s
.19659 .32925 m
.2386 .35077 L
s
.19659 .32925 m
.18997 .3278 L
s
.25186 .35951 m
.25625 .36426 L
s
.22013 .55083 m
.21308 .55411 L
s
.25587 .43882 m
.26804 .44207 L
s
.28233 .4511 m
.28117 .45711 L
s
.28117 .45711 m
.28233 .4511 L
s
.13789 .31787 m
.142 .31648 L
s
.13789 .31787 m
.13045 .32008 L
s
.2474 .35563 m
.25186 .35951 L
s
.25186 .35951 m .27318 .36855 L .2514 .36821 L .544 .324 .532 r
F
0 g
.2421 .37124 m
.25186 .35951 L
s
.25186 .35951 m .28091 .35892 L .27318 .36855 L .544 .324 .532 r
F
0 g
.27746 .36322 m
.28452 .36287 L
s
.27735 .43914 m .29471 .4275 L .30671 .4296 L .656 .751 .92 r
F
0 g
.29876 .42821 m
.3067 .42365 L
s
.27175 .4338 m .29471 .4275 L .27735 .43914 L .656 .751 .92 r
F
0 g
.27735 .43914 m
.28292 .44445 L
s
.2824 .4297 m
.30622 .41735 L
s
.28233 .4511 m
.30625 .43512 L
s
.2474 .35563 m
.25186 .35951 L
s
.24557 .43496 m
.25587 .43882 L
s
.13547 .43468 m .15562 .42818 L .16665 .4386 L .656 .751 .92 r
F
0 0 0 r
2 Mabswid
.16665 .4386 Mdot
.039 .916 .04 r
.5 Mabswid
.09576 .45027 m
.13724 .43655 L
s
0 g
.16665 .4386 m
.17817 .44873 L
s
.16665 .4386 m
.16814 .42152 L
s
.039 .916 .04 r
.14614 .44516 m
.16665 .4386 L
s
0 g
.13458 .31869 m
.142 .31648 L
s
.45526 .36659 m
.45133 .35227 L
s
.45133 .35227 m
.45715 .35041 L
s
.45133 .35227 m
.44664 .33812 L
s
.24685 .51759 m
.25182 .51349 L
s
.25182 .51349 m
.2745 .47037 L
s
.44664 .33812 m
.45245 .33625 L
s
.44664 .33812 m
.44127 .32435 L
s
.16836 .43805 m .22297 .42929 L .16836 .4515 L .544 .324 .532 r
F
.16836 .43805 m .2229 .42059 L .22924 .4258 L .656 .751 .92 r
F
.16836 .43805 m .2229 .42059 L .22297 .42929 L .544 .324 .532 r
F
.16022 .42944 m .2229 .42059 L .16836 .43805 L .656 .751 .92 r
F
0 0 0 r
2 Mabswid
.16836 .43805 Mdot
.039 .916 .04 r
.5 Mabswid
.16665 .4386 m
.16836 .43805 L
s
0 g
.16972 .4281 m
.17027 .42407 L
s
.039 .916 .04 r
.20398 .45967 m
.25144 .4373 L
s
.19013 .45318 m
.24023 .43245 L
s
0 g
.23508 .38209 m
.2421 .37124 L
s
.3039 .40416 m
.3021 .39748 L
s
.3021 .39748 m
.30395 .39689 L
s
.3021 .39748 m
.29991 .39088 L
s
.29991 .39088 m
.30176 .39029 L
s
.29991 .39088 m
.29736 .38448 L
s
.45837 .38086 m
.45526 .36659 L
s
.45526 .36659 m
.46108 .36475 L
s
.30529 .41082 m
.3039 .40416 L
s
.3039 .40416 m
.30575 .40357 L
s
.30395 .39689 m
.30575 .40357 L
s
.30176 .39029 m
.30395 .39689 L
s
.29921 .38389 m
.30176 .39029 L
s
.29736 .38448 m
.29921 .38389 L
s
.29736 .38448 m
.2945 .37839 L
s
.44127 .32435 m
.44708 .32247 L
s
.44127 .32435 m
.4353 .31118 L
s
0 0 0 r
2 Mabswid
.13724 .43655 Mdot
0 g
.5 Mabswid
.30575 .40357 m
.30714 .41023 L
s
.45715 .35041 m
.46108 .36475 L
s
.45245 .33625 m
.45715 .35041 L
s
.28117 .45711 m
.27946 .46239 L
s
.27946 .46239 m
.28117 .45711 L
s
.28117 .45711 m
.30532 .44009 L
s
.14558 .46202 m .16543 .47256 L .14644 .47855 L .544 .324 .532 r
F
.14558 .46202 m .16574 .45561 L .16543 .47256 L F
0 g
.14558 .46202 m
.14614 .44516 L
s
.16574 .45561 m
.16665 .4386 L
s
.44708 .32247 m
.45245 .33625 L
s
.31639 .39301 m .3172 .39283 L .31916 .40007 L .953 .687 .495 r
F
.31409 .3861 m .3172 .39283 L .31639 .39301 L F
.31409 .3861 m .31483 .38568 L .3172 .39283 L F
0 g
.29635 .37779 m
.29921 .38389 L
s
.31143 .37939 m .31483 .38568 L .31409 .3861 L .953 .687 .495 r
F
.31143 .37939 m .31208 .37875 L .31483 .38568 L F
0 g
.31483 .38568 m
.3172 .39283 L
s
.30622 .41735 m
.30529 .41082 L
s
.30529 .41082 m
.30714 .41023 L
s
.31828 .40001 m .31916 .40007 L .32066 .40728 L .953 .687 .495 r
F
.31639 .39301 m .31916 .40007 L .31828 .40001 L F
0 g
.3172 .39283 m
.31916 .40007 L
s
.46108 .36475 m
.46421 .37902 L
s
.2945 .37839 m
.29635 .37779 L
s
.2945 .37839 m
.29137 .37269 L
s
.30714 .41023 m
.30807 .41677 L
s
.30844 .373 m .31208 .37875 L .31143 .37939 L .953 .687 .495 r
F
.30844 .373 m .30898 .37214 L .31208 .37875 L F
0 g
.31208 .37875 m
.31483 .38568 L
s
.22995 .39235 m
.23508 .38209 L
s
.39952 .36782 m
.40258 .37904 L
s
.36776 .37705 m
.39952 .36782 L
s
.39584 .35673 m
.39952 .36782 L
s
.36499 .36871 m
.39584 .35673 L
s
.39161 .34595 m
.39584 .35673 L
s
.31557 .39319 m .31639 .39301 L .31828 .40001 L .953 .687 .495 r
F
.31335 .38652 m .31639 .39301 L .31557 .39319 L F
.31335 .38652 m .31409 .3861 L .31639 .39301 L F
0 g
.46062 .39485 m
.45837 .38086 L
s
.45837 .38086 m
.46421 .37902 L
s
.18997 .3278 m
.2344 .34987 L
s
.18997 .3278 m
.18368 .32798 L
s
.23676 .4306 m
.24557 .43496 L
s
.31078 .38004 m .31409 .3861 L .31335 .38652 L .953 .687 .495 r
F
.31078 .38004 m .31143 .37939 L .31409 .3861 L F
0 g
.29322 .37209 m
.29635 .37779 L
s
.44112 .30929 m
.44708 .32247 L
s
.24296 .3527 m
.2474 .35563 L
s
.2474 .35563 m
.27726 .35569 L
s
.2474 .35563 m
.24296 .3527 L
s
.2514 .36821 m .26756 .37751 L .25094 .37694 L .544 .324 .532 r
F
.2514 .36821 m .27318 .36855 L .26756 .37751 L F
0 g
.26882 .37551 m
.29137 .37269 L
s
.27306 .36875 m
.28803 .36749 L
s
.2514 .36821 m
.25186 .35951 L
s
.12613 .42363 m .15562 .42818 L .13547 .43468 L .656 .751 .92 r
F
.039 .916 .04 r
.13724 .43655 m
.15775 .43026 L
s
0 g
.13547 .43468 m
.14614 .44516 L
s
.31973 .40699 m .32066 .40728 L .32169 .41436 L .953 .687 .495 r
F
.31828 .40001 m .32066 .40728 L .31973 .40699 L F
0 g
.31916 .40007 m
.32066 .40728 L
s
.31739 .39996 m .31828 .40001 L .31973 .40699 L .953 .687 .495 r
F
.31557 .39319 m .31828 .40001 L .31739 .39996 L F
0 g
.40258 .37904 m
.40498 .39023 L
s
.37006 .3855 m
.40258 .37904 L
s
.3067 .42365 m
.30622 .41735 L
s
.30622 .41735 m
.30807 .41677 L
s
.30789 .37386 m .31143 .37939 L .31078 .38004 L .953 .687 .495 r
F
.30789 .37386 m .30844 .373 L .31143 .37939 L F
.30517 .36703 m .30898 .37214 L .30844 .373 L F
.30517 .36703 m .30561 .36596 L .30898 .37214 L F
0 g
.30898 .37214 m
.31208 .37875 L
s
.36179 .3606 m
.39161 .34595 L
s
.38689 .33565 m
.39161 .34595 L
s
.30807 .41677 m
.30855 .42306 L
s
.4353 .31118 m
.44112 .30929 L
s
.4353 .31118 m
.42881 .29882 L
s
.27175 .4338 m .28482 .42471 L .29471 .4275 L .656 .751 .92 r
F
.26613 .42844 m .28482 .42471 L .27175 .4338 L F
0 g
.27175 .4338 m
.27735 .43914 L
s
.039 .916 .04 r
.25144 .4373 m
.26939 .43155 L
s
.31475 .39338 m .31557 .39319 L .31739 .39996 L .953 .687 .495 r
F
.31261 .38693 m .31557 .39319 L .31475 .39338 L F
.31261 .38693 m .31335 .38652 L .31557 .39319 L F
.31012 .38068 m .31335 .38652 L .31261 .38693 L F
.31012 .38068 m .31078 .38004 L .31335 .38652 L F
0 g
.29137 .37269 m
.29322 .37209 L
s
.29137 .37269 m
.28803 .36749 L
s
.31973 .40699 m .32169 .41436 L .32072 .41383 L .953 .687 .495 r
F
.3188 .4067 m .31973 .40699 L .32072 .41383 L F
.31739 .39996 m .31973 .40699 L .3188 .4067 L F
.31651 .3999 m .31739 .39996 L .3188 .4067 L F
.31475 .39338 m .31739 .39996 L .31651 .3999 L F
0 g
.46421 .37902 m
.46647 .39302 L
s
.20118 .55664 m
.20892 .55537 L
s
.20892 .55537 m
.21308 .55411 L
s
.28988 .36689 m
.29322 .37209 L
s
.30734 .37473 m .31078 .38004 L .31012 .38068 L .953 .687 .495 r
F
.30734 .37473 m .30789 .37386 L .31078 .38004 L F
.32072 .41383 m .32169 .41436 L .32222 .42118 L F
0 g
.32066 .40728 m
.32169 .41436 L
s
.30473 .3681 m .30844 .373 L .30789 .37386 L .953 .687 .495 r
F
.30473 .3681 m .30517 .36703 L .30844 .373 L F
0 g
.40498 .39023 m
.40668 .4012 L
s
.37184 .39392 m
.40498 .39023 L
s
.31393 .39356 m .31475 .39338 L .31651 .3999 L .953 .687 .495 r
F
.31187 .38735 m .31475 .39338 L .31393 .39356 L F
.31187 .38735 m .31261 .38693 L .31475 .39338 L F
0 0 0 r
2 Mabswid
.24023 .43245 Mdot
.30947 .38133 m .31261 .38693 L .31187 .38735 L .953 .687 .495 r
F
.30947 .38133 m .31012 .38068 L .31261 .38693 L F
0 g
.5 Mabswid
.22632 .40214 m
.22995 .39235 L
s
.3067 .42365 m
.30855 .42306 L
s
.3188 .4067 m .32072 .41383 L .31976 .41331 L .953 .687 .495 r
F
.31786 .40641 m .3188 .4067 L .31976 .41331 L F
.31651 .3999 m .3188 .4067 L .31786 .40641 L F
.31563 .39985 m .31651 .3999 L .31786 .40641 L F
.31393 .39356 m .31651 .3999 L .31563 .39985 L F
0 g
.43464 .29692 m
.44112 .30929 L
s
.30168 .36157 m .30561 .36596 L .30517 .36703 L .953 .687 .495 r
F
.30168 .36157 m .302 .36032 L .30561 .36596 L F
0 g
.30561 .36596 m
.30898 .37214 L
s
.21308 .55411 m
.20536 .55538 L
s
.27946 .46239 m
.27723 .46684 L
s
.27723 .46683 m
.27946 .46239 L
s
.27946 .46239 m
.30394 .44445 L
s
.30679 .37559 m .31012 .38068 L .30947 .38133 L .953 .687 .495 r
F
.30679 .37559 m .30734 .37473 L .31012 .38068 L F
.32072 .41383 m .32222 .42118 L .32124 .42043 L F
.31976 .41331 m .32072 .41383 L .32124 .42043 L F
0 g
.35822 .35287 m
.38689 .33565 L
s
.38175 .32601 m
.38689 .33565 L
s
.30429 .36916 m .30789 .37386 L .30734 .37473 L .953 .687 .495 r
F
.30429 .36916 m .30473 .3681 L .30789 .37386 L F
0 g
.46196 .40835 m
.46062 .39485 L
s
.46062 .39485 m
.46647 .39302 L
s
.28803 .36749 m
.28988 .36689 L
s
.28803 .36749 m
.28452 .36287 L
s
.31311 .39374 m .31393 .39356 L .31563 .39985 L .953 .687 .495 r
F
.31112 .38777 m .31393 .39356 L .31311 .39374 L F
.31112 .38777 m .31187 .38735 L .31393 .39356 L F
.30882 .38198 m .31187 .38735 L .31112 .38777 L F
.30882 .38198 m .30947 .38133 L .31187 .38735 L F
.31786 .40641 m .31976 .41331 L .31879 .41278 L F
.31693 .40611 m .31786 .40641 L .31879 .41278 L F
.31563 .39985 m .31786 .40641 L .31693 .40611 L F
.30136 .36283 m .30517 .36703 L .30473 .3681 L F
.30136 .36283 m .30168 .36157 L .30517 .36703 L F
.31474 .39979 m .31563 .39985 L .31693 .40611 L F
.31311 .39374 m .31563 .39985 L .31474 .39979 L F
.16836 .4515 m .22428 .43763 L .17035 .46441 L .544 .324 .532 r
F
.16836 .4515 m .22297 .42929 L .22428 .43763 L F
0 g
.16836 .43805 m
.16836 .4515 L
s
.039 .916 .04 r
.22303 .42965 m
.23073 .42685 L
s
0 g
.3292 .39634 m
.32734 .38946 L
s
.32734 .38946 m
.3371 .38634 L
s
.32734 .38946 m
.32508 .38267 L
s
.28638 .36227 m
.28988 .36689 L
s
.32508 .38267 m
.33485 .37954 L
s
.32508 .38267 m
.32247 .37608 L
s
.22924 .4258 m
.23676 .4306 L
s
.31976 .41331 m .32124 .42043 L .32025 .41968 L .953 .687 .495 r
F
.31879 .41278 m .31976 .41331 L .32025 .41968 L F
.30624 .37646 m .30947 .38133 L .30882 .38198 L F
.30624 .37646 m .30679 .37559 L .30947 .38133 L F
.32124 .42043 m .32222 .42118 L .32225 .42763 L F
0 g
.32169 .41436 m
.32222 .42118 L
s
.30385 .37023 m .30734 .37473 L .30679 .37559 L .953 .687 .495 r
F
.30385 .37023 m .30429 .36916 L .30734 .37473 L F
0 g
.33063 .4032 m
.3292 .39634 L
s
.3292 .39634 m
.33897 .39323 L
s
.039 .916 .04 r
.15775 .43026 m
.16025 .42948 L
s
0 0 0 r
2 Mabswid
.15775 .43026 Mdot
.25094 .37694 m .26345 .386 L .25048 .3857 L .544 .324 .532 r
F
.25094 .37694 m .26756 .37751 L .26345 .386 L F
0 g
.5 Mabswid
.25094 .37694 m
.2514 .36821 L
s
.31229 .39392 m .31311 .39374 L .31474 .39979 L .953 .687 .495 r
F
.31038 .38819 m .31311 .39374 L .31229 .39392 L F
.31038 .38819 m .31112 .38777 L .31311 .39374 L F
.30817 .38263 m .31112 .38777 L .31038 .38819 L F
.30817 .38263 m .30882 .38198 L .31112 .38777 L F
0 g
.40668 .4012 m
.40764 .41177 L
s
.37309 .40217 m
.40668 .4012 L
s
.2386 .35077 m
.24296 .3527 L
s
.24296 .3527 m
.27361 .35326 L
s
.24296 .3527 m
.2386 .35077 L
s
.32247 .37608 m
.33223 .37294 L
s
.32247 .37608 m
.31954 .3698 L
s
.42881 .29882 m
.43464 .29692 L
s
.42881 .29882 m
.42192 .28747 L
s
.31693 .40611 m .31879 .41278 L .31782 .41226 L .953 .687 .495 r
F
.31599 .40582 m .31693 .40611 L .31782 .41226 L F
.31474 .39979 m .31693 .40611 L .31599 .40582 L F
0 g
.27134 .47293 m
.24685 .51759 L
s
.24125 .52013 m
.24685 .51759 L
s
.30104 .36408 m .30473 .3681 L .30429 .36916 L .953 .687 .495 r
F
.30104 .36408 m .30136 .36283 L .30473 .3681 L F
0 g
.46647 .39302 m
.46782 .40652 L
s
.31385 .39973 m .31474 .39979 L .31599 .40582 L .953 .687 .495 r
F
.31229 .39392 m .31474 .39979 L .31385 .39973 L F
.29471 .4275 m .30856 .42902 L .30671 .4296 L .656 .751 .92 r
F
0 g
.30625 .43512 m
.30671 .4296 L
s
.3067 .42365 m
.30671 .42881 L
s
.28292 .44445 m
.30671 .4296 L
s
0 0 0 r
2 Mabswid
.16025 .42948 Mdot
.29802 .35673 m .302 .36032 L .30168 .36157 L .953 .687 .495 r
F
.29802 .35673 m .29822 .35531 L .302 .36032 L F
0 g
.5 Mabswid
.302 .36032 m
.30561 .36596 L
s
.32124 .42043 m .32225 .42763 L .32126 .42666 L .953 .687 .495 r
F
.32025 .41968 m .32124 .42043 L .32126 .42666 L F
.31879 .41278 m .32025 .41968 L .31927 .41893 L F
.31782 .41226 m .31879 .41278 L .31927 .41893 L F
.16022 .42944 m .21772 .41498 L .2229 .42059 L .656 .751 .92 r
F
.15401 .42012 m .21772 .41498 L .16022 .42944 L F
0 g
.16022 .42944 m
.16836 .43805 L
s
.30341 .3713 m .30679 .37559 L .30624 .37646 L .953 .687 .495 r
F
.30341 .3713 m .30385 .37023 L .30679 .37559 L F
.30569 .37732 m .30882 .38198 L .30817 .38263 L F
.30569 .37732 m .30624 .37646 L .30882 .38198 L F
0 g
.33161 .40992 m
.33063 .4032 L
s
.33063 .4032 m
.34041 .40009 L
s
.13045 .32008 m
.13458 .31869 L
s
.13045 .32008 m
.12369 .32432 L
s
.29471 .4275 m .30398 .42457 L .30856 .42902 L .656 .751 .92 r
F
0 g
.3081 .43453 m
.30856 .42902 L
s
.30855 .42306 m
.30856 .42902 L
s
.30671 .4296 m
.30856 .42902 L
s
.224 .41155 m
.22632 .40214 L
s
.31038 .38819 m
.31229 .39392 L
s
.30072 .36534 m .30429 .36916 L .30385 .37023 L .953 .687 .495 r
F
.30072 .36534 m .30104 .36408 L .30429 .36916 L F
0 g
.30817 .38263 m
.31038 .38819 L
s
.31599 .40582 m .31782 .41226 L .31685 .41173 L .953 .687 .495 r
F
.31506 .40552 m .31599 .40582 L .31685 .41173 L F
.31385 .39973 m .31599 .40582 L .31506 .40552 L F
0 g
.31229 .39392 m
.31385 .39973 L
s
.35432 .34564 m
.38175 .32601 L
s
.37627 .31717 m
.38175 .32601 L
s
.31954 .3698 m
.3293 .36665 L
s
.31954 .3698 m
.31634 .36393 L
s
.28452 .36287 m
.28638 .36227 L
s
.29783 .35815 m .30168 .36157 L .30136 .36283 L .953 .687 .495 r
F
.29783 .35815 m .29802 .35673 L .30168 .36157 L F
.26613 .42844 m .27641 .42144 L .28482 .42471 L .656 .751 .92 r
F
.26048 .42305 m .27641 .42144 L .26613 .42844 L F
0 g
.26613 .42844 m
.27175 .4338 L
s
.039 .916 .04 r
.24023 .43245 m
.26274 .42522 L
s
.32025 .41968 m .32126 .42666 L .32028 .4257 L .953 .687 .495 r
F
.31927 .41893 m .32025 .41968 L .32028 .4257 L F
.31782 .41226 m .31927 .41893 L .31828 .41817 L F
.31685 .41173 m .31782 .41226 L .31828 .41817 L F
.12613 .42363 m .14509 .41748 L .15562 .42818 L .656 .751 .92 r
F
0 g
.15562 .42818 m
.16665 .4386 L
s
.039 .916 .04 r
.0863 .4422 m
.12922 .42754 L
s
.30297 .37237 m .30624 .37646 L .30569 .37732 L .953 .687 .495 r
F
.30297 .37237 m .30341 .3713 L .30624 .37646 L F
0 g
.30569 .37732 m
.30817 .38263 L
s
.42775 .28555 m
.43464 .29692 L
s
.12783 .32292 m
.13458 .31869 L
s
.37006 .3855 m
.36776 .37705 L
s
.36776 .37705 m
.36499 .36871 L
s
.33897 .39323 m
.3371 .38634 L
s
.3371 .38634 m
.36322 .3784 L
s
.3371 .38634 m
.33485 .37954 L
s
.36499 .36871 m
.36179 .3606 L
s
.32126 .42666 m .32225 .42763 L .32177 .4336 L .953 .687 .495 r
F
0 g
.32222 .42118 m
.32225 .42763 L
s
.3004 .36659 m .30385 .37023 L .30341 .3713 L .953 .687 .495 r
F
.3004 .36659 m .30072 .36534 L .30385 .37023 L F
0 g
.33485 .37954 m
.36056 .37036 L
s
.33485 .37954 m
.33223 .37294 L
s
0 0 0 r
2 Mabswid
.12922 .42754 Mdot
.28482 .42471 m .30398 .42457 L .29471 .4275 L .656 .751 .92 r
F
.039 .916 .04 r
.5 Mabswid
.26939 .43155 m
.28782 .42567 L
s
0 g
.29471 .4275 m
.30671 .4296 L
s
.33213 .41639 m
.33161 .40992 L
s
.33161 .40992 m
.3414 .40682 L
s
.31506 .40552 m .31685 .41173 L .31588 .4112 L .953 .687 .495 r
F
0 g
.31385 .39973 m
.31506 .40552 L
s
.29763 .35957 m .30136 .36283 L .30104 .36408 L .953 .687 .495 r
F
.29763 .35957 m .29783 .35815 L .30136 .36283 L F
.31927 .41893 m .32028 .4257 L .31929 .42473 L F
.31828 .41817 m .31927 .41893 L .31929 .42473 L F
0 g
.36322 .3784 m
.36544 .38654 L
s
.36056 .37036 m
.36322 .3784 L
s
.34041 .40009 m
.33897 .39323 L
s
.33897 .39323 m
.36544 .38654 L
s
.37184 .39392 m
.37006 .3855 L
s
.31685 .41173 m .31828 .41817 L .31729 .41742 L .953 .687 .495 r
F
.31588 .4112 m .31685 .41173 L .31729 .41742 L F
0 g
.35748 .36256 m
.36056 .37036 L
s
.14644 .47855 m .16572 .48946 L .1488 .49475 L .544 .324 .532 r
F
.14644 .47855 m .16543 .47256 L .16572 .48946 L F
0 g
.14558 .46202 m
.14644 .47855 L
s
.16543 .47256 m
.16574 .45561 L
s
.46196 .40835 m
.46782 .40652 L
s
0 0 0 r
2 Mabswid
.23073 .42685 Mdot
0 g
.5 Mabswid
.33223 .37294 m
.35748 .36256 L
s
.33223 .37294 m
.3293 .36665 L
s
.27723 .46684 m
.2745 .47037 L
s
.27451 .47037 m
.27723 .46683 L
s
.27723 .46683 m
.30213 .44811 L
s
.36179 .3606 m
.35822 .35287 L
s
.31634 .36393 m
.32611 .36077 L
s
.31634 .36393 m
.31292 .35857 L
s
.36544 .38654 m
.36715 .39465 L
s
.32126 .42666 m .32177 .4336 L .3208 .43244 L .953 .687 .495 r
F
.32028 .4257 m .32126 .42666 L .3208 .43244 L F
0 g
.18368 .32798 m
.23044 .35004 L
s
.18368 .32798 m
.17784 .3298 L
s
.30008 .36785 m .30341 .3713 L .30297 .37237 L .953 .687 .495 r
F
0 g
.30297 .37237 m
.30569 .37732 L
s
.30008 .36785 m .3004 .36659 L .30341 .3713 L .953 .687 .495 r
F
0 g
.30532 .44009 m
.30625 .43512 L
s
.30625 .43512 m
.3081 .43453 L
s
.29744 .36099 m .30104 .36408 L .30072 .36534 L .953 .687 .495 r
F
.29744 .36099 m .29763 .35957 L .30104 .36408 L F
.29426 .35257 m .29822 .35531 L .29802 .35673 L F
.29426 .35257 m .29433 .35101 L .29822 .35531 L F
0 g
.29822 .35531 m
.302 .36032 L
s
.31828 .41817 m .31929 .42473 L .3183 .42377 L .953 .687 .495 r
F
.31729 .41742 m .31828 .41817 L .3183 .42377 L F
0 g
.35403 .35511 m
.35748 .36256 L
s
.3414 .40682 m
.34041 .40009 L
s
.34041 .40009 m
.36715 .39465 L
s
.31588 .4112 m .31729 .41742 L .3163 .41667 L .953 .687 .495 r
F
0 g
.31506 .40552 m
.31588 .4112 L
s
.3081 .43453 m
.30718 .43951 L
s
.37309 .40217 m
.37184 .39392 L
s
.2229 .42059 m
.22924 .4258 L
s
.25048 .3857 m .26055 .39411 L .25002 .3945 L .544 .324 .532 r
F
.25048 .3857 m .26345 .386 L .26055 .39411 L F
0 g
.25048 .3857 m
.25094 .37694 L
s
.32028 .4257 m .3208 .43244 L .31983 .43127 L .953 .687 .495 r
F
.31929 .42473 m .32028 .4257 L .31983 .43127 L F
0 0 0 r
2 Mabswid
.28782 .42567 Mdot
0 g
.5 Mabswid
.3293 .36665 m
.35403 .35511 L
s
.3293 .36665 m
.32611 .36077 L
s
.29419 .35414 m .29802 .35673 L .29783 .35815 L .953 .687 .495 r
F
.29419 .35414 m .29426 .35257 L .29802 .35673 L F
0 g
.36715 .39465 m
.36835 .4026 L
s
.29724 .36241 m .30072 .36534 L .3004 .36659 L .953 .687 .495 r
F
.29724 .36241 m .29744 .36099 L .30072 .36534 L F
0 g
.33213 .41639 m
.34193 .4133 L
s
.31729 .41742 m .3183 .42377 L .31731 .4228 L .953 .687 .495 r
F
.3163 .41667 m .31729 .41742 L .31731 .4228 L F
.28091 .35892 m .28244 .36555 L .27318 .36855 L .544 .324 .532 r
F
.28091 .35892 m .28277 .35831 L .28244 .36555 L F
0 g
.25186 .35951 m
.28091 .35892 L
s
.28265 .36082 m
.28452 .36287 L
s
.28091 .35892 m
.28277 .35831 L
s
.28277 .35831 m
.28638 .36227 L
s
.27726 .35569 m
.28091 .35892 L
s
.35822 .35287 m
.35432 .34564 L
s
.2229 .42059 m
.224 .41155 L
s
.42192 .28747 m
.42775 .28555 L
s
.42192 .28747 m
.41472 .2773 L
s
.2344 .34987 m
.2386 .35077 L
s
.2386 .35077 m
.27005 .35165 L
s
.2386 .35077 m
.23441 .34987 L
s
.31929 .42473 m .31983 .43127 L .31885 .43011 L .953 .687 .495 r
F
.3183 .42377 m .31929 .42473 L .31885 .43011 L F
.28482 .42471 m .29937 .4201 L .30398 .42457 L .656 .751 .92 r
F
0 g
.30398 .42457 m
.30856 .42902 L
s
.27641 .42144 m .29937 .4201 L .28482 .42471 L .656 .751 .92 r
F
0 g
.28482 .42471 m
.29471 .4275 L
s
.039 .916 .04 r
.28782 .42567 m
.30078 .42147 L
s
0 g
.35028 .34814 m
.35403 .35511 L
s
.35017 .33902 m
.37627 .31717 L
s
.37054 .30928 m
.37627 .31717 L
s
.27911 .35509 m
.28277 .35831 L
s
.29412 .3557 m .29783 .35815 L .29763 .35957 L .953 .687 .495 r
F
.29412 .3557 m .29419 .35414 L .29783 .35815 L F
0 g
.34193 .4133 m
.3414 .40682 L
s
.3414 .40682 m
.36835 .4026 L
s
.29704 .36384 m .3004 .36659 L .30008 .36785 L .953 .687 .495 r
F
0 g
.30008 .36785 m
.30297 .37237 L
s
.29704 .36384 m .29724 .36241 L .3004 .36659 L .953 .687 .495 r
F
0 g
.31292 .35857 m
.3227 .35539 L
s
.31292 .35857 m
.30934 .3538 L
s
.3208 .43244 m .32177 .4336 L .32079 .43899 L .953 .687 .495 r
F
0 g
.32177 .4336 m
.32225 .42763 L
s
.3163 .41667 m .31731 .4228 L .31632 .42183 L .953 .687 .495 r
F
0 g
.31588 .4112 m
.3163 .41667 L
s
.27318 .36855 m .2821 .3728 L .26756 .37751 L .544 .324 .532 r
F
.27318 .36855 m .28244 .36555 L .2821 .3728 L F
0 g
.27318 .36855 m
.28091 .35892 L
s
.28244 .36555 m
.28277 .35831 L
s
.37377 .41012 m
.37309 .40217 L
s
.3183 .42377 m .31885 .43011 L .31788 .42895 L .953 .687 .495 r
F
.31731 .4228 m .3183 .42377 L .31788 .42895 L F
.11818 .41198 m .14509 .41748 L .12613 .42363 L .656 .751 .92 r
F
.039 .916 .04 r
.12922 .42754 m
.14914 .42169 L
s
0 g
.12613 .42363 m
.13547 .43468 L
s
.039 .916 .04 r
.07663 .43414 m
.12211 .41808 L
s
0 g
.32611 .36077 m
.35028 .34814 L
s
.32611 .36077 m
.3227 .35539 L
s
.29406 .35727 m .29763 .35957 L .29744 .36099 L .953 .687 .495 r
F
.29406 .35727 m .29412 .3557 L .29763 .35957 L F
0 g
.36835 .4026 m
.369 .41025 L
s
.3208 .43244 m .32079 .43899 L .31985 .43765 L .953 .687 .495 r
F
.31983 .43127 m .3208 .43244 L .31985 .43765 L F
.26048 .42305 m .2692 .41777 L .27641 .42144 L .656 .751 .92 r
F
.2548 .41764 m .2692 .41777 L .26048 .42305 L F
0 g
.26048 .42305 m
.26613 .42844 L
s
.039 .916 .04 r
.23073 .42685 m
.25596 .41875 L
s
0 g
.42056 .27537 m
.42775 .28555 L
s
.30394 .44445 m
.30532 .44009 L
s
.30532 .44009 m
.30718 .43951 L
s
.17035 .46441 m .22691 .4456 L .17455 .47672 L .544 .324 .532 r
F
.17035 .46441 m .22428 .43763 L .22691 .4456 L F
0 g
.16836 .4515 m
.17035 .46441 L
s
.039 .916 .04 r
.16836 .43805 m
.2229 .42059 L
s
.31731 .4228 m .31788 .42895 L .3169 .42778 L .953 .687 .495 r
F
.31632 .42183 m .31731 .4228 L .3169 .42778 L F
.29045 .34918 m .29433 .35101 L .29426 .35257 L F
.29045 .34918 m .29039 .3475 L .29433 .35101 L F
0 g
.29433 .35101 m
.29822 .35531 L
s
.35432 .34564 m
.35017 .33902 L
s
.29399 .35884 m .29744 .36099 L .29724 .36241 L .953 .687 .495 r
F
.29399 .35884 m .29406 .35727 L .29744 .36099 L F
0 g
.19289 .55584 m
.20118 .55664 L
s
.20118 .55664 m
.20536 .55538 L
s
.31983 .43127 m .31985 .43765 L .31891 .43631 L .953 .687 .495 r
F
.31885 .43011 m .31983 .43127 L .31891 .43631 L F
.32749 .41792 m .34198 .41942 L .33217 .42251 L .656 .751 .92 r
F
0 g
.33173 .42818 m
.33217 .42251 L
s
.33213 .41639 m
.33214 .4184 L
s
.34627 .34177 m
.35028 .34814 L
s
.30718 .43951 m
.3058 .44387 L
s
.34193 .4133 m
.369 .41025 L
s
.29051 .35087 m .29426 .35257 L .29419 .35414 L .953 .687 .495 r
F
.29051 .35087 m .29045 .34918 L .29426 .35257 L F
.31632 .42183 m .3169 .42778 L .31593 .42662 L F
0 g
.3163 .41667 m
.31632 .42183 L
s
.3769 .40925 m .40786 .42178 L .37388 .41764 L .656 .751 .92 r
F
0 g
.37377 .41012 m
.37654 .41026 L
s
.37979 .41042 m
.40764 .41177 L
s
.3769 .40925 m .41467 .4098 L .40786 .42178 L .656 .751 .92 r
F
0 g
.37388 .41764 m
.40786 .42178 L
s
.40731 .43107 m
.40786 .42178 L
s
.29392 .3604 m .29724 .36241 L .29704 .36384 L .953 .687 .495 r
F
0 g
.29704 .36384 m
.30008 .36785 L
s
.29392 .3604 m .29399 .35884 L .29724 .36241 L .953 .687 .495 r
F
.26756 .37751 m .28177 .38008 L .26345 .386 L .544 .324 .532 r
F
.26756 .37751 m .2821 .3728 L .28177 .38008 L F
0 g
.26756 .37751 m
.27318 .36855 L
s
.039 .916 .04 r
.14914 .42169 m
.15406 .42021 L
s
0 0 0 r
2 Mabswid
.14914 .42169 Mdot
.31885 .43011 m .31891 .43631 L .31797 .43496 L .953 .687 .495 r
F
.31788 .42895 m .31885 .43011 L .31797 .43496 L F
0 g
.5 Mabswid
.2745 .47037 m
.27134 .47293 L
s
.27134 .47293 m
.27451 .47037 L
s
.27451 .47037 m
.29991 .45101 L
s
.039 .916 .04 r
.30078 .42147 m
.31213 .41775 L
s
0 0 0 r
2 Mabswid
.30078 .42147 Mdot
0 g
.5 Mabswid
.27726 .35569 m
.27911 .35509 L
s
.27726 .35569 m
.27361 .35326 L
s
.27641 .42144 m .29475 .41562 L .29937 .4201 L .656 .751 .92 r
F
0 g
.29937 .4201 m
.30398 .42457 L
s
.2692 .41777 m .29475 .41562 L .27641 .42144 L .656 .751 .92 r
F
0 g
.27641 .42144 m
.28482 .42471 L
s
.039 .916 .04 r
.26274 .42522 m
.27563 .42109 L
s
0 g
.20536 .55538 m
.19708 .55457 L
s
.30934 .3538 m
.31912 .35062 L
s
.23511 .52102 m
.24125 .52013 L
s
.24125 .52013 m
.26777 .47446 L
s
.25002 .3945 m .25871 .4019 L .24956 .40333 L .544 .324 .532 r
F
.25002 .3945 m .26055 .39411 L .25871 .4019 L F
0 g
.25002 .3945 m
.25048 .3857 L
s
.29057 .35255 m .29419 .35414 L .29412 .3557 L .953 .687 .495 r
F
.29057 .35255 m .29051 .35087 L .29419 .35414 L F
0 g
.3227 .35539 m
.34627 .34177 L
s
.3227 .35539 m
.31912 .35062 L
s
.45407 .4112 m .46824 .41932 L .46237 .42113 L .656 .751 .92 r
F
0 g
.46183 .433 m
.46237 .42113 L
s
.46196 .40835 m
.4622 .41586 L
s
.37377 .41012 m
.37388 .41764 L
s
.27547 .35265 m
.27911 .35509 L
s
.2821 .3728 m
.28244 .36555 L
s
.31788 .42895 m .31797 .43496 L .31702 .43362 L .953 .687 .495 r
F
.3169 .42778 m .31788 .42895 L .31702 .43362 L F
0 0 0 r
2 Mabswid
.2229 .42059 Mdot
0 g
.5 Mabswid
.2229 .42059 m
.22297 .42929 L
s
.31985 .43765 m .32079 .43899 L .31933 .44371 L .953 .687 .495 r
F
0 g
.32079 .43899 m
.32177 .4336 L
s
.29064 .35423 m .29412 .3557 L .29406 .35727 L .953 .687 .495 r
F
.29064 .35423 m .29057 .35255 L .29412 .3557 L F
0 0 0 r
2 Mabswid
.15406 .42021 Mdot
.15401 .42012 m .21374 .40894 L .21772 .41498 L .656 .751 .92 r
F
0 g
.5 Mabswid
.21772 .41498 m
.2229 .42059 L
s
.14993 .41002 m .21374 .40894 L .15401 .42012 L .656 .751 .92 r
F
.039 .916 .04 r
.16025 .42948 m
.21677 .41374 L
s
0 g
.15401 .42012 m
.16022 .42944 L
s
.3169 .42778 m .31702 .43362 L .31608 .43227 L .953 .687 .495 r
F
.31593 .42662 m .3169 .42778 L .31608 .43227 L F
0 g
.34583 .33313 m
.37054 .30928 L
s
.35017 .33902 m
.34583 .33313 L
s
.31985 .43765 m .31933 .44371 L .31843 .44221 L .953 .687 .495 r
F
.31891 .43631 m .31985 .43765 L .31843 .44221 L F
.2907 .35592 m .29406 .35727 L .29399 .35884 L F
.2907 .35592 m .29064 .35423 L .29406 .35727 L F
0 g
.34208 .3361 m
.34627 .34177 L
s
.23044 .35004 m
.2344 .34987 L
s
.23441 .34987 m
.26662 .35091 L
s
.23441 .34987 m
.23044 .35004 L
s
.34096 .41367 m .3691 .41749 L .34198 .41942 L .656 .751 .92 r
F
0 g
.34193 .4133 m
.34193 .4138 L
s
.32749 .41792 m .34096 .41367 L .34198 .41942 L .656 .751 .92 r
F
0 g
.33217 .42251 m
.34198 .41942 L
s
.34155 .42509 m
.34198 .41942 L
s
.45407 .4112 m .46552 .40763 L .46824 .41932 L .656 .751 .92 r
F
0 g
.46772 .43119 m
.46824 .41932 L
s
.46782 .40652 m
.46824 .41932 L
s
.46237 .42113 m
.46824 .41932 L
s
.33081 .43329 m
.33173 .42818 L
s
.33173 .42818 m
.34155 .42509 L
s
.26345 .386 m .28144 .38738 L .26055 .39411 L .544 .324 .532 r
F
.26345 .386 m .28177 .38008 L .28144 .38738 L F
0 g
.26345 .386 m
.26756 .37751 L
s
.31593 .42662 m .31608 .43227 L .31513 .43093 L .953 .687 .495 r
F
0 g
.31593 .42662 m
.31632 .42183 L
s
.30213 .44811 m
.30394 .44445 L
s
.30394 .44445 m
.3058 .44387 L
s
.31891 .43631 m .31843 .44221 L .31754 .44071 L .953 .687 .495 r
F
.31797 .43496 m .31891 .43631 L .31754 .44071 L F
.28666 .34662 m .29039 .3475 L .29045 .34918 L F
.28666 .34662 m .28646 .34484 L .29039 .3475 L F
0 g
.29039 .3475 m
.29433 .35101 L
s
.29076 .3576 m .29399 .35884 L .29392 .3604 L .953 .687 .495 r
F
0 g
.29392 .3604 m
.29704 .36384 L
s
.29076 .3576 m .2907 .35592 L .29399 .35884 L .953 .687 .495 r
F
0 g
.12369 .32432 m
.12783 .32292 L
s
.12369 .32432 m
.11772 .33054 L
s
.41472 .2773 m
.42056 .27537 L
s
.3058 .44387 m
.30399 .44753 L
s
.31912 .35062 m
.34208 .3361 L
s
.31797 .43496 m .31754 .44071 L .31664 .43921 L .953 .687 .495 r
F
.31702 .43362 m .31797 .43496 L .31664 .43921 L F
.28685 .34839 m .29045 .34918 L .29051 .35087 L F
.28685 .34839 m .28666 .34662 L .29045 .34918 L F
0 0 0 r
2 Mabswid
.12211 .41808 Mdot
0 g
.5 Mabswid
.17784 .3298 m
.22677 .35128 L
s
.17784 .3298 m
.17255 .33326 L
s
.30566 .34972 m .3188 .35278 L .30536 .35715 L .544 .324 .532 r
F
.30566 .34972 m .31545 .34652 L .3188 .35278 L F
.3228 .41331 m .34096 .41367 L .32749 .41792 L .656 .751 .92 r
F
0 g
.32749 .41792 m
.33217 .42251 L
s
.30193 .34638 m
.30566 .34972 L
s
.2692 .41777 m .29011 .41112 L .29475 .41562 L .656 .751 .92 r
F
0 g
.29475 .41562 m
.29937 .4201 L
s
.26304 .41375 m .29011 .41112 L .2692 .41777 L .656 .751 .92 r
F
.039 .916 .04 r
.27563 .42109 m
.29421 .41509 L
s
.2548 .41764 m .26304 .41375 L .2692 .41777 L .656 .751 .92 r
F
0 g
.2692 .41777 m
.27641 .42144 L
s
.039 .916 .04 r
.31213 .41775 m
.32351 .41401 L
s
0 g
.37341 .4246 m
.37388 .41764 L
s
.24909 .4122 m .26304 .41375 L .2548 .41764 L .656 .751 .92 r
F
0 g
.2548 .41764 m
.26048 .42305 L
s
.039 .916 .04 r
.25596 .41875 m
.26572 .41562 L
s
.34096 .41367 m .36365 .41204 L .3691 .41749 L .656 .751 .92 r
F
0 g
.36864 .4242 m
.3691 .41749 L
s
.34198 .41942 m
.3691 .41749 L
s
.369 .41025 m
.3691 .41749 L
s
.11818 .41198 m .13507 .40648 L .14509 .41748 L .656 .751 .92 r
F
.039 .916 .04 r
.12211 .41808 m
.14079 .41286 L
s
0 g
.14509 .41748 m
.15562 .42818 L
s
.31702 .43362 m .31664 .43921 L .31574 .43771 L .953 .687 .495 r
F
.31608 .43227 m .31702 .43362 L .31574 .43771 L F
0 g
.27361 .35326 m
.27547 .35265 L
s
.27361 .35326 m
.27005 .35165 L
s
.28704 .35016 m .29051 .35087 L .29057 .35255 L .953 .687 .495 r
F
.28704 .35016 m .28685 .34839 L .29051 .35087 L F
0 g
.12187 .32914 m
.12783 .32292 L
s
.1488 .49475 m .16663 .5063 L .15276 .51061 L .544 .324 .532 r
F
.1488 .49475 m .16572 .48946 L .16663 .5063 L F
0 g
.14644 .47855 m
.1488 .49475 L
s
.16543 .47256 m
.16572 .48946 L
s
.28177 .38008 m
.2821 .3728 L
s
.27191 .35104 m
.27547 .35265 L
s
.28723 .35194 m .29057 .35255 L .29064 .35423 L .953 .687 .495 r
F
.28723 .35194 m .28704 .35016 L .29057 .35255 L F
.31608 .43227 m .31574 .43771 L .31485 .4362 L F
.31513 .43093 m .31608 .43227 L .31485 .4362 L F
.24956 .40333 m .25785 .4094 L .24909 .4122 L .544 .324 .532 r
F
.24956 .40333 m .25871 .4019 L .25785 .4094 L F
0 g
.24956 .40333 m
.25002 .3945 L
s
.40731 .43107 m
.40601 .43946 L
s
.37341 .4246 m
.40731 .43107 L
s
.26055 .39411 m .28111 .39471 L .25871 .4019 L .544 .324 .532 r
F
.26055 .39411 m .28144 .38738 L .28111 .39471 L F
0 g
.26055 .39411 m
.26345 .386 L
s
.34065 .43021 m
.34155 .42509 L
s
.34155 .42509 m
.36864 .4242 L
s
.31843 .44221 m .31933 .44371 L .31739 .44768 L .953 .687 .495 r
F
0 g
.31933 .44371 m
.32079 .43899 L
s
.28743 .35371 m .29064 .35423 L .2907 .35592 L .953 .687 .495 r
F
.28743 .35371 m .28723 .35194 L .29064 .35423 L F
0 g
.27134 .47293 m
.26777 .47446 L
s
.29733 .4531 m
.27134 .47293 L
s
.26777 .47446 m
.27134 .47293 L
s
.31513 .43093 m .31485 .4362 L .31395 .4347 L .953 .687 .495 r
F
0 g
.31513 .43093 m
.31593 .42662 L
s
.22297 .42929 m
.22428 .43763 L
s
.32944 .43777 m
.33081 .43329 L
s
.33081 .43329 m
.34065 .43021 L
s
.31843 .44221 m .31739 .44768 L .31656 .44605 L .953 .687 .495 r
F
.31754 .44071 m .31843 .44221 L .31656 .44605 L F
.28762 .35549 m .2907 .35592 L .29076 .3576 L F
0 g
.29076 .3576 m
.29392 .3604 L
s
.28762 .35549 m .28743 .35371 L .2907 .35592 L .953 .687 .495 r
F
.039 .916 .04 r
.29421 .41509 m
.30561 .41138 L
s
0 0 0 r
2 Mabswid
.29421 .41509 Mdot
.31754 .44071 m .31656 .44605 L .31573 .44441 L .953 .687 .495 r
F
.31664 .43921 m .31754 .44071 L .31573 .44441 L F
0 g
.5 Mabswid
.29991 .45101 m
.30213 .44811 L
s
.30213 .44811 m
.30399 .44753 L
s
.31545 .34652 m .33749 .34 L .3188 .35278 L .544 .324 .532 r
F
.31545 .34652 m .33778 .33123 L .33749 .34 L F
0 g
.30566 .34972 m
.31545 .34652 L
s
.31545 .34652 m
.33778 .33123 L
s
.33778 .33123 m
.34208 .3361 L
s
.31174 .34318 m
.31545 .34652 L
s
.28294 .34492 m .28646 .34484 L .28666 .34662 L .953 .687 .495 r
F
.28294 .34492 m .28262 .34309 L .28646 .34484 L F
0 g
.28646 .34484 m
.29039 .3475 L
s
.31664 .43921 m .31573 .44441 L .3149 .44278 L .953 .687 .495 r
F
.31574 .43771 m .31664 .43921 L .3149 .44278 L F
0 g
.46034 .44375 m
.46183 .433 L
s
.46183 .433 m
.46772 .43119 L
s
.34136 .32806 m .36466 .30248 L .37852 .30988 L .544 .324 .532 r
F
0 g
.35871 .29687 m
.36466 .30248 L
s
.30399 .44753 m
.30178 .45043 L
s
.17455 .47672 m .2311 .45311 L .18136 .48831 L .544 .324 .532 r
F
.17455 .47672 m .22691 .4456 L .2311 .45311 L F
0 g
.17035 .46441 m
.17455 .47672 L
s
.30193 .34638 m
.31174 .34318 L
s
.30193 .34638 m
.29823 .34386 L
s
.30536 .35715 m .32141 .3593 L .30506 .3646 L .544 .324 .532 r
F
.30536 .35715 m .3188 .35278 L .32141 .3593 L F
0 g
.30536 .35715 m
.30566 .34972 L
s
.22677 .35128 m
.23044 .35004 L
s
.23044 .35004 m
.26339 .35105 L
s
.23044 .35004 m
.22677 .35128 L
s
.28327 .34676 m .28666 .34662 L .28685 .34839 L .953 .687 .495 r
F
.28327 .34676 m .28294 .34492 L .28666 .34662 L F
.31574 .43771 m .3149 .44278 L .31406 .44114 L F
.31485 .4362 m .31574 .43771 L .31406 .44114 L F
.25785 .4094 m .28545 .4066 L .26304 .41375 L .656 .751 .92 r
F
.24909 .4122 m .25785 .4094 L .26304 .41375 L F
.26304 .41375 m .28545 .4066 L .29011 .41112 L F
0 g
.26304 .41375 m
.2692 .41777 L
s
.29011 .41112 m
.29475 .41562 L
s
0 0 0 r
2 Mabswid
.21677 .41374 Mdot
.33917 .40812 m .36365 .41204 L .34096 .41367 L .656 .751 .92 r
F
.3228 .41331 m .33917 .40812 L .34096 .41367 L F
0 g
.5 Mabswid
.34096 .41367 m
.34198 .41942 L
s
.37237 .43089 m
.37341 .4246 L
s
.36864 .4242 m
.36763 .43025 L
s
.28359 .34859 m .28685 .34839 L .28704 .35016 L .953 .687 .495 r
F
.28359 .34859 m .28327 .34676 L .28685 .34839 L F
0 g
.28144 .38738 m
.28177 .38008 L
s
.31809 .40868 m .33917 .40812 L .3228 .41331 L .656 .751 .92 r
F
0 g
.3228 .41331 m
.32749 .41792 L
s
.31485 .4362 m .31406 .44114 L .31323 .4395 L .953 .687 .495 r
F
.31395 .4347 m .31485 .4362 L .31323 .4395 L F
0 g
.27005 .35165 m
.27191 .35104 L
s
.27005 .35165 m
.26662 .35091 L
s
.25871 .4019 m .28077 .40206 L .25785 .4094 L .544 .324 .532 r
F
.25871 .4019 m .28111 .39471 L .28077 .40206 L F
0 g
.25871 .4019 m
.26055 .39411 L
s
.039 .916 .04 r
.14079 .41286 m
.14998 .41019 L
s
0 0 0 r
2 Mabswid
.14079 .41286 Mdot
.28391 .35043 m .28704 .35016 L .28723 .35194 L .953 .687 .495 r
F
.28391 .35043 m .28359 .34859 L .28704 .35016 L F
0 g
.5 Mabswid
.22854 .52025 m
.23511 .52102 L
s
.23511 .52102 m
.26387 .47493 L
s
.31395 .4347 m .31323 .4395 L .31239 .43786 L .953 .687 .495 r
F
0 g
.31395 .4347 m
.31513 .43093 L
s
.26849 .3503 m
.27191 .35104 L
s
.46772 .43119 m
.46625 .44194 L
s
.33929 .43468 m
.34065 .43021 L
s
.34065 .43021 m
.36763 .43025 L
s
.28423 .35226 m .28723 .35194 L .28743 .35371 L .953 .687 .495 r
F
.28423 .35226 m .28391 .35043 L .28723 .35194 L F
0 g
.18418 .55297 m
.19289 .55584 L
s
.19289 .55584 m
.19708 .55457 L
s
.24909 .4122 m .25796 .41661 L .24862 .42111 L .544 .324 .532 r
F
.24909 .4122 m .25785 .4094 L .25796 .41661 L F
.24336 .40674 m .25785 .4094 L .24909 .4122 L .656 .751 .92 r
F
0 0 0 r
2 Mabswid
.24909 .4122 Mdot
.039 .916 .04 r
.5 Mabswid
.2229 .42059 m
.24909 .4122 L
s
0 g
.24932 .40783 m
.24956 .40333 L
s
.33917 .40812 m .35817 .40656 L .36365 .41204 L .656 .751 .92 r
F
.039 .916 .04 r
.32351 .41401 m
.33945 .40885 L
s
0 g
.36365 .41204 m
.3691 .41749 L
s
.33343 .32724 m
.33778 .33123 L
s
.11173 .39971 m .13507 .40648 L .11818 .41198 L .656 .751 .92 r
F
0 g
.11818 .41198 m
.12613 .42363 L
s
.34136 .32806 m .37852 .30988 L .34972 .33434 L .544 .324 .532 r
F
0 g
.34136 .32806 m
.36466 .30248 L
s
.34136 .32806 m
.34583 .33313 L
s
.33685 .32391 m
.34136 .32806 L
s
.28455 .3541 m .28743 .35371 L .28762 .35549 L .953 .687 .495 r
F
0 g
.28762 .35549 m
.29076 .3576 L
s
.28455 .3541 m .28423 .35226 L .28743 .35371 L .953 .687 .495 r
F
.31656 .44605 m .31739 .44768 L .31502 .45083 L F
0 g
.31739 .44768 m
.31933 .44371 L
s
.32762 .44153 m
.32944 .43777 L
s
.32944 .43777 m
.33929 .43468 L
s
.40733 .2685 m .41943 .27973 L .40801 .28351 L .544 .324 .532 r
F
.40733 .2685 m .41318 .26655 L .41943 .27973 L F
0 g
.41318 .26655 m
.42056 .27537 L
s
.40733 .2685 m
.41318 .26655 L
s
.39986 .26121 m
.40733 .2685 L
s
.44552 .40124 m .46552 .40763 L .45407 .4112 L .656 .751 .92 r
F
0 g
.45407 .4112 m
.46237 .42113 L
s
.31656 .44605 m .31502 .45083 L .31427 .44908 L .953 .687 .495 r
F
.31573 .44441 m .31656 .44605 L .31427 .44908 L F
0 g
.31174 .34318 m
.30805 .34064 L
s
.19708 .55457 m
.18839 .55169 L
s
.22428 .43763 m
.22691 .4456 L
s
.31573 .44441 m .31427 .44908 L .31351 .44734 L .953 .687 .495 r
F
.3149 .44278 m .31573 .44441 L .31351 .44734 L F
0 g
.26777 .47446 m
.26387 .47493 L
s
.26387 .47493 m
.26777 .47446 L
s
.26777 .47446 m
.29443 .45433 L
s
.40601 .43946 m
.40396 .44683 L
s
.37237 .43089 m
.40601 .43946 L
s
.29733 .4531 m
.29991 .45101 L
s
.29991 .45101 m
.30178 .45043 L
s
.3149 .44278 m .31351 .44734 L .31276 .4456 L .953 .687 .495 r
F
.31406 .44114 m .3149 .44278 L .31276 .4456 L F
.30506 .3646 m .32332 .36608 L .30475 .37208 L .544 .324 .532 r
F
.30506 .3646 m .32141 .3593 L .32332 .36608 L F
0 g
.30506 .3646 m
.30536 .35715 L
s
0 0 0 r
2 Mabswid
.14998 .41019 Mdot
.14993 .41002 m .21106 .40244 L .21374 .40894 L .656 .751 .92 r
F
0 g
.5 Mabswid
.21374 .40894 m
.21772 .41498 L
s
.1484 .39898 m .21106 .40244 L .14993 .41002 L .656 .751 .92 r
F
.039 .916 .04 r
.15406 .42021 m
.21247 .40632 L
s
0 g
.14993 .41002 m
.15401 .42012 L
s
.29823 .34386 m
.30805 .34064 L
s
.29823 .34386 m
.29461 .34219 L
s
.31406 .44114 m .31276 .4456 L .312 .44385 L .953 .687 .495 r
F
.31323 .4395 m .31406 .44114 L .312 .44385 L F
0 g
.30178 .45043 m
.29921 .45251 L
s
.3188 .35278 m .33719 .34881 L .32141 .3593 L .544 .324 .532 r
F
.3188 .35278 m .33749 .34 L .33719 .34881 L F
0 g
.31545 .34652 m
.3188 .35278 L
s
.31174 .34318 m
.33343 .32724 L
s
.33749 .34 m
.33778 .33123 L
s
.37757 .40154 m .41467 .4098 L .3769 .40925 L .656 .751 .92 r
F
0 g
.37388 .41764 m
.3769 .40925 L
s
.37757 .40154 m .41714 .39907 L .41467 .4098 L .656 .751 .92 r
F
0 g
.40786 .42178 m
.41467 .4098 L
s
.27938 .34413 m .28262 .34309 L .28294 .34492 L .953 .687 .495 r
F
.27938 .34413 m .27893 .34227 L .28262 .34309 L F
0 g
.28262 .34309 m
.28646 .34484 L
s
.40573 .25925 m
.41318 .26655 L
s
.28111 .39471 m
.28144 .38738 L
s
.17255 .33326 m
.22347 .35356 L
s
.17255 .33326 m
.16791 .33831 L
s
.31323 .4395 m .312 .44385 L .31125 .44211 L .953 .687 .495 r
F
.31239 .43786 m .31323 .4395 L .31125 .44211 L F
.27982 .346 m .28294 .34492 L .28327 .34676 L F
.27982 .346 m .27938 .34413 L .28294 .34492 L F
.25785 .4094 m .28043 .40944 L .25796 .41661 L .544 .324 .532 r
F
.25785 .4094 m .28077 .40206 L .28545 .4066 L .656 .751 .92 r
F
.25785 .4094 m .28077 .40206 L .28043 .40944 L .544 .324 .532 r
F
0 g
.28545 .4066 m
.29011 .41112 L
s
.25361 .40472 m .28077 .40206 L .25785 .4094 L .656 .751 .92 r
F
0 g
.25844 .40425 m
.25871 .4019 L
s
.039 .916 .04 r
.26572 .41562 m
.28752 .40861 L
s
.24336 .40674 m .25361 .40472 L .25785 .4094 L .656 .751 .92 r
F
.039 .916 .04 r
.24909 .4122 m
.25785 .4094 L
s
0 0 0 r
2 Mabswid
.25785 .4094 Mdot
0 g
.5 Mabswid
.36763 .43025 m
.36607 .43555 L
s
.37076 .4364 m
.37237 .43089 L
s
.28027 .34786 m .28327 .34676 L .28359 .34859 L .953 .687 .495 r
F
.28027 .34786 m .27982 .346 L .28327 .34676 L F
.31239 .43786 m .31125 .44211 L .31049 .44037 L F
0 g
.31239 .43786 m
.31395 .4347 L
s
0 0 0 r
2 Mabswid
.33945 .40885 Mdot
0 g
.5 Mabswid
.26662 .35091 m
.26849 .3503 L
s
.26662 .35091 m
.26339 .35105 L
s
.31809 .40868 m .33667 .40278 L .33917 .40812 L .656 .751 .92 r
F
.31336 .40403 m .33667 .40278 L .31809 .40868 L F
0 g
.31809 .40868 m
.3228 .41331 L
s
.039 .916 .04 r
.30561 .41138 m
.31704 .40765 L
s
.28071 .34973 m .28359 .34859 L .28391 .35043 L .953 .687 .495 r
F
.28071 .34973 m .28027 .34786 L .28359 .34859 L F
.039 .916 .04 r
.28752 .40861 m
.29898 .40491 L
s
0 0 0 r
2 Mabswid
.28752 .40861 Mdot
0 g
.5 Mabswid
.33749 .43844 m
.33929 .43468 L
s
.33929 .43468 m
.36607 .43555 L
s
.11772 .33054 m
.12187 .32914 L
s
.11772 .33054 m
.11267 .33866 L
s
.22347 .35356 m
.22677 .35128 L
s
.22677 .35128 m
.26042 .35208 L
s
.22677 .35128 m
.22347 .35357 L
s
.28115 .3516 m .28391 .35043 L .28423 .35226 L .953 .687 .495 r
F
.28115 .3516 m .28071 .34973 L .28391 .35043 L F
.33667 .40278 m .35817 .40656 L .33917 .40812 L .656 .751 .92 r
F
0 g
.33917 .40812 m
.34096 .41367 L
s
.26526 .35044 m
.26849 .3503 L
s
.33685 .32391 m
.35871 .29687 L
s
.35279 .29258 m
.35871 .29687 L
s
.2816 .35346 m .28423 .35226 L .28455 .3541 L .953 .687 .495 r
F
0 g
.28455 .3541 m
.28762 .35549 L
s
.2816 .35346 m .28115 .3516 L .28423 .35226 L .953 .687 .495 r
F
.24862 .42111 m .25907 .42352 L .24815 .43005 L .544 .324 .532 r
F
.24862 .42111 m .25796 .41661 L .25907 .42352 L F
0 g
.24862 .42111 m
.24909 .4122 L
s
.44552 .40124 m .46146 .39625 L .46552 .40763 L .656 .751 .92 r
F
0 g
.46552 .40763 m
.46824 .41932 L
s
.3291 .32421 m
.33343 .32724 L
s
.33685 .32391 m
.33237 .32075 L
s
.32539 .4445 m
.32762 .44153 L
s
.32762 .44153 m
.33749 .43844 L
s
.11684 .33725 m
.12187 .32914 L
s
.30805 .34064 m
.3291 .32421 L
s
.30805 .34064 m
.30444 .33896 L
s
.31427 .44908 m .31502 .45083 L .31226 .45309 L .953 .687 .495 r
F
0 g
.31502 .45083 m
.31739 .44768 L
s
.15276 .51061 m .16818 .52308 L .15846 .52608 L .544 .324 .532 r
F
.15276 .51061 m .16663 .5063 L .16818 .52308 L F
0 g
.1488 .49475 m
.15276 .51061 L
s
.16572 .48946 m
.16663 .5063 L
s
.2376 .40125 m .25361 .40472 L .24336 .40674 L .656 .751 .92 r
F
0 g
.24336 .40674 m
.24909 .4122 L
s
.039 .916 .04 r
.21677 .41374 m
.24218 .40562 L
s
0 g
.45793 .4532 m
.46034 .44375 L
s
.46034 .44375 m
.46625 .44194 L
s
.33667 .40278 m .35267 .40105 L .35817 .40656 L .656 .751 .92 r
F
0 g
.35817 .40656 m
.36365 .41204 L
s
.039 .916 .04 r
.33945 .40885 m
.35529 .40368 L
s
.31427 .44908 m .31226 .45309 L .31159 .45127 L .953 .687 .495 r
F
.31351 .44734 m .31427 .44908 L .31159 .45127 L F
.11173 .39971 m .12556 .39517 L .13507 .40648 L .656 .751 .92 r
F
0 g
.13507 .40648 m
.14509 .41748 L
s
.30475 .37208 m .32459 .3731 L .30445 .37959 L .544 .324 .532 r
F
.30475 .37208 m .32332 .36608 L .32459 .3731 L F
0 g
.30475 .37208 m
.30506 .3646 L
s
0 0 0 r
2 Mabswid
.21247 .40632 Mdot
.31351 .44734 m .31159 .45127 L .31093 .44945 L .953 .687 .495 r
F
.31276 .4456 m .31351 .44734 L .31093 .44945 L F
.31276 .4456 m .31093 .44945 L .31026 .44762 L F
.312 .44385 m .31276 .4456 L .31026 .44762 L F
0 g
.5 Mabswid
.29443 .45433 m
.29733 .4531 L
s
.29733 .4531 m
.29921 .45251 L
s
.312 .44385 m .31026 .44762 L .3096 .4458 L .953 .687 .495 r
F
.31125 .44211 m .312 .44385 L .3096 .4458 L F
0 0 0 r
2 Mabswid
.24218 .40562 Mdot
0 g
.5 Mabswid
.29461 .34219 m
.30444 .33896 L
s
.29461 .34219 m
.29113 .3414 L
s
.25796 .41661 m .2801 .41684 L .25907 .42352 L .544 .324 .532 r
F
.25796 .41661 m .28043 .40944 L .2801 .41684 L F
0 g
.25785 .4094 m
.25796 .41661 L
s
.31125 .44211 m .3096 .4458 L .30893 .44398 L .953 .687 .495 r
F
.31049 .44037 m .31125 .44211 L .30893 .44398 L F
0 g
.29921 .45251 m
.2963 .45374 L
s
.31049 .44037 m .30893 .44398 L .30827 .44216 L .953 .687 .495 r
F
0 g
.31049 .44037 m
.31239 .43786 L
s
.32141 .3593 m .33689 .35765 L .32332 .36608 L .544 .324 .532 r
F
.32141 .3593 m .33719 .34881 L .33689 .35765 L F
0 g
.3188 .35278 m
.32141 .3593 L
s
.33719 .34881 m
.33749 .34 L
s
.26387 .47493 m
.25969 .47432 L
s
.25969 .47432 m
.26387 .47493 L
s
.26387 .47493 m
.29124 .45468 L
s
.27602 .34427 m .27893 .34227 L .27938 .34413 L .953 .687 .495 r
F
.27602 .34427 m .27546 .3424 L .27893 .34227 L F
0 g
.27893 .34227 m
.28262 .34309 L
s
0 0 0 r
2 Mabswid
.29898 .40491 Mdot
0 g
.5 Mabswid
.46625 .44194 m
.46385 .45139 L
s
.25361 .40472 m .27608 .39751 L .28077 .40206 L .656 .751 .92 r
F
0 g
.28077 .40206 m
.28111 .39471 L
s
.28077 .40206 m
.28545 .4066 L
s
.25035 .3997 m .27608 .39751 L .25361 .40472 L .656 .751 .92 r
F
.039 .916 .04 r
.25785 .4094 m
.28077 .40206 L
s
.2376 .40125 m .25035 .3997 L .25361 .40472 L .656 .751 .92 r
F
.039 .916 .04 r
.24218 .40562 m
.252 .40248 L
s
0 g
.25361 .40472 m
.25785 .4094 L
s
.27658 .34613 m .27938 .34413 L .27982 .346 L .953 .687 .495 r
F
.27658 .34613 m .27602 .34427 L .27938 .34413 L F
.18136 .48831 m .23726 .46005 L .19164 .49894 L .544 .324 .532 r
F
.18136 .48831 m .2311 .45311 L .23726 .46005 L F
0 g
.17455 .47672 m
.18136 .48831 L
s
.22691 .4456 m
.2311 .45311 L
s
.36607 .43555 m
.364 .44 L
s
.34972 .33434 m .38811 .31878 L .35577 .34142 L .544 .324 .532 r
F
.34972 .33434 m .37852 .30988 L .38811 .31878 L F
0 g
.34136 .32806 m
.34972 .33434 L
s
.36466 .30248 m
.37852 .30988 L
s
.27714 .348 m .27982 .346 L .28027 .34786 L .953 .687 .495 r
F
.27714 .348 m .27658 .34613 L .27982 .346 L F
0 g
.22164 .5178 m
.22854 .52025 L
s
.22854 .52025 m
.25969 .47432 L
s
.2777 .34986 m .28027 .34786 L .28071 .34973 L .953 .687 .495 r
F
.2777 .34986 m .27714 .348 L .28027 .34786 L F
0 g
.36862 .44102 m
.37076 .4364 L
s
.37076 .4364 m
.40396 .44683 L
s
.33528 .44141 m
.33749 .43844 L
s
.33749 .43844 m
.364 .44 L
s
.26339 .35105 m
.26526 .35044 L
s
.26339 .35105 m
.26042 .35208 L
s
.27826 .35173 m .28071 .34973 L .28115 .3516 L .953 .687 .495 r
F
.27826 .35173 m .2777 .34986 L .28071 .34973 L F
.31336 .40403 m .33351 .39761 L .33667 .40278 L .656 .751 .92 r
F
.30861 .39936 m .33351 .39761 L .31336 .40403 L F
0 g
.31336 .40403 m
.31809 .40868 L
s
.039 .916 .04 r
.29898 .40491 m
.31047 .40119 L
s
0 g
.40396 .44683 m
.40121 .45303 L
s
.27882 .35359 m .28115 .3516 L .2816 .35346 L .953 .687 .495 r
F
0 g
.2816 .35346 m
.28455 .3541 L
s
.27882 .35359 m .27826 .35173 L .28115 .3516 L .953 .687 .495 r
F
0 0 0 r
2 Mabswid
.35529 .40368 Mdot
0 g
.5 Mabswid
.26229 .35147 m
.26526 .35044 L
s
.39986 .26121 m
.40573 .25925 L
s
.39986 .26121 m
.39243 .25557 L
s
.40801 .28351 m .42442 .29346 L .40851 .29868 L .544 .324 .532 r
F
.40801 .28351 m .41943 .27973 L .42442 .29346 L F
0 g
.40733 .2685 m
.40801 .28351 L
s
.41318 .26655 m
.41943 .27973 L
s
.24815 .43005 m .26126 .43013 L .24768 .43902 L .544 .324 .532 r
F
.24815 .43005 m .25907 .42352 L .26126 .43013 L F
0 g
.24815 .43005 m
.24862 .42111 L
s
.22059 .35687 m
.22347 .35356 L
s
.22347 .35357 m
.25774 .35398 L
s
.22347 .35357 m
.22059 .35687 L
s
.33351 .39761 m .35267 .40105 L .33667 .40278 L .656 .751 .92 r
F
.039 .916 .04 r
.31704 .40765 m
.33598 .40153 L
s
0 g
.33667 .40278 m
.33917 .40812 L
s
.32278 .44664 m
.32539 .4445 L
s
.32539 .4445 m
.33528 .44141 L
s
.32488 .32218 m
.3291 .32421 L
s
0 0 0 r
2 Mabswid
.252 .40248 Mdot
.30445 .37959 m .32523 .38035 L .30414 .38712 L .544 .324 .532 r
F
.30445 .37959 m .32459 .3731 L .32523 .38035 L F
0 g
.5 Mabswid
.30445 .37959 m
.30475 .37208 L
s
.1484 .39898 m .20991 .39541 L .21106 .40244 L .656 .751 .92 r
F
0 g
.21106 .40244 m
.21374 .40894 L
s
.30444 .33896 m
.32488 .32218 L
s
.30444 .33896 m
.30097 .33817 L
s
.17521 .54803 m
.18418 .55297 L
s
.18418 .55297 m
.18839 .55169 L
s
.33237 .32075 m
.35279 .29258 L
s
.33237 .32075 m
.32799 .31864 L
s
.039 .916 .04 r
.28077 .40206 m
.29229 .39837 L
s
0 0 0 r
2 Mabswid
.28077 .40206 Mdot
0 g
.5 Mabswid
.28043 .40944 m
.28077 .40206 L
s
.31159 .45127 m .31226 .45309 L .30914 .45442 L .953 .687 .495 r
F
0 g
.31226 .45309 m
.31502 .45083 L
s
.31159 .45127 m .30914 .45442 L .30857 .45255 L .953 .687 .495 r
F
.31093 .44945 m .31159 .45127 L .30857 .45255 L F
0 g
.39832 .2536 m
.40573 .25925 L
s
.31093 .44945 m .30857 .45255 L .30801 .45068 L .953 .687 .495 r
F
.31026 .44762 m .31093 .44945 L .30801 .45068 L F
.37647 .39435 m .41714 .39907 L .37757 .40154 L .656 .751 .92 r
F
0 g
.3769 .40925 m
.37757 .40154 L
s
0 0 0 r
2 Mabswid
.33598 .40153 Mdot
.31026 .44762 m .30801 .45068 L .30745 .44881 L .953 .687 .495 r
F
.3096 .4458 m .31026 .44762 L .30745 .44881 L F
.3096 .4458 m .30745 .44881 L .30689 .44695 L F
.30893 .44398 m .3096 .4458 L .30689 .44695 L F
.30893 .44398 m .30689 .44695 L .30633 .44508 L F
.30827 .44216 m .30893 .44398 L .30633 .44508 L F
.23181 .39574 m .25035 .3997 L .2376 .40125 L .656 .751 .92 r
F
0 g
.5 Mabswid
.2376 .40125 m
.24336 .40674 L
s
.43672 .39124 m .46146 .39625 L .44552 .40124 L .656 .751 .92 r
F
0 g
.44552 .40124 m
.45407 .4112 L
s
.29124 .45468 m
.29443 .45433 L
s
.29443 .45433 m
.2963 .45374 L
s
.25907 .42352 m .27976 .42426 L .26126 .43013 L .544 .324 .532 r
F
.25907 .42352 m .2801 .41684 L .27976 .42426 L F
0 g
.25796 .41661 m
.25907 .42352 L
s
.30827 .44216 m .30633 .44508 L .30576 .44321 L .953 .687 .495 r
F
0 g
.30827 .44216 m
.31049 .44037 L
s
.347 .28967 m
.35279 .29258 L
s
.16791 .33831 m
.22059 .35687 L
s
.16791 .33831 m
.16401 .34489 L
s
.33351 .39761 m .34714 .39552 L .35267 .40105 L .656 .751 .92 r
F
0 g
.35267 .40105 m
.35817 .40656 L
s
.29113 .3414 m
.30097 .33817 L
s
.29113 .3414 m
.28785 .34153 L
s
.18839 .55169 m
.17943 .54675 L
s
.2963 .45374 m
.29312 .45409 L
s
.32332 .36608 m .3366 .36652 L .32459 .3731 L .544 .324 .532 r
F
.32332 .36608 m .33689 .35765 L .3366 .36652 L F
0 g
.32141 .3593 m
.32332 .36608 L
s
.33689 .35765 m
.33719 .34881 L
s
.27292 .34533 m .27546 .3424 L .27602 .34427 L .953 .687 .495 r
F
.27292 .34533 m .27225 .3435 L .27546 .3424 L F
0 g
.27546 .3424 m
.27893 .34227 L
s
.27359 .34716 m .27602 .34427 L .27658 .34613 L .953 .687 .495 r
F
.27359 .34716 m .27292 .34533 L .27602 .34427 L F
.27426 .34899 m .27658 .34613 L .27714 .348 L F
.27426 .34899 m .27359 .34716 L .27658 .34613 L F
.27493 .35082 m .27714 .348 L .2777 .34986 L F
.27493 .35082 m .27426 .34899 L .27714 .348 L F
.2756 .35266 m .2777 .34986 L .27826 .35173 L F
.2756 .35266 m .27493 .35082 L .2777 .34986 L F
.10691 .38674 m .12556 .39517 L .11173 .39971 L .656 .751 .92 r
F
0 g
.11173 .39971 m
.11818 .41198 L
s
.23181 .39574 m .24814 .39431 L .25035 .3997 L .656 .751 .92 r
F
.039 .916 .04 r
.21247 .40632 m
.23528 .39904 L
s
.25035 .3997 m .27136 .39293 L .27608 .39751 L .656 .751 .92 r
F
0 g
.27608 .39751 m
.28077 .40206 L
s
.24814 .39431 m .27136 .39293 L .25035 .3997 L .656 .751 .92 r
F
.039 .916 .04 r
.252 .40248 m
.27398 .39547 L
s
0 g
.25035 .3997 m
.25361 .40472 L
s
.27626 .35449 m .27826 .35173 L .27882 .35359 L .953 .687 .495 r
F
0 g
.27882 .35359 m
.2816 .35346 L
s
.27626 .35449 m .2756 .35266 L .27826 .35173 L .953 .687 .495 r
F
0 g
.33269 .44354 m
.33528 .44141 L
s
.33528 .44141 m
.36144 .44353 L
s
.25969 .47432 m
.25531 .47264 L
s
.25532 .47264 m
.25969 .47432 L
s
.26042 .35208 m
.26229 .35147 L
s
.26042 .35208 m
.25774 .35398 L
s
.364 .44 m
.36144 .44353 L
s
.30861 .39936 m .3297 .39263 L .33351 .39761 L .656 .751 .92 r
F
.30384 .39468 m .3297 .39263 L .30861 .39936 L F
0 g
.30861 .39936 m
.31336 .40403 L
s
.37647 .39435 m .41667 .38919 L .41714 .39907 L .656 .751 .92 r
F
0 g
.41467 .4098 m
.41714 .39907 L
s
.039 .916 .04 r
.35529 .40368 m
.37697 .39647 L
s
0 0 0 r
2 Mabswid
.23528 .39904 Mdot
.15026 .38672 m .20991 .39541 L .1484 .39898 L .656 .751 .92 r
F
.039 .916 .04 r
.5 Mabswid
.14998 .41019 m
.21018 .39837 L
s
0 g
.1484 .39898 m
.14993 .41002 L
s
.25962 .35337 m
.26229 .35147 L
s
.36597 .44469 m
.36862 .44102 L
s
.36862 .44102 m
.40121 .45303 L
s
.30414 .38712 m .32526 .38782 L .30384 .39468 L .544 .324 .532 r
F
.30414 .38712 m .32523 .38035 L .32526 .38782 L F
0 g
.30414 .38712 m
.30445 .37959 L
s
.24768 .43902 m .26469 .43636 L .24721 .44803 L .544 .324 .532 r
F
.24768 .43902 m .26126 .43013 L .26469 .43636 L F
0 g
.24768 .43902 m
.24815 .43005 L
s
.11267 .33866 m
.11684 .33725 L
s
.11267 .33866 m
.10864 .34855 L
s
0 0 0 r
2 Mabswid
.29229 .39837 Mdot
.21018 .39837 Mdot
0 g
.5 Mabswid
.2801 .41684 m
.28043 .40944 L
s
.4546 .46119 m
.45793 .4532 L
s
.45793 .4532 m
.46385 .45139 L
s
.33269 .44354 m
.32278 .44664 L
s
.31984 .44789 m
.32278 .44664 L
s
.30097 .33817 m
.32082 .32121 L
s
.30097 .33817 m
.29771 .33829 L
s
.35577 .34142 m .39482 .32873 L .36007 .34913 L .544 .324 .532 r
F
.35577 .34142 m .38811 .31878 L .39482 .32873 L F
0 g
.34972 .33434 m
.35577 .34142 L
s
.37852 .30988 m
.38811 .31878 L
s
.3297 .39263 m .34714 .39552 L .33351 .39761 L .656 .751 .92 r
F
0 g
.33351 .39761 m
.33667 .40278 L
s
.039 .916 .04 r
.33598 .40153 m
.34894 .39733 L
s
0 g
.21819 .36115 m
.22059 .35687 L
s
.22059 .35687 m
.25543 .35672 L
s
.22059 .35687 m
.2182 .36115 L
s
0 0 0 r
2 Mabswid
.34894 .39733 Mdot
0 g
.5 Mabswid
.32082 .32121 m
.32488 .32218 L
s
.30576 .44321 m .30347 .44537 L .30302 .44349 L .953 .687 .495 r
F
.30576 .44321 m .30633 .44508 L .30347 .44537 L F
0 g
.30576 .44321 m
.30827 .44216 L
s
.11282 .34714 m
.11684 .33725 L
s
.30633 .44508 m .30392 .44726 L .30347 .44537 L .953 .687 .495 r
F
.30633 .44508 m .30689 .44695 L .30392 .44726 L F
.30689 .44695 m .30437 .44914 L .30392 .44726 L F
.30689 .44695 m .30745 .44881 L .30437 .44914 L F
.30745 .44881 m .30481 .45103 L .30437 .44914 L F
.30745 .44881 m .30801 .45068 L .30481 .45103 L F
.30801 .45068 m .30526 .45292 L .30481 .45103 L F
.30801 .45068 m .30857 .45255 L .30526 .45292 L F
.30857 .45255 m .30571 .4548 L .30526 .45292 L F
.30857 .45255 m .30914 .45442 L .30571 .4548 L F
0 g
.30914 .45442 m
.31226 .45309 L
s
.40121 .45303 m
.39778 .45797 L
s
.32799 .31864 m
.347 .28967 L
s
.32799 .31864 m
.32378 .31762 L
s
.28783 .45414 m
.29124 .45468 L
s
.29124 .45468 m
.29312 .45409 L
s
.26126 .43013 m .27942 .43171 L .26469 .43636 L .544 .324 .532 r
F
.26126 .43013 m .27976 .42426 L .27942 .43171 L F
0 g
.25907 .42352 m
.26126 .43013 L
s
.46385 .45139 m
.46055 .45937 L
s
.43672 .39124 m .45611 .38514 L .46146 .39625 L .656 .751 .92 r
F
0 g
.46146 .39625 m
.46552 .40763 L
s
.21454 .51371 m
.22164 .5178 L
s
.22164 .5178 m
.25531 .47264 L
s
.28785 .34153 m
.29771 .33829 L
s
.28785 .34153 m
.28483 .34257 L
s
.32459 .3731 m .3363 .37543 L .32523 .38035 L .544 .324 .532 r
F
.32459 .3731 m .3366 .36652 L .3363 .37543 L F
0 g
.32332 .36608 m
.32459 .3731 L
s
.3366 .36652 m
.33689 .35765 L
s
.29312 .45409 m
.28971 .45355 L
s
.226 .3902 m .24814 .39431 L .23181 .39574 L .656 .751 .92 r
F
.039 .916 .04 r
.23528 .39904 m
.24831 .39487 L
s
0 g
.23181 .39574 m
.2376 .40125 L
s
.15846 .52608 m .17037 .53982 L .16614 .54111 L .544 .324 .532 r
F
.15846 .52608 m .16818 .52308 L .17037 .53982 L F
0 g
.15276 .51061 m
.15846 .52608 L
s
.16663 .5063 m
.16818 .52308 L
s
.15846 .52608 m
.16614 .54111 L
s
.27397 .35614 m .2756 .35266 L .27626 .35449 L .953 .687 .495 r
F
0 g
.27626 .35449 m
.27882 .35359 L
s
.3297 .39263 m .34158 .38996 L .34714 .39552 L .656 .751 .92 r
F
0 g
.34714 .39552 m
.35267 .40105 L
s
.039 .916 .04 r
.27398 .39547 m
.28555 .3918 L
s
0 0 0 r
2 Mabswid
.27398 .39547 Mdot
.27321 .35437 m .27493 .35082 L .2756 .35266 L .953 .687 .495 r
F
.27397 .35614 m .27321 .35437 L .2756 .35266 L F
.15026 .38672 m .2107 .3877 L .20991 .39541 L .656 .751 .92 r
F
0 g
.5 Mabswid
.20991 .39541 m
.21106 .40244 L
s
.27244 .35261 m .27426 .34899 L .27493 .35082 L .953 .687 .495 r
F
.27321 .35437 m .27244 .35261 L .27493 .35082 L F
.27168 .35084 m .27359 .34716 L .27426 .34899 L F
.27244 .35261 m .27168 .35084 L .27426 .34899 L F
.10691 .38674 m .11659 .38354 L .12556 .39517 L .656 .751 .92 r
F
0 g
.12556 .39517 m
.13507 .40648 L
s
.27091 .34907 m .27292 .34533 L .27359 .34716 L .953 .687 .495 r
F
.27168 .35084 m .27091 .34907 L .27359 .34716 L F
.27015 .34731 m .27225 .3435 L .27292 .34533 L F
.27091 .34907 m .27015 .34731 L .27292 .34533 L F
.27015 .34731 m .26938 .34554 L .27225 .3435 L F
0 g
.27225 .3435 m
.27546 .3424 L
s
0 0 0 r
2 Mabswid
.24831 .39487 Mdot
0 g
.5 Mabswid
.25774 .35398 m
.25962 .35337 L
s
.25774 .35398 m
.25543 .35672 L
s
.35843 .44606 m
.33269 .44354 L
s
.32976 .44479 m
.33269 .44354 L
s
.40851 .29868 m .4282 .30771 L .40884 .31403 L .544 .324 .532 r
F
.40851 .29868 m .42442 .29346 L .4282 .30771 L F
0 g
.40801 .28351 m
.40851 .29868 L
s
.41943 .27973 m
.42442 .29346 L
s
.39243 .25557 m
.39832 .2536 L
s
.39243 .25557 m
.38517 .25169 L
s
.30384 .39468 m .32469 .39551 L .30353 .40226 L .544 .324 .532 r
F
.30384 .39468 m .32526 .38782 L .3297 .39263 L .656 .751 .92 r
F
.30384 .39468 m .32526 .38782 L .32469 .39551 L .544 .324 .532 r
F
.29905 .38997 m .32526 .38782 L .30384 .39468 L .656 .751 .92 r
F
0 0 0 r
2 Mabswid
.30384 .39468 Mdot
.039 .916 .04 r
.5 Mabswid
.31047 .40119 m
.33123 .39452 L
s
.29229 .39837 m
.30384 .39468 L
s
0 g
.30404 .38956 m
.30414 .38712 L
s
.27976 .42426 m
.2801 .41684 L
s
.37389 .38758 m .41667 .38919 L .37647 .39435 L .656 .751 .92 r
F
0 g
.37647 .39435 m
.37757 .40154 L
s
.24814 .39431 m .26663 .38834 L .27136 .39293 L .656 .751 .92 r
F
0 g
.27136 .39293 m
.27608 .39751 L
s
.24717 .38849 m .26663 .38834 L .24814 .39431 L .656 .751 .92 r
F
.039 .916 .04 r
.24831 .39487 m
.26718 .38888 L
s
.226 .3902 m .24717 .38849 L .24814 .39431 L .656 .751 .92 r
F
0 g
.24814 .39431 m
.25035 .3997 L
s
.039 .916 .04 r
.21018 .39837 m
.22845 .39253 L
s
0 g
.2573 .35611 m
.25962 .35337 L
s
.25531 .47264 m
.25081 .46991 L
s
.25081 .4699 m
.25532 .47264 L
s
.36144 .44353 m
.35843 .44606 L
s
.19164 .49894 m .24626 .46616 L .20735 .50802 L .544 .324 .532 r
F
.19164 .49894 m .23726 .46005 L .24626 .46616 L F
0 g
.18136 .48831 m
.19164 .49894 L
s
.19164 .49894 m
.20735 .50802 L
s
.2311 .45311 m
.23726 .46005 L
s
.24721 .44803 m .26968 .44214 L .24674 .45708 L .544 .324 .532 r
F
0 g
.25969 .47432 m
.28783 .45414 L
s
.24721 .44803 m .26469 .43636 L .26968 .44214 L .544 .324 .532 r
F
0 g
.24721 .44803 m
.24768 .43902 L
s
.34144 .28821 m
.347 .28967 L
s
.31661 .44824 m
.31984 .44789 L
s
.31984 .44789 m
.32976 .44479 L
s
.36286 .44732 m
.36597 .44469 L
s
.36597 .44469 m
.39778 .45797 L
s
.16401 .34489 m
.21819 .36115 L
s
.16401 .34489 m
.16092 .35288 L
s
.30302 .44349 m .30041 .44487 L .30008 .443 L .953 .687 .495 r
F
.30302 .44349 m .30347 .44537 L .30041 .44487 L F
0 g
.30302 .44349 m
.30576 .44321 L
s
.29771 .33829 m
.317 .32131 L
s
.29771 .33829 m
.29471 .33933 L
s
.30347 .44537 m .30074 .44673 L .30041 .44487 L .953 .687 .495 r
F
.30347 .44537 m .30392 .44726 L .30074 .44673 L F
0 g
.39108 .24971 m
.39832 .2536 L
s
.16614 .54111 m
.17521 .54803 L
s
.17521 .54803 m
.17943 .54675 L
s
.30392 .44726 m .30106 .4486 L .30074 .44673 L .953 .687 .495 r
F
.30392 .44726 m .30437 .44914 L .30106 .4486 L F
.32526 .38782 m .34158 .38996 L .3297 .39263 L .656 .751 .92 r
F
.039 .916 .04 r
.33123 .39452 m
.3425 .39088 L
s
0 g
.3297 .39263 m
.33351 .39761 L
s
0 0 0 r
2 Mabswid
.22845 .39253 Mdot
0 g
.5 Mabswid
.16818 .52308 m
.17037 .53982 L
s
.30437 .44914 m .30139 .45047 L .30106 .4486 L .953 .687 .495 r
F
.30437 .44914 m .30481 .45103 L .30139 .45047 L F
0 g
.23726 .46005 m
.24626 .46616 L
s
.21632 .36633 m
.21819 .36115 L
s
.2182 .36115 m
.2535 .36027 L
s
.2182 .36115 m
.21632 .36633 L
s
.30481 .45103 m .30172 .45234 L .30139 .45047 L .953 .687 .495 r
F
.30481 .45103 m .30526 .45292 L .30172 .45234 L F
0 g
.28425 .4527 m
.28783 .45414 L
s
.28783 .45414 m
.28971 .45355 L
s
.30526 .45292 m .30204 .45421 L .30172 .45234 L .953 .687 .495 r
F
.30526 .45292 m .30571 .4548 L .30204 .45421 L F
0 g
.30571 .4548 m
.30914 .45442 L
s
.32523 .38035 m .336 .38438 L .32526 .38782 L .544 .324 .532 r
F
.32523 .38035 m .3363 .37543 L .336 .38438 L F
0 g
.32459 .3731 m
.32523 .38035 L
s
.3363 .37543 m
.3366 .36652 L
s
0 0 0 r
2 Mabswid
.28555 .3918 Mdot
0 g
.5 Mabswid
.317 .32131 m
.32082 .32121 L
s
.27199 .35852 m .27321 .35437 L .27397 .35614 L .953 .687 .495 r
F
0 g
.27397 .35614 m
.27626 .35449 L
s
.26469 .43636 m .27908 .43918 L .26968 .44214 L .544 .324 .532 r
F
.26469 .43636 m .27942 .43171 L .27908 .43918 L F
0 g
.26126 .43013 m
.26469 .43636 L
s
.36007 .34913 m .39926 .3395 L .36293 .35735 L .544 .324 .532 r
F
.36007 .34913 m .39482 .32873 L .39926 .3395 L F
0 g
.35577 .34142 m
.36007 .34913 L
s
.38811 .31878 m
.39482 .32873 L
s
.28971 .45355 m
.28614 .45211 L
s
.28483 .34257 m
.29471 .33933 L
s
.28483 .34257 m
.28213 .34451 L
s
.17037 .53982 m
.17943 .54675 L
s
.27114 .35685 m .27244 .35261 L .27321 .35437 L .953 .687 .495 r
F
.27199 .35852 m .27114 .35685 L .27321 .35437 L F
.42767 .38122 m .45611 .38514 L .43672 .39124 L .656 .751 .92 r
F
0 g
.43672 .39124 m
.44552 .40124 L
s
.27029 .35518 m .27168 .35084 L .27244 .35261 L .953 .687 .495 r
F
.27114 .35685 m .27029 .35518 L .27244 .35261 L F
0 g
.32378 .31762 m
.34144 .28821 L
s
.32378 .31762 m
.31982 .31771 L
s
0 0 0 r
2 Mabswid
.3425 .39088 Mdot
.30353 .40226 m .32349 .40342 L .30322 .40987 L .544 .324 .532 r
F
.30353 .40226 m .32469 .39551 L .32349 .40342 L F
0 g
.5 Mabswid
.30353 .40226 m
.30384 .39468 L
s
.26944 .35351 m .27091 .34907 L .27168 .35084 L .953 .687 .495 r
F
.27029 .35518 m .26944 .35351 L .27168 .35084 L F
0 g
.27942 .43171 m
.27976 .42426 L
s
.26859 .35184 m .27015 .34731 L .27091 .34907 L .953 .687 .495 r
F
.26944 .35351 m .26859 .35184 L .27091 .34907 L F
0 g
.25543 .35672 m
.2573 .35611 L
s
.25543 .35672 m
.2535 .36027 L
s
.22016 .38463 m .24717 .38849 L .226 .3902 L .656 .751 .92 r
F
0 g
.226 .3902 m
.23181 .39574 L
s
.26774 .35017 m .26938 .34554 L .27015 .34731 L .953 .687 .495 r
F
.26859 .35184 m .26774 .35017 L .27015 .34731 L F
0 g
.32655 .44513 m
.32976 .44479 L
s
.32976 .44479 m
.35503 .44755 L
s
.29905 .38997 m .3202 .38318 L .32526 .38782 L .656 .751 .92 r
F
.29424 .38525 m .3202 .38318 L .29905 .38997 L F
0 g
.29905 .38997 m
.30384 .39468 L
s
.039 .916 .04 r
.28555 .3918 m
.29717 .38812 L
s
.32526 .38782 m .336 .38438 L .34158 .38996 L .656 .751 .92 r
F
0 g
.34158 .38996 m
.34714 .39552 L
s
.26774 .35017 m .26689 .3485 L .26938 .34554 L .953 .687 .495 r
F
0 g
.26938 .34554 m
.27225 .3435 L
s
.25538 .35966 m
.2573 .35611 L
s
.24674 .45708 m .27685 .44727 L .24626 .46616 L .544 .324 .532 r
F
.24674 .45708 m .26968 .44214 L .27685 .44727 L F
0 g
.25532 .47264 m
.28425 .4527 L
s
.24674 .45708 m
.24721 .44803 L
s
.24626 .46616 m
.24674 .45708 L
s
.24626 .46616 m
.25081 .46991 L
s
.21454 .51371 m
.25081 .46991 L
s
.24626 .46616 m
.25081 .4699 L
s
.25081 .4699 m
.28057 .4504 L
s
.37389 .38758 m .41388 .37995 L .41667 .38919 L .656 .751 .92 r
F
0 g
.41667 .38919 m
.41714 .39907 L
s
.039 .916 .04 r
.34894 .39733 m
.37453 .38892 L
s
.37697 .39647 m
.41638 .3877 L
s
0 g
.39778 .45797 m
.39372 .46153 L
s
.10864 .34855 m
.11282 .34714 L
s
.10864 .34855 m
.10571 .36006 L
s
.30008 .443 m .2972 .44356 L .297 .44174 L .953 .687 .495 r
F
.30008 .443 m .30041 .44487 L .2972 .44356 L F
0 g
.30008 .443 m
.30302 .44349 L
s
.45043 .46755 m
.4546 .46119 L
s
.4546 .46119 m
.46055 .45937 L
s
.039 .916 .04 r
.26718 .38888 m
.27881 .38523 L
s
.30041 .44487 m .2974 .44538 L .2972 .44356 L .953 .687 .495 r
F
.30041 .44487 m .30074 .44673 L .2974 .44538 L F
.24717 .38849 m .26188 .38373 L .26663 .38834 L .656 .751 .92 r
F
0 g
.26663 .38834 m
.27136 .39293 L
s
.24772 .38215 m .26188 .38373 L .24717 .38849 L .656 .751 .92 r
F
.22016 .38463 m .24772 .38215 L .24717 .38849 L F
0 g
.24717 .38849 m
.24814 .39431 L
s
.039 .916 .04 r
.22845 .39253 m
.24716 .38652 L
s
0 g
.20735 .50802 m
.21454 .51371 L
s
.31315 .44766 m
.31661 .44824 L
s
.31661 .44824 m
.32655 .44513 L
s
.30074 .44673 m .2976 .44719 L .2974 .44538 L .953 .687 .495 r
F
.30074 .44673 m .30106 .4486 L .2976 .44719 L F
0 g
.35843 .44606 m
.35503 .44755 L
s
.29471 .33933 m
.31349 .32249 L
s
.29471 .33933 m
.29203 .34126 L
s
0 0 0 r
2 Mabswid
.29717 .38812 Mdot
.30106 .4486 m .29779 .44901 L .2976 .44719 L .953 .687 .495 r
F
.30106 .4486 m .30139 .45047 L .29779 .44901 L F
.32526 .38782 m .3357 .39336 L .32469 .39551 L .544 .324 .532 r
F
.32526 .38782 m .336 .38438 L .3357 .39336 L F
.3202 .38318 m .336 .38438 L .32526 .38782 L .656 .751 .92 r
F
0 0 0 r
.32526 .38782 Mdot
0 g
.5 Mabswid
.32523 .38035 m
.32524 .38356 L
s
.039 .916 .04 r
.30384 .39468 m
.32526 .38782 L
s
0 g
.1099 .35865 m
.11282 .34714 L
s
.15744 .37258 m .2107 .3877 L .15026 .38672 L .656 .751 .92 r
F
0 g
.1484 .39898 m
.15026 .38672 L
s
.15744 .37258 m .21428 .37903 L .2107 .3877 L .656 .751 .92 r
F
0 g
.20991 .39541 m
.2107 .3877 L
s
.2107 .3877 m
.21428 .37903 L
s
.28057 .4504 m
.28425 .4527 L
s
.28425 .4527 m
.28614 .45211 L
s
.27035 .3616 m .27114 .35685 L .27199 .35852 L .953 .687 .495 r
F
0 g
.27199 .35852 m
.27397 .35614 L
s
.30139 .45047 m .29799 .45084 L .29779 .44901 L .953 .687 .495 r
F
.30139 .45047 m .30172 .45234 L .29799 .45084 L F
.36999 .38118 m .41388 .37995 L .37389 .38758 L .656 .751 .92 r
F
0 g
.37389 .38758 m
.37647 .39435 L
s
.039 .916 .04 r
.3425 .39088 m
.37044 .38182 L
s
0 g
.16092 .35288 m
.21632 .36633 L
s
.21501 .37233 m
.21632 .36633 L
s
.21632 .36633 m
.25201 .36456 L
s
.21632 .36633 m
.21501 .37233 L
s
.39372 .46153 m
.36286 .44732 L
s
.35933 .44887 m
.36286 .44732 L
s
.30172 .45234 m .29819 .45266 L .29799 .45084 L .953 .687 .495 r
F
.30172 .45234 m .30204 .45421 L .29819 .45266 L F
0 g
.30204 .45421 m
.30571 .4548 L
s
.26943 .36006 m .27029 .35518 L .27114 .35685 L .953 .687 .495 r
F
.27035 .3616 m .26943 .36006 L .27114 .35685 L F
0 g
.46055 .45937 m
.4564 .46574 L
s
.28614 .45211 m
.28246 .44981 L
s
.30322 .40987 m .32166 .41155 L .30291 .4175 L .544 .324 .532 r
F
.30322 .40987 m .32349 .40342 L .32166 .41155 L F
0 g
.30322 .40987 m
.30353 .40226 L
s
.26851 .35851 m .26944 .35351 L .27029 .35518 L .953 .687 .495 r
F
.26943 .36006 m .26851 .35851 L .27029 .35518 L F
.10395 .37299 m .11659 .38354 L .10691 .38674 L .656 .751 .92 r
F
0 g
.10691 .38674 m
.11173 .39971 L
s
.15026 .38672 m
.15744 .37258 L
s
.28213 .34451 m
.29203 .34126 L
s
.28213 .34451 m
.27979 .34731 L
s
0 0 0 r
2 Mabswid
.24716 .38652 Mdot
.26759 .35697 m .26859 .35184 L .26944 .35351 L .953 .687 .495 r
F
.26851 .35851 m .26759 .35697 L .26944 .35351 L F
.40884 .31403 m .43083 .32246 L .40901 .32954 L .544 .324 .532 r
F
.40884 .31403 m .4282 .30771 L .43083 .32246 L F
0 g
.5 Mabswid
.40851 .29868 m
.40884 .31403 L
s
.42442 .29346 m
.4282 .30771 L
s
.33621 .28824 m
.34144 .28821 L
s
.31349 .32249 m
.317 .32131 L
s
.2535 .36027 m
.25538 .35966 L
s
.2535 .36027 m
.25201 .36456 L
s
.26968 .44214 m .27874 .44668 L .27685 .44727 L .544 .324 .532 r
F
.26968 .44214 m .27908 .43918 L .27874 .44668 L F
0 g
.26469 .43636 m
.26968 .44214 L
s
.26968 .44214 m
.27685 .44727 L
s
.27908 .43918 m
.27942 .43171 L
s
.26667 .35542 m .26774 .35017 L .26859 .35184 L .953 .687 .495 r
F
.26759 .35697 m .26667 .35542 L .26859 .35184 L F
.36293 .35735 m .40173 .35098 L .36449 .36603 L .544 .324 .532 r
F
.36293 .35735 m .39926 .3395 L .40173 .35098 L F
0 g
.36007 .34913 m
.36293 .35735 L
s
.16092 .35288 m
.15872 .36216 L
s
.25389 .36395 m
.25538 .35966 L
s
.26575 .35388 m .26689 .3485 L .26774 .35017 L .953 .687 .495 r
F
.26667 .35542 m .26575 .35388 L .26774 .35017 L F
.297 .44174 m .2939 .44146 L .29383 .43973 L F
.297 .44174 m .2972 .44356 L .2939 .44146 L F
0 g
.297 .44174 m
.30008 .443 L
s
.39482 .32873 m
.39926 .3395 L
s
.38517 .25169 m
.39108 .24971 L
s
.38517 .25169 m
.3782 .24966 L
s
.29424 .38525 m .3145 .37873 L .3202 .38318 L .656 .751 .92 r
F
.28941 .3805 m .3145 .37873 L .29424 .38525 L F
0 g
.29424 .38525 m
.29905 .38997 L
s
.3231 .44455 m
.32655 .44513 L
s
.32655 .44513 m
.35128 .44796 L
s
.039 .916 .04 r
.27881 .38523 m
.29048 .38156 L
s
0 0 0 r
2 Mabswid
.27881 .38523 Mdot
.42767 .38122 m .44952 .3743 L .45611 .38514 L .656 .751 .92 r
F
.039 .916 .04 r
.5 Mabswid
.41638 .3877 m
.42968 .38342 L
s
0 g
.45611 .38514 m
.46146 .39625 L
s
.31982 .31771 m
.33621 .28824 L
s
.31982 .31771 m
.31618 .31893 L
s
.26575 .35388 m .26482 .35233 L .26689 .3485 L .953 .687 .495 r
F
0 g
.26689 .3485 m
.26938 .34554 L
s
.2972 .44356 m .29396 .4432 L .2939 .44146 L .953 .687 .495 r
F
.2972 .44356 m .2974 .44538 L .29396 .4432 L F
.21429 .37903 m .24772 .38215 L .22016 .38463 L .656 .751 .92 r
F
0 g
.22016 .38463 m
.226 .3902 L
s
.24174 .46147 m
.24626 .46616 L
s
.24626 .46616 m
.27685 .44727 L
s
.24174 .46147 m
.24626 .46616 L
s
.20735 .50802 m
.24626 .46616 L
s
.3202 .38318 m .33039 .37877 L .336 .38438 L .656 .751 .92 r
F
0 0 0 r
2 Mabswid
.336 .38438 Mdot
.039 .916 .04 r
.5 Mabswid
.32526 .38782 m
.336 .38438 L
s
0 g
.336 .38438 m
.3363 .37543 L
s
.336 .38438 m
.34158 .38996 L
s
.2974 .44538 m .29402 .44494 L .29396 .4432 L .953 .687 .495 r
F
.2974 .44538 m .2976 .44719 L .29402 .44494 L F
.32469 .39551 m .3354 .40238 L .32349 .40342 L .544 .324 .532 r
F
.32469 .39551 m .3357 .39336 L .3354 .40238 L F
0 g
.32469 .39551 m
.32526 .38782 L
s
.3357 .39336 m
.336 .38438 L
s
.26908 .36532 m .26943 .36006 L .27035 .3616 L .953 .687 .495 r
F
0 g
.27035 .3616 m
.27199 .35852 L
s
.15713 .5323 m
.16614 .54111 L
s
.16614 .54111 m
.17037 .53982 L
s
.24772 .38215 m .25711 .37911 L .26188 .38373 L .656 .751 .92 r
F
.039 .916 .04 r
.24716 .38652 m
.26042 .38232 L
s
0 g
.26188 .38373 m
.26663 .38834 L
s
.2976 .44719 m .29409 .44668 L .29402 .44494 L .953 .687 .495 r
F
.2976 .44719 m .29779 .44901 L .29409 .44668 L F
0 g
.30952 .44617 m
.31315 .44766 L
s
.31315 .44766 m
.3231 .44455 L
s
.10395 .37299 m .10816 .37159 L .11659 .38354 L .656 .751 .92 r
F
0 g
.11659 .38354 m
.12556 .39517 L
s
.10395 .37299 m
.10691 .38674 L
s
.10816 .37159 m
.11659 .38354 L
s
.27685 .44727 m
.28057 .4504 L
s
.28057 .4504 m
.28246 .44981 L
s
.38412 .24766 m
.39108 .24971 L
s
.29203 .34126 m
.31035 .32474 L
s
.29203 .34126 m
.2897 .34407 L
s
.26811 .36393 m .26851 .35851 L .26943 .36006 L .953 .687 .495 r
F
.26908 .36532 m .26811 .36393 L .26943 .36006 L F
.3145 .37873 m .33039 .37877 L .3202 .38318 L .656 .751 .92 r
F
0 g
.3202 .38318 m
.32526 .38782 L
s
.039 .916 .04 r
.29717 .38812 m
.31809 .38145 L
s
.29779 .44901 m .29415 .44842 L .29409 .44668 L .953 .687 .495 r
F
.29779 .44901 m .29799 .45084 L .29415 .44842 L F
0 g
.21501 .37233 m
.25098 .36952 L
s
.15872 .36216 m
.21501 .37233 L
s
.27874 .44668 m
.27908 .43918 L
s
.27874 .44668 m
.28246 .44981 L
s
.30291 .4175 m .31917 .41992 L .3026 .42516 L .544 .324 .532 r
F
.30291 .4175 m .32166 .41155 L .31917 .41992 L F
0 g
.30291 .4175 m
.30322 .40987 L
s
.26713 .36254 m .26759 .35697 L .26851 .35851 L .953 .687 .495 r
F
.26811 .36393 m .26713 .36254 L .26851 .35851 L F
.29799 .45084 m .29422 .45016 L .29415 .44842 L F
.29799 .45084 m .29819 .45266 L .29422 .45016 L F
0 g
.29819 .45266 m
.30204 .45421 L
s
.35503 .44755 m
.35128 .44796 L
s
.16137 .53099 m
.17037 .53982 L
s
.039 .916 .04 r
.26042 .38232 m
.2721 .37867 L
s
0 0 0 r
2 Mabswid
.26042 .38232 Mdot
.25043 .37508 m .25711 .37911 L .24772 .38215 L .656 .751 .92 r
F
.21429 .37903 m .25043 .37508 L .24772 .38215 L F
0 g
.5 Mabswid
.24717 .38849 m
.24772 .38215 L
s
.21428 .37903 m
.21501 .37233 L
s
.21429 .37903 m
.21501 .37233 L
s
.21429 .37903 m
.22016 .38463 L
s
.26616 .36115 m .26667 .35542 L .26759 .35697 L .953 .687 .495 r
F
.26713 .36254 m .26616 .36115 L .26759 .35697 L F
0 g
.25201 .36456 m
.25389 .36395 L
s
.25201 .36456 m
.25098 .36952 L
s
.27979 .34731 m
.2897 .34407 L
s
.27979 .34731 m
.27786 .35095 L
s
.29383 .43973 m .29055 .43862 L .29062 .437 L .953 .687 .495 r
F
.29383 .43973 m .2939 .44146 L .29055 .43862 L F
0 g
.29383 .43973 m
.297 .44174 L
s
0 0 0 r
2 Mabswid
.29048 .38156 Mdot
.26518 .35976 m .26575 .35388 L .26667 .35542 L .953 .687 .495 r
F
.26616 .36115 m .26518 .35976 L .26667 .35542 L F
0 0 0 r
.31809 .38145 Mdot
0 g
.5 Mabswid
.25286 .36891 m
.25389 .36395 L
s
.35545 .4493 m
.35933 .44887 L
s
.35933 .44887 m
.38911 .46365 L
s
.39372 .46153 m
.38911 .46365 L
s
.20021 .50084 m
.20735 .50802 L
s
.41837 .37116 m .44952 .3743 L .42767 .38122 L .656 .751 .92 r
F
.039 .916 .04 r
.42968 .38342 m
.4511 .3767 L
s
0 g
.42767 .38122 m
.43672 .39124 L
s
.36999 .38118 m .40907 .37127 L .41388 .37995 L .656 .751 .92 r
F
0 g
.41388 .37995 m
.41667 .38919 L
s
.36484 .37515 m .40907 .37127 L .36999 .38118 L .656 .751 .92 r
F
0 g
.36999 .38118 m
.37389 .38758 L
s
.039 .916 .04 r
.37453 .38892 m
.41344 .37895 L
s
.2939 .44146 m .29048 .44025 L .29055 .43862 L .953 .687 .495 r
F
.2939 .44146 m .29396 .4432 L .29048 .44025 L F
.2642 .35837 m .26482 .35233 L .26575 .35388 L F
.26518 .35976 m .2642 .35837 L .26575 .35388 L F
0 g
.10571 .36006 m
.1099 .35865 L
s
.10395 .37299 m
.10571 .36006 L
s
.31948 .44306 m
.3231 .44455 L
s
.3231 .44455 m
.34725 .44727 L
s
.28941 .3805 m .30815 .37446 L .3145 .37873 L .656 .751 .92 r
F
.28456 .37574 m .30815 .37446 L .28941 .3805 L F
0 g
.28941 .3805 m
.29424 .38525 L
s
.23733 .4559 m
.24174 .46147 L
s
.24174 .46147 m
.27315 .44335 L
s
.24174 .46147 m
.23733 .4559 L
s
.20021 .50084 m
.24174 .46147 L
s
.26821 .36962 m .26811 .36393 L .26908 .36532 L .953 .687 .495 r
F
0 g
.26908 .36532 m
.27035 .3616 L
s
.31035 .32474 m
.31349 .32249 L
s
.29396 .4432 m .29041 .44187 L .29048 .44025 L .953 .687 .495 r
F
.29396 .4432 m .29402 .44494 L .29041 .44187 L F
.2642 .35837 m .26323 .35697 L .26482 .35233 L F
0 g
.26482 .35233 m
.26689 .3485 L
s
.32349 .40342 m .3351 .41143 L .32166 .41155 L .544 .324 .532 r
F
.32349 .40342 m .3354 .40238 L .3351 .41143 L F
0 g
.32349 .40342 m
.32469 .39551 L
s
.36449 .36603 m .40239 .36312 L .36484 .37515 L .544 .324 .532 r
F
.36449 .36603 m .40173 .35098 L .40239 .36312 L F
0 g
.36293 .35735 m
.36449 .36603 L
s
.27315 .44335 m
.27685 .44727 L
s
.27685 .44727 m
.27874 .44668 L
s
.2672 .36841 m .26713 .36254 L .26811 .36393 L .953 .687 .495 r
F
.26821 .36962 m .2672 .36841 L .26811 .36393 L F
0 g
.3354 .40238 m
.3357 .39336 L
s
.29402 .44494 m .29034 .4435 L .29041 .44187 L .953 .687 .495 r
F
.29402 .44494 m .29409 .44668 L .29034 .4435 L F
0 g
.44545 .47217 m
.45043 .46755 L
s
.45043 .46755 m
.4564 .46574 L
s
.10816 .37159 m
.1099 .35865 L
s
.30577 .44379 m
.30952 .44617 L
s
.30952 .44617 m
.31948 .44306 L
s
.31618 .31893 m
.3314 .28977 L
s
.31618 .31893 m
.31293 .32126 L
s
.27504 .44276 m
.27874 .44668 L
s
.25043 .37508 m .25232 .37446 L .25711 .37911 L .656 .751 .92 r
F
0 g
.25232 .37446 m
.25711 .37911 L
s
.24772 .38215 m
.25043 .37508 L
s
.25711 .37911 m
.26188 .38373 L
s
.21429 .37903 m
.25043 .37508 L
s
.21416 .38634 m
.21429 .37903 L
s
.15744 .37258 m
.21428 .37903 L
s
.21416 .38634 m
.21428 .37903 L
s
.29409 .44668 m .29027 .44513 L .29034 .4435 L .953 .687 .495 r
F
.29409 .44668 m .29415 .44842 L .29027 .44513 L F
.26619 .3672 m .26616 .36115 L .26713 .36254 L F
.2672 .36841 m .26619 .3672 L .26713 .36254 L F
.039 .916 .04 r
.41344 .37895 m
.42281 .37593 L
s
.3026 .42516 m .31596 .42854 L .30229 .43284 L .544 .324 .532 r
F
.3026 .42516 m .31917 .41992 L .31596 .42854 L F
0 g
.3026 .42516 m
.30291 .4175 L
s
.3145 .37873 m .32475 .37313 L .33039 .37877 L .656 .751 .92 r
F
0 g
.33039 .37877 m
.336 .38438 L
s
.2897 .34407 m
.30764 .32803 L
s
.2897 .34407 m
.28779 .3477 L
s
.30815 .37446 m .32475 .37313 L .3145 .37873 L .656 .751 .92 r
F
.039 .916 .04 r
.31809 .38145 m
.32946 .37784 L
s
0 g
.3145 .37873 m
.3202 .38318 L
s
.15744 .37258 m
.15872 .36216 L
s
0 0 0 r
2 Mabswid
.2721 .37867 Mdot
.29062 .437 m .28723 .43507 L .28743 .43359 L .953 .687 .495 r
F
.29062 .437 m .29055 .43862 L .28723 .43507 L F
0 g
.5 Mabswid
.29062 .437 m
.29383 .43973 L
s
.25098 .36952 m
.25286 .36891 L
s
.25043 .37508 m
.25098 .36952 L
s
.3314 .28977 m
.33621 .28824 L
s
.29415 .44842 m .2902 .44676 L .29027 .44513 L .953 .687 .495 r
F
.29415 .44842 m .29422 .45016 L .2902 .44676 L F
0 g
.29422 .45016 m
.29819 .45266 L
s
.26517 .36599 m .26518 .35976 L .26616 .36115 L .953 .687 .495 r
F
.26619 .3672 m .26517 .36599 L .26616 .36115 L F
.40901 .32954 m .43233 .3377 L .409 .34522 L .544 .324 .532 r
F
.40901 .32954 m .43083 .32246 L .43233 .3377 L F
0 g
.40884 .31403 m
.40901 .32954 L
s
.4282 .30771 m
.43083 .32246 L
s
0 0 0 r
2 Mabswid
.32946 .37784 Mdot
0 g
.5 Mabswid
.25232 .37446 m
.25286 .36891 L
s
.29055 .43862 m .28703 .43656 L .28723 .43507 L .953 .687 .495 r
F
.29055 .43862 m .29048 .44025 L .28703 .43656 L F
0 g
.27786 .35095 m
.28779 .3477 L
s
.27786 .35095 m
.27636 .35535 L
s
.26416 .36478 m .2642 .35837 L .26518 .35976 L .953 .687 .495 r
F
.26517 .36599 m .26416 .36478 L .26518 .35976 L F
0 g
.4564 .46574 m
.45144 .47035 L
s
.39926 .3395 m
.40173 .35098 L
s
.26776 .37443 m .2672 .36841 L .26821 .36962 L .953 .687 .495 r
F
0 g
.26821 .36962 m
.26908 .36532 L
s
.35128 .44796 m
.34725 .44727 L
s
.23311 .44956 m
.23733 .4559 L
s
.23733 .4559 m
.26954 .43872 L
s
.23733 .4559 m
.23311 .44956 L
s
.19324 .49227 m
.23733 .4559 L
s
.32166 .41155 m .33479 .42052 L .31917 .41992 L .544 .324 .532 r
F
.32166 .41155 m .3351 .41143 L .33479 .42052 L F
0 g
.32166 .41155 m
.32349 .40342 L
s
.29048 .44025 m .28682 .43804 L .28703 .43656 L .953 .687 .495 r
F
.29048 .44025 m .29041 .44187 L .28682 .43804 L F
.039 .916 .04 r
.4511 .3767 m
.91145 .20006 L
s
0 0 0 r
2 Mabswid
.4511 .3767 Mdot
.26314 .36356 m .26323 .35697 L .2642 .35837 L .953 .687 .495 r
F
.26416 .36478 m .26314 .36356 L .2642 .35837 L F
.26672 .37342 m .26619 .3672 L .2672 .36841 L F
.26776 .37443 m .26672 .37342 L .2672 .36841 L F
0 g
.5 Mabswid
.27504 .44276 m
.27315 .44335 L
s
.26954 .43872 m
.27315 .44335 L
s
.31575 .44067 m
.31948 .44306 L
s
.31948 .44306 m
.34301 .4455 L
s
.29041 .44187 m .28662 .43953 L .28682 .43804 L .953 .687 .495 r
F
.29041 .44187 m .29034 .4435 L .28662 .43953 L F
.26314 .36356 m .26213 .36235 L .26323 .35697 L F
0 g
.26323 .35697 m
.26482 .35233 L
s
.14835 .52174 m
.15713 .5323 L
s
.15713 .5323 m
.16137 .53099 L
s
.28456 .37574 m .30111 .37039 L .30815 .37446 L .656 .751 .92 r
F
.2797 .37096 m .30111 .37039 L .28456 .37574 L F
0 g
.28456 .37574 m
.28941 .3805 L
s
.039 .916 .04 r
.29048 .38156 m
.30972 .37545 L
s
.2721 .37867 m
.28383 .37502 L
s
0 g
.27504 .44276 m
.27143 .43813 L
s
.21416 .38634 m
.25037 .38112 L
s
.21416 .38634 m
.21465 .39411 L
s
.15712 .38394 m
.21416 .38634 L
s
.21416 .38634 m
.21464 .39412 L
s
.26569 .37241 m .26517 .36599 L .26619 .3672 L .953 .687 .495 r
F
.26672 .37342 m .26569 .37241 L .26619 .3672 L F
.28743 .43359 m .28399 .43088 L .28432 .42957 L F
.28743 .43359 m .28723 .43507 L .28399 .43088 L F
0 g
.28743 .43359 m
.29062 .437 L
s
.35127 .44859 m
.35545 .4493 L
s
.35545 .4493 m
.38401 .46428 L
s
0 0 0 r
2 Mabswid
.30972 .37545 Mdot
0 g
.5 Mabswid
.3782 .24966 m
.38412 .24766 L
s
.3782 .24966 m
.37164 .24953 L
s
.36484 .37515 m .40126 .37591 L .36398 .38468 L .544 .324 .532 r
F
.36484 .37515 m .40239 .36312 L .40907 .37127 L .656 .751 .92 r
F
.36484 .37515 m .40239 .36312 L .40126 .37591 L .544 .324 .532 r
F
0 g
.40907 .37127 m
.41388 .37995 L
s
.35846 .36947 m .40239 .36312 L .36484 .37515 L .656 .751 .92 r
F
0 0 0 r
2 Mabswid
.36484 .37515 Mdot
0 g
.5 Mabswid
.36449 .36603 m
.36459 .36858 L
s
.039 .916 .04 r
.40153 .37286 m
.40873 .37078 L
s
.336 .38438 m
.36484 .37515 L
s
.29034 .4435 m .28641 .44102 L .28662 .43953 L .953 .687 .495 r
F
.29034 .4435 m .29027 .44513 L .28641 .44102 L F
0 g
.25043 .37508 m
.25232 .37446 L
s
.25037 .38112 m
.25043 .37508 L
s
0 0 0 r
2 Mabswid
.28383 .37502 Mdot
0 g
.5 Mabswid
.3351 .41143 m
.3354 .40238 L
s
.30229 .43284 m .31197 .43742 L .30198 .44055 L .544 .324 .532 r
F
.30229 .43284 m .31596 .42854 L .31197 .43742 L F
0 g
.30229 .43284 m
.3026 .42516 L
s
.30198 .44055 m
.30229 .43284 L
s
.30198 .44055 m
.30577 .44379 L
s
.30577 .44379 m
.31575 .44067 L
s
.19324 .49227 m
.20021 .50084 L
s
.30764 .32803 m
.31035 .32474 L
s
.26465 .3714 m .26416 .36478 L .26517 .36599 L .953 .687 .495 r
F
.26569 .37241 m .26465 .3714 L .26517 .36599 L F
.28723 .43507 m .28365 .4322 L .28399 .43088 L F
.28723 .43507 m .28703 .43656 L .28365 .4322 L F
0 g
.25226 .38051 m
.25232 .37446 L
s
.30815 .37446 m .31909 .36746 L .32475 .37313 L .656 .751 .92 r
F
0 g
.32475 .37313 m
.33039 .37877 L
s
.30111 .37039 m .31909 .36746 L .30815 .37446 L .656 .751 .92 r
F
0 g
.30815 .37446 m
.3145 .37873 L
s
.039 .916 .04 r
.30972 .37545 m
.32291 .37129 L
s
.26772 .37967 m .26672 .37342 L .26776 .37443 L .953 .687 .495 r
F
0 g
.26776 .37443 m
.26821 .36962 L
s
.16137 .53099 m
.15259 .52042 L
s
.41837 .37116 m .44171 .36373 L .44952 .3743 L .656 .751 .92 r
F
0 g
.44952 .3743 m
.45611 .38514 L
s
.28779 .3477 m
.3054 .33231 L
s
.28779 .3477 m
.28631 .3521 L
s
.29027 .44513 m .28621 .44251 L .28641 .44102 L .953 .687 .495 r
F
.29027 .44513 m .2902 .44676 L .28621 .44251 L F
0 g
.2902 .44676 m
.29422 .45016 L
s
.22917 .44255 m
.23311 .44956 L
s
.23311 .44956 m
.26608 .43346 L
s
.23311 .44956 m
.22916 .44256 L
s
.18658 .48246 m
.23311 .44956 L
s
.26362 .37039 m .26314 .36356 L .26416 .36478 L .953 .687 .495 r
F
.26465 .3714 m .26362 .37039 L .26416 .36478 L F
.31917 .41992 m .33449 .42965 L .31596 .42854 L .544 .324 .532 r
F
.31917 .41992 m .33479 .42052 L .33449 .42965 L F
0 g
.31917 .41992 m
.32166 .41155 L
s
.28703 .43656 m .28331 .43352 L .28365 .4322 L .953 .687 .495 r
F
.28703 .43656 m .28682 .43804 L .28331 .43352 L F
0 g
.37758 .24752 m
.38412 .24766 L
s
.26669 .37888 m .26569 .37241 L .26672 .37342 L .953 .687 .495 r
F
.26772 .37967 m .26669 .37888 L .26672 .37342 L F
0 g
.38911 .46365 m
.38401 .46428 L
s
.27636 .35535 m
.28631 .3521 L
s
.27636 .35535 m
.27534 .36045 L
s
.26608 .43346 m
.26954 .43872 L
s
.26954 .43872 m
.27143 .43813 L
s
.31293 .32126 m
.32709 .2928 L
s
.31293 .32126 m
.31011 .32467 L
s
.10395 .37299 m
.10816 .37159 L
s
.1034 .38712 m
.10395 .37299 L
s
.21465 .39411 m
.25081 .38755 L
s
.21465 .39411 m
.21573 .40222 L
s
.15777 .39606 m
.21464 .39412 L
s
.21573 .40222 m
.21464 .39412 L
s
.28432 .42957 m .28088 .42612 L .28134 .425 L .953 .687 .495 r
F
.28432 .42957 m .28399 .43088 L .28088 .42612 L F
0 g
.28432 .42957 m
.28743 .43359 L
s
.26258 .36938 m .26213 .36235 L .26314 .36356 L .953 .687 .495 r
F
.26362 .37039 m .26258 .36938 L .26314 .36356 L F
0 g
.27143 .43813 m
.26798 .43286 L
s
.28682 .43804 m .28298 .43484 L .28331 .43352 L .953 .687 .495 r
F
.28682 .43804 m .28662 .43953 L .28298 .43484 L F
0 g
.15712 .38394 m
.15744 .37258 L
s
.26565 .37809 m .26465 .3714 L .26569 .37241 L .953 .687 .495 r
F
.26669 .37888 m .26565 .37809 L .26569 .37241 L F
0 g
.25037 .38112 m
.25226 .38051 L
s
.25037 .38112 m
.25081 .38755 L
s
.26812 .38524 m .26669 .37888 L .26772 .37967 L .953 .687 .495 r
F
0 g
.26772 .37967 m
.26776 .37443 L
s
.26258 .36938 m .26154 .36837 L .26213 .36235 L .953 .687 .495 r
F
0 g
.26213 .36235 m
.26323 .35697 L
s
.28399 .43088 m .28042 .42725 L .28088 .42612 L .953 .687 .495 r
F
.28399 .43088 m .28365 .4322 L .28042 .42725 L F
0 g
.31575 .44067 m
.33863 .44267 L
s
.2527 .38694 m
.25226 .38051 L
s
.28662 .43953 m .28264 .43615 L .28298 .43484 L .953 .687 .495 r
F
.28662 .43953 m .28641 .44102 L .28264 .43615 L F
0 g
.10762 .38572 m
.10816 .37159 L
s
.22556 .43501 m
.22917 .44255 L
s
.22917 .44255 m
.26284 .42764 L
s
.22916 .44256 m
.22556 .43501 L
s
.18036 .47159 m
.22916 .44256 L
s
.26461 .3773 m .26362 .37039 L .26465 .3714 L .953 .687 .495 r
F
.26565 .37809 m .26461 .3773 L .26465 .3714 L F
0 g
.34725 .44727 m
.34301 .4455 L
s
0 0 0 r
2 Mabswid
.32291 .37129 Mdot
.40881 .36107 m .44171 .36373 L .41837 .37116 L .656 .751 .92 r
F
0 g
.5 Mabswid
.41837 .37116 m
.42767 .38122 L
s
.039 .916 .04 r
.42281 .37593 m
.44558 .36873 L
s
0 g
.2982 .43651 m
.30198 .44055 L
s
.2797 .37096 m .29335 .36653 L .30111 .37039 L .656 .751 .92 r
F
.27481 .36616 m .29335 .36653 L .2797 .37096 L F
0 g
.2797 .37096 m
.28456 .37574 L
s
.2671 .38468 m .26565 .37809 L .26669 .37888 L .953 .687 .495 r
F
.26812 .38524 m .2671 .38468 L .26669 .37888 L F
0 g
.21573 .40222 m
.25173 .39426 L
s
.21573 .40222 m
.2174 .41051 L
s
.15938 .4087 m
.21573 .40222 L
s
.2174 .41051 m
.21573 .40222 L
s
.26284 .42764 m
.26608 .43346 L
s
.26608 .43346 m
.26798 .43286 L
s
.039 .916 .04 r
.40873 .37078 m
.41586 .36849 L
s
.28365 .4322 m .27996 .42837 L .28042 .42725 L .953 .687 .495 r
F
.28365 .4322 m .28331 .43352 L .27996 .42837 L F
.28134 .425 m .27797 .42087 L .27855 .41996 L F
.28134 .425 m .28088 .42612 L .27797 .42087 L F
0 g
.28134 .425 m
.28432 .42957 L
s
.28641 .44102 m .2823 .43748 L .28264 .43615 L .953 .687 .495 r
F
.28641 .44102 m .28621 .44251 L .2823 .43748 L F
0 g
.28621 .44251 m
.2902 .44676 L
s
.31596 .42854 m .33418 .43882 L .31197 .43742 L .544 .324 .532 r
F
0 g
.30198 .44055 m
.31197 .43742 L
s
.31197 .43742 m
.31575 .44067 L
s
.31596 .42854 m .33449 .42965 L .33418 .43882 L .544 .324 .532 r
F
0 g
.31596 .42854 m
.31917 .41992 L
s
.31197 .43742 m
.31596 .42854 L
s
.36398 .38468 m .39828 .38935 L .3619 .39465 L .544 .324 .532 r
F
.36398 .38468 m .40126 .37591 L .39828 .38935 L F
0 g
.36398 .38468 m
.36484 .37515 L
s
.26358 .37651 m .26258 .36938 L .26362 .37039 L .953 .687 .495 r
F
.26461 .3773 m .26358 .37651 L .26362 .37039 L F
.30111 .37039 m .3134 .36177 L .31909 .36746 L .656 .751 .92 r
F
0 g
.31909 .36746 m
.32475 .37313 L
s
.29335 .36653 m .3134 .36177 L .30111 .37039 L .656 .751 .92 r
F
0 g
.30111 .37039 m
.30815 .37446 L
s
.039 .916 .04 r
.28383 .37502 m
.30012 .36986 L
s
0 g
.32709 .2928 m
.3314 .28977 L
s
.33479 .42052 m
.3351 .41143 L
s
.26798 .43286 m
.26474 .42704 L
s
.26893 .39104 m .2671 .38468 L .26812 .38524 L .953 .687 .495 r
F
0 g
.26772 .37967 m
.26812 .38524 L
s
.25081 .38755 m
.2527 .38694 L
s
.25081 .38755 m
.25173 .39426 L
s
.22236 .42706 m
.22556 .43501 L
s
.22556 .43501 m
.25988 .42139 L
s
.22556 .43501 m
.22236 .42706 L
s
.17468 .45985 m
.22556 .43501 L
s
0 0 0 r
2 Mabswid
.30012 .36986 Mdot
.26607 .38413 m .26461 .3773 L .26565 .37809 L .953 .687 .495 r
F
.2671 .38468 m .26607 .38413 L .26565 .37809 L F
.28331 .43352 m .27949 .4295 L .27996 .42837 L F
.28331 .43352 m .28298 .43484 L .27949 .4295 L F
0 g
.5 Mabswid
.34687 .44676 m
.35127 .44859 L
s
.35127 .44859 m
.37851 .46338 L
s
.28088 .42612 m .27739 .42178 L .27797 .42087 L .953 .687 .495 r
F
.28088 .42612 m .28042 .42725 L .27739 .42178 L F
.409 .34522 m .4327 .35342 L .40881 .36107 L .544 .324 .532 r
F
.409 .34522 m .43233 .3377 L .4327 .35342 L F
0 g
.409 .34522 m
.40901 .32954 L
s
.43083 .32246 m
.43233 .3377 L
s
.2174 .41051 m
.25313 .40112 L
s
.2174 .41051 m
.21962 .41884 L
s
.16194 .42164 m
.2174 .41051 L
s
.21962 .41884 m
.2174 .41051 L
s
.35846 .36947 m .39388 .35549 L .40239 .36312 L .656 .751 .92 r
F
0 g
.40173 .35098 m
.40239 .36312 L
s
.35083 .36415 m .39388 .35549 L .35846 .36947 L .656 .751 .92 r
F
0 g
.35846 .36947 m
.36484 .37515 L
s
.039 .916 .04 r
.32946 .37784 m
.35774 .36891 L
s
.26254 .37572 m .26154 .36837 L .26258 .36938 L .953 .687 .495 r
F
.26358 .37651 m .26254 .37572 L .26258 .36938 L F
0 g
.25362 .39365 m
.2527 .38694 L
s
.18658 .48246 m
.19324 .49227 L
s
.43974 .47494 m
.44545 .47217 L
s
.44545 .47217 m
.45144 .47035 L
s
.3054 .33231 m
.30764 .32803 L
s
.27855 .41996 m .2753 .41522 L .27599 .41454 L .953 .687 .495 r
F
.27855 .41996 m .27797 .42087 L .2753 .41522 L F
0 g
.27855 .41996 m
.28134 .425 L
s
.21962 .41884 m
.22236 .42706 L
s
.22236 .42706 m
.25724 .4148 L
s
.22236 .42706 m
.21962 .41884 L
s
.16965 .44745 m
.22236 .42706 L
s
0 0 0 r
2 Mabswid
.35774 .36891 Mdot
0 g
.5 Mabswid
.21962 .41884 m
.25498 .40801 L
s
.16538 .43464 m
.21962 .41884 L
s
.25988 .42139 m
.26284 .42764 L
s
.26284 .42764 m
.26474 .42704 L
s
.26794 .39073 m .26607 .38413 L .2671 .38468 L .953 .687 .495 r
F
.26893 .39104 m .26794 .39073 L .2671 .38468 L F
0 g
.13996 .50961 m
.14835 .52174 L
s
.14835 .52174 m
.15259 .52042 L
s
.039 .916 .04 r
.44558 .36873 m
.91147 .20008 L
s
0 0 0 r
2 Mabswid
.44558 .36873 Mdot
.26505 .38357 m .26358 .37651 L .26461 .3773 L .953 .687 .495 r
F
.26607 .38413 m .26505 .38357 L .26461 .3773 L F
.28298 .43484 m .27903 .43062 L .27949 .4295 L F
.28298 .43484 m .28264 .43615 L .27903 .43062 L F
.27015 .39698 m .26794 .39073 L .26893 .39104 L F
0 g
.5 Mabswid
.26812 .38524 m
.26893 .39104 L
s
.28042 .42725 m .2768 .42269 L .27739 .42178 L .953 .687 .495 r
F
.28042 .42725 m .27996 .42837 L .2768 .42269 L F
.26254 .37572 m .2615 .37492 L .26154 .36837 L F
0 g
.26154 .36837 m
.26213 .36235 L
s
.25173 .39426 m
.25362 .39365 L
s
.25173 .39426 m
.25313 .40112 L
s
.26474 .42704 m
.26177 .42079 L
s
.27599 .41454 m .27292 .40928 L .27371 .40883 L .953 .687 .495 r
F
.27599 .41454 m .2753 .41522 L .27292 .40928 L F
0 g
.27599 .41454 m
.27855 .41996 L
s
.27797 .42087 m .27461 .4159 L .2753 .41522 L .953 .687 .495 r
F
.27797 .42087 m .27739 .42178 L .27461 .4159 L F
0 g
.3082 .43336 m
.31197 .43742 L
s
.31197 .43742 m
.33418 .43882 L
s
.25502 .40051 m
.25362 .39365 L
s
.26695 .39042 m .26505 .38357 L .26607 .38413 L .953 .687 .495 r
F
.26794 .39073 m .26695 .39042 L .26607 .38413 L F
.27015 .39698 m .26921 .39692 L .26794 .39073 L F
.27175 .40295 m .26921 .39692 L .27015 .39698 L F
0 g
.26893 .39104 m
.27015 .39698 L
s
.26403 .38302 m .26254 .37572 L .26358 .37651 L .953 .687 .495 r
F
.26505 .38357 m .26403 .38302 L .26358 .37651 L F
0 g
.25724 .4148 m
.25988 .42139 L
s
.25988 .42139 m
.26177 .42079 L
s
.28264 .43615 m .27857 .43175 L .27903 .43062 L .953 .687 .495 r
F
.28264 .43615 m .2823 .43748 L .27857 .43175 L F
0 g
.2823 .43748 m
.28621 .44251 L
s
.31011 .32467 m
.32336 .29727 L
s
.31011 .32467 m
.30779 .32911 L
s
.15259 .52042 m
.14421 .50829 L
s
.29452 .43173 m
.2982 .43651 L
s
.2982 .43651 m
.3082 .43336 L
s
.15712 .38394 m
.15777 .39606 L
s
.45144 .47035 m
.44576 .47312 L
s
.26921 .39692 m .26695 .39042 L .26794 .39073 L .953 .687 .495 r
F
.27371 .40883 m .27088 .40314 L .27175 .40295 L F
.27371 .40883 m .27292 .40928 L .27088 .40314 L F
0 g
.27371 .40883 m
.27599 .41454 L
s
.27996 .42837 m .27622 .42361 L .2768 .42269 L .953 .687 .495 r
F
.27996 .42837 m .27949 .4295 L .27622 .42361 L F
0 g
.25313 .40112 m
.25502 .40051 L
s
.25313 .40112 m
.25498 .40801 L
s
.27175 .40295 m .27088 .40314 L .26921 .39692 L .953 .687 .495 r
F
0 g
.27175 .40295 m
.27371 .40883 L
s
.27015 .39698 m
.27175 .40295 L
s
.26177 .42079 m
.25913 .4142 L
s
.25913 .4142 m
.25724 .4148 L
s
.25498 .40801 m
.25724 .4148 L
s
.25498 .40801 m
.25687 .4074 L
s
.2753 .41522 m .27213 .40972 L .27292 .40928 L .953 .687 .495 r
F
.2753 .41522 m .27461 .4159 L .27213 .40972 L F
.27739 .42178 m .27392 .41659 L .27461 .4159 L F
.27739 .42178 m .2768 .42269 L .27392 .41659 L F
0 g
.25687 .4074 m
.25502 .40051 L
s
.27481 .36616 m .28478 .36291 L .29335 .36653 L .656 .751 .92 r
F
0 g
.27481 .36616 m
.27534 .36045 L
s
.27481 .36616 m
.2797 .37096 L
s
.29335 .36653 m .30768 .35605 L .3134 .36177 L .656 .751 .92 r
F
0 g
.3134 .36177 m
.31909 .36746 L
s
.28478 .36291 m .30768 .35605 L .29335 .36653 L .656 .751 .92 r
F
.039 .916 .04 r
.30012 .36986 m
.31638 .36476 L
s
0 g
.29335 .36653 m
.30111 .37039 L
s
.27534 .36045 m
.2853 .3572 L
s
.2853 .3572 m
.28631 .3521 L
s
.26597 .39011 m .26403 .38302 L .26505 .38357 L .953 .687 .495 r
F
.26695 .39042 m .26597 .39011 L .26505 .38357 L F
.26301 .38246 m .2615 .37492 L .26254 .37572 L F
.26403 .38302 m .26301 .38246 L .26254 .37572 L F
0 g
.1034 .38712 m
.10762 .38572 L
s
.1034 .38712 m
.10409 .40219 L
s
.26921 .39692 m .26827 .39686 L .26695 .39042 L .953 .687 .495 r
F
.27088 .40314 m .26827 .39686 L .26921 .39692 L F
0 g
.27478 .37238 m
.27481 .36616 L
s
.25913 .4142 m
.25687 .4074 L
s
.3619 .39465 m .39328 .40349 L .35849 .40507 L .544 .324 .532 r
F
.3619 .39465 m .39828 .38935 L .39328 .40349 L F
0 g
.3619 .39465 m
.36398 .38468 L
s
.27949 .4295 m .27564 .42452 L .27622 .42361 L .953 .687 .495 r
F
.27949 .4295 m .27903 .43062 L .27564 .42452 L F
.26827 .39686 m .26597 .39011 L .26695 .39042 L F
.27292 .40928 m .27001 .40333 L .27088 .40314 L F
.27292 .40928 m .27213 .40972 L .27001 .40333 L F
0 g
.34301 .4455 m
.33863 .44267 L
s
.27088 .40314 m .27001 .40333 L .26827 .39686 L .953 .687 .495 r
F
0 g
.33449 .42965 m
.33479 .42052 L
s
.38401 .46428 m
.37851 .46338 L
s
.2768 .42269 m .27323 .41727 L .27392 .41659 L .953 .687 .495 r
F
.2768 .42269 m .27622 .42361 L .27323 .41727 L F
.26301 .38246 m .26198 .3819 L .2615 .37492 L F
0 g
.2615 .37492 m
.26154 .36837 L
s
.27461 .4159 m .27135 .41016 L .27213 .40972 L .953 .687 .495 r
F
.27461 .4159 m .27392 .41659 L .27135 .41016 L F
0 g
.37164 .24953 m
.37758 .24752 L
s
.37164 .24953 m
.3656 .25133 L
s
.26498 .3898 m .26301 .38246 L .26403 .38302 L .953 .687 .495 r
F
.26597 .39011 m .26498 .3898 L .26403 .38302 L F
0 g
.10832 .4008 m
.10762 .38572 L
s
.26827 .39686 m .26734 .3968 L .26597 .39011 L .953 .687 .495 r
F
.27001 .40333 m .26734 .3968 L .26827 .39686 L F
.27903 .43062 m .27506 .42544 L .27564 .42452 L F
.27903 .43062 m .27857 .43175 L .27506 .42544 L F
0 g
.27857 .43175 m
.2823 .43748 L
s
.26734 .3968 m .26498 .3898 L .26597 .39011 L .953 .687 .495 r
F
0 0 0 r
2 Mabswid
.31638 .36476 Mdot
.27213 .40972 m .26914 .40353 L .27001 .40333 L .953 .687 .495 r
F
.27213 .40972 m .27135 .41016 L .26914 .40353 L F
0 g
.5 Mabswid
.18036 .47159 m
.18658 .48246 L
s
.27001 .40333 m .26914 .40353 L .26734 .3968 L .953 .687 .495 r
F
0 g
.29098 .42629 m
.29452 .43173 L
s
.29452 .43173 m
.30452 .42857 L
s
.30452 .42857 m
.3082 .43336 L
s
.3082 .43336 m
.32975 .434 L
s
.35083 .36415 m .38346 .34841 L .39388 .35549 L .656 .751 .92 r
F
.34184 .35924 m .38346 .34841 L .35083 .36415 L F
.039 .916 .04 r
.36484 .37515 m
.40239 .36312 L
s
0 g
.35083 .36415 m
.35846 .36947 L
s
.039 .916 .04 r
.32291 .37129 m
.34912 .36312 L
s
.27622 .42361 m .27254 .41796 L .27323 .41727 L .953 .687 .495 r
F
.27622 .42361 m .27564 .42452 L .27254 .41796 L F
.26399 .38949 m .26198 .3819 L .26301 .38246 L F
.26498 .3898 m .26399 .38949 L .26301 .38246 L F
.27392 .41659 m .27056 .4106 L .27135 .41016 L F
.27392 .41659 m .27323 .41727 L .27056 .4106 L F
0 g
.34233 .44381 m
.34687 .44676 L
s
.30369 .33751 m
.3054 .33231 L
s
.40881 .36107 m .4327 .35342 L .44171 .36373 L .656 .751 .92 r
F
0 g
.40239 .36312 m
.40907 .37127 L
s
.44171 .36373 m
.44952 .3743 L
s
.26734 .3968 m .2664 .39674 L .26498 .3898 L .953 .687 .495 r
F
.26914 .40353 m .2664 .39674 L .26734 .3968 L F
.2664 .39674 m .26399 .38949 L .26498 .3898 L F
0 g
.37156 .24932 m
.37758 .24752 L
s
.27135 .41016 m .26827 .40372 L .26914 .40353 L .953 .687 .495 r
F
.27135 .41016 m .27056 .4106 L .26827 .40372 L F
0 g
.27478 .37238 m
.28476 .36914 L
s
.27478 .37238 m
.27525 .37899 L
s
.26914 .40353 m .26827 .40372 L .2664 .39674 L .953 .687 .495 r
F
0 0 0 r
2 Mabswid
.40239 .36312 Mdot
0 g
.5 Mabswid
.40126 .37591 m
.40239 .36312 L
s
0 0 0 r
2 Mabswid
.34912 .36312 Mdot
0 g
.5 Mabswid
.15777 .39606 m
.15938 .4087 L
s
.13212 .49614 m
.13996 .50961 L
s
.13996 .50961 m
.14421 .50829 L
s
.28478 .36291 m .30193 .3503 L .30768 .35605 L .656 .751 .92 r
F
0 g
.28478 .36291 m
.30193 .3503 L
s
.27481 .36616 m
.28478 .36291 L
s
.28478 .36291 m
.2853 .3572 L
s
.2853 .3572 m
.30252 .34354 L
s
.28478 .36291 m
.29335 .36653 L
s
.28631 .3521 m
.30369 .33751 L
s
.28476 .36914 m
.28478 .36291 L
s
.27564 .42452 m .27184 .41865 L .27254 .41796 L .953 .687 .495 r
F
.27564 .42452 m .27506 .42544 L .27184 .41865 L F
0 g
.27506 .42544 m
.27857 .43175 L
s
.26399 .38949 m .26299 .38918 L .26198 .3819 L .953 .687 .495 r
F
0 g
.2615 .37492 m
.26198 .3819 L
s
.27323 .41727 m .26977 .41105 L .27056 .4106 L .953 .687 .495 r
F
.27323 .41727 m .27254 .41796 L .26977 .41105 L F
0 g
.32336 .29727 m
.32709 .2928 L
s
.2664 .39674 m .26546 .39668 L .26399 .38949 L .953 .687 .495 r
F
.26827 .40372 m .26546 .39668 L .2664 .39674 L F
.26546 .39668 m .26299 .38918 L .26399 .38949 L F
.35849 .40507 m .3859 .41842 L .35358 .41599 L .544 .324 .532 r
F
.35849 .40507 m .39328 .40349 L .3859 .41842 L F
0 g
.35849 .40507 m
.3619 .39465 L
s
.27056 .4106 m .2674 .40391 L .26827 .40372 L .953 .687 .495 r
F
.27056 .4106 m .26977 .41105 L .2674 .40391 L F
0 g
.30779 .32911 m
.30601 .33451 L
s
.26827 .40372 m .2674 .40391 L .26546 .39668 L .953 .687 .495 r
F
0 g
.30768 .35605 m
.3134 .36177 L
s
.28767 .4203 m
.29098 .42629 L
s
.29098 .42629 m
.301 .42313 L
s
.14421 .50829 m
.13637 .49481 L
s
.27254 .41796 m .26898 .41149 L .26977 .41105 L .953 .687 .495 r
F
.27254 .41796 m .27184 .41865 L .26898 .41149 L F
0 g
.27184 .41865 m
.27506 .42544 L
s
.10409 .40219 m
.10832 .4008 L
s
.10409 .40219 m
.106 .41793 L
s
.40881 .36107 m .43194 .36962 L .40844 .37709 L .544 .324 .532 r
F
.40881 .36107 m .4327 .35342 L .43194 .36962 L F
.39899 .35095 m .4327 .35342 L .40881 .36107 L .656 .751 .92 r
F
0 0 0 r
2 Mabswid
.40881 .36107 Mdot
.039 .916 .04 r
.5 Mabswid
.40239 .36312 m
.40881 .36107 L
s
0 g
.40892 .35168 m
.409 .34522 L
s
.039 .916 .04 r
.43224 .36328 m
.43945 .36098 L
s
0 g
.39388 .35549 m
.40239 .36312 L
s
.301 .42313 m
.30452 .42857 L
s
.30452 .42857 m
.32541 .42831 L
s
.26546 .39668 m .26452 .39663 L .26299 .38918 L .953 .687 .495 r
F
0 g
.26198 .3819 m
.26299 .38918 L
s
.2674 .40391 m .26452 .39663 L .26546 .39668 L .953 .687 .495 r
F
.039 .916 .04 r
.43945 .36098 m
.91149 .20011 L
s
0 0 0 r
2 Mabswid
.43945 .36098 Mdot
0 g
.5 Mabswid
.27525 .37899 m
.28525 .37576 L
s
.27525 .37899 m
.27622 .3859 L
s
.17468 .45985 m
.18036 .47159 L
s
.33418 .43882 m
.33449 .42965 L
s
.33418 .43882 m
.33863 .44267 L
s
.26977 .41105 m .26653 .40411 L .2674 .40391 L .953 .687 .495 r
F
.26977 .41105 m .26898 .41149 L .26653 .40411 L F
.2674 .40391 m .26653 .40411 L .26452 .39663 L F
0 g
.26299 .38918 m
.26452 .39663 L
s
.26898 .41149 m
.27184 .41865 L
s
.28476 .36914 m
.30194 .35767 L
s
.28476 .36914 m
.28525 .37576 L
s
.15938 .4087 m
.16194 .42164 L
s
.26452 .39663 m
.26653 .40411 L
s
.28462 .41385 m
.28767 .4203 L
s
.28767 .4203 m
.29768 .41712 L
s
.11024 .41655 m
.10832 .4008 L
s
.26653 .40411 m
.26898 .41149 L
s
.34184 .35924 m .37097 .34193 L .38346 .34841 L .656 .751 .92 r
F
.33133 .35479 m .37097 .34193 L .34184 .35924 L F
.039 .916 .04 r
.35774 .36891 m
.39442 .35592 L
s
0 g
.34184 .35924 m
.35083 .36415 L
s
.039 .916 .04 r
.31638 .36476 m
.33883 .35784 L
s
0 g
.27622 .3859 m
.28623 .38267 L
s
.27622 .3859 m
.27768 .39296 L
s
.4334 .4758 m
.43974 .47494 L
s
.43974 .47494 m
.44576 .47312 L
s
.30252 .34354 m
.30369 .33751 L
s
.35358 .41599 m .37548 .43435 L .34686 .42751 L .544 .324 .532 r
F
.35358 .41599 m .3859 .41842 L .37548 .43435 L F
0 g
.35358 .41599 m
.35849 .40507 L
s
.29768 .41712 m
.301 .42313 L
s
.301 .42313 m
.32124 .42184 L
s
.12499 .48157 m
.13212 .49614 L
s
.13212 .49614 m
.13637 .49481 L
s
.28191 .40706 m
.28462 .41385 L
s
.28462 .41385 m
.29464 .41066 L
s
.16965 .44745 m
.17468 .45985 L
s
.27768 .39296 m
.28769 .38974 L
s
.27768 .39296 m
.27958 .40006 L
s
0 0 0 r
2 Mabswid
.33883 .35784 Mdot
0 g
.5 Mabswid
.28525 .37576 m
.30253 .36553 L
s
.28525 .37576 m
.28623 .38267 L
s
.16194 .42164 m
.16538 .43464 L
s
.27958 .40006 m
.28191 .40706 L
s
.28191 .40706 m
.29193 .40386 L
s
.37851 .46338 m
.37269 .46097 L
s
.27958 .40006 m
.2896 .39685 L
s
.106 .41793 m
.11024 .41655 L
s
.106 .41793 m
.10912 .43404 L
s
.13637 .49481 m
.12924 .48023 L
s
.44576 .47312 m
.43944 .47396 L
s
.16538 .43464 m
.16965 .44745 L
s
.39828 .38935 m
.40126 .37591 L
s
.30601 .33451 m
.30481 .34077 L
s
.29464 .41066 m
.29768 .41712 L
s
.29768 .41712 m
.31733 .4147 L
s
.32975 .434 m
.33418 .43882 L
s
.039 .916 .04 r
.39442 .35592 m
.40161 .35363 L
s
0 0 0 r
2 Mabswid
.39442 .35592 Mdot
.34686 .42751 m .36054 .45172 L .33771 .43981 L .544 .324 .532 r
F
0 g
.5 Mabswid
.33771 .43981 m
.34233 .44381 L
s
.34686 .42751 m .37548 .43435 L .36054 .45172 L .544 .324 .532 r
F
0 g
.34687 .44676 m
.37269 .46097 L
s
.34686 .42751 m
.35358 .41599 L
s
.34233 .44381 m
.36667 .45706 L
s
.33771 .43981 m
.34686 .42751 L
s
.28623 .38267 m
.30371 .37374 L
s
.28623 .38267 m
.28769 .38974 L
s
.11336 .43267 m
.11024 .41655 L
s
.1187 .46617 m
.12499 .48157 L
s
.12499 .48157 m
.12924 .48023 L
s
.29193 .40386 m
.29464 .41066 L
s
.29464 .41066 m
.31373 .40701 L
s
.3656 .25133 m
.37156 .24932 L
s
.3656 .25133 m
.3602 .25505 L
s
.33133 .35479 m .35607 .33618 L .37097 .34193 L .656 .751 .92 r
F
.31899 .3509 m .35607 .33618 L .33133 .35479 L F
0 g
.33133 .35479 m
.34184 .35924 L
s
.28769 .38974 m
.30546 .38214 L
s
.28769 .38974 m
.2896 .39685 L
s
.32029 .30314 m
.32336 .29727 L
s
.10912 .43404 m
.11336 .43267 L
s
.10912 .43404 m
.11338 .45022 L
s
.30193 .3503 m
.30252 .34354 L
s
.2896 .39685 m
.29193 .40386 L
s
.29193 .40386 m
.31051 .39893 L
s
.2896 .39685 m
.30774 .39059 L
s
.12924 .48023 m
.12296 .46481 L
s
.33311 .43481 m
.33771 .43981 L
s
.33771 .43981 m
.36054 .45172 L
s
0 0 0 r
2 Mabswid
.40161 .35363 Mdot
0 g
.5 Mabswid
.11338 .45022 m
.1187 .46617 L
s
.1187 .46617 m
.12296 .46481 L
s
.39899 .35095 m .42247 .34339 L .4327 .35342 L .656 .751 .92 r
F
0 0 0 r
2 Mabswid
.4327 .35342 Mdot
.039 .916 .04 r
.5 Mabswid
.4327 .35342 m
.9115 .20013 L
s
.40881 .36107 m
.4327 .35342 L
s
0 g
.43233 .3377 m
.4327 .35342 L
s
.4327 .35342 m
.44171 .36373 L
s
.11338 .45022 m
.11763 .44886 L
s
.36618 .25304 m
.37156 .24932 L
s
.11763 .44886 m
.11336 .43267 L
s
.40844 .37709 m .43003 .38629 L .4079 .39328 L .544 .324 .532 r
F
.40844 .37709 m .43194 .36962 L .43003 .38629 L F
0 g
.40844 .37709 m
.40881 .36107 L
s
.43194 .36962 m
.4327 .35342 L
s
.12296 .46481 m
.11763 .44886 L
s
.32975 .434 m
.32541 .42831 L
s
.39328 .40349 m
.39828 .38935 L
s
.38891 .3408 m .42247 .34339 L .39899 .35095 L .656 .751 .92 r
F
0 g
.39899 .35095 m
.40881 .36107 L
s
.039 .916 .04 r
.40161 .35363 m
.42529 .34601 L
s
0 g
.38346 .34841 m
.39388 .35549 L
s
.31899 .3509 m .3381 .33139 L .35607 .33618 L .656 .751 .92 r
F
.039 .916 .04 r
.33883 .35784 m
.37307 .34289 L
s
.34912 .36312 m
.38473 .34917 L
s
.3042 .34779 m .3381 .33139 L .31899 .3509 L .656 .751 .92 r
F
0 g
.31899 .3509 m
.33133 .35479 L
s
.30193 .3503 m
.30768 .35605 L
s
.30193 .3503 m
.30194 .35767 L
s
.37269 .46097 m
.36667 .45706 L
s
.32861 .42889 m
.33311 .43481 L
s
.33311 .43481 m
.35442 .44502 L
s
.039 .916 .04 r
.38473 .34917 m
.39425 .34615 L
s
0 0 0 r
2 Mabswid
.38473 .34917 Mdot
0 g
.5 Mabswid
.42653 .47469 m
.4334 .4758 L
s
.4334 .4758 m
.43944 .47396 L
s
.37097 .34193 m
.38346 .34841 L
s
.32541 .42831 m
.32124 .42184 L
s
.3042 .34779 m .31556 .32805 L .3381 .33139 L .656 .751 .92 r
F
0 g
.3042 .34779 m
.31556 .32805 L
s
.30601 .33451 m
.31794 .31031 L
s
.30481 .34077 m
.31635 .31866 L
s
.3042 .34779 m
.30481 .34077 L
s
.3042 .34779 m
.31899 .3509 L
s
.30779 .32911 m
.32029 .30314 L
s
.3042 .34779 m
.30421 .35546 L
s
.31794 .31031 m
.32029 .30314 L
s
.30253 .36553 m
.30194 .35767 L
s
.43944 .47396 m
.43258 .47285 L
s
0 0 0 r
2 Mabswid
.39425 .34615 Mdot
.039 .916 .04 r
.5 Mabswid
.42529 .34601 m
.91151 .20015 L
s
0 0 0 r
2 Mabswid
.42529 .34601 Mdot
0 g
.5 Mabswid
.3859 .41842 m
.39328 .40349 L
s
.32428 .42216 m
.32861 .42889 L
s
.32861 .42889 m
.3484 .43709 L
s
.32124 .42184 m
.31733 .4147 L
s
.3602 .25505 m
.36618 .25304 L
s
.3602 .25505 m
.35554 .26066 L
s
.4079 .39328 m .42695 .40344 L .40717 .40964 L .544 .324 .532 r
F
.4079 .39328 m .43003 .38629 L .42695 .40344 L F
0 g
.4079 .39328 m
.40844 .37709 L
s
.43003 .38629 m
.43194 .36962 L
s
.30421 .35546 m
.3156 .33832 L
s
.30421 .35546 m
.30483 .36363 L
s
.30371 .37374 m
.30253 .36553 L
s
.38891 .3408 m .41102 .33364 L .42247 .34339 L .656 .751 .92 r
F
0 g
.42247 .34339 m
.4327 .35342 L
s
0 0 0 r
2 Mabswid
.37307 .34289 Mdot
0 g
.5 Mabswid
.36054 .45172 m
.36667 .45706 L
s
.36155 .25864 m
.36618 .25304 L
s
.31733 .4147 m
.31373 .40701 L
s
.32021 .41474 m
.32428 .42216 L
s
.32428 .42216 m
.34262 .42805 L
s
.35607 .33618 m
.37097 .34193 L
s
.30546 .38214 m
.30371 .37374 L
s
.37548 .43435 m
.3859 .41842 L
s
.30483 .36363 m
.31645 .34928 L
s
.30483 .36363 m
.30606 .37215 L
s
.31373 .40701 m
.31051 .39893 L
s
.37857 .33062 m .41102 .33364 L .38891 .3408 L .656 .751 .92 r
F
.039 .916 .04 r
.37307 .34289 m
.38667 .33857 L
s
0 g
.38891 .3408 m
.39899 .35095 L
s
.039 .916 .04 r
.39425 .34615 m
.41717 .33871 L
s
0 g
.30774 .39059 m
.30546 .38214 L
s
.31635 .31866 m
.31794 .31031 L
s
.31051 .39893 m
.30774 .39059 L
s
.31647 .40675 m
.32021 .41474 L
s
.32021 .41474 m
.33717 .41806 L
s
.30606 .37215 m
.31812 .36074 L
s
.30606 .37215 m
.30788 .38089 L
s
.039 .916 .04 r
.41717 .33871 m
.91154 .20018 L
s
0 0 0 r
2 Mabswid
.41717 .33871 Mdot
.38667 .33857 Mdot
0 g
.5 Mabswid
.41923 .47163 m
.42653 .47469 L
s
.42653 .47469 m
.43258 .47285 L
s
.36054 .45172 m
.37548 .43435 L
s
.31313 .39835 m
.31647 .40675 L
s
.31647 .40675 m
.33215 .40732 L
s
.30788 .38089 m
.32058 .37249 L
s
.30788 .38089 m
.31025 .38967 L
s
.32765 .396 m
.31313 .39835 L
s
.31025 .38967 m
.31313 .39835 L
s
.31025 .38967 m
.32377 .38432 L
s
.43258 .47285 m
.4253 .46978 L
s
.3381 .33139 m
.35607 .33618 L
s
.35442 .44502 m
.36054 .45172 L
s
.40717 .40964 m .42263 .42108 L .40626 .42618 L .544 .324 .532 r
F
.40717 .40964 m .42695 .40344 L .42263 .42108 L F
0 g
.40717 .40964 m
.4079 .39328 L
s
.42695 .40344 m
.43003 .38629 L
s
.35554 .26066 m
.36155 .25864 L
s
.35554 .26066 m
.35171 .26808 L
s
.31556 .32805 m
.31635 .31866 L
s
.37857 .33062 m .39831 .3242 L .41102 .33364 L .656 .751 .92 r
F
.039 .916 .04 r
.38667 .33857 m
.40829 .3315 L
s
0 g
.41102 .33364 m
.42247 .34339 L
s
.35774 .26606 m
.36155 .25864 L
s
.039 .916 .04 r
.40829 .3315 m
.91155 .2002 L
s
0 0 0 r
2 Mabswid
.40829 .3315 Mdot
0 g
.5 Mabswid
.31556 .32805 m
.3381 .33139 L
s
.36796 .32042 m .39831 .3242 L .37857 .33062 L .656 .751 .92 r
F
0 g
.37857 .33062 m
.38891 .3408 L
s
.35442 .44502 m
.3484 .43709 L
s
.41164 .46663 m
.41923 .47163 L
s
.41923 .47163 m
.4253 .46978 L
s
.31556 .32805 m
.3156 .33832 L
s
.40626 .42618 m .417 .43922 L .40517 .44288 L .544 .324 .532 r
F
.40626 .42618 m .42263 .42108 L .417 .43922 L F
0 g
.40626 .42618 m
.40717 .40964 L
s
.42263 .42108 m
.42695 .40344 L
s
.4253 .46978 m
.41773 .46476 L
s
.3484 .43709 m
.34262 .42805 L
s
.35171 .26808 m
.35774 .26606 L
s
.35171 .26808 m
.34879 .2772 L
s
.36796 .32042 m .38428 .31507 L .39831 .3242 L .656 .751 .92 r
F
0 g
.39831 .3242 m
.41102 .33364 L
s
.31645 .34928 m
.3156 .33832 L
s
.35484 .27518 m
.35774 .26606 L
s
.34262 .42805 m
.33717 .41806 L
s
.35708 .31018 m .38428 .31507 L .36796 .32042 L .656 .751 .92 r
F
0 g
.36796 .32042 m
.37857 .33062 L
s
.41164 .46663 m
.41773 .46476 L
s
.31812 .36074 m
.31645 .34928 L
s
.40517 .44288 m .40999 .45789 L .40388 .45976 L .544 .324 .532 r
F
0 g
.40388 .45976 m
.41164 .46663 L
s
.40517 .44288 m .417 .43922 L .40999 .45789 L .544 .324 .532 r
F
0 g
.40517 .44288 m
.40626 .42618 L
s
.40388 .45976 m
.40517 .44288 L
s
.417 .43922 m
.42263 .42108 L
s
.40999 .45789 m
.41773 .46476 L
s
.33717 .41806 m
.33215 .40732 L
s
.32058 .37249 m
.31812 .36074 L
s
.34879 .2772 m
.35484 .27518 L
s
.34879 .2772 m
.34685 .28787 L
s
.40999 .45789 m
.417 .43922 L
s
.35708 .31018 m .36888 .30629 L .38428 .31507 L .656 .751 .92 r
F
0 g
.38428 .31507 m
.39831 .3242 L
s
.33215 .40732 m
.32765 .396 L
s
.32377 .38432 m
.32058 .37249 L
s
.35292 .28585 m
.35484 .27518 L
s
.32765 .396 m
.32377 .38432 L
s
.39611 .45114 m
.40388 .45976 L
s
.40388 .45976 m
.40999 .45789 L
s
.34593 .29992 m .36888 .30629 L .35708 .31018 L .656 .751 .92 r
F
0 g
.35708 .31018 m
.36796 .32042 L
s
.40223 .44925 m
.40999 .45789 L
s
.34685 .28787 m
.35292 .28585 L
s
.34593 .29992 m .35201 .2979 L .36888 .30629 L .656 .751 .92 r
F
0 g
.35201 .2979 m
.36888 .30629 L
s
.34593 .29992 m
.34685 .28787 L
s
.36888 .30629 m
.38428 .31507 L
s
.34593 .29992 m
.35708 .31018 L
s
.35201 .2979 m
.35292 .28585 L
s
.38845 .44089 m
.39611 .45114 L
s
.39611 .45114 m
.40223 .44925 L
s
.40223 .44925 m
.39458 .43899 L
s
.34593 .29992 m
.35201 .2979 L
s
.34593 .29992 m
.34605 .31312 L
s
.35201 .2979 m
.35215 .31111 L
s
.38106 .4292 m
.38845 .44089 L
s
.38845 .44089 m
.39458 .43899 L
s
.39458 .43899 m
.3872 .42729 L
s
.34605 .31312 m
.35215 .31111 L
s
.34605 .31312 m
.34722 .32726 L
s
.35334 .32526 m
.35215 .31111 L
s
.37407 .41628 m
.38106 .4292 L
s
.38106 .4292 m
.3872 .42729 L
s
.34722 .32726 m
.35334 .32526 L
s
.34722 .32726 m
.34944 .34206 L
s
.3872 .42729 m
.38022 .41435 L
s
.35556 .34007 m
.35334 .32526 L
s
.36762 .40236 m
.37407 .41628 L
s
.37407 .41628 m
.38022 .41435 L
s
.34944 .34206 m
.35556 .34007 L
s
.34944 .34206 m
.35265 .35726 L
s
.38022 .41435 m
.37377 .40041 L
s
.36183 .3877 m
.36762 .40236 L
s
.36762 .40236 m
.37377 .40041 L
s
.35879 .35528 m
.35556 .34007 L
s
.35265 .35726 m
.35879 .35528 L
s
.35265 .35726 m
.3568 .37257 L
s
.36797 .38574 m
.36183 .3877 L
s
.3568 .37257 m
.36183 .3877 L
s
.3568 .37257 m
.36295 .3706 L
s
.37377 .40041 m
.36797 .38574 L
s
.36295 .3706 m
.35879 .35528 L
s
.36797 .38574 m
.36295 .3706 L
s
0 0 0 r
2 Mabswid
.91155 .2002 Mdot
.91154 .20018 Mdot
.91151 .20015 Mdot
.9115 .20013 Mdot
.91149 .20011 Mdot
.91147 .20008 Mdot
.91145 .20006 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{764.438, 484.312},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{-0.0726447, 1.08536}, {-0.458396, 1.15147}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;l0001i2000`400?l00000o`00003oo`3ooooo
0?ooooh0oooo003o0?ooool0oooooP3oool00?l0ooooo`3oooon0?ooo`00o`3ooooo0?ooooh0oooo
003o0?ooool0oooooP3oool00?l0ooooo`3oooon0?ooo`00o`3ooooo0?ooooh0oooo003o0?ooool0
oooooP3oool00?l0ooooo`3oooon0?ooo`00o`3ooooo0?ooooh0oooo003o0?ooool0oooooP3oool0
0?l0ooooo`3oooon0?ooo`00o`3ooooo0?ooooh0oooo003o0?ooool0oooooP3oool00?l0ooooo`3o
ooon0?ooo`00o`3ooooo0?ooooh0oooo003o0?ooool0oooooP3oool00?l0ooooo`3oooon0?ooo`00
o`3ooooo0?ooooh0oooo003o0?ooool0oooooP3oool00?l0ooooo`3oooon0?ooo`00o`3ooooo0?oo
ooh0oooo003o0?ooool0oooooP3oool00?l0ooooo`3oooon0?ooo`00o`3ooooo0?ooooh0oooo003o
0?ooool0oooooP3oool00?l0ooooo`3oooon0?ooo`00o`3ooooo0?ooooh0oooo003o0?ooool0oooo
oP3oool00?l0ooooo`3oooon0?ooo`00o`3ooooo0?ooooh0oooo003o0?ooool0oooooP3oool00?l0
ooooo`3oooon0?ooo`00o`3ooooo0?ooooh0oooo003o0?ooool0oooooP3oool00?l0ooooo`3oooon
0?ooo`00o`3ooooo0?ooooh0oooo003o0?ooool0oooooP3oool00?l0ooooo`3oooon0?ooo`00o`3o
oooo0?ooooh0oooo003o0?ooool0oooooP3oool00?l0ooooo`3oooon0?ooo`00o`3ooooo0?ooooh0
oooo003o0?ooool0oooooP3oool00?l0ooooo`3oooon0?ooo`00o`3ooooo0?ooooh0oooo003o0?oo
ool0oooooP3oool00?l0ooooo`3oooon0?ooo`00o`3ooooo0?ooooh0oooo003o0?ooool0oooooP3o
ool00?l0ooooo`3oooon0?ooo`00o`3ooooo0?ooooh0oooo003o0?ooool0oooooP3oool00?l0oooo
o`3oooon0?ooo`00o`3ooooo0?ooooh0oooo003o0?ooool0oooooP3oool00?l0ooooo`3oooon0?oo
o`00o`3ooooo0?ooooh0oooo003o0?ooool0oooooP3oool00?l0ooooo`3oooon0?ooo`00o`3ooooo
0?ooooh0oooo003o0?ooool0oooooP3oool00?l0ooooo`3oooon0?ooo`00o`3ooooo0?ooooh0oooo
003o0?ooool0ooookP3oool00`09jPX000000000000=0?ooo`00o`3ooooo0?ooonX0oooo1@09jPX2
000000d0oooo003o0?ooool0ooooiP3oool600WZ2Q80oooo003o0?ooool0ooooh`3oool600WZ2QD0
oooo003o0?ooool0oooog`3oool800WZ2QL0oooo003o0?ooool0oooof`3oool900WZ2QX0oooo003o
0?ooool0ooooe`3oool;00WZ2Q`0oooo003o0?ooool0ooood`3oool<00WZ2Ql0oooo003o0?ooool0
ooood03oool<00WZ2R80oooo003o0?ooool0ooooc03oool>00WZ2R@0oooo003o0?ooool0oooob03o
ool?00WZ2RL0oooo003o0?ooool0ooooa03ooolA00WZ2RT0oooo003o0?ooool0oooo`03ooolB00WZ
2R`0oooo003o0?ooool0oooo_@3ooolB00WZ2Rl0oooo003o0?ooool0oooo^@3ooolD00WZ2S40oooo
003o0?ooool0oooo]@3ooolE00WZ2S@0oooo003o0?ooool0oooo/@3oool;00WZ2P030?ooo`09jPX0
2NX:00T02NX:=P3oool00?l0ooooo`3ooon]0?ooo`@02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`03
00WZ2P030?ooo`09jPX02NX:00T02NX:>@3oool00?l0ooooo`3ooonZ0?ooo`<02NX:00<0oooo00WZ
2P09jPX04P09jPXl0?ooo`00o`3ooooo0?ooojH0oooo1009jPX01@3oool02NX:00WZ2P09jPX0oooo
00<02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0900WZ2Sh0oooo003o0?ooool0ooooXP3oool400WZ
2P030?ooo`09jPX02NX:00802NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0300WZ2P030?ooo`09jPX0
2NX:00@02NX:00<0oooo00WZ2P09jPX0@@3oool00?l0ooooo`3ooonN0?ooo`@02NX:0P3oool300WZ
2P030?ooo`09jPX02NX:00802NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0300WZ2P040?ooo`09jPX0
2NX:0?ooo`<02NX:@`3oool00?l0ooooo`3ooonJ0?ooo`@02NX:0P3oool400WZ2P040?ooo`09jPX0
2NX:00WZ2P80oooo0`09jPX01@3oool02NX:00WZ2P09jPX0oooo00H02NX:AP3oool00?l0ooooo`3o
oonG0?ooo`<02NX:0`3oool300WZ2P80oooo0`09jPX20?ooo`<02NX:00D0oooo00WZ2P09jPX02NX:
0?ooo`0300WZ2P030?ooo`09jPX02NX:04T0oooo003o0?ooool0ooooT`3oool400WZ2P80oooo1009
jPX00`3oool02NX:00WZ2P0200WZ2P80oooo0`09jPX20?ooo`802NX:00D0oooo00WZ2P09jPX02NX:
0?ooo`0300WZ2T/0oooo003o0?ooool0ooooS`3oool400WZ2P80oooo1009jPX20?ooo`<02NX:0`3o
ool300WZ2P80oooo1P09jPX0103oool02NX:00WZ2P09jPY>0?ooo`00o`3ooooo0?oooh/0oooo1009
jPX30?ooo`<02NX:0`3oool300WZ2P<0oooo0`09jPX20?ooo`<02NX:00<0oooo00WZ2P09jPX00P3o
ool200WZ2U40oooo003o0?ooool0ooooQ`3oool400WZ2P<0oooo1009jPX20?ooo`@02NX:0P3oool4
00WZ2P80oooo0`09jPX01@3oool02NX:00WZ2P09jPX0oooo00<02NX:D`3oool00?l0ooooo`3ooon4
0?ooo`<02NX:103oool300WZ2P<0oooo0`09jPX30?ooo`<02NX:0`3oool300WZ2P040?ooo`09jPX0
2NX:00WZ2P80oooo0P09jPYF0?ooo`00o`3ooooo0?oooh00oooo1009jPX30?ooo`@02NX:0`3oool3
00WZ2P<0oooo0`09jPX30?ooo`<02NX:00@0oooo00WZ2P09jPX02NX:0P3oool300WZ2UP0oooo003o
0?ooool0ooooO03oool400WZ2P@0oooo0`09jPX30?ooo`@02NX:0`3oool300WZ2P<0oooo0`09jPX2
0?ooo`802NX:0P3oool300WZ2U/0oooo003o0?ooool0ooooN03oool400WZ2P@0oooo1009jPX30?oo
o`<02NX:103oool300WZ2P<0oooo0`09jPX20?ooo`<02NX:0P3oool200WZ2Uh0oooo003o0?ooool0
ooooM03oool400WZ2PD0oooo0`09jPX40?ooo`<02NX:103oool300WZ2P<0oooo0`09jPX20?ooo`<0
2NX:0P3oool300WZ2V00oooo003o0?ooool0ooooL@3oool300WZ2PD0oooo1009jPX30?ooo`@02NX:
103oool300WZ2P<0oooo0`09jPX20?ooo`<02NX:0`3oool200WZ2V<0oooo003o0?ooool0ooooK@3o
ool400WZ2P@0oooo1009jPX40?ooo`<02NX:1@3oool300WZ2P<0oooo0`09jPX30?ooo`802NX:0`3o
ool300WZ2VD0oooo003o0?ooool0ooooJ@3oool400WZ2PD0oooo0`09jPX50?ooo`<02NX:1@3oool3
00WZ2P<0oooo0`09jPX30?ooo`<02NX:0P3oool300WZ2VP0oooo003o0?ooool0ooooI@3oool400WZ
2PD0oooo1009jPX40?ooo`@02NX:103oool400WZ2P@0oooo0P09jPX30?ooo`<02NX:0`3oool200WZ
2V/0oooo003o0?ooool0ooooH@3oool400WZ2PH0oooo0`09jPX50?ooo`<02NX:1@3oool300WZ2PD0
oooo0`09jPX20?ooo`<02NX:0`3oool300WZ2Vd0oooo003o0?ooool0ooooGP3oool300WZ2PH0oooo
1009jPX50?ooo`<02NX:1@3oool300WZ2PD0oooo0`09jPX30?ooo`802NX:103oool200WZ2W00oooo
003o0?ooool0ooooFP3oool400WZ2PH0oooo0`09jPX50?ooo`@02NX:1@3oool300WZ2PD0oooo0`09
jPX30?ooo`<02NX:0`3oool300WZ2W80oooo003o0?ooool0ooooEP3oool400WZ2PH0oooo1009jPX5
0?ooo`<02NX:1P3oool300WZ2PD0oooo0`09jPX30?ooo`<02NX:0`3oool300WZ2WD0oooo003o0?oo
ool0ooooDP3oool400WZ2PL0oooo0`09jPX60?ooo`<02NX:1P3oool300WZ2PD0oooo0`09jPX30?oo
o`<02NX:103oool200WZ2WP0oooo003o0?oooaH0oooo2P00003o0?ooobh0oooo1009jPX70?ooo`@0
2NX:1@3oool400WZ2PH0oooo0`09jPX50?ooo`<02NX:0`3oool300WZ2P@0oooo0`09jPYj0?ooo`00
o`3ooolC0?ooo`<000000`3oool3000000@0oooo0`00003o0?ooobP0oooo0`09jPX70?ooo`@02NX:
1P3oool300WZ2PL0oooo0`09jPX50?ooo`<02NX:103oool200WZ2PD0oooo0P09jPYm0?ooo`00o`3o
oolA0?ooo`T00000203oool300000?l0oooo8P3oool400WZ2PL0oooo0`09jPX70?ooo`<02NX:1`3o
ool300WZ2PD0oooo0`09jPX40?ooo`<02NX:103oool300WZ2Wl0oooo003o0?ooo`h0oooo0`000009
0?ooo`<000000P3oool3000000<0oooo00<000000?ooo`3oool0o`3ooolK0?ooo`@02NX:1`3oool4
00WZ2PH0oooo1009jPX60?ooo`@02NX:1@3oool300WZ2P@0oooo0`09jPX40?ooo`<02NX:PP3oool0
0?l0oooo2`3oool4000000h0oooo0`0000060?ooo`800000o`3ooolG0?ooo`@02NX:203oool300WZ
2PL0oooo0`09jPX70?ooo`<02NX:1P3oool300WZ2P@0oooo0`09jPX50?ooo`802NX:Q@3oool00?l0
oooo2@3oool2000000030?ooo`00000000000180oooo0P0000060?ooo`030000003oool0oooo0?l0
oooo403oool400WZ2PP0oooo1009jPX70?ooo`<02NX:1`3oool300WZ2PH0oooo0`09jPX50?ooo`80
2NX:1@3oool300WZ2XL0oooo003o0?ooo`P0oooo100000000`3oool000000?ooo`0C0?ooo`800000
0`3oool400000?l0oooo3@3oool300WZ2PT0oooo0`09jPX70?ooo`@02NX:1`3oool300WZ2PL0oooo
0P09jPX50?ooo`<02NX:103oool300WZ2XX0oooo003o0?ooo`L0oooo0P0000030?ooo`030000003o
ool0oooo01D0oooo0`0000040?ooo`030000003oool0oooo0?l0oooo1P3oool400WZ2PP0oooo1009
jPX70?ooo`<02NX:203oool300WZ2PL0oooo0`09jPX40?ooo`<02NX:1@3oool200WZ2Xd0oooo003o
0?ooo`L0oooo00D000000?ooo`3oool0oooo0000000J0?ooo`030000003oool0oooo00<0oooo0P00
003o0?ooo`80oooo1009jPX90?ooo`<02NX:203oool300WZ2PP0oooo0`09jPX70?ooo`<02NX:103o
ool300WZ2PD0oooo0`09jPZ?0?ooo`00o`3oool60?ooo`050000003oool0oooo0?ooo`000000703o
ool2000000D0oooo00<000000?ooo`3oool0nP3oool400WZ2PT0oooo1009jPX70?ooo`@02NX:203o
ool300WZ2PL0oooo0`09jPX50?ooo`802NX:1P3oool200WZ2Y80oooo003o0?ooo`D0oooo00<00000
0?ooo`3oool00P00000O0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0m@3oool4
00WZ2PT0oooo1009jPX80?ooo`<02NX:2@3oool300WZ2PL0oooo0`09jPX50?ooo`<02NX:1@3oool3
00WZ2Y@0oooo003o0?ooo`@0oooo100000000`3oool000000?ooo`0O0?ooo`040000003oool0oooo
0?ooo`<00000l`3oool300WZ2PX0oooo0`09jPX90?ooo`<02NX:2@3oool300WZ2PL0oooo0`09jPX5
0?ooo`<02NX:1@3oool300WZ2YL0oooo003o0?ooo`<0oooo0P0000030?ooo`030000003oool0oooo
0200oooo0`0000030?ooo`030000003oool0oooo0>`0oooo1009jPX90?ooo`@02NX:203oool400WZ
2PP0oooo1009jPX70?ooo`<02NX:1@3oool300WZ2PH0oooo0P09jPZJ0?ooo`00o`3oool30?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0>L0oooo1009jPX:0?ooo`<02NX:2@3oool300WZ2PT0oooo0`09jPX80?ooo`<0
2NX:1P3oool200WZ2PH0oooo0`09jPZL0?ooo`00o`3oool20?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0>80oooo
1009jPX:0?ooo`@02NX:2@3oool300WZ2PT0oooo0`09jPX80?ooo`<02NX:1P3oool300WZ2PH0oooo
0P09jPZO0?ooo`00o`3oool20?ooo`050000003oool0oooo0?ooo`0000009P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0=d0oooo1009jPX;0?ooo`<02NX:2@3oool400WZ2PT0oooo
0`09jPX80?ooo`<02NX:1P3oool300WZ2PH0oooo0`09jPZQ0?ooo`00o`3oool10?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0=P0oooo1009jPX;0?ooo`@02NX:2@3oool300WZ2PX0oooo0`09jPX80?ooo`<02NX:1P3o
ool300WZ2PH0oooo0`09jPZT0?ooo`00o`3oool10?ooo`030000003oool0000000800000:@3oool0
0`000000oooo0?ooo`030?ooo`800000eP3oool300WZ2P`0oooo0`09jPX:0?ooo`<02NX:2P3oool3
00WZ2PP0oooo0`09jPX60?ooo`<02NX:1`3oool200WZ2ZL0oooo003o0?ooo`<000000P3oool00`00
0000oooo0?ooo`0X0?ooo`030000003oool000000080000000<0Re:80000003oool0d@3oool400WZ
2P/0oooo1009jPX90?ooo`@02NX:2P3oool300WZ2PT0oooo0P09jPX70?ooo`802NX:1`3oool300WZ
2ZT0oooo003o0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0:@3oool00`000000
Re:808]BR00308]BR0030000003oool0oooo0</0oooo1009jPX;0?ooo`@02NX:2P3oool300WZ2P/0
oooo0`09jPX90?ooo`<02NX:1P3oool300WZ2PL0oooo0P09jPZ/0?ooo`00oP3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo02X0oooo00<0000008]BR02;DXP00`2;DXP200000<P0oooo
1009jPX<0?ooo`<02NX:2`3oool300WZ2P/0oooo0`09jPX90?ooo`<02NX:1P3oool300WZ2PL0oooo
0`09jPZ^0?ooo`00oP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02X0oooo00<0
000008]BR02;DXP0102;DXP200000<<0oooo1009jPX<0?ooo`@02NX:2P3oool400WZ2PX0oooo1009
jPX90?ooo`<02NX:1P3oool300WZ2PL0oooo0`09jPZa0?ooo`00oP3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo02X0oooo00<0000008]BR02;DXP0102;DXP00`000000oooo0000002o
0?ooo`<02NX:3@3oool300WZ2P/0oooo0`09jPX;0?ooo`<02NX:2P3oool300WZ2PL0oooo0P09jPX8
0?ooo`802NX:]03oool00?d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0Z0?oo
o`030000002;DXP0Re:800D0Re:800<000000?ooo`000000^P3oool400WZ2P`0oooo1009jPX;0?oo
o`<02NX:2`3oool300WZ2PX0oooo0`09jPX70?ooo`<02NX:1`3oool300WZ2[H0oooo003m0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0:`3oool00`000000Re:808]BR00508]BR004
0000003oool0oooo00000;D0oooo1009jPX=0?ooo`<02NX:2`3oool400WZ2P/0oooo0`09jPX:0?oo
o`<02NX:1`3oool300WZ2PP0oooo0P09jPZi0?ooo`00o@3oool010000000oooo0?ooo`3oool20000
02d0oooo00<0000008]BR02;DXP01P2;DXP010000000oooo00000000002`0?ooo`@02NX:3@3oool4
00WZ2P/0oooo0`09jPX<0?ooo`<02NX:2P3oool300WZ2PL0oooo0`09jPX80?ooo`<02NX:^`3oool0
0?`0oooo00<000000?ooo`0000000P0000000`3oool000000?ooo`0]0?ooo`030000002;DXP0Re:8
00D0Re:80P0000000`3oool000000?ooo`2[0?ooo`@02NX:3P3oool300WZ2P`0oooo0`09jPX<0?oo
o`<02NX:2P3oool300WZ2PP0oooo0P09jPX80?ooo`<02NX:_P3oool00?`0oooo0P0000040?ooo`03
0000003oool0oooo02`0oooo00<0000008]BR02;DXP01P2;DXP010000000oooo0?ooo`00002X0?oo
o`<02NX:3P3oool400WZ2P/0oooo1009jPX<0?ooo`<02NX:2P3oool300WZ2PP0oooo0`09jPX80?oo
o`802NX:`@3oool00?`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0]0?ooo`03
0000002;DXP0Re:800H0Re:800D000000?ooo`3oool0oooo0000002S0?ooo`@02NX:3P3oool300WZ
2P`0oooo0`09jPX=0?ooo`<02NX:2P3oool300WZ2PP0oooo0`09jPX80?ooo`<02NX:``3oool00?`0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0]0?ooo`030000002;DXP0Re:800L0
Re:800@000000?ooo`3oool00000W`3oool400WZ2Ph0oooo1009jPX<0?ooo`<02NX:3@3oool300WZ
2PX0oooo0`09jPX80?ooo`<02NX:203oool300WZ2/H0oooo003l0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0;@3oool00`000000Re:808]BR00708]BR0050000003oool0oooo0?oo
o`000000VP3oool400WZ2Ph0oooo1009jPX<0?ooo`@02NX:3@3oool300WZ2P/0oooo0P09jPX90?oo
o`802NX:2@3oool200WZ2/T0oooo003l0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0;@3oool00`000000Re:808]BR00808]BR0050000003oool0oooo0?ooo`000000U@3oool400WZ
2Pl0oooo0`09jPX=0?ooo`<02NX:3@3oool400WZ2P/0oooo0`09jPX80?ooo`<02NX:203oool300WZ
2//0oooo003k0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0;@3oool00`000000
Re:808]BR00808]BR0050000003oool0oooo0?ooo`000000TP3oool300WZ2Pl0oooo1009jPX=0?oo
o`<02NX:3@3oool300WZ2P`0oooo0`09jPX80?ooo`<02NX:2@3oool200WZ2/h0oooo003k0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0;P3oool00`000000Re:808]BR00808]BR003
0000003oool0oooo0080oooo00<000000?ooo`3oool0R`3oool400WZ2Pl0oooo0`09jPX=0?ooo`@0
2NX:3@3oool300WZ2P`0oooo0`09jPX80?ooo`<02NX:2@3oool300WZ2]00oooo003k0?ooo`040000
003oool0oooo0?ooo`800000<03oool00`000000Re:808]BR00908]BR0040000003oool0oooo0?oo
o`800000R03oool400WZ2Pl0oooo1009jPX=0?ooo`<02NX:3P3oool300WZ2P`0oooo0`09jPX80?oo
o`<02NX:2@3oool300WZ2]<0oooo003k0?ooo`@0000000<0oooo0000003oool0;`3oool00`000000
Re:808]BR00908]BR0@0000000<0oooo0000003oool0P`3oool400WZ2Q00oooo0`09jPX>0?ooo`<0
2NX:3P3oool300WZ2P`0oooo0`09jPX90?ooo`802NX:2P3oool200WZ2]H0oooo003`0?ooo`P00000
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02h0oooo00<0000008]BR02;DXP0
2@2;DXP00`000000oooo0?ooo`030?ooo`030000003oool0oooo07d0oooo1009jPX@0?ooo`@02NX:
3@3oool400WZ2Ph0oooo0`09jPX<0?ooo`<02NX:2@3oool300WZ2PT0oooo0`09jP[H0?ooo`00kP3o
ool2000000030?ooo`000000oooo00<0oooo00<000000?ooo`0000000`0000040?ooo`030000003o
ool0oooo02h0oooo00<0000008]BR02;DXP02P2;DXP00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo07T0oooo0`09jPXA0?ooo`<02NX:3P3oool300WZ2Pl0oooo0`09jPX<0?ooo`<02NX:2@3o
ool300WZ2PX0oooo0P09jP[K0?ooo`00k03oool200000080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`030?ooo`8000000`3oool00`000000oooo0?ooo`0^0?ooo`030000002;DXP0
Re:800X0Re:800<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1e0?ooo`@02NX:403oool4
00WZ2Ph0oooo0`09jPX?0?ooo`<02NX:303oool300WZ2PT0oooo0`09jPX:0?ooo`<02NX:g@3oool0
0>X0oooo0P0000001@3oool000000?ooo`3oool0000000<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0000000300000300oooo00<0000008]BR02;DXP02P2;DXP2000000D0oooo00<00000
0?ooo`3oool0L03oool400WZ2Q00oooo1009jPX>0?ooo`@02NX:3`3oool300WZ2P`0oooo0`09jPX:
0?ooo`802NX:2P3oool300WZ2^00oooo003Y0?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`8000000`3oool3000002l0oooo00<00000
08]BR02;DXP02`2;DXP00`000000oooo0?ooo`030?ooo`030000003oool0oooo06`0oooo1009jPXA
0?ooo`<02NX:3`3oool300WZ2Pl0oooo1009jPX<0?ooo`<02NX:2P3oool300WZ2PX0oooo0P09jP[S
0?ooo`00j@3oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`0000001@3o
ool00`000000oooo000000030?ooo`80000000<0oooo0000003oool0;@3oool00`000000Re:808]B
R00;08]BR08000001@3oool00`000000oooo0?ooo`1W0?ooo`@02NX:4@3oool400WZ2Pl0oooo0`09
jPX?0?ooo`<02NX:3P3oool200WZ2PX0oooo0`09jPX:0?ooo`<02NX:i@3oool00>P0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0P00
00040?ooo`050000003oool0oooo0?ooo`000000;@3oool00`000000Re:808]BR00;08]BR0800000
1P3oool00`000000oooo0?ooo`1S0?ooo`<02NX:4P3oool300WZ2Pl0oooo1009jPX?0?ooo`<02NX:
3P3oool300WZ2PT0oooo0`09jPX;0?ooo`802NX:j03oool00>L0oooo0P0000020?ooo`030000003o
ool0000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000030?ooo`800000103o
ool00`000000oooo0?ooo`0Z0?ooo`030000002;DXP0Re:800`0Re:80P0000050?ooo`030000003o
ool0oooo05l0oooo1009jPXA0?ooo`@02NX:3`3oool300WZ2Q00oooo0`09jPX>0?ooo`<02NX:2P3o
ool200WZ2P/0oooo0`09jP[Z0?ooo`00iP3oool200000080oooo00@000000?ooo`3oool000000`3o
ool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`000000
1@3oool00`000000oooo0?ooo`0Y0?ooo`030000002;DXP0Re:800`0Re:800<000000?ooo`000000
103oool2000005`0oooo1009jPXB0?ooo`<02NX:403oool300WZ2Q00oooo0`09jPX>0?ooo`<02NX:
2P3oool300WZ2PX0oooo0`09jP[]0?ooo`00iP3oool200000080oooo00<000000?ooo`000000103o
ool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo100000040?ooo`800000
:P3oool00`000000Re:808]BR00<08]BR0040000003oool000000?ooo`<0000000<0oooo0000003o
ool0E`3oool400WZ2Q80oooo1009jPX?0?ooo`@02NX:403oool300WZ2Ph0oooo0`09jPX:0?ooo`<0
2NX:2`3oool200WZ2_00oooo003U0?ooo`8000000P3oool010000000oooo0?ooo`0000030?ooo`03
0000003oool0oooo00<0oooo00@000000?ooo`3oool0oooo100000000`2W`>/000000:O0j`020000
00050?ooo`000000oooo0?ooo`000000:@3oool00`000000Re:808]BR00=08]BR0030000003oool0
000000D0oooo00<000000?ooo`3oool0D@3oool400WZ2Q<0oooo0`09jPX@0?ooo`<02NX:4@3oool3
00WZ2Ph0oooo0`09jPX:0?ooo`<02NX:2`3oool300WZ2_80oooo003T0?ooo`<000000P3oool00`00
0000oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool20000
00<0Yl3[00@000000:O0j`2W`>/0Yl3[0P0000030?ooo`030000003oool0oooo02H0oooo00<00000
08]BR02;DXP03@2;DXP00`000000oooo000000050?ooo`030000003oool0oooo04h0oooo0`09jPXC
0?ooo`@02NX:403oool300WZ2Q40oooo0`09jPX>0?ooo`<02NX:2`3oool200WZ2P/0oooo0`09jP[e
0?ooo`00i03oool200000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0080oooo0`0000020:O0j`030000002W`>/0Yl3[00<0Yl3[0`000000
0`3oool000000?ooo`0V0?ooo`030000002;DXP0Re:800d0Re:800@000000?ooo`3oool000001@3o
ool00`000000oooo0?ooo`190?ooo`@02NX:4P3oool400WZ2Q00oooo1009jPXA0?ooo`<02NX:3P3o
ool300WZ2P/0oooo0`09jPX;0?ooo`802NX:n03oool00><0oooo0`0000020?ooo`030000003oool0
000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`060000003oool0
oooo0000002W`>/00000202W`>/4000002D0oooo00<0000008]BR02;DXP03P2;DXP00`000000oooo
000000050?ooo`030000003oool0oooo04D0oooo1009jPXC0?ooo`<02NX:4@3oool300WZ2Q40oooo
1009jPX>0?ooo`<02NX:2`3oool300WZ2P/0oooo0`09jP[j0?ooo`00h`3oool200000080oooo00@0
00000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo
0P0000030?ooo`8000002P2W`>/4000002<0oooo00<0000008]BR02;DXP03P2;DXP010000000oooo
0?ooo`0000050?ooo`030000003oool0oooo0400oooo1009jPXC0?ooo`@02NX:4@3oool300WZ2Q40
oooo0`09jPX?0?ooo`<02NX:2`3oool300WZ2P`0oooo0P09jP[m0?ooo`00hP3oool3000000050?oo
o`000000oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`000000103oool00`000000Yl3[0:O0j`0:0:O0j`@000008@3oool00`000000
Re:808]BR00>08]BR0040000003oool0oooo000000H0oooo00<000000?ooo`3oool0>`3oool400WZ
2Q@0oooo0`09jPXA0?ooo`@02NX:4@3oool300WZ2Pl0oooo0`09jPX;0?ooo`<02NX:303oool300WZ
2_l0oooo003R0?ooo`8000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000040?ooo`8000003@2W`>/50000
01h0oooo00<0000008]BR02;DXP03`2;DXP010000000oooo0?ooo`0000050?ooo`030000003oool0
oooo03P0oooo0`09jPXD0?ooo`@02NX:4@3oool300WZ2Q80oooo0`09jPX?0?ooo`<02NX:303oool2
00WZ2P`0oooo0`09jP[o0?ooo`<0oooo003Q0?ooo`<0000000D0oooo0000003oool0oooo00000003
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00
00030?ooo`80000000<0oooo0000002W`>/03@2W`>/20000000308]BR0000000000001`0oooo00<0
000008]BR02;DXP03`2;DXP01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0
<`3oool400WZ2Q@0oooo0`09jPXB0?ooo`<02NX:4P3oool300WZ2Q00oooo0P09jPX<0?ooo`<02NX:
303oool200WZ2_l0oooo1P3oool00>40oooo0`0000001@3oool000000?ooo`3oool000000080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo000000020?ooo`030000002W`>/0Yl3[00d0Yl3[00<0000008]BR02;
DXP00P00000J0?ooo`030000002;DXP0Re:800l0Re:800D000000?ooo`3oool0oooo000000050?oo
o`030000003oool0oooo02l0oooo1009jPXD0?ooo`@02NX:4@3oool400WZ2Q80oooo0`09jPX@0?oo
o`<02NX:2`3oool300WZ2P`0oooo0`09jP[o0?ooo`P0oooo003P0?ooo`<0000000D0oooo0000003o
ool0oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`0000000`3oool00`000000Yl3[0:O0j`0=
0:O0j`8000000P2;DXP00`000000oooo0?ooo`0G0?ooo`030000002;DXP0Re:800l0Re:800<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`800000;03oool400WZ2QD0oooo0`09jPXB
0?ooo`<02NX:4`3oool300WZ2Q00oooo0`09jPX;0?ooo`<02NX:3@3oool200WZ2_l0oooo2`3oool0
0>00oooo0`000000103oool000000?ooo`0000030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`040000003oool000000?ooo`800000103o
ool00`000000Yl3[0:O0j`0>0:O0j`80000000<0Re:80000003oool05`3oool00`000000Re:808]B
R00?08]BR0030000003oool0oooo0080oooo00<000000?ooo`0000000P0000000`3oool000000?oo
o`0W0?ooo`@02NX:5@3oool400WZ2Q80oooo0`09jPXC0?ooo`<02NX:403oool300WZ2P`0oooo0P09
jPX=0?ooo`<02NX:o`3oool=0?ooo`00g`3oool3000000050?ooo`000000oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool4000000030?ooo`000000oooo0080oooo00<0000008]BR00000004@2W`>/3000001L0oooo00<0
000008]BR02;DXP0402;DXP00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool08P3oool300WZ2QD0oooo1009jPXB0?ooo`@02NX:4`3oool300WZ2Q00oooo0`09
jPX<0?ooo`<02NX:303oool300WZ2_l0oooo403oool00=l0oooo0`000000103oool000000?ooo`00
00030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`2;DXP00`000000Yl3[
0:O0j`0@0:O0j`8000005P3oool00`000000Re:808]BR00@08]BR0030000003oool0oooo0080oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0N0?ooo`@02NX:5@3oool300WZ2Q<0oooo
0`09jPXC0?ooo`@02NX:403oool300WZ2P`0oooo0`09jPX=0?ooo`802NX:o`3ooolC0?ooo`00gP3o
ool500000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000000508]BR0030000
002W`>/0Yl3[0100Yl3[0P00000E0?ooo`030000002;DXP0Re:80100Re:800<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01X0oooo1009jPXE0?ooo`@02NX:
4`3oool300WZ2Q<0oooo0`09jPXA0?ooo`<02NX:303oool300WZ2Pd0oooo0`09jP[o0?oooaD0oooo
003N0?ooo`<0000000@0oooo0000003oool000000`3oool01@000000oooo0?ooo`3oool0000000D0
oooo00<000000?ooo`3oool0103oool2000000@0oooo0P00000708]BR0030000002W`>/0Yl3[0140
Yl3[0P00000C0?ooo`030000002;DXP0Re:80100Re:800<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo01D0oooo1009jPXF0?ooo`<02NX:4`3oool400WZ2Q<0
oooo0`09jPXA0?ooo`<02NX:3@3oool200WZ2Ph0oooo0P09jP[o0?oooaP0oooo00140?ooo``00000
S@3oool500000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`000000103oool2000000P0Re:800<000000:O0j`2W
`>/04P2W`>/00`000000oooo0?ooo`0@0?ooo`030000002;DXP0Re:80100Re:800<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo1009jPXF0?ooo`@0
2NX:4`3oool300WZ2Q@0oooo0`09jPXA0?ooo`<02NX:3@3oool300WZ2Pd0oooo0`09jP[o0?oooaX0
oooo00100?ooo``00000103oool3000008X0oooo300000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000040?ooo`030000002;DXP0Re:800P0
Re:800<000000:O0j`2W`>/04P2W`>/200000100oooo00<0000008]BR02;DXP0402;DXP00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03@3oool300WZ2QL0
oooo0`09jPXD0?ooo`<02NX:503oool300WZ2Q40oooo0`09jPX=0?ooo`<02NX:3@3oool300WZ2_l0
oooo7@3oool003d0oooo1000000;0?ooo`<000000`3oool4000008L0oooo1@0000070?ooo`<00000
103oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000
Re:80000000:08]BR0030000002W`>/0Yl3[01<0Yl3[00<000000?ooo`3oool03@3oool00`000000
Re:808]BR00@08]BR0030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`090?ooo`@02NX:5P3oool400WZ2Q<0oooo1009jPXD0?ooo`<02NX:4@3oool300WZ2Pd0
oooo0`09jPX>0?ooo`802NX:o`3ooolP0?ooo`00>P3oool400000140oooo0`0000040?ooo`<00000
P`3oool3000000030?ooo`000000oooo00X0oooo0P0000000`3oool000000?ooo`050?ooo`050000
003oool0oooo0?ooo`0000000P3oool010000000Re:808]BR000000;08]BR0030000002W`>/0Yl3[
01<0Yl3[0P00000=0?ooo`030000002;DXP0Re:80140Re:800<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo1009jPXG0?ooo`<02NX:503oool300WZ
2QD0oooo0`09jPXA0?ooo`<02NX:3P3oool200WZ2Ph0oooo0`09jP[o0?ooob80oooo000i0?ooo`04
0000003oool00000000001D0oooo0`0000040?ooo`<00000P03oool2000000040?ooo`0000000000
0?ooo`D000001`3oool2000000D0oooo00<000000?ooo`3oool00`3oool2000000<0Re:800<00000
08]BR02;DXP02P2;DXP2000001D0Yl3[00<000000?ooo`3oool02P3oool00`000000Re:808]BR00A
08]BR0030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`04
00WZ2QL0oooo1009jPXD0?ooo`<02NX:5@3oool300WZ2Q80oooo0P09jPX>0?ooo`<02NX:3P3oool2
00WZ2_l0oooo9@3oool003L0oooo0P0000000`3oool000000?ooo`0I0?ooo`<000000P3oool40000
07d0oooo0P0000020?ooo`@000000`3oool3000000L0oooo00D000000?ooo`3oool0oooo00000006
0?ooo`030000002;DXP0Re:80080Re:800<0000008]BR02;DXP0302;DXP00`000000Yl3[0:O0j`0C
0:O0j`8000002P3oool00`000000Re:808]BR00A08]BR0030000003oool0oooo00D0oooo00@00000
0?ooo`3oool0oooo1009jPXH0?ooo`<02NX:503oool400WZ2QD0oooo0`09jPXB0?ooo`<02NX:3@3o
ool300WZ2Ph0oooo0`09jP[o0?ooobL0oooo000f0?ooo`@000007P3oool2000000@0oooo00<00000
0?ooo`3oool0NP3oool4000000030?ooo`000000000000<0oooo00@000000?ooo`3oool0oooo0P00
00060?ooo`030000003oool0000000H0oooo0P00000408]BR0030000002;DXP0Re:800d0Re:800<0
00000:O0j`2W`>/0502W`>/00`000000oooo0?ooo`080?ooo`030000002;DXP0Re:80100Re:800<0
00000?ooo`3oool01@3oool0100000002NX:00WZ2P09jPX3000001D0oooo1009jPXD0?ooo`<02NX:
5@3oool400WZ2Q80oooo0`09jPX=0?ooo`<02NX:3P3oool300WZ2_l0oooo:P3oool003D0oooo0P00
00000`3oool000000?ooo`0P0?ooo`030000003oool0oooo0080oooo0P00001i0?ooo`L000000`3o
ool00`000000oooo0?ooo`030?ooo`<000001@3oool2000000D0oooo00<0000008]BR0000000102;
DXP00`000000Re:808]BR00>08]BR0030000002W`>/0Yl3[01@0Yl3[0P0000080?ooo`030000002;
DXP0Re:80100Re:800<000000?ooo`3oool00P3oool400WZ2P<000000P3oool00`000000oooo0?oo
o`0?0?ooo`@02NX:5@3oool300WZ2QD0oooo0`09jPXC0?ooo`<02NX:3@3oool300WZ2Pl0oooo0P09
jP[o0?ooobd0oooo000e0?ooo`030000003oool0000002<0oooo0P0000040?ooo`030000003oool0
oooo07D0oooo1@0000000`3oool000000?ooo`020?ooo`030000003oool0oooo00<0oooo00D00000
0?ooo`3oool0oooo000000060?ooo`050000003oool0oooo0?ooo`0000000P2;DXP010000000Re:8
08]BR02;DXP200000140Re:800<000000:O0j`2W`>/05@2W`>/00`000000oooo0?ooo`050?ooo`03
0000002;DXP0Re:80100Re:800<0000000WZ2P09jPX00P09jPX40?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool02`3oool300WZ2QD0oooo1009jPXE0?ooo`<02NX:4`3oool300WZ2Ph0
oooo0P09jPX?0?ooo`<02NX:o`3oool_0?ooo`00=03oool00`000000oooo0000000V0?ooo`800000
0`3oool00`000000oooo0?ooo`1c0?ooo`80000000<0oooo0000003oool00`0000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0000000<0Re:8100000000`2;DXP0000008]BR00A08]BR0030000002W`>/0Yl3[01D0Yl3[
00<000000?ooo`3oool0103oool00`000000Re:808]BR00=08]BR0@02NX:2@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00L0oooo1009jPXE0?ooo`<02NX:5P3oool300WZ2Q<0oooo
0`09jPX>0?ooo`<02NX:3P3oool300WZ2_l0oooo<P3oool003<0oooo00<000000?ooo`000000:@3o
ool00`000000oooo0?ooo`03000000@0oooo2P00001T0?ooo`@0000000@0oooo0000003oool0oooo
100000040?ooo`030000003oool0oooo00@0oooo0`0000050?ooo`8000000`2;DXP00`000000Re:8
08]BR00208]BR0030000002;DXP0Re:80140Re:800<000000:O0j`2W`>/05@2W`>/2000000@0oooo
00<0000008]BR02;DXP02@2;DXP400WZ2P<0Re:800<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00@0oooo0`09jPXF0?ooo`<02NX:5P3oool300WZ2Q<0oooo
0`09jPX>0?ooo`<02NX:3`3oool200WZ2_l0oooo=@3oool00380oooo0`00000[0?ooo`8000000`3o
ool4000000<0oooo0P0000040?ooo`@00000H03oool700000080oooo00@000000:O0j`2W`>/0Yl3[
1`0000030?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0000000208]BR003
0000002;DXP0Re:80080Re:800<0000008]BR02;DXP04P2;DXP00`000000Yl3[0:O0j`0F0:O0j`05
0000003oool0oooo0?ooo`000000202;DXP300WZ2PL0Re:800<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool02NX:00<02NX:5@3oool400WZ2QH0oooo0`09jPXC0?oo
o`<02NX:3P3oool300WZ2Pl0oooo0`09jP[o0?ooocL0oooo000a0?ooo`80000000<0oooo0000003o
ool0:`3oool00`000000oooo0?ooo`03000000L0oooo0P0000040?ooo`D00000G03oool700000080
oooo0P00000:0:O0j`L0000000<0oooo0000003oool00`3oool01@000000oooo0000002;DXP00000
00D0Re:800<0000008]BR02;DXP04P2;DXP00`000000Yl3[0:O0j`0F0:O0j`80000000<0oooo0000
002;DXP00`2;DXP400WZ2PX0Re:800<000000?ooo`3oool0203oool010000000oooo0?ooo`3oool3
00WZ2QH0oooo0`09jPXG0?ooo`<02NX:4`3oool300WZ2Pl0oooo0P09jPX@0?ooo`802NX:o`3ooolj
0?ooo`00<03oool010000000oooo0?ooo`00000^0?ooo`8000000`3oool2000000L0oooo0P000004
0?ooo`H00000F03oool6000000030?ooo`000000oooo00<000004@2W`>/500000080oooo00@00000
0?ooo`00000000001@2;DXP00`000000Re:808]BR00C08]BR0030000002W`>/0Yl3[01L0Yl3[0P00
000400WZ2Pl0Re:800<000000?ooo`3oool01`3oool400WZ2P80oooo00<000000?ooo`3oool04@3o
ool300WZ2QL0oooo0`09jPXC0?ooo`<02NX:3`3oool300WZ2Pl0oooo0`09jP[o0?oooc`0oooo000`
0?ooo`030000003oool0000002l0oooo0P0000040?ooo`@000001P3oool2000000@0oooo1P00001E
0?ooo`030000003oool0000000<0000000<0oooo0000003oool00P0000000`2W`>/000000:O0j`0E
0:O0j`@0000000<0oooo000000000000102;DXP00`000000Re:808]BR00D08]BR0030000002W`>/0
Yl3[01@0Yl3[0P09jPX2000001<0Re:800<000000?ooo`3oool0103oool300WZ2P030?ooo`000000
oooo00<0oooo00<000000?ooo`3oool03@3oool400WZ2QL0oooo0`09jPXC0?ooo`<02NX:3`3oool3
00WZ2Pl0oooo0`09jP[o0?ooocl0oooo000_0?ooo`040000003oool0oooo000002h0oooo0P000000
0`3oool000000?ooo`030?ooo`030000003oool0oooo008000001P3oool3000000<0oooo1P00001A
0?ooo`80000000<0oooo0000003oool00`000000103oool000000000000000020:O0j`030000002W
`>/0Yl3[01L0Yl3[1000000408]BR0030000002;DXP0Re:801D0Re:800<000000:O0j`2W`>/0402W
`>/300WZ2P@0Yl3[0P00000A08]BR0030000003oool0oooo00@02NX:103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00T0oooo0`09jPXG0?ooo`@02NX:4`3oool300WZ2Pl0oooo0`09
jPX@0?ooo`802NX:o`3ooom20?ooo`00;`3oool00`000000oooo0000000^0?ooo`030000003oool0
oooo00<00000103oool010000000oooo0?ooo`3oool2000000L0oooo0P0000030?ooo`H00000CP3o
ool2000000030?ooo`000000oooo00<0000000D0oooo0000003oool0oooo000000020:O0j`030000
002W`>/0Yl3[01X0Yl3[0`00000208]BR0030000002;DXP0Re:801H0Re:800<000000:O0j`2W`>/0
302W`>/300WZ2PT0Yl3[00<0000008]BR02;DXP03@2;DXP400WZ2PT0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`060?ooo`<02NX:5`3oool300WZ2QD0oooo0P09jPX@0?ooo`802NX:
403oool300WZ2_l0ooooA03oool002h0oooo00@000000?ooo`3oool00000;@3oool00`000000oooo
0?ooo`040?ooo`80000000@0oooo0000000000000000103oool3000000H0oooo0P0000030?ooo`H0
0000B`3oool2000000030?ooo`000000oooo0080000000H0oooo00000000000000000?ooo`000003
0:O0j`030000002W`>/0Yl3[01X0Yl3[00<000000:O0j`2W`>/00`00000I08]BR0030000002W`>/0
Yl3[00P0Yl3[0`09jPX=0:O0j`030000002;DXP0Re:800T0Re:80`09jPX00`2;DXP000000?ooo`0:
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool400WZ2QL0oooo0`09jPXE
0?ooo`<02NX:3`3oool300WZ2Q00oooo0P09jP[o0?ooodL0oooo000]0?ooo`040000003oool0oooo
000002d0oooo00<000000?ooo`3oool01P3oool5000000L0oooo0P0000060?ooo`8000000`3oool6
000004P0oooo0P0000001`3oool000000?ooo`000000oooo0000003oool00P0000020?ooo`050000
002W`>/0Yl3[0:O0j`000000702W`>/00`000000Yl3[0:O0j`020:O0j`@000005`2;DXP00`000000
Yl3[0:O0j`040:O0j`<02NX:4@2W`>/00`000000Re:808]BR00408]BR0@02NX:102;DXP00`000000
oooo0?ooo`090?ooo`040000003oool0oooo0?ooo`<000000`09jPXH0?ooo`<02NX:5@3oool300WZ
2Pl0oooo0`09jPX@0?ooo`<02NX:o`3ooom90?ooo`00;@3oool3000002d0oooo00<000000?ooo`3o
ool01`3oool010000000Re:808]BR02;DXP2000000P0oooo0P0000060?ooo`8000000`3oool60000
04D0oooo0P0000000`3oool0000000000007000000030?ooo`000000Yl3[00<0Yl3[00<000000:O0
j`2W`>/06P2W`>/00`000000Yl3[0:O0j`030:O0j`030000002W`>/0Yl3[00<000005@2;DXP20000
00040:O0j`09jPX02NX:00WZ2QD0Yl3[0P000000102;DXP02NX:00WZ2P09jPX808]BR0030000003o
ool0oooo00X0oooo0`00000300WZ2QP0oooo0`09jPXE0?ooo`<02NX:3`3oool300WZ2Q00oooo0`09
jP[o0?oood`0oooo000/0?ooo`80000000<0oooo0000003oool0:`3oool2000000P0oooo00D00000
08]BR02;DXP0Re:8000000020?ooo`<000001`3oool3000000D0oooo0P0000030?ooo`030000003o
ool0000000<00000@P3oool500000080oooo1@0000020?ooo`030000002W`>/0Yl3[0080Yl3[00<0
00000:O0j`2W`>/06P2W`>/00`000000Yl3[0:O0j`030:O0j`030000002W`>/0Yl3[00<0Yl3[0`00
000B08]BR080000000<02NX:0:O0j`2W`>/05@2W`>/01009jPX0000000000000000;08]BR0030000
003oool0oooo00T0oooo1009jPX30?ooo`030000003oool0oooo0180oooo0`09jPXE0?ooo`<02NX:
403oool200WZ2Q40oooo0P09jP[o0?ooodl0oooo000/0?ooo`030000003oool0000002d0oooo00<0
00000?ooo`0000000P0000050?ooo`050000002;DXP0Re:808]BR00000000`3oool010000000oooo
0000000000080?ooo`8000001@3oool200000080oooo0P0000000`3oool0000000000002000003d0
oooo1P0000020?ooo`@0000000D0oooo000000000000oooo000000050:O0j`030000002W`>/0Yl3[
01/0Yl3[00@000000:O0j`2W`>/0Yl3[0P0000080:O0j`8000003@2;DXP300WZ2P80Re:800<00000
0:O0j`2W`>/04P2W`>/300WZ2P@0Yl3[00<0000008]BR02;DXP0202;DXP00`000000oooo0?ooo`06
0?ooo`<02NX:00<0oooo0000003oool0103oool00`000000oooo0?ooo`0?0?ooo`<02NX:5@3oool3
00WZ2Q00oooo0`09jPX@0?ooo`<02NX:o`3ooomA0?ooo`00:`3oool010000000oooo0?ooo`00000/
0?ooo`030000003oool0oooo00<0oooo0`0000000`3oool0000008]BR00308]BR08000000`3oool0
0`000000oooo0?ooo`03000000L0oooo0P0000050?ooo`80000000D0oooo00000000000000000?oo
o`04000003P0oooo1`0000000`3oool000000000000200000080oooo00<000000?ooo`0000000`00
00040:O0j`8000007@2W`>/4000000030:O0j`000000Yl3[00T0Yl3[0`00000708]BR0<02NX:1P2;
DXP00`000000Yl3[0:O0j`0>0:O0j`<02NX:202W`>/00`000000Re:808]BR00708]BR0030000003o
ool0oooo00<0oooo0`09jPX50?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0303o
ool300WZ2QD0oooo0`09jPX@0?ooo`<02NX:4@3oool200WZ2_l0ooooE03oool002/0oooo00@00000
0?ooo`3oool00000:`3oool00`000000oooo0?ooo`070?ooo`<000000`2;DXP00`000000oooo0000
00030?ooo`030000003oool0oooo0080oooo0P0000070?ooo`<00000103oool3000000030?ooo`00
0000000000@00000;03oool7000000030?ooo`000000000000@0000000<0oooo0000000000001@00
00000`3oool0000000000003000000030?ooo`000000Yl3[00<0Yl3[00<000000:O0j`0000007@2W
`>/00`000000Yl3[0:O0j`020:O0j`030000002W`>/0Yl3[00/0Yl3[0`000000102;DXP02NX:00WZ
2P09jPX:08]BR0030000002W`>/0Yl3[00T0Yl3[1009jPX<0:O0j`030000002;DXP0Re:800H0Re:8
00<000000?ooo`09jPX00`09jPX80?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
203oool300WZ2QD0oooo0`09jPX@0?ooo`<02NX:4@3oool300WZ2_l0ooooEP3oool002X0oooo00@0
00000?ooo`3oool00000;03oool00`000000oooo0?ooo`070?ooo`030000002;DXP0Re:800<00000
0`3oool01@000000oooo0?ooo`3oool0000000D0oooo0`0000070?ooo`800000103oool300000003
0?ooo`000000000000@000009`3oool3000000L0ljmn100000030?ooo`8000000`3oool600000080
oooo0P0000050:O0j`030000002W`>/0000001d0Yl3[00<000000:O0j`2W`>/00`2W`>/00`000000
Yl3[0:O0j`0;0:O0j`0300000009jPX02NX:00h0Re:800<000000:O0j`2W`>/01@2W`>/300WZ2Q40
Yl3[00<0000008]BR02;DXP0102;DXP300WZ2P`0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`040?ooo`@02NX:5@3oool300WZ2Q00oooo0`09jPXA0?ooo`<02NX:o`3ooomI0?ooo`00
:P3oool010000000oooo0?ooo`00000[0?ooo`<00000203oool00`000000Re:808]BR00208]BR0@0
000000@0oooo0000003oool0oooo0P0000070?ooo`8000001`3oool2000000<0oooo100000000`3o
ool0000000000004000002@0oooo00<000000?>_OP3c[gh01`3c[gh200000080ljmn1@0000030?oo
o`070000003oool0oooo0?ooo`000000oooo000000020?ooo`800000102W`>/01@000000Yl3[0:O0
j`2W`>/0000001`0Yl3[00<000000:O0j`2W`>/00`2W`>/00`000000Yl3[0:O0j`090:O0j`802NX:
0`2W`>/3000000`0Re:800@000000:O0j`2W`>/0Yl3[0`09jPXE0:O0j`030000002;DXP0Re:800<0
2NX:00<0Re:80000003oool03@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?oo
o`<02NX:5P3oool300WZ2Q40oooo0P09jPXB0?ooo`802NX:o`3ooomL0?ooo`00:P3oool010000000
oooo0?ooo`00000[0?ooo`030000003oool0oooo00<00000103oool00`000000Re:808]BR00308]B
R0040000003oool0oooo0?ooo`@0000000<0oooo0000003oool0203oool3000000H0oooo0`000004
08]BR0T000008@3oool00`000000ljmn0?>_OP070?>_OPH0000000<0ljmn0000000000000`3oool0
1P000000oooo0?ooo`3oool000000?ooo`80000000<0oooo000000000000102W`>/00`000000Yl3[
0:O0j`020:O0j`030000002W`>/0Yl3[01/0Yl3[00<000000:O0j`2W`>/00P2W`>/00`000000Yl3[
0:O0j`060:O0j`<02NX:202W`>/2000000/0Re:800<0000000WZ2P09jPX0602W`>/00`09jPX00000
0000000408]BR0030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool300WZ2QH0oooo
0`09jPXA0?ooo`<02NX:4@3oool300WZ2_l0ooooGP3oool002T0oooo00@000000?ooo`0000000000
:`3oool00`000000oooo0?ooo`040?ooo`<0000000<0oooo0000002;DXP00`2;DXP00`000000oooo
0?ooo`040?ooo`D000002`3oool2000000D0oooo00@0000008]BR00000000000102;DXP9000001l0
oooo00<000000?>_OP3c[gh01P3c[gh2000000H0ljmn0P0000020?ooo`050000003oool0oooo0?oo
o`0000000`3oool4000000@0Yl3[00<000000:O0j`2W`>/00P2W`>/00`000000Yl3[0:O0j`0K0:O0
j`030000002W`>/0Yl3[0080Yl3[00<000000:O0j`2W`>/0102W`>/200WZ2Pd0Yl3[0P00000608]B
R0<02NX:0P00000F0:O0j`<02NX:00<0Yl3[0000000000001@2;DXP00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00<02NX:00<000000?ooo`3oool04`3oool300WZ2Q40oooo0`09jPXB0?oo
o`802NX:o`3ooomQ0?ooo`00:@3oool2000000030?ooo`000000oooo02X0oooo00<000000?ooo`3o
ool01`3oool3000000<0Re:800<000000?ooo`3oool01@3oool00`000000oooo0?ooo`03000000/0
oooo0`0000000`3oool0000008]BR00308]BR0800000102;DXP9000001`0oooo00<000000?>_OP3c
[gh01`3c[gh00`000000ljmn0?>_OP030?>_OP8000000P3c[gh200000080oooo0P0000040?ooo`D0
00000P2W`>/00`000000Yl3[0:O0j`030:O0j`030000002W`>/0Yl3[01/0Yl3[00<000000:O0j`2W
`>/00P2W`>/00`000000Yl3[0:O0j`020:O0j`802NX:4@2W`>/20000000408]BR009jPX02NX:00WZ
2PD0Re:800<000000:O0j`2W`>/0402W`>/300WZ2PH0Yl3[00<0000008]BR02;DXP00P2;DXP00`00
0000oooo0?ooo`0;0?ooo`<02NX:0`3oool00`000000oooo0?ooo`0A0?ooo`802NX:4@3oool300WZ
2Q80oooo0`09jP[o0?ooof<0oooo000X0?ooo`050000003oool0oooo0?ooo`000000:P3oool00`00
0000oooo0?ooo`080?ooo`030000002;DXP0Re:800@00000203oool010000000oooo0?ooo`3oool4
000000/0oooo0P00000608]BR0<000000`2;DXP9000001T0oooo00<000000?>_OP3c[gh0203c[gh0
0`000000ljmn0?>_OP03000000080?>_OP000000ljmn0000003c[gh000000?ooo`0000060?ooo`03
0000003oool000000080oooo1@0000030:O0j`030000002W`>/0Yl3[01/0Yl3[00<000000:O0j`2W
`>/00`2W`>/0100000002NX:00WZ2P09jPXC0:O0j`0300WZ2P000000000000T0Re:800<000000:O0
j`2W`>/0302W`>/300WZ2PX0Yl3[00D0000008]BR02;DXP0Re:80000000:0?ooo`<02NX:00<0oooo
0000003oool0103oool00`000000oooo0?ooo`0=0?ooo`<02NX:4@3oool200WZ2Q80oooo0`09jP[o
0?ooofH0oooo000X0?ooo`040000003oool0oooo000002/0oooo00<000000?ooo`3oool0203oool0
0`000000Re:808]BR00308]BR0@000001P3oool01@000000oooo0?ooo`3oool000000080oooo0`00
00070?ooo`030000002;DXP0Re:800<000001P2;DXP200000080Re:85000000;0?ooo`<000002@3c
[gh4000000@0ljmn0P0000030?>_OP030000003oool0oooo00@0oooo0P0000001P3oool000000000
00000000Re:8000000<0Re:81000000N0:O0j`060000002W`>/0Yl3[0:O0j`09jPX000004`2W`>/3
00WZ2P040:O0j`0000000000000000T0Re:800<000000:O0j`2W`>/0202W`>/300WZ2Ph0Yl3[00@0
000008]BR02;DXP000001`3oool300WZ2P@0oooo00<000000?ooo`3oool00P3oool2000000`0oooo
0`09jPXA0?ooo`<02NX:4P3oool200WZ2_l0ooooJ@3oool002P0oooo00@000000?ooo`3oool00000
:`3oool00`000000oooo0?ooo`070?ooo`030000002;DXP0Re:800<0Re:800<000000?ooo`3oool0
0P3oool3000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`<000000`3oool00`000000
Re:808]BR00408]BR08000001@2;DXPT000000X0ljmn00<000000?>_OP3c[gh0103c[gh2000000<0
ljmn00<000000?>_OP000000103oool00`000000Yl3[000000030000000308]BR0000000Re:800D0
Re:81P00000J0:O0j`060000002W`>/02NX:00WZ2P2W`>/000004@2W`>/200WZ2PL0Yl3[0P000008
08]BR0030000002W`>/0Yl3[00@0Yl3[0`09jPXB0:O0j`030000002;DXP0000000@0oooo0`09jPX8
0?ooo`@0000000<0oooo0000003oool0203oool300WZ2Q40oooo0`09jPXB0?ooo`<02NX:o`3ooom[
0?ooo`009`3oool01@000000oooo0?ooo`3oool0000002X0oooo0`0000080?ooo`030000002;DXP0
Re:800<0Re:800<000000?ooo`3oool01@3oool3000000030?ooo`000000oooo00<0oooo00<00000
0?ooo`3oool0103oool3000000T0Re:80`0000000`2;DXP0000008]BR00908]BR080000000<0oooo
0000000000004@0000020?ooo`030000003c[gh0ljmn00T0ljmn00<000000?>_OP3c[gh00`3c[gh2
00000080ljmn0P0000030?>_OP040000003oool0oooo00000080Yl3[00<000000:O0j`0000000P00
000608]BR0050000002;DXP0000008]BR00000000P2;DXP4000001D0Yl3[00<02NX:00000009jPX0
0`2W`>/00`000000Yl3[0:O0j`0<0:O0j`<02NX:2`2W`>/00`000000Re:808]BR00508]BR0040000
002W`>/0Yl3[0:O0j`<02NX:5P2W`>/2000000040?ooo`09jPX02NX:00WZ2P/0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`040?ooo`<02NX:4@3oool300WZ2Q80oooo0`09jP[o0?oo
ofh0oooo000W0?ooo`040000003oool0oooo000002/0oooo00<000000?ooo`3oool0100000030?oo
o`030000002;DXP0Re:800@0Re:800<000000?ooo`3oool0203oool3000000@0oooo00<000000?oo
o`3oool0103oool00`000000Re:800000002000000T0Re:89@00000:0?>_OPL0000000@0ljmn0000
003c[gh000001P3c[gh2000000<0Yl3[00<000000:O0j`0000000P00000508]BR0060000002;DXP0
Re:80000002;DXP000001P2;DXP300000100Yl3[0P09jPX00`2W`>/000000:O0j`030:O0j`030000
002W`>/0Yl3[00T0Yl3[0`09jPX?0:O0j`030000002;DXP0Re:800D0Re:800<0000000WZ2P09jPX0
602W`>/200WZ2P0300000009jPX0oooo00d0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0300WZ2Q80oooo0P09jPXC0?ooo`802NX:o`3oooma0?ooo`009`3oool010000000oooo0?oo
o`00000[0?ooo`030000003oool0oooo00@0oooo1000000608]BR0030000003oool0oooo00/0oooo
1P0000040?ooo`030000002;DXP0Re:800<0Re:80`00000508]BR0030000002;DXP0Re:800h0Re:8
0P0000000`3oool00000000000090?ooo`800000103oool00`000000ljmn0?>_OP060?>_OPH00000
0`3oool3000000H0ljmn00<000000:O0j`2W`>/00`2W`>/00`000000Yl3[00000002000000D0Re:8
00@0000008]BR02;DXP000000P2;DXP00`000000Re:808]BR00608]BR0<000002`2W`>/200WZ2P<0
Yl3[00<000000:O0j`2W`>/00`2W`>/00`000000Yl3[0:O0j`060:O0j`802NX:4`2W`>/010000000
Re:808]BR02;DXP300WZ2P0308]BR0000000000001D0Yl3[0`09jPX208]BR0030000003oool0oooo
00d0oooo00<000000?ooo`3oool00`3oool300WZ2Q80oooo0`09jPXB0?ooo`<02NX:o`3ooomc0?oo
o`009P3oool01@000000oooo0?ooo`3oool0000002X0oooo00<000000?ooo`3oool01`3oool00`00
0000Re:8000000030000000308]BR0000000oooo00h0oooo1P0000020?ooo`030000002;DXP0Re:8
00L0Re:80`0000000`2;DXP0000008]BR00B08]BR080000000<0oooo0000000000003@0000080?>_
OP@000000P3oool010000000oooo0?ooo`3oool4000000<0ljmn0P0000060:O0j`030000002W`>/0
00000080Yl3[00D0000008]BR02;DXP0Re:80000000408]BR0030000002;DXP0000000/0Re:80P00
00060:O0j`<02NX:1P2W`>/00`000000Yl3[0:O0j`03000000D0Yl3[0`09jPXF0:O0j`80000000<0
2NX:08]BR02;DXP00P2;DXP200000180Yl3[0`09jPX508]BR08000003`3oool00`000000oooo00WZ
2P0200WZ2P030000003oool0oooo00l0oooo0`09jPXC0?ooo`802NX:o`3ooomf0?ooo`009P3oool0
1@000000oooo0?ooo`3oool0000002X0oooo00<000000?ooo`3oool01`3oool00`000000Re:808]B
R00308]BR0@000003@3oool00`000000oooo0?ooo`020?ooo`@00000302;DXPP000000030?ooo`00
0000oooo00<0oooo00<000000?>_OP3c[gh01@3c[gh01P000000oooo0?ooo`000000oooo00000080
oooo00@000000?ooo`00000000000`3oool00`000000ljmn000000080:O0j`030000002W`>/00000
00<0Yl3[00<0000008]BR00000001@2;DXP00`000000Re:80000000=08]BR0@000000P09jPX90:O0
j`<000000P2W`>/010000000Yl3[0:O0j`2W`>/200WZ2QH0Yl3[0`09jPX3000000@0Re:800<00000
0?ooo`0000003P2W`>/300WZ2PP0Re:800<000000:O0j`0000003@3oool300WZ2P@0oooo00<00000
0?ooo`3oool02`3oool300WZ2Q<0oooo0`09jP[o0?ooogP0oooo000V0?ooo`040000003oool0oooo
000002/0oooo00<000000?ooo`3oool01P3oool00`000000Re:808]BR00508]BR0030000003oool0
oooo00@000002P3oool00`000000oooo0?ooo`020?ooo`030000002;DXP0Re:800<000002@2;DXP0
0`000000Re:808]BR00G08]BR08000000`3oool2000000D0oooo00<000000?>_OP3c[gh0103c[gh0
1@000000oooo0?ooo`3oool000000080oooo100000000`3oool000000?ooo`030?ooo`030000002W
`>/0Yl3[00H0Yl3[0P0000000`2W`>/000000:O0j`030:O0j`030000002;DXP0Re:800@0Re:800@0
000008]BR02;DXP000003@2;DXP01009jPX0000000WZ2P00000:0:O0j`030000002W`>/0Yl3[0080
Yl3[00@0000000WZ2P09jPX02NX:5@2W`>/300WZ2PH0Yl3[00<0000008]BR02;DXP00P2;DXP00`00
0000oooo0000000:0:O0j`<02NX:2`2;DXP010000000Yl3[0:O0j`0000090?ooo`<02NX:00<0oooo
0000003oool0103oool00`000000oooo0?ooo`090?ooo`802NX:4`3oool300WZ2_l0ooooN`3oool0
02D0oooo00<000000?ooo`0000000P00000[0?ooo`030000003oool0oooo00H0oooo00<0000008]B
R02;DXP01@2;DXP00`000000oooo0?ooo`040?ooo`D000001P3oool010000000oooo0?ooo`000006
08]BR0<000001@2;DXP00`000000Re:808]BR00J08]BR0/000001P3c[gh90000000408]BR0000000
oooo00000080oooo0P0000080:O0j`050000002W`>/000000:O0j`0000000`2W`>/00`000000Yl3[
0000000508]BR0040000002;DXP0Re:8000000X0Re:80`09jPX010000000oooo0?ooo`3oool20000
00P0Yl3[00<000000:O0j`2W`>/00`09jPX00`000000Yl3[0:O0j`0B0:O0j`<02NX:2P2W`>/20000
0080Re:800@000000?ooo`3oool000001P2W`>/300WZ2Ph0Re:800D000000:O0j`2W`>/0Yl3[0000
00050?ooo`<02NX:1@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo0`09
jPXC0?ooo`802NX:o`3ooomn0?ooo`009@3oool200000080oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`050?ooo`030000002;DXP0Re:800H0Re:800<000000?ooo`3oool02@3oool4
00000080oooo00<000000?ooo`0000002P2;DXP300000080Re:800<0000008]BR02;DXP0302;DXP@
0000000308]BR0000000Re:800@0Re:800<000000?>_OP3c[gh0103c[gh010000000Re:808]BR02;
DXP2000000<0Re:800<0000008]BR00000000P0000000`3oool000000:O0j`070:O0j`8000000P2W
`>/010000000Yl3[0:O0j`0000020:O0j`040000002W`>/0Yl3[000000@0Re:800@0000008]BR02;
DXP000001`2;DXP300WZ2P<0Re:800@000000?ooo`3oool0oooo100000070:O0j`0300000009jPX0
Yl3[0080Yl3[00<000000:O0j`2W`>/0402W`>/200WZ2Pl0Yl3[00<0000008]BR00000000`3oool3
000000<02NX:4@2;DXP00`000000Yl3[0:O0j`020:O0j`8000000`09jPX80?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool300WZ2Q<0oooo0`09jP[o0?oooh00oooo000U0?oo
o`050000003oool0oooo0?ooo`000000:P3oool00`000000oooo0?ooo`060?ooo`030000002;DXP0
Re:800D0Re:800<000000?ooo`3oool03P3oool4000000h0Re:84@00000<08]BR0D000001P2;DXP0
0`000000ljmn0?>_OP040?>_OP050000002;DXP0Re:808]BR00000000`2;DXP00`000000Re:808]B
R004000000P0Yl3[00<000000:O0j`2W`>/00P2W`>/01P000000Yl3[0:O0j`000000Yl3[000000@0
Yl3[00<0000008]BR02;DXP00P00000308]BR0030000002;DXP0Re:800@02NX:1P2;DXP010000000
oooo0000000000040?ooo`8000000P2W`>/300WZ2P030000002W`>/0Yl3[0080Yl3[00<000000:O0
j`2W`>/03@2W`>/300WZ2Q80Yl3[0P0000020?ooo`802NX:00<0000000WZ2P2;DXP04`2;DXP01@00
0000Yl3[0:O0j`2W`>/02NX:008000002`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
2NX:00802NX:503oool200WZ2_l0ooooP`3oool002D0oooo00D000000?ooo`3oool0oooo0000000Z
0?ooo`@000001@3oool00`000000Re:808]BR00508]BR0030000003oool0oooo0140oooo1@00000;
08]BR0030000002;DXP0Re:801T0Re:800<000000?ooo`0000000P00000608]BR0030000003c[gh0
ljmn00@0ljmn00D0000008]BR02;DXP0Re:80000000208]BR0040000002;DXP0Re:808]BR0@00000
1P2W`>/2000000D0Yl3[00<000000:O0j`2W`>/00P0000060:O0j`80000000<0Re:80000002;DXP0
0P2;DXP300WZ2PX0Re:80P0000080?ooo`0300000009jPX0Yl3[0080Yl3[00<000000:O0j`2W`>/0
0`2W`>/00`000000Yl3[0:O0j`090:O0j`<02NX:5@2W`>/2000000802NX:0P3oool00`000000Re:8
08]BR00B08]BR0030000002W`>/02NX:00802NX:0`2W`>/00`000000oooo0?ooo`090?ooo`040000
003oool0oooo0?ooo`<02NX:503oool300WZ2_l0ooooQ@3oool002D0oooo00D000000?ooo`3oool0
oooo0000000Z0?ooo`040000003oool0oooo0?ooo`D00000202;DXP00`000000oooo0?ooo`0@0?oo
o`030000002;DXP0Re:800<0Re:81000000608]BR0030000002;DXP0Re:801T0Re:800<000000?oo
o`3oool00P00000708]BR0030000003c[gh0ljmn00<0ljmn00<0000008]BR02;DXP00P2;DXP00`00
0000Re:80000000208]BR0<0000000<0Yl3[0000002W`>/00`0000020:O0j`030000002W`>/0Yl3[
00D0Yl3[00@000000:O0j`2W`>/000001`2W`>/4000000<02NX:00<0000008]BR02;DXP02P2;DXP0
0`000000oooo0?ooo`040?ooo`<02NX:100000000`2W`>/000000:O0j`040:O0j`030000002W`>/0
Yl3[00H0Yl3[0`09jPXE0:O0j`<02NX:0P0000040?ooo`030000002;DXP0Re:80180Re:800<00000
00WZ2P2W`>/01P2W`>/00`000000oooo0?ooo`080?ooo`040000003oool02NX:00WZ2P80oooo00<0
00000?ooo`3oool03`3oool300WZ2_l0ooooR03oool002D0oooo00D000000?ooo`3oool0oooo0000
000Z0?ooo`030000003oool0oooo00D0oooo1`00000208]BR0030000003oool0oooo00l0oooo00<0
000008]BR02;DXP0202;DXP400000080Re:800<0000008]BR02;DXP0302;DXPB000000L0Re:800<0
00000?>_OP3c[gh00`3c[gh00`000000Re:808]BR00208]BR0030000002;DXP0000000800000102W
`>/00`000000Yl3[0:O0j`020:O0j`800000202W`>/010000000Yl3[0:O0j`0000060:O0j`030000
0009jPX0000000802NX:00D0000008]BR02;DXP0Re:80000000;08]BR0040000003oool0oooo0?oo
o`<02NX:1@3oool4000000D0Yl3[00<000000:O0j`2W`>/0102W`>/200WZ2QD0Yl3[0`09jPX408]B
R08000000`3oool00`000000Re:808]BR00B08]BR0030000002W`>/0Yl3[00H0Yl3[00<000000?oo
o`3oool01`3oool300WZ2P<0oooo0P00000?0?ooo`802NX:o`3ooon;0?ooo`009@3oool010000000
oooo0?ooo`00000[0?ooo`030000003oool0oooo00@0oooo00<0000008]BR02;DXP01@2;DXP50000
00l0oooo00<0000008]BR02;DXP0302;DXPA000000/0Re:800<000000?ooo`3oool01000000608]B
R0030000003c[gh0ljmn00@0ljmn00<0000008]BR02;DXP00P2;DXP2000000L0Yl3[00D000000:O0
j`2W`>/0Yl3[000000020:O0j`8000001@2W`>/200000080Yl3[00@000000:O0j`2W`>/0Yl3[0P09
jPX00`0000002NX:0:O0j`020:O0j`8000000`2;DXP00`000000Re:808]BR00908]BR00400000009
jPX02NX:00WZ2PD0oooo0`0000030?ooo`8000001@2W`>/00`000000Yl3[0:O0j`0300WZ2Q@0Yl3[
0`09jPX708]BR0030000002W`>/000000080oooo00<0000008]BR02;DXP04P2;DXP00`000000Yl3[
0:O0j`070:O0j`030000003oool0oooo00<0oooo0`09jPX20?ooo`@0000000<0oooo0000003oool0
2`3oool300WZ2_l0ooooS@3oool002@0oooo00D000000?ooo`3oool0oooo0000000[0?ooo`030000
003oool0oooo00@0oooo00<0000008]BR02;DXP01P2;DXP010000000oooo0?ooo`3oool6000000P0
oooo00<0000008]BR02;DXP03P2;DXP00`000000Re:808]BR00H08]BR0040000003oool0oooo0?oo
o`<000001P2;DXP00`000000ljmn0?>_OP040?>_OP030000002;DXP0Re:80080Re:80P0000070:O0
j`040000002W`>/00000000000D0Yl3[0P0000001@2W`>/000000000002W`>/000000080Yl3[00H0
000000WZ2P09jPX02NX:0:O0j`0000060:O0j`050000002;DXP0Re:808]BR00000002@2;DXP300WZ
2PH0oooo0P0000070?ooo`800000102W`>/00`0000002NX:00WZ2P0D0:O0j`<02NX:2P2;DXP01P00
0000Yl3[0:O0j`000000oooo000001@0Re:800<000000:O0j`2W`>/0202W`>/00`000000oooo00WZ
2P0200WZ2PD0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`802NX:o`3o
oon@0?ooo`00903oool01@000000oooo0?ooo`3oool0000002X0oooo00<000000?ooo`3oool0103o
ool00`000000Re:808]BR00708]BR0030000003oool0oooo00L0oooo1P0000000`3oool0000008]B
R00@08]BR0030000002;DXP0Re:801L0Re:800<000000?ooo`3oool00P3oool00`000000Re:80000
000608]BR0030000003c[gh0ljmn00<0ljmn00@0000008]BR02;DXP0Re:80`0000000`2;DXP00000
0:O0j`050:O0j`8000002@2W`>/01@000000Yl3[0:O0j`2W`>/0000000<02NX:00@000000:O0j`2W
`>/000001`2W`>/200000080Re:800<0000008]BR02;DXP0102;DXP300WZ2P80Re:800<000000?oo
o`3oool00P3oool2000000T0oooo00<000000?ooo`0000000`09jPX00`000000Yl3[0:O0j`0A0:O0
j`<02NX:3@2;DXP01P000000Yl3[0:O0j`000000oooo000001@0Re:800<000000:O0j`2W`>/0202W
`>/2000000P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`<02NX:o`3o
oonB0?ooo`00903oool01@000000oooo0?ooo`3oool0000002X0oooo00<000000?ooo`3oool0103o
ool00`000000Re:808]BR00708]BR0030000003oool0oooo00d0oooo1@00000>08]BR0030000002;
DXP0Re:801H0Re:82@00000608]BR0030000003c[gh0ljmn00<0ljmn00<0000008]BR02;DXP00P2;
DXP200000080Re:800<000000:O0j`2W`>/00P2W`>/2000000P0Yl3[0P0000001P2W`>/000000000
0009jPX0Yl3[00000080Yl3[00<000000:O0j`000000202W`>/01@000000Yl3[0000002;DXP00000
00<0Re:80`09jPX508]BR0030000003oool00000008000002`3oool00`0000002NX:00WZ2P020000
0080Yl3[00<000000:O0j`2W`>/03@2W`>/300WZ2Q00Re:800@000000:O0j`2W`>/0Yl3[0P00000D
08]BR0030000002W`>/0Yl3[00D0Yl3[0`09jPX2000000P0oooo00<000000?ooo`3oool00`3oool0
10000000oooo0?ooo`3oool300WZ2_l0ooooU@3oool002@0oooo00D000000?ooo`3oool0oooo0000
000Z0?ooo`030000003oool0oooo00@0oooo00<0000008]BR02;DXP01`2;DXP00`000000oooo0?oo
o`0=0?ooo`030000002;DXP0Re:80080Re:81P00000708]BR0030000002;DXP0Re:800d0Re:83000
00040?ooo`030000002;DXP0000000H0Re:800<000000?>_OP3c[gh00`3c[gh01`000000Re:808]B
R02;DXP0000008]BR00000000`2;DXP4000000030:O0j`000000Yl3[00D0Yl3[0P00000300WZ2P03
0:O0j`0000000000008000000P2W`>/2000000X0Yl3[00@000000:O0j`00000000000`09jPX808]B
R08000002`3oool300WZ2P040000003oool0oooo0?ooo`@00000302W`>/300WZ2Q80Re:800<00000
0:O0j`2W`>/00P2W`>/00`09jPX0000008]BR00C08]BR0030000002W`>/0Yl3[0080Yl3[0`09jPX5
0:O0j`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool010000000oooo00WZ2P09
jP[o0?oooiP0oooo000T0?ooo`030000003oool0000000800000:P3oool00`000000oooo0?ooo`03
0?ooo`030000002;DXP0Re:800P0Re:800<000000?ooo`3oool0303oool00`000000Re:808]BR009
08]BR0D000000P2;DXP00`000000Re:808]BR00208]BR0/00000202;DXP010000000oooo0?ooo`3o
ool50000000308]BR0000000Re:800D0Re:800<000000?>_OP3c[gh00`3c[gh010000000Re:808]B
R000000208]BR0030000002;DXP0000000<000000`2W`>/00`000000Yl3[0:O0j`030:O0j`030000
0009jPX02NX:00L0Yl3[00@000000:O0j`2W`>/000002`2W`>/01@0000002NX:00000009jPX00000
00T0Re:800<000000?ooo`3oool01`3oool400WZ2P@0oooo1`0000090:O0j`<02NX:5@2;DXP00`00
0000Yl3[00WZ2P0200WZ2P030:O0j`000000Re:801<0Re:800<000000:O0j`09jPX00P09jPX80:O0
j`030000003oool0oooo00H0oooo00@000000?ooo`3oool0oooo0`09jP[o0?oooiX0oooo000T0?oo
o`8000000P2W`>/00`000000oooo0?ooo`0X0?ooo`D0000000<0oooo0000002;DXP02@2;DXP00`00
0000oooo0?ooo`0<0?ooo`030000002;DXP0Re:800h0Re:81`00000C08]BR0030000003oool0oooo
00@0oooo0`00000708]BR0030000003c[gh0ljmn00<0ljmn00@0000008]BR02;DXP000000P2;DXP2
000000@0Re:800@000000:O0j`2W`>/000000P2W`>/00`09jPX000000000000;0:O0j`<00000202W
`>/200WZ2P8000000`2W`>/00`000000Re:808]BR00708]BR0030000003oool0oooo00<0oooo1009
jPX50?ooo`D000000P3oool00`000000oooo000000060:O0j`<02NX:602;DXP00`0000002NX:0:O0
j`030:O0j`030000002;DXP0Re:80180Re:800<0000000WZ2P2W`>/02`2W`>/00`000000oooo0?oo
o`050?ooo`060000003oool02NX:00WZ2P3oool00000o`3ooonK0?ooo`00903oool010000000Yl3[
0:O0j`2W`>/2000002T0oooo00<000000:O0j`2W`>/00P2W`>/900000080Re:800<000000?ooo`3o
ool0303oool00`000000Re:808]BR00A08]BR0030000002;DXP0Re:801@0Re:800<000000?ooo`3o
ool01@3oool3000000L0Re:800<000000?>_OP3c[gh00`3c[gh00`000000Re:80000000308]BR003
0000002;DXP0Re:800<0Re:8100000000`09jPX000000000000<0:O0j`80000000<0Yl3[0000002W
`>/00`2W`>/400WZ2P040:O0j`000000Yl3[000000@0Yl3[00<0000008]BR02;DXP01P2;DXP00`00
0000oooo0?ooo`0300WZ2PH0oooo0`0000030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`0000000P2W`>/300WZ2Q/0Re:800<000000:O0j`2W`>/00`2W`>/00`000000Re:808]BR00B08]B
R0030000002W`>/0Yl3[00`0Yl3[00<000000?ooo`3oool00`3oool300WZ2P<0oooo00<000000?oo
o`3oool0o`3ooonI0?ooo`00903oool01`000000Yl3[0:O0j`2W`>/000000:O0j`0000009`3oool2
000000d0Yl3[200000080?ooo`030000002;DXP0Re:80180Re:800<0000008]BR02;DXP04`2;DXP2
000000<0oooo1`00000708]BR0030000003c[gh0ljmn00<0ljmn0`00000308]BR0030000002;DXP0
Re:800<0Re:800<02NX:00000009jPX00P00000<0:O0j`80000000<0Yl3[0000002W`>/00`000002
00WZ2P<0Yl3[0P0000020:O0j`030000002W`>/0Yl3[00<0Yl3[00<0000008]BR02;DXP0102;DXP4
00WZ2PH0oooo0`0000070?ooo`070000003oool0oooo0?ooo`0000002NX:0000000200WZ2Qh0Re:8
00<000000:O0j`2W`>/00`2W`>/00`000000Re:808]BR00A08]BR0030000002W`>/0Yl3[00d0Yl3[
00<000000?ooo`3oool00`09jPX00`3oool000000?ooo`030?ooo`030000003oool0oooo0?l0oooo
V@3oool002@0oooo0P0000020:O0j`030000002W`>/0000002L0oooo0P00000E0:O0j`T00000502;
DXP00`000000Re:808]BR00@08]BR0P00000102W`>/010000000Yl3[00000000000608]BR0030000
003c[gh0ljmn00<0ljmn0P00000408]BR0030000002;DXP0Re:800<02NX:00@000000?ooo`000000
00002`2W`>/2000000<0Yl3[00@0000000WZ2P0000002NX:0`0000000`2W`>/00000000000050:O0
j`030000002W`>/0Yl3[00<0Yl3[00<0000008]BR02;DXP00`09jPX00`2;DXP000000?ooo`040?oo
o`<000002P3oool00`000000oooo00WZ2P0200WZ2P030?ooo`000000000001l0Re:800<000000:O0
j`2W`>/00`2W`>/00`000000Re:808]BR00A08]BR0030000002W`>/0Yl3[00d0Yl3[00<02NX:0000
00000000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0ooooV@3oool002@0
oooo0P0000020:O0j`040000002W`>/0Yl3[000002D0oooo00<000000:O0j`0000007@2W`>/90000
00/0Re:800<0000008]BR02;DXP02@2;DXP8000000/0Yl3[0P000000102W`>/000000:O0j`000005
08]BR0030000003c[gh0ljmn00<0ljmn00<0000008]BR02;DXP00`2;DXP00`0000002NX:00WZ2P02
08]BR0<0000000<0oooo000000000000202W`>/2000000<0Yl3[0P09jPX010000000Yl3[0:O0j`00
00030:O0j`8000001P2W`>/00`000000Yl3[0:O0j`030:O0j`<02NX:102;DXP00`000000oooo0?oo
o`03000000`0oooo00<02NX:00000009jPX00`3oool00`000000oooo0000000O08]BR0030000002W
`>/0Yl3[00<0Yl3[00<0000008]BR02;DXP04@2;DXP00`000000Yl3[0:O0j`0:0:O0j`<02NX:00<0
Yl3[000000000000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0ooooV03o
ool002@0oooo0P0000020:O0j`050000002W`>/0Yl3[0:O0j`000000903oool00`000000Yl3[0000
000V0:O0j`P000000`2;DXP010000000Re:808]BR02;DXP8000001<0Yl3[0P0000001@2W`>/00000
0:O0j`2W`>/0000000@0Re:800<000000?>_OP3c[gh00`3c[gh010000000Re:800WZ2P00000200WZ
2P030000002;DXP000000080000000L0Re:80000003oool0oooo0000003oool0000000D0Yl3[0P00
00020:O0j`<02NX:0`2W`>/010000000Yl3[0000002W`>/200000080Yl3[0P0000040:O0j`030000
002W`>/0Yl3[00<02NX:00<0Yl3[000000000000102;DXP3000000`0oooo0`09jPX20?ooo`030000
003oool000000080000000<0oooo0000002;DXP07P2;DXP00`000000Yl3[0:O0j`030:O0j`030000
002;DXP0Re:80140Re:800<000000:O0j`2W`>/01`2W`>/300WZ2PD0Yl3[00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0ooooV03oool002@0oooo0P00
00000`2W`>/000000:O0j`030:O0j`030000003oool0oooo0240oooo00@000000:O0j`2W`>/00000
;P2W`>/7000001/0Yl3[0P0000000`2W`>/000000:O0j`020:O0j`8000000`2;DXP00`000000ljmn
0?>_OP020?>_OP0300000009jPX0Re:80080000000<0Re:8000000000000102;DXP00`000000oooo
0000000400000080Yl3[0P000000102W`>/02NX:00WZ2P09jPX60:O0j`040000002W`>/000000000
00H0Yl3[00<000000:O0j`2W`>/00P2W`>/00`0000002NX:0:O0j`050:O0j`050000002;DXP0Re:8
08]BR00000002P3oool400WZ2P@0oooo0`0000020?ooo`030000003oool0000001h0Re:800<00000
0:O0j`2W`>/00`2W`>/00`09jPX0000008]BR00B08]BR0030000002W`>/0Yl3[00@0Yl3[0`09jPX9
0:O0j`030000003oool0oooo0080oooo00<000000?ooo`3oool00`00003o0?oooiX0oooo000S0?oo
o`030000003oool0oooo008000001@2W`>/00`000000oooo0?ooo`0P0?ooo`040000002W`>/0Yl3[
00000340Yl3[00<0000008]BR00000006P2W`>/6000000D0Yl3[00@0000008]BR02;DXP00000103c
[gh00`000000Re:808]BR00308]BR0030000002;DXP0Re:800<0Re:80P0000020?ooo`030000003o
ool0oooo008000000`09jPX90:O0j`030000002W`>/0000000P0Yl3[00D0000000WZ2P09jPX02NX:
000000080:O0j`040000002;DXP0Re:8000000L0oooo0`09jPX50?ooo`<000000P3oool00`000000
oooo0?ooo`020000000308]BR0000000Re:801`0Re:800<000000:O0j`09jPX00`09jPX00`2W`>/0
000008]BR00B08]BR0040000002W`>/0Yl3[0:O0j`<02NX:302W`>/00`000000oooo0?ooo`020?oo
o`<000000P3oool00`000000oooo0?ooo`3o0?oooiP0oooo000S0?ooo`030000003oool0oooo0080
00001@2W`>/00`000000oooo0?ooo`0O0?ooo`050000002W`>/0Yl3[0:O0j`000000<02W`>/20000
0080Re:80P00000A0:O0j`L0000000H0Yl3[0000002W`>/000000:O0j`0000050:O0j`0400WZ2P00
00000000000000@0ljmn00<0000008]BR02;DXP00`2;DXP00`000000Re:808]BR00308]BR0040000
003oool0oooo0?ooo`@0000000<02NX:0:O0j`2W`>/02@2W`>/2000000030:O0j`000000Yl3[00H0
Yl3[0P09jPX010000000Yl3[0:O0j`0000090:O0j`030000002;DXP0000000@0oooo0`09jPX40?oo
o`@000001@3oool01`000000oooo0?ooo`3oool0000008]BR00000007@2;DXP00`0000002NX:0:O0
j`040:O0j`030000002;DXP0Re:80140Re:800@0000000WZ2P09jPX02NX:402W`>/01@000000oooo
0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0o`3ooonH0?ooo`008`3oool00`000000oooo
0?ooo`02000000H0Yl3[00<000000?ooo`3oool07P3oool01@000000Yl3[0:O0j`2W`>/000000300
Yl3[0P00000408]BR0030000002W`>/0Yl3[00P0Yl3[1P0000080:O0j`050000002W`>/000000:O0
j`0000000P2W`>/300WZ2P040:O0j`0000000000000000@0ljmn00<0000008]BR02;DXP00`2;DXP0
0`000000Re:808]BR00308]BR0030000003oool0oooo0080000000D02NX:0?ooo`3oool0oooo0000
00080:O0j`80000000@0Yl3[0000002W`>/00000102W`>/300WZ2P<0Yl3[0P0000000`2W`>/00000
0:O0j`080:O0j`80000000@0oooo00WZ2P09jPX02NX:103oool3000000T0oooo00L000000?ooo`3o
ool0oooo0000002;DXP0000001d0Re:800<000000:O0j`2W`>/0102W`>/00`000000Re:808]BR00@
08]BR00300000009jPX0Yl3[01<0Yl3[00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`3o0?oooiP0oooo000S0?ooo`030000003oool0oooo008000001`2W`>/00`000000oooo0?ooo`0L
0?ooo`030000002W`>/0Yl3[0080Yl3[3P00000R0:O0j`030000002;DXP0000000D0Re:800@00000
0:O0j`2W`>/0Yl3[1P00000>0:O0j`050000002W`>/000000:O0j`0000000P09jPX60:O0j`030000
003c[gh0ljmn0080ljmn00<0000008]BR02;DXP0102;DXP00`000000Re:808]BR00208]BR0<00000
00<0oooo0000003oool0103oool00`000000Yl3[0:O0j`020:O0j`<000000`2W`>/010000000Yl3[
0:O0j`00000300WZ2PP0Yl3[0P0000000`2W`>/000000:O0j`060:O0j`<02NX:103oool3000000d0
oooo00@0000000WZ2P09jPX000000P2;DXP00`000000Re:808]BR00I08]BR0030000002W`>/0Yl3[
00D0Yl3[00<0000008]BR02;DXP0402;DXP00`000000Yl3[0:O0j`0C0:O0j`040000003oool0oooo
000000D0oooo00<000000?ooo`3oool0o`3ooonG0?ooo`008`3oool00`000000oooo0?ooo`020000
00L0Yl3[00<000000?ooo`3oool0703oool00`000000Yl3[0:O0j`020:O0j`030000002W`>/0Yl3[
00/0Yl3[6@0000090:O0j`030000002;DXP000000080Re:81`00000D0:O0j`0300000009jPX02NX:
00800000202W`>/00`000000ljmn0?>_OP020?>_OP030000002;DXP0Re:800@0Re:800<0000000WZ
2P0000000`0000030?ooo`030000003oool0oooo00D0000000<0Yl3[0000000000001`2W`>/00`00
00002NX:000000080:O0j`<0000000<0Yl3[0000002W`>/01@2W`>/300WZ2P0408]BR00000000000
0?ooo`<000003P3oool200WZ2P050000003oool0oooo0000002;DXP00P00000K08]BR0030000002W
`>/0Yl3[00D0Yl3[00<0000008]BR02;DXP0402;DXP2000001D0Yl3[00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`3o0?oooiL0oooo000S0?ooo`<0000000<0oooo0000002W`>/01`2W
`>/00`000000oooo0?ooo`0J0?ooo`030000002W`>/0Yl3[00<0Yl3[00<000000:O0j`2W`>/0902W
`>/>000000D0Re:800<000000:O0j`2W`>/04@2W`>/00`09jPX00000000000020:O0j`8000002@2W
`>/01@000000ljmn0?>_OP3c[gh0000000<0Re:80`09jPX40000000308]BR0000000oooo00D00000
103oool2000000H0Yl3[0`09jPX00`000000Yl3[000000060:O0j`8000001@2W`>/00`000000Yl3[
0:O0j`0300WZ2P@0Re:800<000000:O0j`0000003P3oool300WZ2P80oooo00<000000?ooo`000000
0P0000000`2;DXP0000008]BR00J08]BR0030000002W`>/0Yl3[00D0Yl3[00<0000008]BR02;DXP0
402;DXP00`000000oooo0000000D0:O0j`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0o`3ooonG0?ooo`008`3oool01@000000oooo0?ooo`3oool0000000T0Yl3[00<000000?ooo`3o
ool06@3oool00`000000Yl3[0:O0j`030:O0j`030000002W`>/0Yl3[02`0Yl3[00@0000008]BR02;
DXP00000202;DXP00`000000Yl3[0:O0j`0=0:O0j`<02NX:00<0Yl3[000000000000100000090:O0
j`050000003c[gh0ljmn0?>_OP0000000`09jPX308]BR0030000002;DXP0Re:80080Re:80P000003
0?ooo`030000003oool0oooo00<000000P3oool2000000040:O0j`09jPX02NX:00WZ2P<0Yl3[00<0
00000:O0j`000000102W`>/2000000H0Yl3[00@02NX:0000000000002NX:1`2;DXP010000000Yl3[
0:O0j`00000:0?ooo`<02NX:0`3oool4000000030?ooo`000000Re:80080Re:800<0000008]BR02;
DXP0602;DXP00`000000Yl3[0:O0j`050:O0j`030000002;DXP0Re:80100Re:800@000000?ooo`3o
ool00000502W`>/00`000000oooo000000040?ooo`030000003oool0oooo0?l0ooooU`3oool002<0
oooo00@000000?ooo`3oool0oooo0P0000090:O0j`030000003oool0oooo01P0oooo00<000000:O0
j`2W`>/00`2W`>/00`000000Yl3[0:O0j`0/0:O0j`040000002;DXP0Re:8000000T0Re:800<00000
0:O0j`2W`>/0202W`>/400WZ2PH000000P2W`>/2000000T0Yl3[00<000000?>_OP3c[gh00P3c[gh0
0`000000Re:808]BR00408]BR0050000002;DXP0Re:808]BR0000000103oool3000000@0oooo00@0
2NX:00000009jPX02NX:1P2W`>/00`000000Yl3[0:O0j`04000000D0Yl3[0`09jPX00`2;DXP00000
0000000808]BR0050000002W`>/0Yl3[0:O0j`0000001P3oool300WZ2P80oooo100000030?ooo`80
0000102;DXP00`000000Re:808]BR00G08]BR0030000002W`>/0Yl3[00H0Yl3[00<0000008]BR02;
DXP0402;DXP01@000000oooo0?ooo`3oool0000001<0Yl3[00<000000?ooo`000000103oool00`00
0000oooo0?ooo`3o0?oooiL0oooo000S0?ooo`040000003oool0oooo0?ooo`8000002P2W`>/00`00
0000oooo0?ooo`0G0?ooo`030000002W`>/0Yl3[00<0Yl3[00<000000:O0j`2W`>/0;02W`>/01000
0000Re:808]BR000000:08]BR0030000002W`>/0Yl3[00@0Yl3[0P09jPX5000000D0Yl3[00<00000
0:O0j`2W`>/00P0000080:O0j`0300WZ2P000000ljmn00<0ljmn00<0000008]BR02;DXP0102;DXP0
1@000000Re:808]BR02;DXP0000000<0oooo0P0000020?ooo`@02NX:0`3oool2000000H0Yl3[00<0
00000:O0j`0000001@2W`>/300WZ2PD0Re:800<0000008]BR02;DXP01P2;DXP00`000000Yl3[0:O0
j`020:O0j`030000003oool0oooo00<02NX:0P3oool3000000P0oooo00<0000008]BR02;DXP00P2;
DXP00`000000Re:808]BR00G08]BR0030000002W`>/0Yl3[0080Yl3[1009jPX00`000000Re:808]B
R00@08]BR0030000003oool0oooo0080oooo00<000000:O0j`2W`>/04@2W`>/2000000@0oooo00<0
00000?ooo`3oool0o`3ooonG0?ooo`008`3oool010000000oooo0?ooo`3oool2000000X0Yl3[00<0
00000?ooo`3oool05P3oool00`000000Yl3[0:O0j`050:O0j`030000002W`>/0Yl3[02/0Yl3[00D0
000008]BR02;DXP0Re:80000000:08]BR0030000002W`>/0000000D000002P2W`>/01P000000Yl3[
0:O0j`000000Yl3[000000@0Yl3[0`09jPX00`2W`>/000000?>_OP030?>_OP030000002;DXP0Re:8
00@0Re:800@0000008]BR02;DXP0Re:81P00000200WZ2PH0oooo100000030:O0j`<0000000@0Yl3[
0000002W`>/0Yl3[0`09jPX808]BR0030000002;DXP0Re:800H0Re:800H000000:O0j`2W`>/0Yl3[
00WZ2P00000200WZ2P030?ooo`0000000000008000002`3oool00`000000Re:808]BR00308]BR003
0000002;DXP0Re:801H0Re:800<0000000WZ2P09jPX00P09jPX40:O0j`030000002;DXP0Re:80100
Re:800<000000?ooo`3oool00`3oool00`000000Yl3[0:O0j`0@0:O0j`8000001@3oool00`000000
oooo0?ooo`3o0?oooiH0oooo000S0?ooo`070000003oool0oooo0?ooo`000000oooo0000000:0:O0
j`030000003oool0oooo01D0oooo00<000000:O0j`2W`>/01@2W`>/00`000000Yl3[0:O0j`0[0:O0
j`050000002;DXP0Re:808]BR00000001`2;DXP50000000300WZ2P2W`>/0Yl3[00d0Yl3[00@00000
0:O0j`2W`>/0Yl3[0P0000020:O0j`802NX:102W`>/00`000000ljmn0?>_OP020?>_OP8000001P2;
DXP4000000@02NX:00<0oooo0000003oool00P3oool400000080oooo00<000000?ooo`0000000P00
00020:O0j`050000002W`>/02NX:00000009jPX02P2;DXP2000000P0Re:800D0000000WZ2P09jPX0
2NX:0:O0j`04000000l0oooo00<0000008]BR02;DXP00`2;DXP00`000000Re:808]BR00E08]BR003
00000009jPX0Yl3[00L0Yl3[00<0000008]BR02;DXP03`2;DXP00`000000oooo0?ooo`040?ooo`03
0000002W`>/0Yl3[0140Yl3[00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?oooiH0
oooo000S0?ooo`070000003oool0oooo0?ooo`000000oooo0000000;0:O0j`030000003oool0oooo
01@0oooo00<000000:O0j`2W`>/01@2W`>/00`000000Yl3[0:O0j`0[0:O0j`050000002;DXP0Re:8
08]BR00000000P2;DXP5000000<02NX:0`00000?0:O0j`040000002W`>/0Yl3[0:O0j`8000000P09
jPX60:O0j`030000003c[gh0ljmn0080ljmn00<000000:O0j`0000001@2;DXP0100000002NX:00WZ
2P09jPX50?ooo`@000001@3oool3000000040?ooo`000000Yl3[0:O0j`802NX:00<0000008]BR000
00002`2;DXP00`000000Re:80000000708]BR0030000002W`>/0Yl3[00D0Yl3[00<000000?ooo`3o
ool02`3oool01009jPX0000008]BR000000508]BR0030000002;DXP0Re:801@0Re:800<000000:O0
j`2W`>/01`2W`>/00`000000Re:808]BR00?08]BR0030000003oool0oooo00D0oooo00<000000:O0
j`2W`>/0402W`>/2000000<0oooo0P00003o0?oooiP0oooo000S0?ooo`030000003oool0oooo0080
oooo0P00000<0:O0j`030000003oool0oooo01<0oooo00<000000:O0j`2W`>/01@2W`>/00`000000
Yl3[0:O0j`0S0:O0j`l000000P2;DXP300WZ2P@0Re:800<000000?ooo`0000003P2W`>/00`000000
Yl3[00000003000000T0Yl3[00<000000?>_OP3c[gh00P3c[gh00`000000Yl3[0000000208]BR080
2NX:00@0000008]BR02;DXP000000P3oool4000000D0oooo0`0000020?ooo`030000003oool02NX:
00802NX:0P2;DXP00`000000Re:80000000;08]BR0030000002;DXP0000000L0Re:800<000000:O0
j`2W`>/01P2W`>/00`000000oooo0?ooo`070?ooo`<02NX:00@0oooo0000002;DXP000001@2;DXP0
0`000000Re:808]BR00D08]BR0030000002W`>/0Yl3[00L0Yl3[00<0000008]BR02;DXP03`2;DXP0
0`000000oooo0?ooo`060?ooo`030000002W`>/0Yl3[0100Yl3[100000000`3oool000000?ooo`3o
0?oooiL0oooo000T0?ooo`070000003oool0oooo0?ooo`000000oooo0000000<0:O0j`030000003o
ool0oooo0180oooo00<000000:O0j`2W`>/01@2W`>/00`000000Yl3[0:O0j`0:0:O0jaT00000202W
`>/01@000000Re:808]BR02;DXP000000080Re:80P09jPX708]BR0040000003oool0oooo000000X0
Yl3[1@0000020:O0j`8000002@2W`>/00`000000ljmn0?>_OP020?>_OP0300000009jPX02NX:0080
00000P2;DXP00`000000Re:808]BR003000000@0oooo00<000000?ooo`0000000P0000040?ooo`<0
2NX:0P00000408]BR0030000002;DXP0000000X0Re:800<0000008]BR00000001`2;DXP00`000000
Yl3[0:O0j`070:O0j`030000003oool0oooo00<0oooo0`09jPX20?ooo`<000000P2;DXP00`000000
Re:808]BR00208]BR0030000002;DXP0Re:801<0Re:800<000000:O0j`2W`>/0202W`>/00`000000
Re:808]BR00?08]BR0030000003oool0oooo00L0oooo00<000000:O0j`2W`>/03`2W`>/00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0?l0ooooUP3oool002@0oooo00L000000?ooo`3oool0
oooo0000003oool0000000`0Yl3[00<000000?ooo`3oool04@3oool00`000000Yl3[0:O0j`060:O0
j`d000008@2W`>/01@000000Re:808]BR02;DXP0000000802NX:2@2;DXP01@000000oooo0?ooo`3o
ool0000000D0Yl3[1000000200WZ2P80Yl3[00<000000:O0j`2W`>/00P0000090:O0j`030000003c
[gh0ljmn0080ljmn00<000000:O0j`2W`>/00P00000208]BR0040000002;DXP0Re:8000000D0oooo
0`0000040?ooo`<02NX:0P3oool3000000@0Re:800<0000008]BR00000002P2;DXP4000000H0Re:8
00<000000:O0j`2W`>/0202W`>/2000000<02NX:1@0000020?ooo`040000002;DXP0Re:8000000D0
Re:800<0000008]BR02;DXP04P2;DXP00`000000Yl3[0:O0j`080:O0j`030000002;DXP0Re:800l0
Re:800<000000?ooo`3oool0203oool00`000000Yl3[0:O0j`0?0:O0j`050000003oool0oooo0?oo
o`000000o`3ooonH0?ooo`00903oool01`000000oooo0?ooo`3oool000000?ooo`0000003@2W`>/0
0`000000oooo0?ooo`0@0?ooo`030000002W`>/0Yl3[00H0Yl3[00<000000:O0j`2W`>/0:P2W`>/2
000000<02NX:00<0000008]BR02;DXP0202;DXP00`000000oooo0?ooo`030?ooo`D000000P09jPX6
0:O0j`060000002W`>/0Yl3[0000002W`>/00000202W`>/00`000000ljmn0?>_OP020?>_OP030000
002W`>/0Yl3[0080Yl3[00H0000008]BR02;DXP0000008]BR00000020?ooo`<0000000@0oooo0000
003oool000000`09jPX30?ooo`<0000000<0oooo0000002;DXP00`2;DXP00`000000Re:800000003
08]BR0P000000P2;DXP00`000000Re:808]BR00408]BR0030000002W`>/0Yl3[00L0Yl3[00<02NX:
00000009jPX00`0000060?ooo`050000002;DXP0Re:808]BR00000001@2;DXP00`000000Re:808]B
R00B08]BR0030000002W`>/0Yl3[00P0Yl3[00<0000008]BR02;DXP03`2;DXP00`000000oooo0?oo
o`090?ooo`030000002W`>/0Yl3[00h0Yl3[00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`3o0?oooiD0oooo000T0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000Yl3[0:O0
j`0;0:O0j`030000003oool0oooo00l0oooo00<000000:O0j`2W`>/01P2W`>/00`000000Yl3[0:O0
j`0X0:O0j`802NX:00<0000000WZ2P2;DXP00`2;DXP00`000000Re:808]BR00708]BR0H0000000<0
2NX:00000009jPX02P2W`>/010000000Yl3[0:O0j`2W`>/2000000D0Yl3[0`09jPX00`000000ljmn
0?>_OP020?>_OP030000002W`>/0Yl3[00<0Yl3[00<0000008]BR0000000100000040?ooo`0400WZ
2P0000002NX:00000080oooo0`0000020?ooo`800000102;DXP30000000408]BR000000000000000
00L0Re:800D0000008]BR02;DXP0Re:80000000508]BR0030000002W`>/0Yl3[00<0Yl3[1009jPX3
0:O0j`030000003oool0oooo00H0oooo00<0000008]BR02;DXP00P2;DXP00`000000Re:808]BR002
08]BR0030000002;DXP0Re:80140Re:800<000000:O0j`2W`>/02@2W`>/00`000000Re:808]BR00?
08]BR0030000003oool0oooo00X0oooo00<000000:O0j`2W`>/03P2W`>/01@000000oooo0?ooo`3o
ool000000?l0ooooU`3oool002@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000002W
`>/0Yl3[00`0Yl3[00<000000?ooo`3oool03P3oool00`000000Yl3[0:O0j`060:O0j`030000002W
`>/0Yl3[02<0Yl3[1@09jPX40:O0j`050000002;DXP0Re:808]BR00000001P2;DXP400000080oooo
0`09jPX00`3oool000000000000;0:O0j`030000002W`>/0Yl3[008000000P2W`>/300WZ2P@0Yl3[
00D000000?>_OP3c[gh0ljmn000000060:O0j`<00000103oool300WZ2P030?ooo`000000oooo00<0
00001P3oool500000080Re:800<0000008]BR0000000202;DXP00`000000Re:808]BR00208]BR003
0000002;DXP0Re:800<0Re:800<000000:O0j`09jPX00`09jPX80:O0j`030000003oool0oooo00D0
oooo00<0000008]BR02;DXP00P2;DXP00`000000Re:808]BR00208]BR08000004P2;DXP00`000000
Yl3[0:O0j`090:O0j`030000002;DXP0Re:800h0Re:800<000000?ooo`3oool0303oool00`000000
Yl3[0:O0j`0=0:O0j`050000003oool0oooo0?ooo`000000o`3ooonG0?ooo`00903oool00`000000
oooo0000000200000080oooo00<000000:O0j`2W`>/03@2W`>/00`000000oooo0?ooo`0=0?ooo`03
0000002W`>/0Yl3[00H0Yl3[00<000000:O0j`2W`>/07P2W`>/500WZ2PT0Yl3[00H0000008]BR02;
DXP0Re:80000002;DXP500000080Re:800@0000000WZ2P09jPX02NX:1P3oool00`000000Yl3[0:O0
j`080:O0j`D000000P09jPX70:O0j`030000003c[gh0ljmn0080ljmn00<000000:O0j`2W`>/0102W
`>/3000000<02NX:0`3oool3000000D0oooo1@00000608]BR0040000002;DXP0Re:8000000L0Re:8
00<0000008]BR02;DXP00P2;DXP00`000000Re:808]BR00308]BR00300000009jPX0Yl3[00`0Yl3[
00<000000?ooo`3oool00`3oool00`000000Re:808]BR00308]BR0030000002;DXP0000000800000
00<0Re:80000002;DXP04@2;DXP00`000000Yl3[0:O0j`090:O0j`030000002;DXP0Re:800h0Re:8
00<000000?ooo`3oool03@3oool00`000000Yl3[0:O0j`0<0:O0j`050000003oool0oooo0?ooo`00
0000o`3ooonG0?ooo`00903oool200000080oooo00D000000?ooo`3oool0oooo0000000>0:O0j`03
0000003oool0oooo00h0oooo00<000000:O0j`2W`>/01@2W`>/00`000000Yl3[0:O0j`0H0:O0j`H0
2NX:3P2W`>/6000000D0Re:80`09jPX:0?ooo`030000002W`>/0Yl3[00@0Yl3[1@0000000`09jPX0
0000000000090:O0j`030000003c[gh0ljmn0080ljmn00<000000:O0j`2W`>/00`2W`>/200WZ2P80
00000`3oool300000080oooo00<000000?ooo`0000000`0000040?ooo`030000002;DXP0Re:800D0
Re:800<0000008]BR00000001`2;DXP00`000000Re:808]BR00308]BR0030000002;DXP0Re:80080
Re:80P00000>0:O0j`030000003oool0oooo00802NX:00<0000008]BR02;DXP0102;DXP00`000000
Re:808]BR00308]BR0030000002;DXP0Re:800h0Re:800<000000:O0j`2W`>/02@2W`>/00`000000
Re:808]BR00?08]BR0030000003oool0oooo00d0oooo00<000000:O0j`2W`>/03@2W`>/010000000
oooo0?ooo`00003o0?oooiL0oooo000T0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000Yl3[0:O0j`0=0:O0j`030000003oool0oooo00d0oooo00<000000:O0j`2W`>/01P2W`>/00`00
0000Yl3[0:O0j`0B0:O0j`D02NX:2`2W`>/:000000<0Re:800@0000008]BR02;DXP0Re:80`09jPX2
08]BR0030000003oool0oooo00T0oooo00<000000:O0j`0000000`000000102W`>/02NX:00WZ2P09
jPX3000000030:O0j`000000Yl3[00P0Yl3[00D000000?>_OP3c[gh0ljmn000000020:O0j`<02NX:
0P2;DXP5000000@0oooo0`0000060?ooo`802NX:00<0000008]BR02;DXP01@2;DXP010000000Re:8
08]BR000000608]BR0030000002;DXP0Re:800<0Re:800<0000008]BR02;DXP00P2;DXP2000000h0
Yl3[0`09jPX00`3oool000000000000608]BR0030000002;DXP0Re:800<0Re:800<0000008]BR02;
DXP03P2;DXP00`000000Yl3[0:O0j`090:O0j`030000002;DXP0Re:800l0Re:800<000000?ooo`3o
ool03P3oool00`000000Yl3[0:O0j`0<0:O0j`040000003oool0oooo00000?l0ooooU`3oool002@0
oooo00D000000?ooo`3oool0oooo000000040?ooo`030000002W`>/0Yl3[00d0Yl3[00<000000?oo
o`3oool0303oool00`000000Yl3[0:O0j`060:O0j`030000002W`>/0Yl3[00d0Yl3[1@09jPX80:O0
j`P000002P2W`>/010000000Re:808]BR000000300WZ2PD0Re:80P0000080?ooo`@000000P2W`>/3
00WZ2PD0Yl3[00<000000:O0j`0000002@2W`>/01@000000ljmn0?>_OP3c[gh0000000802NX:1@2;
DXP00`000000Yl3[000000030?ooo`<0000000<0oooo0000003oool00`3oool300WZ2P80oooo00<0
000008]BR02;DXP01@2;DXP010000000Re:808]BR000000608]BR0030000002;DXP0Re:800@0Re:8
00@0000008]BR02;DXP0Re:80P00000;0:O0j`<02NX:00<0Yl3[0000000000000P00000808]BR003
0000002;DXP0Re:800<0Re:800<0000008]BR02;DXP03@2;DXP00`000000Yl3[0:O0j`090:O0j`03
0000002;DXP0Re:800l0Re:800<000000?ooo`3oool03`3oool00`000000Yl3[0:O0j`0<0:O0j`04
0000003oool0oooo00000?l0ooooUP3oool002@0oooo00D000000?ooo`3oool0oooo000000040?oo
o`030000002W`>/0Yl3[00h0Yl3[00<000000?ooo`3oool02`3oool00`000000Yl3[0:O0j`060:O0
j`030000002W`>/0Yl3[00P0Yl3[1@09jPX50:O0j`P000004@2W`>/2000000802NX:00<0000008]B
R02;DXP01@2;DXP00`000000oooo000000040?ooo`@000000P3oool200WZ2P0300000009jPX0Yl3[
00P0Yl3[0P0000090:O0j`030000003c[gh0ljmn0080ljmn00<0000008]BR02;DXP0102;DXP20000
00040:O0j`0000000000000000D0oooo00D0000000WZ2P09jPX02NX:0?ooo`05000000P0Re:800<0
000008]BR00000001P2;DXP00`000000Re:808]BR00408]BR0070000002;DXP0Re:808]BR0000000
Yl3[000000070:O0j`<02NX:1P2W`>/2000000P0Re:800<0000008]BR02;DXP00`2;DXP00`000000
Re:808]BR00<08]BR0030000002W`>/0Yl3[00X0Yl3[00<0000008]BR02;DXP03`2;DXP00`000000
oooo0?ooo`0@0?ooo`030000002W`>/0Yl3[00/0Yl3[00@000000?ooo`3oool00000o`3ooonF0?oo
o`009@3oool010000000oooo0?ooo`0000050?ooo`030000002W`>/0Yl3[00h0Yl3[00<000000?oo
o`3oool02P3oool00`000000Yl3[0:O0j`060:O0j`030000002W`>/0Yl3[0080Yl3[1P09jPX00`2W
`>/0000000000007000001P0Yl3[00<02NX:00000009jPX00`2;DXP00`000000Re:808]BR00408]B
R0030000003oool0000000@000000`3oool300WZ2P80oooo0P0000090:O0j`<000001@2W`>/300WZ
2P0308]BR0000000ljmn0080ljmn00<0000008]BR02;DXP0102;DXP3000000030:O0j`0000000000
00@0oooo00@02NX:0000003oool0oooo0`0000030?ooo`030000002;DXP0Re:800@0Re:80`000002
08]BR0P000001@2;DXP01`000000Re:808]BR02;DXP000000:O0j`000000102W`>/300WZ2PX0Yl3[
00<0000008]BR02;DXP01`2;DXP00`000000Re:808]BR00308]BR0030000002;DXP0Re:800/0Re:8
00<000000:O0j`2W`>/02P2W`>/00`000000Re:808]BR00>08]BR0030000003oool0oooo0180oooo
00<000000:O0j`2W`>/02P2W`>/400000?l0ooooUP3oool002D0oooo00@000000?ooo`3oool00000
1@3oool00`000000Yl3[0:O0j`0>0:O0j`030000003oool0oooo00/0oooo00<000000:O0j`2W`>/0
1@2W`>/0100000002NX:00WZ2P09jPX8000001`0Yl3[1@09jPX30:O0j`040000002;DXP0Re:80000
00D0Re:81@0000030?ooo`<02NX:1`3oool00`000000Yl3[0:O0j`040:O0j`D000000P2W`>/300WZ
2P@0Re:800D000000?>_OP3c[gh0ljmn0000000608]BR0800000102W`>/2000000802NX:00@0oooo
00000000000000001P3oool00`000000Re:808]BR00400000080Re:800@0000008]BR02;DXP00000
102;DXP00`000000Re:808]BR0070000000308]BR0000000Yl3[0080Yl3[00@0000000WZ2P09jPX0
2NX:302W`>/00`000000Re:808]BR00808]BR0030000002;DXP0Re:800<0Re:800<0000008]BR02;
DXP02P2;DXP00`000000Yl3[0:O0j`0;0:O0j`030000002;DXP0Re:800h0Re:800<000000?ooo`3o
ool04P3oool00`000000Yl3[0:O0j`0;0:O0j`030000003oool000000?l0ooooUP3oool002D0oooo
00@000000?ooo`3oool000001@3oool00`000000Yl3[0:O0j`0?0:O0j`030000003oool0oooo00X0
oooo00<000000:O0j`2W`>/01@09jPX400000200Yl3[1009jPX80:O0j`050000002;DXP0Re:80000
002;DXP0100000001@2;DXP000000?ooo`3oool0000000<02NX:2`3oool00`000000Yl3[0:O0j`03
00000080Yl3[00D000000:O0j`000000000000WZ2P0708]BR0030000003c[gh0ljmn0080ljmn00<0
000008]BR02;DXP00`2;DXP010000000Yl3[0000002W`>/200WZ2P80000000D0oooo000000000000
oooo000000060?ooo`@000001`2;DXP010000000Re:808]BR000000308]BR0030000002;DXP0Re:8
00H0Re:800@0000008]BR0000000Yl3[0`09jPX00`000000Yl3[0:O0j`0<0:O0j`030000002;DXP0
Re:800T0Re:800<0000008]BR02;DXP00P2;DXP00`000000Re:808]BR00:08]BR0030000002W`>/0
Yl3[00/0Yl3[00<0000008]BR02;DXP03P2;DXP00`000000oooo0?ooo`0C0?ooo`030000002W`>/0
Yl3[00X0Yl3[00<000000?ooo`000000o`3ooonF0?ooo`009@3oool01@000000oooo0?ooo`3oool0
000000D0oooo00<000000:O0j`2W`>/03`2W`>/00`000000oooo0?ooo`070?ooo`0300WZ2P000000
000000802NX:1@2W`>/00`000000Yl3[0:O0j`0M0:O0j`@02NX:302W`>/5000000@0Re:800<00000
0?ooo`09jPX00P09jPX>0?ooo`<00000102W`>/200WZ2P<000002@2;DXP01@000000ljmn0?>_OP3c
[gh0000000D0Re:800@0000000WZ2P0000002NX:102W`>/01@000000oooo0?ooo`3oool000000080
oooo100000000`3oool0000008]BR00808]BR0040000002;DXP0Re:800000080Re:800<0000008]B
R02;DXP0202;DXP20000000400WZ2P2W`>/0Yl3[000000h0Yl3[00<0000008]BR02;DXP02P2;DXP0
0`000000Re:808]BR00308]BR0030000002;DXP0Re:800P0Re:800<000000:O0j`2W`>/0302W`>/0
0`000000Re:808]BR00>08]BR0030000003oool0oooo01@0oooo00<000000:O0j`2W`>/02@2W`>/0
0`000000oooo0000003o0?oooiH0oooo000U0?ooo`050000003oool0oooo0?ooo`0000001@3oool0
0`000000Yl3[0:O0j`0@0:O0j`040000003oool0oooo0?ooo`D02NX:00<0oooo0000000000001`2W
`>/00`000000Yl3[0:O0j`0H0:O0j`D02NX:302W`>/60000000308]BR0000000Re:800<0Re:80`09
jPX30?ooo`030000003oool0oooo00P0oooo0`0000020?ooo`8000000`09jPX208]BR0030000002;
DXP0000000T0Re:800<000000?>_OP3c[gh00P3c[gh00`000000Re:808]BR00208]BR0040000002W
`>/0Yl3[000000D0Yl3[00<000000?ooo`0000000`0000050?ooo`030000002;DXP0Re:800P0Re:8
00H0000008]BR02;DXP0000008]BR000000:08]BR0800000102W`>/00`000000Yl3[0:O0j`0;0:O0
j`030000002;DXP0Re:800/0Re:800<0000008]BR02;DXP00P2;DXP00`000000Re:808]BR00708]B
R0030000002W`>/0Yl3[00d0Yl3[00<0000008]BR02;DXP03@2;DXP00`000000oooo0?ooo`0F0?oo
o`030000002W`>/0Yl3[00T0Yl3[0P00003o0?oooiH0oooo000U0?ooo`050000003oool0oooo0?oo
o`0000001P3oool00`000000Yl3[0:O0j`0?0:O0j`0400WZ2P0000000000000000P0oooo00<00000
0:O0j`2W`>/0102W`>/00`000000Yl3[0:O0j`0D0:O0j`@02NX:302W`>/5000000H0Yl3[0P000000
1@2;DXP02NX:00WZ2P09jPX0Re:8008000000`3oool00`000000oooo0?ooo`050?ooo`<00000103o
ool200WZ2P800000102;DXP00`000000Re:80000000908]BR0030000003c[gh0ljmn0080ljmn00<0
000008]BR02;DXP00P2;DXP010000000Yl3[0:O0j`0000020:O0j`D000000P3oool010000000oooo
0?ooo`3oool300WZ2P030000002;DXP0Re:800T0Re:800D0000008]BR0000000Re:80000000;08]B
R0030000002W`>/0Yl3[0080Yl3[00<000000:O0j`2W`>/02`2W`>/00`000000Re:808]BR00;08]B
R0030000002;DXP0Re:800<0Re:800<0000008]BR02;DXP01P2;DXP00`000000Yl3[0:O0j`0=0:O0
j`030000002;DXP0Re:800d0Re:800<000000?ooo`3oool05P3oool00`000000Yl3[0:O0j`090:O0
j`800000o`3ooonF0?ooo`009@3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000:O0
j`2W`>/0302W`>/300WZ2P80Yl3[0P0000080?ooo`030000002W`>/0Yl3[00D0Yl3[00<000000:O0
j`2W`>/03`2W`>/400WZ2P/0Yl3[1@00000:0:O0j`0400WZ2P0000002NX:000000@0Re:80P000003
0?ooo`030000003oool0oooo0080oooo0`0000040?ooo`<02NX:0P3oool00`000000Re:808]BR004
08]BR0<00000202;DXP00`000000ljmn0?>_OP020?>_OP030000002;DXP0Re:80080Re:800@00000
0:O0j`2W`>/0Yl3[0P0000050:O0j`040000003oool0oooo000000802NX:00@000000?ooo`3oool0
00002`2;DXP01@000000Re:80000002;DXP0000000/0Re:800<000000:O0j`2W`>/00P2W`>/00`00
0000Yl3[0:O0j`0:0:O0j`030000002;DXP0Re:800d0Re:800<0000008]BR02;DXP00P2;DXP00`00
0000Re:808]BR00508]BR0030000002W`>/0Yl3[00h0Yl3[00<0000008]BR02;DXP03@2;DXP00`00
0000oooo0?ooo`0G0?ooo`030000002W`>/0Yl3[00P0Yl3[0P00003o0?oooiH0oooo000V0?ooo`04
0000003oool0oooo000000L0oooo00<000000:O0j`2W`>/0202W`>/300WZ2PH0Yl3[00<000000?oo
o`3oool01@3oool2000000L0Yl3[00<000000:O0j`2W`>/02P2W`>/500WZ2PX0Yl3[1@00000<0:O0
j`<02NX:00@0Yl3[0000000000000000102;DXP00`000000oooo000000030?ooo`@00000103oool3
00WZ2PD0oooo00<0000008]BR02;DXP00`2;DXP4000000T0Re:800<000000?>_OP3c[gh00P3c[gh0
1@000000Re:808]BR02;DXP0000000<0Yl3[00<000000:O0j`2W`>/0102W`>/00`09jPX000000000
0002000000@0oooo00<0000008]BR02;DXP01P2;DXP50000000308]BR00000000000008000002@2;
DXP00`000000Yl3[0:O0j`020:O0j`030000002W`>/0Yl3[00X0Yl3[00<0000008]BR02;DXP03@2;
DXP010000000Re:808]BR02;DXP3000000H0Re:800<000000:O0j`2W`>/03P2W`>/00`000000Re:8
08]BR00=08]BR0030000003oool0oooo01P0oooo00<000000:O0j`2W`>/01`2W`>/200000?l0oooo
UP3oool002H0oooo00@000000?ooo`3oool00000203oool00`000000Yl3[0:O0j`040:O0j`<02NX:
2P2W`>/00`000000oooo0?ooo`040?ooo`030000002;DXP0000000H0Yl3[00<000000:O0j`2W`>/0
1P2W`>/400WZ2PX0Yl3[1@00000=0:O0j`@02NX:1P2W`>/00`000000Re:808]BR00208]BR0040000
003oool000000?ooo`<000000`3oool400WZ2PP0oooo00<0000008]BR02;DXP00`000000102;DXP0
000000000000000908]BR0030000003c[gh0ljmn0080ljmn00D0000008]BR02;DXP0Re:800000004
0:O0j`030000002W`>/0Yl3[00<02NX:00@0Yl3[00000000000000001@3oool9000000@0Re:800<0
000008]BR00000000`2;DXP5000000@0Re:80P0000030:O0j`030000002W`>/0Yl3[00T0Yl3[00<0
000008]BR02;DXP03`2;DXP300000080Re:800<0000008]BR02;DXP00`2;DXP00`000000Yl3[0:O0
j`0?0:O0j`030000002;DXP0Re:800`0Re:800<000000?ooo`3oool06P3oool00`000000Yl3[0:O0
j`060:O0j`800000o`3ooonF0?ooo`009P3oool010000000oooo0000000000090?ooo`030000002W
`>/0Yl3[00<02NX:3P2W`>/00`000000oooo0?ooo`030?ooo`030000002;DXP0000000H0Yl3[00<0
00000:O0j`2W`>/00P2W`>/400WZ2PT0Yl3[1@00000>0:O0j`@02NX:2P2W`>/200000080Re:800<0
00000?ooo`0000000P0000020?ooo`0400000009jPX02NX:00WZ2P`0oooo0`00000508]BR0030000
002;DXP0000000P0Re:800<000000?>_OP3c[gh00`3c[gh010000000Re:808]BR00000040:O0j`03
00000009jPX02NX:00H0Yl3[1`00000=08]BR0<000001`2;DXP6000000@0Yl3[00<000000:O0j`2W
`>/0202W`>/00`000000Re:808]BR00?08]BR0030000002;DXP0Re:800<0Re:800<0000008]BR02;
DXP00P2;DXP00`000000Yl3[0:O0j`0?0:O0j`030000002;DXP0Re:800`0Re:800<000000?ooo`3o
ool06`3oool00`000000Yl3[0:O0j`060:O0j`030000003oool0oooo0?l0ooooU03oool002H0oooo
0P0000000`3oool000000?ooo`080?ooo`80000000<02NX:0:O0j`2W`>/0402W`>/2000000<0oooo
00<0000008]BR00000001P2W`>/00`0000002NX:00WZ2P0200WZ2PP0Yl3[1@00000@0:O0j`<02NX:
3`2W`>/500000080oooo00D0000000WZ2P09jPX02NX:0000000;0?ooo`@000001`2;DXP00`000000
Re:80000000908]BR0030000003c[gh0ljmn0080ljmn00@0000008]BR02;DXP000000P2W`>/200WZ
2P030000002W`>/0Yl3[00<0Yl3[0`0000000`2W`>/000000?ooo`030?ooo`030000002;DXP0Re:8
00/0Re:80`00000;08]BR0<000000`2W`>/00`000000Yl3[0:O0j`070:O0j`030000002;DXP0Re:8
0140Re:800<0000008]BR02;DXP00P2;DXP01@000000Re:808]BR02;DXP000000180Yl3[00<00000
08]BR02;DXP0302;DXP00`000000oooo0?ooo`0L0?ooo`030000002W`>/0Yl3[00D0Yl3[00<00000
0?ooo`3oool0o`3ooonD0?ooo`009P3oool010000000oooo0?ooo`0000060?ooo`<02NX:0P00000E
0:O0j`040000003oool0oooo00000080Re:800<000000:O0j`09jPX00`09jPX00`2W`>/000000:O0
j`050:O0j`D000004@2W`>/400WZ2Q00Yl3[1P000000103oool02NX:00WZ2P09jPX30?ooo`030000
003oool0oooo00L0oooo0P0000030?ooo`030000002;DXP0Re:800D0Re:80`00000908]BR0030000
003c[gh0ljmn0080ljmn00@0000008]BR02;DXP000000P09jPX30:O0j`030000002W`>/000000080
00001@2W`>/00`000000oooo00000002000000d0Re:80P0000000`2;DXP0000008]BR00908]BR003
0000002W`>/000000080Yl3[2`00000D08]BR0030000002;DXP0Re:800<0Re:800<0000008]BR02;
DXP01P00000<0:O0j`030000002;DXP0Re:800d0Re:800<000000?ooo`3oool07@3oool00`000000
Yl3[0:O0j`030:O0j`800000o`3ooonF0?ooo`009P3oool01@000000oooo0?ooo`3oool000000080
oooo0`09jPX50?ooo`030000002W`>/0Yl3[01<0Yl3[0P0000001@2;DXP02NX:00WZ2P0000002NX:
00D0Yl3[00<000000:O0j`0000001000000C0:O0j`<02NX:4@2W`>/300000080Yl3[00<000000:O0
j`09jPX00P09jPX30?ooo`040000003oool0oooo000000H0oooo0`0000050?ooo`030000002;DXP0
Re:800D0Re:80P0000000`2;DXP0000008]BR00708]BR0030000003c[gh0ljmn00<0ljmn00<00000
08]BR00000001@2W`>/2000000P0Yl3[0P0000020?ooo`030000002;DXP0Re:800/0Re:80P000002
08]BR0030000002;DXP0Re:800L0Re:800<000000:O0j`0000000P0000000`3oool000000?ooo`07
0?ooo`030000002;DXP0Re:801<0Re:800<0000008]BR02;DXP00P2;DXP00`000000Re:800000006
0?ooo`X000000P2W`>/00`000000Re:808]BR00<08]BR0030000003oool0oooo01l0oooo00<00000
0:O0j`0000000P0000000`3oool000000?ooo`3o0?oooiD0oooo000V0?ooo`050000003oool0oooo
0?ooo`0000000P09jPX90?ooo`030000002W`>/0Yl3[0140Yl3[00@02NX:0000000000002NX:0P2;
DXP00`000000Yl3[0:O0j`040:O0j`800000502W`>/400WZ2Q00Yl3[100000040:O0j`802NX:00<0
000008]BR00000000P0000020?ooo`050000003oool0oooo0?ooo`0000000P3oool3000000H0oooo
0P09jPX00`000000Re:808]BR00608]BR0<000002@2;DXP00`000000ljmn0?>_OP020?>_OP800000
1P2W`>/00`000000Yl3[0:O0j`080:O0j`80000000<02NX:0000002;DXP02P2;DXP50000000308]B
R0000000Re:800P0Re:80P0000001@3oool000000?ooo`3oool0000000L0oooo00<0000008]BR02;
DXP0502;DXP00`000000Re:808]BR00308]BR0030000003oool0oooo00l0oooo0`00000>08]BR003
0000003oool0oooo0200oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?oooi@0
oooo000W0?ooo`0400000009jPX02NX:000000`0oooo00<000000:O0j`2W`>/03@2W`>/300WZ2P04
0:O0j`0000000000000000<0Re:800<000000:O0j`2W`>/00`2W`>/00`000000Yl3[0:O0j`0@0:O0
j`<02NX:4@2W`>/3000000D0Yl3[0`09jPX208]BR0030000002;DXP000000080Yl3[00<000000?oo
o`0000000P3oool4000000H0oooo0`09jPX20?ooo`030000002;DXP0Re:800<0Re:81@0000000`2;
DXP0000008]BR00708]BR0030000003c[gh0ljmn00<0ljmn0P0000060:O0j`030000002W`>/0Yl3[
00@0Yl3[0`09jPX400000080Re:82@0000001@2;DXP0000008]BR02;DXP000000080Re:80`000006
08]BR0070000003oool0oooo0?ooo`000000oooo000000070?ooo`030000002;DXP0Re:801D0Re:8
00<0000008]BR02;DXP00P2;DXP200000180oooo00<0000008]BR02;DXP0302;DXP00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3ooonD0?ooo`00903o
ool300WZ2P040000003oool0oooo000000d0oooo00<000000:O0j`2W`>/0202W`>/400WZ2PL0Yl3[
00D0000008]BR02;DXP0Re:8000000040:O0j`030000002W`>/0Yl3[00`0Yl3[1009jPXA0:O0j`<0
00001@2W`>/300WZ2PH0Re:80P0000030:O0j`030000003oool0000000<000001@3oool300WZ2PD0
oooo00@0000008]BR02;DXP0Re:80P00000308]BR0040000002;DXP00000000000T0Re:800<00000
0?>_OP3c[gh00`3c[gh4000000@0Yl3[00<000000:O0j`2W`>/00`09jPX20:O0j`L000002P2;DXP0
1`000000Re:808]BR02;DXP0000008]BR00000000P2;DXP3000000<0Re:800<000000?ooo`3oool0
0P3oool2000000H0oooo00<0000008]BR02;DXP05P2;DXP01`000000Re:808]BR02;DXP000000?oo
o`0000004P3oool00`000000Re:808]BR00<08]BR0030000003oool0oooo0200oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`3o0?oooi@0oooo000Q0?ooo`<02NX:0`3oool010000000
oooo0?ooo`00000=0?ooo`030000002W`>/0Yl3[00@0Yl3[1009jPX<0:O0j`050000002;DXP0Re:8
08]BR0000000102W`>/00`000000Yl3[0:O0j`070:O0j`@02NX:4@2W`>/4000000D0Yl3[0`09jPX9
08]BR08000000`2W`>/300000080oooo00<000000?ooo`3oool00`09jPX80?ooo`@000001@2;DXP0
1@000000Re:80000002;DXP0000000P0Re:800<000000?>_OP3c[gh0103c[gh00`000000Yl3[0:O0
j`03000000040:O0j`0000002NX:00WZ2PD000000P2W`>/00`000000Yl3[0000000;08]BR0030000
002;DXP0Re:800<0Re:800<0000008]BR0000000102;DXP4000000@0oooo2000000J08]BR0030000
002;DXP0000000<0oooo00<000000?ooo`3oool03`3oool00`000000Re:808]BR00;08]BR0030000
003oool0oooo0240oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?oooi@0oooo
000O0?ooo`802NX:1P3oool01@000000oooo0?ooo`3oool0000000d0oooo00<000000:O0j`2W`>/0
0`09jPXA0:O0j`040000002;DXP0Re:8000000@0Yl3[00<000000:O0j`2W`>/0102W`>/300WZ2Q80
Yl3[0`0000060:O0j`<02NX:302;DXP500000080Yl3[0`00000300WZ2PT0oooo0`00000908]BR080
000000<0Re:80000002;DXP0202;DXP00`000000ljmn0?>_OP030?>_OP030000002W`>/0Yl3[00@0
2NX:100000070:O0j`8000002`2;DXP00`000000Re:808]BR00308]BR0040000002;DXP0Re:80000
00H0Re:81@0000000`3oool000000?ooo`040?ooo`030000002;DXP0Re:801P0Re:800@0000008]B
R000000000000P3oool00`000000oooo0?ooo`0?0?ooo`030000002;DXP0Re:800/0Re:800<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0ooooU03oool0
01`0oooo0`09jPX80?ooo`050000003oool0oooo0?ooo`0000003@3oool00`09jPX0000000WZ2P0E
0:O0j`040000002;DXP0Re:8000000<0Yl3[00<000000:O0j`2W`>/01009jPXA0:O0j`@000001P2W
`>/300WZ2Pl0Re:80P0000040:O0j`@02NX:00<0oooo0000003oool01`3oool2000000030?ooo`00
0000Re:800T0Re:800<0000008]BR00000000P00000808]BR0030000003c[gh0ljmn00@0ljmn00<0
000000WZ2P2W`>/0102W`>/00`000000Yl3[0:O0j`05000000<0Yl3[00<0000008]BR02;DXP02@2;
DXP00`000000Re:808]BR00408]BR0030000002;DXP0000000H0Re:80P0000000`3oool000000000
0002000000@0oooo00<0000008]BR02;DXP06P2;DXP00`000000oooo0?ooo`05000000l0oooo00<0
000008]BR02;DXP02`2;DXP00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0o`3ooonD0?ooo`006@3oool300WZ2P/0oooo00D000000?ooo`3oool0oooo0000
000:0?ooo`<02NX:00<0oooo0000000000005P2W`>/010000000Re:808]BR00000020:O0j`030000
0009jPX02NX:0180Yl3[0`0000070:O0j`<02NX:3`2;DXP30000000308]BR0000000Yl3[00<02NX:
102W`>/2000000D0oooo0`0000030?ooo`030000002;DXP0Re:800P0Re:80`0000000`2;DXP00000
08]BR00808]BR0030000003c[gh0ljmn00<0ljmn00<000000:O0j`2W`>/01@2W`>/00`000000Yl3[
0:O0j`030:O0jaT0000000<0Re:80000002;DXP0102;DXP00`000000oooo0?ooo`020?ooo`<00000
0`3oool00`000000Re:808]BR00J08]BR0030000003oool000000080000000<0oooo0000003oool0
1@00000:0?ooo`030000002;DXP0Re:800X0Re:800<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0?l0ooooU03oool001H0oooo0`09jPX>0?ooo`050000003o
ool0oooo0?ooo`0000001`3oool300WZ2PH0oooo00<000000:O0j`2W`>/0502W`>/40000000300WZ
2P2W`>/0000000l0Yl3[100000070:O0j`<02NX:3`2;DXP3000000@0Re:800<0000000WZ2P2W`>/0
202W`>/00`000000oooo0?ooo`02000000H0oooo00<0000008]BR02;DXP01`2;DXP400000080Re:8
00<0000008]BR02;DXP01`2;DXP00`000000ljmn0?>_OP030?>_OP030000002W`>/0Yl3[00D0Yl3[
00<000000:O0j`2W`>/00`2W`>/30000000308]BR0000000Re:800P0Re:800<0000008]BR02;DXP0
1P2;DXP00`000000Re:808]BR002000000<0Re:800<000000?ooo`3oool00P3oool00`000000oooo
000000020?ooo`030000002;DXP0Re:801X0Re:800<000000?ooo`0000001@3oool00`000000oooo
0?ooo`030?ooo`D000001@3oool00`000000Re:808]BR00:08]BR0030000003oool0oooo0240oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?oooi@0oooo000C0?ooo`<02NX:4P3o
ool010000000oooo0?ooo`0000040?ooo`<02NX:2@3oool00`000000Yl3[0:O0j`0B0:O0j`802NX:
100000020:O0j`030000002W`>/0Yl3[00X0Yl3[0`0000080:O0j`<02NX:402;DXP2000000L0Re:8
0P0000090:O0j`<000001@3oool300WZ2P030000002;DXP0Re:800@0Re:80`00000208]BR0030000
002;DXP000000080Re:800<0000008]BR02;DXP01P2;DXP00`000000ljmn0?>_OP030?>_OP030000
002W`>/0Yl3[00D0Yl3[00<000000:O0j`2W`>/00`0000020:O0j`040000002;DXP0Re:8000000L0
Re:800<0000008]BR02;DXP0202;DXP010000000Re:80000002;DXP4000000<0oooo1P00000L08]B
R0040000003oool0oooo000000H0oooo00<000000?ooo`3oool01`3oool6000000`0Re:800<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0ooooU03oool0
0100oooo0`09jPXE0?ooo`050000003oool0oooo0?ooo`0000000`09jPX=0?ooo`030000002W`>/0
Yl3[00h0Yl3[0`09jPX40:O0j`050000002;DXP000000:O0j`0000002@2W`>/3000000P0Yl3[0`09
jPX@08]BR0<000002@2;DXP2000000H0Yl3[0`0000030:O0j`8000000`09jPX30?ooo`030000002;
DXP0Re:80080Re:80P00000508]BR0060000002;DXP0Re:80000002;DXP000002@2;DXP00`000000
ljmn0?>_OP030?>_OP030000002W`>/0Yl3[00D0Yl3[0P0000050:O0j`050000002;DXP0Re:808]B
R00000001P2;DXP00`000000Re:808]BR00908]BR0030000002;DXP0000000<0Re:810000000103o
ool000000?ooo`3oool2000001`0Re:80P0000020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0303oool00`000000Re:808]BR00908]BR0030000003oool0oooo0280oooo00<00000
0?ooo`3oool01000003o0?oooiH0oooo000=0?ooo`<02NX:603oool00`000000oooo000000020000
0140oooo00<000000:O0j`2W`>/02@2W`>/400WZ2PP0Yl3[00@0000008]BR000000000001@2W`>/4
000000P0Yl3[0`09jPXA08]BR0800000302;DXP2000000@0Yl3[0P0000060:O0j`802NX:0P000004
0?ooo`030000002;DXP0Re:800800000202;DXP010000000Re:80000002;DXP2000000P0Re:800<0
00000?>_OP3c[gh0103c[gh00`000000Yl3[0:O0j`050:O0j`040000002W`>/0Yl3[0:O0j`<00000
102;DXP00`000000Re:808]BR00308]BR0030000002;DXP0Re:800X0Re:800<0000008]BR0000000
0P2;DXP00`000000oooo0000000300000080oooo0P00000K08]BR0030000003oool0oooo00@00000
1@3oool00`000000oooo0?ooo`0;0?ooo`030000002;DXP0Re:800T0Re:800<000000?ooo`3oool0
8P3oool3000000<0oooo00<000000?ooo`3oool0o`3ooonD0?ooo`00303oool00`09jPX0oooo0?oo
o`0H0?ooo`0300WZ2P00000000000080oooo00<000000?ooo`3oool0403oool00`000000Yl3[0:O0
j`040:O0j`@02NX:3@2W`>/01@000000Re:8000000000000Yl3[00<000002@2W`>/300WZ2Q40Re:8
0`00000?08]BR0D000001@2W`>/300WZ2P@0Yl3[0P0000020?ooo`<000002`2;DXP30000000308]B
R0000000Re:800P0Re:800<000000?>_OP3c[gh0103c[gh00`000000Yl3[0:O0j`050:O0j`030000
002W`>/000000080oooo00@0000008]BR02;DXP0Re:85P000000102;DXP0000008]BR00000030?oo
o`@000000P2;DXP00`000000Re:808]BR00G08]BR0030000003oool0oooo00@0oooo100000030?oo
o`030000003oool0oooo00X0oooo00<0000008]BR02;DXP02@2;DXP00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3ooonD0?ooo`00903oool300WZ2P03
0?ooo`000000oooo0080oooo00<000000?ooo`3oool04@3oool00`000000Yl3[0:O0j`0300WZ2Q80
Yl3[00@0000008]BR000000000002@2W`>/300WZ2Q40Re:80`00000B08]BR08000001P2W`>/200WZ
2PT0Yl3[0`00000<08]BR080000000D0Re:80000002;DXP0Re:80000000808]BR08000001P3c[gh0
0`000000Yl3[0:O0j`040:O0j`8000000P3oool5000000<0Re:800@0000008]BR02;DXP000003P2;
DXP00`000000Re:808]BR002000000030?ooo`000000000000D0000000<0Re:80000002;DXP0602;
DXP00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@000002`3oool00`000000Re:808]B
R00908]BR0030000003oool0oooo02<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`3o0?oooiD0oooo000Q0?ooo`<02NX:103oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0100oooo00<02NX:00000009jPX05P2W`>/3000000H0Yl3[0`09jPXB08]BR08000004`2;DXP4
000000<0Yl3[0`09jPX90:O0j`8000000P2W`>/00`000000Re:808]BR00808]BR08000000P2;DXP0
0`000000Re:80000000208]BR0030000002;DXP0Re:800D0Re:800<000000:O0j`0000001P3c[gh0
10000000Yl3[0:O0j`2W`>/200000080oooo0P0000000`3oool0000008]BR00608]BR0030000002;
DXP0000000l0Re:800<0000008]BR00000000`000000103oool000000?ooo`00000208]BR0<00000
5`2;DXP00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo100000070?ooo`030000
002;DXP0Re:800T0Re:800<000000?ooo`3oool08`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0?l0ooooU@3oool001h0oooo0`09jPX80?ooo`050000003oool0oooo0?ooo`000000
3`3oool300WZ2P030?ooo`000000000001L0Yl3[10000000102W`>/02NX:00WZ2P09jPXB08]BR0<0
00004`2;DXP200000080Re:800<000000:O0j`0000000P09jPX:0:O0j`800000102W`>/00`000000
Re:808]BR00608]BR0800000102;DXP01P000000Re:808]BR0000000Re:8000000L0Re:800@00000
0:O0j`2W`>/000001P3c[gh3000000@0oooo00@000000?ooo`3oool000001`2;DXP<000000L0Re:8
0P0000000`3oool000000?ooo`03000000H0Re:800<0000008]BR02;DXP04`2;DXP4000000L0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`3oool3000000@0oooo00<0000008]BR02;
DXP02@2;DXP00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0o`3ooonE0?ooo`006`3oool300WZ2P/0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`<0
2NX:1P3oool00`000000Yl3[0:O0j`0D0:O0j`0300WZ2P0000002NX:00802NX:4`2;DXP2000001@0
Re:80P00000408]BR00300000009jPX0000000X0Yl3[0P0000060:O0j`030000002;DXP0Re:800@0
Re:80P00000708]BR0030000002;DXP0000000<000001P2;DXP010000000Yl3[0:O0j`0000080?>_
OP030000003oool0oooo00<0oooo0`00000408]BR0<0000000<0oooo0000000000001P3c[gh00`00
0000oooo0?ooo`09000000030?ooo`000000000000@000001@2;DXP00`000000Re:808]BR00B08]B
R0030000003oool0oooo0080oooo0`0000050?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool5000000X0Re:800<000000?ooo`3oool0903oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0?l0ooooU@3oool001P0oooo0`09jPX>0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01P3oool300WZ2PX0oooo00<000000:O0j`2W`>/0402W`>/300WZ2P04
08]BR0000000000000000140Re:80`00000D08]BR08000001`2;DXP00`000000Yl3[000000070:O0
j`8000001P2W`>/200WZ2P030000002;DXP0Re:80080Re:80P00000908]BR08000000P2;DXP20000
00H0Re:800D000000:O0j`2W`>/0Yl3[000000080?>_OP8000000P3oool40000000308]BR0000000
0000008000000`3oool00`000000ljmn000000050?>_OP030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00`000000103oool0000000000000000208]BR0800000102;DXP00`000000Re:808]B
R00@08]BR0030000003oool0oooo00H0oooo0`0000020?ooo`040000003oool0oooo0?ooo`@00000
203oool00`000000Re:808]BR00808]BR0030000003oool0oooo02<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`3o0?oooiD0oooo000E0?ooo`<02NX:4P3oool01@000000oooo0?oo
o`3oool0000000H0oooo0P09jPX>0?ooo`030000002W`>/0Yl3[00`0Yl3[0`09jPX408]BR0<00000
3P2;DXP3000001D0Re:80P00000908]BR0040000002W`>/0Yl3[000000<0Yl3[0`0000060:O0j`80
2NX:0P2W`>/00`000000Re:808]BR002000000X0Re:800@0000008]BR02;DXP000000P2;DXP20000
00D0Re:800<000000:O0j`2W`>/00P2W`>/00`000000ljmn0?>_OP070?>_OP8000000`3oool40000
00030?ooo`000000oooo008000000P3c[gh7000000D0oooo100000030?ooo`030000003oool0oooo
00<000000P2;DXP2000000<0Re:800<0000008]BR02;DXP03`2;DXP00`000000oooo0?ooo`090?oo
o`H000000`3oool00`000000oooo0?ooo`060?ooo`030000002;DXP0Re:800P0Re:800<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0ooooUP3oool001@0
oooo00<02NX:0?ooo`3oool04`3oool01@000000oooo0?ooo`3oool0000000<0oooo0`09jPXA0?oo
o`030000002W`>/0Yl3[00P0Yl3[0`09jPX708]BR0<00000302;DXP2000001H0Re:80P00000<08]B
R0040000002W`>/000000:O0j`8000001`2W`>/200WZ2P@0Yl3[0`00000:08]BR0800000102;DXP2
0000000308]BR0000000000000@0Re:80P0000030:O0j`030000003c[gh0ljmn00P0ljmn0P000003
0?ooo`030000003oool0000000<0000000@0ljmn00000000000000000`3c[gh010000000ljmn0000
003ooolD00000080Re:80P00000208]BR0030000002;DXP0Re:800d0Re:81000000<0?ooo`@00000
0`3oool00`000000oooo0?ooo`050?ooo`030000002;DXP0Re:800L0Re:800<000000?ooo`3oool0
903oool010000000oooo0?ooo`3oool200000?l0ooooV03oool002X0oooo00D000000?ooo`3oool0
oooo0000000300WZ2QD0oooo00<000000:O0j`2W`>/0102W`>/300WZ2PX0Re:80`00000908]BR0<0
00005P2;DXP2000000h0Re:800@000000:O0j`00000000001P2W`>/300WZ2P@0Yl3[0`00000:08]B
R0800000202;DXP4000000<0Re:800H000000?ooo`000000Yl3[0000003oool2000000X0ljmn0`00
00000`3oool0000000000004000000H0ljmn1`0000000`3oool0000000000003000000030?ooo`00
0000000000@0000000<0oooo0000000000000P00000308]BR0<000003P2;DXP00`000000oooo0?oo
o`020?ooo`<000002P3oool00`000000oooo0?ooo`03000000030?ooo`000000oooo00D0oooo00<0
000008]BR02;DXP01`2;DXP00`000000oooo0?ooo`0T0?ooo`@0000000<0oooo0000003oool0o`3o
oonG0?ooo`00:P3oool00`000000oooo00WZ2P0200WZ2P030000003oool0oooo01H0oooo00<00000
0:O0j`2W`>/00`09jPX=08]BR0030000002W`>/0000000L0Re:80P00000G08]BR0800000402;DXP2
000000030:O0j`000000Yl3[00<0Yl3[0P09jPX50:O0j`8000000P2W`>/00`000000Re:808]BR006
08]BR08000002@2;DXP40000000508]BR0000000Re:80000002W`>/00`0000040?ooo`030000003c
[gh0ljmn00X0ljmn00@000000?>_OP00000000001P3c[gh3000000040?>_OP000000oooo0?oooa@0
000000<0oooo0000000000000`2;DXP2000000`0Re:800<000000?ooo`3oool01P3oool2000000T0
oooo00<000000?ooo`3oool00P3oool3000000D0oooo00<0000008]BR02;DXP01`2;DXP00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3ooonF0?ooo`00
:@3oool200WZ2P050000003oool0oooo0?ooo`000000603oool00`09jPX0000000WZ2P0@08]BR003
0000002W`>/0000000@0Re:80`00000G08]BR08000004@2;DXP00`000000Re:8000000020:O0j`04
0000002W`>/02NX:00WZ2PD0Yl3[0P0000040:O0j`030000002;DXP0Re:800D0Re:800<0000008]B
R02;DXP0202;DXP00`000000Re:808]BR00208]BR0040000002;DXP00000000000<0Yl3[00<00000
0?ooo`3oool00`3oool00`000000ljmn0?>_OP0=0?>_OP80000000@0ljmn0000000000000000103c
[gh3000000030?ooo`000000000001H000000`2;DXP00`000000Re:808]BR00808]BR08000002P3o
ool3000000L0oooo00<000000?ooo`3oool0103oool3000000030?ooo`000000000000P0Re:800<0
00000?ooo`3oool09@3oool01@000000oooo0?ooo`3oool000000?l0ooooV@3oool002L0oooo0P09
jPX20?ooo`050000003oool0oooo0?ooo`0000005@3oool300WZ2P030?ooo`00000000000100Re:8
00@000000:O0j`000000Re:80`00000H08]BR08000004@2;DXP200000080Re:800D000000:O0j`2W
`>/0000000WZ2P050:O0j`8000001P2W`>/00`000000Re:808]BR00308]BR08000002@2;DXP20000
00H0Re:800D0000008]BR000000000000:O0j`02000000@0oooo0`00000@0?>_OP<000000P3c[gh3
00000080oooo1P0000060?oooa0000000P2;DXP00`000000Re:808]BR00608]BR0030000003oool0
oooo00<000002P3oool3000000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
000000P0Re:800<000000?ooo`3oool09@3oool01@000000oooo0?ooo`3oool000000?l0ooooV@3o
ool002@0oooo0`09jPX40?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool3
00WZ2P@0oooo00<0000008]BR02;DXP03`2;DXP010000000Yl3[00000000000H08]BR0<000004@2;
DXP2000000D0Re:800@0000000WZ2P2W`>/000000`2W`>/2000000P0Yl3[00@0000008]BR02;DXP0
Re:80P00000908]BR0800000202;DXP200000080Yl3[00<000000?ooo`0000000`3oool01@000000
oooo0?ooo`3oool000000180ljmn0`0000000`3c[gh0000000000002000001@0oooo2@0000000`2;
DXP0000008]BR00608]BR0030000003oool0oooo00<0oooo0P00000;0?ooo`8000000`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00800000202;DXP00`000000oooo0?ooo`0T0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3ooonG0?ooo`008@3oool300WZ2PP0
oooo00<000000?ooo`0000000P00000>0?ooo`<02NX:1`3oool00`000000Re:808]BR00?08]BR004
00000009jPX00000000001H0Re:80P00000B08]BR08000001`2;DXP01@000000Yl3[0:O0j`000000
Yl3[008000002P2W`>/010000000Re:800000000000908]BR08000002@2;DXP01@000000Yl3[0:O0
j`000000Yl3[00<0000000<0oooo0000000000001@3oool00`000000ljmn0?>_OP0B0?>_OP800000
703oool50000000308]BR0000000Re:800@0Re:80`0000060?ooo`<000002P3oool3000000030?oo
o`000000oooo00D0oooo0P0000000`3oool0000008]BR00608]BR0030000003oool0oooo02D0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?oooiL0oooo000N0?ooo`<02NX:2`3o
ool200000080oooo00<000000?ooo`3oool02@3oool300WZ2PX0oooo00<0000008]BR02;DXP03`2;
DXP01@000000Yl3[0000002;DXP0000001<0Re:80P00000C08]BR0030000002;DXP0Re:800P0Re:8
00@000000:O0j`0000000000302W`>/2000000X0Re:800<0000008]BR02;DXP01`2;DXP2000000@0
Yl3[00<000000?ooo`0000000P0000060?ooo`040000003oool0000000000180ljmn00<000000?oo
o`3oool07@3oool6000000<0Re:800@000000?ooo`3oool0oooo0`0000060?ooo`8000002`3oool3
000000<0oooo100000000`3oool0000008]BR00608]BR0030000003oool0oooo02D0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?oooiL0oooo000M0?ooo`0300WZ2P3oool0oooo
00`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`<02NX:3@3oool00`00
0000Re:808]BR00?08]BR0050000002W`>/0000008]BR00000004@2;DXP2000001<0Re:80P00000;
08]BR080000000<0Yl3[0000002W`>/02P2W`>/2000000T0Re:80P00000808]BR08000001P2W`>/4
000000030?ooo`000000oooo00<0oooo00H000000?ooo`3oool000000?ooo`00000?0?>_OP800000
8P3oool50000000308]BR0000000oooo00800000103oool2000000H0oooo0`00000:0?ooo`@00000
0`3oool3000000H0Re:800<000000?ooo`3oool09P3oool01@000000oooo0?ooo`3oool000000?l0
ooooVP3oool002d0oooo00D000000?ooo`3oool0oooo000000040?ooo`<02NX:403oool00`000000
Re:808]BR00?08]BR0050000002W`>/0000008]BR00000003`2;DXP2000001<0Re:80P00000<08]B
R08000000`2W`>/00`000000Yl3[0:O0j`060:O0j`80000000<0Yl3[0000002;DXP01P2;DXP20000
00T0Re:800<000000:O0j`2W`>/01@2W`>/01P000000oooo0?ooo`3oool000000?ooo`D000000P3o
ool00`000000oooo0?ooo`02000000d0ljmn00<000000?ooo`3oool08`3oool5000000@0oooo0P00
00040?ooo`8000001`3oool3000000P0oooo00<000000?ooo`0000000`0000000`3oool000000000
000608]BR0030000003oool0oooo02D0oooo00<000000?ooo`3oool00`00003o0?oooiX0oooo000]
0?ooo`060000003oool0oooo0?ooo`000000oooo0`09jPXC0?ooo`030000002;DXP0Re:800l0Re:8
00<000000:O0j`0000000P2;DXP00`000000Re:808]BR00:08]BR08000004`2;DXP2000000d0Re:8
00@0000008]BR02;DXP000000`2W`>/00`000000Yl3[0:O0j`030:O0j`8000000`2W`>/00`000000
Re:808]BR00308]BR08000002@2;DXP2000000H0Yl3[0P0000030?ooo`X000000P3oool6000000P0
ljmn0P00000X0?ooo`D00000103oool2000000@0oooo0P0000080?ooo`8000001`3oool02@000000
oooo0?ooo`3oool000000?ooo`000000Re:80000000508]BR0030000003oool0oooo02D0oooo0`00
00020?ooo`030000003oool0oooo0?l0ooooV03oool002d0oooo00<000000?ooo`3oool00P09jPX0
0`000000oooo0?ooo`0D0?ooo`030000002;DXP0Re:800l0Re:800<000000:O0j`0000000P2;DXP0
0`000000Re:808]BR00808]BR0800000502;DXP00`000000Re:808]BR00<08]BR0030000002;DXP0
Re:80080Re:800@000000:O0j`2W`>/00000102W`>/00`000000Yl3[0:O0j`020:O0j`030000002;
DXP0Re:800<0Re:800<0000008]BR02;DXP0202;DXP00`000000Yl3[0:O0j`050:O0j`030000002W
`>/0000000<0oooo0P0000000`3oool000000000000:000000<0oooo0`0000020?>_OP<00000;03o
ool5000000@0oooo0P0000040?ooo`<000001`3oool3000000D0oooo00H000000?ooo`3oool00000
0?ooo`00000208]BR0050000002;DXP0Re:808]BR0000000:03oool01@000000oooo0?ooo`3oool0
00000?l0ooooV`3oool002d0oooo00<02NX:00000009jPX00P3oool00`000000oooo0?ooo`0D0?oo
o`030000002;DXP0Re:800l0Re:800<000000:O0j`0000000P2;DXP00`000000Re:808]BR00608]B
R0800000502;DXP2000000d0Re:80P00000608]BR0050000002W`>/0Yl3[0000002W`>/00P000005
0:O0j`040000002;DXP0Re:808]BR08000002@2;DXP2000000H0Yl3[0P000000102W`>/000000?oo
o`3oool3000000030?ooo`00000000000080oooo0P000000103oool000000000000000090?ooo`80
0000<@3oool5000000@0oooo0P0000050?ooo`800000203oool2000000@0oooo0P0000020?ooo`05
0000002;DXP0Re:808]BR00000000P2;DXP00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0o`3ooonI0?ooo`00:P3oool300WZ2P030?ooo`000000oooo0080
oooo00<000000?ooo`3oool04P3oool200WZ2P030000002;DXP0Re:800l0Re:800@000000:O0j`2W
`>/000000P2;DXP00`000000Re:808]BR00308]BR0800000502;DXP2000000h0Re:800<0000008]B
R02;DXP01`2;DXP010000000Yl3[0000000000070:O0j`040000002;DXP00000000000T0Re:80P00
00070:O0j`080000002W`>/0Yl3[0:O0j`000000oooo0000003oool4000000050?ooo`0000000000
0000003oool00`00000n0?ooo`H00000103oool2000000D0oooo0P0000080?ooo`<0000000<0oooo
0000000000000P3oool00`000000Re:808]BR00208]BR0030000002;DXP0000002L0oooo00D00000
0?ooo`3oool0oooo0000003o0?oooi`0oooo000W0?ooo`<02NX:103oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00h0oooo0`09jPX20?ooo`030000002;DXP0Re:800l0Re:800@00000
0:O0j`2W`>/000000P2;DXP010000000Re:808]BR02;DXP2000001@0Re:80P00000>08]BR0800000
2`2;DXP010000000Yl3[0:O0j`0000060:O0j`8000002P2;DXP00`000000Yl3[0:O0j`050:O0j`80
00000`2W`>/3000000030?ooo`000000oooo0080000000<0oooo0000000000001@0000110?ooo`H0
0000103oool2000000D0oooo0P0000080?ooo`8000000P3oool00`000000oooo0000000408]BR080
00009`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0ooooVP3oool002D0oooo
0P09jPX80?ooo`050000003oool0oooo0?ooo`0000003@3oool300WZ2PD0oooo00<0000008]BR02;
DXP03`2;DXP010000000Yl3[0:O0j`00000208]BR0040000002;DXP00000000001@0Re:80P00000?
08]BR0030000002;DXP0Re:800X0Re:800<0000008]BR00000000P2W`>/00`000000Yl3[0:O0j`02
0:O0j`8000002@2;DXP2000000L0Yl3[00<000000:O0j`2W`>/00P2W`>/200000080oooo00<00000
0?ooo`00000010000000103oool000000000000000150?ooo`H00000103oool2000000D0oooo0`00
00040?ooo`030000003oool0oooo00<0oooo0P000000102;DXP000000000000000020?ooo`030000
003oool0oooo02@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?oooiX0oooo
000_0?ooo`050000003oool0oooo0?ooo`0000002P3oool300WZ2PP0oooo00<0000008]BR02;DXP0
3`2;DXP010000000Yl3[00WZ2P00000308]BR0030000002;DXP0Re:801<0Re:800<0000008]BR02;
DXP03P2;DXP00`000000Re:808]BR00:08]BR0040000002;DXP0Re:808]BR080000000<0Yl3[0000
002W`>/00P0000000`2W`>/0000008]BR00708]BR0030000002W`>/0Yl3[00D0Yl3[0P0000040:O0
j`8000000`3oool6000000040?ooo`0000000000000004P0oooo0`0000000`3oool0000000000004
0?ooo`8000001P3oool2000000030?ooo`000000oooo00H0oooo0P0000060?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`0000000P00003o0?oooid0oooo000_0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0103oool300WZ2P/0oooo00<0000008]BR02;DXP03`2;DXP01000
00002NX:0:O0j`00000308]BR0030000002;DXP0Re:80140Re:80P00000?08]BR0800000302;DXP0
0`000000Re:808]BR00408]BR0<000000`2W`>/00`000000Re:808]BR00408]BR08000001P2W`>/2
000000D0Yl3[0P0000030?ooo`80000000@0oooo000000000000oooo1000001;0?ooo`<0000000<0
oooo000000000000103oool2000000D0oooo0P00000:0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool08@3oool300000080oooo00<000000?ooo`3oool0o`3ooonK0?ooo`00<03oool0
1@000000oooo0?ooo`3oool0000000<0oooo0`09jPX>0?ooo`030000002;DXP0Re:800l0Re:81@00
000308]BR0030000002;DXP0Re:800h0Re:80P00000@08]BR0030000002;DXP0Re:800X0Re:80P00
000708]BR0<000000`2W`>/00`000000Re:808]BR00308]BR0030000002W`>/0Yl3[00D0Yl3[00<0
00000:O0j`2W`>/00`2W`>/3000000<0oooo0P000000103oool000000000003oool3000004l0oooo
0`0000000`3oool00000000000040?ooo`80000000<0oooo0000000000003@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0200oooo00D000000?ooo`3oool0oooo0000003o0?oooih0
oooo000`0?ooo`050000003oool0oooo0?ooo`0000000`09jPXA0?ooo`030000002;DXP0Re:800l0
Re:800D000000?ooo`3oool0oooo0000000308]BR0030000002;DXP0Re:800`0Re:80P00000@08]B
R0800000302;DXP00`000000Re:808]BR00608]BR0030000002;DXP0Re:8008000000P2W`>/01000
0000Re:808]BR02;DXP2000000H0Yl3[0P0000050:O0j`040000002W`>/0Yl3[00000080oooo0P00
00000`3oool0000000000004000005<0oooo1@0000020?ooo`<00000403oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo01h0oooo00D000000?ooo`3oool0oooo0000003o0?oooil0oooo
000`0?ooo`040000003oool02NX:00WZ2P8000004`3oool00`000000Re:808]BR00>08]BR0030000
003oool0oooo0080oooo00<0000008]BR02;DXP00P2;DXP00`000000Re:808]BR00:08]BR0030000
002;DXP0Re:800l0Re:800<0000008]BR02;DXP02`2;DXP00`000000Re:808]BR00608]BR0030000
002;DXP0Re:800<0Re:800@000000:O0j`000000Re:80P0000070:O0j`030000002W`>/0Yl3[00@0
Yl3[00D000000:O0j`2W`>/000000?ooo`02000000030?ooo`000000000000D00000F03oool30000
01@0oooo00<000000?ooo`3oool00`3oool3000001d0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`3o0?oooid0oooo000_0?ooo`802NX:0`0000000`3oool000000?ooo`0B0?ooo`03
0000002;DXP0Re:800h0Re:800<000000?ooo`3oool00P3oool00`000000Re:808]BR00208]BR003
0000002;DXP0Re:800P0Re:80P00000@08]BR08000003@2;DXP00`000000Re:808]BR00608]BR003
0000002;DXP0Re:800D0Re:80`0000070:O0j`8000001@2W`>/2000000<0Yl3[0P0000020?ooo`L0
0000L@3oool00`000000oooo00000002000000<0oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`0200000?l0ooooX03oool002d0oooo0P09jPX20?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0403oool00`000000Re:808]BR00>08]BR0030000003oool0oooo0080oooo
00<0000008]BR02;DXP00`2;DXP00`000000Re:808]BR00508]BR08000004@2;DXP00`000000Re:8
08]BR00;08]BR0800000202;DXP00`000000Re:808]BR00708]BR08000001P2W`>/00`000000Yl3[
0:O0j`040:O0j`030000002W`>/0Yl3[0080Yl3[0P0000020?ooo`80000000@0oooo000000000000
0000M03oool2000000H0oooo0P00000I0?ooo`@00000o`3ooonR0?ooo`00<@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00d0oooo0`09jPX00`000000Re:808]BR00>08]BR0030000
003oool0oooo00<0oooo00<0000008]BR02;DXP00P2;DXP00`000000Re:808]BR00308]BR0800000
4P2;DXP00`000000Re:808]BR00;08]BR0030000002;DXP0Re:800L0Re:800<0000008]BR02;DXP0
202;DXP00`000000Yl3[000000030:O0j`8000001@2W`>/2000000@0Yl3[0P0000020?ooo`800000
00@0oooo0000000000000000M`3oool2000000H0oooo00<000000?ooo`3oool05@3oool200000003
0?ooo`000000oooo0?l0ooooXP3oool00380oooo00D000000?ooo`3oool0oooo0000000<0?ooo`<0
2NX:0`3oool00`000000Re:808]BR00>08]BR0030000003oool0oooo00<0oooo00<0000008]BR02;
DXP00`2;DXP01@000000Re:808]BR02;DXP000000180Re:80P00000=08]BR0030000002;DXP0Re:8
00L0Re:800<0000008]BR02;DXP0202;DXP01`000000Yl3[0:O0j`2W`>/000000:O0j`0000001P2W
`>/00`000000Yl3[0:O0j`030:O0j`80000000D0oooo00000000000000000?ooo`03000007X0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0C0?ooo`040000003oool0oooo00000?l0
ooooY03oool00380oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`<02NX:
1P3oool00`000000Re:808]BR00>08]BR0030000003oool0oooo00<0oooo00<0000008]BR02;DXP0
0`2;DXP010000000Re:800000000000B08]BR0030000002;DXP0Re:800`0Re:800<0000008]BR02;
DXP01`2;DXP00`000000Re:808]BR00808]BR0030000002W`>/0Yl3[00<0Yl3[0P0000040:O0j`80
00001@2W`>/2000000040?ooo`000000oooo0?ooo`@00000O03oool2000000<0oooo1@00000A0?oo
o`040000003oool0000000000?l0ooooY@3oool003<0oooo00D000000?ooo`3oool0oooo00000005
0?ooo`<02NX:2@3oool00`000000Re:808]BR00>08]BR0030000003oool0oooo00@02NX:00<00000
08]BR02;DXP00`2;DXP00`000000Re:808]BR00@08]BR08000003P2;DXP00`000000Re:808]BR007
08]BR0030000002;DXP0Re:800P0Re:800<000000?ooo`000000200000000`2W`>/000000:O0j`04
0:O0j`80000000<0Yl3[0000000000000P3oool010000000oooo00000000001o0?ooo`<000001@3o
ool3000000d0oooo0`00003o0?ooojL0oooo000c0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool300WZ2P`0oooo00<0000008]BR02;DXP03P2;DXP00`0000002NX:00WZ2P040?ooo`030000002;
DXP0Re:800<0Re:800<0000008]BR02;DXP03`2;DXP00`000000Re:808]BR00<08]BR08000002@2;
DXP00`000000Re:808]BR00808]BR0030000003oool0oooo00@0oooo00<000000?ooo`3oool01`00
00001@2W`>/000000:O0j`2W`>/0000000<0oooo1@0000210?ooo`8000001P3oool6000000H0oooo
0`00003o0?ooojT0oooo000d0?ooo`060000003oool0oooo00WZ2P0000002NX:3`3oool00`000000
Re:808]BR00>08]BR0030000003oool0oooo00@0oooo00<0000008]BR02;DXP0102;DXP00`000000
Re:808]BR00=08]BR0030000002;DXP0Re:800`0Re:800<0000008]BR02;DXP0202;DXP00`000000
Re:808]BR00808]BR08000001@3oool00`000000oooo0?ooo`030?ooo`050000003oool000000000
003oool0100000030?ooo`<0000000<0oooo0000003oool0P`3oool2000000040?ooo`0000000000
000000H0oooo2000003o0?ooojX0oooo000d0?ooo`0500000009jPX02NX:0?ooo`000000403oool0
0`000000Re:808]BR00>08]BR0030000003oool0oooo00@0oooo00<0000008]BR02;DXP01@2;DXP0
0`000000Re:808]BR00:08]BR08000003P2;DXP00`000000Re:808]BR00808]BR0030000002;DXP0
Re:800P0Re:800<000000?ooo`000000103oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo3@0000260?ooo`@00000103oool700000?l0oooo[@3oool003@0oooo00D000000?oo
o`3oool0oooo0000000@0?ooo`030000002;DXP0Re:800h0Re:800<000000?ooo`3oool01@3oool0
0`000000Re:808]BR00408]BR0030000002;DXP0Re:800T0Re:800<0000008]BR02;DXP03@2;DXP0
0`000000Re:808]BR00808]BR0030000002;DXP0Re:800P0Re:800D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0200000080oooo1@00002;0?ooo`D00000o`3ooonc0?ooo`00=@3oool01@000000oooo0?ooo`3o
ool0000000l0oooo00<0000008]BR02;DXP03P2;DXP00`000000oooo0?ooo`050?ooo`030000002;
DXP0Re:800D0Re:800<0000008]BR02;DXP01P2;DXP2000000h0Re:80P00000:08]BR0030000002;
DXP0Re:800P0Re:800<000000?ooo`0000000P3oool00`000000oooo000000050?ooo`030000003o
ool0oooo00<0oooo00T000000?ooo`3oool000000?ooo`000000oooo0000003oool01000003o0?oo
ool0ooooA03oool003D0oooo00D000000?ooo`3oool0oooo0000000>0?ooo`0300WZ2P000000Re:8
00l0Re:800<000000?ooo`3oool01@3oool00`000000Re:808]BR00508]BR0030000002;DXP0Re:8
00D0Re:800<0000008]BR02;DXP03@2;DXP00`000000Re:808]BR00908]BR0030000002;DXP0Re:8
00P0Re:800@000000?ooo`3oool000000P3oool00`000000oooo000000050?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool000000P3oool2000000030?ooo`000000000000800000o`3o
oooo0?ooodD0oooo000f0?ooo`040000003oool0oooo000000/0oooo0`09jPX00`3oool0000008]B
R00?08]BR0030000003oool0oooo00H0oooo00<0000008]BR02;DXP01@2;DXP00`000000Re:808]B
R00308]BR0030000002;DXP0Re:800d0Re:800<0000008]BR02;DXP02@2;DXP00`000000Re:808]B
R00808]BR0050000003oool0oooo0?ooo`0000000P3oool2000000D0oooo00<000000?ooo`3oool0
0`3oool010000000oooo0?ooo`0000020?ooo`@0000000<0oooo000000000000o`3ooooo0?ooodD0
oooo000f0?ooo`030000003oool0oooo008000001P3oool400WZ2P@0oooo00<0000008]BR02;DXP0
3P2;DXP00`000000oooo0?ooo`070?ooo`030000002;DXP0Re:800D0Re:800<0000008]BR02;DXP0
0P00000?08]BR0030000002;DXP0Re:800P0Re:80P00000:08]BR0030000003oool0oooo0080oooo
00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0000
00<0oooo00<000000?ooo`0000000`00003o0?ooool0ooooAP3oool003L0oooo0P0000000`3oool0
00000?ooo`020?ooo`<02NX:203oool00`000000Re:808]BR00?08]BR0030000003oool0oooo00H0
oooo00<0000008]BR02;DXP01@2;DXP00`000000Re:80000000@08]BR0030000002;DXP0Re:800P0
Re:800<0000008]BR02;DXP02@2;DXP00`000000oooo0?ooo`030?ooo`040000003oool000000000
00@0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000<0oooo0`000000
0`3oool000000000003o0?ooool0ooooAP3oool003L0oooo00D000000?ooo`3oool0oooo00000002
00WZ2P`0oooo00<0000008]BR02;DXP03P2;DXP00`000000oooo0?ooo`070?ooo`030000002;DXP0
Re:800D0Re:800<0000008]BR02;DXP03@2;DXP2000000X0Re:800<0000008]BR02;DXP02@2;DXP0
0`000000oooo0?ooo`040?ooo`80000000<0oooo0000003oool00`3oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`0000000`3oool600000?l0ooooo`3ooom70?ooo`00>03oool0
10000000oooo0?ooo`00000>0?ooo`030000002;DXP0Re:800h0Re:800<000000?ooo`3oool01`3o
ool00`000000Re:808]BR00508]BR0030000002;DXP0Re:800`0Re:800<0000008]BR02;DXP02@2;
DXP00`000000Re:808]BR00908]BR0030000003oool0oooo00D0oooo0P0000000`3oool000000?oo
o`020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000`3oool01@000000oooo
000000000000oooo00800000o`3ooooo0?ooodL0oooo000h0?ooo`050000003oool0oooo0?ooo`00
00003@3oool00`000000Re:808]BR00>08]BR0030000003oool0oooo00P0oooo00<0000008]BR02;
DXP01@2;DXP00`000000Re:808]BR00:08]BR0030000002;DXP0Re:800T0Re:800<0000008]BR02;
DXP02@2;DXP00`000000oooo0?ooo`060?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool00`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`0000000`00003o
0?ooool0ooooB03oool003T0oooo00@000000?ooo`3oool000003@3oool00`000000Re:808]BR00>
08]BR0030000003oool0oooo00T0oooo00<0000008]BR02;DXP01@2;DXP00`000000Re:808]BR008
08]BR0030000002;DXP0Re:800T0Re:800<0000008]BR02;DXP02@2;DXP00`000000oooo0?ooo`06
0?ooo`8000000P3oool00`000000oooo000000050?ooo`050000003oool0oooo0?ooo`0000000`3o
ool01@000000oooo0?ooo`000000oooo00800000o`3ooooo0?ooodP0oooo000i0?ooo`050000003o
ool0oooo0?ooo`000000303oool00`000000Re:808]BR00>08]BR0030000003oool0oooo00T0oooo
00<0000008]BR02;DXP01@2;DXP00`000000Re:808]BR00608]BR08000002`2;DXP00`000000Re:8
08]BR00908]BR0040000002W`>/00000000000D0oooo00<000000?ooo`0000000P3oool00`000000
oooo000000050?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo000000030000
0?l0ooooo`3ooom90?ooo`00>P3oool01@000000oooo0?ooo`3oool0000000`0oooo00<0000008]B
R02;DXP03@2;DXP00`000000oooo0?ooo`0:0?ooo`030000002;DXP0Re:800D0Re:800<0000008]B
R02;DXP0102;DXP00`000000Re:808]BR00:08]BR0030000002;DXP0Re:800T0Re:800<000000:O0
j`2W`>/00P2W`>/200000080oooo00@000000?ooo`3oool000000P3oool2000000D0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00@00000o`3ooooo0?ooodT0oooo000j
0?ooo`050000003oool0oooo0?ooo`000000303oool00`000000Re:808]BR00=08]BR0030000003o
ool0oooo00X0oooo00<0000008]BR02;DXP01P2;DXP00`000000Re:808]BR00208]BR0030000002;
DXP0Re:800X0Re:800<0000008]BR02;DXP02P2;DXP00`000000Yl3[0:O0j`040:O0j`8000000P3o
ool01@000000oooo0?ooo`3oool0000000D0oooo00D000000?ooo`3oool0oooo000000030?ooo`03
0000003oool0oooo00@00000o`3ooooo0?ooodX0oooo000j0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool02@3oool00`000000Re:808]BR00=08]BR0030000003oool0oooo00/0oooo
00<0000008]BR02;DXP01@2;DXP01@000000Re:808]BR02;DXP0000000`0Re:800<0000008]BR02;
DXP02P2;DXP00`000000Yl3[0:O0j`060:O0j`80000000@0oooo0000003oool0oooo0P0000050?oo
o`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0400000?l0ooooo`3ooom:
0?ooo`00>`3oool01@000000oooo0?ooo`3oool0000000/0oooo00<0000008]BR02;DXP03@2;DXP0
0`000000oooo0?ooo`0<0?ooo`030000002;DXP0Re:800D0Re:800<0000008]BR0000000302;DXP0
0`000000Re:808]BR00:08]BR0@000001@2W`>/00`000000Yl3[0:O0j`0200000080oooo0P000004
0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0400000?l0ooooo`3o
oom;0?ooo`00>`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<00000
08]BR02;DXP03@2;DXP00`000000oooo0?ooo`0=0?ooo`030000002;DXP0Re:800D0Re:800<00000
08]BR02;DXP02P2;DXP00`000000Re:808]BR00:08]BR0030000003oool0oooo0080oooo0`000000
0`2W`>/000000:O0j`040:O0j`80000000<0oooo0000003oool00P3oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`0000000P3oool400000?l0ooooo`3ooom;0?ooo`00?03oool0
1@000000oooo0?ooo`3oool0000000/0oooo00<0000008]BR02;DXP0302;DXP00`000000oooo0?oo
o`0>0?ooo`030000002;DXP0Re:800@0Re:800<0000008]BR02;DXP02@2;DXP00`000000Re:808]B
R00:08]BR0030000003oool0oooo00H0oooo0`0000040:O0j`@000000P3oool00`000000oooo0?oo
o`020?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo00000000003o0?ooool0
ooooC03oool003`0oooo00<000000?ooo`3oool00`00000:0?ooo`030000002;DXP0Re:800`0Re:8
00<000000?ooo`3oool03`3oool00`000000Re:808]BR00408]BR0030000002;DXP0Re:800L0Re:8
00<0000008]BR02;DXP02P2;DXP00`000000oooo0?ooo`060?ooo`040000003oool0oooo0?ooo`@0
000000@0Yl3[00000000000000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00H00000
0?ooo`3oool0oooo0000003oool200000?l0ooooo`3ooom<0?ooo`00?@3oool200000080oooo00<0
00000?ooo`3oool0203oool00`000000Re:808]BR00<08]BR0030000003oool0oooo0100oooo00<0
000008]BR02;DXP0102;DXP00`000000Re:808]BR00508]BR0030000002;DXP0Re:800X0Re:800<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`8000000P3oool00`000000oooo0000
00040?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo00000000003o0?ooool0
ooooC@3oool003d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000
002;DXP0Re:800`0Re:800<000000?ooo`3oool04@3oool00`000000Re:808]BR00408]BR0030000
002;DXP0Re:800<0Re:800<0000008]BR02;DXP02P2;DXP00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00@0oooo0P0000030?ooo`800000103oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool00P00003o0?ooool0ooooC@3oool003h0oooo00D000000?ooo`3oool0
oooo0000000:0?ooo`030000002;DXP0Re:800/0Re:800<000000?ooo`3oool04P3oool00`000000
Re:808]BR00408]BR0050000002;DXP0Re:808]BR0000000302;DXP00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`0000000`3oool2000000<0oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`000000oooo00800000o`3ooooo0?ooodh0oooo000n0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000Re:808]BR00;08]B
R0030000003oool0oooo01<0oooo0P00000508]BR0030000002;DXP0000000`0Re:800<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P00
003o0?ooool0ooooCP3oool003l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`06
0?ooo`030000002;DXP0Re:800/0Re:800<000000?ooo`3oool05@3oool2000000@0Re:800<00000
08]BR02;DXP02P2;DXP00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00@00000
0?ooo`3oool000000P3oool2000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`040000
003oool0000000000?l0ooooo`3ooom?0?ooo`00@03oool01@000000oooo0?ooo`3oool0000000P0
oooo00<0000008]BR02;DXP02`2;DXP00`000000oooo0?ooo`0G0?ooo`050000002;DXP0Re:808]B
R00000002`2;DXP00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00D000000?oo
o`3oool0oooo000000020?ooo`8000000`3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool00P00003o0?ooool0ooooC`3oool00400oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`050?ooo`030000002;DXP0Re:800/0Re:800<000000?ooo`3oool0603oool2
00000080Re:800<0000008]BR02;DXP01`2;DXP00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00P3oool010000000oooo0000000000030?ooo`050000003o
ool0oooo0?ooo`0000000`3oool010000000oooo00000000003o0?ooool0ooooD03oool00440oooo
00D000000?ooo`3oool0oooo000000080?ooo`030000002;DXP0Re:800X0Re:800<000000?ooo`3o
ool06P3oool20000000308]BR0000000Re:800H0Re:800<000000?ooo`3oool0203oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00D000000?ooo`000000oooo000000020?oo
o`030000003oool0oooo0080oooo00D000000?ooo`3oool000000?ooo`0200000?l0ooooo`3ooomA
0?ooo`00@@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<0000008]B
R02;DXP02P2;DXP00`000000oooo0?ooo`0L0?ooo`<000001@2;DXP00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool200000080oooo00@000000?oo
o`3oool000000`3oool010000000oooo0?ooo`0000020?ooo`800000o`3ooooo0?oooe40oooo0012
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000Re:808]BR00:
08]BR0030000003oool0oooo01h0oooo0P00000308]BR0030000003oool0oooo00P0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`8000000P3oool00`000000oooo00000003
0?ooo`060000003oool0oooo0?ooo`000000oooo0P00003o0?ooool0ooooDP3oool004<0oooo00D0
00000?ooo`3oool0oooo000000060?ooo`030000002;DXP0Re:800X0Re:800<000000?ooo`3oool0
7`3oool20000000308]BR0000000oooo00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`070000003oool0oooo0?ooo`000000oooo000000030?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool0o`3ooooo0?oooe40oooo00130?ooo`030000003oool0oooo
00<000001@3oool00`000000Re:808]BR00:08]BR0030000003oool0oooo0240oooo0P00000:0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool2000000030?ooo`0000000000
008000000`3oool01P000000oooo0?ooo`3oool000000?ooo`800000o`3ooooo0?oooe<0oooo0014
0?ooo`8000000P3oool00`000000oooo0?ooo`040?ooo`030000002;DXP0Re:800T0Re:800<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0103oool300000080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo0?l0ooooo`3ooomB0?ooo`00A03oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo00<0000008]BR02;DXP02@2;DXP00`000000oooo0?ooo`0T
0?ooo`8000001@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`000000o`3o
oooo0?oooeD0oooo00150?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
0`000000Re:808]BR00:08]BR0030000003oool0oooo02D0oooo00D000000?ooo`3oool0oooo0000
00070?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool000000P3oool01@000000oooo
0?ooo`3oool0000000<0oooo00@000000?ooo`3oool00000o`3ooooo0?oooeD0oooo00160?ooo`05
0000003oool0oooo0?ooo`0000001@3oool00`000000Re:808]BR00908]BR0030000003oool0oooo
02H0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`050?ooo`030000003oool00000
00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`<00000o`3ooooo0?oooeH0oooo00160?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000Re:808]BR00908]B
R0030000003oool0oooo02L0oooo0P0000070?ooo`030000003oool0oooo00@0oooo00@000000?oo
o`3oool000000P3oool200000080oooo00@000000?ooo`3oool0oooo0P00003o0?ooool0ooooF03o
ool004L0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000/0Re:800<0
00000?ooo`3oool0:@3oool2000000@0oooo00<000000?ooo`3oool0103oool02@000000oooo0?oo
o`3oool000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00800000o`3ooooo0?oo
oeT0oooo00180?ooo`050000003oool0oooo0?ooo`000000103oool00`000000Re:808]BR00808]B
R0030000003oool0oooo02/0oooo0P0000000`3oool000000?ooo`050?ooo`030000003oool0oooo
0080oooo00L000000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3oool0o`3o
oooo0?oooeP0oooo00180?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000
000:08]BR0030000003oool0oooo02d0oooo0`0000050?ooo`030000003oool0oooo0080oooo0P00
0000103oool000000?ooo`0000020?ooo`800000o`3ooooo0?oooe/0oooo00190?ooo`050000003o
ool0oooo0?ooo`0000000`3oool00`000000Re:808]BR00808]BR0030000003oool0oooo0300oooo
0`0000000`3oool000000?ooo`030?ooo`060000003oool000000?ooo`000000oooo0`00003o0?oo
ool0ooooG@3oool004T0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool00000
00X0Re:800<000000?ooo`3oool0<P3oool400000080oooo1P00003o0?ooool0ooooH03oool004X0
oooo00<000000?ooo`3oool00`0000020?ooo`030000002;DXP0Re:800P0Re:800<000000?ooo`3o
ool0=P3oool5000000030?ooo`000000oooo0?l0ooooo`3ooomP0?ooo`00B`3oool200000080oooo
00@000000?ooo`3oool000002P2;DXP00`000000oooo0?ooo`0h0?ooo`040000003oool0oooo0000
0?l0ooooo`3ooomR0?ooo`00B`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
00T0Re:800<000000?ooo`3oool0=`3oool01@000000oooo0?ooo`3oool000000?l0ooooo`3ooomR
0?ooo`00C03oool00`000000oooo0?ooo`020?ooo`030000003oool0000000T0Re:800<000000?oo
o`3oool0=`3oool01@000000oooo0?ooo`3oool000000?l0ooooo`3ooomR0?ooo`00C@3oool00`00
0000oooo0?ooo`020?ooo`8000002@2;DXP00`000000oooo0?ooo`0g0?ooo`040000003oool0oooo
00000?l0ooooo`3ooomS0?ooo`00CP3oool00`000000oooo0?ooo`020?ooo`800000202;DXP00`00
0000oooo0?ooo`0f0?ooo`050000003oool0oooo0?ooo`000000o`3ooooo0?ooof<0oooo001?0?oo
o`030000003oool0oooo0080oooo00<0000008]BR02;DXP01P2;DXP00`000000oooo0?ooo`0f0?oo
o`050000003oool0oooo0?ooo`000000o`3ooooo0?ooof<0oooo001@0?ooo`030000003oool0oooo
0080oooo00<0000008]BR02;DXP01P2;DXP00`000000oooo0?ooo`0e0?ooo`040000003oool0oooo
00000?l0ooooo`3ooomT0?ooo`00D@3oool010000000oooo0?ooo`3oool2000000L0Re:800<00000
0?ooo`3oool0=03oool00`000000oooo0000000200000?l0ooooo`3ooomT0?ooo`00DP3oool00`00
0000oooo0?ooo`03000000H0Re:800<000000?ooo`3oool0=03oool200000080oooo00<000000?oo
o`3oool0o`3ooooo0?ooof80oooo001C0?ooo`80000000@0oooo0000002;DXP000001@2;DXP00`00
0000oooo0?ooo`0d0?ooo`040000003oool0oooo00000?l0ooooo`3ooomU0?ooo`00E03oool01P00
0000oooo0?ooo`000000Re:8000000@0Re:800<000000?ooo`3oool0<`3oool01@000000oooo0?oo
o`3oool000000?l0ooooo`3ooomU0?ooo`00E@3oool01P000000oooo0?ooo`000000Re:8000000<0
Re:800<000000?ooo`3oool0<`3oool010000000oooo0?ooo`00003o0?ooool0ooooIP3oool005H0
oooo00<000000?ooo`0000000P2;DXP010000000Re:808]BR000000d0?ooo`050000003oool0oooo
0?ooo`000000o`3ooooo0?ooofH0oooo001G0?ooo`030000003oool000000080Re:800@0000008]B
R02;DXP00000<`3oool010000000oooo0?ooo`00003o0?ooool0ooooI`3oool005P0oooo0P000003
08]BR0030000002;DXP000000380oooo00D000000?ooo`3oool0oooo0000003o0?ooool0ooooI`3o
ool005T0oooo0P00000308]BR0800000<P3oool400000?l0ooooo`3ooomX0?ooo`00FP3oool00`00
0000Re:808]BR00400000300oooo0P0000020?ooo`030000003oool0oooo0?l0ooooo`3ooomV0?oo
o`00F`3oool2000000@0oooo00<000000?ooo`3oool0;@3oool010000000oooo0?ooo`00003o0?oo
ool0ooooJ@3oool005d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0[0?ooo`04
0000003oool0oooo00000?l0ooooo`3ooomZ0?ooo`00GP3oool00`000000oooo0?ooo`020?ooo`80
0000:P3oool010000000oooo0?ooo`00003o0?ooool0ooooJ`3oool005l0oooo0P0000040?ooo`03
0000003oool0oooo02L0oooo00<000000?ooo`000000o`3ooooo0?ooof`0oooo001Q0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool09@3oool300000?l0ooooo`3ooom]0?ooo`00HP3o
ool00`000000oooo0?ooo`04000002<0oooo0`00003o0?ooool0ooooK`3oool006<0oooo0P000004
0?ooo`800000803oool00`000000oooo0000003o0?ooool0ooooL03oool006D0oooo0P0000040?oo
o`8000007@3oool00`000000oooo0000003o0?ooool0ooooL@3oool006L0oooo0P0000040?ooo`80
00006P3oool300000?l0ooooo`3ooomb0?ooo`00J@3oool200000080oooo1000000F0?ooo`<00000
o`3ooooo0?ooog@0oooo001[0?ooo`800000103oool300000140oooo0`00003o0?ooool0ooooMP3o
ool006d0oooo0`0000040?ooo`8000002`3oool500000?l0ooooo`3ooomh0?ooo`00L03oool30000
0080oooo3P00003o0?ooool0ooooN`3oool007<0oooo1@0000030?ooo`@00000o`3ooooo0?ooogl0
oooo001h0?ooo`@00000o`3ooooo0?oooh80oooo003o0?ooool0oooooP3oool00?l0ooooo`3oooon
0?ooo`00o`3ooooo0?ooooh0oooo003o0?ooool0oooooP3oool00?l0ooooo`3oooon0?ooo`00o`3o
oooo0?ooooh0oooo003o0?ooool0oooooP3oool00?l0ooooo`3oooon0?ooo`00o`3ooooo0?ooooh0
oooo003o0?ooool0oooooP3oool00?l0ooooo`3oooon0?ooo`00o`3ooooo0?ooooh0oooo003o0?oo
ool0oooooP3oool00?l0ooooo`3oooon0?ooo`00o`3ooooo0?ooooh0oooo003o0?ooool0oooooP3o
ool00?l0ooooo`3oooon0?ooo`00o`3ooooo0?ooooh0oooo003o0?ooool0oooooP3oool00?l0oooo
o`3oooon0?ooo`00o`3ooooo0?ooooh0oooo003o0?ooool0oooooP3oool00?l0ooooo`3oooon0?oo
o`00o`3ooooo0?ooooh0oooo003o0?ooool0oooooP3oool00?l0ooooo`3oooon0?ooo`00o`3ooooo
0?ooooh0oooo003o0?ooool0oooooP3oool00?l0ooooo`3oooon0?ooo`00o`3ooooo0?ooooh0oooo
003o0?ooool0oooooP3oool00?l0ooooo`3oooon0?ooo`00o`3ooooo0?ooooh0oooo003o0?ooool0
oooooP3oool00?l0ooooo`3oooon0?ooo`00o`3ooooo0?ooooh0oooo003o0?ooool0oooooP3oool0
0?l0ooooo`3oooon0?ooo`00o`3ooooo0?ooooh0oooo003o0?ooool0oooooP3oool00?l0ooooo`3o
ooon0?ooo`00o`3ooooo0?ooooh0oooo003o0?ooool0oooooP3oool00?l0ooooo`3oooon0?ooo`00
o`3ooooo0?ooooh0oooo003o0?ooool0oooooP3oool00?l0ooooo`3oooon0?ooo`00o`3ooooo0?oo
ooh0oooo003o0?ooool0oooooP3oool00?l0ooooo`3oooon0?ooo`00o`3ooooo0?ooooh0oooo003o
0?ooool0oooooP3oool00?l0ooooo`3oooon0?ooo`00o`3ooooo0?ooooh0oooo003o0?ooool0oooo
oP3oool00?l0ooooo`3oooon0?ooo`00o`3ooooo0?ooooh0oooo003o0?ooool0oooooP3oool00?l0
ooooo`3oooon0?ooo`00o`3ooooo0?ooooh0oooo003o0?ooool0oooooP3oool00?l0ooooo`3oooon
0?ooo`00o`3ooooo0?ooooh0oooo003o0?ooool0oooooP3oool00?l0ooooo`3oooon0?ooo`00o`3o
oooo0?ooooh0oooo003o0?ooool0oooooP3oool00?l0ooooo`3oooon0?ooo`00o`3ooooo0?ooooh0
oooo003o0?ooool0oooooP3oool00?l0ooooo`3oooon0?ooo`00o`3ooooo0?ooooh0oooo003o0?oo
ool0oooooP3oool00?l0ooooo`3oooon0?ooo`00o`3ooooo0?ooooh0oooo003o0?ooool0oooooP3o
ool00?l0ooooo`3oooon0?ooo`00o`3ooooo0?ooooh0oooo003o0?ooool0oooooP3oool00?l0oooo
o`3oooon0?ooo`00o`3ooooo0?ooooh0oooo003o0?ooool0oooooP3oool00?l0ooooo`3oooon0?oo
o`00o`3ooooo0?ooooh0oooo003o0?ooool0oooooP3oool00?l0ooooo`3oooon0?ooo`00o`3ooooo
0?ooooh0oooo003o0?ooool0oooooP3oool00?l0ooooo`3oooon0?ooo`00o`3ooooo0?ooooh0oooo
003o0?ooool0oooooP3oool00?l0ooooo`3oooon0?ooo`00o`3ooooo0?ooooh0oooo003o0?ooool0
oooooP3oool00?l0ooooo`3oooon0?ooo`00o`3ooooo0?ooooh0oooo003o0?ooool0oooooP3oool0
0?l0ooooo`3oooon0?ooo`00o`3ooooo0?ooooh0oooo003o0?ooool0oooooP3oool00?l0ooooo`3o
ooon0?ooo`00o`3ooooo0?ooooh0oooo003o0?ooool0oooooP3oool00001\
\>"],
  ImageRangeCache->{{{-55.5, 828.688}, {705.312, -73.3125}} -> {0.0881223, \
-0.0280915, 0.00110039, 0.00110039}},
  CellTags->"CompoundLens"]
}, Open  ]],

Cell[CellGroupData[{

Cell["AnalyzeSystem[result, PlotType->TopView, PlotPoints->30];", "Input",
  CellTags->"CompoundLens"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .28289 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0247047 0.00537563 0.141444 0.00537563 [
[ 0 0 0 0 ]
[ 1 .28289 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.5 g
.11368 .00674 m
.11901 .00674 L
.11471 .02919 L
.10239 .02919 L
.11368 .00674 L
F
.10239 .02919 m
.11471 .02919 L
.1112 .05164 L
.09352 .05164 L
.10239 .02919 L
F
.09352 .05164 m
.1112 .05164 L
.10849 .07409 L
.08683 .07409 L
.09352 .05164 L
F
.08683 .07409 m
.10849 .07409 L
.10656 .09654 L
.08215 .09654 L
.08683 .07409 L
F
.08215 .09654 m
.10656 .09654 L
.10541 .11899 L
.07938 .11899 L
.08215 .09654 L
F
.07938 .11899 m
.10541 .11899 L
.10503 .14144 L
.07846 .14144 L
.07938 .11899 L
F
.07846 .14144 m
.10503 .14144 L
.10541 .1639 L
.07938 .1639 L
.07846 .14144 L
F
.07938 .1639 m
.10541 .1639 L
.10656 .18635 L
.08215 .18635 L
.07938 .1639 L
F
.08215 .18635 m
.10656 .18635 L
.10849 .2088 L
.08683 .2088 L
.08215 .18635 L
F
.08683 .2088 m
.10849 .2088 L
.1112 .23125 L
.09352 .23125 L
.08683 .2088 L
F
.09352 .23125 m
.1112 .23125 L
.11471 .2537 L
.10239 .2537 L
.09352 .23125 L
F
.10239 .2537 m
.11471 .2537 L
.11901 .27615 L
.11368 .27615 L
.10239 .2537 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.11368 .00674 m
.10239 .02919 L
.09352 .05164 L
.08683 .07409 L
.08215 .09654 L
.07938 .11899 L
.07846 .14144 L
.07938 .1639 L
.08215 .18635 L
.08683 .2088 L
.09352 .23125 L
.10239 .2537 L
.11368 .27615 L
.11901 .27615 L
.11471 .2537 L
.1112 .23125 L
.10849 .2088 L
.10656 .18635 L
.10541 .1639 L
.10503 .14144 L
.10541 .11899 L
.10656 .09654 L
.10849 .07409 L
.1112 .05164 L
.11471 .02919 L
.11901 .00674 L
.11368 .00674 L
s
.5 g
.11368 .14144 m
.11901 .14144 L
.11471 .14144 L
.10239 .14144 L
.11368 .14144 L
F
.10239 .14144 m
.11471 .14144 L
.1112 .14144 L
.09352 .14144 L
.10239 .14144 L
F
.09352 .14144 m
.1112 .14144 L
.10849 .14144 L
.08683 .14144 L
.09352 .14144 L
F
.08683 .14144 m
.10849 .14144 L
.10656 .14144 L
.08215 .14144 L
.08683 .14144 L
F
.08215 .14144 m
.10656 .14144 L
.10541 .14144 L
.07938 .14144 L
.08215 .14144 L
F
.07938 .14144 m
.10541 .14144 L
.10503 .14144 L
.07846 .14144 L
.07938 .14144 L
F
.07846 .14144 m
.10503 .14144 L
.10541 .14144 L
.07938 .14144 L
.07846 .14144 L
F
.07938 .14144 m
.10541 .14144 L
.10656 .14144 L
.08215 .14144 L
.07938 .14144 L
F
.08215 .14144 m
.10656 .14144 L
.10849 .14144 L
.08683 .14144 L
.08215 .14144 L
F
.08683 .14144 m
.10849 .14144 L
.1112 .14144 L
.09352 .14144 L
.08683 .14144 L
F
.09352 .14144 m
.1112 .14144 L
.11471 .14144 L
.10239 .14144 L
.09352 .14144 L
F
.10239 .14144 m
.11471 .14144 L
.11901 .14144 L
.11368 .14144 L
.10239 .14144 L
F
0 g
.11368 .14144 m
.10239 .14144 L
.09352 .14144 L
.08683 .14144 L
.08215 .14144 L
.07938 .14144 L
.07846 .14144 L
.07938 .14144 L
.08215 .14144 L
.08683 .14144 L
.09352 .14144 L
.10239 .14144 L
.11368 .14144 L
.11901 .14144 L
.11471 .14144 L
.1112 .14144 L
.10849 .14144 L
.10656 .14144 L
.10541 .14144 L
.10503 .14144 L
.10541 .14144 L
.10656 .14144 L
.10849 .14144 L
.1112 .14144 L
.11471 .14144 L
.11901 .14144 L
.11368 .14144 L
s
.5 g
.1638 .03303 m
.21031 .0716 L
.19845 .08324 L
.14293 .0511 L
.1638 .03303 L
F
.14293 .0511 m
.19845 .08324 L
.19009 .09488 L
.12874 .06917 L
.14293 .0511 L
F
.12874 .06917 m
.19009 .09488 L
.18417 .10652 L
.11886 .08724 L
.12874 .06917 L
F
.11886 .08724 m
.18417 .10652 L
.18018 .11816 L
.11227 .10531 L
.11886 .08724 L
F
.11227 .10531 m
.18018 .11816 L
.17788 .1298 L
.10848 .12338 L
.11227 .10531 L
F
.10848 .12338 m
.17788 .1298 L
.17712 .14144 L
.10723 .14144 L
.10848 .12338 L
F
.10723 .14144 m
.17712 .14144 L
.17788 .15309 L
.10848 .15951 L
.10723 .14144 L
F
.10848 .15951 m
.17788 .15309 L
.18018 .16473 L
.11227 .17758 L
.10848 .15951 L
F
.11227 .17758 m
.18018 .16473 L
.18417 .17637 L
.11886 .19565 L
.11227 .17758 L
F
.11886 .19565 m
.18417 .17637 L
.19009 .18801 L
.12874 .21372 L
.11886 .19565 L
F
.12874 .21372 m
.19009 .18801 L
.19845 .19965 L
.14293 .23179 L
.12874 .21372 L
F
.14293 .23179 m
.19845 .19965 L
.21031 .21129 L
.1638 .24985 L
.14293 .23179 L
F
0 g
.1638 .03303 m
.14293 .0511 L
.12874 .06917 L
.11886 .08724 L
.11227 .10531 L
.10848 .12338 L
.10723 .14144 L
.10848 .15951 L
.11227 .17758 L
.11886 .19565 L
.12874 .21372 L
.14293 .23179 L
.1638 .24985 L
.21031 .21129 L
.19845 .19965 L
.19009 .18801 L
.18417 .17637 L
.18018 .16473 L
.17788 .15309 L
.17712 .14144 L
.17788 .1298 L
.18018 .11816 L
.18417 .10652 L
.19009 .09488 L
.19845 .08324 L
.21031 .0716 L
.1638 .03303 L
s
.5 g
.1638 .14144 m
.21031 .14144 L
.19845 .14144 L
.14293 .14144 L
.1638 .14144 L
F
.14293 .14144 m
.19845 .14144 L
.19009 .14144 L
.12874 .14144 L
.14293 .14144 L
F
.12874 .14144 m
.19009 .14144 L
.18417 .14144 L
.11886 .14144 L
.12874 .14144 L
F
.11886 .14144 m
.18417 .14144 L
.18018 .14144 L
.11227 .14144 L
.11886 .14144 L
F
.11227 .14144 m
.18018 .14144 L
.17788 .14144 L
.10848 .14144 L
.11227 .14144 L
F
.10848 .14144 m
.17788 .14144 L
.17712 .14144 L
.10723 .14144 L
.10848 .14144 L
F
.10723 .14144 m
.17712 .14144 L
.17788 .14144 L
.10848 .14144 L
.10723 .14144 L
F
.10848 .14144 m
.17788 .14144 L
.18018 .14144 L
.11227 .14144 L
.10848 .14144 L
F
.11227 .14144 m
.18018 .14144 L
.18417 .14144 L
.11886 .14144 L
.11227 .14144 L
F
.11886 .14144 m
.18417 .14144 L
.19009 .14144 L
.12874 .14144 L
.11886 .14144 L
F
.12874 .14144 m
.19009 .14144 L
.19845 .14144 L
.14293 .14144 L
.12874 .14144 L
F
.14293 .14144 m
.19845 .14144 L
.21031 .14144 L
.1638 .14144 L
.14293 .14144 L
F
0 g
.1638 .14144 m
.14293 .14144 L
.12874 .14144 L
.11886 .14144 L
.11227 .14144 L
.10848 .14144 L
.10723 .14144 L
.10848 .14144 L
.11227 .14144 L
.11886 .14144 L
.12874 .14144 L
.14293 .14144 L
.1638 .14144 L
.21031 .14144 L
.19845 .14144 L
.19009 .14144 L
.18417 .14144 L
.18018 .14144 L
.17788 .14144 L
.17712 .14144 L
.17788 .14144 L
.18018 .14144 L
.18417 .14144 L
.19009 .14144 L
.19845 .14144 L
.21031 .14144 L
.1638 .14144 L
s
.5 g
.21031 .0716 m
.24779 .0837 L
.23845 .09332 L
.21031 .08324 L
.21031 .0716 L
F
.21031 .08324 m
.23845 .09332 L
.23178 .10295 L
.21031 .09488 L
.21031 .08324 L
F
.21031 .09488 m
.23178 .10295 L
.22703 .11257 L
.21031 .10652 L
.21031 .09488 L
F
.21031 .10652 m
.22703 .11257 L
.22383 .12219 L
.21031 .11816 L
.21031 .10652 L
F
.21031 .11816 m
.22383 .12219 L
.22197 .13182 L
.21031 .1298 L
.21031 .11816 L
F
.21031 .1298 m
.22197 .13182 L
.22136 .14144 L
.21031 .14144 L
.21031 .1298 L
F
.21031 .14144 m
.22136 .14144 L
.22197 .15107 L
.21031 .15309 L
.21031 .14144 L
F
.21031 .15309 m
.22197 .15107 L
.22383 .16069 L
.21031 .16473 L
.21031 .15309 L
F
.21031 .16473 m
.22383 .16069 L
.22703 .17032 L
.21031 .17637 L
.21031 .16473 L
F
.21031 .17637 m
.22703 .17032 L
.23178 .17994 L
.21031 .18801 L
.21031 .17637 L
F
.21031 .18801 m
.23178 .17994 L
.23845 .18957 L
.21031 .19965 L
.21031 .18801 L
F
.21031 .19965 m
.23845 .18957 L
.24779 .19919 L
.21031 .21129 L
.21031 .19965 L
F
0 g
.21031 .0716 m
.21031 .08324 L
.21031 .09488 L
.21031 .10652 L
.21031 .11816 L
.21031 .1298 L
.21031 .14144 L
.21031 .15309 L
.21031 .16473 L
.21031 .17637 L
.21031 .18801 L
.21031 .19965 L
.21031 .21129 L
.24779 .19919 L
.23845 .18957 L
.23178 .17994 L
.22703 .17032 L
.22383 .16069 L
.22197 .15107 L
.22136 .14144 L
.22197 .13182 L
.22383 .12219 L
.22703 .11257 L
.23178 .10295 L
.23845 .09332 L
.24779 .0837 L
.21031 .0716 L
s
.5 g
.21031 .14144 m
.24779 .14144 L
.23845 .14144 L
.21031 .14144 L
.21031 .14144 L
F
.21031 .14144 m
.23845 .14144 L
.23178 .14144 L
.21031 .14144 L
.21031 .14144 L
F
.21031 .14144 m
.23178 .14144 L
.22703 .14144 L
.21031 .14144 L
.21031 .14144 L
F
.21031 .14144 m
.22703 .14144 L
.22383 .14144 L
.21031 .14144 L
.21031 .14144 L
F
.21031 .14144 m
.22383 .14144 L
.22197 .14144 L
.21031 .14144 L
.21031 .14144 L
F
.21031 .14144 m
.22197 .14144 L
.22136 .14144 L
.21031 .14144 L
.21031 .14144 L
F
.21031 .14144 m
.22136 .14144 L
.22197 .14144 L
.21031 .14144 L
.21031 .14144 L
F
.21031 .14144 m
.22197 .14144 L
.22383 .14144 L
.21031 .14144 L
.21031 .14144 L
F
.21031 .14144 m
.22383 .14144 L
.22703 .14144 L
.21031 .14144 L
.21031 .14144 L
F
.21031 .14144 m
.22703 .14144 L
.23178 .14144 L
.21031 .14144 L
.21031 .14144 L
F
.21031 .14144 m
.23178 .14144 L
.23845 .14144 L
.21031 .14144 L
.21031 .14144 L
F
.21031 .14144 m
.23845 .14144 L
.24779 .14144 L
.21031 .14144 L
.21031 .14144 L
F
0 g
.21031 .14144 m
.21031 .14144 L
.21031 .14144 L
.21031 .14144 L
.21031 .14144 L
.21031 .14144 L
.21031 .14144 L
.21031 .14144 L
.21031 .14144 L
.21031 .14144 L
.21031 .14144 L
.21031 .14144 L
.21031 .14144 L
.24779 .14144 L
.23845 .14144 L
.23178 .14144 L
.22703 .14144 L
.22383 .14144 L
.22197 .14144 L
.22136 .14144 L
.22197 .14144 L
.22383 .14144 L
.22703 .14144 L
.23178 .14144 L
.23845 .14144 L
.24779 .14144 L
.21031 .14144 L
s
.5 g
.24779 .0837 m
.25013 .0837 L
.25013 .09332 L
.23845 .09332 L
.24779 .0837 L
F
.23845 .09332 m
.25013 .09332 L
.25013 .10295 L
.23178 .10295 L
.23845 .09332 L
F
.23178 .10295 m
.25013 .10295 L
.25013 .11257 L
.22703 .11257 L
.23178 .10295 L
F
.22703 .11257 m
.25013 .11257 L
.25013 .12219 L
.22383 .12219 L
.22703 .11257 L
F
.22383 .12219 m
.25013 .12219 L
.25013 .13182 L
.22197 .13182 L
.22383 .12219 L
F
.22197 .13182 m
.25013 .13182 L
.25013 .14144 L
.22136 .14144 L
.22197 .13182 L
F
.22136 .14144 m
.25013 .14144 L
.25013 .15107 L
.22197 .15107 L
.22136 .14144 L
F
.22197 .15107 m
.25013 .15107 L
.25013 .16069 L
.22383 .16069 L
.22197 .15107 L
F
.22383 .16069 m
.25013 .16069 L
.25013 .17032 L
.22703 .17032 L
.22383 .16069 L
F
.22703 .17032 m
.25013 .17032 L
.25013 .17994 L
.23178 .17994 L
.22703 .17032 L
F
.23178 .17994 m
.25013 .17994 L
.25013 .18957 L
.23845 .18957 L
.23178 .17994 L
F
.23845 .18957 m
.25013 .18957 L
.25013 .19919 L
.24779 .19919 L
.23845 .18957 L
F
0 g
.24779 .0837 m
.23845 .09332 L
.23178 .10295 L
.22703 .11257 L
.22383 .12219 L
.22197 .13182 L
.22136 .14144 L
.22197 .15107 L
.22383 .16069 L
.22703 .17032 L
.23178 .17994 L
.23845 .18957 L
.24779 .19919 L
.25013 .19919 L
.25013 .18957 L
.25013 .17994 L
.25013 .17032 L
.25013 .16069 L
.25013 .15107 L
.25013 .14144 L
.25013 .13182 L
.25013 .12219 L
.25013 .11257 L
.25013 .10295 L
.25013 .09332 L
.25013 .0837 L
.24779 .0837 L
s
.5 g
.24779 .14144 m
.25013 .14144 L
.25013 .14144 L
.23845 .14144 L
.24779 .14144 L
F
.23845 .14144 m
.25013 .14144 L
.25013 .14144 L
.23178 .14144 L
.23845 .14144 L
F
.23178 .14144 m
.25013 .14144 L
.25013 .14144 L
.22703 .14144 L
.23178 .14144 L
F
.22703 .14144 m
.25013 .14144 L
.25013 .14144 L
.22383 .14144 L
.22703 .14144 L
F
.22383 .14144 m
.25013 .14144 L
.25013 .14144 L
.22197 .14144 L
.22383 .14144 L
F
.22197 .14144 m
.25013 .14144 L
.25013 .14144 L
.22136 .14144 L
.22197 .14144 L
F
.22136 .14144 m
.25013 .14144 L
.25013 .14144 L
.22197 .14144 L
.22136 .14144 L
F
.22197 .14144 m
.25013 .14144 L
.25013 .14144 L
.22383 .14144 L
.22197 .14144 L
F
.22383 .14144 m
.25013 .14144 L
.25013 .14144 L
.22703 .14144 L
.22383 .14144 L
F
.22703 .14144 m
.25013 .14144 L
.25013 .14144 L
.23178 .14144 L
.22703 .14144 L
F
.23178 .14144 m
.25013 .14144 L
.25013 .14144 L
.23845 .14144 L
.23178 .14144 L
F
.23845 .14144 m
.25013 .14144 L
.25013 .14144 L
.24779 .14144 L
.23845 .14144 L
F
0 g
.24779 .14144 m
.23845 .14144 L
.23178 .14144 L
.22703 .14144 L
.22383 .14144 L
.22197 .14144 L
.22136 .14144 L
.22197 .14144 L
.22383 .14144 L
.22703 .14144 L
.23178 .14144 L
.23845 .14144 L
.24779 .14144 L
.25013 .14144 L
.25013 .14144 L
.25013 .14144 L
.25013 .14144 L
.25013 .14144 L
.25013 .14144 L
.25013 .14144 L
.25013 .14144 L
.25013 .14144 L
.25013 .14144 L
.25013 .14144 L
.25013 .14144 L
.25013 .14144 L
.24779 .14144 L
s
.5 g
.27891 .08217 m
.29119 .08217 L
.29573 .09205 L
.27891 .09205 L
.27891 .08217 L
F
.27891 .09205 m
.29573 .09205 L
.29933 .10193 L
.27891 .10193 L
.27891 .09205 L
F
.27891 .10193 m
.29933 .10193 L
.30205 .11181 L
.27891 .11181 L
.27891 .10193 L
F
.27891 .11181 m
.30205 .11181 L
.30396 .12169 L
.27891 .12169 L
.27891 .11181 L
F
.27891 .12169 m
.30396 .12169 L
.3051 .13157 L
.27891 .13157 L
.27891 .12169 L
F
.27891 .13157 m
.3051 .13157 L
.30547 .14144 L
.27891 .14144 L
.27891 .13157 L
F
.27891 .14144 m
.30547 .14144 L
.3051 .15132 L
.27891 .15132 L
.27891 .14144 L
F
.27891 .15132 m
.3051 .15132 L
.30396 .1612 L
.27891 .1612 L
.27891 .15132 L
F
.27891 .1612 m
.30396 .1612 L
.30205 .17108 L
.27891 .17108 L
.27891 .1612 L
F
.27891 .17108 m
.30205 .17108 L
.29933 .18096 L
.27891 .18096 L
.27891 .17108 L
F
.27891 .18096 m
.29933 .18096 L
.29573 .19084 L
.27891 .19084 L
.27891 .18096 L
F
.27891 .19084 m
.29573 .19084 L
.29119 .20072 L
.27891 .20072 L
.27891 .19084 L
F
0 g
.27891 .08217 m
.27891 .09205 L
.27891 .10193 L
.27891 .11181 L
.27891 .12169 L
.27891 .13157 L
.27891 .14144 L
.27891 .15132 L
.27891 .1612 L
.27891 .17108 L
.27891 .18096 L
.27891 .19084 L
.27891 .20072 L
.29119 .20072 L
.29573 .19084 L
.29933 .18096 L
.30205 .17108 L
.30396 .1612 L
.3051 .15132 L
.30547 .14144 L
.3051 .13157 L
.30396 .12169 L
.30205 .11181 L
.29933 .10193 L
.29573 .09205 L
.29119 .08217 L
.27891 .08217 L
s
.5 g
.27891 .14144 m
.29119 .14144 L
.29573 .14144 L
.27891 .14144 L
.27891 .14144 L
F
.27891 .14144 m
.29573 .14144 L
.29933 .14144 L
.27891 .14144 L
.27891 .14144 L
F
.27891 .14144 m
.29933 .14144 L
.30205 .14144 L
.27891 .14144 L
.27891 .14144 L
F
.27891 .14144 m
.30205 .14144 L
.30396 .14144 L
.27891 .14144 L
.27891 .14144 L
F
.27891 .14144 m
.30396 .14144 L
.3051 .14144 L
.27891 .14144 L
.27891 .14144 L
F
.27891 .14144 m
.3051 .14144 L
.30547 .14144 L
.27891 .14144 L
.27891 .14144 L
F
.27891 .14144 m
.30547 .14144 L
.3051 .14144 L
.27891 .14144 L
.27891 .14144 L
F
.27891 .14144 m
.3051 .14144 L
.30396 .14144 L
.27891 .14144 L
.27891 .14144 L
F
.27891 .14144 m
.30396 .14144 L
.30205 .14144 L
.27891 .14144 L
.27891 .14144 L
F
.27891 .14144 m
.30205 .14144 L
.29933 .14144 L
.27891 .14144 L
.27891 .14144 L
F
.27891 .14144 m
.29933 .14144 L
.29573 .14144 L
.27891 .14144 L
.27891 .14144 L
F
.27891 .14144 m
.29573 .14144 L
.29119 .14144 L
.27891 .14144 L
.27891 .14144 L
F
0 g
.27891 .14144 m
.27891 .14144 L
.27891 .14144 L
.27891 .14144 L
.27891 .14144 L
.27891 .14144 L
.27891 .14144 L
.27891 .14144 L
.27891 .14144 L
.27891 .14144 L
.27891 .14144 L
.27891 .14144 L
.27891 .14144 L
.29119 .14144 L
.29573 .14144 L
.29933 .14144 L
.30205 .14144 L
.30396 .14144 L
.3051 .14144 L
.30547 .14144 L
.3051 .14144 L
.30396 .14144 L
.30205 .14144 L
.29933 .14144 L
.29573 .14144 L
.29119 .14144 L
.27891 .14144 L
s
.5 g
.29119 .08217 m
.31873 .0714 L
.31873 .08307 L
.29573 .09205 L
.29119 .08217 L
F
.29573 .09205 m
.31873 .08307 L
.31873 .09475 L
.29933 .10193 L
.29573 .09205 L
F
.29933 .10193 m
.31873 .09475 L
.31873 .10642 L
.30205 .11181 L
.29933 .10193 L
F
.30205 .11181 m
.31873 .10642 L
.31873 .11809 L
.30396 .12169 L
.30205 .11181 L
F
.30396 .12169 m
.31873 .11809 L
.31873 .12977 L
.3051 .13157 L
.30396 .12169 L
F
.3051 .13157 m
.31873 .12977 L
.31873 .14144 L
.30547 .14144 L
.3051 .13157 L
F
.30547 .14144 m
.31873 .14144 L
.31873 .15312 L
.3051 .15132 L
.30547 .14144 L
F
.3051 .15132 m
.31873 .15312 L
.31873 .16479 L
.30396 .1612 L
.3051 .15132 L
F
.30396 .1612 m
.31873 .16479 L
.31873 .17647 L
.30205 .17108 L
.30396 .1612 L
F
.30205 .17108 m
.31873 .17647 L
.31873 .18814 L
.29933 .18096 L
.30205 .17108 L
F
.29933 .18096 m
.31873 .18814 L
.31873 .19982 L
.29573 .19084 L
.29933 .18096 L
F
.29573 .19084 m
.31873 .19982 L
.31873 .21149 L
.29119 .20072 L
.29573 .19084 L
F
0 g
.29119 .08217 m
.29573 .09205 L
.29933 .10193 L
.30205 .11181 L
.30396 .12169 L
.3051 .13157 L
.30547 .14144 L
.3051 .15132 L
.30396 .1612 L
.30205 .17108 L
.29933 .18096 L
.29573 .19084 L
.29119 .20072 L
.31873 .21149 L
.31873 .19982 L
.31873 .18814 L
.31873 .17647 L
.31873 .16479 L
.31873 .15312 L
.31873 .14144 L
.31873 .12977 L
.31873 .11809 L
.31873 .10642 L
.31873 .09475 L
.31873 .08307 L
.31873 .0714 L
.29119 .08217 L
s
.5 g
.29119 .14144 m
.31873 .14144 L
.31873 .14144 L
.29573 .14144 L
.29119 .14144 L
F
.29573 .14144 m
.31873 .14144 L
.31873 .14144 L
.29933 .14144 L
.29573 .14144 L
F
.29933 .14144 m
.31873 .14144 L
.31873 .14144 L
.30205 .14144 L
.29933 .14144 L
F
.30205 .14144 m
.31873 .14144 L
.31873 .14144 L
.30396 .14144 L
.30205 .14144 L
F
.30396 .14144 m
.31873 .14144 L
.31873 .14144 L
.3051 .14144 L
.30396 .14144 L
F
.3051 .14144 m
.31873 .14144 L
.31873 .14144 L
.30547 .14144 L
.3051 .14144 L
F
.30547 .14144 m
.31873 .14144 L
.31873 .14144 L
.3051 .14144 L
.30547 .14144 L
F
.3051 .14144 m
.31873 .14144 L
.31873 .14144 L
.30396 .14144 L
.3051 .14144 L
F
.30396 .14144 m
.31873 .14144 L
.31873 .14144 L
.30205 .14144 L
.30396 .14144 L
F
.30205 .14144 m
.31873 .14144 L
.31873 .14144 L
.29933 .14144 L
.30205 .14144 L
F
.29933 .14144 m
.31873 .14144 L
.31873 .14144 L
.29573 .14144 L
.29933 .14144 L
F
.29573 .14144 m
.31873 .14144 L
.31873 .14144 L
.29119 .14144 L
.29573 .14144 L
F
0 g
.29119 .14144 m
.29573 .14144 L
.29933 .14144 L
.30205 .14144 L
.30396 .14144 L
.3051 .14144 L
.30547 .14144 L
.3051 .14144 L
.30396 .14144 L
.30205 .14144 L
.29933 .14144 L
.29573 .14144 L
.29119 .14144 L
.31873 .14144 L
.31873 .14144 L
.31873 .14144 L
.31873 .14144 L
.31873 .14144 L
.31873 .14144 L
.31873 .14144 L
.31873 .14144 L
.31873 .14144 L
.31873 .14144 L
.31873 .14144 L
.31873 .14144 L
.31873 .14144 L
.29119 .14144 L
s
.5 g
.32312 .0687 m
.35143 .04445 L
.369 .06062 L
.33387 .08083 L
.32312 .0687 L
F
.33387 .08083 m
.369 .06062 L
.38117 .07678 L
.3417 .09295 L
.33387 .08083 L
F
.3417 .09295 m
.38117 .07678 L
.38972 .09295 L
.34734 .10507 L
.3417 .09295 L
F
.34734 .10507 m
.38972 .09295 L
.39544 .10911 L
.35117 .1172 L
.34734 .10507 L
F
.35117 .1172 m
.39544 .10911 L
.39874 .12528 L
.3534 .12932 L
.35117 .1172 L
F
.3534 .12932 m
.39874 .12528 L
.39982 .14144 L
.35413 .14144 L
.3534 .12932 L
F
.35413 .14144 m
.39982 .14144 L
.39874 .15761 L
.3534 .15357 L
.35413 .14144 L
F
.3534 .15357 m
.39874 .15761 L
.39544 .17377 L
.35117 .16569 L
.3534 .15357 L
F
.35117 .16569 m
.39544 .17377 L
.38972 .18994 L
.34734 .17782 L
.35117 .16569 L
F
.34734 .17782 m
.38972 .18994 L
.38117 .2061 L
.3417 .18994 L
.34734 .17782 L
F
.3417 .18994 m
.38117 .2061 L
.369 .22227 L
.33387 .20206 L
.3417 .18994 L
F
.33387 .20206 m
.369 .22227 L
.35143 .23843 L
.32312 .21419 L
.33387 .20206 L
F
0 g
.32312 .0687 m
.33387 .08083 L
.3417 .09295 L
.34734 .10507 L
.35117 .1172 L
.3534 .12932 L
.35413 .14144 L
.3534 .15357 L
.35117 .16569 L
.34734 .17782 L
.3417 .18994 L
.33387 .20206 L
.32312 .21419 L
.35143 .23843 L
.369 .22227 L
.38117 .2061 L
.38972 .18994 L
.39544 .17377 L
.39874 .15761 L
.39982 .14144 L
.39874 .12528 L
.39544 .10911 L
.38972 .09295 L
.38117 .07678 L
.369 .06062 L
.35143 .04445 L
.32312 .0687 L
s
.5 g
.32312 .14144 m
.35143 .14144 L
.369 .14144 L
.33387 .14144 L
.32312 .14144 L
F
.33387 .14144 m
.369 .14144 L
.38117 .14144 L
.3417 .14144 L
.33387 .14144 L
F
.3417 .14144 m
.38117 .14144 L
.38972 .14144 L
.34734 .14144 L
.3417 .14144 L
F
.34734 .14144 m
.38972 .14144 L
.39544 .14144 L
.35117 .14144 L
.34734 .14144 L
F
.35117 .14144 m
.39544 .14144 L
.39874 .14144 L
.3534 .14144 L
.35117 .14144 L
F
.3534 .14144 m
.39874 .14144 L
.39982 .14144 L
.35413 .14144 L
.3534 .14144 L
F
.35413 .14144 m
.39982 .14144 L
.39874 .14144 L
.3534 .14144 L
.35413 .14144 L
F
.3534 .14144 m
.39874 .14144 L
.39544 .14144 L
.35117 .14144 L
.3534 .14144 L
F
.35117 .14144 m
.39544 .14144 L
.38972 .14144 L
.34734 .14144 L
.35117 .14144 L
F
.34734 .14144 m
.38972 .14144 L
.38117 .14144 L
.3417 .14144 L
.34734 .14144 L
F
.3417 .14144 m
.38117 .14144 L
.369 .14144 L
.33387 .14144 L
.3417 .14144 L
F
.33387 .14144 m
.369 .14144 L
.35143 .14144 L
.32312 .14144 L
.33387 .14144 L
F
0 g
.32312 .14144 m
.33387 .14144 L
.3417 .14144 L
.34734 .14144 L
.35117 .14144 L
.3534 .14144 L
.35413 .14144 L
.3534 .14144 L
.35117 .14144 L
.34734 .14144 L
.3417 .14144 L
.33387 .14144 L
.32312 .14144 L
.35143 .14144 L
.369 .14144 L
.38117 .14144 L
.38972 .14144 L
.39544 .14144 L
.39874 .14144 L
.39982 .14144 L
.39874 .14144 L
.39544 .14144 L
.38972 .14144 L
.38117 .14144 L
.369 .14144 L
.35143 .14144 L
.32312 .14144 L
s
.5 g
.40376 .01751 m
.41098 .01751 L
.41896 .03817 L
.40493 .03817 L
.40376 .01751 L
F
.40493 .03817 m
.41896 .03817 L
.42534 .05882 L
.40588 .05882 L
.40493 .03817 L
F
.40588 .05882 m
.42534 .05882 L
.43021 .07948 L
.40663 .07948 L
.40588 .05882 L
F
.40663 .07948 m
.43021 .07948 L
.43364 .10013 L
.40716 .10013 L
.40663 .07948 L
F
.40716 .10013 m
.43364 .10013 L
.43568 .12079 L
.40747 .12079 L
.40716 .10013 L
F
.40747 .12079 m
.43568 .12079 L
.43635 .14144 L
.40758 .14144 L
.40747 .12079 L
F
.40758 .14144 m
.43635 .14144 L
.43568 .1621 L
.40747 .1621 L
.40758 .14144 L
F
.40747 .1621 m
.43568 .1621 L
.43364 .18275 L
.40716 .18275 L
.40747 .1621 L
F
.40716 .18275 m
.43364 .18275 L
.43021 .20341 L
.40663 .20341 L
.40716 .18275 L
F
.40663 .20341 m
.43021 .20341 L
.42534 .22407 L
.40588 .22407 L
.40663 .20341 L
F
.40588 .22407 m
.42534 .22407 L
.41896 .24472 L
.40493 .24472 L
.40588 .22407 L
F
.40493 .24472 m
.41896 .24472 L
.41098 .26538 L
.40376 .26538 L
.40493 .24472 L
F
0 g
.40376 .01751 m
.40493 .03817 L
.40588 .05882 L
.40663 .07948 L
.40716 .10013 L
.40747 .12079 L
.40758 .14144 L
.40747 .1621 L
.40716 .18275 L
.40663 .20341 L
.40588 .22407 L
.40493 .24472 L
.40376 .26538 L
.41098 .26538 L
.41896 .24472 L
.42534 .22407 L
.43021 .20341 L
.43364 .18275 L
.43568 .1621 L
.43635 .14144 L
.43568 .12079 L
.43364 .10013 L
.43021 .07948 L
.42534 .05882 L
.41896 .03817 L
.41098 .01751 L
.40376 .01751 L
s
.5 g
.40376 .14144 m
.41098 .14144 L
.41896 .14144 L
.40493 .14144 L
.40376 .14144 L
F
.40493 .14144 m
.41896 .14144 L
.42534 .14144 L
.40588 .14144 L
.40493 .14144 L
F
.40588 .14144 m
.42534 .14144 L
.43021 .14144 L
.40663 .14144 L
.40588 .14144 L
F
.40663 .14144 m
.43021 .14144 L
.43364 .14144 L
.40716 .14144 L
.40663 .14144 L
F
.40716 .14144 m
.43364 .14144 L
.43568 .14144 L
.40747 .14144 L
.40716 .14144 L
F
.40747 .14144 m
.43568 .14144 L
.43635 .14144 L
.40758 .14144 L
.40747 .14144 L
F
.40758 .14144 m
.43635 .14144 L
.43568 .14144 L
.40747 .14144 L
.40758 .14144 L
F
.40747 .14144 m
.43568 .14144 L
.43364 .14144 L
.40716 .14144 L
.40747 .14144 L
F
.40716 .14144 m
.43364 .14144 L
.43021 .14144 L
.40663 .14144 L
.40716 .14144 L
F
.40663 .14144 m
.43021 .14144 L
.42534 .14144 L
.40588 .14144 L
.40663 .14144 L
F
.40588 .14144 m
.42534 .14144 L
.41896 .14144 L
.40493 .14144 L
.40588 .14144 L
F
.40493 .14144 m
.41896 .14144 L
.41098 .14144 L
.40376 .14144 L
.40493 .14144 L
F
0 g
.40376 .14144 m
.40493 .14144 L
.40588 .14144 L
.40663 .14144 L
.40716 .14144 L
.40747 .14144 L
.40758 .14144 L
.40747 .14144 L
.40716 .14144 L
.40663 .14144 L
.40588 .14144 L
.40493 .14144 L
.40376 .14144 L
.41098 .14144 L
.41896 .14144 L
.42534 .14144 L
.43021 .14144 L
.43364 .14144 L
.43568 .14144 L
.43635 .14144 L
.43568 .14144 L
.43364 .14144 L
.43021 .14144 L
.42534 .14144 L
.41896 .14144 L
.41098 .14144 L
.40376 .14144 L
s
.11368 .27615 m
.11901 .27615 L
.11901 .275 L
.11368 .275 L
.11368 .27615 L
s
.11368 .275 m
.11901 .275 L
.11901 .27156 L
.11368 .27156 L
.11368 .275 L
s
.11368 .27156 m
.11901 .27156 L
.11901 .2659 L
.11368 .2659 L
.11368 .27156 L
s
.11368 .2659 m
.11901 .2659 L
.11901 .25811 L
.11368 .25811 L
.11368 .2659 L
s
.11368 .25811 m
.11901 .25811 L
.11901 .24832 L
.11368 .24832 L
.11368 .25811 L
s
.11368 .24832 m
.11901 .24832 L
.11901 .2367 L
.11368 .2367 L
.11368 .24832 L
s
.11368 .2367 m
.11901 .2367 L
.11901 .22345 L
.11368 .22345 L
.11368 .2367 L
s
.11368 .22345 m
.11901 .22345 L
.11901 .2088 L
.11368 .2088 L
.11368 .22345 L
s
.11368 .2088 m
.11901 .2088 L
.11901 .19299 L
.11368 .19299 L
.11368 .2088 L
s
.11368 .19299 m
.11901 .19299 L
.11901 .17631 L
.11368 .17631 L
.11368 .19299 L
s
.11368 .17631 m
.11901 .17631 L
.11901 .15903 L
.11368 .15903 L
.11368 .17631 L
s
.11368 .15903 m
.11901 .15903 L
.11901 .14144 L
.11368 .14144 L
.11368 .15903 L
s
.11368 .14144 m
.11901 .14144 L
.11901 .12386 L
.11368 .12386 L
.11368 .14144 L
s
.11368 .12386 m
.11901 .12386 L
.11901 .10658 L
.11368 .10658 L
.11368 .12386 L
s
.11368 .10658 m
.11901 .10658 L
.11901 .08989 L
.11368 .08989 L
.11368 .10658 L
s
.11368 .08989 m
.11901 .08989 L
.11901 .07409 L
.11368 .07409 L
.11368 .08989 L
s
.11368 .07409 m
.11901 .07409 L
.11901 .05944 L
.11368 .05944 L
.11368 .07409 L
s
.11368 .05944 m
.11901 .05944 L
.11901 .04619 L
.11368 .04619 L
.11368 .05944 L
s
.11368 .04619 m
.11901 .04619 L
.11901 .03457 L
.11368 .03457 L
.11368 .04619 L
s
.11368 .03457 m
.11901 .03457 L
.11901 .02478 L
.11368 .02478 L
.11368 .03457 L
s
.11368 .02478 m
.11901 .02478 L
.11901 .01699 L
.11368 .01699 L
.11368 .02478 L
s
.11368 .01699 m
.11901 .01699 L
.11901 .01133 L
.11368 .01133 L
.11368 .01699 L
s
.11368 .01133 m
.11901 .01133 L
.11901 .00789 L
.11368 .00789 L
.11368 .01133 L
s
.11368 .00789 m
.11901 .00789 L
.11901 .00674 L
.11368 .00674 L
.11368 .00789 L
s
.11368 .00674 m
.11901 .00674 L
.11901 .00789 L
.11368 .00789 L
.11368 .00674 L
s
.11368 .00789 m
.11901 .00789 L
.11901 .01133 L
.11368 .01133 L
.11368 .00789 L
s
.11368 .01133 m
.11901 .01133 L
.11901 .01699 L
.11368 .01699 L
.11368 .01133 L
s
.11368 .01699 m
.11901 .01699 L
.11901 .02478 L
.11368 .02478 L
.11368 .01699 L
s
.11368 .02478 m
.11901 .02478 L
.11901 .03457 L
.11368 .03457 L
.11368 .02478 L
s
.11368 .03457 m
.11901 .03457 L
.11901 .04619 L
.11368 .04619 L
.11368 .03457 L
s
.11368 .04619 m
.11901 .04619 L
.11901 .05944 L
.11368 .05944 L
.11368 .04619 L
s
.11368 .05944 m
.11901 .05944 L
.11901 .07409 L
.11368 .07409 L
.11368 .05944 L
s
.11368 .07409 m
.11901 .07409 L
.11901 .08989 L
.11368 .08989 L
.11368 .07409 L
s
.11368 .08989 m
.11901 .08989 L
.11901 .10658 L
.11368 .10658 L
.11368 .08989 L
s
.11368 .10658 m
.11901 .10658 L
.11901 .12386 L
.11368 .12386 L
.11368 .10658 L
s
.11368 .12386 m
.11901 .12386 L
.11901 .14144 L
.11368 .14144 L
.11368 .12386 L
s
.11368 .14144 m
.11901 .14144 L
.11901 .15903 L
.11368 .15903 L
.11368 .14144 L
s
.11368 .15903 m
.11901 .15903 L
.11901 .17631 L
.11368 .17631 L
.11368 .15903 L
s
.11368 .17631 m
.11901 .17631 L
.11901 .19299 L
.11368 .19299 L
.11368 .17631 L
s
.11368 .19299 m
.11901 .19299 L
.11901 .2088 L
.11368 .2088 L
.11368 .19299 L
s
.11368 .2088 m
.11901 .2088 L
.11901 .22345 L
.11368 .22345 L
.11368 .2088 L
s
.11368 .22345 m
.11901 .22345 L
.11901 .2367 L
.11368 .2367 L
.11368 .22345 L
s
.11368 .2367 m
.11901 .2367 L
.11901 .24832 L
.11368 .24832 L
.11368 .2367 L
s
.11368 .24832 m
.11901 .24832 L
.11901 .25811 L
.11368 .25811 L
.11368 .24832 L
s
.11368 .25811 m
.11901 .25811 L
.11901 .2659 L
.11368 .2659 L
.11368 .25811 L
s
.11368 .2659 m
.11901 .2659 L
.11901 .27156 L
.11368 .27156 L
.11368 .2659 L
s
.11368 .27156 m
.11901 .27156 L
.11901 .275 L
.11368 .275 L
.11368 .27156 L
s
.11368 .275 m
.11901 .275 L
.11901 .27615 L
.11368 .27615 L
.11368 .275 L
s
.1638 .24985 m
.21031 .21129 L
.21031 .21069 L
.1638 .24893 L
.1638 .24985 L
s
.1638 .24893 m
.21031 .21069 L
.21031 .20891 L
.1638 .24616 L
.1638 .24893 L
s
.1638 .24616 m
.21031 .20891 L
.21031 .20598 L
.1638 .2416 L
.1638 .24616 L
s
.1638 .2416 m
.21031 .20598 L
.21031 .20193 L
.1638 .23533 L
.1638 .2416 L
s
.1638 .23533 m
.21031 .20193 L
.21031 .19686 L
.1638 .22745 L
.1638 .23533 L
s
.1638 .22745 m
.21031 .19686 L
.21031 .19083 L
.1638 .2181 L
.1638 .22745 L
s
.1638 .2181 m
.21031 .19083 L
.21031 .18396 L
.1638 .20744 L
.1638 .2181 L
s
.1638 .20744 m
.21031 .18396 L
.21031 .17637 L
.1638 .19565 L
.1638 .20744 L
s
.1638 .19565 m
.21031 .17637 L
.21031 .16817 L
.1638 .18293 L
.1638 .19565 L
s
.1638 .18293 m
.21031 .16817 L
.21031 .15952 L
.1638 .1695 L
.1638 .18293 L
s
.1638 .1695 m
.21031 .15952 L
.21031 .15056 L
.1638 .15559 L
.1638 .1695 L
s
.1638 .15559 m
.21031 .15056 L
.21031 .14144 L
.1638 .14144 L
.1638 .15559 L
s
.1638 .14144 m
.21031 .14144 L
.21031 .13233 L
.1638 .12729 L
.1638 .14144 L
s
.1638 .12729 m
.21031 .13233 L
.21031 .12337 L
.1638 .11339 L
.1638 .12729 L
s
.1638 .11339 m
.21031 .12337 L
.21031 .11471 L
.1638 .09996 L
.1638 .11339 L
s
.1638 .09996 m
.21031 .11471 L
.21031 .10652 L
.1638 .08724 L
.1638 .09996 L
s
.1638 .08724 m
.21031 .10652 L
.21031 .09892 L
.1638 .07545 L
.1638 .08724 L
s
.1638 .07545 m
.21031 .09892 L
.21031 .09205 L
.1638 .06479 L
.1638 .07545 L
s
.1638 .06479 m
.21031 .09205 L
.21031 .08603 L
.1638 .05544 L
.1638 .06479 L
s
.1638 .05544 m
.21031 .08603 L
.21031 .08095 L
.1638 .04756 L
.1638 .05544 L
s
.1638 .04756 m
.21031 .08095 L
.21031 .07691 L
.1638 .04129 L
.1638 .04756 L
s
.1638 .04129 m
.21031 .07691 L
.21031 .07398 L
.1638 .03673 L
.1638 .04129 L
s
.1638 .03673 m
.21031 .07398 L
.21031 .07219 L
.1638 .03396 L
.1638 .03673 L
s
.1638 .03396 m
.21031 .07219 L
.21031 .0716 L
.1638 .03303 L
.1638 .03396 L
s
.1638 .03303 m
.21031 .0716 L
.21031 .07219 L
.1638 .03396 L
.1638 .03303 L
s
.1638 .03396 m
.21031 .07219 L
.21031 .07398 L
.1638 .03673 L
.1638 .03396 L
s
.1638 .03673 m
.21031 .07398 L
.21031 .07691 L
.1638 .04129 L
.1638 .03673 L
s
.1638 .04129 m
.21031 .07691 L
.21031 .08095 L
.1638 .04756 L
.1638 .04129 L
s
.1638 .04756 m
.21031 .08095 L
.21031 .08603 L
.1638 .05544 L
.1638 .04756 L
s
.1638 .05544 m
.21031 .08603 L
.21031 .09205 L
.1638 .06479 L
.1638 .05544 L
s
.1638 .06479 m
.21031 .09205 L
.21031 .09892 L
.1638 .07545 L
.1638 .06479 L
s
.1638 .07545 m
.21031 .09892 L
.21031 .10652 L
.1638 .08724 L
.1638 .07545 L
s
.1638 .08724 m
.21031 .10652 L
.21031 .11471 L
.1638 .09996 L
.1638 .08724 L
s
.1638 .09996 m
.21031 .11471 L
.21031 .12337 L
.1638 .11339 L
.1638 .09996 L
s
.1638 .11339 m
.21031 .12337 L
.21031 .13233 L
.1638 .12729 L
.1638 .11339 L
s
.1638 .12729 m
.21031 .13233 L
.21031 .14144 L
.1638 .14144 L
.1638 .12729 L
s
.1638 .14144 m
.21031 .14144 L
.21031 .15056 L
.1638 .15559 L
.1638 .14144 L
s
.1638 .15559 m
.21031 .15056 L
.21031 .15952 L
.1638 .1695 L
.1638 .15559 L
s
.1638 .1695 m
.21031 .15952 L
.21031 .16817 L
.1638 .18293 L
.1638 .1695 L
s
.1638 .18293 m
.21031 .16817 L
.21031 .17637 L
.1638 .19565 L
.1638 .18293 L
s
.1638 .19565 m
.21031 .17637 L
.21031 .18396 L
.1638 .20744 L
.1638 .19565 L
s
.1638 .20744 m
.21031 .18396 L
.21031 .19083 L
.1638 .2181 L
.1638 .20744 L
s
.1638 .2181 m
.21031 .19083 L
.21031 .19686 L
.1638 .22745 L
.1638 .2181 L
s
.1638 .22745 m
.21031 .19686 L
.21031 .20193 L
.1638 .23533 L
.1638 .22745 L
s
.1638 .23533 m
.21031 .20193 L
.21031 .20598 L
.1638 .2416 L
.1638 .23533 L
s
.1638 .2416 m
.21031 .20598 L
.21031 .20891 L
.1638 .24616 L
.1638 .2416 L
s
.1638 .24616 m
.21031 .20891 L
.21031 .21069 L
.1638 .24893 L
.1638 .24616 L
s
.1638 .24893 m
.21031 .21069 L
.21031 .21129 L
.1638 .24985 L
.1638 .24893 L
s
.21031 .21129 m
.24779 .19919 L
.24779 .1987 L
.21031 .21069 L
.21031 .21129 L
s
.21031 .21069 m
.24779 .1987 L
.24779 .19722 L
.21031 .20891 L
.21031 .21069 L
s
.21031 .20891 m
.24779 .19722 L
.24779 .1948 L
.21031 .20597 L
.21031 .20891 L
s
.21031 .20597 m
.24779 .1948 L
.24779 .19145 L
.21031 .20193 L
.21031 .20597 L
s
.21031 .20193 m
.24779 .19145 L
.24779 .18726 L
.21031 .19686 L
.21031 .20193 L
s
.21031 .19686 m
.24779 .18726 L
.24779 .18228 L
.21031 .19083 L
.21031 .19686 L
s
.21031 .19083 m
.24779 .18228 L
.24779 .1766 L
.21031 .18396 L
.21031 .19083 L
s
.21031 .18396 m
.24779 .1766 L
.24779 .17032 L
.21031 .17637 L
.21031 .18396 L
s
.21031 .17637 m
.24779 .17032 L
.24779 .16354 L
.21031 .16817 L
.21031 .17637 L
s
.21031 .16817 m
.24779 .16354 L
.24779 .15639 L
.21031 .15952 L
.21031 .16817 L
s
.21031 .15952 m
.24779 .15639 L
.24779 .14898 L
.21031 .15056 L
.21031 .15952 L
s
.21031 .15056 m
.24779 .14898 L
.24779 .14144 L
.21031 .14144 L
.21031 .15056 L
s
.21031 .14144 m
.24779 .14144 L
.24779 .13391 L
.21031 .13233 L
.21031 .14144 L
s
.21031 .13233 m
.24779 .13391 L
.24779 .1265 L
.21031 .12337 L
.21031 .13233 L
s
.21031 .12337 m
.24779 .1265 L
.24779 .11935 L
.21031 .11472 L
.21031 .12337 L
s
.21031 .11472 m
.24779 .11935 L
.24779 .11257 L
.21031 .10652 L
.21031 .11472 L
s
.21031 .10652 m
.24779 .11257 L
.24779 .10629 L
.21031 .09892 L
.21031 .10652 L
s
.21031 .09892 m
.24779 .10629 L
.24779 .10061 L
.21031 .09206 L
.21031 .09892 L
s
.21031 .09206 m
.24779 .10061 L
.24779 .09563 L
.21031 .08603 L
.21031 .09206 L
s
.21031 .08603 m
.24779 .09563 L
.24779 .09143 L
.21031 .08096 L
.21031 .08603 L
s
.21031 .08096 m
.24779 .09143 L
.24779 .08809 L
.21031 .07691 L
.21031 .08096 L
s
.21031 .07691 m
.24779 .08809 L
.24779 .08566 L
.21031 .07398 L
.21031 .07691 L
s
.21031 .07398 m
.24779 .08566 L
.24779 .08419 L
.21031 .0722 L
.21031 .07398 L
s
.21031 .0722 m
.24779 .08419 L
.24779 .0837 L
.21031 .0716 L
.21031 .0722 L
s
.21031 .0716 m
.24779 .0837 L
.24779 .08419 L
.21031 .0722 L
.21031 .0716 L
s
.21031 .0722 m
.24779 .08419 L
.24779 .08566 L
.21031 .07398 L
.21031 .0722 L
s
.21031 .07398 m
.24779 .08566 L
.24779 .08809 L
.21031 .07691 L
.21031 .07398 L
s
.21031 .07691 m
.24779 .08809 L
.24779 .09143 L
.21031 .08096 L
.21031 .07691 L
s
.21031 .08096 m
.24779 .09143 L
.24779 .09563 L
.21031 .08603 L
.21031 .08096 L
s
.21031 .08603 m
.24779 .09563 L
.24779 .10061 L
.21031 .09206 L
.21031 .08603 L
s
.21031 .09206 m
.24779 .10061 L
.24779 .10629 L
.21031 .09892 L
.21031 .09206 L
s
.21031 .09892 m
.24779 .10629 L
.24779 .11257 L
.21031 .10652 L
.21031 .09892 L
s
.21031 .10652 m
.24779 .11257 L
.24779 .11935 L
.21031 .11472 L
.21031 .10652 L
s
.21031 .11472 m
.24779 .11935 L
.24779 .1265 L
.21031 .12337 L
.21031 .11472 L
s
.21031 .12337 m
.24779 .1265 L
.24779 .13391 L
.21031 .13233 L
.21031 .12337 L
s
.21031 .13233 m
.24779 .13391 L
.24779 .14144 L
.21031 .14144 L
.21031 .13233 L
s
.21031 .14144 m
.24779 .14144 L
.24779 .14898 L
.21031 .15056 L
.21031 .14144 L
s
.21031 .15056 m
.24779 .14898 L
.24779 .15639 L
.21031 .15952 L
.21031 .15056 L
s
.21031 .15952 m
.24779 .15639 L
.24779 .16354 L
.21031 .16817 L
.21031 .15952 L
s
.21031 .16817 m
.24779 .16354 L
.24779 .17032 L
.21031 .17637 L
.21031 .16817 L
s
.21031 .17637 m
.24779 .17032 L
.24779 .1766 L
.21031 .18396 L
.21031 .17637 L
s
.21031 .18396 m
.24779 .1766 L
.24779 .18228 L
.21031 .19083 L
.21031 .18396 L
s
.21031 .19083 m
.24779 .18228 L
.24779 .18726 L
.21031 .19686 L
.21031 .19083 L
s
.21031 .19686 m
.24779 .18726 L
.24779 .19145 L
.21031 .20193 L
.21031 .19686 L
s
.21031 .20193 m
.24779 .19145 L
.24779 .1948 L
.21031 .20597 L
.21031 .20193 L
s
.21031 .20597 m
.24779 .1948 L
.24779 .19722 L
.21031 .20891 L
.21031 .20597 L
s
.21031 .20891 m
.24779 .19722 L
.24779 .1987 L
.21031 .21069 L
.21031 .20891 L
s
.21031 .21069 m
.24779 .1987 L
.24779 .19919 L
.21031 .21129 L
.21031 .21069 L
s
.24779 .19919 m
.25013 .19919 L
.25013 .1987 L
.24779 .1987 L
.24779 .19919 L
s
.24779 .1987 m
.25013 .1987 L
.25013 .19722 L
.24779 .19722 L
.24779 .1987 L
s
.24779 .19722 m
.25013 .19722 L
.25013 .1948 L
.24779 .1948 L
.24779 .19722 L
s
.24779 .1948 m
.25013 .1948 L
.25013 .19145 L
.24779 .19145 L
.24779 .1948 L
s
.24779 .19145 m
.25013 .19145 L
.25013 .18726 L
.24779 .18726 L
.24779 .19145 L
s
.24779 .18726 m
.25013 .18726 L
.25013 .18228 L
.24779 .18228 L
.24779 .18726 L
s
.24779 .18228 m
.25013 .18228 L
.25013 .1766 L
.24779 .1766 L
.24779 .18228 L
s
.24779 .1766 m
.25013 .1766 L
.25013 .17032 L
.24779 .17032 L
.24779 .1766 L
s
.24779 .17032 m
.25013 .17032 L
.25013 .16354 L
.24779 .16354 L
.24779 .17032 L
s
.24779 .16354 m
.25013 .16354 L
.25013 .15639 L
.24779 .15639 L
.24779 .16354 L
s
.24779 .15639 m
.25013 .15639 L
.25013 .14898 L
.24779 .14898 L
.24779 .15639 L
s
.24779 .14898 m
.25013 .14898 L
.25013 .14144 L
.24779 .14144 L
.24779 .14898 L
s
.24779 .14144 m
.25013 .14144 L
.25013 .13391 L
.24779 .13391 L
.24779 .14144 L
s
.24779 .13391 m
.25013 .13391 L
.25013 .1265 L
.24779 .1265 L
.24779 .13391 L
s
.24779 .1265 m
.25013 .1265 L
.25013 .11935 L
.24779 .11935 L
.24779 .1265 L
s
.24779 .11935 m
.25013 .11935 L
.25013 .11257 L
.24779 .11257 L
.24779 .11935 L
s
.24779 .11257 m
.25013 .11257 L
.25013 .10629 L
.24779 .10629 L
.24779 .11257 L
s
.24779 .10629 m
.25013 .10629 L
.25013 .10061 L
.24779 .10061 L
.24779 .10629 L
s
.24779 .10061 m
.25013 .10061 L
.25013 .09563 L
.24779 .09563 L
.24779 .10061 L
s
.24779 .09563 m
.25013 .09563 L
.25013 .09143 L
.24779 .09143 L
.24779 .09563 L
s
.24779 .09143 m
.25013 .09143 L
.25013 .08809 L
.24779 .08809 L
.24779 .09143 L
s
.24779 .08809 m
.25013 .08809 L
.25013 .08566 L
.24779 .08566 L
.24779 .08809 L
s
.24779 .08566 m
.25013 .08566 L
.25013 .08419 L
.24779 .08419 L
.24779 .08566 L
s
.24779 .08419 m
.25013 .08419 L
.25013 .0837 L
.24779 .0837 L
.24779 .08419 L
s
.24779 .0837 m
.25013 .0837 L
.25013 .08419 L
.24779 .08419 L
.24779 .0837 L
s
.24779 .08419 m
.25013 .08419 L
.25013 .08566 L
.24779 .08566 L
.24779 .08419 L
s
.24779 .08566 m
.25013 .08566 L
.25013 .08809 L
.24779 .08809 L
.24779 .08566 L
s
.24779 .08809 m
.25013 .08809 L
.25013 .09143 L
.24779 .09143 L
.24779 .08809 L
s
.24779 .09143 m
.25013 .09143 L
.25013 .09563 L
.24779 .09563 L
.24779 .09143 L
s
.24779 .09563 m
.25013 .09563 L
.25013 .10061 L
.24779 .10061 L
.24779 .09563 L
s
.24779 .10061 m
.25013 .10061 L
.25013 .10629 L
.24779 .10629 L
.24779 .10061 L
s
.24779 .10629 m
.25013 .10629 L
.25013 .11257 L
.24779 .11257 L
.24779 .10629 L
s
.24779 .11257 m
.25013 .11257 L
.25013 .11935 L
.24779 .11935 L
.24779 .11257 L
s
.24779 .11935 m
.25013 .11935 L
.25013 .1265 L
.24779 .1265 L
.24779 .11935 L
s
.24779 .1265 m
.25013 .1265 L
.25013 .13391 L
.24779 .13391 L
.24779 .1265 L
s
.24779 .13391 m
.25013 .13391 L
.25013 .14144 L
.24779 .14144 L
.24779 .13391 L
s
.24779 .14144 m
.25013 .14144 L
.25013 .14898 L
.24779 .14898 L
.24779 .14144 L
s
.24779 .14898 m
.25013 .14898 L
.25013 .15639 L
.24779 .15639 L
.24779 .14898 L
s
.24779 .15639 m
.25013 .15639 L
.25013 .16354 L
.24779 .16354 L
.24779 .15639 L
s
.24779 .16354 m
.25013 .16354 L
.25013 .17032 L
.24779 .17032 L
.24779 .16354 L
s
.24779 .17032 m
.25013 .17032 L
.25013 .1766 L
.24779 .1766 L
.24779 .17032 L
s
.24779 .1766 m
.25013 .1766 L
.25013 .18228 L
.24779 .18228 L
.24779 .1766 L
s
.24779 .18228 m
.25013 .18228 L
.25013 .18726 L
.24779 .18726 L
.24779 .18228 L
s
.24779 .18726 m
.25013 .18726 L
.25013 .19145 L
.24779 .19145 L
.24779 .18726 L
s
.24779 .19145 m
.25013 .19145 L
.25013 .1948 L
.24779 .1948 L
.24779 .19145 L
s
.24779 .1948 m
.25013 .1948 L
.25013 .19722 L
.24779 .19722 L
.24779 .1948 L
s
.24779 .19722 m
.25013 .19722 L
.25013 .1987 L
.24779 .1987 L
.24779 .19722 L
s
.24779 .1987 m
.25013 .1987 L
.25013 .19919 L
.24779 .19919 L
.24779 .1987 L
s
.5 g
.26452 .19146 m
.26452 .19355 L
.26452 .1931 L
.26452 .19104 L
.26452 .19146 L
F
.26452 .19104 m
.26452 .1931 L
.26452 .19177 L
.26452 .18976 L
.26452 .19104 L
F
.26452 .18976 m
.26452 .19177 L
.26452 .18958 L
.26452 .18766 L
.26452 .18976 L
F
.26452 .18766 m
.26452 .18958 L
.26452 .18657 L
.26452 .18476 L
.26452 .18766 L
F
.26452 .18476 m
.26452 .18657 L
.26452 .18278 L
.26452 .18113 L
.26452 .18476 L
F
.26452 .18113 m
.26452 .18278 L
.26452 .17829 L
.26452 .17681 L
.26452 .18113 L
F
.26452 .17681 m
.26452 .17829 L
.26452 .17316 L
.26452 .17189 L
.26452 .17681 L
F
.26452 .17189 m
.26452 .17316 L
.26452 .1675 L
.26452 .16645 L
.26452 .17189 L
F
.26452 .16645 m
.26452 .1675 L
.26452 .16138 L
.26452 .16059 L
.26452 .16645 L
F
.26452 .16059 m
.26452 .16138 L
.26452 .15493 L
.26452 .15439 L
.26452 .16059 L
F
.26452 .15439 m
.26452 .15493 L
.26452 .14824 L
.26452 .14797 L
.26452 .15439 L
F
.26452 .14797 m
.26452 .14824 L
.26452 .14144 L
.26452 .14144 L
.26452 .14797 L
F
.26452 .14144 m
.26452 .14144 L
.26452 .13464 L
.26452 .13492 L
.26452 .14144 L
F
.26452 .13492 m
.26452 .13464 L
.26452 .12796 L
.26452 .1285 L
.26452 .13492 L
F
.26452 .1285 m
.26452 .12796 L
.26452 .1215 L
.26452 .1223 L
.26452 .1285 L
F
.26452 .1223 m
.26452 .1215 L
.26452 .11539 L
.26452 .11643 L
.26452 .1223 L
F
.26452 .11643 m
.26452 .11539 L
.26452 .10973 L
.26452 .11099 L
.26452 .11643 L
F
.26452 .11099 m
.26452 .10973 L
.26452 .1046 L
.26452 .10607 L
.26452 .11099 L
F
.26452 .10607 m
.26452 .1046 L
.26452 .10011 L
.26452 .10176 L
.26452 .10607 L
F
.26452 .10176 m
.26452 .10011 L
.26452 .09632 L
.26452 .09813 L
.26452 .10176 L
F
.26452 .09813 m
.26452 .09632 L
.26452 .09331 L
.26452 .09523 L
.26452 .09813 L
F
.26452 .09523 m
.26452 .09331 L
.26452 .09112 L
.26452 .09313 L
.26452 .09523 L
F
.26452 .09313 m
.26452 .09112 L
.26452 .08979 L
.26452 .09185 L
.26452 .09313 L
F
.26452 .09185 m
.26452 .08979 L
.26452 .08934 L
.26452 .09142 L
.26452 .09185 L
F
.26452 .09142 m
.26452 .08934 L
.26452 .08979 L
.26452 .09185 L
.26452 .09142 L
F
.26452 .09185 m
.26452 .08979 L
.26452 .09112 L
.26452 .09313 L
.26452 .09185 L
F
.26452 .09313 m
.26452 .09112 L
.26452 .09331 L
.26452 .09523 L
.26452 .09313 L
F
.26452 .09523 m
.26452 .09331 L
.26452 .09632 L
.26452 .09813 L
.26452 .09523 L
F
.26452 .09813 m
.26452 .09632 L
.26452 .10011 L
.26452 .10176 L
.26452 .09813 L
F
.26452 .10176 m
.26452 .10011 L
.26452 .1046 L
.26452 .10607 L
.26452 .10176 L
F
.26452 .10607 m
.26452 .1046 L
.26452 .10973 L
.26452 .11099 L
.26452 .10607 L
F
.26452 .11099 m
.26452 .10973 L
.26452 .11539 L
.26452 .11643 L
.26452 .11099 L
F
.26452 .11643 m
.26452 .11539 L
.26452 .1215 L
.26452 .1223 L
.26452 .11643 L
F
.26452 .1223 m
.26452 .1215 L
.26452 .12796 L
.26452 .1285 L
.26452 .1223 L
F
.26452 .1285 m
.26452 .12796 L
.26452 .13464 L
.26452 .13492 L
.26452 .1285 L
F
.26452 .13492 m
.26452 .13464 L
.26452 .14144 L
.26452 .14144 L
.26452 .13492 L
F
.26452 .14144 m
.26452 .14144 L
.26452 .14824 L
.26452 .14797 L
.26452 .14144 L
F
.26452 .14797 m
.26452 .14824 L
.26452 .15493 L
.26452 .15439 L
.26452 .14797 L
F
.26452 .15439 m
.26452 .15493 L
.26452 .16138 L
.26452 .16059 L
.26452 .15439 L
F
.26452 .16059 m
.26452 .16138 L
.26452 .1675 L
.26452 .16645 L
.26452 .16059 L
F
.26452 .16645 m
.26452 .1675 L
.26452 .17316 L
.26452 .17189 L
.26452 .16645 L
F
.26452 .17189 m
.26452 .17316 L
.26452 .17829 L
.26452 .17681 L
.26452 .17189 L
F
.26452 .17681 m
.26452 .17829 L
.26452 .18278 L
.26452 .18113 L
.26452 .17681 L
F
.26452 .18113 m
.26452 .18278 L
.26452 .18657 L
.26452 .18476 L
.26452 .18113 L
F
.26452 .18476 m
.26452 .18657 L
.26452 .18958 L
.26452 .18766 L
.26452 .18476 L
F
.26452 .18766 m
.26452 .18958 L
.26452 .19177 L
.26452 .18976 L
.26452 .18766 L
F
.26452 .18976 m
.26452 .19177 L
.26452 .1931 L
.26452 .19104 L
.26452 .18976 L
F
.26452 .19104 m
.26452 .1931 L
.26452 .19355 L
.26452 .19146 L
.26452 .19104 L
F
.26452 .19355 m
.26452 .19563 L
.26452 .19517 L
.26452 .1931 L
.26452 .19355 L
F
.26452 .1931 m
.26452 .19517 L
.26452 .19379 L
.26452 .19177 L
.26452 .1931 L
F
.26452 .19177 m
.26452 .19379 L
.26452 .19151 L
.26452 .18958 L
.26452 .19177 L
F
.26452 .18958 m
.26452 .19151 L
.26452 .18837 L
.26452 .18657 L
.26452 .18958 L
F
.26452 .18657 m
.26452 .18837 L
.26452 .18443 L
.26452 .18278 L
.26452 .18657 L
F
.26452 .18278 m
.26452 .18443 L
.26452 .17976 L
.26452 .17829 L
.26452 .18278 L
F
.26452 .17829 m
.26452 .17976 L
.26452 .17443 L
.26452 .17316 L
.26452 .17829 L
F
.26452 .17316 m
.26452 .17443 L
.26452 .16854 L
.26452 .1675 L
.26452 .17316 L
F
.26452 .1675 m
.26452 .16854 L
.26452 .16218 L
.26452 .16138 L
.26452 .1675 L
F
.26452 .16138 m
.26452 .16218 L
.26452 .15547 L
.26452 .15493 L
.26452 .16138 L
F
.26452 .15493 m
.26452 .15547 L
.26452 .14852 L
.26452 .14824 L
.26452 .15493 L
F
.26452 .14824 m
.26452 .14852 L
.26452 .14144 L
.26452 .14144 L
.26452 .14824 L
F
.26452 .14144 m
.26452 .14144 L
.26452 .13437 L
.26452 .13464 L
.26452 .14144 L
F
.26452 .13464 m
.26452 .13437 L
.26452 .12742 L
.26452 .12796 L
.26452 .13464 L
F
.26452 .12796 m
.26452 .12742 L
.26452 .12071 L
.26452 .1215 L
.26452 .12796 L
F
.26452 .1215 m
.26452 .12071 L
.26452 .11435 L
.26452 .11539 L
.26452 .1215 L
F
.26452 .11539 m
.26452 .11435 L
.26452 .10846 L
.26452 .10973 L
.26452 .11539 L
F
.26452 .10973 m
.26452 .10846 L
.26452 .10313 L
.26452 .1046 L
.26452 .10973 L
F
.26452 .1046 m
.26452 .10313 L
.26452 .09845 L
.26452 .10011 L
.26452 .1046 L
F
.26452 .10011 m
.26452 .09845 L
.26452 .09452 L
.26452 .09632 L
.26452 .10011 L
F
.26452 .09632 m
.26452 .09452 L
.26452 .09138 L
.26452 .09331 L
.26452 .09632 L
F
.26452 .09331 m
.26452 .09138 L
.26452 .0891 L
.26452 .09112 L
.26452 .09331 L
F
.26452 .09112 m
.26452 .0891 L
.26452 .08772 L
.26452 .08979 L
.26452 .09112 L
F
.26452 .08979 m
.26452 .08772 L
.26452 .08726 L
.26452 .08934 L
.26452 .08979 L
F
.26452 .08934 m
.26452 .08726 L
.26452 .08772 L
.26452 .08979 L
.26452 .08934 L
F
.26452 .08979 m
.26452 .08772 L
.26452 .0891 L
.26452 .09112 L
.26452 .08979 L
F
.26452 .09112 m
.26452 .0891 L
.26452 .09138 L
.26452 .09331 L
.26452 .09112 L
F
.26452 .09331 m
.26452 .09138 L
.26452 .09452 L
.26452 .09632 L
.26452 .09331 L
F
.26452 .09632 m
.26452 .09452 L
.26452 .09845 L
.26452 .10011 L
.26452 .09632 L
F
.26452 .10011 m
.26452 .09845 L
.26452 .10313 L
.26452 .1046 L
.26452 .10011 L
F
.26452 .1046 m
.26452 .10313 L
.26452 .10846 L
.26452 .10973 L
.26452 .1046 L
F
.26452 .10973 m
.26452 .10846 L
.26452 .11435 L
.26452 .11539 L
.26452 .10973 L
F
.26452 .11539 m
.26452 .11435 L
.26452 .12071 L
.26452 .1215 L
.26452 .11539 L
F
.26452 .1215 m
.26452 .12071 L
.26452 .12742 L
.26452 .12796 L
.26452 .1215 L
F
.26452 .12796 m
.26452 .12742 L
.26452 .13437 L
.26452 .13464 L
.26452 .12796 L
F
.26452 .13464 m
.26452 .13437 L
.26452 .14144 L
.26452 .14144 L
.26452 .13464 L
F
.26452 .14144 m
.26452 .14144 L
.26452 .14852 L
.26452 .14824 L
.26452 .14144 L
F
.26452 .14824 m
.26452 .14852 L
.26452 .15547 L
.26452 .15493 L
.26452 .14824 L
F
.26452 .15493 m
.26452 .15547 L
.26452 .16218 L
.26452 .16138 L
.26452 .15493 L
F
.26452 .16138 m
.26452 .16218 L
.26452 .16854 L
.26452 .1675 L
.26452 .16138 L
F
.26452 .1675 m
.26452 .16854 L
.26452 .17443 L
.26452 .17316 L
.26452 .1675 L
F
.26452 .17316 m
.26452 .17443 L
.26452 .17976 L
.26452 .17829 L
.26452 .17316 L
F
.26452 .17829 m
.26452 .17976 L
.26452 .18443 L
.26452 .18278 L
.26452 .17829 L
F
.26452 .18278 m
.26452 .18443 L
.26452 .18837 L
.26452 .18657 L
.26452 .18278 L
F
.26452 .18657 m
.26452 .18837 L
.26452 .19151 L
.26452 .18958 L
.26452 .18657 L
F
.26452 .18958 m
.26452 .19151 L
.26452 .19379 L
.26452 .19177 L
.26452 .18958 L
F
.26452 .19177 m
.26452 .19379 L
.26452 .19517 L
.26452 .1931 L
.26452 .19177 L
F
.26452 .1931 m
.26452 .19517 L
.26452 .19563 L
.26452 .19355 L
.26452 .1931 L
F
.26452 .19563 m
.26452 .19772 L
.26452 .19723 L
.26452 .19517 L
.26452 .19563 L
F
.26452 .19517 m
.26452 .19723 L
.26452 .1958 L
.26452 .19379 L
.26452 .19517 L
F
.26452 .19379 m
.26452 .1958 L
.26452 .19343 L
.26452 .19151 L
.26452 .19379 L
F
.26452 .19151 m
.26452 .19343 L
.26452 .19018 L
.26452 .18837 L
.26452 .19151 L
F
.26452 .18837 m
.26452 .19018 L
.26452 .18609 L
.26452 .18443 L
.26452 .18837 L
F
.26452 .18443 m
.26452 .18609 L
.26452 .18123 L
.26452 .17976 L
.26452 .18443 L
F
.26452 .17976 m
.26452 .18123 L
.26452 .1757 L
.26452 .17443 L
.26452 .17976 L
F
.26452 .17443 m
.26452 .1757 L
.26452 .16958 L
.26452 .16854 L
.26452 .17443 L
F
.26452 .16854 m
.26452 .16958 L
.26452 .16298 L
.26452 .16218 L
.26452 .16854 L
F
.26452 .16218 m
.26452 .16298 L
.26452 .15601 L
.26452 .15547 L
.26452 .16218 L
F
.26452 .15547 m
.26452 .15601 L
.26452 .14879 L
.26452 .14852 L
.26452 .15547 L
F
.26452 .14852 m
.26452 .14879 L
.26452 .14144 L
.26452 .14144 L
.26452 .14852 L
F
.26452 .14144 m
.26452 .14144 L
.26452 .1341 L
.26452 .13437 L
.26452 .14144 L
F
.26452 .13437 m
.26452 .1341 L
.26452 .12688 L
.26452 .12742 L
.26452 .13437 L
F
.26452 .12742 m
.26452 .12688 L
.26452 .11991 L
.26452 .12071 L
.26452 .12742 L
F
.26452 .12071 m
.26452 .11991 L
.26452 .11331 L
.26452 .11435 L
.26452 .12071 L
F
.26452 .11435 m
.26452 .11331 L
.26452 .10719 L
.26452 .10846 L
.26452 .11435 L
F
.26452 .10846 m
.26452 .10719 L
.26452 .10165 L
.26452 .10313 L
.26452 .10846 L
F
.26452 .10313 m
.26452 .10165 L
.26452 .0968 L
.26452 .09845 L
.26452 .10313 L
F
.26452 .09845 m
.26452 .0968 L
.26452 .09271 L
.26452 .09452 L
.26452 .09845 L
F
.26452 .09452 m
.26452 .09271 L
.26452 .08946 L
.26452 .09138 L
.26452 .09452 L
F
.26452 .09138 m
.26452 .08946 L
.26452 .08709 L
.26452 .0891 L
.26452 .09138 L
F
.26452 .0891 m
.26452 .08709 L
.26452 .08565 L
.26452 .08772 L
.26452 .0891 L
F
.26452 .08772 m
.26452 .08565 L
.26452 .08517 L
.26452 .08726 L
.26452 .08772 L
F
.26452 .08726 m
.26452 .08517 L
.26452 .08565 L
.26452 .08772 L
.26452 .08726 L
F
.26452 .08772 m
.26452 .08565 L
.26452 .08709 L
.26452 .0891 L
.26452 .08772 L
F
.26452 .0891 m
.26452 .08709 L
.26452 .08946 L
.26452 .09138 L
.26452 .0891 L
F
.26452 .09138 m
.26452 .08946 L
.26452 .09271 L
.26452 .09452 L
.26452 .09138 L
F
.26452 .09452 m
.26452 .09271 L
.26452 .0968 L
.26452 .09845 L
.26452 .09452 L
F
.26452 .09845 m
.26452 .0968 L
.26452 .10165 L
.26452 .10313 L
.26452 .09845 L
F
.26452 .10313 m
.26452 .10165 L
.26452 .10719 L
.26452 .10846 L
.26452 .10313 L
F
.26452 .10846 m
.26452 .10719 L
.26452 .11331 L
.26452 .11435 L
.26452 .10846 L
F
.26452 .11435 m
.26452 .11331 L
.26452 .11991 L
.26452 .12071 L
.26452 .11435 L
F
.26452 .12071 m
.26452 .11991 L
.26452 .12688 L
.26452 .12742 L
.26452 .12071 L
F
.26452 .12742 m
.26452 .12688 L
.26452 .1341 L
.26452 .13437 L
.26452 .12742 L
F
.26452 .13437 m
.26452 .1341 L
.26452 .14144 L
.26452 .14144 L
.26452 .13437 L
F
.26452 .14144 m
.26452 .14144 L
.26452 .14879 L
.26452 .14852 L
.26452 .14144 L
F
.26452 .14852 m
.26452 .14879 L
.26452 .15601 L
.26452 .15547 L
.26452 .14852 L
F
.26452 .15547 m
.26452 .15601 L
.26452 .16298 L
.26452 .16218 L
.26452 .15547 L
F
.26452 .16218 m
.26452 .16298 L
.26452 .16958 L
.26452 .16854 L
.26452 .16218 L
F
.26452 .16854 m
.26452 .16958 L
.26452 .1757 L
.26452 .17443 L
.26452 .16854 L
F
.26452 .17443 m
.26452 .1757 L
.26452 .18123 L
.26452 .17976 L
.26452 .17443 L
F
.26452 .17976 m
.26452 .18123 L
.26452 .18609 L
.26452 .18443 L
.26452 .17976 L
F
.26452 .18443 m
.26452 .18609 L
.26452 .19018 L
.26452 .18837 L
.26452 .18443 L
F
.26452 .18837 m
.26452 .19018 L
.26452 .19343 L
.26452 .19151 L
.26452 .18837 L
F
.26452 .19151 m
.26452 .19343 L
.26452 .1958 L
.26452 .19379 L
.26452 .19151 L
F
.26452 .19379 m
.26452 .1958 L
.26452 .19723 L
.26452 .19517 L
.26452 .19379 L
F
.26452 .19517 m
.26452 .19723 L
.26452 .19772 L
.26452 .19563 L
.26452 .19517 L
F
.26452 .19772 m
.26452 .1998 L
.26452 .1993 L
.26452 .19723 L
.26452 .19772 L
F
.26452 .19723 m
.26452 .1993 L
.26452 .19781 L
.26452 .1958 L
.26452 .19723 L
F
.26452 .1958 m
.26452 .19781 L
.26452 .19536 L
.26452 .19343 L
.26452 .1958 L
F
.26452 .19343 m
.26452 .19536 L
.26452 .19198 L
.26452 .19018 L
.26452 .19343 L
F
.26452 .19018 m
.26452 .19198 L
.26452 .18774 L
.26452 .18609 L
.26452 .19018 L
F
.26452 .18609 m
.26452 .18774 L
.26452 .18271 L
.26452 .18123 L
.26452 .18609 L
F
.26452 .18123 m
.26452 .18271 L
.26452 .17697 L
.26452 .1757 L
.26452 .18123 L
F
.26452 .1757 m
.26452 .17697 L
.26452 .17062 L
.26452 .16958 L
.26452 .1757 L
F
.26452 .16958 m
.26452 .17062 L
.26452 .16378 L
.26452 .16298 L
.26452 .16958 L
F
.26452 .16298 m
.26452 .16378 L
.26452 .15655 L
.26452 .15601 L
.26452 .16298 L
F
.26452 .15601 m
.26452 .15655 L
.26452 .14906 L
.26452 .14879 L
.26452 .15601 L
F
.26452 .14879 m
.26452 .14906 L
.26452 .14144 L
.26452 .14144 L
.26452 .14879 L
F
.26452 .14144 m
.26452 .14144 L
.26452 .13383 L
.26452 .1341 L
.26452 .14144 L
F
.26452 .1341 m
.26452 .13383 L
.26452 .12634 L
.26452 .12688 L
.26452 .1341 L
F
.26452 .12688 m
.26452 .12634 L
.26452 .11911 L
.26452 .11991 L
.26452 .12688 L
F
.26452 .11991 m
.26452 .11911 L
.26452 .11227 L
.26452 .11331 L
.26452 .11991 L
F
.26452 .11331 m
.26452 .11227 L
.26452 .10592 L
.26452 .10719 L
.26452 .11331 L
F
.26452 .10719 m
.26452 .10592 L
.26452 .10018 L
.26452 .10165 L
.26452 .10719 L
F
.26452 .10165 m
.26452 .10018 L
.26452 .09515 L
.26452 .0968 L
.26452 .10165 L
F
.26452 .0968 m
.26452 .09515 L
.26452 .09091 L
.26452 .09271 L
.26452 .0968 L
F
.26452 .09271 m
.26452 .09091 L
.26452 .08753 L
.26452 .08946 L
.26452 .09271 L
F
.26452 .08946 m
.26452 .08753 L
.26452 .08508 L
.26452 .08709 L
.26452 .08946 L
F
.26452 .08709 m
.26452 .08508 L
.26452 .08359 L
.26452 .08565 L
.26452 .08709 L
F
.26452 .08565 m
.26452 .08359 L
.26452 .08309 L
.26452 .08517 L
.26452 .08565 L
F
.26452 .08517 m
.26452 .08309 L
.26452 .08359 L
.26452 .08565 L
.26452 .08517 L
F
.26452 .08565 m
.26452 .08359 L
.26452 .08508 L
.26452 .08709 L
.26452 .08565 L
F
.26452 .08709 m
.26452 .08508 L
.26452 .08753 L
.26452 .08946 L
.26452 .08709 L
F
.26452 .08946 m
.26452 .08753 L
.26452 .09091 L
.26452 .09271 L
.26452 .08946 L
F
.26452 .09271 m
.26452 .09091 L
.26452 .09515 L
.26452 .0968 L
.26452 .09271 L
F
.26452 .0968 m
.26452 .09515 L
.26452 .10018 L
.26452 .10165 L
.26452 .0968 L
F
.26452 .10165 m
.26452 .10018 L
.26452 .10592 L
.26452 .10719 L
.26452 .10165 L
F
.26452 .10719 m
.26452 .10592 L
.26452 .11227 L
.26452 .11331 L
.26452 .10719 L
F
.26452 .11331 m
.26452 .11227 L
.26452 .11911 L
.26452 .11991 L
.26452 .11331 L
F
.26452 .11991 m
.26452 .11911 L
.26452 .12634 L
.26452 .12688 L
.26452 .11991 L
F
.26452 .12688 m
.26452 .12634 L
.26452 .13383 L
.26452 .1341 L
.26452 .12688 L
F
.26452 .1341 m
.26452 .13383 L
.26452 .14144 L
.26452 .14144 L
.26452 .1341 L
F
.26452 .14144 m
.26452 .14144 L
.26452 .14906 L
.26452 .14879 L
.26452 .14144 L
F
.26452 .14879 m
.26452 .14906 L
.26452 .15655 L
.26452 .15601 L
.26452 .14879 L
F
.26452 .15601 m
.26452 .15655 L
.26452 .16378 L
.26452 .16298 L
.26452 .15601 L
F
.26452 .16298 m
.26452 .16378 L
.26452 .17062 L
.26452 .16958 L
.26452 .16298 L
F
.26452 .16958 m
.26452 .17062 L
.26452 .17697 L
.26452 .1757 L
.26452 .16958 L
F
.26452 .1757 m
.26452 .17697 L
.26452 .18271 L
.26452 .18123 L
.26452 .1757 L
F
.26452 .18123 m
.26452 .18271 L
.26452 .18774 L
.26452 .18609 L
.26452 .18123 L
F
.26452 .18609 m
.26452 .18774 L
.26452 .19198 L
.26452 .19018 L
.26452 .18609 L
F
.26452 .19018 m
.26452 .19198 L
.26452 .19536 L
.26452 .19343 L
.26452 .19018 L
F
.26452 .19343 m
.26452 .19536 L
.26452 .19781 L
.26452 .1958 L
.26452 .19343 L
F
.26452 .1958 m
.26452 .19781 L
.26452 .1993 L
.26452 .19723 L
.26452 .1958 L
F
.26452 .19723 m
.26452 .1993 L
.26452 .1998 L
.26452 .19772 L
.26452 .19723 L
F
.26452 .1998 m
.26452 .20188 L
.26452 .20137 L
.26452 .1993 L
.26452 .1998 L
F
.26452 .1993 m
.26452 .20137 L
.26452 .19982 L
.26452 .19781 L
.26452 .1993 L
F
.26452 .19781 m
.26452 .19982 L
.26452 .19728 L
.26452 .19536 L
.26452 .19781 L
F
.26452 .19536 m
.26452 .19728 L
.26452 .19379 L
.26452 .19198 L
.26452 .19536 L
F
.26452 .19198 m
.26452 .19379 L
.26452 .18939 L
.26452 .18774 L
.26452 .19198 L
F
.26452 .18774 m
.26452 .18939 L
.26452 .18418 L
.26452 .18271 L
.26452 .18774 L
F
.26452 .18271 m
.26452 .18418 L
.26452 .17824 L
.26452 .17697 L
.26452 .18271 L
F
.26452 .17697 m
.26452 .17824 L
.26452 .17166 L
.26452 .17062 L
.26452 .17697 L
F
.26452 .17062 m
.26452 .17166 L
.26452 .16457 L
.26452 .16378 L
.26452 .17062 L
F
.26452 .16378 m
.26452 .16457 L
.26452 .15709 L
.26452 .15655 L
.26452 .16378 L
F
.26452 .15655 m
.26452 .15709 L
.26452 .14933 L
.26452 .14906 L
.26452 .15655 L
F
.26452 .14906 m
.26452 .14933 L
.26452 .14144 L
.26452 .14144 L
.26452 .14906 L
F
.26452 .14144 m
.26452 .14144 L
.26452 .13356 L
.26452 .13383 L
.26452 .14144 L
F
.26452 .13383 m
.26452 .13356 L
.26452 .1258 L
.26452 .12634 L
.26452 .13383 L
F
.26452 .12634 m
.26452 .1258 L
.26452 .11831 L
.26452 .11911 L
.26452 .12634 L
F
.26452 .11911 m
.26452 .11831 L
.26452 .11122 L
.26452 .11227 L
.26452 .11911 L
F
.26452 .11227 m
.26452 .11122 L
.26452 .10465 L
.26452 .10592 L
.26452 .11227 L
F
.26452 .10592 m
.26452 .10465 L
.26452 .09871 L
.26452 .10018 L
.26452 .10592 L
F
.26452 .10018 m
.26452 .09871 L
.26452 .09349 L
.26452 .09515 L
.26452 .10018 L
F
.26452 .09515 m
.26452 .09349 L
.26452 .0891 L
.26452 .09091 L
.26452 .09515 L
F
.26452 .09091 m
.26452 .0891 L
.26452 .0856 L
.26452 .08753 L
.26452 .09091 L
F
.26452 .08753 m
.26452 .0856 L
.26452 .08306 L
.26452 .08508 L
.26452 .08753 L
F
.26452 .08508 m
.26452 .08306 L
.26452 .08152 L
.26452 .08359 L
.26452 .08508 L
F
.26452 .08359 m
.26452 .08152 L
.26452 .081 L
.26452 .08309 L
.26452 .08359 L
F
.26452 .08309 m
.26452 .081 L
.26452 .08152 L
.26452 .08359 L
.26452 .08309 L
F
.26452 .08359 m
.26452 .08152 L
.26452 .08306 L
.26452 .08508 L
.26452 .08359 L
F
.26452 .08508 m
.26452 .08306 L
.26452 .0856 L
.26452 .08753 L
.26452 .08508 L
F
.26452 .08753 m
.26452 .0856 L
.26452 .0891 L
.26452 .09091 L
.26452 .08753 L
F
.26452 .09091 m
.26452 .0891 L
.26452 .09349 L
.26452 .09515 L
.26452 .09091 L
F
.26452 .09515 m
.26452 .09349 L
.26452 .09871 L
.26452 .10018 L
.26452 .09515 L
F
.26452 .10018 m
.26452 .09871 L
.26452 .10465 L
.26452 .10592 L
.26452 .10018 L
F
.26452 .10592 m
.26452 .10465 L
.26452 .11122 L
.26452 .11227 L
.26452 .10592 L
F
.26452 .11227 m
.26452 .11122 L
.26452 .11831 L
.26452 .11911 L
.26452 .11227 L
F
.26452 .11911 m
.26452 .11831 L
.26452 .1258 L
.26452 .12634 L
.26452 .11911 L
F
.26452 .12634 m
.26452 .1258 L
.26452 .13356 L
.26452 .13383 L
.26452 .12634 L
F
.26452 .13383 m
.26452 .13356 L
.26452 .14144 L
.26452 .14144 L
.26452 .13383 L
F
.26452 .14144 m
.26452 .14144 L
.26452 .14933 L
.26452 .14906 L
.26452 .14144 L
F
.26452 .14906 m
.26452 .14933 L
.26452 .15709 L
.26452 .15655 L
.26452 .14906 L
F
.26452 .15655 m
.26452 .15709 L
.26452 .16457 L
.26452 .16378 L
.26452 .15655 L
F
.26452 .16378 m
.26452 .16457 L
.26452 .17166 L
.26452 .17062 L
.26452 .16378 L
F
.26452 .17062 m
.26452 .17166 L
.26452 .17824 L
.26452 .17697 L
.26452 .17062 L
F
.26452 .17697 m
.26452 .17824 L
.26452 .18418 L
.26452 .18271 L
.26452 .17697 L
F
.26452 .18271 m
.26452 .18418 L
.26452 .18939 L
.26452 .18774 L
.26452 .18271 L
F
.26452 .18774 m
.26452 .18939 L
.26452 .19379 L
.26452 .19198 L
.26452 .18774 L
F
.26452 .19198 m
.26452 .19379 L
.26452 .19728 L
.26452 .19536 L
.26452 .19198 L
F
.26452 .19536 m
.26452 .19728 L
.26452 .19982 L
.26452 .19781 L
.26452 .19536 L
F
.26452 .19781 m
.26452 .19982 L
.26452 .20137 L
.26452 .1993 L
.26452 .19781 L
F
.26452 .1993 m
.26452 .20137 L
.26452 .20188 L
.26452 .1998 L
.26452 .1993 L
F
.26452 .20188 m
.26452 .20397 L
.26452 .20343 L
.26452 .20137 L
.26452 .20188 L
F
.26452 .20137 m
.26452 .20343 L
.26452 .20184 L
.26452 .19982 L
.26452 .20137 L
F
.26452 .19982 m
.26452 .20184 L
.26452 .19921 L
.26452 .19728 L
.26452 .19982 L
F
.26452 .19728 m
.26452 .19921 L
.26452 .19559 L
.26452 .19379 L
.26452 .19728 L
F
.26452 .19379 m
.26452 .19559 L
.26452 .19105 L
.26452 .18939 L
.26452 .19379 L
F
.26452 .18939 m
.26452 .19105 L
.26452 .18566 L
.26452 .18418 L
.26452 .18939 L
F
.26452 .18418 m
.26452 .18566 L
.26452 .17951 L
.26452 .17824 L
.26452 .18418 L
F
.26452 .17824 m
.26452 .17951 L
.26452 .17271 L
.26452 .17166 L
.26452 .17824 L
F
.26452 .17166 m
.26452 .17271 L
.26452 .16537 L
.26452 .16457 L
.26452 .17166 L
F
.26452 .16457 m
.26452 .16537 L
.26452 .15763 L
.26452 .15709 L
.26452 .16457 L
F
.26452 .15709 m
.26452 .15763 L
.26452 .14961 L
.26452 .14933 L
.26452 .15709 L
F
.26452 .14933 m
.26452 .14961 L
.26452 .14144 L
.26452 .14144 L
.26452 .14933 L
F
.26452 .14144 m
.26452 .14144 L
.26452 .13328 L
.26452 .13356 L
.26452 .14144 L
F
.26452 .13356 m
.26452 .13328 L
.26452 .12526 L
.26452 .1258 L
.26452 .13356 L
F
.26452 .1258 m
.26452 .12526 L
.26452 .11752 L
.26452 .11831 L
.26452 .1258 L
F
.26452 .11831 m
.26452 .11752 L
.26452 .11018 L
.26452 .11122 L
.26452 .11831 L
F
.26452 .11122 m
.26452 .11018 L
.26452 .10338 L
.26452 .10465 L
.26452 .11122 L
F
.26452 .10465 m
.26452 .10338 L
.26452 .09723 L
.26452 .09871 L
.26452 .10465 L
F
.26452 .09871 m
.26452 .09723 L
.26452 .09184 L
.26452 .09349 L
.26452 .09871 L
F
.26452 .09349 m
.26452 .09184 L
.26452 .0873 L
.26452 .0891 L
.26452 .09349 L
F
.26452 .0891 m
.26452 .0873 L
.26452 .08368 L
.26452 .0856 L
.26452 .0891 L
F
.26452 .0856 m
.26452 .08368 L
.26452 .08105 L
.26452 .08306 L
.26452 .0856 L
F
.26452 .08306 m
.26452 .08105 L
.26452 .07945 L
.26452 .08152 L
.26452 .08306 L
F
.26452 .08152 m
.26452 .07945 L
.26452 .07892 L
.26452 .081 L
.26452 .08152 L
F
.26452 .081 m
.26452 .07892 L
.26452 .07945 L
.26452 .08152 L
.26452 .081 L
F
.26452 .08152 m
.26452 .07945 L
.26452 .08105 L
.26452 .08306 L
.26452 .08152 L
F
.26452 .08306 m
.26452 .08105 L
.26452 .08368 L
.26452 .0856 L
.26452 .08306 L
F
.26452 .0856 m
.26452 .08368 L
.26452 .0873 L
.26452 .0891 L
.26452 .0856 L
F
.26452 .0891 m
.26452 .0873 L
.26452 .09184 L
.26452 .09349 L
.26452 .0891 L
F
.26452 .09349 m
.26452 .09184 L
.26452 .09723 L
.26452 .09871 L
.26452 .09349 L
F
.26452 .09871 m
.26452 .09723 L
.26452 .10338 L
.26452 .10465 L
.26452 .09871 L
F
.26452 .10465 m
.26452 .10338 L
.26452 .11018 L
.26452 .11122 L
.26452 .10465 L
F
.26452 .11122 m
.26452 .11018 L
.26452 .11752 L
.26452 .11831 L
.26452 .11122 L
F
.26452 .11831 m
.26452 .11752 L
.26452 .12526 L
.26452 .1258 L
.26452 .11831 L
F
.26452 .1258 m
.26452 .12526 L
.26452 .13328 L
.26452 .13356 L
.26452 .1258 L
F
.26452 .13356 m
.26452 .13328 L
.26452 .14144 L
.26452 .14144 L
.26452 .13356 L
F
.26452 .14144 m
.26452 .14144 L
.26452 .14961 L
.26452 .14933 L
.26452 .14144 L
F
.26452 .14933 m
.26452 .14961 L
.26452 .15763 L
.26452 .15709 L
.26452 .14933 L
F
.26452 .15709 m
.26452 .15763 L
.26452 .16537 L
.26452 .16457 L
.26452 .15709 L
F
.26452 .16457 m
.26452 .16537 L
.26452 .17271 L
.26452 .17166 L
.26452 .16457 L
F
.26452 .17166 m
.26452 .17271 L
.26452 .17951 L
.26452 .17824 L
.26452 .17166 L
F
.26452 .17824 m
.26452 .17951 L
.26452 .18566 L
.26452 .18418 L
.26452 .17824 L
F
.26452 .18418 m
.26452 .18566 L
.26452 .19105 L
.26452 .18939 L
.26452 .18418 L
F
.26452 .18939 m
.26452 .19105 L
.26452 .19559 L
.26452 .19379 L
.26452 .18939 L
F
.26452 .19379 m
.26452 .19559 L
.26452 .19921 L
.26452 .19728 L
.26452 .19379 L
F
.26452 .19728 m
.26452 .19921 L
.26452 .20184 L
.26452 .19982 L
.26452 .19728 L
F
.26452 .19982 m
.26452 .20184 L
.26452 .20343 L
.26452 .20137 L
.26452 .19982 L
F
.26452 .20137 m
.26452 .20343 L
.26452 .20397 L
.26452 .20188 L
.26452 .20137 L
F
0 g
.26452 .19146 m
.26452 .19104 L
.26452 .18976 L
.26452 .18766 L
.26452 .18476 L
.26452 .18113 L
.26452 .17681 L
.26452 .17189 L
.26452 .16645 L
.26452 .16059 L
.26452 .15439 L
.26452 .14797 L
.26452 .14144 L
.26452 .13492 L
.26452 .1285 L
.26452 .1223 L
.26452 .11643 L
.26452 .11099 L
.26452 .10607 L
.26452 .10176 L
.26452 .09813 L
.26452 .09523 L
.26452 .09313 L
.26452 .09185 L
.26452 .09142 L
.26452 .09185 L
.26452 .09313 L
.26452 .09523 L
.26452 .09813 L
.26452 .10176 L
.26452 .10607 L
.26452 .11099 L
.26452 .11643 L
.26452 .1223 L
.26452 .1285 L
.26452 .13492 L
.26452 .14144 L
.26452 .14797 L
.26452 .15439 L
.26452 .16059 L
.26452 .16645 L
.26452 .17189 L
.26452 .17681 L
.26452 .18113 L
.26452 .18476 L
.26452 .18766 L
.26452 .18976 L
.26452 .19104 L
.26452 .19146 L
s
.26452 .20397 m
.26452 .20343 L
.26452 .20184 L
.26452 .19921 L
.26452 .19559 L
.26452 .19105 L
.26452 .18566 L
.26452 .17951 L
.26452 .17271 L
.26452 .16537 L
.26452 .15763 L
.26452 .14961 L
.26452 .14144 L
.26452 .13328 L
.26452 .12526 L
.26452 .11752 L
.26452 .11018 L
.26452 .10338 L
.26452 .09723 L
.26452 .09184 L
.26452 .0873 L
.26452 .08368 L
.26452 .08105 L
.26452 .07945 L
.26452 .07892 L
.26452 .07945 L
.26452 .08105 L
.26452 .08368 L
.26452 .0873 L
.26452 .09184 L
.26452 .09723 L
.26452 .10338 L
.26452 .11018 L
.26452 .11752 L
.26452 .12526 L
.26452 .13328 L
.26452 .14144 L
.26452 .14961 L
.26452 .15763 L
.26452 .16537 L
.26452 .17271 L
.26452 .17951 L
.26452 .18566 L
.26452 .19105 L
.26452 .19559 L
.26452 .19921 L
.26452 .20184 L
.26452 .20343 L
.26452 .20397 L
s
.27891 .20072 m
.29119 .20072 L
.29119 .20021 L
.27891 .20021 L
.27891 .20072 L
s
.27891 .20021 m
.29119 .20021 L
.29119 .1987 L
.27891 .1987 L
.27891 .20021 L
s
.27891 .1987 m
.29119 .1987 L
.29119 .1962 L
.27891 .1962 L
.27891 .1987 L
s
.27891 .1962 m
.29119 .1962 L
.29119 .19278 L
.27891 .19278 L
.27891 .1962 L
s
.27891 .19278 m
.29119 .19278 L
.29119 .18847 L
.27891 .18847 L
.27891 .19278 L
s
.27891 .18847 m
.29119 .18847 L
.29119 .18336 L
.27891 .18336 L
.27891 .18847 L
s
.27891 .18336 m
.29119 .18336 L
.29119 .17753 L
.27891 .17753 L
.27891 .18336 L
s
.27891 .17753 m
.29119 .17753 L
.29119 .17108 L
.27891 .17108 L
.27891 .17753 L
s
.27891 .17108 m
.29119 .17108 L
.29119 .16413 L
.27891 .16413 L
.27891 .17108 L
s
.27891 .16413 m
.29119 .16413 L
.29119 .15678 L
.27891 .15678 L
.27891 .16413 L
s
.27891 .15678 m
.29119 .15678 L
.29119 .14918 L
.27891 .14918 L
.27891 .15678 L
s
.27891 .14918 m
.29119 .14918 L
.29119 .14144 L
.27891 .14144 L
.27891 .14918 L
s
.27891 .14144 m
.29119 .14144 L
.29119 .13371 L
.27891 .13371 L
.27891 .14144 L
s
.27891 .13371 m
.29119 .13371 L
.29119 .1261 L
.27891 .1261 L
.27891 .13371 L
s
.27891 .1261 m
.29119 .1261 L
.29119 .11876 L
.27891 .11876 L
.27891 .1261 L
s
.27891 .11876 m
.29119 .11876 L
.29119 .11181 L
.27891 .11181 L
.27891 .11876 L
s
.27891 .11181 m
.29119 .11181 L
.29119 .10536 L
.27891 .10536 L
.27891 .11181 L
s
.27891 .10536 m
.29119 .10536 L
.29119 .09953 L
.27891 .09953 L
.27891 .10536 L
s
.27891 .09953 m
.29119 .09953 L
.29119 .09442 L
.27891 .09442 L
.27891 .09953 L
s
.27891 .09442 m
.29119 .09442 L
.29119 .09011 L
.27891 .09011 L
.27891 .09442 L
s
.27891 .09011 m
.29119 .09011 L
.29119 .08668 L
.27891 .08668 L
.27891 .09011 L
s
.27891 .08668 m
.29119 .08668 L
.29119 .08419 L
.27891 .08419 L
.27891 .08668 L
s
.27891 .08419 m
.29119 .08419 L
.29119 .08268 L
.27891 .08268 L
.27891 .08419 L
s
.27891 .08268 m
.29119 .08268 L
.29119 .08217 L
.27891 .08217 L
.27891 .08268 L
s
.27891 .08217 m
.29119 .08217 L
.29119 .08268 L
.27891 .08268 L
.27891 .08217 L
s
.27891 .08268 m
.29119 .08268 L
.29119 .08419 L
.27891 .08419 L
.27891 .08268 L
s
.27891 .08419 m
.29119 .08419 L
.29119 .08668 L
.27891 .08668 L
.27891 .08419 L
s
.27891 .08668 m
.29119 .08668 L
.29119 .09011 L
.27891 .09011 L
.27891 .08668 L
s
.27891 .09011 m
.29119 .09011 L
.29119 .09442 L
.27891 .09442 L
.27891 .09011 L
s
.27891 .09442 m
.29119 .09442 L
.29119 .09953 L
.27891 .09953 L
.27891 .09442 L
s
.27891 .09953 m
.29119 .09953 L
.29119 .10536 L
.27891 .10536 L
.27891 .09953 L
s
.27891 .10536 m
.29119 .10536 L
.29119 .11181 L
.27891 .11181 L
.27891 .10536 L
s
.27891 .11181 m
.29119 .11181 L
.29119 .11876 L
.27891 .11876 L
.27891 .11181 L
s
.27891 .11876 m
.29119 .11876 L
.29119 .1261 L
.27891 .1261 L
.27891 .11876 L
s
.27891 .1261 m
.29119 .1261 L
.29119 .13371 L
.27891 .13371 L
.27891 .1261 L
s
.27891 .13371 m
.29119 .13371 L
.29119 .14144 L
.27891 .14144 L
.27891 .13371 L
s
.27891 .14144 m
.29119 .14144 L
.29119 .14918 L
.27891 .14918 L
.27891 .14144 L
s
.27891 .14918 m
.29119 .14918 L
.29119 .15678 L
.27891 .15678 L
.27891 .14918 L
s
.27891 .15678 m
.29119 .15678 L
.29119 .16413 L
.27891 .16413 L
.27891 .15678 L
s
.27891 .16413 m
.29119 .16413 L
.29119 .17108 L
.27891 .17108 L
.27891 .16413 L
s
.27891 .17108 m
.29119 .17108 L
.29119 .17753 L
.27891 .17753 L
.27891 .17108 L
s
.27891 .17753 m
.29119 .17753 L
.29119 .18336 L
.27891 .18336 L
.27891 .17753 L
s
.27891 .18336 m
.29119 .18336 L
.29119 .18847 L
.27891 .18847 L
.27891 .18336 L
s
.27891 .18847 m
.29119 .18847 L
.29119 .19278 L
.27891 .19278 L
.27891 .18847 L
s
.27891 .19278 m
.29119 .19278 L
.29119 .1962 L
.27891 .1962 L
.27891 .19278 L
s
.27891 .1962 m
.29119 .1962 L
.29119 .1987 L
.27891 .1987 L
.27891 .1962 L
s
.27891 .1987 m
.29119 .1987 L
.29119 .20021 L
.27891 .20021 L
.27891 .1987 L
s
.27891 .20021 m
.29119 .20021 L
.29119 .20072 L
.27891 .20072 L
.27891 .20021 L
s
.29119 .20072 m
.31873 .21149 L
.31873 .21089 L
.29119 .20021 L
.29119 .20072 L
s
.29119 .20021 m
.31873 .21089 L
.31873 .20911 L
.29119 .1987 L
.29119 .20021 L
s
.29119 .1987 m
.31873 .20911 L
.31873 .20616 L
.29119 .1962 L
.29119 .1987 L
s
.29119 .1962 m
.31873 .20616 L
.31873 .20211 L
.29119 .19278 L
.29119 .1962 L
s
.29119 .19278 m
.31873 .20211 L
.31873 .19702 L
.29119 .18847 L
.29119 .19278 L
s
.29119 .18847 m
.31873 .19702 L
.31873 .19098 L
.29119 .18336 L
.29119 .18847 L
s
.29119 .18336 m
.31873 .19098 L
.31873 .18409 L
.29119 .17753 L
.29119 .18336 L
s
.29119 .17753 m
.31873 .18409 L
.31873 .17647 L
.29119 .17108 L
.29119 .17753 L
s
.29119 .17108 m
.31873 .17647 L
.31873 .16825 L
.29119 .16413 L
.29119 .17108 L
s
.29119 .16413 m
.31873 .16825 L
.31873 .15957 L
.29119 .15678 L
.29119 .16413 L
s
.29119 .15678 m
.31873 .15957 L
.31873 .15059 L
.29119 .14918 L
.29119 .15678 L
s
.29119 .14918 m
.31873 .15059 L
.31873 .14144 L
.29119 .14144 L
.29119 .14918 L
s
.29119 .14144 m
.31873 .14144 L
.31873 .1323 L
.29119 .13371 L
.29119 .14144 L
s
.29119 .13371 m
.31873 .1323 L
.31873 .12331 L
.29119 .1261 L
.29119 .13371 L
s
.29119 .1261 m
.31873 .12331 L
.31873 .11464 L
.29119 .11876 L
.29119 .1261 L
s
.29119 .11876 m
.31873 .11464 L
.31873 .10642 L
.29119 .11181 L
.29119 .11876 L
s
.29119 .11181 m
.31873 .10642 L
.31873 .0988 L
.29119 .10536 L
.29119 .11181 L
s
.29119 .10536 m
.31873 .0988 L
.31873 .09191 L
.29119 .09953 L
.29119 .10536 L
s
.29119 .09953 m
.31873 .09191 L
.31873 .08587 L
.29119 .09442 L
.29119 .09953 L
s
.29119 .09442 m
.31873 .08587 L
.31873 .08078 L
.29119 .09011 L
.29119 .09442 L
s
.29119 .09011 m
.31873 .08078 L
.31873 .07673 L
.29119 .08668 L
.29119 .09011 L
s
.29119 .08668 m
.31873 .07673 L
.31873 .07378 L
.29119 .08419 L
.29119 .08668 L
s
.29119 .08419 m
.31873 .07378 L
.31873 .07199 L
.29119 .08268 L
.29119 .08419 L
s
.29119 .08268 m
.31873 .07199 L
.31873 .0714 L
.29119 .08217 L
.29119 .08268 L
s
.29119 .08217 m
.31873 .0714 L
.31873 .07199 L
.29119 .08268 L
.29119 .08217 L
s
.29119 .08268 m
.31873 .07199 L
.31873 .07378 L
.29119 .08419 L
.29119 .08268 L
s
.29119 .08419 m
.31873 .07378 L
.31873 .07673 L
.29119 .08668 L
.29119 .08419 L
s
.29119 .08668 m
.31873 .07673 L
.31873 .08078 L
.29119 .09011 L
.29119 .08668 L
s
.29119 .09011 m
.31873 .08078 L
.31873 .08587 L
.29119 .09442 L
.29119 .09011 L
s
.29119 .09442 m
.31873 .08587 L
.31873 .09191 L
.29119 .09953 L
.29119 .09442 L
s
.29119 .09953 m
.31873 .09191 L
.31873 .0988 L
.29119 .10536 L
.29119 .09953 L
s
.29119 .10536 m
.31873 .0988 L
.31873 .10642 L
.29119 .11181 L
.29119 .10536 L
s
.29119 .11181 m
.31873 .10642 L
.31873 .11464 L
.29119 .11876 L
.29119 .11181 L
s
.29119 .11876 m
.31873 .11464 L
.31873 .12331 L
.29119 .1261 L
.29119 .11876 L
s
.29119 .1261 m
.31873 .12331 L
.31873 .1323 L
.29119 .13371 L
.29119 .1261 L
s
.29119 .13371 m
.31873 .1323 L
.31873 .14144 L
.29119 .14144 L
.29119 .13371 L
s
.29119 .14144 m
.31873 .14144 L
.31873 .15059 L
.29119 .14918 L
.29119 .14144 L
s
.29119 .14918 m
.31873 .15059 L
.31873 .15957 L
.29119 .15678 L
.29119 .14918 L
s
.29119 .15678 m
.31873 .15957 L
.31873 .16825 L
.29119 .16413 L
.29119 .15678 L
s
.29119 .16413 m
.31873 .16825 L
.31873 .17647 L
.29119 .17108 L
.29119 .16413 L
s
.29119 .17108 m
.31873 .17647 L
.31873 .18409 L
.29119 .17753 L
.29119 .17108 L
s
.29119 .17753 m
.31873 .18409 L
.31873 .19098 L
.29119 .18336 L
.29119 .17753 L
s
.29119 .18336 m
.31873 .19098 L
.31873 .19702 L
.29119 .18847 L
.29119 .18336 L
s
.29119 .18847 m
.31873 .19702 L
.31873 .20211 L
.29119 .19278 L
.29119 .18847 L
s
.29119 .19278 m
.31873 .20211 L
.31873 .20616 L
.29119 .1962 L
.29119 .19278 L
s
.29119 .1962 m
.31873 .20616 L
.31873 .20911 L
.29119 .1987 L
.29119 .1962 L
s
.29119 .1987 m
.31873 .20911 L
.31873 .21089 L
.29119 .20021 L
.29119 .1987 L
s
.29119 .20021 m
.31873 .21089 L
.31873 .21149 L
.29119 .20072 L
.29119 .20021 L
s
.32312 .21419 m
.35143 .23843 L
.35143 .2376 L
.32312 .21356 L
.32312 .21419 L
s
.32312 .21356 m
.35143 .2376 L
.35143 .23513 L
.32312 .21171 L
.32312 .21356 L
s
.32312 .21171 m
.35143 .23513 L
.35143 .23105 L
.32312 .20865 L
.32312 .21171 L
s
.32312 .20865 m
.35143 .23105 L
.35143 .22544 L
.32312 .20444 L
.32312 .20865 L
s
.32312 .20444 m
.35143 .22544 L
.35143 .21839 L
.32312 .19915 L
.32312 .20444 L
s
.32312 .19915 m
.35143 .21839 L
.35143 .21003 L
.32312 .19288 L
.32312 .19915 L
s
.32312 .19288 m
.35143 .21003 L
.35143 .20049 L
.32312 .18573 L
.32312 .19288 L
s
.32312 .18573 m
.35143 .20049 L
.35143 .18994 L
.32312 .17782 L
.32312 .18573 L
s
.32312 .17782 m
.35143 .18994 L
.35143 .17856 L
.32312 .16928 L
.32312 .17782 L
s
.32312 .16928 m
.35143 .17856 L
.35143 .16655 L
.32312 .16027 L
.32312 .16928 L
s
.32312 .16027 m
.35143 .16655 L
.35143 .1541 L
.32312 .15094 L
.32312 .16027 L
s
.32312 .15094 m
.35143 .1541 L
.35143 .14144 L
.32312 .14144 L
.32312 .15094 L
s
.32312 .14144 m
.35143 .14144 L
.35143 .12878 L
.32312 .13195 L
.32312 .14144 L
s
.32312 .13195 m
.35143 .12878 L
.35143 .11634 L
.32312 .12262 L
.32312 .13195 L
s
.32312 .12262 m
.35143 .11634 L
.35143 .10433 L
.32312 .11361 L
.32312 .12262 L
s
.32312 .11361 m
.35143 .10433 L
.35143 .09295 L
.32312 .10507 L
.32312 .11361 L
s
.32312 .10507 m
.35143 .09295 L
.35143 .0824 L
.32312 .09716 L
.32312 .10507 L
s
.32312 .09716 m
.35143 .0824 L
.35143 .07286 L
.32312 .09001 L
.32312 .09716 L
s
.32312 .09001 m
.35143 .07286 L
.35143 .0645 L
.32312 .08373 L
.32312 .09001 L
s
.32312 .08373 m
.35143 .0645 L
.35143 .05745 L
.32312 .07845 L
.32312 .08373 L
s
.32312 .07845 m
.35143 .05745 L
.35143 .05184 L
.32312 .07424 L
.32312 .07845 L
s
.32312 .07424 m
.35143 .05184 L
.35143 .04776 L
.32312 .07118 L
.32312 .07424 L
s
.32312 .07118 m
.35143 .04776 L
.35143 .04528 L
.32312 .06932 L
.32312 .07118 L
s
.32312 .06932 m
.35143 .04528 L
.35143 .04445 L
.32312 .0687 L
.32312 .06932 L
s
.32312 .0687 m
.35143 .04445 L
.35143 .04528 L
.32312 .06932 L
.32312 .0687 L
s
.32312 .06932 m
.35143 .04528 L
.35143 .04776 L
.32312 .07118 L
.32312 .06932 L
s
.32312 .07118 m
.35143 .04776 L
.35143 .05184 L
.32312 .07424 L
.32312 .07118 L
s
.32312 .07424 m
.35143 .05184 L
.35143 .05745 L
.32312 .07845 L
.32312 .07424 L
s
.32312 .07845 m
.35143 .05745 L
.35143 .0645 L
.32312 .08373 L
.32312 .07845 L
s
.32312 .08373 m
.35143 .0645 L
.35143 .07286 L
.32312 .09001 L
.32312 .08373 L
s
.32312 .09001 m
.35143 .07286 L
.35143 .0824 L
.32312 .09716 L
.32312 .09001 L
s
.32312 .09716 m
.35143 .0824 L
.35143 .09295 L
.32312 .10507 L
.32312 .09716 L
s
.32312 .10507 m
.35143 .09295 L
.35143 .10433 L
.32312 .11361 L
.32312 .10507 L
s
.32312 .11361 m
.35143 .10433 L
.35143 .11634 L
.32312 .12262 L
.32312 .11361 L
s
.32312 .12262 m
.35143 .11634 L
.35143 .12878 L
.32312 .13195 L
.32312 .12262 L
s
.32312 .13195 m
.35143 .12878 L
.35143 .14144 L
.32312 .14144 L
.32312 .13195 L
s
.32312 .14144 m
.35143 .14144 L
.35143 .1541 L
.32312 .15094 L
.32312 .14144 L
s
.32312 .15094 m
.35143 .1541 L
.35143 .16655 L
.32312 .16027 L
.32312 .15094 L
s
.32312 .16027 m
.35143 .16655 L
.35143 .17856 L
.32312 .16928 L
.32312 .16027 L
s
.32312 .16928 m
.35143 .17856 L
.35143 .18994 L
.32312 .17782 L
.32312 .16928 L
s
.32312 .17782 m
.35143 .18994 L
.35143 .20049 L
.32312 .18573 L
.32312 .17782 L
s
.32312 .18573 m
.35143 .20049 L
.35143 .21003 L
.32312 .19288 L
.32312 .18573 L
s
.32312 .19288 m
.35143 .21003 L
.35143 .21839 L
.32312 .19915 L
.32312 .19288 L
s
.32312 .19915 m
.35143 .21839 L
.35143 .22544 L
.32312 .20444 L
.32312 .19915 L
s
.32312 .20444 m
.35143 .22544 L
.35143 .23105 L
.32312 .20865 L
.32312 .20444 L
s
.32312 .20865 m
.35143 .23105 L
.35143 .23513 L
.32312 .21171 L
.32312 .20865 L
s
.32312 .21171 m
.35143 .23513 L
.35143 .2376 L
.32312 .21356 L
.32312 .21171 L
s
.32312 .21356 m
.35143 .2376 L
.35143 .23843 L
.32312 .21419 L
.32312 .21356 L
s
.40376 .26538 m
.41098 .26538 L
.41098 .26432 L
.40376 .26432 L
.40376 .26538 L
s
.40376 .26432 m
.41098 .26432 L
.41098 .26115 L
.40376 .26115 L
.40376 .26432 L
s
.40376 .26115 m
.41098 .26115 L
.41098 .25594 L
.40376 .25594 L
.40376 .26115 L
s
.40376 .25594 m
.41098 .25594 L
.41098 .24877 L
.40376 .24877 L
.40376 .25594 L
s
.40376 .24877 m
.41098 .24877 L
.41098 .23977 L
.40376 .23977 L
.40376 .24877 L
s
.40376 .23977 m
.41098 .23977 L
.41098 .22908 L
.40376 .22908 L
.40376 .23977 L
s
.40376 .22908 m
.41098 .22908 L
.41098 .21689 L
.40376 .21689 L
.40376 .22908 L
s
.40376 .21689 m
.41098 .21689 L
.41098 .20341 L
.40376 .20341 L
.40376 .21689 L
s
.40376 .20341 m
.41098 .20341 L
.41098 .18887 L
.40376 .18887 L
.40376 .20341 L
s
.40376 .18887 m
.41098 .18887 L
.41098 .17352 L
.40376 .17352 L
.40376 .18887 L
s
.40376 .17352 m
.41098 .17352 L
.41098 .15762 L
.40376 .15762 L
.40376 .17352 L
s
.40376 .15762 m
.41098 .15762 L
.41098 .14144 L
.40376 .14144 L
.40376 .15762 L
s
.40376 .14144 m
.41098 .14144 L
.41098 .12527 L
.40376 .12527 L
.40376 .14144 L
s
.40376 .12527 m
.41098 .12527 L
.41098 .10937 L
.40376 .10937 L
.40376 .12527 L
s
.40376 .10937 m
.41098 .10937 L
.41098 .09402 L
.40376 .09402 L
.40376 .10937 L
s
.40376 .09402 m
.41098 .09402 L
.41098 .07948 L
.40376 .07948 L
.40376 .09402 L
s
.40376 .07948 m
.41098 .07948 L
.41098 .066 L
.40376 .066 L
.40376 .07948 L
s
.40376 .066 m
.41098 .066 L
.41098 .05381 L
.40376 .05381 L
.40376 .066 L
s
.40376 .05381 m
.41098 .05381 L
.41098 .04312 L
.40376 .04312 L
.40376 .05381 L
s
.40376 .04312 m
.41098 .04312 L
.41098 .03412 L
.40376 .03412 L
.40376 .04312 L
s
.40376 .03412 m
.41098 .03412 L
.41098 .02695 L
.40376 .02695 L
.40376 .03412 L
s
.40376 .02695 m
.41098 .02695 L
.41098 .02174 L
.40376 .02174 L
.40376 .02695 L
s
.40376 .02174 m
.41098 .02174 L
.41098 .01857 L
.40376 .01857 L
.40376 .02174 L
s
.40376 .01857 m
.41098 .01857 L
.41098 .01751 L
.40376 .01751 L
.40376 .01857 L
s
.40376 .01751 m
.41098 .01751 L
.41098 .01857 L
.40376 .01857 L
.40376 .01751 L
s
.40376 .01857 m
.41098 .01857 L
.41098 .02174 L
.40376 .02174 L
.40376 .01857 L
s
.40376 .02174 m
.41098 .02174 L
.41098 .02695 L
.40376 .02695 L
.40376 .02174 L
s
.40376 .02695 m
.41098 .02695 L
.41098 .03412 L
.40376 .03412 L
.40376 .02695 L
s
.40376 .03412 m
.41098 .03412 L
.41098 .04312 L
.40376 .04312 L
.40376 .03412 L
s
.40376 .04312 m
.41098 .04312 L
.41098 .05381 L
.40376 .05381 L
.40376 .04312 L
s
.40376 .05381 m
.41098 .05381 L
.41098 .066 L
.40376 .066 L
.40376 .05381 L
s
.40376 .066 m
.41098 .066 L
.41098 .07948 L
.40376 .07948 L
.40376 .066 L
s
.40376 .07948 m
.41098 .07948 L
.41098 .09402 L
.40376 .09402 L
.40376 .07948 L
s
.40376 .09402 m
.41098 .09402 L
.41098 .10937 L
.40376 .10937 L
.40376 .09402 L
s
.40376 .10937 m
.41098 .10937 L
.41098 .12527 L
.40376 .12527 L
.40376 .10937 L
s
.40376 .12527 m
.41098 .12527 L
.41098 .14144 L
.40376 .14144 L
.40376 .12527 L
s
.40376 .14144 m
.41098 .14144 L
.41098 .15762 L
.40376 .15762 L
.40376 .14144 L
s
.40376 .15762 m
.41098 .15762 L
.41098 .17352 L
.40376 .17352 L
.40376 .15762 L
s
.40376 .17352 m
.41098 .17352 L
.41098 .18887 L
.40376 .18887 L
.40376 .17352 L
s
.40376 .18887 m
.41098 .18887 L
.41098 .20341 L
.40376 .20341 L
.40376 .18887 L
s
.40376 .20341 m
.41098 .20341 L
.41098 .21689 L
.40376 .21689 L
.40376 .20341 L
s
.40376 .21689 m
.41098 .21689 L
.41098 .22908 L
.40376 .22908 L
.40376 .21689 L
s
.40376 .22908 m
.41098 .22908 L
.41098 .23977 L
.40376 .23977 L
.40376 .22908 L
s
.40376 .23977 m
.41098 .23977 L
.41098 .24877 L
.40376 .24877 L
.40376 .23977 L
s
.40376 .24877 m
.41098 .24877 L
.41098 .25594 L
.40376 .25594 L
.40376 .24877 L
s
.40376 .25594 m
.41098 .25594 L
.41098 .26115 L
.40376 .26115 L
.40376 .25594 L
s
.40376 .26115 m
.41098 .26115 L
.41098 .26432 L
.40376 .26432 L
.40376 .26115 L
s
.40376 .26432 m
.41098 .26432 L
.41098 .26538 L
.40376 .26538 L
.40376 .26432 L
s
.039 .916 .04 r
.02381 .08772 m
.08416 .08571 L
s
0 0 0 r
2 Mabswid
.08416 .08571 Mdot
.039 .916 .04 r
.5 Mabswid
.02431 .10562 m
.08097 .10436 L
s
0 0 0 r
2 Mabswid
.08097 .10436 Mdot
.039 .916 .04 r
.5 Mabswid
.02461 .12353 m
.07908 .12292 L
s
0 0 0 r
2 Mabswid
.07908 .12292 Mdot
.039 .916 .04 r
.5 Mabswid
.0247 .14144 m
.07846 .14144 L
s
0 0 0 r
2 Mabswid
.07846 .14144 Mdot
.039 .916 .04 r
.5 Mabswid
.02461 .15936 m
.07908 .15997 L
s
0 0 0 r
2 Mabswid
.07908 .15997 Mdot
.039 .916 .04 r
.5 Mabswid
.02431 .17727 m
.08097 .17853 L
s
0 0 0 r
2 Mabswid
.08097 .17853 Mdot
.039 .916 .04 r
.5 Mabswid
.02381 .19517 m
.08416 .19718 L
s
0 0 0 r
2 Mabswid
.08416 .19718 Mdot
.039 .916 .04 r
.5 Mabswid
.08416 .08571 m
.10729 .08705 L
s
0 0 0 r
2 Mabswid
.10729 .08705 Mdot
.039 .916 .04 r
.5 Mabswid
.08097 .10436 m
.10602 .10531 L
s
0 0 0 r
2 Mabswid
.10602 .10531 Mdot
.039 .916 .04 r
.5 Mabswid
.07908 .12292 m
.10527 .12341 L
s
0 0 0 r
2 Mabswid
.10527 .12341 Mdot
.039 .916 .04 r
.5 Mabswid
.07846 .14144 m
.10503 .14144 L
s
0 0 0 r
2 Mabswid
.10503 .14144 Mdot
.039 .916 .04 r
.5 Mabswid
.07908 .15997 m
.10527 .15947 L
s
0 0 0 r
2 Mabswid
.10527 .15947 Mdot
.039 .916 .04 r
.5 Mabswid
.08097 .17853 m
.10602 .17758 L
s
0 0 0 r
2 Mabswid
.10602 .17758 Mdot
.039 .916 .04 r
.5 Mabswid
.08416 .19718 m
.10729 .19584 L
s
0 0 0 r
2 Mabswid
.10729 .19584 Mdot
.039 .916 .04 r
.5 Mabswid
.10729 .08705 m
.11873 .08753 L
s
0 0 0 r
2 Mabswid
.11873 .08753 Mdot
.039 .916 .04 r
.5 Mabswid
.10602 .10531 m
.11222 .10548 L
s
0 0 0 r
2 Mabswid
.11222 .10548 Mdot
.039 .916 .04 r
.5 Mabswid
.10527 .12341 m
.10846 .12346 L
s
0 0 0 r
2 Mabswid
.10846 .12346 Mdot
.039 .916 .04 r
.5 Mabswid
.10503 .14144 m
.10723 .14144 L
s
0 0 0 r
2 Mabswid
.10723 .14144 Mdot
.039 .916 .04 r
.5 Mabswid
.10527 .15947 m
.10846 .15943 L
s
0 0 0 r
2 Mabswid
.10846 .15943 Mdot
.039 .916 .04 r
.5 Mabswid
.10602 .17758 m
.11222 .17741 L
s
0 0 0 r
2 Mabswid
.11222 .17741 Mdot
.039 .916 .04 r
.5 Mabswid
.10729 .19584 m
.11873 .19535 L
s
0 0 0 r
2 Mabswid
.11873 .19535 Mdot
.039 .916 .04 r
.5 Mabswid
.11873 .08753 m
.1874 .09966 L
s
0 0 0 r
2 Mabswid
.1874 .09966 Mdot
.039 .916 .04 r
.5 Mabswid
.11222 .10548 m
.18161 .11336 L
s
0 0 0 r
2 Mabswid
.18161 .11336 Mdot
.039 .916 .04 r
.5 Mabswid
.10846 .12346 m
.17823 .12734 L
s
0 0 0 r
2 Mabswid
.17823 .12734 Mdot
.039 .916 .04 r
.5 Mabswid
.10723 .14144 m
.17712 .14144 L
s
0 0 0 r
2 Mabswid
.17712 .14144 Mdot
.039 .916 .04 r
.5 Mabswid
.10846 .15943 m
.17823 .15555 L
s
0 0 0 r
2 Mabswid
.17823 .15555 Mdot
.039 .916 .04 r
.5 Mabswid
.11222 .17741 m
.18161 .16953 L
s
0 0 0 r
2 Mabswid
.18161 .16953 Mdot
.039 .916 .04 r
.5 Mabswid
.11873 .19535 m
.1874 .18323 L
s
0 0 0 r
2 Mabswid
.1874 .18323 Mdot
.039 .916 .04 r
.5 Mabswid
.1874 .09966 m
.21031 .09978 L
s
0 0 0 r
2 Mabswid
.21031 .09978 Mdot
.039 .916 .04 r
.5 Mabswid
.18161 .11336 m
.21031 .11349 L
s
0 0 0 r
2 Mabswid
.21031 .11349 Mdot
.039 .916 .04 r
.5 Mabswid
.17823 .12734 m
.21031 .12742 L
s
0 0 0 r
2 Mabswid
.21031 .12742 Mdot
.039 .916 .04 r
.5 Mabswid
.17712 .14144 m
.21031 .14144 L
s
0 0 0 r
2 Mabswid
.21031 .14144 Mdot
.039 .916 .04 r
.5 Mabswid
.17823 .15555 m
.21031 .15546 L
s
0 0 0 r
2 Mabswid
.21031 .15546 Mdot
.039 .916 .04 r
.5 Mabswid
.18161 .16953 m
.21031 .16939 L
s
0 0 0 r
2 Mabswid
.21031 .16939 Mdot
.039 .916 .04 r
.5 Mabswid
.1874 .18323 m
.21031 .18311 L
s
0 0 0 r
2 Mabswid
.21031 .18311 Mdot
.039 .916 .04 r
.5 Mabswid
.21031 .09978 m
.2337 .09985 L
s
0 0 0 r
2 Mabswid
.2337 .09985 Mdot
.039 .916 .04 r
.5 Mabswid
.21031 .11349 m
.22665 .11354 L
s
0 0 0 r
2 Mabswid
.22665 .11354 Mdot
.039 .916 .04 r
.5 Mabswid
.21031 .12742 m
.22266 .12744 L
s
0 0 0 r
2 Mabswid
.22266 .12744 Mdot
.039 .916 .04 r
.5 Mabswid
.21031 .14144 m
.22136 .14144 L
s
0 0 0 r
2 Mabswid
.22136 .14144 Mdot
.039 .916 .04 r
.5 Mabswid
.21031 .15546 m
.22266 .15544 L
s
0 0 0 r
2 Mabswid
.22266 .15544 Mdot
.039 .916 .04 r
.5 Mabswid
.21031 .16939 m
.22665 .16935 L
s
0 0 0 r
2 Mabswid
.22665 .16935 Mdot
.039 .916 .04 r
.5 Mabswid
.21031 .18311 m
.2337 .18304 L
s
0 0 0 r
2 Mabswid
.2337 .18304 Mdot
.039 .916 .04 r
.5 Mabswid
.2337 .09985 m
.25013 .1 L
s
0 0 0 r
2 Mabswid
.25013 .1 Mdot
.039 .916 .04 r
.5 Mabswid
.22665 .11354 m
.25013 .11369 L
s
0 0 0 r
2 Mabswid
.25013 .11369 Mdot
.039 .916 .04 r
.5 Mabswid
.22266 .12744 m
.25013 .12754 L
s
0 0 0 r
2 Mabswid
.25013 .12754 Mdot
.039 .916 .04 r
.5 Mabswid
.22136 .14144 m
.25013 .14144 L
s
0 0 0 r
2 Mabswid
.25013 .14144 Mdot
.039 .916 .04 r
.5 Mabswid
.22266 .15544 m
.25013 .15535 L
s
0 0 0 r
2 Mabswid
.25013 .15535 Mdot
.039 .916 .04 r
.5 Mabswid
.22665 .16935 m
.25013 .16919 L
s
0 0 0 r
2 Mabswid
.25013 .16919 Mdot
.039 .916 .04 r
.5 Mabswid
.2337 .18304 m
.25013 .18289 L
s
0 0 0 r
2 Mabswid
.25013 .18289 Mdot
.039 .916 .04 r
.5 Mabswid
.25013 .1 m
.26452 .10021 L
s
0 0 0 r
2 Mabswid
.26452 .10021 Mdot
.039 .916 .04 r
.5 Mabswid
.25013 .11369 m
.26452 .11385 L
s
0 0 0 r
2 Mabswid
.26452 .11385 Mdot
.039 .916 .04 r
.5 Mabswid
.25013 .12754 m
.26452 .12762 L
s
0 0 0 r
2 Mabswid
.26452 .12762 Mdot
.039 .916 .04 r
.5 Mabswid
.25013 .14144 m
.26452 .14144 L
s
0 0 0 r
2 Mabswid
.26452 .14144 Mdot
.039 .916 .04 r
.5 Mabswid
.25013 .15535 m
.26452 .15527 L
s
0 0 0 r
2 Mabswid
.26452 .15527 Mdot
.039 .916 .04 r
.5 Mabswid
.25013 .16919 m
.26452 .16904 L
s
0 0 0 r
2 Mabswid
.26452 .16904 Mdot
.039 .916 .04 r
.5 Mabswid
.25013 .18289 m
.26452 .18267 L
s
0 0 0 r
2 Mabswid
.26452 .18267 Mdot
.039 .916 .04 r
.5 Mabswid
.26452 .10021 m
.27891 .10043 L
s
0 0 0 r
2 Mabswid
.27891 .10043 Mdot
.039 .916 .04 r
.5 Mabswid
.26452 .11385 m
.27891 .114 L
s
0 0 0 r
2 Mabswid
.27891 .114 Mdot
.039 .916 .04 r
.5 Mabswid
.26452 .12762 m
.27891 .12769 L
s
0 0 0 r
2 Mabswid
.27891 .12769 Mdot
.039 .916 .04 r
.5 Mabswid
.26452 .14144 m
.27891 .14144 L
s
0 0 0 r
2 Mabswid
.27891 .14144 Mdot
.039 .916 .04 r
.5 Mabswid
.26452 .15527 m
.27891 .15519 L
s
0 0 0 r
2 Mabswid
.27891 .15519 Mdot
.039 .916 .04 r
.5 Mabswid
.26452 .16904 m
.27891 .16889 L
s
0 0 0 r
2 Mabswid
.27891 .16889 Mdot
.039 .916 .04 r
.5 Mabswid
.26452 .18267 m
.27891 .18246 L
s
0 0 0 r
2 Mabswid
.27891 .18246 Mdot
.039 .916 .04 r
.5 Mabswid
.27891 .10043 m
.2989 .10061 L
s
0 0 0 r
2 Mabswid
.2989 .10061 Mdot
.039 .916 .04 r
.5 Mabswid
.27891 .114 m
.30258 .11416 L
s
0 0 0 r
2 Mabswid
.30258 .11416 Mdot
.039 .916 .04 r
.5 Mabswid
.27891 .12769 m
.30475 .12778 L
s
0 0 0 r
2 Mabswid
.30475 .12778 Mdot
.039 .916 .04 r
.5 Mabswid
.27891 .14144 m
.30547 .14144 L
s
0 0 0 r
2 Mabswid
.30547 .14144 Mdot
.039 .916 .04 r
.5 Mabswid
.27891 .15519 m
.30475 .15511 L
s
0 0 0 r
2 Mabswid
.30475 .15511 Mdot
.039 .916 .04 r
.5 Mabswid
.27891 .16889 m
.30258 .16873 L
s
0 0 0 r
2 Mabswid
.30258 .16873 Mdot
.039 .916 .04 r
.5 Mabswid
.27891 .18246 m
.2989 .18228 L
s
0 0 0 r
2 Mabswid
.2989 .18228 Mdot
.039 .916 .04 r
.5 Mabswid
.2989 .10061 m
.31873 .10086 L
s
0 0 0 r
2 Mabswid
.31873 .10086 Mdot
.039 .916 .04 r
.5 Mabswid
.30258 .11416 m
.31873 .1143 L
s
0 0 0 r
2 Mabswid
.31873 .1143 Mdot
.039 .916 .04 r
.5 Mabswid
.30475 .12778 m
.31873 .12784 L
s
0 0 0 r
2 Mabswid
.31873 .12784 Mdot
.039 .916 .04 r
.5 Mabswid
.30547 .14144 m
.31873 .14144 L
s
0 0 0 r
2 Mabswid
.31873 .14144 Mdot
.039 .916 .04 r
.5 Mabswid
.30475 .15511 m
.31873 .15504 L
s
0 0 0 r
2 Mabswid
.31873 .15504 Mdot
.039 .916 .04 r
.5 Mabswid
.30258 .16873 m
.31873 .16859 L
s
0 0 0 r
2 Mabswid
.31873 .16859 Mdot
.039 .916 .04 r
.5 Mabswid
.2989 .18228 m
.31873 .18203 L
s
0 0 0 r
2 Mabswid
.31873 .18203 Mdot
.039 .916 .04 r
.5 Mabswid
.31873 .10086 m
.34584 .1014 L
s
0 0 0 r
2 Mabswid
.34584 .1014 Mdot
.039 .916 .04 r
.5 Mabswid
.31873 .1143 m
.35053 .11474 L
s
0 0 0 r
2 Mabswid
.35053 .11474 Mdot
.039 .916 .04 r
.5 Mabswid
.31873 .12784 m
.35324 .12809 L
s
0 0 0 r
2 Mabswid
.35324 .12809 Mdot
.039 .916 .04 r
.5 Mabswid
.31873 .14144 m
.35413 .14144 L
s
0 0 0 r
2 Mabswid
.35413 .14144 Mdot
.039 .916 .04 r
.5 Mabswid
.31873 .15504 m
.35324 .1548 L
s
0 0 0 r
2 Mabswid
.35324 .1548 Mdot
.039 .916 .04 r
.5 Mabswid
.31873 .16859 m
.35053 .16815 L
s
0 0 0 r
2 Mabswid
.35053 .16815 Mdot
.039 .916 .04 r
.5 Mabswid
.31873 .18203 m
.34584 .18148 L
s
0 0 0 r
2 Mabswid
.34584 .18148 Mdot
.039 .916 .04 r
.5 Mabswid
.34584 .1014 m
.39078 .09547 L
s
0 0 0 r
2 Mabswid
.39078 .09547 Mdot
.039 .916 .04 r
.5 Mabswid
.35053 .11474 m
.39592 .11093 L
s
0 0 0 r
2 Mabswid
.39592 .11093 Mdot
.039 .916 .04 r
.5 Mabswid
.35324 .12809 m
.39886 .12622 L
s
0 0 0 r
2 Mabswid
.39886 .12622 Mdot
.039 .916 .04 r
.5 Mabswid
.35413 .14144 m
.39982 .14144 L
s
0 0 0 r
2 Mabswid
.39982 .14144 Mdot
.039 .916 .04 r
.5 Mabswid
.35324 .1548 m
.39886 .15666 L
s
0 0 0 r
2 Mabswid
.39886 .15666 Mdot
.039 .916 .04 r
.5 Mabswid
.35053 .16815 m
.39592 .17196 L
s
0 0 0 r
2 Mabswid
.39592 .17196 Mdot
.039 .916 .04 r
.5 Mabswid
.34584 .18148 m
.39078 .18742 L
s
0 0 0 r
2 Mabswid
.39078 .18742 Mdot
.039 .916 .04 r
.5 Mabswid
.39078 .09547 m
.40706 .0956 L
s
0 0 0 r
2 Mabswid
.40706 .0956 Mdot
.039 .916 .04 r
.5 Mabswid
.39592 .11093 m
.40735 .111 L
s
0 0 0 r
2 Mabswid
.40735 .111 Mdot
.039 .916 .04 r
.5 Mabswid
.39886 .12622 m
.40752 .12625 L
s
0 0 0 r
2 Mabswid
.40752 .12625 Mdot
.039 .916 .04 r
.5 Mabswid
.39982 .14144 m
.40758 .14144 L
s
0 0 0 r
2 Mabswid
.40758 .14144 Mdot
.039 .916 .04 r
.5 Mabswid
.39886 .15666 m
.40752 .15663 L
s
0 0 0 r
2 Mabswid
.40752 .15663 Mdot
.039 .916 .04 r
.5 Mabswid
.39592 .17196 m
.40735 .17189 L
s
0 0 0 r
2 Mabswid
.40735 .17189 Mdot
.039 .916 .04 r
.5 Mabswid
.39078 .18742 m
.40706 .18728 L
s
0 0 0 r
2 Mabswid
.40706 .18728 Mdot
.039 .916 .04 r
.5 Mabswid
.40706 .0956 m
.43299 .09551 L
s
0 0 0 r
2 Mabswid
.43299 .09551 Mdot
.039 .916 .04 r
.5 Mabswid
.40735 .111 m
.43488 .11095 L
s
0 0 0 r
2 Mabswid
.43488 .11095 Mdot
.039 .916 .04 r
.5 Mabswid
.40752 .12625 m
.43599 .12623 L
s
0 0 0 r
2 Mabswid
.43599 .12623 Mdot
.039 .916 .04 r
.5 Mabswid
.40758 .14144 m
.43635 .14144 L
s
0 0 0 r
2 Mabswid
.43635 .14144 Mdot
.039 .916 .04 r
.5 Mabswid
.40752 .15663 m
.43599 .15666 L
s
0 0 0 r
2 Mabswid
.43599 .15666 Mdot
.039 .916 .04 r
.5 Mabswid
.40735 .17189 m
.43488 .17194 L
s
0 0 0 r
2 Mabswid
.43488 .17194 Mdot
.039 .916 .04 r
.5 Mabswid
.40706 .18728 m
.43299 .18738 L
s
0 0 0 r
2 Mabswid
.43299 .18738 Mdot
.039 .916 .04 r
.5 Mabswid
.43299 .09551 m
.97619 .14156 L
s
0 0 0 r
2 Mabswid
.97619 .14156 Mdot
.039 .916 .04 r
.5 Mabswid
.43488 .11095 m
.97619 .14154 L
s
0 0 0 r
2 Mabswid
.97619 .14154 Mdot
.039 .916 .04 r
.5 Mabswid
.43599 .12623 m
.97619 .14148 L
s
0 0 0 r
2 Mabswid
.97619 .14148 Mdot
.039 .916 .04 r
.5 Mabswid
.43635 .14144 m
.97619 .14144 L
s
0 0 0 r
2 Mabswid
.97619 .14144 Mdot
.039 .916 .04 r
.5 Mabswid
.43599 .15666 m
.97619 .14141 L
s
0 0 0 r
2 Mabswid
.97619 .14141 Mdot
.039 .916 .04 r
.5 Mabswid
.43488 .17194 m
.97619 .14135 L
s
0 0 0 r
2 Mabswid
.97619 .14135 Mdot
.039 .916 .04 r
.5 Mabswid
.43299 .18738 m
.97619 .14132 L
s
0 0 0 r
2 Mabswid
.97619 .14132 Mdot
0 0 m
1 0 L
1 .28289 L
0 .28289 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{834.875, 236.188},
  ImageMargins->{{28, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000=20000k2000`400?l00000o`00003oo`3ooooo
0?ooool0ooooA@3oool00?l0ooooo`3ooooo0?ooodD0oooo003o0?ooool0ooooo`3ooom50?ooo`00
o`3ooooo0?ooool0ooooA@3oool00?l0ooooo`3ooooo0?ooodD0oooo003o0?ooool0ooooo`3ooom5
0?ooo`00G`3oool600000?l0ooooo`3ooooO0?ooo`00G`3oool600000?l0ooooo`3ooooO0?ooo`00
GP3oool2000000@0Ogmo00<000000?ooo`3oool0o`3ooooo0?ooomd0oooo001N0?ooo`8000000`1o
Ogl200000?l0ooooo`3ooooO0?ooo`00G@3oool00`000000Ogmo0000000500000?l0ooooo`3ooooO
0?ooo`00G@3oool00`000000Ogmo0000000307moO`800000o`3ooooo0?oooml0oooo001L0?ooo`04
0000001oOgl0Ogmo000000<0Ogmo0P00003o0?ooool0oooog`3oool005`0oooo00@0000007moO`1o
Ogl000000`1oOgl200000?l0ooooo`3ooooO0?ooo`00F`3oool010000000Ogmo07moO`1oOgl60000
0?l0ooooo`3ooooO0?ooo`00F`3oool01@000000Ogmo07moO`1oOgl000000080Ogmo00<000000?oo
o`000000j`3oool700000?l0ooook03oool005X0oooo00<0000007moO`1oOgl00P1oOgl01P000000
Ogmo07moO`000000oooo00000>/0oooo1`00003o0?ooon`0oooo001J0?ooo`030000001oOgl0Ogmo
0080Ogmo00H0000007moO`1oOgl000000?ooo`00003[0?ooo`030000001oOgl0Ogmo00<0Ogmo0P00
003o0?ooon/0oooo001J0?ooo`030000001oOgl0Ogmo0080Ogmo00H0000007moO`1oOgl000000?oo
o`00003[0?ooo`P00000o`3oooo[0?ooo`00F@3oool00`000000Ogmo07moO`0307moO`030000001o
Ogl000000080oooo00<000000?ooo`3oool0j@3oool00`000000Ogmo07moO`0307moO`800000o`3o
ooo[0?ooo`00F@3oool00`000000Ogmo07moO`0307moO`030000001oOgl000000080oooo00<00000
0?ooo`3oool0j@3oool00`000000Ogmo07moO`0307moO`030000001oOgl000000?l0oooojP3oool0
05P0oooo00<0000007moO`1oOgl0101oOgl600000>/0oooo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo0000003o0?ooonX0oooo001H0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`00
00000P3oool00`000000oooo0?ooo`3Y0?ooo`030000001oOgl0Ogmo00<0Ogmo00@0000007moO`1o
Ogl00000o`3ooooY0?ooo`00E`3oool00`000000Ogmo07moO`0507moO`030000001oOgl000000080
oooo00<000000?ooo`3oool0j@3oool700000080Ogmo00<000000?ooo`3oool0o`3ooooW0?ooo`00
E`3oool00`000000Ogmo07moO`0507moO`8000000`3oool00`000000oooo0?ooo`3Y0?ooo`800000
101oOgl01@000000Ogmo07moO`1oOgl000000?l0ooooj03oool005H0oooo00<0000007moO`1oOgl0
1P1oOgl2000000<0oooo00<000000?ooo`3oool0j@3oool2000000@0Ogmo00D0000007moO`1oOgl0
Ogmo0000003o0?ooonP0oooo001F0?ooo`030000001oOgl0Ogmo00H0Ogmo0P0000030?ooo`030000
003oool0oooo0>T0oooo0P00000407moO`050000001oOgl0Ogmo07moO`000000o`3ooooX0?ooo`00
E@3oool00`000000Ogmo07moO`0707moO`8000000`3oool00`000000oooo0?ooo`3Y0?ooo`800000
101oOgl00`000000Ogmo07moO`0207moO`030000003oool0oooo0?l0ooooi@3oool005D0oooo00<0
000007moO`1oOgl01`1oOgl2000000<0oooo00<000000?ooo`3oool08@3oool300000<D0oooo0P00
000407moO`030000001oOgl0Ogmo0080Ogmo00<000000?ooo`3oool0o`3ooooU0?ooo`00E@3oool0
0`000000Ogmo07moO`0707moO`H000008P3oool00`000000Ogmo0000000200000<@0oooo1`000005
07moO`030000003oool0oooo0?l0ooooi03oool005@0oooo00<0000007moO`1oOgl0201oOgl00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo01l0oooo00D0000007moO`1oOgl0000007moO`02
00000<<0oooo0P00000407moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0o`3ooooT
0?ooo`00E03oool00`000000Ogmo07moO`0807moO`030000003oool0oooo0080oooo00<000000?oo
o`3oool07P3oool010000000Ogmo07moO`1oOgl20000000307moO`00000000000<80oooo0P000004
07moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0o`3ooooT0?ooo`00D`3oool00`00
0000Ogmo07moO`0907moO`030000003oool0oooo0080oooo00<000000?ooo`3oool07@3oool00`00
0000Ogmo07moO`0207moO`040000001oOgl0000007moO`800000`@3oool2000000@0Ogmo00<00000
07moO`1oOgl0101oOgl00`000000oooo0?ooo`3o0?ooon<0oooo001C0?ooo`030000001oOgl0Ogmo
00T0Ogmo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0L0?ooo`030000001oOgl0Ogmo
00<0Ogmo00D0000007moO`1oOgl0000007moO`0300000;l0oooo0P00000407moO`030000001oOgl0
Ogmo00@0Ogmo00<000000?ooo`3oool0o`3ooooS0?ooo`00D`3oool00`000000Ogmo07moO`0907mo
O`030000003oool0oooo0080oooo00<000000?ooo`3oool06`3oool00`000000Ogmo07moO`0407mo
O`050000001oOgl0Ogmo07moO`0000000P1oOgl200000;h0oooo0P00000407moO`030000001oOgl0
Ogmo00@0Ogmo00<000000?ooo`3oool0o`3ooooS0?ooo`00DP3oool00`000000Ogmo07moO`0907mo
O`800000103oool00`000000oooo0?ooo`0I0?ooo`8000001`1oOgl2000000<0Ogmo0P0000000`1o
Ogl000000000002m0?ooo`800000101oOgl00`000000Ogmo07moO`0507moO`030000003oool0oooo
0?l0oooohP3oool00580oooo00<0000007moO`1oOgl02@1oOgl2000000@0oooo00<000000?ooo`3o
ool0603oool00`000000Ogmo07moO`0707moO`030000001oOgl0000000@0Ogmo00@0000007moO`00
00000000_03oool7000000L0Ogmo00<000000?ooo`3oool0o`3ooooR0?ooo`00DP3oool00`000000
Ogmo07moO`0907moO`800000103oool00`000000oooo0?ooo`0G0?ooo`030000001oOgl0Ogmo00P0
Ogmo00@0000007moO`1oOgl00000101oOgl00`000000Ogmo00000002000008h0oooo0`00000Y0?oo
o`800000101oOgl00`000000Ogmo07moO`0507moO`030000003oool0oooo0?l0oooohP3oool00540
oooo00<0000007moO`1oOgl02P1oOgl2000000@0oooo00<000000?ooo`3oool05P3oool00`000000
Ogmo07moO`0907moO`040000001oOgl0Ogmo07moO`8000000`1oOgl00`000000Ogmo07moO`020000
08`0oooo0`0000000`1oOgl000000?ooo`0W0?ooo`800000101oOgl00`000000Ogmo07moO`0607mo
O`030000003oool0oooo0?l0ooooh@3oool00540oooo00<0000007moO`1oOgl02P1oOgl7000001L0
oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0307moO`040000001oOgl0Ogmo07mo
O`80000000<0Ogmo000000000000RP3oool20000000507moO`000000Ogmo07moO`0000009`3oool2
000000@0Ogmo00<0000007moO`1oOgl01P1oOgl00`000000oooo0?ooo`3o0?ooon40oooo001@0?oo
o`030000001oOgl0Ogmo00/0Ogmo0P0000040?ooo`030000003oool0oooo01@0oooo00<0000007mo
O`1oOgl02`1oOgl2000000D0Ogmo00<0000007moO`1oOgl00P1oOgl010000000Ogmo000000000028
0?ooo`80000000<0Ogmo0000000000000`1oOgl00`000000oooo0?ooo`0T0?ooo`800000101oOgl0
0`000000Ogmo07moO`0607moO`030000003oool0oooo0?l0ooooh@3oool00500oooo00<0000007mo
O`1oOgl02P1oOgl00`000000oooo000000040?ooo`030000003oool0oooo01<0oooo00<0000007mo
O`1oOgl0301oOgl00`000000Ogmo0000000507moO`8000000`1oOgl010000000Ogmo000000000026
0?ooo`80000000@0Ogmo0000001oOgl00000101oOgl00`000000oooo0?ooo`0S0?ooo`030000003o
ool0000000<0Ogmo00<0000007moO`1oOgl01`1oOgl00`000000oooo0?ooo`3o0?ooon00oooo001@
0?ooo`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`000000103oool00`000000oooo0?ooo`0B
0?ooo`030000001oOgl0Ogmo00d0Ogmo00@0000007moO`1oOgl000001P1oOgl01@000000Ogmo07mo
O`1oOgl000000080Ogmo0P0000220?ooo`<0000000D0Ogmo0000001oOgl0Ogmo0000000507moO`03
0000003oool0oooo0280oooo00<000000?ooo`0000000`1oOgl00`000000Ogmo07moO`0707moO`03
0000003oool0oooo0?l0ooooh03oool004l0oooo00<0000007moO`1oOgl02`1oOgl00`000000oooo
000000040?ooo`030000003oool0oooo0140oooo00<0000007moO`1oOgl03P1oOgl010000000Ogmo
07moO`1oOgl2000000D0Ogmo00@0000007moO`1oOgl0Ogmo0P0000000`1oOgl00000000000200?oo
o`<0000000@0Ogmo0000001oOgl0Ogmo0P00000607moO`030000003oool0oooo0240oooo00<00000
0?ooo`0000000`1oOgl00`000000Ogmo07moO`0707moO`030000003oool0oooo0?l0ooooh03oool0
04l0oooo00<0000007moO`1oOgl02`1oOgl00`000000oooo000000040?ooo`030000003oool0oooo
0140oooo00<0000007moO`1oOgl03P1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
00<0Ogmo0P00000307moO`040000001oOgl00000000007h0oooo0P0000000`1oOgl0000000000002
07moO`030000001oOgl0000000L0Ogmo00<000000?ooo`3oool0803oool00`000000oooo00000003
07moO`030000001oOgl0Ogmo00L0Ogmo00<000000?ooo`3oool0o`3ooooP0?ooo`00C`3oool00`00
0000Ogmo07moO`0;07moO`030000003oool0000000@0oooo00<000000?ooo`3oool0403oool00`00
0000Ogmo07moO`0?07moO`030000001oOgl0Ogmo00@0Ogmo0P00000507moO`050000001oOgl0Ogmo
07moO`0000000P1oOgl00`000000oooo0?ooo`1j0?ooo`80000000<0Ogmo0000001oOgl00P1oOgl0
10000000Ogmo07moO`00000807moO`030000003oool0oooo01l0oooo1`00000:07moO`030000003o
ool0oooo0?l0oooog`3oool004h0oooo00<0000007moO`1oOgl0301oOgl00`000000oooo00000004
0?ooo`030000003oool0oooo00l0oooo00<0000007moO`1oOgl0401oOgl2000000L0Ogmo00<00000
07moO`1oOgl00`1oOgl010000000Ogmo07moO`1oOgl20000000307moO`000000000007T0oooo0P00
00000`1oOgl0000007moO`0207moO`050000001oOgl0Ogmo07moO`0000002@1oOgl00`000000oooo
0?ooo`0N0?ooo`030000003oool0000000<0Ogmo00<0000007moO`1oOgl0201oOgl00`000000oooo
0?ooo`3o0?oooml0oooo001>0?ooo`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`000000103o
ool00`000000oooo0?ooo`0>0?ooo`030000001oOgl0Ogmo0140Ogmo00<0000007moO`0000001`1o
Ogl00`000000Ogmo07moO`0307moO`8000000`1oOgl010000000Ogmo00000000001f0?ooo`<00000
00@0Ogmo0000001oOgl0Ogmo0P00000407moO`030000001oOgl0Ogmo00P0Ogmo00<000000?ooo`3o
ool07@3oool00`000000oooo0000000307moO`030000001oOgl0Ogmo00P0Ogmo00<000000?ooo`3o
ool0o`3ooooO0?ooo`00CP3oool00`000000Ogmo07moO`0<07moO`030000003oool0000000@0oooo
00<000000?ooo`3oool03@3oool00`000000Ogmo07moO`0B07moO`030000001oOgl0Ogmo00800000
1P1oOgl2000000D0Ogmo00H0000007moO`1oOgl0Ogmo0000001oOgl2000007@0oooo1@00000207mo
O`030000001oOgl0Ogmo00<0Ogmo0P00000;07moO`030000003oool0oooo01`0oooo00<000000?oo
o`0000000`1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo0?l0oooogP3oool004d0
oooo00<0000007moO`1oOgl0301oOgl010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
00d0oooo00<0000007moO`1oOgl04P1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo
00D0Ogmo00<0000007moO`1oOgl00`1oOgl200000080Ogmo00@0000007moO`1oOgl00000LP3oool2
0000000307moO`000000Ogmo0080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo0000000<
07moO`030000003oool0oooo01/0oooo00<000000?ooo`0000000`1oOgl00`000000Ogmo07moO`09
07moO`030000003oool0oooo0?l0oooogP3oool004d0oooo00<0000007moO`1oOgl0301oOgl00`00
0000oooo0?ooo`06000000h0oooo00<0000007moO`1oOgl04`1oOgl00`000000Ogmo07moO`0307mo
O`8000001P1oOgl2000000D0Ogmo00<0000007moO`1oOgl00P0000000`1oOgl000000?ooo`1_0?oo
o`80000000<0Ogmo0000001oOgl00P1oOgl00`000000Ogmo07moO`0307moO`040000001oOgl0Ogmo
000000d0Ogmo00<000000?ooo`3oool06P3oool00`000000oooo0000000307moO`030000001oOgl0
Ogmo00T0Ogmo00<000000?ooo`3oool0o`3ooooN0?ooo`00C@3oool00`000000Ogmo07moO`0<07mo
O`040000003oool0oooo000000@0oooo00<000000?ooo`3oool02`3oool00`000000Ogmo07moO`0D
07moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`03
07moO`060000001oOgl0Ogmo07moO`000000Ogmo0P00001]0?ooo`@000000P1oOgl2000000@0Ogmo
0P00000307moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool06@3oool00`000000oooo
0000000307moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0o`3ooooN0?ooo`00C03o
ool00`000000Ogmo07moO`0=07moO`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
2P3oool00`000000Ogmo07moO`0E07moO`030000001oOgl0Ogmo00H0Ogmo0P00000607moO`030000
001oOgl0Ogmo00<0Ogmo0P00000207moO`040000001oOgl00000000006X0oooo1000000307moO`03
0000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0<07moO`03
0000003oool0oooo01T0oooo00<000000?ooo`0000000`1oOgl00`000000Ogmo07moO`0:07moO`03
0000003oool0oooo0?l0oooog@3oool004`0oooo00<0000007moO`1oOgl03@1oOgl010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo00T0oooo00<0000007moO`1oOgl05P1oOgl00`000000
Ogmo07moO`0807moO`030000001oOgl0Ogmo00@0Ogmo0P00000507moO`040000001oOgl0Ogmo0000
0080Ogmo00<000000?ooo`3oool0IP3oool4000000<0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000Ogmo07moO`0407moO`030000001oOgl0Ogmo00d0Ogmo00<000000?ooo`3oool0603oool00`00
0000oooo0000000307moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0o`3ooooM0?oo
o`00C03oool00`000000Ogmo07moO`0=07moO`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool02@3oool00`000000Ogmo07moO`0F07moO`8000002P1oOgl2000000H0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`020000000307moO`000000oooo06D0oooo0P000000101o
Ogl0000007moO`1oOgl2000000@0Ogmo0P00000607moO`800000401oOgl00`000000oooo0?ooo`0G
0?ooo`030000003oool0000000<0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`3o
0?ooomd0oooo001;0?ooo`030000001oOgl0Ogmo00h0Ogmo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`080?ooo`030000001oOgl0Ogmo01L0Ogmo00@0000007moO`00000000002P1o
Ogl00`000000Ogmo07moO`0407moO`800000101oOgl200000080Ogmo00@0000007moO`0000000000
H`3oool400000080Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0507moO`030000
001oOgl000000140Ogmo00<000000?ooo`3oool05P3oool7000000`0Ogmo00<000000?ooo`3oool0
o`3ooooM0?ooo`00B`3oool00`000000Ogmo07moO`0>07moO`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool01`3oool00`000000Ogmo07moO`0H07moO`050000001oOgl0Ogmo07moO`00
00002P1oOgl2000000H0Ogmo00<0000007moO`1oOgl00`1oOgl01@000000Ogmo07moO`000000Ogmo
00800000H@3oool3000000<0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0407mo
O`8000000P1oOgl00`000000Ogmo07moO`0?07moO`030000003oool0oooo01H0oooo00<000000?oo
o`0000000`1oOgl00`000000Ogmo07moO`0;07moO`030000003oool0oooo0?l0oooog03oool004/0
oooo00<0000007moO`1oOgl03P1oOgl010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
00H0oooo00<0000007moO`1oOgl06@1oOgl00`000000Ogmo07moO`0207moO`8000002P1oOgl00`00
0000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo00@0000007moO`1oOgl000000P1oOgl0
0`000000oooo0?ooo`1M0?ooo`<000000`1oOgl00`000000Ogmo07moO`0207moO`8000001P1oOgl0
0`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo0100Ogmo00<000000?ooo`3oool05@3oool0
0`000000oooo0000000307moO`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0o`3ooooL
0?ooo`00BP3oool00`000000Ogmo07moO`0>07moO`050000003oool0oooo0?ooo`000000103oool0
0`000000oooo0?ooo`050?ooo`030000001oOgl0Ogmo01X0Ogmo00<0000007moO`1oOgl0101oOgl2
000000T0Ogmo0P00000507moO`800000101oOgl20000000507moO`000000000007moO`000000GP3o
ool200000080Ogmo0P00000407moO`030000001oOgl0Ogmo00@0Ogmo0P00000507moO`030000001o
Ogl0Ogmo0140Ogmo00<000000?ooo`3oool0503oool010000000oooo0?ooo`00000207moO`030000
001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0o`3ooooL0?ooo`00BP3oool00`000000Ogmo07mo
O`0>07moO`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`050?ooo`030000
001oOgl0Ogmo01X0Ogmo00<0000007moO`1oOgl01P1oOgl00`000000Ogmo07moO`0807moO`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl00`1oOgl01P000000Ogmo07moO`000000Ogmo0000
05d0oooo0P0000000`1oOgl0000007moO`0407moO`030000001oOgl0Ogmo00@0Ogmo00<0000007mo
O`1oOgl01@1oOgl00`000000Ogmo07moO`0B07moO`030000003oool0oooo01<0oooo00@000000?oo
o`3oool000000P1oOgl00`000000Ogmo07moO`0;07moO`030000003oool0oooo0?l0oooog03oool0
04X0oooo00<0000007moO`1oOgl03P1oOgl01@000000oooo0?ooo`3oool0000000@0oooo00<00000
0?ooo`3oool0103oool00`000000Ogmo07moO`0K07moO`030000001oOgl0Ogmo00L0Ogmo0P000009
07moO`8000001@1oOgl2000000@0Ogmo00D0000007moO`1oOgl0000007moO`03000005H0oooo0P00
00020?ooo`030000003oool0000000@0Ogmo0P00000507moO`800000201oOgl00`000000Ogmo07mo
O`0C07moO`030000003oool0oooo0180oooo00@000000?ooo`3oool000000P1oOgl00`000000Ogmo
07moO`0;07moO`030000003oool0oooo0?l0oooog03oool004T0oooo00<0000007moO`1oOgl03`1o
Ogl01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0103oool00`000000Ogmo
07moO`0K07moO`030000001oOgl0Ogmo00T0Ogmo0P00000907moO`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl00P1oOgl20000000307moO`00000000000080Ogmo0`00001@0?ooo`<00000
00@0Ogmo0000003oool0oooo0P0000001@3oool0000007moO`1oOgl0000000H0Ogmo00<0000007mo
O`1oOgl01`1oOgl2000001D0Ogmo00<000000?ooo`3oool04P3oool010000000oooo0?ooo`000002
07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0o`3ooooK0?ooo`00B@3oool00`00
0000Ogmo07moO`0?07moO`040000003oool0oooo0?ooo`H000001@3oool00`000000Ogmo07moO`0L
07moO`030000001oOgl0Ogmo00/0Ogmo00<0000007moO`1oOgl01`1oOgl2000000D0Ogmo00<00000
07moO`1oOgl00`1oOgl00`000000oooo00000002000000<0Ogmo0`00001;0?ooo`8000000`1oOgl2
00000080oooo00@000000?ooo`3oool0oooo0P00000507moO`800000201oOgl20000000307moO`00
0000Ogmo01D0Ogmo00<000000?ooo`3oool04@3oool010000000oooo0?ooo`00000207moO`030000
001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0o`3ooooK0?ooo`00B@3oool00`000000Ogmo07mo
O`0?07moO`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`030?ooo`030000
001oOgl0Ogmo01`0Ogmo0P00000=07moO`8000002@1oOgl00`000000Ogmo07moO`0307moO`800000
0P1oOgl010000000oooo00000000000207moO`<000000`1oOgl3000004D0oooo0`00000207moO`<0
000000D0Ogmo0000003oool0oooo000000020?ooo`<00000101oOgl00`000000Ogmo07moO`0707mo
O`050000001oOgl0Ogmo07moO`0000005`1oOgl00`000000oooo0?ooo`0@0?ooo`040000003oool0
oooo00000080Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`3o0?ooom/0oooo0019
0?ooo`030000001oOgl0Ogmo00l0Ogmo00D000000?ooo`3oool0oooo000000040?ooo`030000003o
ool0oooo0080oooo00<0000007moO`1oOgl07@1oOgl010000000Ogmo00000000000=07moO`800000
201oOgl2000000D0Ogmo0P0000030?ooo`<000000`1oOgl3000000<0Ogmo0`00000o0?ooo`<00000
0P1oOgl3000000<0Ogmo0P0000020?ooo`030000003oool000000080oooo00<0000007moO`1oOgl0
0P00000807moO`800000101oOgl00`000000Ogmo07moO`0F07moO`030000003oool0oooo00l0oooo
00@000000?ooo`3oool000000P1oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo0?l0
oooof`3oool004P0oooo00<0000007moO`1oOgl0401oOgl01@000000oooo0?ooo`3oool0000000@0
oooo00<000000?ooo`3oool00P3oool00`000000Ogmo07moO`0M07moO`040000001oOgl0Ogmo07mo
O`8000003@1oOgl2000000P0Ogmo00<0000007moO`1oOgl00P1oOgl300000080oooo00<0000007mo
O`1oOgl00`00000307moO`<000000`1oOgl3000003X0oooo0P00000207moO`<000000`1oOgl30000
000407moO`000000oooo0?ooo`800000103oool2000000P0Ogmo0P00000607moO`030000001oOgl0
Ogmo01H0Ogmo00<000000?ooo`3oool03`3oool010000000oooo0?ooo`00000207moO`030000001o
Ogl0Ogmo00d0Ogmo00<000000?ooo`3oool0o`3ooooJ0?ooo`00B03oool00`000000Ogmo07moO`0@
07moO`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool000000200Ogmo
00<0000007moO`1oOgl00`1oOgl2000000d0Ogmo00<0000007moO`1oOgl01P1oOgl20000000307mo
O`000000oooo0080oooo00<000000?ooo`0000001@1oOgl3000000<0Ogmo0`00000307moO`<00000
603oool00`000000oooo0?ooo`0I0?ooo`<0000000@0Ogmo00000000000000000`1oOgl3000000@0
Ogmo00@000000?ooo`3oool00000103oool3000000L0Ogmo00<0000007moO`1oOgl01P1oOgl00`00
0000Ogmo07moO`0G07moO`030000003oool0oooo00h0oooo1`00000?07moO`030000003oool0oooo
0?l0oooofP3oool004P0oooo00<0000007moO`1oOgl0401oOgl01@000000oooo0?ooo`3oool00000
00@0oooo00@000000?ooo`3oool000008@1oOgl00`000000Ogmo07moO`0507moO`800000301oOgl2
000000P0Ogmo00<000000?ooo`3oool00`3oool2000000P0Ogmo0`00000307moO`<000000`1oOgl3
000001D0oooo00<000000?ooo`3oool05`3oool20000000407moO`0000000000000000<0Ogmo0`00
000607moO`8000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<0000007moO`1oOgl0
0P1oOgl2000000T0Ogmo00<0000007moO`1oOgl05`1oOgl00`000000oooo0?ooo`0>0?ooo`040000
003oool0oooo00000080Ogmo00<0000007moO`1oOgl03@1oOgl00`000000oooo0?ooo`3o0?ooomX0
oooo00180?ooo`030000001oOgl0Ogmo00l0Ogmo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo00000240Ogmo00<0000007moO`1oOgl01`1oOgl2000000`0
Ogmo0P00000507moO`040000003oool00000000000@0oooo0`00000907moO`<000000`1oOgl30000
00<0Ogmo0`00000B0?ooo`030000003oool0oooo01@0oooo1P00000307moO`<000001P1oOgl30000
000607moO`000000oooo0?ooo`000000oooo0P0000050?ooo`040000001oOgl00000000000/0Ogmo
00<0000007moO`1oOgl0601oOgl00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo00000080
Ogmo00<0000007moO`1oOgl03@1oOgl00`000000oooo0?ooo`3o0?ooomX0oooo00180?ooo`030000
001oOgl0Ogmo00l0Ogmo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000
003oool000000280Ogmo00<0000007moO`1oOgl02@1oOgl2000000`0Ogmo00D0000007moO`1oOgl0
Ogmo000000040?ooo`050000003oool0oooo0?ooo`0000000P1oOgl4000000P0Ogmo0`00000307mo
O`<000000`1oOgl3000000l0oooo00<000000?ooo`3oool02@3oool>000000<0Ogmo0`00000607mo
O`<00000101oOgl00`000000oooo0?ooo`02000000L0oooo0P00000<07moO`8000006P1oOgl00`00
0000oooo0?ooo`0=0?ooo`040000003oool0oooo00000080Ogmo00<0000007moO`1oOgl03@1oOgl0
0`000000oooo0?ooo`3o0?ooomX0oooo00170?ooo`030000001oOgl0Ogmo0100Ogmo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool000000280Ogmo00<0000007mo
O`1oOgl02`1oOgl2000000/0Ogmo0`0000060?ooo`80000000<0oooo0000001oOgl01@1oOgl40000
00L0Ogmo0`00000307moO`<000000`1oOgl4000000/0oooo00<000000?ooo`3oool02@3oool;0000
00<0Ogmo0`00000607moO`<000001`1oOgl010000000oooo0?ooo`0000070?ooo`030000003oool0
000000X0Ogmo0P0000000`1oOgl0000007moO`0J07moO`030000003oool0oooo00`0oooo00@00000
0?ooo`3oool000000P1oOgl00`000000Ogmo07moO`0>07moO`030000003oool0oooo0?l0oooof@3o
ool004H0oooo0P00000B07moO`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool2
000002<0Ogmo00<0000007moO`1oOgl03@1oOgl2000000/0Ogmo0P0000070?ooo`8000002P1oOgl4
000000H0Ogmo0`00000307moO`D0000000<0Ogmo0000003oool02P3oool00`000000oooo0?ooo`09
0?ooo`030000001oOgl0Ogmo00L0Ogmo1000000607moO`<000002P1oOgl010000000oooo0?ooo`00
00050?ooo`8000000`3oool00`000000Ogmo07moO`0507moO`8000000`1oOgl00`000000Ogmo07mo
O`0I07moO`030000003oool0oooo00`0oooo00@000000?ooo`3oool000000P1oOgl00`000000Ogmo
07moO`0>07moO`030000003oool0oooo0?l0oooof@3oool002h0oooo6009jPX00`0000002NX:00WZ
2P0900WZ2PL0Ogmo0P0000040?ooo`030000003oool0oooo0080oooo0P00000S07moO`030000001o
Ogl0Ogmo00l0Ogmo0P00000807moO`040000003oool0oooo000000L0oooo0`00000<07moO`<00000
1P1oOgl300000080Ogmo1@00000;0?ooo`030000003oool0oooo00T0oooo3000000507moO`<00000
2`1oOgl300000080oooo00@000000?ooo`3oool0oooo0P0000050?ooo`030000001oOgl0Ogmo00<0
Ogmo0P00000507moO`030000001oOgl0Ogmo01X0Ogmo00<000000?ooo`3oool02`3oool010000000
oooo0?ooo`00000207moO`030000001oOgl0Ogmo00h0Ogmo00<000000?ooo`3oool0o`3ooooI0?oo
o`005@3ooolI00WZ2QT0oooo00<0000007moO`1oOgl0201oOgl700WZ2P0300000009jPX02NX:00/0
2NX:8P1oOgl200000180Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`020?ooo`80
00001@3oool00`000000Ogmo07moO`04000000/0Ogmo1000000507moO`<0000000@0Ogmo0000001o
Ogl000002`3oool00`000000oooo0?ooo`090?ooo`030000001oOgl0Ogmo00L0Ogmo00@0000007mo
O`000000Ogmo0`00000;07moO`<000000P1oOgl010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo00H0oooo00<0000007moO`1oOgl00P00000707moO`030000001oOgl0Ogmo01X0Ogmo00<0
00000?ooo`3oool02`3oool010000000oooo0?ooo`00000207moO`030000001oOgl0Ogmo00h0Ogmo
00<000000?ooo`3oool0o`3ooooI0?ooo`00A`3oool00`000000Ogmo07moO`0@07moO`030000003o
ool0oooo0080oooo00@000000?ooo`3oool0oooo0P00000207moO`H02NX:701oOgl00`000000Ogmo
0000000200000100Ogmo0P00000307moO`030000003oool0oooo00D0oooo0P0000030?ooo`030000
001oOgl0Ogmo00@0Ogmo1000000;07moO`@0000000@0Ogmo0000001oOgl0Ogmo1000000;0?ooo`03
0000003oool0oooo00T0oooo00<0000007moO`1oOgl01`1oOgl4000000/0Ogmo0`00000507moO`03
0000003oool0oooo00<000002P3oool2000000T0Ogmo00<0000007moO`1oOgl06`1oOgl00`000000
oooo0?ooo`0:0?ooo`040000003oool0oooo00000080Ogmo00<0000007moO`1oOgl03P1oOgl00`00
0000oooo0?ooo`3o0?ooomT0oooo00160?ooo`030000001oOgl0Ogmo0140Ogmo00<000000?ooo`3o
ool00P3oool6000000P0Ogmo1P09jPXF07moO`030000001oOgl0Ogmo0080Ogmo0P00000@07moO`<0
00002P3oool010000000oooo0?ooo`00000:07moO`@000002`1oOgl40000000407moO`000000Ogmo
000000/0oooo00<000000?ooo`3oool02@3oool;00000080Ogmo00<0000007moO`1oOgl01@1oOgl4
000000P0Ogmo00@000000?ooo`3oool000002P3oool2000000030?ooo`000000Ogmo00P0Ogmo00<0
000007moO`1oOgl06`1oOgl00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo00000080Ogmo
00<0000007moO`1oOgl03P1oOgl00`000000oooo0?ooo`3o0?ooomT0oooo00160?ooo`030000001o
Ogl0Ogmo0140Ogmo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`3oool2000000h0Ogmo
1@09jPXA07moO`030000001oOgl0Ogmo00@0Ogmo0`00000?07moO`8000002P3oool3000000h0Ogmo
0`00000707moO`030000001oOgl0Ogmo0080Ogmo1000000;0?ooo`030000003oool0oooo00T0oooo
00<0000007moO`1oOgl01`1oOgl010000000Ogmo07moO`00000407moO`<00000301oOgl010000000
oooo0?ooo`0000080?ooo`8000000`3oool00`000000Ogmo07moO`0707moO`030000001oOgl0Ogmo
01`0Ogmo00<000000?ooo`3oool02@3oool010000000oooo0?ooo`00000207moO`030000001oOgl0
Ogmo00l0Ogmo00<000000?ooo`3oool0o`3ooooH0?ooo`00AP3oool00`000000Ogmo07moO`0@07mo
O`030000003oool0oooo00<0oooo00@000000?ooo`3oool0oooo0P00000C07moO`H02NX:2`1oOgl0
0`000000Ogmo07moO`0707moO`800000301oOgl00`000000oooo0?ooo`02000000X0oooo0`00000?
07moO`@000000P1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0000000/0oooo00<00000
0?ooo`3oool02@3oool00`000000Ogmo07moO`0707moO`040000001oOgl0Ogmo07moO`@000003@1o
Ogl300000080oooo00<000000?ooo`3oool0103oool2000000H0oooo00<0000007moO`1oOgl01P1o
Ogl00`000000Ogmo07moO`0L07moO`030000003oool0oooo00T0oooo00@000000?ooo`3oool00000
0P1oOgl00`000000Ogmo07moO`0?07moO`030000003oool0oooo0?l0oooof03oool004H0oooo00<0
000007moO`1oOgl0401oOgl00`000000oooo0?ooo`030?ooo`060000003oool0oooo0000001oOgl0
00006@1oOgl600WZ2PD0Ogmo00<0000007moO`1oOgl02@1oOgl2000000T0Ogmo00<000000?ooo`3o
ool00`3oool2000000P0oooo00<0000007moO`1oOgl01@00000>07moO`@000001@1oOgl00`000000
Ogmo0000000;0?ooo`030000003oool0oooo00T0oooo00<0000007moO`1oOgl01`1oOgl00`000000
Ogmo00000002000000`0Ogmo1000000207moO`040000003oool0oooo000000@0oooo0P0000090?oo
o`030000001oOgl0Ogmo00@0Ogmo0P00000O07moO`030000003oool0oooo00P0oooo1`00000A07mo
O`030000003oool0oooo0?l0oooof03oool004H0oooo00<0000007moO`1oOgl0401oOgl00`000000
oooo0?ooo`030?ooo`060000003oool0oooo0000001oOgl000007`1oOgl600WZ2Pd0Ogmo0`000005
07moO`030000003oool0oooo00H0oooo0P0000060?ooo`030000001oOgl0Ogmo00D0Ogmo1000000;
07moO`030000001oOgl0Ogmo00@0000000@0Ogmo0000001oOgl000002`3oool00`000000oooo0?oo
o`090?ooo``000000`1oOgl00`000000Ogmo07moO`0507moO`@000001P1oOgl010000000oooo0?oo
o`0000020?ooo`8000002`3oool010000000Ogmo07moO`1oOgl30000000307moO`000000Ogmo01h0
Ogmo0P0000090?ooo`030000003oool0oooo0080000000<0Ogmo0000001oOgl0401oOgl200000?l0
oooof@3oool004D0oooo00<0000007moO`1oOgl04@1oOgl00`000000oooo0?ooo`030?ooo`030000
003oool000000080Ogmo00<0000007moO`1oOgl08P1oOgl00`0000002NX:00WZ2P0400WZ2PX0Ogmo
0P00000307moO`030000003oool0oooo00P0oooo0P0000040?ooo`030000001oOgl0Ogmo00T0Ogmo
1@00000507moO`030000001oOgl0Ogmo00D0Ogmo1000000;0?ooo`030000003oool0oooo00T0oooo
00<0000007moO`1oOgl01`1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo0080Ogmo
0`00000:07moO`030000003oool0oooo00<000003P3oool3000000@0Ogmo00<0000007moO`1oOgl0
6P1oOgl300WZ2P0300000009jPX02NX:02002NX:00<0000000WZ2P09jPX01@09jP[o0?ooom<0oooo
00150?ooo`030000001oOgl0Ogmo0140Ogmo00<000000?ooo`3oool00`3oool00`000000oooo0000
000207moO`030000001oOgl0Ogmo0280Ogmo00<0000007moO`1oOgl0101oOgl500WZ2PL0Ogmo0`00
000=0?ooo`8000000P3oool00`000000Ogmo07moO`0>07moO`D000002@1oOgl00`000000Ogmo0000
000;0?ooo`030000003oool0oooo00T0oooo00<0000007moO`1oOgl01`1oOgl00`000000Ogmo07mo
O`0207moO`D000003@1oOgl010000000oooo0?ooo`00000?0?ooo`8000001P1oOgl00`000000Ogmo
07moO`0C07moO`L02NX:101oOgl00`000000oooo0?ooo`070?ooo`040000003oool0oooo00000080
Ogmo00<0000007moO`1oOgl03`1oOgl00`000000oooo0?ooo`050?ooo``02NX:o`3oooo70?ooo`00
A@3oool00`000000Ogmo07moO`0A07moO`030000003oool0oooo00<0oooo00<000000?ooo`000000
0P1oOgl00`000000Ogmo07moO`0R07moO`030000001oOgl0Ogmo00T0Ogmo1P09jPX307moO`<00000
3@3oool3000001<0Ogmo1@00000607moO`030000001oOgl0000000/0oooo00<000000?ooo`3oool0
2@3oool00`000000Ogmo07moO`0707moO`030000001oOgl0000000@000003P1oOgl300000080oooo
00<000000?ooo`3oool02P3oool300000080oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`0;07moO`P02NX:2`1oOgl00`000000oooo0?ooo`070?ooo`040000003oool0oooo00000080
Ogmo00<0000007moO`1oOgl0401oOgl00`000000oooo0?ooo`0@0?ooo``02NX:o`3ooonk0?ooo`00
A@3oool00`000000Ogmo07moO`0A07moO`030000003oool0oooo00<0oooo0P00000307moO`030000
001oOgl0Ogmo0280Ogmo0`00000?07moO`0300WZ2P0000002NX:01402NX:00<0000000WZ2P09jPX0
7P09jPX00`0000002NX:00WZ2P0500WZ2P@0oooo0P00000:0?ooo`d00000101oOgl2000000T0Ogmo
1000000207moO`040000003oool0oooo000000X0oooo0P0000050?ooo`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl00`1oOgl800WZ2Q@0Ogmo00<000000?ooo`3oool01P3oool010000000
oooo0?ooo`00000207moO`030000001oOgl0Ogmo0100Ogmo00<000000?ooo`3oool0703oool<00WZ
2_l0oooo[`3oool004D0oooo00<0000007moO`1oOgl04@1oOgl00`000000oooo0?ooo`030?ooo`80
00000`1oOgl00`000000Ogmo07moO`0R07moO`030000001oOgl0Ogmo00<000003@1oOgl2000000H0
oooo0P0000090?ooo`8000000`1oOgl5000000X0Ogmo0P00000907moO`@000001P3oool400WZ2P03
00000009jPX02NX:00T02NX:00<0000000WZ2P09jPX07P09jPX00`0000002NX:00WZ2P0:00WZ2P80
0000203oool200000080Ogmo1`09jPXL07moO`030000003oool0oooo00H0oooo00@000000?ooo`3o
ool000000P1oOgl00`000000Ogmo07moO`0@07moO`030000003oool0oooo02P0oooo2`09jP[o0?oo
oj@0oooo00150?ooo`030000001oOgl0Ogmo0140Ogmo00<000000?ooo`3oool00`3oool00`000000
Ogmo07moO`0207moO`030000001oOgl0Ogmo0280Ogmo00<0000007moO`1oOgl00`1oOgl3000000X0
Ogmo00<000000?ooo`3oool01`3oool2000000P0oooo00<0000007moO`1oOgl01P1oOgl5000000@0
Ogmo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo0000000;0?ooo`030000003oool0oooo00T0
oooo00<0000007moO`1oOgl01`1oOgl00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0
00002@1oOgl200000080oooo00<000000?ooo`3oool00`3oool2000000030?ooo`09jPX02NX:00`0
2NX:00<0Ogmo0000001oOgl08@1oOgl00`000000oooo0?ooo`050?ooo`040000003oool0oooo0000
0080Ogmo00<0000007moO`1oOgl0401oOgl00`000000oooo0?ooo`0c0?ooo``02NX:o`3ooonH0?oo
o`00A03oool00`000000Ogmo07moO`0B07moO`030000003oool0oooo00<0oooo00<0000007moO`1o
Ogl00P1oOgl00`000000Ogmo07moO`0R07moO`030000001oOgl0Ogmo00H0Ogmo0`00000707moO`03
0000003oool0oooo00T0oooo0`0000050?ooo`030000001oOgl0Ogmo00/0Ogmo1@00000<07moO`03
0000001oOgl0000000/0oooo00<000000?ooo`3oool02@3oool00`000000Ogmo07moO`0707moO`03
0000001oOgl0Ogmo00<0Ogmo1000000=07moO`040000003oool0oooo000000<0oooo0P00000>0?oo
o`050000001oOgl0Ogmo07moO`0000008P1oOgl00`000000oooo0?ooo`050?ooo`040000003oool0
oooo00000080Ogmo00<0000007moO`1oOgl0401oOgl00`000000oooo0?ooo`0o0?ooo``02NX:o`3o
oon<0?ooo`00;@3ooolS00WZ2PP0Ogmo0P0000050?ooo`030000001oOgl0Ogmo0080Ogmo00<00000
07moO`1oOgl08P1oOgl00`000000Ogmo07moO`0907moO`<000000`1oOgl00`000000oooo0?ooo`0=
0?ooo`8000000`3oool00`000000Ogmo07moO`0>07moO`030000001oOgl0000000@000001`1oOgl0
0`000000Ogmo0000000;0?ooo`030000003oool0oooo00T0oooo00<0000007moO`1oOgl01`1oOgl0
0`000000Ogmo000000030000000307moO`000000Ogmo00h0Ogmo00<000000?ooo`3oool01000000@
0?ooo`030000001oOgl0Ogmo008000008P1oOgl00`000000oooo0?ooo`050?ooo`040000003oool0
oooo00000080Ogmo00<0000007moO`1oOgl0401oOgl00`000000oooo0?ooo`1;0?ooo``02NX:o`3o
oon00?ooo`005@3ooolH00WZ2QL0oooo0P00000:07moO`P02NX:00<0000000WZ2P09jPX02009jPX0
0`1oOgl0000007moO`0S07moO`030000001oOgl0Ogmo00`0Ogmo1000000A0?ooo`@000003`1oOgl0
0`000000Ogmo07moO`0507moO`D000000P1oOgl00`000000Ogmo0000000;0?ooo`030000003oool0
oooo00T0oooo3000000607moO`030000001oOgl0Ogmo00`0Ogmo00@000000?ooo`3oool000004`3o
ool30000000307moO`000000Ogmo0280Ogmo00<000000?ooo`3oool0103oool010000000oooo0?oo
o`00000207moO`030000001oOgl0Ogmo0100Ogmo00<000000?ooo`3oool0E`3oool<00WZ2_l0oooo
M03oool004@0oooo00<0000007moO`1oOgl04P1oOgl00`000000oooo0?ooo`020?ooo`D000002009
jPXN07moO`030000001oOgl0Ogmo00h0Ogmo1000000B0?ooo`@00000301oOgl00`000000Ogmo07mo
O`0:07moO`D000002`3oool00`000000oooo0?ooo`090?ooo`030000001oOgl0Ogmo00L0Ogmo00<0
000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0907moO`@000000P3oool00`000000oooo0?oo
o`0>0?ooo`<0000000D0oooo0000001oOgl0Ogmo0000000S07moO`030000003oool0oooo00@0oooo
00@000000?ooo`3oool000000P1oOgl00`000000Ogmo07moO`0A07moO`030000003oool0oooo0680
oooo3009jP[o0?ooofP0oooo00140?ooo`030000001oOgl0Ogmo0180Ogmo00<000000?ooo`3oool0
0P3oool2000000@0Ogmo00<0000007moO`1oOgl0101oOgl900WZ2QD0Ogmo00<0000007moO`1oOgl0
3P1oOgl010000000oooo0?ooo`3oool3000000l0oooo00@0000007moO`1oOgl0Ogmo1P00000607mo
O`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`0000002`3oool00`000000oooo0?ooo`090?oo
o`030000001oOgl0Ogmo00L0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0307mo
O`H000000`1oOgl010000000oooo0?ooo`00000=0?ooo`<00000103oool010000000Ogmo07moO`00
000S07moO`030000003oool0oooo00@0oooo00@000000?ooo`3oool000000P1oOgl00`000000Ogmo
07moO`0A07moO`030000003oool0oooo06h0oooo3009jP[o0?oooe`0oooo00140?ooo`030000001o
Ogl0Ogmo0140Ogmo00<000000?ooo`3oool00P3oool00`000000Ogmo0000000407moO`030000001o
Ogl0Ogmo00d0Ogmo2009jPX=07moO`030000001oOgl0Ogmo00h0Ogmo00<000000?ooo`3oool0103o
ool3000000`0oooo00<0000007moO`1oOgl01`1oOgl7000000h0Ogmo00<0000007moO`0000002`3o
ool00`000000oooo0?ooo`090?ooo`030000001oOgl0Ogmo00L0Ogmo00<0000007moO`1oOgl01@1o
Ogl6000000T0Ogmo00@000000?ooo`3oool000002P3oool3000000P0oooo00<0000007moO`000000
901oOgl00`000000oooo0?ooo`030?ooo`L000004`1oOgl00`000000oooo0?ooo`1j0?ooo`/02NX:
o`3ooomA0?ooo`00A03oool00`000000Ogmo07moO`0A07moO`030000003oool0oooo0080oooo00<0
000007moO`000000101oOgl00`000000Ogmo07moO`0E07moO`P02NX:1@1oOgl00`000000Ogmo07mo
O`0=07moO`030000003oool0oooo00P0oooo0`0000090?ooo`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`0000001@00000807moO`030000001oOgl0000000/0oooo00<000000?ooo`3oool02@3o
ool00`000000Ogmo07moO`0707moO`030000001oOgl0Ogmo00L000003@1oOgl010000000oooo0?oo
o`0000070?ooo`<000002`3oool00`000000Ogmo0000000S07moO`8000001@3oool00`000000oooo
0?ooo`020000000307moO`000000Ogmo0180Ogmo0P0000260?ooo``02NX:o`3ooom50?ooo`00A03o
ool00`000000Ogmo07moO`0A07moO`030000003oool0oooo0080oooo00<0000007moO`000000101o
Ogl00`000000Ogmo07moO`0M07moO`T02NX:301oOgl00`000000oooo0?ooo`0;0?ooo`<000001P3o
ool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo00D0Ogmo1P00000207moO`030000001o
Ogl0000000/0oooo00<000000?ooo`3oool02@3oool=000000H0Ogmo00<0000007moO`1oOgl02`1o
Ogl010000000oooo0?ooo`0000040?ooo`<000003P3oool00`000000Ogmo0000000N07moO`D02NX:
00<0000000WZ2P09jPX0:009jPZ:0?ooo``02NX:o`3oooli0?ooo`00A03oool00`000000Ogmo07mo
O`0A07moO`030000003oool0oooo0080oooo00<0000007moO`000000101oOgl00`000000Ogmo07mo
O`0R07moO`040000001oOgl0Ogmo07moO`P02NX:0P1oOgl300000100oooo0`0000020?ooo`800000
301oOgl2000000h0Ogmo1@00000:0?ooo`8000002`3oool00`000000Ogmo07moO`0707moO`030000
001oOgl0Ogmo00H0Ogmo00<0000007moO`1oOgl02`1oOgl01@000000oooo0?ooo`000000oooo00<0
00004P3oool200000140Ogmo3@09jPX607moO`030000003oool0oooo00<0oooo00L000000?ooo`3o
ool0oooo0000001oOgl0000001<0Ogmo00<000000?ooo`3oool01`3ooolB00WZ2X@0oooo3009jP[o
0?ooobd0oooo00130?ooo`030000001oOgl0Ogmo0180Ogmo00<000000?ooo`3oool00P3oool00`00
0000Ogmo0000000407moO`030000001oOgl0Ogmo0280Ogmo0`00000907moO`802NX:00<0000000WZ
2P09jPX05@09jPX00`0000002NX:00WZ2P0N00WZ2P0300000009jPX02NX:00T02NX:00<0000000WZ
2P09jPX02@09jPX00`0000002NX:00WZ2P0N00WZ2P0300000009jPX02NX:00`02NX:303oool20000
00@0Ogmo3@09jPXD07moO`030000003oool0oooo0080oooo00L000000?ooo`3oool0oooo0000001o
Ogl0000001<0Ogmo00<000000?ooo`3oool06@3ooolB00WZ2Wh0oooo3009jP[o0?ooob40oooo0013
0?ooo`030000001oOgl0Ogmo0180Ogmo00D000000?ooo`3oool0oooo0000000207moO`030000001o
Ogl0Ogmo0080Ogmo00<0000007moO`1oOgl08P1oOgl00`000000Ogmo07moO`05000000L0Ogmo00<0
00000?ooo`3oool05@3oool5000000P0Ogmo00<0000007moO`1oOgl03`1oOgl00`000000Ogmo0000
000;0?ooo`030000003oool0oooo00P0oooo0P00000907moO`030000001oOgl0Ogmo00H0Ogmo0P00
000807moO`D000000P3oool00`000000oooo0?ooo`080?oooa802NX:8@1oOgl00`000000oooo0?oo
o`020?ooo`070000003oool0oooo0?ooo`000000Ogmo0000000C07moO`030000003oool0oooo02/0
oooo4P09jPYh0?ooo``02NX:o`3ooolE0?ooo`00@`3oool00`000000Ogmo07moO`0B07moO`050000
003oool0oooo0?ooo`0000000P1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo0280
Ogmo00<0000007moO`1oOgl01@1oOgl500000080Ogmo00<000000?ooo`3oool05@3oool00`000000
Ogmo07moO`0207moO`T000004@1oOgl00`000000Ogmo0000000;0?ooo`030000003oool0oooo00T0
oooo00<0000007moO`1oOgl01`1oOgl00`000000Ogmo07moO`0607moO`030000001oOgl0000000L0
0000101oOgl010000000oooo0?ooo`00000E0?ooo`<000009@1oOgl00`000000oooo0?ooo`020?oo
o`070000003oool0oooo0?ooo`000000Ogmo0000000C07moO`030000003oool0oooo03d0oooo4P09
jPYb0?ooo``02NX:o`3oool90?ooo`00@`3oool00`000000Ogmo07moO`0B07moO`050000003oool0
oooo0?ooo`0000000P1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo0280Ogmo00<0
000007moO`1oOgl02P1oOgl5000001D0oooo00<0000007moO`1oOgl02P1oOgl7000000/0Ogmo00<0
000007moO`0000002`3oool00`000000oooo0?ooo`090?ooo`030000001oOgl0Ogmo00L0Ogmo00@0
000007moO`1oOgl0Ogmo1`00000<07moO`040000003oool0oooo00000100oooo1@0000020?ooo`03
0000001oOgl0Ogmo02<0Ogmo00<000000?ooo`3oool00P3oool01`000000oooo0?ooo`3oool00000
07moO`000000501oOgl00`000000oooo0?ooo`1>0?oooa802NX:K03oool<00WZ2_`0oooo00130?oo
o`030000001oOgl0Ogmo0180Ogmo00D000000?ooo`3oool0oooo0000000207moO`030000001oOgl0
Ogmo0080Ogmo00<0000007moO`1oOgl08P1oOgl00`000000Ogmo07moO`0;07moO`040000003oool0
oooo0?ooo`D00000403oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00D0Ogmo2000
000307moO`030000001oOgl0000000/0oooo00<000000?ooo`3oool02@3oool>000000H0Ogmo00<0
000007moO`1oOgl02P1oOgl010000000oooo0?ooo`00000;0?ooo`D000001`3oool00`000000Ogmo
07moO`0S07moO`030000003oool0oooo0080oooo00L000000?ooo`3oool0oooo0000001oOgl00000
01@0Ogmo00<000000?ooo`3oool0H03ooolB00WZ2VH0oooo2`09jP[a0?ooo`00@`3oool00`000000
Ogmo07moO`0B07moO`050000003oool0oooo0?ooo`0000000P1oOgl00`000000Ogmo07moO`0207mo
O`030000001oOgl0Ogmo0280Ogmo00<0000007moO`1oOgl02`1oOgl00`000000oooo0?ooo`060?oo
o`D000002`3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00d0Ogmo1P00000;0?oo
o`030000003oool0oooo00T0oooo00<0000007moO`1oOgl01`1oOgl00`000000Ogmo07moO`0707mo
O`030000001oOgl0Ogmo00X0Ogmo00@000000?ooo`3oool000001P3oool5000000`0oooo00<00000
07moO`1oOgl08`1oOgl00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`000000Ogmo
0000000D07moO`030000003oool0oooo0780oooo4P09jPYO0?ooo``02NX:i@3oool004<0oooo00<0
000007moO`1oOgl04P1oOgl010000000oooo0?ooo`00000307moO`030000001oOgl0Ogmo0080Ogmo
00<0000007moO`1oOgl08P1oOgl00`000000Ogmo07moO`0;07moO`030000003oool0oooo00/0oooo
1@0000060?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0401oOgl00`000000Ogmo
0000000;0?ooo`030000003oool0oooo00T0oooo00<0000007moO`1oOgl01`1oOgl00`000000Ogmo
07moO`0707moO`030000001oOgl0Ogmo00X0Ogmo00D000000?ooo`3oool000000?ooo`0500000140
oooo0P00000T07moO`030000003oool0oooo0080oooo00L000000?ooo`3oool0oooo0000001oOgl0
000001@0Ogmo00<000000?ooo`3oool0Q03ooolB00WZ2UT0oooo3009jP[I0?ooo`00@P3oool20000
01@0Ogmo1000000307moO`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl08P1oOgl00`00
0000Ogmo07moO`0:07moO`030000003oool0oooo0140oooo1@0000000`3oool0000007moO`0907mo
O`030000001oOgl0Ogmo0140Ogmo00<0000007moO`0000002`3oool00`000000oooo0?ooo`090?oo
o`030000001oOgl0Ogmo00L0Ogmo00<0000007moO`1oOgl01`1oOgl00`000000Ogmo07moO`0:07mo
O`030000003oool0oooo008000005P3oool2000002D0Ogmo00D000000?ooo`3oool0oooo00000003
0?ooo`030000001oOgl0000001@0Ogmo00<000000?ooo`3oool0UP3ooolB00WZ2U<0oooo3009jP[=
0?ooo`005@3oool]00WZ2P0300000009jPX02NX:01D02NX:00<0000000WZ2P09jPX02@09jPXS07mo
O`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool05P3oool:00000080Ogmo00<0000007mo
O`1oOgl04@1oOgl00`000000Ogmo0000000;0?ooo`030000003oool0oooo00T0oooo00<0000007mo
O`1oOgl01`1oOgl00`000000Ogmo07moO`0707moO`030000001oOgl0Ogmo00@0Ogmo1`0000020?oo
o`030000003oool0oooo01D0oooo0P00000U07moO`050000003oool0oooo0?ooo`0000000`3oool0
0`000000Ogmo0000000D07moO`030000003oool0oooo0:P0oooo4P09jPY=0?ooo``02NX:`@3oool0
04<0oooo00<0000007moO`1oOgl04P1oOgl010000000oooo0?ooo`00000307moO`030000001oOgl0
Ogmo0080Ogmo00<0000007moO`09jPX04P09jPX@07moO`030000001oOgl0Ogmo00X0Ogmo00<00000
0?ooo`3oool05`3oool00`000000Ogmo07moO`0607moO`l000001`1oOgl00`000000Ogmo0000000;
0?ooo`030000003oool0oooo00T0oooo00<0000007moO`1oOgl01`1oOgl00`000000Ogmo07moO`03
07moO`/000001P1oOgl010000000oooo0?ooo`00000G0?ooo`8000009@1oOgl010000000oooo0?oo
o`3oool7000001@0Ogmo00<000000?ooo`3oool0^P3ooolB00WZ2TL0oooo3009jPZe0?ooo`00@`3o
ool00`000000Ogmo07moO`0B07moO`040000003oool0oooo000000<0Ogmo00<0000007moO`1oOgl0
0P1oOgl00`000000Ogmo07moO`0B07moOa<02NX:2P1oOgl00`000000oooo0?ooo`0G0?ooo`030000
001oOgl0Ogmo00L0Ogmo00<0000007moO`1oOgl02`1oOgl:000000/0oooo00<000000?ooo`3oool0
2@3oool@000000@0Ogmo00<0000007moO`1oOgl02P1oOgl010000000oooo0?ooo`00000G0?ooo`80
0000701oOgl@00WZ2P0300000009jPX02NX:02L02NX:_@3ooolB00WZ2T40oooo3009jPZY0?ooo`00
@`3oool00`000000Ogmo07moO`0B07moO`040000003oool0oooo000000<0Ogmo00<0000007moO`1o
Ogl00P1oOgl00`000000Ogmo07moO`0R07moO`<000002009jPX00`0000002NX:00WZ2P0H00WZ2P03
00000009jPX02NX:00L02NX:00<0000000WZ2P09jPX05009jPX00`0000002NX:00WZ2P0900WZ2P03
00000009jPX02NX:00T02NX:00<0000000WZ2P09jPX02P09jPX907moO`8000002@1oOgl200000080
oooo00<000000?ooo`3oool05@3oool3000000P0Ogmo4`09jPX907moO`8000000P3oool00`000000
oooo0?ooo`020000000307moO`000000Ogmo01<0Ogmo0P00000@0?ooob<02NX:[03ooolB00WZ2S/0
oooo3009jPZM0?ooo`00@`3oool00`000000Ogmo07moO`0B07moO`040000003oool0oooo000000<0
Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0R07moO`030000001oOgl0Ogmo00<0
Ogmo2P00000F0?ooo`800000201oOgl2000001@0Ogmo0`00000:0?ooo`8000002P3oool2000000T0
Ogmo00<0000007moO`09jPX04`09jPX00`0000002NX:00WZ2P0T00WZ2Q`0Ogmo00D000000?ooo`3o
ool0oooo000000030?ooo`030000001oOgl0000001@0Ogmo00<000000?ooo`3oool0<P3ooolR00WZ
2Y`0oooo4P09jPXe0?ooo`/02NX:TP3oool004<0oooo00<0000007moO`1oOgl04P1oOgl010000000
oooo0?ooo`00000307moO`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl08P1oOgl00`00
0000Ogmo07moO`0907moO`040000003oool0oooo0?ooo`T000003P3oool00`000000Ogmo07moO`07
07moO`030000001oOgl0Ogmo0180Ogmo00<0000007moO`0000002`3oool00`000000oooo0?ooo`09
0?ooo`030000001oOgl0Ogmo00L0Ogmo00<0000007moO`1oOgl0201oOgl00`000000Ogmo07moO`09
07moO`040000003oool0oooo000000/0oooo200000040?ooo`030000003oool0000002@0Ogmo00D0
00000?ooo`3oool0oooo000000030?ooo`030000001oOgl0000001@0Ogmo00<000000?ooo`3oool0
E03ooolS00WZ2X/0oooo4P09jPX^0?ooo``02NX:QP3oool00480oooo00<0000007moO`1oOgl04`1o
Ogl010000000oooo0?ooo`00000307moO`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl0
8P1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo00X0oooo2P0000040?ooo`030000
001oOgl0Ogmo00H0Ogmo00<0000007moO`1oOgl04`1oOgl00`000000Ogmo0000000;0?ooo`030000
003oool0oooo00T0oooo00<0000007moO`1oOgl01`1oOgl00`000000Ogmo07moO`0807moO`030000
001oOgl0Ogmo00T0Ogmo00@000000?ooo`3oool000000`3oool8000000`0oooo00<000000?ooo`00
0000901oOgl01@000000oooo0?ooo`3oool0000000<0oooo00<0000007moO`000000501oOgl00`00
0000oooo0?ooo`1g0?ooob802NX:N`3ooolB00WZ2RP0oooo3009jPYj0?ooo`00@P3oool00`000000
Ogmo07moO`0C07moO`040000003oool0oooo000000<0Ogmo00<0000007moO`1oOgl00P1oOgl00`00
0000Ogmo07moO`0R07moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0503oool>0000
01D0Ogmo00<0000007moO`0000002`3oool00`000000oooo0?ooo`090?ooo`030000001oOgl0Ogmo
00L0Ogmo00<0000007moO`1oOgl0201oOgl=00000080oooo1000000D0?ooo`030000003oool00000
02@0Ogmo00D000000?ooo`3oool0oooo000000030?ooo`030000001oOgl0000001D0Ogmo00<00000
0?ooo`3oool0V03ooolS00WZ2VX0oooo4P09jPXR0?ooo``02NX:KP3oool00480oooo00<0000007mo
O`1oOgl04`1oOgl00`000000oooo0000000407moO`030000001oOgl0Ogmo0080Ogmo00<0000007mo
O`1oOgl08P1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo01P0oooo00<0000007mo
O`1oOgl01P1oOgl?000000L0Ogmo00<0000007moO`0000002`3oool00`000000oooo0?ooo`090?oo
oaH000002`1oOgl010000000oooo0?ooo`00000G0?ooo`030000003oool0000002@0Ogmo00D00000
0?ooo`3oool0oooo000000030?ooo`030000001oOgl0000001D0Ogmo00<000000?ooo`3oool0^`3o
oolS00WZ2UT0oooo4P09jPXL0?ooo``02NX:HP3oool00480oooo00<0000007moO`1oOgl04`1oOgl0
0`000000oooo0000000407moO`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl08P1oOgl0
0`000000Ogmo07moO`0907moO`030000003oool0oooo01P0oooo00<0000007moO`1oOgl01P1oOgl0
0`000000Ogmo07moO`0<07moO`X000002`3oool00`000000oooo0?ooo`090?ooo`030000001oOgl0
Ogmo00L0Ogmo00<0000007moO`1oOgl0201oOgl00`000000Ogmo07moO`0907moO`040000003oool0
oooo000001L0oooo00<000000?ooo`0000009@1oOgl010000000oooo0?ooo`0000030?ooo`030000
001oOgl0000001D0Ogmo00<000000?ooo`3oool0gP3ooolR00WZ2TT0oooo4P09jPXF0?ooo``02NX:
EP3oool00480oooo00<0000007moO`1oOgl04`1oOgl00`000000oooo0000000407moO`030000001o
Ogl0Ogmo0080Ogmo00<0000007moO`1oOgl08P1oOgl00`000000Ogmo07moO`0907moO`030000003o
ool0oooo01P0oooo00<0000007moO`1oOgl01P1oOgl00`000000Ogmo07moO`0C07moO`030000001o
Ogl0000000/0oooo00<000000?ooo`3oool02@3oool00`000000Ogmo07moO`0707moO`030000001o
Ogl0Ogmo00P0Ogmo00<0000007moO`1oOgl02@1oOgl010000000oooo0?ooo`00000G0?ooo`030000
003oool0000002D0Ogmo00@000000?ooo`3oool000000`3oool00`000000Ogmo0000000E07moO`03
0000003oool0oooo0?l0oooo0@3ooolS00WZ2SP0oooo4P09jPX@0?ooo``02NX:BP3oool00480oooo
00<0000007moO`1oOgl04`1oOgl00`000000oooo0000000407moO`030000001oOgl0Ogmo0080Ogmo
00<0000007moO`1oOgl08P1oOgl00`000000Ogmo07moO`0807moO`030000003oool0oooo01T0oooo
00<0000007moO`1oOgl01P1oOgl00`000000Ogmo07moO`0C07moO`030000001oOgl0000000/0oooo
00<000000?ooo`3oool02@3oool00`000000Ogmo07moO`0707moO`030000001oOgl0Ogmo00P0Ogmo
00<0000007moO`1oOgl02@1oOgl010000000oooo0?ooo`00000G0?ooo`030000003oool0000002D0
Ogmo00@000000?ooo`3oool000000`3oool00`000000Ogmo0000000E07moO`030000003oool0oooo
0?l0oooo903ooolR00WZ2RP0oooo4P09jPX:0?ooo`/02NX:?`3oool00480oooo00<0000007moO`1o
Ogl04`1oOgl00`000000oooo0000000407moO`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1o
Ogl08P1oOgl00`000000Ogmo07moO`0807moO`030000003oool0oooo01T0oooo00<0000007moO`1o
Ogl01P1oOgl00`000000Ogmo07moO`0C07moO`030000001oOgl0000000/0oooo00<000000?ooo`3o
ool02@3oool00`000000Ogmo07moO`0707moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1o
Ogl0201oOgl010000000oooo0?ooo`00000G0?ooo`030000003oool0000002D0Ogmo00@000000?oo
o`3oool000000`3oool00`000000Ogmo0000000E07moO`030000003oool0oooo0?l0ooooAP3ooolS
00WZ2QL0oooo4P09jPX30?ooo``02NX:<`3oool00480oooo00<0000007moO`1oOgl04`1oOgl00`00
0000oooo0000000407moO`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl08P1oOgl00`00
0000Ogmo07moO`0807moO`030000003oool0oooo01T0oooo00<0000007moO`1oOgl01P1oOgl00`00
0000Ogmo07moO`0C07moO`030000001oOgl0000000/0oooo00<000000?ooo`3oool02@3oool00`00
0000Ogmo07moO`0707moO`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0201oOgl01000
0000oooo0?ooo`00000G0?ooo`030000003oool0000002D0Ogmo00@000000?ooo`3oool000000`3o
ool00`000000Ogmo0000000E07moO`030000003oool0oooo0?l0ooooJ@3ooolR00WZ2PL0oooo6`09
jPXW0?ooo`00@@3oool2000001D0Ogmo0`00000407moO`030000001oOgl0Ogmo0080Ogmo00<00000
07moO`1oOgl08P1oOgl00`000000Ogmo07moO`0807moO`8000006@3oool2000000L0Ogmo0P00000E
07moO`<000002P3oool2000000X0oooo0P00000907moO`030000001oOgl0Ogmo00P0Ogmo0P000009
07moO`8000000P3oool00`000000oooo0?ooo`0E0?ooo`040000003oool00000000002@0Ogmo0P00
0000103oool000000?ooo`3oool20000000307moO`000000Ogmo01<0Ogmo0P00003o0?ooohd0oooo
;P09jPX50?ooo`800000503oool001D0oooo;009jPX00`0000002NX:00WZ2P0E00WZ2P0300000009
jPX02NX:05<02NX:00<0000000WZ2P09jPX01P09jPX00`0000002NX:00WZ2P0E00WZ2P0300000009
jPX02NX:00T02NX:00<0000000WZ2P09jPX02@09jPX00`0000002NX:00WZ2P0C00WZ2P0300000009
jPX02NX:00P02NX:00<0000000WZ2P09jPX0A`09jPX00`0000002NX:00WZ2P0E00WZ2P0300000009
jPX02NX:0?l02NX:_`09jPX2000001@0oooo00120?ooo`030000001oOgl0Ogmo01<0Ogmo00<00000
0?ooo`000000101oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo0280Ogmo00<00000
07moO`1oOgl0201oOgl00`000000oooo0?ooo`0I0?ooo`030000001oOgl0Ogmo00H0Ogmo00<00000
07moO`1oOgl04`1oOgl00`000000Ogmo0000000;0?ooo`030000003oool0oooo00T0oooo00<00000
07moO`1oOgl01`1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00P0Ogmo00@00000
0?ooo`3oool000005`3oool00`000000oooo0000000U07moO`040000003oool0oooo000000<0oooo
00<0000007moO`0000005@1oOgl00`000000oooo0?ooo`3o0?ooohX0oooo;P09jPXL0?ooo`00@P3o
ool00`000000Ogmo07moO`0C07moO`030000003oool0000000@0Ogmo00<0000007moO`1oOgl00P1o
Ogl00`000000Ogmo07moO`0R07moO`030000001oOgl0Ogmo00P0Ogmo00<000000?ooo`3oool06@3o
ool00`000000Ogmo07moO`0607moO`030000001oOgl0Ogmo01<0Ogmo00<0000007moO`0000002`3o
ool00`000000oooo0?ooo`090?ooo`030000001oOgl0Ogmo00L0Ogmo00<0000007moO`1oOgl02@1o
Ogl00`000000Ogmo07moO`0807moO`040000003oool0oooo000001L0oooo00<000000?ooo`000000
9@1oOgl010000000oooo0?ooo`0000030?ooo`030000001oOgl0000001D0Ogmo00<000000?ooo`3o
ool0o`3ooomX0?ooob802NX:1`3ooolK00WZ2RP0oooo00120?ooo`030000001oOgl0Ogmo01<0Ogmo
00<000000?ooo`000000101oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo0280Ogmo
00<0000007moO`1oOgl0201oOgl00`000000oooo0?ooo`0I0?ooo`030000001oOgl0Ogmo00H0Ogmo
00<0000007moO`1oOgl04`1oOgl00`000000Ogmo0000000;0?ooo`030000003oool0oooo00T0oooo
00<0000007moO`1oOgl01`1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00P0Ogmo
00@000000?ooo`3oool000005`3oool00`000000oooo0000000U07moO`040000003oool0oooo0000
00<0oooo00<0000007moO`0000005@1oOgl00`000000oooo0?ooo`3o0?ooodD0oooo8`09jPXG0?oo
oa802NX:0`3oool<00WZ2S@0oooo00120?ooo`030000001oOgl0Ogmo01<0Ogmo00<000000?ooo`00
0000101oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo0280Ogmo00<0000007moO`1o
Ogl0201oOgl00`000000oooo0?ooo`0I0?ooo`030000001oOgl0Ogmo00H0Ogmo00<0000007moO`1o
Ogl04`1oOgl00`000000Ogmo0000000;0?ooo`030000003oool0oooo00T0oooo00<0000007moO`1o
Ogl01`1oOgl00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo00P0Ogmo00@000000?ooo`3o
ool000005`3oool00`000000oooo0000000U07moO`040000003oool0oooo000000<0oooo00<00000
07moO`0000005@1oOgl00`000000oooo0?ooo`3o0?ooob<0oooo8P09jPXX0?oooa802NX:2P3oool;
00WZ2T00oooo00120?ooo`030000001oOgl0Ogmo01<0Ogmo00<000000?ooo`000000101oOgl00`00
0000Ogmo07moO`0207moO`030000001oOgl0Ogmo0280Ogmo00<0000007moO`1oOgl0201oOgl00`00
0000oooo0?ooo`0I0?ooo`030000001oOgl0Ogmo00H0Ogmo00<0000007moO`1oOgl04`1oOgl00`00
0000Ogmo0000000;0?ooo`030000003oool0oooo00T0oooo00<0000007moO`1oOgl01`1oOgl00`00
0000Ogmo07moO`0807moO`030000001oOgl0Ogmo00T0Ogmo00@000000?ooo`3oool000005`3oool0
0`000000oooo0000000U07moO`040000003oool0oooo000000<0oooo00<0000007moO`0000005@1o
Ogl00`000000oooo0?ooo`3o0?ooob<02NX:>03ooolB00WZ2Q00oooo3009jPY;0?ooo`00@P3oool0
0`000000Ogmo07moO`0C07moO`030000003oool0000000@0Ogmo00<0000007moO`1oOgl00P1oOgl0
0`000000Ogmo07moO`0R07moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0603oool0
0`000000Ogmo07moO`0607moO`030000001oOgl0Ogmo00@0Ogmo4P00000;0?ooo`030000003oool0
oooo00T0oooo4@00000407moO`030000001oOgl0Ogmo00T0Ogmo00@000000?ooo`3oool000005`3o
ool00`000000oooo0000000U07moO`040000003oool0oooo000000<0oooo00<0000007moO`000000
5@1oOgl00`000000oooo0?ooo`3L0?ooob<02NX:B@3ooolB00WZ2QH0oooo3009jPYG0?ooo`00@P3o
ool00`000000Ogmo07moO`0C07moO`030000003oool0000000@0Ogmo00<0000007moO`1oOgl00P1o
Ogl00`000000Ogmo07moO`0R07moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0503o
oolD000000l0Ogmo00<0000007moO`0000002`3oool00`000000oooo0?ooo`090?ooo`030000001o
Ogl0Ogmo00L0Ogmo00<0000007moO`1oOgl0101oOgl;000000D0Ogmo00@000000?ooo`3oool00000
5`3oool00`000000oooo0000000T07moO`050000003oool0oooo0?ooo`0000000`3oool00`000000
Ogmo0000000E07moO`030000003oool0oooo0;X0oooo8P09jPYJ0?oooa802NX:703oool<00WZ2V<0
oooo00120?ooo`030000001oOgl0Ogmo01<0Ogmo00@000000?ooo`3oool000000`1oOgl00`000000
Ogmo07moO`0207moO`030000001oOgl0Ogmo0280Ogmo00<0000007moO`1oOgl02@1oOgl00`000000
oooo0?ooo`0<0?ooo`P00000103oool00`000000Ogmo07moO`0607moO`030000001oOgl0Ogmo01<0
Ogmo00<0000007moO`0000002`3oool00`000000oooo0?ooo`090?ooo`030000001oOgl0Ogmo00L0
Ogmo00<0000007moO`1oOgl0201oOgl00`000000Ogmo07moO`0407moO`H000000P3oool700000140
oooo00<000000?ooo`000000901oOgl01@000000oooo0?ooo`3oool0000000<0oooo00<0000007mo
O`0000005@1oOgl00`000000oooo0?ooo`2G0?ooob<02NX:JP3ooolB00WZ2R80oooo3009jPY_0?oo
o`00@P3oool00`000000Ogmo07moO`0C07moO`040000003oool0oooo000000<0Ogmo00<0000007mo
O`1oOgl00P1oOgl00`000000Ogmo07moO`0R07moO`030000001oOgl0Ogmo00T0Ogmo00<000000?oo
o`3oool0103oool8000000`0oooo00<0000007moO`1oOgl01P1oOgl00`000000Ogmo07moO`0C07mo
O`030000001oOgl0000000/0oooo00<000000?ooo`3oool02@3oool00`000000Ogmo07moO`0707mo
O`030000001oOgl0Ogmo00P0Ogmo00<0000007moO`1oOgl02@1oOgl010000000oooo0?ooo`000006
0?ooo``000001@3oool00`000000oooo0000000T07moO`050000003oool0oooo0?ooo`0000000`3o
ool00`000000Ogmo0000000D07moO`030000003oool0oooo07H0oooo8P09jPYk0?oooa802NX::03o
ool<00WZ2W/0oooo00130?ooo`030000001oOgl0Ogmo0180Ogmo00@000000?ooo`3oool000000`1o
Ogl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo0280Ogmo00<0000007moO`1oOgl02@1o
Ogl7000001@0oooo00<0000007moO`1oOgl01P1oOgl00`000000Ogmo07moO`0C07moO`030000001o
Ogl0000000/0oooo00<000000?ooo`3oool02@3oool00`000000Ogmo07moO`0707moO`030000001o
Ogl0Ogmo00P0Ogmo00<0000007moO`1oOgl02@1oOgl010000000oooo0?ooo`00000B0?ooo`H00000
00<0oooo0000001oOgl08`1oOgl01@000000oooo0?ooo`3oool0000000<0oooo00<0000007moO`00
0000501oOgl00`000000oooo0?ooo`1C0?ooob<02NX:R`3ooolB00WZ2Rh0oooo3009jPZ70?ooo`00
@`3oool00`000000Ogmo07moO`0B07moO`040000003oool0oooo000000<0Ogmo00<0000007moO`1o
Ogl00P1oOgl00`000000Ogmo07moO`0R07moO`040000001oOgl0Ogmo07moO`T000006@3oool20000
00P0Ogmo0P00000;07moO`X02NX:00<0000000WZ2P09jPX02@09jPX00`0000002NX:00WZ2P0900WZ
2P0300000009jPX02NX:01h02NX:00<0000000WZ2P09jPX09@09jPXK07moO`050000003oool0oooo
0?ooo`0000000`3oool00`000000Ogmo0000000D07moO`030000003oool0oooo0340oooo8P09jPZL
0?oooa802NX:=@3oool;00WZ2Y<0oooo00130?ooo`030000001oOgl0Ogmo0180Ogmo00@000000?oo
o`3oool000000`1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo0280Ogmo0P000009
00WZ2P0300000009jPX02NX:01P02NX:00<0000000WZ2P09jPX01`09jPX00`0000002NX:00WZ2P0:
00WZ2P@0Ogmo2000000:0?ooo`8000002P3oool2000000T0Ogmo00<0000007moO`1oOgl0201oOgl2
000000T0Ogmo0P0000020?ooo`030000003oool0oooo01D0oooo0`00000907moOa<02NX:201oOgl2
00000080oooo00<000000?ooo`3oool00P0000000`1oOgl0000007moO`0C07moO`8000003`3ooolS
00WZ2Z`0oooo4P09jPXk0?ooo``02NX:WP3oool004<0oooo00<0000007moO`1oOgl04P1oOgl01000
0000oooo0?ooo`00000307moO`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl04@1oOglC
00WZ2P/0Ogmo00<000000?ooo`3oool05`3oool00`000000Ogmo07moO`0707moO`030000001oOgl0
Ogmo0080Ogmo2`00000507moO`030000001oOgl0000000/0oooo00<000000?ooo`3oool02@3ooolA
000000<0Ogmo00<0000007moO`1oOgl02P1oOgl010000000oooo0?ooo`00000G0?ooo`8000007@1o
Ogl?00WZ2P0300000009jPX02NX:02H02NX:_@3ooolB00WZ2T40oooo3009jPZZ0?ooo`00@`3oool0
0`000000Ogmo07moO`0B07moO`@000000`1oOgl00`000000Ogmo07moO`0207moO`0300000009jPX0
2NX:01402NX:4@1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo01L0oooo00<00000
07moO`1oOgl00P1oOgl:00000100Ogmo00<0000007moO`0000002`3oool00`000000oooo0?ooo`09
0?ooo`030000001oOgl0Ogmo00L0Ogmo00<0000007moO`1oOgl0101oOgl;000000D0Ogmo00@00000
0?ooo`3oool000005`3oool2000002D0Ogmo00D000000?ooo`3oool0oooo000000030?ooo`030000
001oOgl0000001@0Ogmo00<000000?ooo`3oool0^@3ooolB00WZ2TL0oooo3009jPZf0?ooo`005@3o
ool]00WZ2P0300000009jPX02NX:01D02NX:00<0000000WZ2P09jPX02009jPXT07moO`030000001o
Ogl0Ogmo00X0Ogmo00<000000?ooo`3oool05@3oool7000000H0Ogmo00<0000007moO`1oOgl04@1o
Ogl00`000000Ogmo0000000;0?ooo`030000003oool0oooo00T0oooo00<0000007moO`1oOgl01`1o
Ogl00`000000Ogmo07moO`0707moO`030000001oOgl0Ogmo00D0Ogmo1P0000020?ooo`030000003o
ool0oooo01D0oooo0P00000U07moO`050000003oool0oooo0?ooo`0000000`3oool00`000000Ogmo
0000000D07moO`030000003oool0oooo0:L0oooo4P09jPY=0?ooo``02NX:`P3oool00480oooo0P00
000D07moO`040000003oool0oooo000000<0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo
07moO`0R07moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0403oool500000080oooo
00<0000007moO`1oOgl0201oOgl00`000000Ogmo07moO`0A07moO`030000001oOgl0000000/0oooo
00<000000?ooo`3oool02@3oool00`000000Ogmo07moO`0707moO`030000001oOgl0Ogmo00L0Ogmo
00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`03000001D0oooo0P00000U07moO`050000
003oool0oooo0?ooo`0000000`3oool00`000000Ogmo0000000D07moO`030000003oool0oooo09D0
oooo4P09jPYC0?ooo``02NX:cP3oool004<0oooo00<0000007moO`1oOgl04P1oOgl010000000oooo
0?ooo`00000307moO`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl08P1oOgl00`000000
Ogmo07moO`0:07moO`030000003oool0oooo00/0oooo1@0000070?ooo`030000001oOgl0Ogmo00P0
Ogmo00<0000007moO`1oOgl04@1oOgl00`000000Ogmo0000000;0?ooo`030000003oool0oooo00T0
oooo00<0000007moO`1oOgl01`1oOgl00`000000Ogmo07moO`0707moO`030000001oOgl0Ogmo00X0
Ogmo00@000000?ooo`3oool000000P3oool500000100oooo0P00000T07moO`030000003oool0oooo
0080oooo00L000000?ooo`3oool0oooo0000001oOgl0000001@0Ogmo00<000000?ooo`3oool0P`3o
oolB00WZ2UT0oooo3009jP[J0?ooo`00@`3oool00`000000Ogmo07moO`0B07moO`050000003oool0
oooo0?ooo`0000000P1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo0280Ogmo00<0
000007moO`1oOgl02`1oOgl00`000000oooo0?ooo`050?ooo`D00000303oool00`000000Ogmo07mo
O`0907moO`030000001oOgl0Ogmo00`0Ogmo1`00000;0?ooo`030000003oool0oooo00T0oooo00<0
000007moO`1oOgl01`1oOgl00`000000Ogmo07moO`0707moO`030000001oOgl0Ogmo00X0Ogmo00@0
00000?ooo`3oool000001`3oool5000000/0oooo00<0000007moO`1oOgl08`1oOgl00`000000oooo
0?ooo`020?ooo`070000003oool0oooo0?ooo`000000Ogmo0000000D07moO`030000003oool0oooo
0740oooo4P09jPYO0?ooo``02NX:iP3oool004<0oooo00<0000007moO`1oOgl04P1oOgl01@000000
oooo0?ooo`3oool000000080Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0R07mo
O`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool01@00000A0?ooo`030000001oOgl0Ogmo
00T0Ogmo00<0000007moO`1oOgl0101oOgl8000000@0Ogmo00<0000007moO`0000002`3oool00`00
0000oooo0?ooo`090?ooo`l000001@1oOgl00`000000Ogmo07moO`0:07moO`040000003oool0oooo
000000`0oooo1@0000060?ooo`030000001oOgl0Ogmo02<0Ogmo00<000000?ooo`3oool00P3oool0
1`000000oooo0?ooo`3oool0000007moO`000000501oOgl00`000000oooo0?ooo`1O0?oooa802NX:
IP3oool;00WZ2_80oooo00130?ooo`030000001oOgl0Ogmo0180Ogmo00D000000?ooo`3oool0oooo
0000000207moO`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl08P1oOgl00`000000Ogmo
07moO`0907moO`D000005P3oool00`000000Ogmo07moO`0907moO`L00000301oOgl00`000000Ogmo
0000000;0?ooo`030000003oool0oooo00T0oooo00<0000007moO`1oOgl01`1oOgl00`000000Ogmo
07moO`0207moO`P000002P1oOgl010000000oooo0?ooo`00000A0?ooo`D0000000<0oooo0000001o
Ogl0901oOgl00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`000000Ogmo0000000D
07moO`030000003oool0oooo04d0oooo4P09jPY/0?ooo``02NX:o@3oool004<0oooo00<0000007mo
O`1oOgl04P1oOgl01@000000oooo0?ooo`3oool000000080Ogmo00<0000007moO`1oOgl00P1oOgl0
0`000000Ogmo07moO`0R07moO`030000001oOgl0Ogmo00@0Ogmo1@00000207moO`030000003oool0
oooo01H0oooo00@0000007moO`1oOgl0Ogmo200000000`1oOgl0000007moO`0@07moO`030000001o
Ogl0000000/0oooo00<000000?ooo`3oool02@3oool00`000000Ogmo07moO`0707moO`030000001o
Ogl0Ogmo00H0Ogmo00@0000007moO`1oOgl0Ogmo1`00000307moO`040000003oool0oooo000001H0
oooo0P00000U07moO`030000003oool0oooo0080oooo00L000000?ooo`3oool0oooo0000001oOgl0
000001@0Ogmo00<000000?ooo`3oool0>`3ooolB00WZ2W80oooo3009jP[o0?ooo`X0oooo00130?oo
o`030000001oOgl0Ogmo0180Ogmo00D000000?ooo`3oool0oooo0000000207moO`030000001oOgl0
Ogmo0080Ogmo00<0000007moO`1oOgl08P1oOgl00`000000Ogmo00000004000000P0Ogmo00<00000
0?ooo`3oool04`3oool6000000T0Ogmo00<0000007moO`1oOgl03`1oOgl3000000X0oooo0P00000:
0?ooo`8000002@1oOgl00`000000Ogmo07moO`0607moO`8000001@1oOgl600WZ2P0300000009jPX0
2NX:01l02NX:801oOgl00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`000000Ogmo
0000000C07moO`030000003oool0oooo02X0oooo4P09jPYh0?ooo``02NX:o`3ooolF0?ooo`00@`3o
ool00`000000Ogmo07moO`0B07moO`030000003oool0oooo0080oooo00<0000007moO`000000101o
Ogl00`000000Ogmo07moO`0R07moO`8000002@1oOgl300WZ2P0300000009jPX02NX:01D02NX:00<0
000000WZ2P09jPX07P09jPX00`0000002NX:00WZ2P0900WZ2P0300000009jPX02NX:00T02NX:00<0
000000WZ2P09jPX06009jPX607moO`8000000P3oool3000001@0oooo0P00000507moO`d02NX:4`1o
Ogl00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`000000Ogmo0000000C07moO`03
0000003oool0oooo01P0oooo4P09jPYn0?ooo``02NX:o`3ooolR0?ooo`00A03oool00`000000Ogmo
07moO`0A07moO`030000003oool0oooo0080oooo00<0000007moO`000000101oOgl00`000000Ogmo
07moO`0R07moO`030000001oOgl0Ogmo00P02NX:0`1oOgl2000000l0oooo0`0000040?ooo`800000
301oOgl2000000d0Ogmo1P00000;0?ooo`030000003oool0oooo00T0oooo00<0000007moO`1oOgl0
1`1oOgl00`000000Ogmo07moO`0607moO`030000001oOgl0Ogmo00/0Ogmo00@000000?ooo`3oool0
00000P3oool300000140oooo0P00000B07moO`d02NX:1@1oOgl00`000000oooo0?ooo`030?ooo`07
0000003oool0oooo0?ooo`000000Ogmo0000000C07moO`030000003oool0oooo00H0oooo4P09jPZ4
0?ooo``02NX:o`3oool^0?ooo`00A03oool00`000000Ogmo07moO`0A07moO`030000003oool0oooo
0080oooo00<0000007moO`000000101oOgl00`000000Ogmo07moO`0L07moO`T02NX:3@1oOgl00`00
0000oooo0?ooo`090?ooo`<00000203oool00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo
00D0Ogmo1P00000307moO`030000001oOgl0000000/0oooo00<000000?ooo`3oool02@3oool>0000
00D0Ogmo00<0000007moO`1oOgl02`1oOgl010000000oooo0?ooo`0000050?ooo`<000003P3oool2
000001l0Ogmo1009jPX00`0000002NX:00WZ2P0W00WZ2XX0oooo3009jP[o0?ooocX0oooo00140?oo
o`030000001oOgl0Ogmo0140Ogmo00<000000?ooo`3oool00P3oool00`000000Ogmo0000000407mo
O`030000001oOgl0Ogmo01@0Ogmo2009jPX607moO`030000001oOgl0Ogmo00d0Ogmo00<000000?oo
o`3oool01@3oool4000000/0oooo00<0000007moO`1oOgl0301oOgl7000000T0Ogmo00<0000007mo
O`0000002`3oool00`000000oooo0?ooo`090?ooo`030000001oOgl0Ogmo00L0Ogmo00@0000007mo
O`1oOgl0Ogmo1P00000=07moO`040000003oool0oooo000000P0oooo0`00000:0?ooo`030000001o
Ogl0000002<0Ogmo0P0000050?ooo`030000003oool0oooo0080000000<0Ogmo0000001oOgl04P1o
Ogl2000008D0oooo3009jP[o0?ooodH0oooo00140?ooo`030000001oOgl0Ogmo0140Ogmo00<00000
0?ooo`3oool00P3oool00`000000Ogmo0000000407moO`030000001oOgl0Ogmo00`0Ogmo2009jPX>
07moO`030000001oOgl0Ogmo00d0Ogmo00<000000?ooo`3oool00P3oool3000000l0oooo00<00000
07moO`1oOgl01P1oOgl7000000l0Ogmo00<0000007moO`0000002`3oool00`000000oooo0?ooo`09
0?ooo`030000001oOgl0Ogmo00L0Ogmo00<0000007moO`1oOgl01P1oOgl6000000P0Ogmo00@00000
0?ooo`3oool000002`3oool3000000L0oooo00<0000007moO`000000901oOgl00`000000oooo0?oo
o`030?ooo`L000004`1oOgl00`000000oooo0?ooo`1i0?ooo`/02NX:o`3ooomB0?ooo`00A03oool0
0`000000Ogmo07moO`0A07moO`030000003oool0oooo00<0oooo0P00000407moO`030000001oOgl0
Ogmo00<0Ogmo2@09jPXF07moO`030000001oOgl0Ogmo00h0Ogmo1000000B0?ooo`030000001oOgl0
Ogmo00H000001P1oOgl00`000000Ogmo07moO`0=07moO`030000001oOgl0000000/0oooo00<00000
0?ooo`3oool02@3oool00`000000Ogmo07moO`0707moO`030000001oOgl0Ogmo00D0Ogmo00<00000
07moO`1oOgl0101oOgl600000080Ogmo00@000000?ooo`3oool000003P3oool3000000@0oooo00<0
000007moO`000000901oOgl00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080Ogmo
00<0000007moO`1oOgl04@1oOgl00`000000oooo0?ooo`1]0?ooo``02NX:o`3ooomM0?ooo`00A03o
ool00`000000Ogmo07moO`0A07moO`800000103oool4000000P02NX:7`1oOgl00`000000Ogmo07mo
O`0<07moO`<00000503oool4000000d0Ogmo00<0000007moO`1oOgl02@1oOgl6000000/0oooo00<0
00000?ooo`3oool02@3oool00`000000Ogmo07moO`0707moO`030000001oOgl0Ogmo00D0Ogmo00<0
000007moO`1oOgl02P1oOgl300000080oooo00<000000?ooo`3oool03`3oool400000080Ogmo00<0
000007moO`1oOgl08@1oOgl00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000080Ogmo
00<0000007moO`1oOgl04@1oOgl00`000000oooo0?ooo`1Q0?ooo``02NX:o`3ooomY0?ooo`005@3o
oolI00WZ2QH0oooo0P00000907moO`T02NX:00<0000000WZ2P09jPX01`09jPX207moO`030000001o
Ogl0Ogmo0280Ogmo00<0000007moO`1oOgl0201oOgl400000080Ogmo00<000000?ooo`3oool03`3o
ool3000000030?ooo`000000Ogmo00h0Ogmo00<0000007moO`1oOgl0101oOgl5000000<0Ogmo00<0
000007moO`0000002`3oool00`000000oooo0?ooo`090?ooo`d000001@1oOgl00`000000Ogmo07mo
O`0<07moO`030000003oool0oooo008000004`3oool4000002<0Ogmo00<000000?ooo`3oool0103o
ool010000000oooo0?ooo`00000207moO`030000001oOgl0Ogmo0140Ogmo00<000000?ooo`3oool0
E@3oool<00WZ2_l0ooooM@3oool002h0oooo8@09jPX:07moO`030000003oool0oooo0080oooo0P00
000407moO`030000001oOgl0Ogmo0280Ogmo00<0000007moO`1oOgl01@1oOgl3000000L0Ogmo00<0
00000?ooo`3oool0303oool2000000@0oooo00<0000007moO`1oOgl03@1oOgl00`000000Ogmo0000
0004000000P0Ogmo00<0000007moO`0000002`3oool00`000000oooo0?ooo`090?ooo`030000001o
Ogl0Ogmo00L0Ogmo00<0000007moO`1oOgl01P00000>07moO`050000003oool0oooo0000003oool0
0`00000@0?ooo`040000001oOgl0Ogmo000002<0Ogmo00<000000?ooo`3oool0103oool010000000
oooo0?ooo`00000207moO`030000001oOgl0Ogmo0100Ogmo00<000000?ooo`3oool0BP3oool<00WZ
2_l0ooooP@3oool004@0oooo00<0000007moO`1oOgl04P1oOgl00`000000oooo0?ooo`030?ooo`03
0000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl08P1oOgl00`000000Ogmo07moO`0207moO`<0
00002P1oOgl00`000000oooo0?ooo`090?ooo`<000001P3oool00`000000Ogmo07moO`0:07moO`D0
00003@1oOgl00`000000Ogmo0000000;0?ooo`030000003oool0oooo00T0oooo00<0000007moO`1o
Ogl01`1oOgl00`000000Ogmo07moO`0407moO`H000002P1oOgl010000000oooo0?ooo`0000040?oo
o`8000003@3oool01@000000Ogmo07moO`1oOgl000000280Ogmo00<000000?ooo`3oool01@3oool0
10000000oooo0?ooo`00000207moO`030000001oOgl0Ogmo0100Ogmo00<000000?ooo`3oool0?P3o
ool<00WZ2_l0ooooS@3oool004D0oooo00<0000007moO`1oOgl04@1oOgl00`000000oooo0?ooo`03
0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl08P1oOgl00`000000Ogmo00000002
000000h0Ogmo00<000000?ooo`3oool01P3oool2000000T0oooo00<0000007moO`1oOgl01@1oOgl5
000000@0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo0000000;0?ooo`030000003oool0
oooo00T0oooo00<0000007moO`1oOgl01`1oOgl00`000000Ogmo07moO`0307moO`8000001@1oOgl4
000000D0Ogmo0P0000020?ooo`030000003oool0oooo00@0oooo00<0000000WZ2P09jPX03P09jPX0
0`000000Ogmo07moO`0P07moO`030000003oool0oooo00D0oooo00@000000?ooo`3oool000000P1o
Ogl00`000000Ogmo07moO`0@07moO`030000003oool0oooo0380oooo3009jP[o0?oooiT0oooo0015
0?ooo`030000001oOgl0Ogmo0140Ogmo00<000000?ooo`3oool00`3oool00`000000Ogmo07moO`02
07moO`030000001oOgl0Ogmo0280Ogmo0P00000A07moO`8000001@3oool2000000X0oooo0P000002
07moO`D000000P1oOglF00WZ2P0300000009jPX02NX:00T02NX:00<0000000WZ2P09jPX02@09jPX0
0`0000002NX:00WZ2P0N00WZ2P0300000009jPX02NX:00T02NX:00@0oooo00000000000000001`3o
ool2000000<0Ogmo1`09jPXK07moO`030000003oool0oooo00H0oooo00@000000?ooo`3oool00000
0P1oOgl00`000000Ogmo07moO`0@07moO`030000003oool0oooo02L0oooo2`09jP[o0?ooojD0oooo
00150?ooo`030000001oOgl0Ogmo0140Ogmo00<000000?ooo`3oool00`3oool2000000<0Ogmo00<0
000007moO`1oOgl08P1oOgl00`000000Ogmo07moO`0>07moO`802NX:00<0000000WZ2P09jPX04009
jPX00`0000002NX:00WZ2P0800WZ2PT0Ogmo0P00000307moO`D000000P1oOgl3000000X0oooo0P00
000:0?ooo`h000000`1oOgl00`000000Ogmo07moO`0=07moO`8000000P3oool00`000000oooo0?oo
o`090?ooo`8000001@3oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00@0Ogmo2009
jPXC07moO`030000003oool0oooo00H0oooo00@000000?ooo`3oool000000P1oOgl00`000000Ogmo
07moO`0@07moO`030000003oool0oooo01/0oooo3009jP[o0?oook00oooo00150?ooo`030000001o
Ogl0Ogmo0140Ogmo00<000000?ooo`3oool00`3oool2000000<0Ogmo00<0000007moO`1oOgl08P1o
Ogl00`000000Ogmo07moO`0807moO`H02NX:0`1oOgl3000000d0oooo0P0000000`3oool0000007mo
O`0B07moO`@000001`1oOgl00`000000Ogmo0000000;0?ooo`030000003oool0oooo00T0oooo00<0
000007moO`1oOgl01`1oOgl00`000000Ogmo07moO`0400000100Ogmo00@000000?ooo`3oool00000
3@3oool3000000030?ooo`000000Ogmo00@0Ogmo00<0000007moO`1oOgl0301oOgl800WZ2P/0Ogmo
00<000000?ooo`3oool01P3oool010000000oooo0?ooo`00000207moO`030000001oOgl0Ogmo0100
Ogmo00<000000?ooo`3oool03`3oool<00WZ2_l0oooo_03oool004D0oooo00<0000007moO`1oOgl0
4@1oOgl00`000000oooo0?ooo`030?ooo`030000003oool000000080Ogmo00<0000007moO`1oOgl0
8P1oOgl00`000000Ogmo07moO`0207moO`H02NX:1`1oOgl4000000`0oooo0P0000030?ooo`030000
001oOgl0Ogmo00`0Ogmo1P00000:07moO`030000001oOgl0000000/0oooo00<000000?ooo`3oool0
2@3oool00`000000Ogmo07moO`0707moO`030000001oOgl0Ogmo00<0Ogmo1@00000<07moO`030000
003oool0oooo008000003`3oool2000000D0Ogmo00<0000007moO`1oOgl0501oOgl700WZ2P<0Ogmo
00<000000?ooo`3oool01`3oool010000000oooo0?ooo`00000207moO`030000001oOgl0Ogmo0100
Ogmo00<000000?ooo`3oool00`3oool<00WZ2_l0oooob03oool004D0oooo00<0000007moO`1oOgl0
4@1oOgl00`000000oooo0?ooo`030?ooo`030000003oool000000080Ogmo00<0000007moO`1oOgl0
8P1oOgl500WZ2P/0Ogmo0P00000307moO`030000003oool0oooo00P0oooo0P0000050?ooo`030000
001oOgl0Ogmo00P0Ogmo1000000607moO`030000001oOgl0Ogmo00D0Ogmo1@00000;0?ooo`030000
003oool0oooo00T0oooo00<0000007moO`1oOgl01`1oOgl00`000000Ogmo07moO`0207moO`030000
001oOgl0Ogmo00<0Ogmo0`00000907moO`050000003oool0oooo0000003oool00P00000=0?ooo`04
0000001oOgl00000000000<0Ogmo00<0000007moO`1oOgl06`1oOgl200WZ2P0300000009jPX02NX:
02002NX:00<0000000WZ2P09jPX01009jP[o0?ooom@0oooo00150?ooo`030000001oOgl0Ogmo0140
Ogmo00<000000?ooo`3oool00`3oool00`000000oooo0000000207moO`030000001oOgl0Ogmo01`0
Ogmo1P09jPX00`000000Ogmo07moO`0:07moO`<000001P1oOgl00`000000oooo0?ooo`050?ooo`80
00001`3oool00`000000Ogmo07moO`0407moO`@000002`1oOgl00`000000Ogmo07moO`0400000080
Ogmo00<0000007moO`0000002`3oool00`000000oooo0?ooo`090?ooo`d000000P1oOgl00`000000
Ogmo07moO`0607moO`@000001@1oOgl010000000oooo0?ooo`0000030?ooo`8000002`3oool01000
0000Ogmo07moO`1oOgl4000001l0Ogmo0P0000090?ooo`L000004@1oOgl200000?l0oooof@3oool0
04H0oooo00<0000007moO`1oOgl0401oOgl00`000000oooo0?ooo`030?ooo`060000003oool0oooo
0000001oOgl00000601oOgl600WZ2PH0Ogmo00<0000007moO`1oOgl0201oOgl2000000T0Ogmo00<0
00000?ooo`3oool00`3oool2000000T0oooo00<0000007moO`0000001000000>07moO`@000001P1o
Ogl00`000000Ogmo0000000;0?ooo`030000003oool0oooo00T0oooo00<0000007moO`1oOgl01`1o
Ogl00`000000Ogmo07moO`03000000`0Ogmo100000001@1oOgl000000?ooo`3oool0000000D0oooo
0P0000080?ooo`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl07@1oOgl00`000000oooo
0?ooo`080?ooo`040000003oool0oooo00000080Ogmo00<0000007moO`1oOgl03`1oOgl00`000000
oooo0?ooo`3o0?ooomP0oooo00160?ooo`030000001oOgl0Ogmo0100Ogmo00<000000?ooo`3oool0
0`3oool01P000000oooo0?ooo`000000Ogmo00000180Ogmo1P09jPX<07moO`030000001oOgl0Ogmo
00H0Ogmo0P00000<07moO`030000003oool0oooo008000002P3oool3000000l0Ogmo1000000307mo
O`030000001oOgl0Ogmo0080Ogmo1@00000;0?ooo`030000003oool0oooo00T0oooo00<0000007mo
O`1oOgl01`1oOgl01P000000Ogmo07moO`1oOgl0000007moO`<000003@1oOgl200000080oooo00<0
00000?ooo`3oool01@3oool2000000H0oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07mo
O`0M07moO`030000003oool0oooo00P0oooo00@000000?ooo`3oool000000P1oOgl00`000000Ogmo
07moO`0?07moO`030000003oool0oooo0?l0oooof03oool004H0oooo00<0000007moO`1oOgl0401o
Ogl00`000000oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`800000301oOgl600WZ2Q80Ogmo
00<0000007moO`1oOgl00`1oOgl3000000l0Ogmo0P00000:0?ooo`80000000<0oooo0000001oOgl0
301oOgl3000000P0Ogmo1000000207moO`030000001oOgl0000000/0oooo00<000000?ooo`3oool0
2@3oool00`000000Ogmo07moO`0707moO`050000001oOgl0Ogmo07moO`000000101oOgl4000000X0
Ogmo00@000000?ooo`3oool000002@3oool2000000<0oooo00<0000007moO`1oOgl01P1oOgl00`00
0000Ogmo07moO`0L07moO`030000003oool0oooo00T0oooo00@000000?ooo`3oool000000P1oOgl0
0`000000Ogmo07moO`0?07moO`030000003oool0oooo0?l0oooof03oool004H0oooo00<0000007mo
O`1oOgl04@1oOgl00`000000oooo0?ooo`020?ooo`H000001`1oOgl500WZ2QP0Ogmo00@0000007mo
O`1oOgl0Ogmo0P00000@07moO`80000000<0Ogmo0000003oool0203oool01@000000oooo0?ooo`3o
ool0000000T0Ogmo1000000807moO`D00000101oOgl00`000000Ogmo0000000;0?ooo`030000003o
ool0oooo00T0oooo3P00000907moO`<000001`1oOgl00`000000oooo0?ooo`02000000X0oooo0`00
000907moO`030000001oOgl0Ogmo01`0Ogmo00<000000?ooo`3oool02@3oool010000000oooo0?oo
o`00000207moO`030000001oOgl0Ogmo00h0Ogmo00<000000?ooo`3oool0o`3ooooI0?ooo`00AP3o
ool00`000000Ogmo07moO`0A07moO`030000003oool0oooo0080oooo00@000000?ooo`3oool0oooo
0P0000000`1oOgl02NX:00WZ2P0400WZ2Qd0Ogmo1000000@07moO`800000101oOgl00`000000oooo
0?ooo`040?ooo`800000103oool00`000000Ogmo07moO`0307moO`@000002@1oOgl3000000D0Ogmo
00<0000007moO`0000001000000;0?ooo`030000003oool0oooo00T0oooo00<0000007moO`1oOgl0
1`1oOgl00`000000Ogmo07moO`03000000X0Ogmo0`00000407moO`050000003oool0oooo0000003o
ool00P00000:0?ooo`800000201oOgl00`000000Ogmo07moO`0K07moO`030000003oool0oooo00X0
oooo00@000000?ooo`3oool000000P1oOgl00`000000Ogmo07moO`0>07moO`030000003oool0oooo
0?l0oooof@3oool001D0oooo6P09jPXH0?ooo`030000001oOgl0Ogmo00L0Ogmo2009jPX00`000000
2NX:00WZ2P0:00WZ2R<0Ogmo00<0000007moO`1oOgl0401oOgl00`000000Ogmo07moO`0407moO`03
0000003oool0oooo0080oooo0P0000060?ooo`030000001oOgl0000000<000002@1oOgl4000000L0
Ogmo0`00000207moO`030000001oOgl0000000/0oooo00<000000?ooo`3oool02@3oool=000000<0
Ogmo0`00000:07moO`<0000000D0Ogmo0000003oool0oooo000000030?ooo`030000003oool0oooo
00H0oooo00<0000007moO`1oOgl00P00000607moO`030000001oOgl0Ogmo01/0Ogmo00<000000?oo
o`3oool02P3oool010000000oooo0?ooo`00000207moO`030000001oOgl0Ogmo00h0Ogmo00<00000
0?ooo`3oool0o`3ooooI0?ooo`00;`3ooolG00WZ2P0300000009jPX02NX:00P02NX:201oOgl20000
00@0oooo00<000000?ooo`3oool00P3oool00`000000Ogmo07moO`0R07moO`030000001oOgl0Ogmo
00h0Ogmo0P00000807moO`040000003oool0oooo000000L0oooo0`00000:07moO`<00000201oOgl3
000000<0Ogmo1@00000;0?ooo`030000003oool0oooo00T0oooo00<0000007moO`1oOgl01`1oOgl0
0`000000Ogmo00000002000000@0Ogmo1000000907moO`8000000P3oool00`000000oooo0?ooo`02
0?ooo`8000001@3oool00`000000Ogmo07moO`0307moO`800000101oOgl00`000000Ogmo07moO`0J
07moO`030000003oool0oooo00/0oooo00@000000?ooo`3oool000000P1oOgl00`000000Ogmo07mo
O`0>07moO`030000003oool0oooo0?l0oooof@3oool004H0oooo0P00000B07moO`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool2000002<0Ogmo00<0000007moO`1oOgl0301oOgl2
000000/0Ogmo0P0000070?ooo`030000003oool0000000P0Ogmo0`00000807moO`<000000`1oOgl3
0000000507moO`000000000007moO`0000002`3oool00`000000oooo0?ooo`090?ooo`030000001o
Ogl0Ogmo00L0Ogmo0P00000307moO`8000001P1oOgl3000000L0Ogmo00@000000?ooo`3oool00000
1P3oool200000080oooo00<0000007moO`1oOgl01P1oOgl200000080Ogmo00<0000007moO`1oOgl0
6P1oOgl00`000000oooo0?ooo`0;0?ooo`040000003oool0oooo00000080Ogmo00<0000007moO`1o
Ogl03P1oOgl00`000000oooo0?ooo`3o0?ooomT0oooo00170?ooo`030000001oOgl0Ogmo0100Ogmo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`8000008`1oOgl00`000000Ogmo
07moO`0:07moO`8000002`1oOgl20000000307moO`000000oooo00@0oooo0P0000020?ooo`030000
001oOgl0Ogmo0080Ogmo1000000807moO`<000000`1oOgl3000000<0Ogmo1@00000;0?ooo`030000
003oool0oooo00T0oooo3000000507moO`<000001P1oOgl3000000@0Ogmo00<000000?ooo`3oool0
0P0000070?ooo`030000003oool0000000X0Ogmo0`00000K07moO`030000003oool0oooo00`0oooo
00@000000?ooo`3oool000000P1oOgl00`000000Ogmo07moO`0>07moO`030000003oool0oooo0?l0
oooof@3oool004L0oooo00<0000007moO`1oOgl0401oOgl00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`0000008P1oOgl00`000000Ogmo07moO`0807moO`800000
301oOgl00`000000Ogmo07moO`0207moO`050000003oool0oooo0?ooo`000000103oool00`000000
Ogmo00000002000000T0Ogmo0`00000307moO`<000000`1oOgl300000100oooo00<000000?ooo`3o
ool02@3oool?000000D0Ogmo0`00000607moO`<0000000L0Ogmo0000003oool0oooo0000003oool0
000000L0oooo0P00000<07moO`030000001oOgl0Ogmo01T0Ogmo00<000000?ooo`3oool0303oool0
10000000oooo0?ooo`00000207moO`030000001oOgl0Ogmo00d0Ogmo00<000000?ooo`3oool0o`3o
oooJ0?ooo`00B03oool00`000000Ogmo07moO`0?07moO`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0000000R07moO`030000001oOgl0Ogmo00H0Ogmo0P00000<
07moO`8000001P1oOgl3000000@0oooo0`00000907moO`<000000`1oOgl300000080Ogmo1000000C
0?ooo`030000003oool0oooo01D0oooo1P00000507moO`8000001`1oOgl200000080oooo00<00000
0?ooo`3oool00P0000040?ooo`030000001oOgl0Ogmo008000002P1oOgl00`000000Ogmo07moO`0H
07moO`030000003oool0oooo00d0oooo00@000000?ooo`3oool000000P1oOgl00`000000Ogmo07mo
O`0=07moO`030000003oool0oooo0?l0oooofP3oool004P0oooo00<0000007moO`1oOgl03`1oOgl0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000008@1o
Ogl00`000000Ogmo07moO`0407moO`800000301oOgl2000000L0Ogmo0`0000040?ooo`030000003o
ool0000000L0Ogmo0`00000307moO`<000000P1oOgl4000001H0oooo00<000000?ooo`3oool0603o
ool20000000407moO`0000000000000000@0Ogmo0`00000507moO`040000003oool0oooo000000@0
oooo00D000000?ooo`3oool0oooo0000000407moO`800000201oOgl00`000000Ogmo07moO`0H07mo
O`030000003oool0oooo00d0oooo1`00000?07moO`030000003oool0oooo0?l0oooofP3oool004P0
oooo00<0000007moO`1oOgl0401oOgl01@000000oooo0?ooo`3oool0000000@0oooo00@000000?oo
o`3oool000008@1oOgl00`000000Ogmo07moO`0207moO`800000301oOgl2000000P0Ogmo00D00000
07moO`1oOgl0Ogmo000000020?ooo`040000003oool0oooo000000@0Ogmo0`00000307moO`<00000
00<0Ogmo0000000000000`00000I0?ooo`030000003oool0oooo01X0oooo0`000000101oOgl00000
00000000000407moO`8000000`1oOgl00`000000oooo0?ooo`02000000@0oooo0`00000707moO`03
0000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl05`1oOgl00`000000oooo0?ooo`0>0?ooo`04
0000003oool0oooo00000080Ogmo00<0000007moO`1oOgl03@1oOgl00`000000oooo0?ooo`3o0?oo
omX0oooo00180?ooo`030000001oOgl0Ogmo0100Ogmo00D000000?ooo`3oool0oooo000000040?oo
o`050000003oool0oooo0?ooo`000000801oOgl00`000000Ogmo07moO`02000000d0Ogmo00<00000
07moO`1oOgl01P1oOgl2000000D0Ogmo0P0000030?ooo`030000001oOgl00000008000000`1oOgl3
0000000307moO`000000000000<00000?03oool30000000407moO`0000000000000000<0Ogmo1000
00020?ooo`030000003oool0000000@0oooo0P00000807moO`8000001@1oOgl00`000000Ogmo07mo
O`0G07moO`030000003oool0oooo00h0oooo00@000000?ooo`3oool000000P1oOgl00`000000Ogmo
07moO`0=07moO`030000003oool0oooo0?l0oooofP3oool004P0oooo00<0000007moO`1oOgl0401o
Ogl01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000Ogmo
07moO`0M07moO`<000003@1oOgl2000000P0Ogmo00<0000007moO`1oOgl0101oOgl00`000000Ogmo
000000020?ooo`<000000`1oOgl30000000307moO`000000000000<00000@P3oool200000080Ogmo
0`00000307moO`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P1oOgl20000
00P0Ogmo0P00000307moO`030000001oOgl0Ogmo01H0Ogmo00<000000?ooo`3oool03`3oool01000
0000oooo0?ooo`00000207moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0o`3ooooK
0?ooo`00B@3oool00`000000Ogmo07moO`0?07moO`050000003oool0oooo0?ooo`000000103oool0
0`000000oooo0?ooo`020?ooo`030000001oOgl0Ogmo01d0Ogmo00<0000007moO`1oOgl02`1oOgl2
000000P0Ogmo0P00000507moO`8000000`1oOgl2000000030?ooo`000000Ogmo00T00000A`3oool3
00000080Ogmo100000020?ooo`040000003oool0oooo0?ooo`8000001@1oOgl00`000000Ogmo07mo
O`0707moO`040000001oOgl0Ogmo000001P0Ogmo00<000000?ooo`3oool03`3oool010000000oooo
0?ooo`00000207moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0o`3ooooK0?ooo`00
B@3oool00`000000Ogmo07moO`0?07moO`040000003oool0oooo0?ooo`H000001@3oool00`000000
Ogmo07moO`0L07moO`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl01`1oOgl00`000000
Ogmo07moO`0407moO`030000001oOgl0Ogmo00<0Ogmo2`00001=0?ooo`8000000`1oOgl00`000000
oooo0?ooo`0200000080oooo00<0000007moO`0000001@1oOgl2000000P0Ogmo0`00000G07moO`03
0000003oool0oooo0100oooo00@000000?ooo`3oool000000P1oOgl00`000000Ogmo07moO`0<07mo
O`030000003oool0oooo0?l0oooof`3oool004T0oooo00<0000007moO`1oOgl03`1oOgl01@000000
oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00`3oool00`000000Ogmo07moO`0L07mo
O`030000001oOgl0Ogmo00P0Ogmo0P00000807moO`8000001P1oOgl00`000000Ogmo07moO`0207mo
O`80000000<0Ogmo0000000000001@00001B0?ooo`@000000P3oool010000000oooo000000000003
07moO`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl01`1oOgl00`000000Ogmo07moO`0D
07moO`030000003oool0oooo0140oooo00@000000?ooo`3oool000000P1oOgl00`000000Ogmo07mo
O`0<07moO`030000003oool0oooo0?l0oooof`3oool004T0oooo00<0000007moO`1oOgl03`1oOgl0
1@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0103oool00`000000Ogmo07mo
O`0K07moO`030000001oOgl0Ogmo00H0Ogmo0P00000807moO`8000001P1oOgl2000000@0Ogmo00<0
000007moO`1oOgl01@00001H0?ooo`030000003oool0oooo00@00000101oOgl2000000D0Ogmo0P00
000707moO`030000001oOgl0Ogmo01<0Ogmo00<000000?ooo`3oool04P3oool010000000oooo0?oo
o`00000207moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0o`3ooooK0?ooo`00BP3o
ool00`000000Ogmo07moO`0>07moO`050000003oool0oooo0?ooo`000000103oool00`000000oooo
0?ooo`040?ooo`030000001oOgl0Ogmo01/0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo
07moO`0707moO`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo
07moO`03000005h0oooo0`0000000`1oOgl000000000000407moO`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0C07moO`030000003oool0oooo0180oooo
00@000000?ooo`3oool000000P1oOgl00`000000Ogmo07moO`0;07moO`030000003oool0oooo0?l0
oooog03oool004X0oooo00<0000007moO`1oOgl03P1oOgl01@000000oooo0?ooo`3oool0000000@0
oooo00<000000?ooo`3oool01@3oool00`000000Ogmo07moO`0J07moO`030000001oOgl0Ogmo00<0
Ogmo0P00000807moO`8000001P1oOgl2000000@0Ogmo0P0000000`1oOgl0000000000002000005l0
oooo0P0000001@1oOgl0000007moO`1oOgl0000000@0Ogmo00<0000007moO`1oOgl0101oOgl20000
00@0Ogmo00<0000007moO`1oOgl04P1oOgl00`000000oooo0?ooo`0C0?ooo`040000003oool0oooo
00000080Ogmo00<0000007moO`1oOgl02`1oOgl00`000000oooo0?ooo`3o0?ooom`0oooo001:0?oo
o`030000001oOgl0Ogmo00h0Ogmo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0
oooo00D0oooo00<0000007moO`1oOgl06P1oOgl010000000Ogmo07moO`1oOgl2000000T0Ogmo00<0
000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0307moO`050000001oOgl0Ogmo0000001oOgl0
0P00001R0?ooo`030000001oOgl000000080Ogmo00<0000007moO`1oOgl00P1oOgl2000000H0Ogmo
00D0000007moO`1oOgl0Ogmo0000000C07moO`030000003oool0oooo01@0oooo00<000000?ooo`00
00000`1oOgl00`000000Ogmo07moO`0;07moO`030000003oool0oooo0?l0oooog03oool004/0oooo
00<0000007moO`1oOgl03P1oOgl010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00H0
oooo00<0000007moO`1oOgl06@1oOgl010000000Ogmo07moO`00000907moO`8000001`1oOgl00`00
0000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@00000I03oool00`000000Ogmo0000000207mo
O`800000101oOgl00`000000Ogmo07moO`0407moO`80000000<0Ogmo0000001oOgl04@1oOgl00`00
0000oooo0?ooo`0E0?ooo`030000003oool0000000<0Ogmo00<0000007moO`1oOgl02`1oOgl00`00
0000oooo0?ooo`3o0?ooom`0oooo001;0?ooo`030000001oOgl0Ogmo00h0Ogmo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`070?ooo`030000001oOgl0Ogmo01P0Ogmo0`00000907mo
O`030000001oOgl0Ogmo00D0Ogmo0P00000407moO`8000000P1oOgl4000006H0oooo00@0000007mo
O`00000000000P1oOgl00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo00D0Ogmo0P00000A
07moO`030000003oool0oooo01H0oooo1`00000<07moO`030000003oool0oooo0?l0oooog@3oool0
04/0oooo00<0000007moO`1oOgl03P1oOgl010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo00P0oooo00<0000007moO`1oOgl05`1oOgl00`000000Ogmo07moO`0707moO`8000001`1oOgl0
0`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo00@00000J@3oool010000000Ogmo07moO`00
000207moO`030000001oOgl0Ogmo0080Ogmo0P00000607moO`030000001oOgl0Ogmo00l0Ogmo00<0
00000?ooo`3oool05P3oool00`000000oooo0000000307moO`030000001oOgl0Ogmo00X0Ogmo00<0
00000?ooo`3oool0o`3ooooM0?ooo`00C03oool00`000000Ogmo07moO`0=07moO`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool02@3oool00`000000Ogmo07moO`0F07moO`030000001o
Ogl0Ogmo00H0Ogmo00<0000007moO`1oOgl01@1oOgl2000000D0Ogmo00D0000007moO`1oOgl00000
07moO`02000006/0oooo0P000000101oOgl0000007moO`1oOgl2000000@0Ogmo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0>07moO`030000003oool0oooo01L0oooo00<000000?ooo`00
00000`1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo0?l0oooog@3oool004`0oooo
00<0000007moO`1oOgl03@1oOgl010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00T0
oooo00<0000007moO`1oOgl05P1oOgl00`000000Ogmo07moO`0407moO`8000001`1oOgl00`000000
Ogmo07moO`0307moO`8000000P1oOgl4000006d0oooo0P0000000`1oOgl0000007moO`0207moO`03
0000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0=07moO`03
0000003oool0oooo01P0oooo00<000000?ooo`0000000`1oOgl00`000000Ogmo07moO`0:07moO`03
0000003oool0oooo0?l0oooog@3oool004`0oooo00<0000007moO`1oOgl03@1oOgl010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo00X0oooo00<0000007moO`1oOgl05@1oOgl00`000000
Ogmo07moO`0207moO`800000201oOgl00`000000Ogmo07moO`0307moO`040000001oOgl0Ogmo07mo
O`@00000K`3oool20000000307moO`000000Ogmo0080Ogmo00<0000007moO`1oOgl00P1oOgl20000
0080Ogmo00<0000007moO`1oOgl02`1oOgl2000001/0oooo00<000000?ooo`0000000`1oOgl00`00
0000Ogmo07moO`0:07moO`030000003oool0oooo0?l0oooog@3oool004d0oooo00<0000007moO`1o
Ogl0301oOgl00`000000oooo0?ooo`06000000d0oooo00<0000007moO`1oOgl0501oOgl01@000000
Ogmo07moO`1oOgl0000000P0Ogmo0P00000407moO`8000000P1oOgl4000007<0oooo00@0000007mo
O`00000000000P1oOgl2000000@0Ogmo00<0000007moO`000000301oOgl00`000000oooo0?ooo`0K
0?ooo`030000003oool0000000<0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`3o
0?ooomh0oooo001=0?ooo`030000001oOgl0Ogmo00`0Ogmo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`0<0?ooo`030000001oOgl0Ogmo01<0Ogmo00@0000007moO`0000000000201o
Ogl00`000000Ogmo07moO`0307moO`060000001oOgl0Ogmo07moO`000000Ogmo0P00001e0?ooo`04
0000001oOgl0Ogmo000000<0Ogmo00<0000007moO`1oOgl00P1oOgl2000000/0Ogmo00<000000?oo
o`3oool0703oool00`000000oooo0000000307moO`030000001oOgl0Ogmo00T0Ogmo00<000000?oo
o`3oool0o`3ooooN0?ooo`00C@3oool00`000000Ogmo07moO`0<07moO`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool03@3oool00`000000Ogmo07moO`0B07moO`800000201oOgl20000
00D0Ogmo00H0000007moO`1oOgl0Ogmo0000001oOgl2000007L0oooo0P0000000`1oOgl0000007mo
O`0207moO`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl0201oOgl00`000000oooo0?oo
o`0M0?ooo`030000003oool0000000<0Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?oo
o`3o0?ooomh0oooo001>0?ooo`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`000000103oool0
0`000000oooo0?ooo`0=0?ooo`030000001oOgl0Ogmo0180Ogmo00<0000007moO`1oOgl01P1oOgl0
0`000000Ogmo07moO`0307moO`8000000P1oOgl5000007T0oooo0P0000000`1oOgl0000007moO`02
07moO`8000000P1oOgl00`000000Ogmo07moO`0707moO`030000003oool0oooo01h0oooo00<00000
0?ooo`0000000`1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo0?l0oooogP3oool0
04h0oooo00<0000007moO`1oOgl0301oOgl00`000000oooo000000040?ooo`030000003oool0oooo
00h0oooo00<0000007moO`1oOgl04@1oOgl00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo
00<0Ogmo00H0000007moO`1oOgl0Ogmo0000001oOgl3000007/0oooo0P0000000`1oOgl0000007mo
O`0307moO`030000001oOgl0000000P0Ogmo00<000000?ooo`3oool07`3oool00`000000oooo0000
000307moO`030000001oOgl0Ogmo00P0Ogmo00<000000?ooo`3oool0o`3ooooO0?ooo`00CP3oool0
0`000000Ogmo07moO`0<07moO`030000003oool0000000@0oooo00<000000?ooo`3oool03`3oool0
0`000000Ogmo07moO`0@07moO`030000001oOgl0Ogmo00<0Ogmo0P00000507moO`060000001oOgl0
Ogmo07moO`000000Ogmo0P00001n0?ooo`80000000<0Ogmo0000000000000`1oOgl2000000L0Ogmo
00<000000?ooo`3oool0803oool7000000X0Ogmo00<000000?ooo`3oool0o`3ooooO0?ooo`00C`3o
ool00`000000Ogmo07moO`0;07moO`030000003oool0000000@0oooo00<000000?ooo`3oool0403o
ool00`000000Ogmo07moO`0?07moO`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl00`1o
Ogl2000000<0Ogmo00@0000007moO`0000000000P03oool200000080Ogmo00D0000007moO`1oOgl0
Ogmo0000000607moO`030000003oool0oooo0240oooo00<000000?ooo`0000000`1oOgl00`000000
Ogmo07moO`0807moO`030000003oool0oooo0?l0oooog`3oool004l0oooo00<0000007moO`1oOgl0
2`1oOgl00`000000oooo000000040?ooo`030000003oool0oooo0140oooo0P00000?07moO`030000
001oOgl0Ogmo008000001@1oOgl010000000Ogmo07moO`1oOgl5000008<0oooo0P0000001@1oOgl0
000007moO`1oOgl0000000D0Ogmo00<000000?ooo`3oool08P3oool00`000000oooo0000000307mo
O`030000001oOgl0Ogmo00L0Ogmo00<000000?ooo`3oool0o`3ooooP0?ooo`00C`3oool00`000000
Ogmo07moO`0;07moO`030000003oool0000000@0oooo00<000000?ooo`3oool04`3oool00`000000
Ogmo07moO`0<07moO`030000001oOgl0000000H0Ogmo00H0000007moO`1oOgl0Ogmo0000001oOgl3
000008D0oooo0P000000101oOgl0000007moO`00000407moO`030000003oool0oooo02<0oooo00<0
00000?ooo`0000000`1oOgl00`000000Ogmo07moO`0707moO`030000003oool0oooo0?l0ooooh03o
ool00500oooo00<0000007moO`1oOgl02P1oOgl00`000000oooo000000040?ooo`030000003oool0
oooo01@0oooo00<0000007moO`1oOgl02`1oOgl2000000D0Ogmo0P00000307moO`040000001oOgl0
0000000008P0oooo0P0000000`1oOgl000000000000307moO`030000003oool0oooo02@0oooo00<0
00000?ooo`0000000`1oOgl00`000000Ogmo07moO`0707moO`030000003oool0oooo0?l0ooooh03o
ool00500oooo00<0000007moO`1oOgl02P1oOgl00`000000oooo000000040?ooo`030000003oool0
oooo01D0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0307moO`030000001oOgl0
Ogmo0080Ogmo00@0000007moO`0000000000RP3oool20000000507moO`000000Ogmo07moO`000000
9`3oool2000000@0Ogmo00<0000007moO`1oOgl01P1oOgl00`000000oooo0?ooo`3o0?ooon40oooo
001@0?ooo`030000001oOgl0Ogmo00/0Ogmo1`00000H0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0
000007moO`1oOgl00P1oOgl010000000Ogmo07moO`1oOgl20000000307moO`000000000008`0oooo
0`0000000`1oOgl000000?ooo`0W0?ooo`800000101oOgl00`000000Ogmo07moO`0607moO`030000
003oool0oooo0?l0ooooh@3oool00540oooo00<0000007moO`1oOgl02P1oOgl2000000@0oooo00<0
00000?ooo`3oool05`3oool00`000000Ogmo07moO`0807moO`030000001oOgl0Ogmo008000000`1o
Ogl00`000000Ogmo00000002000008h0oooo0`00000Y0?ooo`800000101oOgl00`000000Ogmo07mo
O`0607moO`030000003oool0oooo0?l0ooooh@3oool00540oooo00<0000007moO`1oOgl02P1oOgl2
000000@0oooo00<000000?ooo`3oool0603oool00`000000Ogmo07moO`0707moO`030000001oOgl0
000000@0Ogmo00<0000007moO`0000000P00002@0?ooo`030000003oool0oooo02P0oooo0P000004
07moO`030000001oOgl0Ogmo00H0Ogmo00<000000?ooo`3oool0o`3ooooQ0?ooo`00DP3oool00`00
0000Ogmo07moO`0907moO`800000103oool00`000000oooo0?ooo`0I0?ooo`8000001`1oOgl20000
00@0Ogmo00@0000007moO`0000000000_@3oool7000000L0Ogmo00<000000?ooo`3oool0o`3ooooR
0?ooo`00DP3oool00`000000Ogmo07moO`0907moO`800000103oool00`000000oooo0?ooo`0K0?oo
o`030000001oOgl0Ogmo00@0Ogmo00@0000007moO`1oOgl0Ogmo0P0000000`1oOgl000000000002n
0?ooo`800000101oOgl00`000000Ogmo07moO`0507moO`030000003oool0oooo0?l0oooohP3oool0
0580oooo00<0000007moO`1oOgl02@1oOgl2000000@0oooo00<000000?ooo`3oool0703oool00`00
0000Ogmo07moO`0307moO`050000001oOgl0Ogmo0000001oOgl00`00002o0?ooo`800000101oOgl0
0`000000Ogmo07moO`0507moO`030000003oool0oooo0?l0oooohP3oool005<0oooo00<0000007mo
O`1oOgl02@1oOgl00`000000oooo0?ooo`020?ooo`030000003oool0oooo01d0oooo00<0000007mo
O`1oOgl00P1oOgl010000000Ogmo0000001oOgl300000<00oooo0P00000407moO`030000001oOgl0
Ogmo00@0Ogmo00<000000?ooo`3oool0o`3ooooS0?ooo`00D`3oool00`000000Ogmo07moO`0907mo
O`030000003oool0oooo0080oooo00<000000?ooo`3oool07P3oool010000000Ogmo07moO`1oOgl2
0000000307moO`00000000000<80oooo0P00000407moO`030000001oOgl0Ogmo00@0Ogmo00<00000
0?ooo`3oool0o`3ooooS0?ooo`00D`3oool00`000000Ogmo07moO`0907moO`030000003oool0oooo
0080oooo00<000000?ooo`3oool07`3oool01@000000Ogmo07moO`000000Ogmo00800000``3oool2
000000@0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`3o0?ooon<0oooo001D0?oo
o`030000001oOgl0Ogmo00P0Ogmo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0P0?oo
o`030000001oOgl0000000800000a03oool2000000@0Ogmo00<0000007moO`1oOgl00`1oOgl00`00
0000oooo0?ooo`3o0?ooon@0oooo001D0?ooo`030000001oOgl0Ogmo00P0Ogmo1P00000S0?ooo`<0
0000a@3oool7000000D0Ogmo00<000000?ooo`3oool0o`3ooooT0?ooo`00E@3oool00`000000Ogmo
07moO`0707moO`030000003oool0oooo0080oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`340?ooo`800000101oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo0?l0oooo
i03oool005D0oooo00<0000007moO`1oOgl01`1oOgl2000000<0oooo00<000000?ooo`3oool0j@3o
ool2000000@0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`3o0?ooonD0oooo001E
0?ooo`030000001oOgl0Ogmo00L0Ogmo0P0000030?ooo`030000003oool0oooo0>T0oooo0P000004
07moO`030000001oOgl0Ogmo0080Ogmo00<000000?ooo`3oool0o`3ooooU0?ooo`00EP3oool00`00
0000Ogmo07moO`0607moO`8000000`3oool00`000000oooo0?ooo`3Y0?ooo`800000101oOgl01@00
0000Ogmo07moO`1oOgl000000?l0ooooj03oool005H0oooo00<0000007moO`1oOgl01P1oOgl20000
00<0oooo00<000000?ooo`3oool0j@3oool2000000@0Ogmo00D0000007moO`1oOgl0Ogmo0000003o
0?ooonP0oooo001G0?ooo`030000001oOgl0Ogmo00D0Ogmo0P0000030?ooo`030000003oool0oooo
0>T0oooo1`00000207moO`030000003oool0oooo0?l0ooooi`3oool005L0oooo00<0000007moO`1o
Ogl01@1oOgl00`000000Ogmo000000020?ooo`030000003oool0oooo0>T0oooo00<0000007moO`1o
Ogl00`1oOgl010000000Ogmo07moO`00003o0?ooonT0oooo001H0?ooo`030000001oOgl0Ogmo00@0
Ogmo1P00003[0?ooo`030000001oOgl0Ogmo00<0Ogmo00@0000007moO`1oOgl00000o`3ooooY0?oo
o`00F03oool00`000000Ogmo07moO`0407moO`030000001oOgl000000080oooo00<000000?ooo`3o
ool0j@3oool00`000000Ogmo07moO`0307moO`030000001oOgl000000?l0oooojP3oool005T0oooo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo000000020?ooo`030000003oool0oooo0>T0oooo
1`0000000`1oOgl000000?ooo`3o0?ooonT0oooo001I0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0
000007moO`0000000P3oool00`000000oooo0?ooo`3Y0?ooo`030000001oOgl0Ogmo00<0Ogmo0P00
003o0?ooon/0oooo001J0?ooo`030000001oOgl0Ogmo0080Ogmo00H0000007moO`1oOgl000000?oo
o`00003[0?ooo`030000001oOgl0Ogmo00<0Ogmo0P00003o0?ooon/0oooo001J0?ooo`030000001o
Ogl0Ogmo0080Ogmo00H0000007moO`1oOgl000000?ooo`00003[0?ooo`P00000o`3oooo[0?ooo`00
F`3oool010000000Ogmo07moO`1oOgl600000>/0oooo1`00003o0?ooon`0oooo001K0?ooo`050000
001oOgl0Ogmo07moO`0000000P1oOgl00`000000oooo0000003o0?ooool0oooog`3oool005/0oooo
00D0000007moO`1oOgl0Ogmo0000000207moO`030000003oool000000?l0ooooo`3ooooO0?ooo`00
G03oool010000000Ogmo07moO`00000307moO`800000o`3ooooo0?oooml0oooo001L0?ooo`040000
001oOgl0Ogmo000000<0Ogmo0P00003o0?ooool0oooog`3oool005d0oooo00<0000007moO`000000
1@00003o0?ooool0oooog`3oool005d0oooo00<0000007moO`0000000`1oOgl200000?l0ooooo`3o
oooO0?ooo`00GP3oool2000000<0Ogmo0P00003o0?ooool0oooog`3oool005h0oooo1`00003o0?oo
ool0oooog`3oool005l0oooo1P00003o0?ooool0oooog`3oool00?l0ooooo`3ooooo0?ooodD0oooo
003o0?ooool0ooooo`3ooom50?ooo`00o`3ooooo0?ooool0ooooA@3oool00?l0ooooo`3ooooo0?oo
odD0oooo003o0?ooool0ooooo`3ooom50?ooo`00\
\>"],
  ImageRangeCache->{{{0, 833.875}, {235.188, 0}} -> {-4.87638, -26.3123, \
0.223758, 0.223758}},
  CellTags->"CompoundLens"]
}, Open  ]],

Cell[TextData[{
  "The ",
  StyleBox["CreateStereoView -> Crossed", "Input"],
  " option allows you to see the information in three-dimensions with your \
eyes crossed."
}], "Text",
  CellTags->"CompoundLens"],

Cell[CellGroupData[{

Cell["\<\
AnalyzeSystem[result, CreateStereoView -> Crossed, PlotPoints->30];\
\
\>", "Input",
  CellTags->"CompoundLens"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .57143 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0136054 0.47619 [
[ 0 0 0 0 ]
[ 1 .57143 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .57143 L
0 .57143 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0136054 0.568027 0.557823 MathSubStart
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.26377 .59706 m
.26002 .58266 L
s
.26002 .58266 m
.26378 .58144 L
s
.26002 .58266 m
.25532 .56847 L
s
.25532 .56847 m
.25908 .56724 L
s
.25532 .56847 m
.24974 .5547 L
s
.26652 .61145 m
.26377 .59706 L
s
.26377 .59706 m
.26754 .59585 L
s
.26378 .58144 m
.26754 .59585 L
s
.25908 .56724 m
.26378 .58144 L
s
.2535 .55346 m
.25908 .56724 L
s
.24974 .5547 m
.2535 .55346 L
s
.24974 .5547 m
.24337 .54157 L
s
.26754 .59585 m
.27029 .61024 L
s
.24713 .54033 m
.2535 .55346 L
s
.26821 .6256 m
.26652 .61145 L
s
.26652 .61145 m
.27029 .61024 L
s
.24337 .54157 m
.24713 .54033 L
s
.24337 .54157 m
.23631 .52929 L
s
.27029 .61024 m
.27198 .6244 L
s
.24007 .52803 m
.24713 .54033 L
s
.26881 .63928 m
.26821 .6256 L
s
.26821 .6256 m
.27198 .6244 L
s
.23631 .52929 m
.24007 .52803 L
s
.23631 .52929 m
.22865 .51805 L
s
.27198 .6244 m
.27259 .63809 L
s
.23241 .51678 m
.24007 .52803 L
s
.26881 .63928 m
.27259 .63809 L
s
.22865 .51805 m
.23241 .51678 L
s
.22865 .51805 m
.22052 .50803 L
s
.22429 .50675 m
.23241 .51678 L
s
.24955 .64544 m .2721 .65111 L .26831 .6523 L .647 .745 .92 r
F
0 g
.26671 .66442 m
.26831 .6523 L
s
.26839 .65018 m
.26881 .63928 L
s
.22052 .50803 m
.22429 .50675 L
s
.24955 .64544 m .25831 .64268 L .2721 .65111 L .647 .745 .92 r
F
0 g
.27051 .66324 m
.2721 .65111 L
s
.2721 .65111 m
.27259 .63809 L
s
.26831 .6523 m
.2721 .65111 L
s
.23239 .638 m .25831 .64268 L .24955 .64544 L .647 .745 .92 r
F
0 g
.24955 .64544 m
.26831 .6523 L
s
.26402 .67546 m
.26671 .66442 L
s
.26671 .66442 m
.27051 .66324 L
s
.21204 .4994 m .21122 .51476 L .20249 .51771 L .528 .308 .524 r
F
.21204 .4994 m .21582 .49812 L .21122 .51476 L F
0 g
.21471 .50212 m
.22052 .50803 L
s
.21204 .4994 m
.21582 .49812 L
s
.21582 .49812 m
.22429 .50675 L
s
.20335 .49232 m
.21204 .4994 L
s
.27051 .66324 m
.26783 .67428 L
s
.20713 .49103 m
.21582 .49812 L
s
.28785 .58511 m
.28478 .57338 L
s
.28478 .57338 m
.3025 .56576 L
s
.28478 .57338 m
.28096 .56182 L
s
.28096 .56182 m
.29999 .5582 L
s
.28096 .56182 m
.27643 .5506 L
s
.23239 .638 m .24499 .63401 L .25831 .64268 L .647 .745 .92 r
F
0 g
.25831 .64268 m
.2721 .65111 L
s
.29011 .59682 m
.28785 .58511 L
s
.28785 .58511 m
.30451 .57343 L
s
.27643 .5506 m
.29704 .55086 L
s
.27643 .5506 m
.27126 .5399 L
s
.29151 .60832 m
.29011 .59682 L
s
.29011 .59682 m
.30599 .58108 L
s
.27126 .5399 m
.29367 .54386 L
s
.27126 .5399 m
.26555 .5299 L
s
.20249 .51771 m .20716 .53131 L .1946 .53553 L .528 .308 .524 r
F
.20249 .51771 m .21122 .51476 L .20716 .53131 L F
0 g
.20249 .51771 m
.21204 .4994 L
s
.21122 .51476 m
.21582 .49812 L
s
.21667 .63002 m .24499 .63401 L .23239 .638 L .647 .745 .92 r
F
0 g
.23239 .638 m
.24955 .64544 L
s
.26027 .68521 m
.26402 .67546 L
s
.26402 .67546 m
.26783 .67428 L
s
.29204 .61943 m
.29151 .60832 L
s
.26783 .67428 m
.2641 .68403 L
s
.20335 .49232 m
.20713 .49103 L
s
.20335 .49232 m
.19458 .48691 L
s
.26555 .5299 m
.25937 .52075 L
s
.19837 .48561 m
.20713 .49103 L
s
.21667 .63002 m .23213 .62509 L .24499 .63401 L .647 .745 .92 r
F
0 g
.24499 .63401 m
.25831 .64268 L
s
.1946 .53553 m .20364 .54779 L .18822 .55292 L .528 .308 .524 r
F
.1946 .53553 m .20716 .53131 L .20364 .54779 L F
0 g
.1946 .53553 m
.20249 .51771 L
s
.20716 .53131 m
.21122 .51476 L
s
.25937 .52075 m
.25283 .51261 L
s
.20227 .62152 m .23213 .62509 L .21667 .63002 L .647 .745 .92 r
F
0 g
.21667 .63002 m
.23239 .638 L
s
.039 .916 .04 r
.16536 .6385 m
.20906 .62568 L
s
0 g
.25552 .69351 m
.26027 .68521 L
s
.26027 .68521 m
.2641 .68403 L
s
.268 .62703 m .30708 .60266 L .29169 .62997 L .647 .745 .92 r
F
0 g
.29044 .63977 m
.29169 .62997 L
s
.2641 .68403 m
.25936 .69234 L
s
.19458 .48691 m
.19837 .48561 L
s
.19458 .48691 m
.18587 .48329 L
s
.18822 .55292 m .20066 .56419 L .18323 .56995 L .528 .308 .524 r
F
.18822 .55292 m .20364 .54779 L .20066 .56419 L F
0 g
.18822 .55292 m
.1946 .53553 L
s
.20364 .54779 m
.20716 .53131 L
s
.18967 .48198 m
.19837 .48561 L
s
.268 .62703 m .29279 .60036 L .30708 .60266 L .647 .745 .92 r
F
0 g
.29718 .60106 m
.30692 .58858 L
s
.30327 .60205 m
.30729 .59581 L
s
.24906 .62256 m .29279 .60036 L .268 .62703 L .647 .745 .92 r
F
0 g
.268 .62703 m
.29169 .62997 L
s
.20227 .62152 m .21973 .61591 L .23213 .62509 L .647 .745 .92 r
F
0 g
.23213 .62509 m
.24499 .63401 L
s
.28833 .64867 m
.29044 .63977 L
s
.18914 .61251 m .21973 .61591 L .20227 .62152 L .647 .745 .92 r
F
0 g
.20227 .62152 m
.21667 .63002 L
s
.039 .916 .04 r
.20906 .62568 m
.22492 .61982 L
s
.15677 .63083 m
.19756 .61844 L
s
.23313 .61708 m .28103 .59723 L .24906 .62256 L .647 .745 .92 r
F
.24906 .62256 m .28103 .59723 L .29279 .60036 L F
0 g
.24906 .62256 m
.268 .62703 L
s
.29044 .63977 m
.30629 .60901 L
s
.29169 .62997 m
.30708 .60266 L
s
.24602 .5056 m .26796 .5327 L .22986 .52333 L .528 .308 .524 r
F
.24602 .5056 m .27733 .52152 L .26796 .5327 L F
0 g
.26934 .53105 m
.28996 .53733 L
s
.27331 .52632 m
.28595 .53136 L
s
.27583 .52332 m
.28172 .52607 L
s
.24602 .5056 m
.27733 .52152 L
s
.23905 .49987 m
.24602 .5056 L
s
.22986 .52333 m .26114 .54305 L .21847 .53948 L .528 .308 .524 r
F
.22986 .52333 m .26796 .5327 L .26114 .54305 L F
0 g
.22986 .52333 m
.24602 .5056 L
s
.24983 .70021 m
.25552 .69351 L
s
.25552 .69351 m
.25936 .69234 L
s
.18323 .56995 m .19821 .58053 L .17957 .58664 L .528 .308 .524 r
F
.18323 .56995 m .20066 .56419 L .19821 .58053 L F
0 g
.18323 .56995 m
.18822 .55292 L
s
.20066 .56419 m
.20364 .54779 L
s
0 0 0 r
2 Mabswid
.19756 .61844 Mdot
0 g
.5 Mabswid
.25936 .69234 m
.25368 .69903 L
s
.18587 .48329 m
.18967 .48198 L
s
.18587 .48329 m
.17737 .48153 L
s
.21847 .53948 m .25608 .55282 L .21013 .55465 L .528 .308 .524 r
F
.21847 .53948 m .26114 .54305 L .25608 .55282 L F
0 g
.21847 .53948 m
.22986 .52333 L
s
.18118 .48021 m
.18967 .48198 L
s
.23313 .61708 m .27103 .59351 L .28103 .59723 L .647 .745 .92 r
F
.2195 .61082 m .27103 .59351 L .23313 .61708 L F
0 g
.23313 .61708 m
.24906 .62256 L
s
.039 .916 .04 r
.22492 .61982 m
.23289 .61699 L
s
0 g
.28536 .65651 m
.28833 .64867 L
s
.28833 .64867 m
.30494 .61475 L
s
.18914 .61251 m .20779 .60649 L .21973 .61591 L .647 .745 .92 r
F
0 g
.21973 .61591 m
.23213 .62509 L
s
.23905 .49987 m
.27285 .51782 L
s
.23905 .49987 m
.23204 .4955 L
s
.17722 .603 m .20779 .60649 L .18914 .61251 L .647 .745 .92 r
F
0 g
.18914 .61251 m
.20227 .62152 L
s
.039 .916 .04 r
.19756 .61844 m
.21501 .61226 L
s
.14797 .62314 m
.18696 .61089 L
s
.21013 .55465 m .25243 .56216 L .20412 .5691 L .528 .308 .524 r
F
.21013 .55465 m .25608 .55282 L .25243 .56216 L F
0 g
.21013 .55465 m
.21847 .53948 L
s
.17957 .58664 m .1963 .5968 L .17722 .603 L .528 .308 .524 r
F
.17957 .58664 m .19821 .58053 L .1963 .5968 L F
0 g
.17957 .58664 m
.18323 .56995 L
s
.2195 .61082 m .26242 .58933 L .27103 .59351 L .647 .745 .92 r
F
.20781 .60387 m .26242 .58933 L .2195 .61082 L F
0 g
.2195 .61082 m
.23313 .61708 L
s
.039 .916 .04 r
.21501 .61226 m
.21938 .61076 L
s
0 g
.24328 .70517 m
.24983 .70021 L
s
.24983 .70021 m
.25368 .69903 L
s
.28159 .66315 m
.28536 .65651 L
s
.28536 .65651 m
.30304 .61978 L
s
.25368 .69903 m
.24715 .70399 L
s
.3025 .56576 m
.30451 .57343 L
s
.29999 .5582 m
.3025 .56576 L
s
.30451 .57343 m
.3025 .56576 L
s
.3025 .56576 m
.32499 .55785 L
s
.3025 .56576 m
.29999 .5582 L
s
.29704 .55086 m
.29999 .5582 L
s
.29999 .5582 m
.32291 .55155 L
s
.29999 .5582 m
.29704 .55086 L
s
.17737 .48153 m
.18118 .48021 L
s
.17737 .48153 m
.16922 .48168 L
s
.20412 .5691 m .25 .57113 L .20009 .58295 L .528 .308 .524 r
F
0 g
.19821 .58053 m
.20066 .56419 L
s
.20412 .5691 m .25243 .56216 L .25 .57113 L .528 .308 .524 r
F
0 g
.20412 .5691 m
.21013 .55465 L
s
.30451 .57343 m
.30599 .58108 L
s
.30599 .58108 m
.30451 .57343 L
s
.30451 .57343 m
.32667 .56424 L
s
.23204 .4955 m
.26836 .51501 L
s
.23204 .4955 m
.2251 .49259 L
s
.29367 .54386 m
.29704 .55086 L
s
.29704 .55086 m
.32045 .54544 L
s
.29704 .55086 m
.29367 .54386 L
s
.17305 .48036 m
.18118 .48021 L
s
.30599 .58108 m
.30692 .58858 L
s
.30693 .58858 m
.30599 .58108 L
s
.30599 .58108 m
.32792 .57061 L
s
.28996 .53733 m
.29367 .54386 L
s
.29367 .54386 m
.31766 .53961 L
s
.29367 .54386 m
.28996 .53733 L
s
.17722 .603 m .1963 .5968 L .20779 .60649 L .647 .745 .92 r
F
0 g
.20779 .60649 m
.21973 .61591 L
s
.039 .916 .04 r
.18696 .61089 m
.20549 .6046 L
s
0 g
.30692 .58858 m
.30729 .59581 L
s
.30729 .59581 m
.30693 .58858 L
s
.28595 .53136 m
.28996 .53733 L
s
.28996 .53733 m
.28596 .53137 L
s
.17722 .603 m .19493 .61301 L .17616 .61907 L .528 .308 .524 r
F
.17722 .603 m .1963 .5968 L .19493 .61301 L F
.16651 .59298 m .1963 .5968 L .17722 .603 L .647 .745 .92 r
F
0 0 0 r
2 Mabswid
.17722 .603 Mdot
.039 .916 .04 r
.5 Mabswid
.13897 .61545 m
.17722 .603 L
s
0 g
.17844 .59451 m
.17957 .58664 L
s
.20781 .60387 m .255 .58474 L .26242 .58933 L .647 .745 .92 r
F
.19789 .59628 m .255 .58474 L .20781 .60387 L F
0 g
.20781 .60387 m
.2195 .61082 L
s
.039 .916 .04 r
.20549 .6046 m
.20776 .60384 L
s
.20009 .58295 m .24869 .57975 L .19789 .59628 L .528 .308 .524 r
F
.20009 .58295 m .25 .57113 L .24869 .57975 L F
0 g
.20009 .58295 m
.20412 .5691 L
s
.30708 .60266 m
.30729 .59581 L
s
.28172 .52607 m
.28595 .53136 L
s
.28596 .53137 m
.28172 .52607 L
s
.27707 .66847 m
.28159 .66315 L
s
.28159 .66315 m
.30063 .62402 L
s
.2251 .49259 m
.26393 .51316 L
s
.2251 .49259 m
.21835 .4912 L
s
.23598 .70827 m
.24328 .70517 L
s
.24328 .70517 m
.24715 .70399 L
s
.30629 .60901 m
.30708 .60266 L
s
.30148 .59758 m .32889 .58854 L .30708 .60266 L .647 .745 .92 r
F
0 g
.30629 .60901 m
.30708 .60266 L
s
.29279 .60036 m
.30708 .60266 L
s
.24715 .70399 m
.23986 .70709 L
s
.16922 .48168 m
.17305 .48036 L
s
.16922 .48168 m
.16158 .48378 L
s
.27733 .52152 m
.28172 .52607 L
s
.28103 .59723 m
.29279 .60036 L
s
.16541 .48246 m
.17305 .48036 L
s
.16651 .59298 m .18526 .58684 L .1963 .5968 L .647 .745 .92 r
F
0 0 0 r
2 Mabswid
.1963 .5968 Mdot
0 g
.5 Mabswid
.1963 .5968 m
.19821 .58053 L
s
.1963 .5968 m
.20779 .60649 L
s
.039 .916 .04 r
.12977 .60775 m
.1683 .59478 L
s
.17722 .603 m
.1963 .5968 L
s
.19789 .59628 m .24848 .58805 L .19746 .6091 L .528 .308 .524 r
F
.19789 .59628 m .24869 .57975 L .255 .58474 L .647 .745 .92 r
F
.19789 .59628 m .24869 .57975 L .24848 .58805 L .528 .308 .524 r
F
.18969 .58805 m .24869 .57975 L .19789 .59628 L .647 .745 .92 r
F
0 0 0 r
2 Mabswid
.19789 .59628 Mdot
.039 .916 .04 r
.5 Mabswid
.1963 .5968 m
.19789 .59628 L
s
0 g
.19948 .58667 m
.20009 .58295 L
s
.039 .916 .04 r
.23289 .61699 m
.27674 .59576 L
s
0 0 0 r
2 Mabswid
.1683 .59478 Mdot
0 g
.5 Mabswid
.30629 .60901 m
.30494 .61475 L
s
.30494 .61475 m
.30629 .60901 L
s
.17616 .61907 m .19411 .62917 L .17644 .63482 L .528 .308 .524 r
F
.17616 .61907 m .19493 .61301 L .19411 .62917 L F
0 g
.17616 .61907 m
.17722 .603 L
s
.19493 .61301 m
.1963 .5968 L
s
.27285 .51782 m
.27733 .52152 L
s
.27733 .52152 m .29673 .53019 L .27664 .52982 L .528 .308 .524 r
F
0 g
.26796 .5327 m
.27733 .52152 L
s
.27733 .52152 m .30417 .521 L .29673 .53019 L .528 .308 .524 r
F
0 g
.30083 .52513 m
.30779 .52478 L
s
.27285 .51782 m
.27733 .52152 L
s
.27103 .59351 m
.28103 .59723 L
s
.30148 .59758 m .31735 .5865 L .32889 .58854 L .647 .745 .92 r
F
0 g
.32164 .58726 m
.32904 .58286 L
s
.29586 .59247 m .31735 .5865 L .30148 .59758 L .647 .745 .92 r
F
0 g
.30148 .59758 m
.30708 .60266 L
s
.30629 .60901 m
.32826 .59381 L
s
.27186 .67237 m
.27707 .66847 L
s
.27707 .66847 m
.29774 .62738 L
s
.15705 .58243 m .18526 .58684 L .16651 .59298 L .647 .745 .92 r
F
.039 .916 .04 r
.1683 .59478 m
.1874 .58883 L
s
0 g
.16651 .59298 m
.17722 .603 L
s
.039 .916 .04 r
.12036 .60004 m
.1602 .58617 L
s
0 g
.26114 .54305 m
.26796 .5327 L
s
.21835 .4912 m
.25964 .51231 L
s
.21835 .4912 m
.2119 .49136 L
s
.32667 .56424 m
.32499 .55785 L
s
.32499 .55785 m
.32672 .55729 L
s
.32499 .55785 m
.32291 .55155 L
s
.32291 .55155 m
.32464 .55099 L
s
.32291 .55155 m
.32045 .54544 L
s
.25608 .55282 m
.26114 .54305 L
s
.30494 .61475 m
.30304 .61978 L
s
.30305 .61978 m
.30494 .61475 L
s
.30494 .61475 m
.32717 .59856 L
s
.32792 .57061 m
.32667 .56424 L
s
.32667 .56424 m
.3284 .56368 L
s
.32672 .55729 m
.3284 .56368 L
s
.32464 .55099 m
.32672 .55729 L
s
.32045 .54544 m
.32218 .54487 L
s
.32045 .54544 m
.31766 .53961 L
s
.32218 .54487 m
.32464 .55099 L
s
.26242 .58933 m
.27103 .59351 L
s
.3284 .56368 m
.32965 .57005 L
s
.26836 .51501 m
.27285 .51782 L
s
.27285 .51782 m
.30048 .51792 L
s
.27285 .51782 m
.26836 .51501 L
s
.31939 .53904 m
.32218 .54487 L
s
.27664 .52982 m .29126 .53873 L .27594 .53815 L .528 .308 .524 r
F
.27664 .52982 m .29673 .53019 L .29126 .53873 L F
0 g
.29235 .53702 m
.31459 .53417 L
s
.29656 .53046 m
.31128 .5292 L
s
.27664 .52982 m
.27733 .52152 L
s
.22803 .70945 m
.23598 .70827 L
s
.23598 .70827 m
.23986 .70709 L
s
.32871 .57685 m
.32792 .57061 L
s
.32792 .57061 m
.32965 .57005 L
s
.33845 .55362 m .3393 .55344 L .34113 .56036 L .943 .684 .516 r
F
.33627 .54701 m .3393 .55344 L .33845 .55362 L F
.33627 .54701 m .33704 .54662 L .3393 .55344 L F
.3337 .5406 m .33704 .54662 L .33627 .54701 L F
.3337 .5406 m .33439 .53999 L .33704 .54662 L F
0 g
.33704 .54662 m
.3393 .55344 L
s
.31766 .53961 m
.31939 .53904 L
s
.31766 .53961 m
.31459 .53417 L
s
.32965 .57005 m
.33045 .57629 L
s
.34022 .56031 m .34113 .56036 L .34248 .56726 L .943 .684 .516 r
F
.33845 .55362 m .34113 .56036 L .34022 .56031 L F
0 g
.3393 .55344 m
.34113 .56036 L
s
.33078 .53449 m .33439 .53999 L .3337 .5406 L .943 .684 .516 r
F
.33078 .53449 m .33137 .53367 L .33439 .53999 L F
0 g
.33439 .53999 m
.33704 .54662 L
s
.31632 .5336 m
.31939 .53904 L
s
.19746 .6091 m .24942 .59601 L .19889 .62141 L .528 .308 .524 r
F
.19746 .6091 m .24848 .58805 L .24942 .59601 L F
0 g
.19746 .6091 m
.19789 .59628 L
s
.039 .916 .04 r
.22385 .60887 m
.26582 .59111 L
s
.29021 .58734 m .30778 .58383 L .29586 .59247 L .647 .745 .92 r
F
.039 .916 .04 r
.27674 .59576 m
.29349 .59031 L
s
.29586 .59247 m .30778 .58383 L .31735 .5865 L .647 .745 .92 r
F
0 g
.31303 .58529 m
.32871 .57685 L
s
.29586 .59247 m
.30148 .59758 L
s
.3376 .55379 m .33845 .55362 L .34022 .56031 L .943 .684 .516 r
F
.33549 .54741 m .33845 .55362 L .3376 .55379 L F
.33549 .54741 m .33627 .54701 L .33845 .55362 L F
.33301 .54122 m .33627 .54701 L .33549 .54741 L F
.33301 .54122 m .3337 .5406 L .33627 .54701 L F
0 g
.23986 .70709 m
.23192 .70827 L
s
.039 .916 .04 r
.1874 .58883 m
.18972 .58809 L
s
0 0 0 r
2 Mabswid
.1874 .58883 Mdot
0 g
.5 Mabswid
.25243 .56216 m
.25608 .55282 L
s
.32904 .58286 m
.32871 .57685 L
s
.32871 .57685 m
.33045 .57629 L
s
0 0 0 r
2 Mabswid
.26582 .59111 Mdot
0 g
.5 Mabswid
.16158 .48378 m
.16541 .48246 L
s
.16158 .48378 m
.15457 .48782 L
s
.34153 .56698 m .34248 .56726 L .34336 .57402 L .943 .684 .516 r
F
.34022 .56031 m .34248 .56726 L .34153 .56698 L F
0 g
.34113 .56036 m
.34248 .56726 L
s
.33931 .56025 m .34022 .56031 L .34153 .56698 L .943 .684 .516 r
F
.3376 .55379 m .34022 .56031 L .33931 .56025 L F
0 g
.31459 .53417 m
.31632 .5336 L
s
.31459 .53417 m
.31128 .5292 L
s
.47108 .5286 m
.4674 .51489 L
s
.4674 .51489 m
.47286 .51312 L
s
.4674 .51489 m
.46292 .50134 L
s
.33019 .53532 m .3337 .5406 L .33301 .54122 L .943 .684 .516 r
F
.33019 .53532 m .33078 .53449 L .3337 .5406 L F
0 g
.46292 .50134 m
.46838 .49956 L
s
.46292 .50134 m
.45772 .48816 L
s
.32757 .52878 m .33137 .53367 L .33078 .53449 L .943 .684 .516 r
F
.32757 .52878 m .32805 .52777 L .33137 .53367 L F
0 g
.33137 .53367 m
.33439 .53999 L
s
.33045 .57629 m
.33077 .5823 L
s
0 0 0 r
2 Mabswid
.18972 .58809 Mdot
.18969 .58805 m .24346 .57438 L .24869 .57975 L .647 .745 .92 r
F
.039 .916 .04 r
.5 Mabswid
.24856 .58868 m
.25647 .58574 L
s
.18328 .57915 m .24346 .57438 L .18969 .58805 L .647 .745 .92 r
F
0 g
.18969 .58805 m
.19789 .59628 L
s
.33675 .55396 m .3376 .55379 L .33931 .56025 L .943 .684 .516 r
F
.33471 .54781 m .3376 .55379 L .33675 .55396 L F
.33471 .54781 m .33549 .54741 L .3376 .55379 L F
.33232 .54183 m .33549 .54741 L .33471 .54781 L F
.33232 .54183 m .33301 .54122 L .33549 .54741 L F
0 g
.31301 .52863 m
.31632 .5336 L
s
.34153 .56698 m .34336 .57402 L .34237 .57351 L .943 .684 .516 r
F
.34057 .56669 m .34153 .56698 L .34237 .57351 L F
.33931 .56025 m .34153 .56698 L .34057 .56669 L F
.3384 .5602 m .33931 .56025 L .34057 .56669 L F
.33675 .55396 m .33931 .56025 L .3384 .5602 L F
0 g
.47391 .54226 m
.47108 .5286 L
s
.47108 .5286 m
.47655 .52684 L
s
.15842 .48648 m
.16541 .48246 L
s
.3296 .53614 m .33301 .54122 L .33232 .54183 L .943 .684 .516 r
F
.3296 .53614 m .33019 .53532 L .33301 .54122 L F
.32709 .5298 m .33078 .53449 L .33019 .53532 L F
.32709 .5298 m .32757 .52878 L .33078 .53449 L F
0 0 0 r
2 Mabswid
.1602 .58617 Mdot
0 g
.5 Mabswid
.255 .58474 m
.26242 .58933 L
s
.15705 .58243 m .17468 .57662 L .18526 .58684 L .647 .745 .92 r
F
0 g
.18526 .58684 m
.1963 .5968 L
s
.30304 .61978 m
.30063 .62402 L
s
.30063 .62402 m
.30305 .61978 L
s
.30305 .61978 m
.32563 .60272 L
s
.45772 .48816 m
.46318 .48637 L
s
.45772 .48816 m
.45188 .47556 L
s
.41774 .52968 m
.4206 .54042 L
s
.38701 .53846 m
.41774 .52968 L
s
.41423 .51907 m
.41774 .52968 L
s
.38437 .53048 m
.41423 .51907 L
s
.41014 .50876 m
.41423 .51907 L
s
.34237 .57351 m .34336 .57402 L .34372 .58053 L .943 .684 .516 r
F
0 g
.34248 .56726 m
.34336 .57402 L
s
.3359 .55413 m .33675 .55396 L .3384 .5602 L .943 .684 .516 r
F
.33394 .5482 m .33675 .55396 L .3359 .55413 L F
.33394 .5482 m .33471 .54781 L .33675 .55396 L F
0 g
.32904 .58286 m
.33077 .5823 L
s
.33163 .54245 m .33471 .54781 L .33394 .5482 L .943 .684 .516 r
F
.33163 .54245 m .33232 .54183 L .33471 .54781 L F
0 g
.47286 .51312 m
.47655 .52684 L
s
.46838 .49956 m
.47286 .51312 L
s
.32411 .52357 m .32805 .52777 L .32757 .52878 L .943 .684 .516 r
F
.32411 .52357 m .32448 .52237 L .32805 .52777 L F
0 g
.32805 .52777 m
.33137 .53367 L
s
.46318 .48637 m
.46838 .49956 L
s
.34057 .56669 m .34237 .57351 L .34139 .57301 L .943 .684 .516 r
F
.33962 .56641 m .34057 .56669 L .34139 .57301 L F
.3384 .5602 m .34057 .56669 L .33962 .56641 L F
.27594 .53815 m .28719 .54683 L .27523 .54652 L .528 .308 .524 r
F
.27594 .53815 m .29126 .53873 L .28719 .54683 L F
0 g
.27594 .53815 m
.27664 .52982 L
s
.31128 .5292 m
.31301 .52863 L
s
.31128 .5292 m
.30779 .52478 L
s
.17644 .63482 m .19384 .64527 L .1781 .65027 L .528 .308 .524 r
F
.17644 .63482 m .19411 .62917 L .19384 .64527 L F
0 g
.17616 .61907 m
.17644 .63482 L
s
.19411 .62917 m
.19493 .61301 L
s
.26393 .51316 m
.26836 .51501 L
s
.26836 .51501 m
.2968 .51559 L
s
.26836 .51501 m
.26393 .51316 L
s
.33748 .56014 m .3384 .5602 L .33962 .56641 L .943 .684 .516 r
F
.3359 .55413 m .3384 .5602 L .33748 .56014 L F
.32901 .53696 m .33232 .54183 L .33163 .54245 L F
.32901 .53696 m .3296 .53614 L .33232 .54183 L F
.32661 .53082 m .33019 .53532 L .3296 .53614 L F
.32661 .53082 m .32709 .5298 L .33019 .53532 L F
0 g
.29441 .62982 m
.27186 .67237 L
s
.26605 .67477 m
.27186 .67237 L
s
.4206 .54042 m
.42278 .55112 L
s
.38915 .54654 m
.4206 .54042 L
s
.38128 .52273 m
.41014 .50876 L
s
.40552 .49891 m
.41014 .50876 L
s
.34237 .57351 m .34372 .58053 L .34272 .57981 L .943 .684 .516 r
F
.34139 .57301 m .34237 .57351 L .34272 .57981 L F
0 g
.30952 .52421 m
.31301 .52863 L
s
.25 .57113 m
.25243 .56216 L
s
.33505 .55431 m .3359 .55413 L .33748 .56014 L .943 .684 .516 r
F
.33316 .5486 m .3359 .55413 L .33505 .55431 L F
.33316 .5486 m .33394 .5482 L .3359 .55413 L F
.33094 .54306 m .33394 .5482 L .33316 .5486 L F
.33094 .54306 m .33163 .54245 L .33394 .5482 L F
.32375 .52476 m .32757 .52878 L .32709 .5298 L F
.32375 .52476 m .32411 .52357 L .32757 .52878 L F
0 g
.47655 .52684 m
.47939 .5405 L
s
.33962 .56641 m .34139 .57301 L .3404 .5725 L .943 .684 .516 r
F
.33866 .56613 m .33962 .56641 L .3404 .5725 L F
.33748 .56014 m .33962 .56641 L .33866 .56613 L F
0 g
.45734 .47375 m
.46318 .48637 L
s
.33657 .56009 m .33748 .56014 L .33866 .56613 L .943 .684 .516 r
F
.33505 .55431 m .33748 .56014 L .33657 .56009 L F
0 g
.47585 .55565 m
.47391 .54226 L
s
.47391 .54226 m
.47939 .5405 L
s
.32613 .53184 m .3296 .53614 L .32901 .53696 L .943 .684 .516 r
F
.32613 .53184 m .32661 .53082 L .3296 .53614 L F
.32842 .53779 m .33163 .54245 L .33094 .54306 L F
.32842 .53779 m .32901 .53696 L .33163 .54245 L F
.34139 .57301 m .34272 .57981 L .34173 .57909 L F
.3404 .5725 m .34139 .57301 L .34173 .57909 L F
0 g
.2119 .49136 m
.25555 .51246 L
s
.2119 .49136 m
.20587 .49309 L
s
.35038 .55682 m
.34864 .55025 L
s
.34864 .55025 m
.35778 .54728 L
s
.34864 .55025 m
.3465 .54376 L
s
.3465 .54376 m
.35563 .54078 L
s
.3465 .54376 m
.34397 .53746 L
s
.34272 .57981 m .34372 .58053 L .34358 .58669 L .943 .684 .516 r
F
0 g
.34336 .57402 m
.34372 .58053 L
s
.45188 .47556 m
.45734 .47375 L
s
.45188 .47556 m
.44548 .46373 L
s
.32339 .52596 m .32709 .5298 L .32661 .53082 L .943 .684 .516 r
F
.32339 .52596 m .32375 .52476 L .32709 .5298 L F
.33419 .55448 m .33505 .55431 L .33657 .56009 L F
.33238 .549 m .33505 .55431 L .33419 .55448 L F
.33238 .549 m .33316 .5486 L .33505 .55431 L F
.33025 .54368 m .33316 .5486 L .33238 .549 L F
.33025 .54368 m .33094 .54306 L .33316 .5486 L F
0 g
.42278 .55112 m
.42423 .56161 L
s
.39077 .55459 m
.42278 .55112 L
s
.29021 .58734 m .2996 .58068 L .30778 .58383 L .647 .745 .92 r
F
.28454 .58218 m .2996 .58068 L .29021 .58734 L F
0 g
.29021 .58734 m
.29586 .59247 L
s
.039 .916 .04 r
.26582 .59111 m
.28682 .58425 L
s
.31735 .5865 m .33062 .58799 L .32889 .58854 L .647 .745 .92 r
F
0 g
.32826 .59381 m
.32889 .58854 L
s
.32891 .5878 m
.32904 .58286 L
s
.30708 .60266 m
.32889 .58854 L
s
.32047 .51894 m .32448 .52237 L .32411 .52357 L .943 .684 .516 r
F
.32047 .51894 m .32071 .51758 L .32448 .52237 L F
0 g
.32448 .52237 m
.32805 .52777 L
s
.35167 .56337 m
.35038 .55682 L
s
.35038 .55682 m
.35952 .55386 L
s
.33866 .56613 m .3404 .5725 L .33941 .572 L .943 .684 .516 r
F
.3377 .56585 m .33866 .56613 L .33941 .572 L F
.33657 .56009 m .33866 .56613 L .3377 .56585 L F
0 g
.34397 .53746 m
.3531 .53447 L
s
.34397 .53746 m
.34111 .53145 L
s
.33566 .56003 m .33657 .56009 L .3377 .56585 L .943 .684 .516 r
F
.33419 .55448 m .33657 .56009 L .33566 .56003 L F
0 g
.37779 .51533 m
.40552 .49891 L
s
.40045 .48969 m
.40552 .49891 L
s
.32564 .53286 m .32901 .53696 L .32842 .53779 L .943 .684 .516 r
F
.32564 .53286 m .32613 .53184 L .32901 .53696 L F
.32783 .53861 m .33094 .54306 L .33025 .54368 L F
.32783 .53861 m .32842 .53779 L .33094 .54306 L F
0 g
.30779 .52478 m
.30952 .52421 L
s
.3404 .5725 m .34173 .57909 L .34073 .57837 L .943 .684 .516 r
F
.33941 .572 m .3404 .5725 L .34073 .57837 L F
0 0 0 r
2 Mabswid
.25647 .58574 Mdot
.34272 .57981 m .34358 .58669 L .34258 .58577 L .943 .684 .516 r
F
.34173 .57909 m .34272 .57981 L .34258 .58577 L F
.31735 .5865 m .32601 .58373 L .33062 .58799 L .647 .745 .92 r
F
0 g
.5 Mabswid
.33 .59325 m
.33062 .58799 L
s
.33062 .58799 m
.33077 .5823 L
s
.32889 .58854 m
.33062 .58799 L
s
.14888 .57132 m .17468 .57662 L .15705 .58243 L .647 .745 .92 r
F
0 g
.15705 .58243 m
.16651 .59298 L
s
.039 .916 .04 r
.1602 .58617 m
.17876 .58064 L
s
.11076 .59233 m
.15294 .57714 L
s
.32302 .52716 m .32661 .53082 L .32613 .53184 L .943 .684 .516 r
F
.32302 .52716 m .32339 .52596 L .32661 .53082 L F
0 g
.33238 .549 m
.33419 .55448 L
s
.32023 .52029 m .32411 .52357 L .32375 .52476 L .943 .684 .516 r
F
.32023 .52029 m .32047 .51894 L .32411 .52357 L F
0 g
.33025 .54368 m
.33238 .549 L
s
.47939 .5405 m
.48133 .5539 L
s
.35251 .56979 m
.35167 .56337 L
s
.35167 .56337 m
.36082 .56042 L
s
.3377 .56585 m .33941 .572 L .33843 .57149 L .943 .684 .516 r
F
.33674 .56557 m .3377 .56585 L .33843 .57149 L F
.33566 .56003 m .3377 .56585 L .33674 .56557 L F
0 g
.33419 .55448 m
.33566 .56003 L
s
.34111 .53145 m
.35024 .52846 L
s
.34111 .53145 m
.33797 .52584 L
s
.32516 .53388 m .32842 .53779 L .32783 .53861 L .943 .684 .516 r
F
.32516 .53388 m .32564 .53286 L .32842 .53779 L F
0 g
.24869 .57975 m
.255 .58474 L
s
.45094 .46191 m
.45734 .47375 L
s
.32783 .53861 m
.33025 .54368 L
s
.34173 .57909 m .34258 .58577 L .34159 .58484 L .943 .684 .516 r
F
.34073 .57837 m .34173 .57909 L .34159 .58484 L F
.33941 .572 m .34073 .57837 L .33973 .57765 L F
.33843 .57149 m .33941 .572 L .33973 .57765 L F
.30778 .58383 m .32601 .58373 L .31735 .5865 L .647 .745 .92 r
F
0 g
.31735 .5865 m
.32889 .58854 L
s
.039 .916 .04 r
.29349 .59031 m
.31069 .58474 L
s
0 g
.30063 .62402 m
.29774 .62738 L
s
.29774 .62738 m
.30063 .62402 L
s
.30063 .62402 m
.32367 .60621 L
s
.32266 .52836 m .32613 .53184 L .32564 .53286 L .943 .684 .516 r
F
.32266 .52836 m .32302 .52716 L .32613 .53184 L F
.31999 .52165 m .32375 .52476 L .32339 .52596 L F
.31999 .52165 m .32023 .52029 L .32375 .52476 L F
.27523 .54652 m .28426 .55456 L .27453 .55491 L .528 .308 .524 r
F
.27523 .54652 m .28719 .54683 L .28426 .55456 L F
0 g
.27523 .54652 m
.27594 .53815 L
s
.24869 .57975 m
.25 .57113 L
s
.33674 .56557 m .33843 .57149 L .33744 .57099 L .943 .684 .516 r
F
0 g
.33566 .56003 m
.33674 .56557 L
s
.34258 .58577 m .34358 .58669 L .34292 .59239 L .943 .684 .516 r
F
0 g
.34358 .58669 m
.34372 .58053 L
s
.47685 .56856 m
.47585 .55565 L
s
.47585 .55565 m
.48133 .5539 L
s
.42423 .56161 m
.42493 .57173 L
s
.39183 .56248 m
.42423 .56161 L
s
.34073 .57837 m .34159 .58484 L .3406 .58392 L .943 .684 .516 r
F
.33973 .57765 m .34073 .57837 L .3406 .58392 L F
.19889 .62141 m .2516 .60361 L .20237 .63315 L .528 .308 .524 r
F
.19889 .62141 m .24942 .59601 L .2516 .60361 L F
0 g
.19746 .6091 m
.19889 .62141 L
s
.039 .916 .04 r
.19789 .59628 m
.24869 .57975 L
s
.33843 .57149 m .33973 .57765 L .33873 .57693 L .943 .684 .516 r
F
.33744 .57099 m .33843 .57149 L .33873 .57693 L F
0 g
.25964 .51231 m
.26393 .51316 L
s
.26393 .51316 m
.29317 .51405 L
s
.26393 .51316 m
.25964 .51231 L
s
.35952 .55386 m
.35778 .54728 L
s
.35778 .54728 m
.38265 .53974 L
s
.35778 .54728 m
.35563 .54078 L
s
.35286 .57598 m
.35251 .56979 L
s
.35251 .56979 m
.36166 .56685 L
s
.35563 .54078 m
.38011 .53205 L
s
.35563 .54078 m
.3531 .53447 L
s
.31669 .51496 m .32071 .51758 L .32047 .51894 L .943 .684 .516 r
F
.31669 .51496 m .31681 .51347 L .32071 .51758 L F
0 g
.32071 .51758 m
.32448 .52237 L
s
.32229 .52956 m .32564 .53286 L .32516 .53388 L .943 .684 .516 r
F
0 g
.32516 .53388 m
.32783 .53861 L
s
.32229 .52956 m .32266 .52836 L .32564 .53286 L .943 .684 .516 r
F
.31975 .52301 m .32339 .52596 L .32302 .52716 L F
.31975 .52301 m .31999 .52165 L .32339 .52596 L F
0 g
.32717 .59856 m
.32826 .59381 L
s
.32826 .59381 m
.33 .59325 L
s
.33797 .52584 m
.3471 .52283 L
s
.33797 .52584 m
.33458 .52071 L
s
.37395 .50841 m
.40045 .48969 L
s
.39501 .48123 m
.40045 .48969 L
s
.039 .916 .04 r
.17876 .58064 m
.18334 .57924 L
s
0 0 0 r
2 Mabswid
.17876 .58064 Mdot
0 g
.5 Mabswid
.44548 .46373 m
.45094 .46191 L
s
.44548 .46373 m
.43862 .45287 L
s
.36082 .56042 m
.35952 .55386 L
s
.35952 .55386 m
.38472 .54752 L
s
.34258 .58577 m .34292 .59239 L .34195 .59128 L .943 .684 .516 r
F
.34159 .58484 m .34258 .58577 L .34195 .59128 L F
0 0 0 r
2 Mabswid
.31069 .58474 Mdot
0 g
.5 Mabswid
.3531 .53447 m
.37714 .52459 L
s
.3531 .53447 m
.35024 .52846 L
s
.38915 .54654 m
.38701 .53846 L
s
.38701 .53846 m
.38437 .53048 L
s
.33973 .57765 m .3406 .58392 L .3396 .583 L .943 .684 .516 r
F
.33873 .57693 m .33973 .57765 L .3396 .583 L F
0 g
.38437 .53048 m
.38128 .52273 L
s
.30417 .521 m .30537 .52733 L .29673 .53019 L .528 .308 .524 r
F
.30417 .521 m .3059 .52043 L .30537 .52733 L F
0 g
.27733 .52152 m
.30417 .521 L
s
.30573 .52263 m
.30779 .52478 L
s
.30417 .521 m
.3059 .52043 L
s
.3059 .52043 m
.30952 .52421 L
s
.30048 .51792 m
.30417 .521 L
s
.33 .59325 m
.32891 .598 L
s
.21957 .70866 m
.22803 .70945 L
s
.22803 .70945 m
.23192 .70827 L
s
.33744 .57099 m .33873 .57693 L .33773 .57621 L .943 .684 .516 r
F
0 g
.33674 .56557 m
.33744 .57099 L
s
.31658 .51646 m .32047 .51894 L .32023 .52029 L .943 .684 .516 r
F
.31658 .51646 m .31669 .51496 L .32047 .51894 L F
0 g
.38265 .53974 m
.38472 .54752 L
s
.38011 .53205 m
.38265 .53974 L
s
.31951 .52436 m .32302 .52716 L .32266 .52836 L .943 .684 .516 r
F
.31951 .52436 m .31975 .52301 L .32302 .52716 L F
0 g
.37714 .52459 m
.38011 .53205 L
s
.30778 .58383 m .32138 .57945 L .32601 .58373 L .647 .745 .92 r
F
0 g
.32601 .58373 m
.33062 .58799 L
s
.2996 .58068 m .32138 .57945 L .30778 .58383 L .647 .745 .92 r
F
0 g
.30778 .58383 m
.31735 .5865 L
s
.039 .916 .04 r
.31069 .58474 m
.3228 .58076 L
s
0 g
.39077 .55459 m
.38915 .54654 L
s
.34159 .58484 m .34195 .59128 L .34098 .59017 L .943 .684 .516 r
F
.3406 .58392 m .34159 .58484 L .34098 .59017 L F
0 g
.30222 .51734 m
.3059 .52043 L
s
.38128 .52273 m
.37779 .51533 L
s
.36166 .56685 m
.36082 .56042 L
s
.36082 .56042 m
.38627 .55527 L
s
.48133 .5539 m
.48235 .56683 L
s
.38472 .54752 m
.38627 .55527 L
s
.33873 .57693 m .3396 .583 L .3386 .58207 L .943 .684 .516 r
F
.33773 .57621 m .33873 .57693 L .3386 .58207 L F
0 g
.35024 .52846 m
.37377 .51747 L
s
.35024 .52846 m
.3471 .52283 L
s
.31647 .51795 m .32023 .52029 L .31999 .52165 L .943 .684 .516 r
F
.31647 .51795 m .31658 .51646 L .32023 .52029 L F
.29673 .53019 m .30483 .53426 L .29126 .53873 L .528 .308 .524 r
F
.29673 .53019 m .30537 .52733 L .30483 .53426 L F
0 g
.29673 .53019 m
.30417 .521 L
s
.30537 .52733 m
.3059 .52043 L
s
.37377 .51747 m
.37714 .52459 L
s
0 0 0 r
2 Mabswid
.18334 .57924 Mdot
.18328 .57915 m .23934 .56862 L .24346 .57438 L .647 .745 .92 r
F
.17886 .56951 m .23934 .56862 L .18328 .57915 L F
.039 .916 .04 r
.5 Mabswid
.18972 .58809 m
.24249 .5732 L
s
0 g
.18328 .57915 m
.18969 .58805 L
s
.31927 .52572 m .32266 .52836 L .32229 .52956 L .943 .684 .516 r
F
0 g
.32229 .52956 m
.32516 .53388 L
s
.31927 .52572 m .31951 .52436 L .32266 .52836 L .943 .684 .516 r
F
0 g
.35286 .57598 m
.36203 .57304 L
s
.28454 .58218 m .29255 .57717 L .2996 .58068 L .647 .745 .92 r
F
.27884 .57701 m .29255 .57717 L .28454 .58218 L F
0 g
.28454 .58218 m
.29021 .58734 L
s
.039 .916 .04 r
.25647 .58574 m
.28001 .57807 L
s
.3406 .58392 m .34098 .59017 L .34 .58905 L .943 .684 .516 r
F
.3396 .583 m .3406 .58392 L .34 .58905 L F
0 g
.23192 .70827 m
.22347 .70747 L
s
.44409 .45103 m
.45094 .46191 L
s
.33458 .52071 m
.34372 .5177 L
s
.33458 .52071 m
.33101 .51616 L
s
.15457 .48782 m
.15842 .48648 L
s
.15457 .48782 m
.14833 .49373 L
s
.39183 .56248 m
.39077 .55459 L
s
.33773 .57621 m .3386 .58207 L .33761 .58114 L .943 .684 .516 r
F
0 g
.33744 .57099 m
.33773 .57621 L
s
.31636 .51945 m .31999 .52165 L .31975 .52301 L .943 .684 .516 r
F
.31636 .51945 m .31647 .51795 L .31999 .52165 L F
.34195 .59128 m .34292 .59239 L .34176 .59754 L F
0 g
.34292 .59239 m
.34358 .58669 L
s
.37779 .51533 m
.37395 .50841 L
s
.38627 .55527 m
.38729 .56287 L
s
0 0 0 r
2 Mabswid
.15294 .57714 Mdot
.3396 .583 m .34 .58905 L .33903 .58794 L .943 .684 .516 r
F
.3386 .58207 m .3396 .583 L .33903 .58794 L F
0 g
.5 Mabswid
.36203 .57304 m
.36166 .56685 L
s
.36166 .56685 m
.38729 .56287 L
s
.37007 .51081 m
.37377 .51747 L
s
.39232 .57008 m
.42493 .57173 L
s
.25974 .6756 m
.26605 .67477 L
s
.26605 .67477 m
.2907 .63127 L
s
.31285 .51172 m .31681 .51347 L .31669 .51496 L .943 .684 .516 r
F
.31285 .51172 m .31283 .51011 L .31681 .51347 L F
0 g
.31681 .51347 m
.32071 .51758 L
s
.24346 .57438 m
.24869 .57975 L
s
0 0 0 r
2 Mabswid
.24869 .57975 Mdot
0 g
.5 Mabswid
.24848 .58805 m
.24869 .57975 L
s
.3471 .52283 m
.37007 .51081 L
s
.3471 .52283 m
.34372 .5177 L
s
.32563 .60272 m
.32717 .59856 L
s
.32717 .59856 m
.32891 .598 L
s
.34195 .59128 m .34176 .59754 L .34083 .59626 L .943 .684 .516 r
F
.34098 .59017 m .34195 .59128 L .34083 .59626 L F
.31625 .52094 m .31975 .52301 L .31951 .52436 L F
.31625 .52094 m .31636 .51945 L .31975 .52301 L F
.27453 .55491 m .28231 .562 L .27382 .56334 L .528 .308 .524 r
F
.27453 .55491 m .28426 .55456 L .28231 .562 L F
0 g
.27453 .55491 m
.27523 .54652 L
s
.29126 .53873 m .30429 .54121 L .28719 .54683 L .528 .308 .524 r
F
.29126 .53873 m .30483 .53426 L .30429 .54121 L F
0 g
.29126 .53873 m
.29673 .53019 L
s
.15219 .4924 m
.15842 .48648 L
s
.36983 .50208 m
.39501 .48123 L
s
.38929 .47369 m
.39501 .48123 L
s
.3386 .58207 m .33903 .58794 L .33805 .58683 L .943 .684 .516 r
F
.33761 .58114 m .3386 .58207 L .33805 .58683 L F
0 g
.29774 .62738 m
.29441 .62982 L
s
.29441 .62981 m
.29774 .62738 L
s
.29774 .62738 m
.32131 .60897 L
s
.31287 .51333 m .31669 .51496 L .31658 .51646 L .943 .684 .516 r
F
.31287 .51333 m .31285 .51172 L .31669 .51496 L F
.2996 .58068 m .31673 .57516 L .32138 .57945 L .647 .745 .92 r
F
0 g
.32138 .57945 m
.32601 .58373 L
s
.29255 .57717 m .31673 .57516 L .2996 .58068 L .647 .745 .92 r
F
0 g
.2996 .58068 m
.30778 .58383 L
s
.039 .916 .04 r
.28682 .58425 m
.29884 .58035 L
s
0 g
.30048 .51792 m
.30222 .51734 L
s
.30048 .51792 m
.2968 .51559 L
s
.32891 .598 m
.32738 .60216 L
s
.47685 .56856 m
.48235 .56683 L
s
.14888 .57132 m .16457 .56611 L .17468 .57662 L .647 .745 .92 r
F
.039 .916 .04 r
.15294 .57714 m
.17035 .57221 L
s
0 g
.17468 .57662 m
.18526 .58684 L
s
.34098 .59017 m .34083 .59626 L .33989 .59497 L .943 .684 .516 r
F
.34 .58905 m .34098 .59017 L .33989 .59497 L F
.31614 .52244 m .31951 .52436 L .31927 .52572 L F
0 g
.31927 .52572 m
.32229 .52956 L
s
.31614 .52244 m .31625 .52094 L .31951 .52436 L .943 .684 .516 r
F
.1781 .65027 m .19415 .66133 L .18124 .66539 L .528 .308 .524 r
F
.1781 .65027 m .19384 .64527 L .19415 .66133 L F
0 g
.17644 .63482 m
.1781 .65027 L
s
.19384 .64527 m
.19411 .62917 L
s
.39232 .57008 m
.39183 .56248 L
s
.20587 .49309 m
.25175 .51363 L
s
.20587 .49309 m
.20036 .49639 L
s
.34803 .57743 m .36191 .5789 L .35274 .58183 L .647 .745 .92 r
F
0 g
.35213 .58724 m
.35274 .58183 L
s
.35282 .57794 m
.35286 .57598 L
s
.29853 .51501 m
.30222 .51734 L
s
.039 .916 .04 r
.3228 .58076 m
.33339 .57723 L
s
0 g
.38729 .56287 m
.38776 .57019 L
s
.25555 .51246 m
.25964 .51231 L
s
.25964 .51231 m
.28965 .51334 L
s
.25964 .51231 m
.25556 .51246 L
s
.30483 .53426 m
.30537 .52733 L
s
.31289 .51493 m .31658 .51646 L .31647 .51795 L .943 .684 .516 r
F
.31289 .51493 m .31287 .51333 L .31658 .51646 L F
.33761 .58114 m .33805 .58683 L .33707 .58571 L F
0 g
.33761 .58114 m
.33773 .57621 L
s
.37395 .50841 m
.36983 .50208 L
s
.43862 .45287 m
.44409 .45103 L
s
.43862 .45287 m
.43141 .44314 L
s
.34 .58905 m .33989 .59497 L .33895 .59369 L .943 .684 .516 r
F
.33903 .58794 m .34 .58905 L .33895 .59369 L F
0 g
.3661 .50471 m
.37007 .51081 L
s
.36203 .57304 m
.38776 .57019 L
s
.31291 .51654 m .31647 .51795 L .31636 .51945 L .943 .684 .516 r
F
.31291 .51654 m .31289 .51493 L .31647 .51795 L F
0 g
.34372 .5177 m
.3661 .50471 L
s
.34372 .5177 m
.34015 .51313 L
s
.33903 .58794 m .33895 .59369 L .33802 .5924 L .943 .684 .516 r
F
.33805 .58683 m .33903 .58794 L .33802 .5924 L F
.28719 .54683 m .30376 .54818 L .28426 .55456 L .528 .308 .524 r
F
.28719 .54683 m .30429 .54121 L .30376 .54818 L F
0 g
.28719 .54683 m
.29126 .53873 L
s
.34083 .59626 m .34176 .59754 L .34012 .60205 L .943 .684 .516 r
F
0 g
.34176 .59754 m
.34292 .59239 L
s
.31293 .51815 m .31636 .51945 L .31625 .52094 L .943 .684 .516 r
F
.31293 .51815 m .31291 .51654 L .31636 .51945 L F
.33805 .58683 m .33802 .5924 L .33708 .59111 L F
.33707 .58571 m .33805 .58683 L .33708 .59111 L F
0 g
.43688 .44129 m
.44409 .45103 L
s
.30901 .50926 m .31283 .51011 L .31285 .51172 L .943 .684 .516 r
F
.30901 .50926 m .30886 .50757 L .31283 .51011 L F
0 g
.31283 .51011 m
.31681 .51347 L
s
.34083 .59626 m .34012 .60205 L .33924 .60061 L .943 .684 .516 r
F
.33989 .59497 m .34083 .59626 L .33924 .60061 L F
.27311 .57181 m .28646 .57331 L .27884 .57701 L .647 .745 .92 r
F
.27884 .57701 m .28646 .57331 L .29255 .57717 L F
0 g
.27884 .57701 m
.28454 .58218 L
s
.31295 .51976 m .31625 .52094 L .31614 .52244 L .943 .684 .516 r
F
0 g
.31614 .52244 m
.31927 .52572 L
s
.31295 .51976 m .31293 .51815 L .31625 .52094 L .943 .684 .516 r
F
0 g
.32367 .60621 m
.32563 .60272 L
s
.32563 .60272 m
.32738 .60216 L
s
.29255 .57717 m .31206 .57085 L .31673 .57516 L .647 .745 .92 r
F
0 g
.31673 .57516 m
.32138 .57945 L
s
.28646 .57331 m .31206 .57085 L .29255 .57717 L .647 .745 .92 r
F
.039 .916 .04 r
.29884 .58035 m
.31618 .57466 L
s
0 g
.29255 .57717 m
.2996 .58068 L
s
.039 .916 .04 r
.28001 .57807 m
.28911 .5751 L
s
.33707 .58571 m .33708 .59111 L .33614 .58983 L .943 .684 .516 r
F
0 g
.33707 .58571 m
.33761 .58114 L
s
.39463 .56925 m .42487 .5813 L .39222 .57726 L .647 .745 .92 r
F
0 g
.39222 .57726 m
.39232 .57008 L
s
.39463 .56925 m .4307 .56985 L .42487 .5813 L .647 .745 .92 r
F
0 g
.39222 .57726 m
.42487 .5813 L
s
.42403 .59017 m
.42487 .5813 L
s
.30916 .51096 m .31285 .51172 L .31287 .51333 L .943 .684 .516 r
F
.30916 .51096 m .30901 .50926 L .31285 .51172 L F
.33989 .59497 m .33924 .60061 L .33835 .59918 L F
.33895 .59369 m .33989 .59497 L .33835 .59918 L F
0 g
.35104 .59212 m
.35213 .58724 L
s
.35213 .58724 m
.36131 .58431 L
s
.36983 .50208 m
.3655 .49645 L
s
.32738 .60216 m
.32541 .60565 L
s
.27382 .56334 m .28129 .56915 L .27311 .57181 L .528 .308 .524 r
F
.27382 .56334 m .28231 .562 L .28129 .56915 L F
0 g
.27382 .56334 m
.27453 .55491 L
s
.2968 .51559 m
.29853 .51501 L
s
.2968 .51559 m
.29317 .51405 L
s
.36192 .49929 m
.3661 .50471 L
s
.36062 .57339 m .38766 .57711 L .36191 .5789 L .647 .745 .92 r
F
0 g
.36202 .57359 m
.36203 .57304 L
s
.34803 .57743 m .36062 .57339 L .36191 .5789 L .647 .745 .92 r
F
0 g
.35274 .58183 m
.36191 .5789 L
s
.36131 .58431 m
.36191 .5789 L
s
.24848 .58805 m
.24942 .59601 L
s
.20237 .63315 m .25523 .61079 L .20828 .64422 L .528 .308 .524 r
F
.20237 .63315 m .2516 .60361 L .25523 .61079 L F
0 g
.19889 .62141 m
.20237 .63315 L
s
.32732 .51225 m .33937 .51519 L .3268 .51935 L .528 .308 .524 r
F
.32732 .51225 m .33647 .50921 L .33937 .51519 L F
0 g
.33862 .51364 m
.34015 .51313 L
s
.32356 .50906 m
.32732 .51225 L
s
.3655 .49645 m
.38929 .47369 L
s
.30931 .51265 m .31287 .51333 L .31289 .51493 L .943 .684 .516 r
F
.30931 .51265 m .30916 .51096 L .31287 .51333 L F
.33895 .59369 m .33835 .59918 L .33747 .59774 L F
.33802 .5924 m .33895 .59369 L .33747 .59774 L F
0 g
.34015 .51313 m
.36192 .49929 L
s
.30429 .54121 m
.30483 .53426 L
s
.039 .916 .04 r
.17035 .57221 m
.17891 .56968 L
s
0 0 0 r
2 Mabswid
.17035 .57221 Mdot
0 g
.5 Mabswid
.2949 .51347 m
.29853 .51501 L
s
.28426 .55456 m .30322 .55517 L .28231 .562 L .528 .308 .524 r
F
.28426 .55456 m .30376 .54818 L .30322 .55517 L F
0 g
.28426 .55456 m
.28719 .54683 L
s
.14208 .55962 m .16457 .56611 L .14888 .57132 L .647 .745 .92 r
F
0 g
.14888 .57132 m
.15705 .58243 L
s
.3433 .57301 m .36062 .57339 L .34803 .57743 L .647 .745 .92 r
F
.039 .916 .04 r
.33339 .57723 m
.34402 .57369 L
s
0 g
.34803 .57743 m
.35274 .58183 L
s
.30946 .51435 m .31289 .51493 L .31291 .51654 L .943 .684 .516 r
F
.30946 .51435 m .30931 .51265 L .31289 .51493 L F
.33802 .5924 m .33747 .59774 L .33658 .5963 L F
.33708 .59111 m .33802 .5924 L .33658 .5963 L F
0 g
.29441 .62982 m
.2907 .63127 L
s
.29071 .63126 m
.29441 .62981 L
s
.29441 .62981 m
.31859 .61096 L
s
.30961 .51604 m .31291 .51654 L .31293 .51815 L .943 .684 .516 r
F
.30961 .51604 m .30946 .51435 L .31291 .51654 L F
.46841 .57128 m .48241 .57907 L .47689 .5808 L .647 .745 .92 r
F
0 g
.47598 .59215 m
.47689 .5808 L
s
.47685 .56856 m
.47688 .57599 L
s
.33708 .59111 m .33658 .5963 L .3357 .59486 L .943 .684 .516 r
F
.33614 .58983 m .33708 .59111 L .3357 .59486 L F
0 0 0 r
2 Mabswid
.24249 .5732 Mdot
0 g
.5 Mabswid
.25175 .51363 m
.25555 .51246 L
s
.25556 .51246 m
.28632 .51347 L
s
.25556 .51246 m
.25175 .51363 L
s
.30977 .51774 m .31293 .51815 L .31295 .51976 L .943 .684 .516 r
F
0 g
.31295 .51976 m
.31614 .52244 L
s
.30977 .51774 m .30961 .51604 L .31293 .51815 L .943 .684 .516 r
F
.33924 .60061 m .34012 .60205 L .33802 .60583 L F
0 g
.34012 .60205 m
.34176 .59754 L
s
.33614 .58983 m .3357 .59486 L .33481 .59343 L .943 .684 .516 r
F
0 g
.33614 .58983 m
.33707 .58571 L
s
.21074 .70588 m
.21957 .70866 L
s
.21957 .70866 m
.22347 .70747 L
s
.39154 .58392 m
.39222 .57726 L
s
.36062 .57339 m .38215 .57189 L .38766 .57711 L .647 .745 .92 r
F
0 g
.38699 .58352 m
.38766 .57711 L
s
.36191 .5789 m
.38766 .57711 L
s
.38766 .57711 m
.38776 .57019 L
s
.039 .916 .04 r
.31618 .57466 m
.32682 .57113 L
s
0 0 0 r
2 Mabswid
.31618 .57466 Mdot
0 g
.5 Mabswid
.43141 .44314 m
.43688 .44129 L
s
.33924 .60061 m .33802 .60583 L .3372 .60427 L .943 .684 .516 r
F
.33835 .59918 m .33924 .60061 L .3372 .60427 L F
0 g
.36024 .5892 m
.36131 .58431 L
s
.36131 .58431 m
.38699 .58352 L
s
.28129 .56915 m .30738 .56653 L .28646 .57331 L .647 .745 .92 r
F
.28646 .57331 m .30738 .56653 L .31206 .57085 L F
0 g
.31206 .57085 m
.31673 .57516 L
s
.27311 .57181 m .28129 .56915 L .28646 .57331 L .647 .745 .92 r
F
0 g
.28646 .57331 m
.29255 .57717 L
s
.30522 .50764 m .30886 .50757 L .30901 .50926 L .943 .684 .516 r
F
.30522 .50764 m .30494 .50589 L .30886 .50757 L F
0 g
.30886 .50757 m
.31283 .51011 L
s
.32131 .60897 m
.32367 .60621 L
s
.32367 .60621 m
.32541 .60565 L
s
.3495 .59639 m
.35104 .59212 L
s
.35104 .59212 m
.36024 .5892 L
s
.25301 .67484 m
.25974 .6756 L
s
0 0 0 r
2 Mabswid
.17891 .56968 Mdot
.17886 .56951 m .23644 .56242 L .23934 .56862 L .647 .745 .92 r
F
0 g
.5 Mabswid
.23934 .56862 m
.24346 .57438 L
s
.1768 .55899 m .23644 .56242 L .17886 .56951 L .647 .745 .92 r
F
.039 .916 .04 r
.18334 .57924 m
.23799 .56612 L
s
0 g
.17886 .56951 m
.18328 .57915 L
s
.33835 .59918 m .3372 .60427 L .33639 .60271 L .943 .684 .516 r
F
.33747 .59774 m .33835 .59918 L .33639 .60271 L F
.33647 .50921 m .35704 .50301 L .33937 .51519 L .528 .308 .524 r
F
.33647 .50921 m .35759 .49463 L .35704 .50301 L F
0 g
.32732 .51225 m
.33647 .50921 L
s
.33647 .50921 m
.35759 .49463 L
s
.35759 .49463 m
.36192 .49929 L
s
.33272 .50601 m
.33647 .50921 L
s
.46841 .57128 m .47916 .56788 L .48241 .57907 L .647 .745 .92 r
F
0 g
.48151 .59043 m
.48241 .57907 L
s
.48235 .56683 m
.48241 .57907 L
s
.47689 .5808 m
.48241 .57907 L
s
.30551 .50939 m .30901 .50926 L .30916 .51096 L .943 .684 .516 r
F
.30551 .50939 m .30522 .50764 L .30901 .50926 L F
.28231 .562 m .30267 .56219 L .28129 .56915 L .528 .308 .524 r
F
.28231 .562 m .30322 .55517 L .30267 .56219 L F
0 g
.28231 .562 m
.28426 .55456 L
s
.32541 .60565 m
.32305 .60842 L
s
.29317 .51405 m
.2949 .51347 L
s
.29317 .51405 m
.28965 .51334 L
s
.32356 .50906 m
.33272 .50601 L
s
.32356 .50906 m
.3198 .50664 L
s
.22347 .70747 m
.21465 .70468 L
s
.3268 .51935 m .34157 .52143 L .32629 .52647 L .528 .308 .524 r
F
.3268 .51935 m .33937 .51519 L .34157 .52143 L F
0 g
.3268 .51935 m
.32732 .51225 L
s
.30376 .54818 m
.30429 .54121 L
s
.33747 .59774 m .33639 .60271 L .33557 .60114 L .943 .684 .516 r
F
.33658 .5963 m .33747 .59774 L .33557 .60114 L F
0 g
.14833 .49373 m
.15219 .4924 L
s
.14833 .49373 m
.14297 .50146 L
s
.30579 .51115 m .30916 .51096 L .30931 .51265 L .943 .684 .516 r
F
.30579 .51115 m .30551 .50939 L .30916 .51096 L F
.27311 .57181 m .28116 .57603 L .2724 .5803 L .528 .308 .524 r
F
.27311 .57181 m .28129 .56915 L .28116 .57603 L F
.26736 .56658 m .28129 .56915 L .27311 .57181 L .647 .745 .92 r
F
0 0 0 r
2 Mabswid
.27311 .57181 Mdot
.039 .916 .04 r
.5 Mabswid
.24869 .57975 m
.27311 .57181 L
s
0 g
.27346 .5677 m
.27382 .56334 L
s
.29139 .51276 m
.2949 .51347 L
s
.33658 .5963 m .33557 .60114 L .33475 .59958 L .943 .684 .516 r
F
.3357 .59486 m .33658 .5963 L .33475 .59958 L F
0 g
.42403 .59017 m
.42244 .5982 L
s
.39154 .58392 m
.42403 .59017 L
s
.20036 .49639 m
.2483 .51581 L
s
.20036 .49639 m
.19548 .5012 L
s
.30607 .5129 m .30931 .51265 L .30946 .51435 L .943 .684 .516 r
F
.30607 .5129 m .30579 .51115 L .30931 .51265 L F
0 g
.24942 .59601 m
.2516 .60361 L
s
.3357 .59486 m .33475 .59958 L .33394 .59801 L .943 .684 .516 r
F
.33481 .59343 m .3357 .59486 L .33394 .59801 L F
.30635 .51465 m .30946 .51435 L .30961 .51604 L F
.30635 .51465 m .30607 .5129 L .30946 .51435 L F
.3433 .57301 m .35861 .56809 L .36062 .57339 L .647 .745 .92 r
F
.33856 .56858 m .35861 .56809 L .3433 .57301 L F
0 g
.3433 .57301 m
.34803 .57743 L
s
.35861 .56809 m .38215 .57189 L .36062 .57339 L .647 .745 .92 r
F
0 g
.36062 .57339 m
.36191 .5789 L
s
.36101 .49161 m .38337 .46718 L .39596 .47426 L .528 .308 .524 r
F
0 g
.37735 .46182 m
.38337 .46718 L
s
.14685 .50013 m
.15219 .4924 L
s
.33481 .59343 m .33394 .59801 L .33312 .59644 L .943 .684 .516 r
F
0 g
.33481 .59343 m
.33614 .58983 L
s
.30663 .51641 m .30961 .51604 L .30977 .51774 L .943 .684 .516 r
F
0 g
.30977 .51774 m
.31295 .51976 L
s
.30663 .51641 m .30635 .51465 L .30961 .51604 L .943 .684 .516 r
F
0 g
.38699 .58352 m
.38577 .5893 L
s
.39028 .58992 m
.39154 .58392 L
s
.2907 .63127 m
.28668 .6317 L
s
.28668 .6317 m
.29071 .63126 L
s
.29071 .63126 m
.31556 .61212 L
s
.14208 .55962 m .15494 .55532 L .16457 .56611 L .647 .745 .92 r
F
0 g
.16457 .56611 m
.17468 .57662 L
s
.35871 .59347 m
.36024 .5892 L
s
.36024 .5892 m
.38577 .5893 L
s
.18124 .66539 m .19504 .67733 L .186 .68015 L .528 .308 .524 r
F
.18124 .66539 m .19415 .66133 L .19504 .67733 L F
0 g
.1781 .65027 m
.18124 .66539 L
s
.19384 .64527 m
.19415 .66133 L
s
.3372 .60427 m .33802 .60583 L .33549 .60883 L .943 .684 .516 r
F
0 g
.33802 .60583 m
.34012 .60205 L
s
.3532 .49082 m
.35759 .49463 L
s
.36101 .49161 m .39596 .47426 L .36854 .49761 L .528 .308 .524 r
F
0 g
.36101 .49161 m
.3655 .49645 L
s
.36101 .49161 m
.38337 .46718 L
s
.35645 .48764 m
.36101 .49161 L
s
.34752 .59998 m
.3495 .59639 L
s
.3495 .59639 m
.35871 .59347 L
s
.3372 .60427 m .33549 .60883 L .33475 .60716 L .943 .684 .516 r
F
.33639 .60271 m .3372 .60427 L .33475 .60716 L F
.28129 .56915 m .30213 .56923 L .28116 .57603 L .528 .308 .524 r
F
.28129 .56915 m .30267 .56219 L .30738 .56653 L .647 .745 .92 r
F
.28129 .56915 m .30267 .56219 L .30213 .56923 L .528 .308 .524 r
F
0 g
.30738 .56653 m
.31206 .57085 L
s
.27699 .56467 m .30267 .56219 L .28129 .56915 L .647 .745 .92 r
F
0 g
.282 .56419 m
.28231 .562 L
s
.039 .916 .04 r
.28911 .5751 m
.30946 .56846 L
s
.26736 .56658 m .27699 .56467 L .28129 .56915 L .647 .745 .92 r
F
.039 .916 .04 r
.27311 .57181 m
.28129 .56915 L
s
0 0 0 r
2 Mabswid
.28129 .56915 Mdot
0 g
.5 Mabswid
.33272 .50601 m
.32897 .50359 L
s
.2483 .51581 m
.25175 .51363 L
s
.25175 .51363 m
.28322 .51445 L
s
.25175 .51363 m
.2483 .51581 L
s
.31859 .61096 m
.32131 .60897 L
s
.32131 .60897 m
.32305 .60842 L
s
.30157 .50688 m .30494 .50589 L .30522 .50764 L .943 .684 .516 r
F
.30157 .50688 m .30116 .5051 L .30494 .50589 L F
0 g
.30494 .50589 m
.30886 .50757 L
s
.33639 .60271 m .33475 .60716 L .33402 .6055 L .943 .684 .516 r
F
.33557 .60114 m .33639 .60271 L .33402 .6055 L F
0 g
.30322 .55517 m
.30376 .54818 L
s
.35861 .56809 m .37663 .56664 L .38215 .57189 L .647 .745 .92 r
F
0 g
.38215 .57189 m
.38766 .57711 L
s
.039 .916 .04 r
.34402 .57369 m
.35891 .56879 L
s
.32629 .52647 m .34312 .5279 L .32577 .53361 L .528 .308 .524 r
F
.32629 .52647 m .34157 .52143 L .34312 .5279 L F
0 g
.32629 .52647 m
.3268 .51935 L
s
.3198 .50664 m
.32897 .50359 L
s
.3198 .50664 m
.3161 .50504 L
s
.30197 .50866 m .30522 .50764 L .30551 .50939 L .943 .684 .516 r
F
.30197 .50866 m .30157 .50688 L .30522 .50764 L F
.33557 .60114 m .33402 .6055 L .33329 .60383 L F
.33475 .59958 m .33557 .60114 L .33329 .60383 L F
0 g
.32305 .60842 m
.32034 .6104 L
s
.28965 .51334 m
.29139 .51276 L
s
.28965 .51334 m
.28632 .51347 L
s
.47411 .60244 m
.47598 .59215 L
s
.47598 .59215 m
.48151 .59043 L
s
.30238 .51045 m .30551 .50939 L .30579 .51115 L .943 .684 .516 r
F
.30238 .51045 m .30197 .50866 L .30551 .50939 L F
.33475 .59958 m .33329 .60383 L .33255 .60216 L F
.33394 .59801 m .33475 .59958 L .33255 .60216 L F
.33937 .51519 m .35649 .51142 L .34157 .52143 L .528 .308 .524 r
F
.33937 .51519 m .35704 .50301 L .35649 .51142 L F
0 g
.33647 .50921 m
.33937 .51519 L
s
.33272 .50601 m
.3532 .49082 L
s
.35704 .50301 m
.35759 .49463 L
s
.2724 .5803 m .28196 .58263 L .27169 .58883 L .528 .308 .524 r
F
.2724 .5803 m .28116 .57603 L .28196 .58263 L F
0 g
.2724 .5803 m
.27311 .57181 L
s
.30279 .51223 m .30579 .51115 L .30607 .5129 L .943 .684 .516 r
F
.30279 .51223 m .30238 .51045 L .30579 .51115 L F
0 g
.28806 .51289 m
.29139 .51276 L
s
.33394 .59801 m .33255 .60216 L .33182 .6005 L .943 .684 .516 r
F
.33312 .59644 m .33394 .59801 L .33182 .6005 L F
.039 .916 .04 r
.30946 .56846 m
.32016 .56494 L
s
0 0 0 r
2 Mabswid
.30946 .56846 Mdot
.23799 .56612 Mdot
.3032 .51401 m .30607 .5129 L .30635 .51465 L .943 .684 .516 r
F
.3032 .51401 m .30279 .51223 L .30607 .5129 L F
.33312 .59644 m .33182 .6005 L .33109 .59883 L F
0 g
.5 Mabswid
.33312 .59644 m
.33481 .59343 L
s
.26158 .56133 m .27699 .56467 L .26736 .56658 L .647 .745 .92 r
F
0 g
.26736 .56658 m
.27311 .57181 L
s
.039 .916 .04 r
.24249 .5732 m
.26618 .56551 L
s
.30361 .51579 m .30635 .51465 L .30663 .51641 L .943 .684 .516 r
F
0 g
.30663 .51641 m
.30977 .51774 L
s
.30361 .51579 m .3032 .51401 L .30635 .51465 L .943 .684 .516 r
F
.42396 .43472 m .43481 .44546 L .42411 .44907 L .528 .308 .524 r
F
.42396 .43472 m .42944 .43286 L .43481 .44546 L F
0 g
.42944 .43286 m
.43688 .44129 L
s
.42396 .43472 m
.42944 .43286 L
s
.41638 .42775 m
.42396 .43472 L
s
.20828 .64422 m .26069 .61743 L .21741 .65439 L .528 .308 .524 r
F
.20828 .64422 m .25523 .61079 L .26069 .61743 L F
0 g
.20237 .63315 m
.20828 .64422 L
s
.25974 .6756 m
.28668 .6317 L
s
.33856 .56858 m .35593 .56298 L .35861 .56809 L .647 .745 .92 r
F
.33379 .56413 m .35593 .56298 L .33856 .56858 L F
0 g
.33856 .56858 m
.3433 .57301 L
s
.039 .916 .04 r
.32682 .57113 m
.3375 .5676 L
s
0 0 0 r
2 Mabswid
.35891 .56879 Mdot
0 g
.5 Mabswid
.48151 .59043 m
.47965 .60072 L
s
.2516 .60361 m
.25523 .61079 L
s
0 0 0 r
2 Mabswid
.26618 .56551 Mdot
0 g
.5 Mabswid
.42244 .5982 m
.4201 .60523 L
s
.39028 .58992 m
.42244 .5982 L
s
.35674 .59705 m
.35871 .59347 L
s
.35871 .59347 m
.38401 .59436 L
s
.38577 .5893 m
.38401 .59436 L
s
.38846 .59518 m
.39028 .58992 L
s
.39485 .56188 m .4307 .56985 L .39463 .56925 L .647 .745 .92 r
F
0 g
.39222 .57726 m
.39463 .56925 L
s
.35593 .56298 m .37663 .56664 L .35861 .56809 L .647 .745 .92 r
F
0 g
.35861 .56809 m
.36062 .57339 L
s
.28116 .57603 m .30158 .57629 L .28196 .58263 L .528 .308 .524 r
F
.28116 .57603 m .30213 .56923 L .30158 .57629 L F
0 g
.28116 .57603 m
.28129 .56915 L
s
.45968 .56172 m .47916 .56788 L .46841 .57128 L .647 .745 .92 r
F
0 g
.46841 .57128 m
.47689 .5808 L
s
.32897 .50359 m
.3488 .48791 L
s
.32897 .50359 m
.32529 .50198 L
s
.3488 .48791 m
.3532 .49082 L
s
.246 .67248 m
.25301 .67484 L
s
.25301 .67484 m
.2824 .63111 L
s
.34513 .60281 m
.34752 .59998 L
s
.34752 .59998 m
.35674 .59705 L
s
.39485 .56188 m .43246 .5596 L .4307 .56985 L .647 .745 .92 r
F
0 g
.42487 .5813 m
.4307 .56985 L
s
.33475 .60716 m .33549 .60883 L .33257 .61098 L .943 .684 .516 r
F
0 g
.33549 .60883 m
.33802 .60583 L
s
.42188 .42588 m
.42944 .43286 L
s
.35645 .48764 m
.37735 .46182 L
s
.37132 .45771 m
.37735 .46182 L
s
.32577 .53361 m .34407 .53461 L .32525 .54077 L .528 .308 .524 r
F
.32577 .53361 m .34312 .5279 L .34407 .53461 L F
0 g
.32577 .53361 m
.32629 .52647 L
s
.35645 .48764 m
.35189 .48461 L
s
.33475 .60716 m .33257 .61098 L .33193 .60924 L .943 .684 .516 r
F
.33402 .6055 m .33475 .60716 L .33193 .60924 L F
.27699 .56467 m .29795 .55783 L .30267 .56219 L .647 .745 .92 r
F
0 g
.30267 .56219 m
.30322 .55517 L
s
.30267 .56219 m
.30738 .56653 L
s
.27361 .55987 m .29795 .55783 L .27699 .56467 L .647 .745 .92 r
F
.039 .916 .04 r
.28129 .56915 m
.30267 .56219 L
s
.26158 .56133 m .27361 .55987 L .27699 .56467 L .647 .745 .92 r
F
.039 .916 .04 r
.26618 .56551 m
.27534 .56253 L
s
0 g
.27699 .56467 m
.28129 .56915 L
s
.28668 .6317 m
.2824 .63111 L
s
.2824 .63111 m
.28668 .6317 L
s
.28668 .6317 m
.31226 .61245 L
s
.31556 .61212 m
.31859 .61096 L
s
.31859 .61096 m
.32034 .6104 L
s
.33402 .6055 m .33193 .60924 L .33129 .6075 L .943 .684 .516 r
F
.33329 .60383 m .33402 .6055 L .33129 .6075 L F
0 g
.3161 .50504 m
.32529 .50198 L
s
.3161 .50504 m
.31253 .50429 L
s
.20169 .70115 m
.21074 .70588 L
s
.21074 .70588 m
.21465 .70468 L
s
.33329 .60383 m .33129 .6075 L .33066 .60576 L .943 .684 .516 r
F
.33255 .60216 m .33329 .60383 L .33066 .60576 L F
.2981 .50701 m .30116 .5051 L .30157 .50688 L F
.2981 .50701 m .29757 .50523 L .30116 .5051 L F
0 g
.30116 .5051 m
.30494 .50589 L
s
.33255 .60216 m .33066 .60576 L .33002 .60402 L .943 .684 .516 r
F
.33182 .6005 m .33255 .60216 L .33002 .60402 L F
.1368 .54725 m .15494 .55532 L .14208 .55962 L .647 .745 .92 r
F
0 g
.14208 .55962 m
.14888 .57132 L
s
.29862 .50879 m .30157 .50688 L .30197 .50866 L .943 .684 .516 r
F
.29862 .50879 m .2981 .50701 L .30157 .50688 L F
0 g
.32034 .6104 m
.31731 .61157 L
s
.28632 .51347 m
.28806 .51289 L
s
.28632 .51347 m
.28322 .51445 L
s
.1768 .55899 m .23496 .55571 L .23644 .56242 L .647 .745 .92 r
F
0 g
.23644 .56242 m
.23934 .56862 L
s
.24526 .51896 m
.2483 .51581 L
s
.2483 .51581 m
.28042 .51625 L
s
.2483 .51581 m
.24526 .51896 L
s
.29915 .51057 m .30197 .50866 L .30238 .51045 L .943 .684 .516 r
F
.29915 .51057 m .29862 .50879 L .30197 .50866 L F
.33182 .6005 m .33002 .60402 L .32938 .60228 L F
.33109 .59883 m .33182 .6005 L .32938 .60228 L F
0 g
.19548 .5012 m
.24526 .51896 L
s
.19548 .5012 m
.19132 .50746 L
s
0 0 0 r
2 Mabswid
.32016 .56494 Mdot
.29968 .51235 m .30238 .51045 L .30279 .51223 L .943 .684 .516 r
F
.29968 .51235 m .29915 .51057 L .30238 .51045 L F
.35593 .56298 m .37108 .56137 L .37663 .56664 L .647 .745 .92 r
F
0 g
.5 Mabswid
.37663 .56664 m
.38215 .57189 L
s
.039 .916 .04 r
.35891 .56879 m
.37372 .56388 L
s
.33109 .59883 m .32938 .60228 L .32874 .60053 L .943 .684 .516 r
F
0 g
.33109 .59883 m
.33312 .59644 L
s
.27169 .58883 m .28378 .58893 L .27097 .59739 L .528 .308 .524 r
F
.27169 .58883 m .28196 .58263 L .28378 .58893 L F
0 g
.27169 .58883 m
.2724 .5803 L
s
.30021 .51413 m .30279 .51223 L .3032 .51401 L .943 .684 .516 r
F
.30021 .51413 m .29968 .51235 L .30279 .51223 L F
0 g
.28497 .51386 m
.28806 .51289 L
s
.30074 .51591 m .3032 .51401 L .30361 .51579 L .943 .684 .516 r
F
0 g
.30361 .51579 m
.30663 .51641 L
s
.30074 .51591 m .30021 .51413 L .3032 .51401 L .943 .684 .516 r
F
.34157 .52143 m .35594 .51987 L .34312 .5279 L .528 .308 .524 r
F
.34157 .52143 m .35649 .51142 L .35594 .51987 L F
0 g
.33937 .51519 m
.34157 .52143 L
s
.35649 .51142 m
.35704 .50301 L
s
.21465 .70468 m
.20562 .69994 L
s
.14297 .50146 m
.14685 .50013 L
s
.14297 .50146 m
.13862 .51087 L
s
0 0 0 r
2 Mabswid
.27534 .56253 Mdot
.33379 .56413 m .35263 .55804 L .35593 .56298 L .647 .745 .92 r
F
.32901 .55966 m .35263 .55804 L .33379 .56413 L F
0 g
.5 Mabswid
.33379 .56413 m
.33856 .56858 L
s
.039 .916 .04 r
.32016 .56494 m
.33089 .56142 L
s
.17787 .54731 m .23496 .55571 L .1768 .55899 L .647 .745 .92 r
F
.039 .916 .04 r
.17891 .56968 m
.23538 .55853 L
s
0 g
.1768 .55899 m
.17886 .56951 L
s
.25578 .55606 m .27361 .55987 L .26158 .56133 L .647 .745 .92 r
F
0 g
.26158 .56133 m
.26736 .56658 L
s
.35437 .59989 m
.35674 .59705 L
s
.35674 .59705 m
.38173 .59861 L
s
.36854 .49761 m .40456 .48279 L .37391 .50439 L .528 .308 .524 r
F
.36854 .49761 m .39596 .47426 L .40456 .48279 L F
0 g
.36101 .49161 m
.36854 .49761 L
s
.38337 .46718 m
.39596 .47426 L
s
.45968 .56172 m .47463 .55698 L .47916 .56788 L .647 .745 .92 r
F
0 g
.47916 .56788 m
.48241 .57907 L
s
.039 .916 .04 r
.30267 .56219 m
.31342 .55869 L
s
0 0 0 r
2 Mabswid
.30267 .56219 Mdot
0 g
.5 Mabswid
.30213 .56923 m
.30267 .56219 L
s
.1425 .50954 m
.14685 .50013 L
s
.38401 .59436 m
.38173 .59861 L
s
.28196 .58263 m .30104 .58338 L .28378 .58893 L .528 .308 .524 r
F
.28196 .58263 m .30158 .57629 L .30104 .58338 L F
0 g
.28116 .57603 m
.28196 .58263 L
s
.32525 .54077 m .34444 .54153 L .32473 .54797 L .528 .308 .524 r
F
.32525 .54077 m .34407 .53461 L .34444 .54153 L F
0 g
.32525 .54077 m
.32577 .53361 L
s
.32529 .50198 m
.34448 .48597 L
s
.32529 .50198 m
.32173 .50122 L
s
.38611 .5996 m
.38846 .59518 L
s
.38846 .59518 m
.4201 .60523 L
s
0 0 0 r
2 Mabswid
.37372 .56388 Mdot
0 g
.5 Mabswid
.34238 .60485 m
.34513 .60281 L
s
.34513 .60281 m
.35437 .59989 L
s
.4713 .61147 m
.47411 .60244 L
s
.47411 .60244 m
.47965 .60072 L
s
.34448 .48597 m
.3488 .48791 L
s
.35263 .55804 m .37108 .56137 L .35593 .56298 L .647 .745 .92 r
F
.039 .916 .04 r
.3375 .5676 m
.3552 .56179 L
s
0 g
.35593 .56298 m
.35861 .56809 L
s
.33193 .60924 m .33257 .61098 L .32931 .61225 L .943 .684 .516 r
F
0 g
.33257 .61098 m
.33549 .60883 L
s
.31226 .61245 m
.31556 .61212 L
s
.31556 .61212 m
.31731 .61157 L
s
.33193 .60924 m .32931 .61225 L .32878 .61046 L .943 .684 .516 r
F
.33129 .6075 m .33193 .60924 L .32878 .61046 L F
.33129 .6075 m .32878 .61046 L .32825 .60867 L F
.33066 .60576 m .33129 .6075 L .32825 .60867 L F
.33066 .60576 m .32825 .60867 L .32772 .60689 L F
.33002 .60402 m .33066 .60576 L .32772 .60689 L F
0 g
.35189 .48461 m
.37132 .45771 L
s
.35189 .48461 m
.34741 .48259 L
s
.25578 .55606 m .27122 .55472 L .27361 .55987 L .647 .745 .92 r
F
.039 .916 .04 r
.23799 .56612 m
.25926 .55922 L
s
.27361 .55987 m .29322 .55346 L .29795 .55783 L .647 .745 .92 r
F
0 g
.29795 .55783 m
.30267 .56219 L
s
.27122 .55472 m .29322 .55346 L .27361 .55987 L .647 .745 .92 r
F
.039 .916 .04 r
.27534 .56253 m
.29585 .55589 L
s
0 g
.27361 .55987 m
.27699 .56467 L
s
.31253 .50429 m
.32173 .50122 L
s
.31253 .50429 m
.30914 .50441 L
s
.33002 .60402 m .32772 .60689 L .32719 .6051 L .943 .684 .516 r
F
.32938 .60228 m .33002 .60402 L .32719 .6051 L F
0 0 0 r
2 Mabswid
.23538 .55853 Mdot
.32938 .60228 m .32719 .6051 L .32666 .60332 L .943 .684 .516 r
F
.32874 .60053 m .32938 .60228 L .32666 .60332 L F
0 0 0 r
.25926 .55922 Mdot
.32874 .60053 m .32666 .60332 L .32613 .60153 L .943 .684 .516 r
F
0 g
.5 Mabswid
.32874 .60053 m
.33109 .59883 L
s
.4201 .60523 m
.41706 .61116 L
s
.31731 .61157 m
.31402 .61189 L
s
.2824 .63111 m
.27794 .62949 L
s
.27794 .62949 m
.2824 .63111 L
s
.29487 .50802 m .29757 .50523 L .2981 .50701 L .943 .684 .516 r
F
.29487 .50802 m .29423 .50627 L .29757 .50523 L F
0 g
.29757 .50523 m
.30116 .5051 L
s
.28322 .51445 m
.28497 .51386 L
s
.28322 .51445 m
.28042 .51625 L
s
.29551 .50977 m .2981 .50701 L .29862 .50879 L .943 .684 .516 r
F
.29551 .50977 m .29487 .50802 L .2981 .50701 L F
.29615 .51152 m .29862 .50879 L .29915 .51057 L F
.29615 .51152 m .29551 .50977 L .29862 .50879 L F
0 g
.41638 .42775 m
.42188 .42588 L
s
.41638 .42775 m
.4088 .42235 L
s
0 0 0 r
2 Mabswid
.3552 .56179 Mdot
.29679 .51326 m .29915 .51057 L .29968 .51235 L .943 .684 .516 r
F
.29679 .51326 m .29615 .51152 L .29915 .51057 L F
.29743 .51501 m .29968 .51235 L .30021 .51413 L F
.29743 .51501 m .29679 .51326 L .29968 .51235 L F
.1368 .54725 m .14579 .54422 L .15494 .55532 L .647 .745 .92 r
F
0 g
.5 Mabswid
.15494 .55532 m
.16457 .56611 L
s
.29807 .51676 m .30021 .51413 L .30074 .51591 L .943 .684 .516 r
F
0 g
.30074 .51591 m
.30361 .51579 L
s
.29807 .51676 m .29743 .51501 L .30021 .51413 L .943 .684 .516 r
F
.27097 .59739 m .28675 .59489 L .27025 .60599 L .528 .308 .524 r
F
.27097 .59739 m .28378 .58893 L .28675 .59489 L F
0 g
.27097 .59739 m
.27169 .58883 L
s
.28217 .51567 m
.28497 .51386 L
s
.186 .68015 m .19653 .69329 L .19259 .69451 L .528 .308 .524 r
F
.186 .68015 m .19504 .67733 L .19653 .69329 L F
0 g
.18124 .66539 m
.186 .68015 L
s
.19415 .66133 m
.19504 .67733 L
s
.186 .68015 m
.19259 .69451 L
s
.42411 .44907 m .439 .4586 L .42409 .46359 L .528 .308 .524 r
F
.42411 .44907 m .43481 .44546 L .439 .4586 L F
0 g
.42396 .43472 m
.42411 .44907 L
s
.42944 .43286 m
.43481 .44546 L
s
.47965 .60072 m
.47686 .60975 L
s
.24268 .52304 m
.24526 .51896 L
s
.24526 .51896 m
.27796 .51887 L
s
.24526 .51896 m
.24269 .52304 L
s
.34312 .5279 m .35538 .52834 L .34407 .53461 L .528 .308 .524 r
F
.34312 .5279 m .35594 .51987 L .35538 .52834 L F
0 g
.34157 .52143 m
.34312 .5279 L
s
.35594 .51987 m
.35649 .51142 L
s
.3654 .45493 m
.37132 .45771 L
s
.35263 .55804 m .3655 .55607 L .37108 .56137 L .647 .745 .92 r
F
0 g
.37108 .56137 m
.37663 .56664 L
s
.3934 .555 m .43246 .5596 L .39485 .56188 L .647 .745 .92 r
F
0 g
.39463 .56925 m
.39485 .56188 L
s
.32421 .55518 m .34872 .55327 L .32901 .55966 L .647 .745 .92 r
F
.32901 .55966 m .34872 .55327 L .35263 .55804 L F
0 g
.32901 .55966 m
.33379 .56413 L
s
.30158 .57629 m
.30213 .56923 L
s
0 0 0 r
2 Mabswid
.31342 .55869 Mdot
0 g
.5 Mabswid
.23882 .66855 m
.246 .67248 L
s
.35163 .60192 m
.35437 .59989 L
s
.35437 .59989 m
.37898 .60197 L
s
.41431 .42047 m
.42188 .42588 L
s
.32473 .54797 m .34423 .54867 L .32421 .55518 L .528 .308 .524 r
F
.32473 .54797 m .34444 .54153 L .34423 .54867 L F
0 g
.32473 .54797 m
.32525 .54077 L
s
.17787 .54731 m .23527 .54836 L .23496 .55571 L .647 .745 .92 r
F
0 g
.23496 .55571 m
.23644 .56242 L
s
.24995 .55076 m .27122 .55472 L .25578 .55606 L .647 .745 .92 r
F
.039 .916 .04 r
.25926 .55922 m
.27141 .55526 L
s
0 g
.25578 .55606 m
.26158 .56133 L
s
.28378 .58893 m .30049 .59048 L .28675 .59489 L .528 .308 .524 r
F
.28378 .58893 m .30104 .58338 L .30049 .59048 L F
0 g
.28196 .58263 m
.28378 .58893 L
s
.32173 .50122 m
.3403 .48504 L
s
.32173 .50122 m
.31835 .50133 L
s
.38173 .59861 m
.37898 .60197 L
s
.35163 .60192 m
.34238 .60485 L
s
.3393 .60604 m
.34238 .60485 L
s
.19132 .50746 m
.24268 .52304 L
s
.19132 .50746 m
.18796 .51507 L
s
.21741 .65439 m .26879 .62328 L .23159 .6631 L .528 .308 .524 r
F
.21741 .65439 m .26069 .61743 L .26879 .62328 L F
0 g
.20828 .64422 m
.21741 .65439 L
s
.246 .67248 m
.27794 .62949 L
s
.21741 .65439 m
.23159 .6631 L
s
.25523 .61079 m
.26069 .61743 L
s
.32613 .60153 m .3237 .60359 L .32329 .60179 L .943 .684 .516 r
F
.32613 .60153 m .32666 .60332 L .3237 .60359 L F
0 g
.32613 .60153 m
.32874 .60053 L
s
.32666 .60332 m .32411 .60539 L .3237 .60359 L .943 .684 .516 r
F
.32666 .60332 m .32719 .6051 L .32411 .60539 L F
.45072 .55214 m .47463 .55698 L .45968 .56172 L .647 .745 .92 r
F
0 g
.45968 .56172 m
.46841 .57128 L
s
.30876 .61192 m
.31226 .61245 L
s
.31226 .61245 m
.31402 .61189 L
s
.32719 .6051 m .32453 .6072 L .32411 .60539 L .943 .684 .516 r
F
.32719 .6051 m .32772 .60689 L .32453 .6072 L F
0 g
.38326 .60309 m
.38611 .5996 L
s
.38611 .5996 m
.41706 .61116 L
s
.32772 .60689 m .32494 .609 L .32453 .6072 L .943 .684 .516 r
F
.32772 .60689 m .32825 .60867 L .32494 .609 L F
.32825 .60867 m .32535 .6108 L .32494 .609 L F
.32825 .60867 m .32878 .61046 L .32535 .6108 L F
.32878 .61046 m .32576 .6126 L .32535 .6108 L F
.32878 .61046 m .32931 .61225 L .32576 .6126 L F
0 g
.32931 .61225 m
.33257 .61098 L
s
.34872 .55327 m .3655 .55607 L .35263 .55804 L .647 .745 .92 r
F
0 g
.35263 .55804 m
.35593 .56298 L
s
.039 .916 .04 r
.3552 .56179 m
.36732 .5578 L
s
0 g
.3403 .48504 m
.34448 .48597 L
s
.30914 .50441 m
.31835 .50133 L
s
.30914 .50441 m
.306 .5054 L
s
.19504 .67733 m
.19653 .69329 L
s
.19259 .69451 m
.20169 .70115 L
s
.20169 .70115 m
.20562 .69994 L
s
0 0 0 r
2 Mabswid
.27141 .55526 Mdot
.29567 .51834 m .29743 .51501 L .29807 .51676 L .943 .684 .516 r
F
0 g
.5 Mabswid
.29807 .51676 m
.30074 .51591 L
s
.039 .916 .04 r
.29585 .55589 m
.30665 .5524 L
s
0 0 0 r
2 Mabswid
.29585 .55589 Mdot
0 g
.5 Mabswid
.31402 .61189 m
.31052 .61136 L
s
.29492 .51665 m .29679 .51326 L .29743 .51501 L .943 .684 .516 r
F
.29567 .51834 m .29492 .51665 L .29743 .51501 L F
0 g
.28042 .51625 m
.28217 .51567 L
s
.28042 .51625 m
.27796 .51887 L
s
.29418 .51496 m .29615 .51152 L .29679 .51326 L .943 .684 .516 r
F
.29492 .51665 m .29418 .51496 L .29679 .51326 L F
.37391 .50439 m .41046 .4923 L .37765 .51176 L .528 .308 .524 r
F
.37391 .50439 m .40456 .48279 L .41046 .4923 L F
0 g
.36854 .49761 m
.37391 .50439 L
s
.39596 .47426 m
.40456 .48279 L
s
.29344 .51328 m .29551 .50977 L .29615 .51152 L .943 .684 .516 r
F
.29418 .51496 m .29344 .51328 L .29615 .51152 L F
.2927 .51159 m .29487 .50802 L .29551 .50977 L F
.29344 .51328 m .2927 .51159 L .29551 .50977 L F
0 0 0 r
2 Mabswid
.36732 .5578 Mdot
.27122 .55472 m .28846 .54907 L .29322 .55346 L .647 .745 .92 r
F
0 g
.5 Mabswid
.29322 .55346 m
.29795 .55783 L
s
.26997 .54917 m .28846 .54907 L .27122 .55472 L .647 .745 .92 r
F
.039 .916 .04 r
.27141 .55526 m
.28902 .54958 L
s
.24995 .55076 m .26997 .54917 L .27122 .55472 L .647 .745 .92 r
F
0 g
.27122 .55472 m
.27361 .55987 L
s
.039 .916 .04 r
.23538 .55853 m
.2524 .55299 L
s
0 g
.34741 .48259 m
.3654 .45493 L
s
.34741 .48259 m
.34308 .48161 L
s
.29196 .5099 m .29423 .50627 L .29487 .50802 L .943 .684 .516 r
F
.2927 .51159 m .29196 .5099 L .29487 .50802 L F
.29196 .5099 m .29121 .50821 L .29423 .50627 L F
0 g
.29423 .50627 m
.29757 .50523 L
s
.3934 .555 m .43146 .55014 L .43246 .5596 L .647 .745 .92 r
F
0 g
.4307 .56985 m
.43246 .5596 L
s
.039 .916 .04 r
.37372 .56388 m
.39399 .55704 L
s
0 g
.27794 .62949 m
.27338 .62687 L
s
.27338 .62687 m
.27794 .62949 L
s
.27025 .60599 m .29117 .60042 L .26952 .61462 L .528 .308 .524 r
F
0 g
.2824 .63111 m
.30876 .61192 L
s
.27025 .60599 m .28675 .59489 L .29117 .60042 L .528 .308 .524 r
F
0 g
.27025 .60599 m
.27097 .59739 L
s
.27971 .51829 m
.28217 .51567 L
s
.34407 .53461 m .35483 .53686 L .34444 .54153 L .528 .308 .524 r
F
.34407 .53461 m .35538 .52834 L .35483 .53686 L F
0 g
.34312 .5279 m
.34407 .53461 L
s
.35538 .52834 m
.35594 .51987 L
s
.30104 .58338 m
.30158 .57629 L
s
.19653 .69329 m
.20562 .69994 L
s
.13862 .51087 m
.1425 .50954 L
s
.13862 .51087 m
.13535 .52183 L
s
.24062 .52798 m
.24268 .52304 L
s
.24269 .52304 m
.27588 .52225 L
s
.24269 .52304 m
.24063 .52798 L
s
0 0 0 r
2 Mabswid
.2524 .55299 Mdot
.32421 .55518 m .34345 .55601 L .32369 .56242 L .528 .308 .524 r
F
.32421 .55518 m .34423 .54867 L .34872 .55327 L .647 .745 .92 r
F
.32421 .55518 m .34423 .54867 L .34345 .55601 L .528 .308 .524 r
F
.31939 .55068 m .34423 .54867 L .32421 .55518 L .647 .745 .92 r
F
0 0 0 r
.32421 .55518 Mdot
0 g
.5 Mabswid
.32457 .55026 m
.32473 .54797 L
s
.039 .916 .04 r
.31342 .55869 m
.32421 .55518 L
s
0 g
.26069 .61743 m
.26879 .62328 L
s
.34872 .55327 m .3599 .55075 L .3655 .55607 L .647 .745 .92 r
F
.039 .916 .04 r
.33089 .56142 m
.35029 .55508 L
s
0 g
.3655 .55607 m
.37108 .56137 L
s
.37579 .60438 m
.35163 .60192 L
s
.34857 .6031 m
.35163 .60192 L
s
.41706 .61116 m
.41335 .61587 L
s
.4676 .6191 m
.4713 .61147 L
s
.4713 .61147 m
.47686 .60975 L
s
.13924 .5205 m
.1425 .50954 L
s
.31835 .50133 m
.33635 .48513 L
s
.31835 .50133 m
.31522 .50231 L
s
.32329 .60179 m .32056 .6031 L .32027 .60132 L .943 .684 .516 r
F
.32329 .60179 m .3237 .60359 L .32056 .6031 L F
0 g
.32329 .60179 m
.32613 .60153 L
s
.3237 .60359 m .32084 .60488 L .32056 .6031 L .943 .684 .516 r
F
.3237 .60359 m .32411 .60539 L .32084 .60488 L F
.28675 .59489 m .29994 .59762 L .29117 .60042 L .528 .308 .524 r
F
.28675 .59489 m .30049 .59048 L .29994 .59762 L F
0 g
.28378 .58893 m
.28675 .59489 L
s
.33596 .60636 m
.3393 .60604 L
s
.3393 .60604 m
.34857 .6031 L
s
.32411 .60539 m .32113 .60667 L .32084 .60488 L .943 .684 .516 r
F
.32411 .60539 m .32453 .6072 L .32113 .60667 L F
.13323 .53415 m .14579 .54422 L .1368 .54725 L .647 .745 .92 r
F
0 g
.1368 .54725 m
.14208 .55962 L
s
.35967 .45353 m
.3654 .45493 L
s
.30511 .61054 m
.30876 .61192 L
s
.30876 .61192 m
.31052 .61136 L
s
.24409 .54544 m .26997 .54917 L .24995 .55076 L .647 .745 .92 r
F
0 g
.24995 .55076 m
.25578 .55606 L
s
.29356 .52061 m .29492 .51665 L .29567 .51834 L .943 .684 .516 r
F
0 g
.29567 .51834 m
.29807 .51676 L
s
.32453 .6072 m .32142 .60845 L .32113 .60667 L .943 .684 .516 r
F
.32453 .6072 m .32494 .609 L .32142 .60845 L F
0 0 0 r
2 Mabswid
.30665 .5524 Mdot
0 g
.5 Mabswid
.37898 .60197 m
.37579 .60438 L
s
.29272 .51901 m .29418 .51496 L .29492 .51665 L .943 .684 .516 r
F
.29356 .52061 m .29272 .51901 L .29492 .51665 L F
.32494 .609 m .3217 .61024 L .32142 .60845 L F
.32494 .609 m .32535 .6108 L .3217 .61024 L F
.39056 .54852 m .43146 .55014 L .3934 .555 L .647 .745 .92 r
F
0 g
.3934 .555 m
.39485 .56188 L
s
.039 .916 .04 r
.36732 .5578 m
.39124 .54981 L
s
0 g
.4088 .42235 m
.41431 .42047 L
s
.4088 .42235 m
.40135 .41864 L
s
.32535 .6108 m .32199 .61203 L .3217 .61024 L .943 .684 .516 r
F
.32535 .6108 m .32576 .6126 L .32199 .61203 L F
0 g
.32576 .6126 m
.32931 .61225 L
s
.29189 .51742 m .29344 .51328 L .29418 .51496 L .943 .684 .516 r
F
.29272 .51901 m .29189 .51742 L .29418 .51496 L F
0 g
.306 .5054 m
.31522 .50231 L
s
.306 .5054 m
.30316 .50724 L
s
.31052 .61136 m
.30687 .60998 L
s
.34423 .54867 m .3599 .55075 L .34872 .55327 L .647 .745 .92 r
F
.039 .916 .04 r
.35029 .55508 m
.36082 .55163 L
s
0 g
.34872 .55327 m
.35263 .55804 L
s
.27796 .51887 m
.27971 .51829 L
s
.27796 .51887 m
.27588 .52225 L
s
.29106 .51582 m .2927 .51159 L .29344 .51328 L .943 .684 .516 r
F
.29189 .51742 m .29106 .51582 L .29344 .51328 L F
.42409 .46359 m .44205 .47223 L .42392 .47826 L .528 .308 .524 r
F
.42409 .46359 m .439 .4586 L .44205 .47223 L F
0 g
.42409 .46359 m
.42411 .44907 L
s
.43481 .44546 m
.439 .4586 L
s
.45072 .55214 m .4689 .54634 L .47463 .55698 L .647 .745 .92 r
F
0 g
.47463 .55698 m
.47916 .56788 L
s
.47686 .60975 m
.47318 .61738 L
s
.29023 .51423 m .29196 .5099 L .2927 .51159 L .943 .684 .516 r
F
.29106 .51582 m .29023 .51423 L .2927 .51159 L F
0 g
.30049 .59048 m
.30104 .58338 L
s
.1839 .53384 m .23527 .54836 L .17787 .54731 L .647 .745 .92 r
F
0 g
.1768 .55899 m
.17787 .54731 L
s
.37996 .6056 m
.38326 .60309 L
s
.38326 .60309 m
.41335 .61587 L
s
.33635 .48513 m
.3403 .48504 L
s
.34444 .54153 m .35427 .5454 L .34423 .54867 L .528 .308 .524 r
F
.34444 .54153 m .35483 .53686 L .35427 .5454 L F
0 g
.34407 .53461 m
.34444 .54153 L
s
.35483 .53686 m
.35538 .52834 L
s
.2894 .51263 m .29121 .50821 L .29196 .5099 L .943 .684 .516 r
F
.29023 .51423 m .2894 .51263 L .29196 .5099 L F
0 g
.23159 .6631 m
.23882 .66855 L
s
.23882 .66855 m
.27338 .62687 L
s
.27763 .52167 m
.27971 .51829 L
s
.26952 .61462 m .29762 .60533 L .26879 .62328 L .528 .308 .524 r
F
.26952 .61462 m .29117 .60042 L .29762 .60533 L F
0 g
.27794 .62949 m
.30511 .61054 L
s
.26952 .61462 m
.27025 .60599 L
s
.26879 .62328 m
.26952 .61462 L
s
.2894 .51263 m .28856 .51103 L .29121 .50821 L .943 .684 .516 r
F
0 g
.29121 .50821 m
.29423 .50627 L
s
.26879 .62328 m
.27338 .62687 L
s
.26879 .62328 m
.27338 .62687 L
s
.27338 .62687 m
.30138 .60833 L
s
.32369 .56242 m .3421 .56356 L .32316 .56968 L .528 .308 .524 r
F
.32369 .56242 m .34345 .55601 L .3421 .56356 L F
0 g
.32369 .56242 m
.32421 .55518 L
s
.1839 .53384 m .2382 .54009 L .23527 .54836 L .647 .745 .92 r
F
0 g
.23527 .54836 m
.2382 .54009 L
s
.23496 .55571 m
.23527 .54836 L
s
.17787 .54731 m
.1839 .53384 L
s
.34308 .48161 m
.35967 .45353 L
s
.34308 .48161 m
.33897 .4817 L
s
.26997 .54917 m .28368 .54466 L .28846 .54907 L .647 .745 .92 r
F
0 g
.28846 .54907 m
.29322 .55346 L
s
.27014 .54312 m .28368 .54466 L .26997 .54917 L .647 .745 .92 r
F
.24409 .54544 m .27014 .54312 L .26997 .54917 L F
0 g
.26997 .54917 m
.27122 .55472 L
s
.039 .916 .04 r
.2524 .55299 m
.26985 .54729 L
s
.31939 .55068 m .33915 .54423 L .34423 .54867 L .647 .745 .92 r
F
.31455 .54616 m .33915 .54423 L .31939 .55068 L F
0 g
.31939 .55068 m
.32421 .55518 L
s
.039 .916 .04 r
.30665 .5524 m
.3175 .54891 L
s
0 g
.18796 .51507 m
.24062 .52798 L
s
.23912 .53369 m
.24062 .52798 L
s
.24063 .52798 m
.27423 .52634 L
s
.24063 .52798 m
.23912 .53369 L
s
.40687 .41675 m
.41431 .42047 L
s
.039 .916 .04 r
.28902 .54958 m
.29988 .54611 L
s
0 g
.18796 .51507 m
.18547 .52392 L
s
.37765 .51176 m .41423 .5026 L .38003 .51962 L .528 .308 .524 r
F
.37765 .51176 m .41046 .4923 L .41423 .5026 L F
0 g
.37391 .50439 m
.37765 .51176 L
s
.40456 .48279 m
.41046 .4923 L
s
0 0 0 r
2 Mabswid
.36082 .55163 Mdot
.32027 .60132 m .31728 .60184 L .31712 .60011 L .943 .684 .516 r
F
.32027 .60132 m .32056 .6031 L .31728 .60184 L F
0 g
.5 Mabswid
.32027 .60132 m
.32329 .60179 L
s
.34524 .60342 m
.34857 .6031 L
s
.34857 .6031 m
.37222 .60579 L
s
.13323 .53415 m .13714 .53282 L .14579 .54422 L .647 .745 .92 r
F
0 g
.14579 .54422 m
.15494 .55532 L
s
.13323 .53415 m
.1368 .54725 L
s
.13714 .53282 m
.14579 .54422 L
s
.32056 .6031 m .31743 .60358 L .31728 .60184 L .943 .684 .516 r
F
.32056 .6031 m .32084 .60488 L .31743 .60358 L F
.34423 .54867 m .35427 .5454 L .3599 .55075 L .647 .745 .92 r
F
0 g
.3599 .55075 m
.3655 .55607 L
s
.29178 .52354 m .29272 .51901 L .29356 .52061 L .943 .684 .516 r
F
0 g
.29356 .52061 m
.29567 .51834 L
s
.32084 .60488 m .31759 .60532 L .31743 .60358 L .943 .684 .516 r
F
.32084 .60488 m .32113 .60667 L .31759 .60532 L F
0 g
.31522 .50231 m
.33268 .48626 L
s
.31522 .50231 m
.31239 .50416 L
s
0 0 0 r
2 Mabswid
.3175 .54891 Mdot
0 g
.5 Mabswid
.30138 .60833 m
.30511 .61054 L
s
.30511 .61054 m
.30687 .60998 L
s
0 0 0 r
2 Mabswid
.26985 .54729 Mdot
.29087 .52207 m .29189 .51742 L .29272 .51901 L .943 .684 .516 r
F
.29178 .52354 m .29087 .52207 L .29272 .51901 L F
.32113 .60667 m .31774 .60705 L .31759 .60532 L F
.32113 .60667 m .32142 .60845 L .31774 .60705 L F
0 g
.5 Mabswid
.3324 .6058 m
.33596 .60636 L
s
.33596 .60636 m
.34524 .60342 L
s
.18361 .68607 m
.19259 .69451 L
s
.19259 .69451 m
.19653 .69329 L
s
.28997 .52059 m .29106 .51582 L .29189 .51742 L .943 .684 .516 r
F
.29087 .52207 m .28997 .52059 L .29189 .51742 L F
.32142 .60845 m .3179 .60879 L .31774 .60705 L F
.32142 .60845 m .3217 .61024 L .3179 .60879 L F
0 g
.30687 .60998 m
.30314 .60777 L
s
.27588 .52225 m
.27763 .52167 L
s
.27588 .52225 m
.27423 .52634 L
s
.28906 .51912 m .29023 .51423 L .29106 .51582 L .943 .684 .516 r
F
.28997 .52059 m .28906 .51912 L .29106 .51582 L F
.3217 .61024 m .31806 .61053 L .3179 .60879 L F
.3217 .61024 m .32199 .61203 L .31806 .61053 L F
0 g
.32199 .61203 m
.32576 .6126 L
s
.44152 .54254 m .4689 .54634 L .45072 .55214 L .647 .745 .92 r
F
0 g
.45072 .55214 m
.45968 .56172 L
s
.30316 .50724 m
.31239 .50416 L
s
.30316 .50724 m
.30066 .50992 L
s
.34423 .54867 m .3537 .55398 L .34345 .55601 L .528 .308 .524 r
F
.34423 .54867 m .35427 .5454 L .3537 .55398 L F
.33915 .54423 m .35427 .5454 L .34423 .54867 L .647 .745 .92 r
F
0 0 0 r
2 Mabswid
.34423 .54867 Mdot
0 g
.5 Mabswid
.34435 .54463 m
.34444 .54153 L
s
.039 .916 .04 r
.32421 .55518 m
.34423 .54867 L
s
.2382 .54009 m .27014 .54312 L .24409 .54544 L .647 .745 .92 r
F
0 g
.24409 .54544 m
.24995 .55076 L
s
.29117 .60042 m .29938 .60477 L .29762 .60533 L .528 .308 .524 r
F
.29117 .60042 m .29994 .59762 L .29938 .60477 L F
0 g
.28675 .59489 m
.29117 .60042 L
s
.29117 .60042 m
.29762 .60533 L
s
.29994 .59762 m
.30049 .59048 L
s
.28815 .51764 m .2894 .51263 L .29023 .51423 L .943 .684 .516 r
F
.28906 .51912 m .28815 .51764 L .29023 .51423 L F
0 g
.27599 .52576 m
.27763 .52167 L
s
.32316 .56968 m .34015 .57133 L .32263 .57697 L .528 .308 .524 r
F
.32316 .56968 m .3421 .56356 L .34015 .57133 L F
0 g
.32316 .56968 m
.32369 .56242 L
s
.37579 .60438 m
.37222 .60579 L
s
.13535 .52183 m
.13924 .5205 L
s
.13323 .53415 m
.13535 .52183 L
s
.28724 .51617 m .28856 .51103 L .2894 .51263 L .943 .684 .516 r
F
.28815 .51764 m .28724 .51617 L .2894 .51263 L F
0 g
.18755 .68485 m
.19653 .69329 L
s
.26427 .61879 m
.26879 .62328 L
s
.26879 .62328 m
.29762 .60533 L
s
.26427 .61879 m
.26879 .62328 L
s
.23159 .6631 m
.26879 .62328 L
s
.41335 .61587 m
.40903 .61926 L
s
.28724 .51617 m .28633 .51469 L .28856 .51103 L .943 .684 .516 r
F
0 g
.28856 .51103 m
.29121 .50821 L
s
0 0 0 r
2 Mabswid
.29988 .54611 Mdot
.39056 .54852 m .42828 .5413 L .43146 .55014 L .647 .745 .92 r
F
0 g
.5 Mabswid
.43146 .55014 m
.43246 .5596 L
s
.039 .916 .04 r
.39399 .55704 m
.4311 .54872 L
s
0 g
.33268 .48626 m
.33635 .48513 L
s
.23912 .53369 m
.27304 .53108 L
s
.18547 .52392 m
.23912 .53369 L
s
.37626 .60707 m
.37996 .6056 L
s
.37996 .6056 m
.40903 .61926 L
s
.31712 .60011 m .31392 .59983 L .3139 .59818 L .943 .684 .516 r
F
.31712 .60011 m .31728 .60184 L .31392 .59983 L F
0 g
.31712 .60011 m
.32027 .60132 L
s
.31455 .54616 m .33348 .53997 L .33915 .54423 L .647 .745 .92 r
F
.3097 .54162 m .33348 .53997 L .31455 .54616 L F
0 g
.31455 .54616 m
.31939 .55068 L
s
.039 .916 .04 r
.29988 .54611 m
.31077 .54263 L
s
.38648 .54241 m .42828 .5413 L .39056 .54852 L .647 .745 .92 r
F
0 g
.39056 .54852 m
.3934 .555 L
s
.039 .916 .04 r
.36082 .55163 m
.38695 .54301 L
s
0 g
.13714 .53282 m
.13924 .5205 L
s
.35423 .45356 m
.35967 .45353 L
s
.31728 .60184 m .31394 .60149 L .31392 .59983 L .943 .684 .516 r
F
.31728 .60184 m .31743 .60358 L .31394 .60149 L F
.27014 .54312 m .27889 .54023 L .28368 .54466 L .647 .745 .92 r
F
.039 .916 .04 r
.26985 .54729 m
.28222 .5433 L
s
0 g
.28368 .54466 m
.28846 .54907 L
s
.29037 .52709 m .29087 .52207 L .29178 .52354 L .943 .684 .516 r
F
0 g
.29178 .52354 m
.29356 .52061 L
s
.33897 .4817 m
.35423 .45356 L
s
.33897 .4817 m
.33517 .48286 L
s
.34169 .60286 m
.34524 .60342 L
s
.34524 .60342 m
.36833 .60618 L
s
.31743 .60358 m .31396 .60315 L .31394 .60149 L .943 .684 .516 r
F
.31743 .60358 m .31759 .60532 L .31396 .60315 L F
0 g
.46304 .62518 m
.4676 .6191 L
s
.4676 .6191 m
.47318 .61738 L
s
.28941 .52576 m .28997 .52059 L .29087 .52207 L .943 .684 .516 r
F
.29037 .52709 m .28941 .52576 L .29087 .52207 L F
0 g
.29762 .60533 m
.30138 .60833 L
s
.30138 .60833 m
.30314 .60777 L
s
.22446 .65623 m
.23159 .6631 L
s
.31759 .60532 m .31398 .60481 L .31396 .60315 L .943 .684 .516 r
F
.31759 .60532 m .31774 .60705 L .31398 .60481 L F
.38003 .51962 m .41616 .51358 L .3812 .52792 L .528 .308 .524 r
F
.38003 .51962 m .41423 .5026 L .41616 .51358 L F
0 g
.37765 .51176 m
.38003 .51962 L
s
.27232 .53637 m .27889 .54023 L .27014 .54312 L .647 .745 .92 r
F
.2382 .54009 m .27232 .53637 L .27014 .54312 L F
0 g
.26997 .54917 m
.27014 .54312 L
s
.2382 .54009 m
.23912 .53369 L
s
.2382 .54009 m
.23912 .53369 L
s
.2382 .54009 m
.24409 .54544 L
s
.28844 .52444 m .28906 .51912 L .28997 .52059 L .943 .684 .516 r
F
.28941 .52576 m .28844 .52444 L .28997 .52059 L F
0 g
.31239 .50416 m
.32936 .4884 L
s
.31239 .50416 m
.30992 .50683 L
s
.29938 .60477 m
.29994 .59762 L
s
.039 .916 .04 r
.28222 .5433 m
.29313 .53984 L
s
0 0 0 r
2 Mabswid
.28222 .5433 Mdot
0 g
.5 Mabswid
.27423 .52634 m
.27599 .52576 L
s
.27423 .52634 m
.27304 .53108 L
s
.29938 .60477 m
.30314 .60777 L
s
.32868 .60437 m
.3324 .6058 L
s
.3324 .6058 m
.34169 .60286 L
s
.33915 .54423 m .34861 .54003 L .35427 .5454 L .647 .745 .92 r
F
0 0 0 r
2 Mabswid
.35427 .5454 Mdot
.039 .916 .04 r
.5 Mabswid
.34423 .54867 m
.35427 .5454 L
s
0 g
.35427 .5454 m
.35483 .53686 L
s
.35427 .5454 m
.3599 .55075 L
s
.31774 .60705 m .314 .60647 L .31398 .60481 L .943 .684 .516 r
F
.31774 .60705 m .3179 .60879 L .314 .60647 L F
.34345 .55601 m .35314 .5626 L .3421 .56356 L .528 .308 .524 r
F
.34345 .55601 m .3537 .55398 L .35314 .5626 L F
0 g
.34345 .55601 m
.34423 .54867 L
s
.3537 .55398 m
.35427 .5454 L
s
.28747 .52311 m .28815 .51764 L .28906 .51912 L .943 .684 .516 r
F
.28844 .52444 m .28747 .52311 L .28906 .51912 L F
.42392 .47826 m .44402 .48634 L .42357 .49309 L .528 .308 .524 r
F
.42392 .47826 m .44205 .47223 L .44402 .48634 L F
0 g
.42392 .47826 m
.42409 .46359 L
s
.439 .4586 m
.44205 .47223 L
s
.1839 .53384 m
.18547 .52392 L
s
.27479 .53049 m
.27599 .52576 L
s
.32263 .57697 m .33758 .57932 L .32211 .58428 L .528 .308 .524 r
F
.32263 .57697 m .34015 .57133 L .33758 .57932 L F
0 g
.32263 .57697 m
.32316 .56968 L
s
.40135 .41864 m
.40687 .41675 L
s
.40135 .41864 m
.39414 .4167 L
s
.3179 .60879 m .31402 .60814 L .314 .60647 L .943 .684 .516 r
F
.3179 .60879 m .31806 .61053 L .31402 .60814 L F
0 g
.31806 .61053 m
.32199 .61203 L
s
.33348 .53997 m .34861 .54003 L .33915 .54423 L .647 .745 .92 r
F
0 g
.33915 .54423 m
.34423 .54867 L
s
.039 .916 .04 r
.3175 .54891 m
.33705 .54258 L
s
0 g
.30066 .50992 m
.30992 .50683 L
s
.30066 .50992 m
.29857 .51339 L
s
.2865 .52178 m .28724 .51617 L .28815 .51764 L .943 .684 .516 r
F
.28747 .52311 m .2865 .52178 L .28815 .51764 L F
0 g
.41046 .4923 m
.41423 .5026 L
s
.47318 .61738 m
.46864 .62346 L
s
.25988 .61347 m
.26427 .61879 L
s
.26427 .61879 m
.29391 .60159 L
s
.26427 .61879 m
.25988 .61347 L
s
.22446 .65623 m
.26427 .61879 L
s
.3139 .59818 m .31055 .59711 L .31067 .59556 L .943 .684 .516 r
F
.3139 .59818 m .31392 .59983 L .31055 .59711 L F
0 g
.3139 .59818 m
.31712 .60011 L
s
.28553 .52045 m .28633 .51469 L .28724 .51617 L .943 .684 .516 r
F
.2865 .52178 m .28553 .52045 L .28724 .51617 L F
0 0 0 r
2 Mabswid
.31077 .54263 Mdot
0 g
.5 Mabswid
.23789 .54706 m
.2382 .54009 L
s
.1839 .53384 m
.2382 .54009 L
s
.23788 .54706 m
.2382 .54009 L
s
.28936 .5312 m .28941 .52576 L .29037 .52709 L .943 .684 .516 r
F
0 g
.29037 .52709 m
.29178 .52354 L
s
.28553 .52045 m .28456 .51912 L .28633 .51469 L .943 .684 .516 r
F
0 g
.28633 .51469 m
.28856 .51103 L
s
.31392 .59983 m .31043 .59866 L .31055 .59711 L .943 .684 .516 r
F
.31392 .59983 m .31394 .60149 L .31043 .59866 L F
0 g
.37222 .60579 m
.36833 .60618 L
s
0 0 0 r
2 Mabswid
.33705 .54258 Mdot
.3097 .54162 m .32719 .53588 L .33348 .53997 L .647 .745 .92 r
F
.30482 .53707 m .32719 .53588 L .3097 .54162 L F
0 g
.5 Mabswid
.3097 .54162 m
.31455 .54616 L
s
.39968 .41479 m
.40687 .41675 L
s
.28835 .53004 m .28844 .52444 L .28941 .52576 L .943 .684 .516 r
F
.28936 .5312 m .28835 .53004 L .28941 .52576 L F
.31394 .60149 m .31032 .60021 L .31043 .59866 L F
.31394 .60149 m .31396 .60315 L .31032 .60021 L F
.44152 .54254 m .462 .53596 L .4689 .54634 L .647 .745 .92 r
F
.039 .916 .04 r
.4311 .54872 m
.44356 .54465 L
s
0 g
.4689 .54634 m
.47463 .55698 L
s
.29762 .60533 m
.29938 .60477 L
s
.29391 .60159 m
.29762 .60533 L
s
.27232 .53637 m .27408 .53579 L .27889 .54023 L .647 .745 .92 r
F
0 g
.27408 .53579 m
.27889 .54023 L
s
.2382 .54009 m
.27232 .53637 L
s
.27014 .54312 m
.27232 .53637 L
s
.27889 .54023 m
.28368 .54466 L
s
.17489 .67598 m
.18361 .68607 L
s
.18361 .68607 m
.18755 .68485 L
s
.32936 .4884 m
.33268 .48626 L
s
.28734 .52888 m .28747 .52311 L .28844 .52444 L .943 .684 .516 r
F
.28835 .53004 m .28734 .52888 L .28844 .52444 L F
.31396 .60315 m .3102 .60177 L .31032 .60021 L F
.31396 .60315 m .31398 .60481 L .3102 .60177 L F
0 g
.33799 .60142 m
.34169 .60286 L
s
.34169 .60286 m
.36417 .60552 L
s
.27304 .53108 m
.27479 .53049 L
s
.27232 .53637 m
.27304 .53108 L
s
.29568 .60102 m
.29938 .60477 L
s
.37222 .60747 m
.37626 .60707 L
s
.37626 .60707 m
.40418 .62128 L
s
.3421 .56356 m .35257 .57124 L .34015 .57133 L .528 .308 .524 r
F
.3421 .56356 m .35314 .5626 L .35257 .57124 L F
0 g
.3421 .56356 m
.34345 .55601 L
s
0 0 0 r
2 Mabswid
.29313 .53984 Mdot
.44356 .54465 Mdot
.28632 .52773 m .2865 .52178 L .28747 .52311 L .943 .684 .516 r
F
.28734 .52888 m .28632 .52773 L .28747 .52311 L F
.31398 .60481 m .31009 .60332 L .3102 .60177 L F
.31398 .60481 m .314 .60647 L .31009 .60332 L F
0 g
.5 Mabswid
.27408 .53579 m
.27479 .53049 L
s
.38123 .53663 m .42321 .533 L .38648 .54241 L .647 .745 .92 r
F
.38648 .54241 m .42321 .533 L .42828 .5413 L F
0 g
.38648 .54241 m
.39056 .54852 L
s
.039 .916 .04 r
.39124 .54981 m
.42781 .54034 L
s
0 g
.42828 .5413 m
.43146 .55014 L
s
.30992 .50683 m
.32646 .49154 L
s
.30992 .50683 m
.30783 .5103 L
s
.32487 .60209 m
.32868 .60437 L
s
.32868 .60437 m
.33799 .60142 L
s
.13323 .53415 m
.13714 .53282 L
s
.13233 .5476 m
.13323 .53415 L
s
.32211 .58428 m .33434 .58754 L .32157 .59162 L .528 .308 .524 r
F
.32211 .58428 m .33758 .57932 L .33434 .58754 L F
0 g
.32211 .58428 m
.32263 .57697 L
s
.25571 .60741 m
.25988 .61347 L
s
.25988 .61347 m
.29032 .59716 L
s
.25988 .61347 m
.25571 .60741 L
s
.21754 .64803 m
.25988 .61347 L
s
.31067 .59556 m .30722 .59372 L .30747 .5923 L .943 .684 .516 r
F
.31067 .59556 m .31055 .59711 L .30722 .59372 L F
0 g
.31067 .59556 m
.3139 .59818 L
s
.35314 .5626 m
.3537 .55398 L
s
.33517 .48286 m
.34919 .45502 L
s
.33517 .48286 m
.33173 .48508 L
s
.18755 .68485 m
.17884 .67474 L
s
.40903 .61926 m
.40418 .62128 L
s
.28531 .52657 m .28553 .52045 L .2865 .52178 L .943 .684 .516 r
F
.28632 .52773 m .28531 .52657 L .2865 .52178 L F
.314 .60647 m .30997 .60488 L .31009 .60332 L F
.314 .60647 m .31402 .60814 L .30997 .60488 L F
0 g
.31402 .60814 m
.31806 .61053 L
s
.33348 .53997 m .34293 .53463 L .34861 .54003 L .647 .745 .92 r
F
0 g
.34861 .54003 m
.35427 .5454 L
s
.32719 .53588 m .34293 .53463 L .33348 .53997 L .647 .745 .92 r
F
.039 .916 .04 r
.33705 .54258 m
.34767 .53914 L
s
0 g
.33348 .53997 m
.33915 .54423 L
s
.3812 .52792 m .41638 .52519 L .38123 .53663 L .528 .308 .524 r
F
.3812 .52792 m .41616 .51358 L .41638 .52519 L F
0 g
.38003 .51962 m
.3812 .52792 L
s
.23789 .54706 m
.2721 .54214 L
s
.23789 .54706 m
.23818 .55448 L
s
.18329 .54467 m
.23788 .54706 L
s
.23788 .54706 m
.23818 .55448 L
s
.28876 .53579 m .28835 .53004 L .28936 .5312 L .943 .684 .516 r
F
0 g
.28936 .5312 m
.29037 .52709 L
s
.29857 .51339 m
.30783 .5103 L
s
.29857 .51339 m
.29691 .51759 L
s
.31055 .59711 m .30697 .59513 L .30722 .59372 L .943 .684 .516 r
F
.31055 .59711 m .31043 .59866 L .30697 .59513 L F
0 g
.21754 .64803 m
.22446 .65623 L
s
.28429 .52541 m .28456 .51912 L .28553 .52045 L .943 .684 .516 r
F
.28531 .52657 m .28429 .52541 L .28553 .52045 L F
0 g
.13625 .54628 m
.13714 .53282 L
s
.28772 .53482 m .28734 .52888 L .28835 .53004 L .943 .684 .516 r
F
.28876 .53579 m .28772 .53482 L .28835 .53004 L F
.43208 .5329 m .462 .53596 L .44152 .54254 L .647 .745 .92 r
F
.039 .916 .04 r
.44356 .54465 m
.46365 .53826 L
s
0 g
.44152 .54254 m
.45072 .55214 L
s
.34919 .45502 m
.35423 .45356 L
s
.29032 .59716 m
.29391 .60159 L
s
.29391 .60159 m
.29568 .60102 L
s
.31043 .59866 m .30671 .59655 L .30697 .59513 L .943 .684 .516 r
F
.31043 .59866 m .31032 .60021 L .30671 .59655 L F
.28429 .52541 m .28328 .52425 L .28456 .51912 L F
0 g
.28456 .51912 m
.28633 .51469 L
s
0 0 0 r
2 Mabswid
.34767 .53914 Mdot
0 g
.5 Mabswid
.18329 .54467 m
.1839 .53384 L
s
.27232 .53637 m
.27408 .53579 L
s
.2721 .54214 m
.27232 .53637 L
s
.28668 .53386 m .28632 .52773 L .28734 .52888 L .943 .684 .516 r
F
.28772 .53482 m .28668 .53386 L .28734 .52888 L F
0 g
.29568 .60102 m
.29208 .59659 L
s
.31032 .60021 m .30646 .59797 L .30671 .59655 L .943 .684 .516 r
F
.31032 .60021 m .3102 .60177 L .30646 .59797 L F
.30482 .53707 m .32027 .53198 L .32719 .53588 L .647 .745 .92 r
F
.29992 .53249 m .32027 .53198 L .30482 .53707 L F
0 g
.30482 .53707 m
.3097 .54162 L
s
.039 .916 .04 r
.31077 .54263 m
.32874 .53683 L
s
.29313 .53984 m
.30408 .53637 L
s
.34015 .57133 m .352 .57993 L .33758 .57932 L .528 .308 .524 r
F
.34015 .57133 m .35257 .57124 L .352 .57993 L F
0 g
.34015 .57133 m
.3421 .56356 L
s
.25184 .60071 m
.25571 .60741 L
s
.25571 .60741 m
.28689 .59212 L
s
.25571 .60741 m
.25184 .60072 L
s
.21097 .63866 m
.25571 .60741 L
s
.27386 .54156 m
.27408 .53579 L
s
.30747 .5923 m .30398 .58971 L .30436 .58845 L .943 .684 .516 r
F
.30747 .5923 m .30722 .59372 L .30398 .58971 L F
0 g
.30747 .5923 m
.31067 .59556 L
s
.28564 .53289 m .28531 .52657 L .28632 .52773 L .943 .684 .516 r
F
.28668 .53386 m .28564 .53289 L .28632 .52773 L F
.039 .916 .04 r
.42781 .54034 m
.43658 .53747 L
s
0 0 0 r
2 Mabswid
.30408 .53637 Mdot
0 g
.5 Mabswid
.23818 .55448 m
.27238 .54828 L
s
.23818 .55448 m
.23908 .56221 L
s
.18364 .55622 m
.23818 .55448 L
s
.23908 .56221 m
.23818 .55448 L
s
.28858 .54078 m .28772 .53482 L .28876 .53579 L .943 .684 .516 r
F
0 g
.28876 .53579 m
.28936 .5312 L
s
.3102 .60177 m .30621 .59939 L .30646 .59797 L .943 .684 .516 r
F
.3102 .60177 m .31009 .60332 L .30621 .59939 L F
0 g
.33419 .59912 m
.33799 .60142 L
s
.33799 .60142 m
.35982 .60381 L
s
.36833 .60618 m
.36417 .60552 L
s
0 0 0 r
2 Mabswid
.32874 .53683 Mdot
.30722 .59372 m .3036 .59096 L .30398 .58971 L .943 .684 .516 r
F
.30722 .59372 m .30697 .59513 L .3036 .59096 L F
.32157 .59162 m .33037 .59601 L .32104 .59898 L .528 .308 .524 r
F
.32157 .59162 m .33434 .58754 L .33037 .59601 L F
0 g
.5 Mabswid
.32157 .59162 m
.32211 .58428 L
s
.32104 .59898 m
.32157 .59162 L
s
.2846 .53193 m .28429 .52541 L .28531 .52657 L .943 .684 .516 r
F
.28564 .53289 m .2846 .53193 L .28531 .52657 L F
0 g
.45771 .62958 m
.46304 .62518 L
s
.46304 .62518 m
.46864 .62346 L
s
.32104 .59898 m
.32487 .60209 L
s
.32487 .60209 m
.33419 .59912 L
s
.30783 .5103 m
.32402 .49562 L
s
.30783 .5103 m
.30619 .5145 L
s
.42357 .49309 m .44493 .50092 L .42307 .50808 L .528 .308 .524 r
F
.42357 .49309 m .44402 .48634 L .44493 .50092 L F
0 g
.42357 .49309 m
.42392 .47826 L
s
.44205 .47223 m
.44402 .48634 L
s
.31009 .60332 m .30596 .60081 L .30621 .59939 L .943 .684 .516 r
F
.31009 .60332 m .30997 .60488 L .30596 .60081 L F
0 g
.30997 .60488 m
.31402 .60814 L
s
.28754 .54003 m .28668 .53386 L .28772 .53482 L .943 .684 .516 r
F
.28858 .54078 m .28754 .54003 L .28772 .53482 L F
0 g
.32646 .49154 m
.32936 .4884 L
s
.41423 .5026 m
.41616 .51358 L
s
.28689 .59212 m
.29032 .59716 L
s
.29032 .59716 m
.29208 .59659 L
s
.32719 .53588 m .33722 .52921 L .34293 .53463 L .647 .745 .92 r
F
0 g
.34293 .53463 m
.34861 .54003 L
s
.32027 .53198 m .33722 .52921 L .32719 .53588 L .647 .745 .92 r
F
0 g
.32719 .53588 m
.33348 .53997 L
s
.039 .916 .04 r
.32874 .53683 m
.34107 .53287 L
s
0 g
.29691 .51759 m
.30619 .5145 L
s
.29691 .51759 m
.29571 .52245 L
s
.30697 .59513 m .30322 .59222 L .3036 .59096 L .943 .684 .516 r
F
.30697 .59513 m .30671 .59655 L .30322 .59222 L F
0 g
.35257 .57124 m
.35314 .5626 L
s
.28356 .53096 m .28328 .52425 L .28429 .52541 L .943 .684 .516 r
F
.2846 .53193 m .28356 .53096 L .28429 .52541 L F
0 g
.36791 .60678 m
.37222 .60747 L
s
.37222 .60747 m
.39886 .62186 L
s
.2721 .54214 m
.27386 .54156 L
s
.2721 .54214 m
.27238 .54828 L
s
.24833 .59351 m
.25184 .60071 L
s
.25184 .60071 m
.28371 .58657 L
s
.25184 .60072 m
.24833 .59351 L
s
.20486 .62827 m
.25184 .60072 L
s
.29208 .59659 m
.28866 .59155 L
s
.28649 .53927 m .28564 .53289 L .28668 .53386 L .943 .684 .516 r
F
.28754 .54003 m .28649 .53927 L .28668 .53386 L F
0 g
.16663 .6644 m
.17489 .67598 L
s
.17489 .67598 m
.17884 .67474 L
s
.23908 .56221 m
.27315 .55468 L
s
.23908 .56221 m
.24058 .57012 L
s
.18498 .56828 m
.23908 .56221 L
s
.24058 .57012 m
.23908 .56221 L
s
.30436 .58845 m .30091 .58515 L .30141 .58408 L .943 .684 .516 r
F
.30436 .58845 m .30398 .58971 L .30091 .58515 L F
0 g
.30436 .58845 m
.30747 .5923 L
s
.38123 .53663 m .41493 .53742 L .38014 .54574 L .528 .308 .524 r
F
.38123 .53663 m .41638 .52519 L .42321 .533 L .647 .745 .92 r
F
.38123 .53663 m .41638 .52519 L .41493 .53742 L .528 .308 .524 r
F
0 g
.42321 .533 m
.42828 .5413 L
s
.37484 .53119 m .41638 .52519 L .38123 .53663 L .647 .745 .92 r
F
0 0 0 r
2 Mabswid
.38123 .53663 Mdot
0 g
.5 Mabswid
.3812 .52792 m
.38121 .53027 L
s
.039 .916 .04 r
.35427 .5454 m
.38123 .53663 L
s
0 g
.27414 .5477 m
.27386 .54156 L
s
.28356 .53096 m .28252 .52999 L .28328 .52425 L .943 .684 .516 r
F
0 g
.28328 .52425 m
.28456 .51912 L
s
.39414 .4167 m
.39968 .41479 L
s
.39414 .4167 m
.3873 .41657 L
s
.33758 .57932 m .35143 .58865 L .33434 .58754 L .528 .308 .524 r
F
.33758 .57932 m .352 .57993 L .35143 .58865 L F
0 g
.33758 .57932 m
.34015 .57133 L
s
.30671 .59655 m .30284 .59348 L .30322 .59222 L .943 .684 .516 r
F
.30671 .59655 m .30646 .59797 L .30284 .59348 L F
.28884 .5461 m .28754 .54003 L .28858 .54078 L F
0 g
.28858 .54078 m
.28876 .53579 L
s
.33173 .48508 m
.34463 .4579 L
s
.33173 .48508 m
.32872 .48834 L
s
.46864 .62346 m
.46333 .62786 L
s
.28544 .53852 m .2846 .53193 L .28564 .53289 L .943 .684 .516 r
F
.28649 .53927 m .28544 .53852 L .28564 .53289 L F
0 g
.21097 .63866 m
.21754 .64803 L
s
.13233 .5476 m
.13625 .54628 L
s
.13233 .5476 m
.13266 .56196 L
s
.30398 .58971 m .3004 .58623 L .30091 .58515 L .943 .684 .516 r
F
.30398 .58971 m .3036 .59096 L .3004 .58623 L F
0 g
.24525 .58591 m
.24833 .59351 L
s
.24833 .59351 m
.28082 .58059 L
s
.24833 .59351 m
.24524 .58591 L
s
.19934 .61706 m
.24833 .59351 L
s
.039 .916 .04 r
.46365 .53826 m
.89618 .36901 L
s
0 0 0 r
2 Mabswid
.46365 .53826 Mdot
.30646 .59797 m .30245 .59474 L .30284 .59348 L .943 .684 .516 r
F
.30646 .59797 m .30621 .59939 L .30245 .59474 L F
0 g
.5 Mabswid
.24058 .57012 m
.27441 .56123 L
s
.24058 .57012 m
.24265 .57807 L
s
.18726 .58062 m
.24058 .57012 L
s
.24265 .57807 m
.24058 .57012 L
s
.2878 .54557 m .28649 .53927 L .28754 .54003 L .943 .684 .516 r
F
.28884 .5461 m .2878 .54557 L .28754 .54003 L F
0 g
.17884 .67474 m
.17058 .66315 L
s
.28371 .58657 m
.28689 .59212 L
s
.28689 .59212 m
.28866 .59155 L
s
.18329 .54467 m
.18364 .55622 L
s
.29992 .53249 m .31266 .52828 L .32027 .53198 L .647 .745 .92 r
F
.29501 .5279 m .31266 .52828 L .29992 .53249 L F
0 g
.29992 .53249 m
.30482 .53707 L
s
.28439 .53776 m .28356 .53096 L .2846 .53193 L .943 .684 .516 r
F
.28544 .53852 m .28439 .53776 L .2846 .53193 L F
0 g
.27238 .54828 m
.27414 .5477 L
s
.27238 .54828 m
.27315 .55468 L
s
.24265 .57807 m
.24525 .58591 L
s
.24525 .58591 m
.27828 .5743 L
s
.24524 .58591 m
.24265 .57807 L
s
.19451 .60524 m
.24524 .58591 L
s
.24265 .57807 m
.27613 .56781 L
s
.19046 .59301 m
.24265 .57807 L
s
.30141 .58408 m .29804 .58013 L .29866 .57927 L .943 .684 .516 r
F
.30141 .58408 m .30091 .58515 L .29804 .58013 L F
0 g
.30141 .58408 m
.30436 .58845 L
s
.3036 .59096 m .29989 .5873 L .3004 .58623 L .943 .684 .516 r
F
.3036 .59096 m .30322 .59222 L .29989 .5873 L F
0 g
.33419 .59912 m
.35536 .60109 L
s
.28866 .59155 m
.28548 .586 L
s
.30621 .59939 m .30207 .596 L .30245 .59474 L .943 .684 .516 r
F
.30621 .59939 m .30596 .60081 L .30207 .596 L F
0 g
.30596 .60081 m
.30997 .60488 L
s
.28952 .55164 m .2878 .54557 L .28884 .5461 L .943 .684 .516 r
F
0 g
.28858 .54078 m
.28884 .5461 L
s
.39286 .41466 m
.39968 .41479 L
s
.31725 .59511 m
.32104 .59898 L
s
.13659 .56065 m
.13625 .54628 L
s
.28676 .54504 m .28544 .53852 L .28649 .53927 L .943 .684 .516 r
F
.2878 .54557 m .28676 .54504 L .28649 .53927 L F
0 g
.27492 .5541 m
.27414 .5477 L
s
.40418 .62128 m
.39886 .62186 L
s
0 0 0 r
2 Mabswid
.34107 .53287 Mdot
0 g
.5 Mabswid
.30619 .5145 m
.305 .51937 L
s
.28334 .537 m .28252 .52999 L .28356 .53096 L .943 .684 .516 r
F
.28439 .53776 m .28334 .537 L .28356 .53096 L F
.32027 .53198 m .33148 .52377 L .33722 .52921 L .647 .745 .92 r
F
0 g
.33722 .52921 m
.34293 .53463 L
s
.31266 .52828 m .33148 .52377 L .32027 .53198 L .647 .745 .92 r
F
0 g
.32027 .53198 m
.32719 .53588 L
s
.039 .916 .04 r
.30408 .53637 m
.31929 .53147 L
s
0 g
.29571 .52245 m
.305 .51937 L
s
.30322 .59222 m .29938 .58837 L .29989 .5873 L .943 .684 .516 r
F
.30322 .59222 m .30284 .59348 L .29938 .58837 L F
.30091 .58515 m .29742 .581 L .29804 .58013 L F
.30091 .58515 m .3004 .58623 L .29742 .581 L F
.33434 .58754 m .35086 .5974 L .33037 .59601 L .528 .308 .524 r
F
0 g
.32104 .59898 m
.33037 .59601 L
s
.33037 .59601 m
.33419 .59912 L
s
.33434 .58754 m .35143 .58865 L .35086 .5974 L .528 .308 .524 r
F
0 g
.33434 .58754 m
.33758 .57932 L
s
.33037 .59601 m
.33434 .58754 L
s
.28082 .58059 m
.28371 .58657 L
s
.28371 .58657 m
.28548 .586 L
s
.36417 .60552 m
.35982 .60381 L
s
0 0 0 r
2 Mabswid
.31929 .53147 Mdot
.28851 .55135 m .28676 .54504 L .2878 .54557 L .943 .684 .516 r
F
.28952 .55164 m .28851 .55135 L .2878 .54557 L F
.43208 .5329 m .45395 .52583 L .462 .53596 L .647 .745 .92 r
F
0 g
.5 Mabswid
.462 .53596 m
.4689 .54634 L
s
.27315 .55468 m
.27441 .56123 L
s
.27492 .5541 m
.27315 .55468 L
s
.28572 .54451 m .28439 .53776 L .28544 .53852 L .943 .684 .516 r
F
.28676 .54504 m .28572 .54451 L .28544 .53852 L F
.29866 .57927 m .29544 .57474 L .29617 .57409 L F
.29866 .57927 m .29804 .58013 L .29544 .57474 L F
0 g
.29866 .57927 m
.30141 .58408 L
s
.28334 .537 m .28229 .53625 L .28252 .52999 L .943 .684 .516 r
F
0 g
.28252 .52999 m
.28328 .52425 L
s
.29062 .55731 m .28851 .55135 L .28952 .55164 L .943 .684 .516 r
F
0 g
.28884 .5461 m
.28952 .55164 L
s
.34463 .4579 m
.34919 .45502 L
s
.28548 .586 m
.28259 .58002 L
s
.352 .57993 m
.35257 .57124 L
s
.30284 .59348 m .29887 .58945 L .29938 .58837 L .943 .684 .516 r
F
.30284 .59348 m .30245 .59474 L .29887 .58945 L F
0 g
.27617 .56065 m
.27492 .5541 L
s
.3004 .58623 m .29679 .58187 L .29742 .581 L .943 .684 .516 r
F
.3004 .58623 m .29989 .5873 L .29679 .58187 L F
0 g
.32402 .49562 m
.32646 .49154 L
s
.27828 .5743 m
.28082 .58059 L
s
.28082 .58059 m
.28259 .58002 L
s
.2875 .55105 m .28572 .54451 L .28676 .54504 L .943 .684 .516 r
F
.28851 .55135 m .2875 .55105 L .28676 .54504 L F
.28468 .54397 m .28334 .537 L .28439 .53776 L F
.28572 .54451 m .28468 .54397 L .28439 .53776 L F
.29617 .57409 m .29315 .56906 L .29397 .56864 L F
.29617 .57409 m .29544 .57474 L .29315 .56906 L F
0 g
.29617 .57409 m
.29866 .57927 L
s
.27441 .56123 m
.27617 .56065 L
s
.27441 .56123 m
.27613 .56781 L
s
.38014 .54574 m .41174 .55026 L .3779 .55526 L .528 .308 .524 r
F
.38014 .54574 m .41493 .53742 L .41174 .55026 L F
0 g
.38014 .54574 m
.38123 .53663 L
s
.29804 .58013 m .29471 .57539 L .29544 .57474 L .943 .684 .516 r
F
.29804 .58013 m .29742 .581 L .29471 .57539 L F
.29062 .55731 m .28965 .55726 L .28851 .55135 L F
.29211 .56301 m .28965 .55726 L .29062 .55731 L F
0 g
.28952 .55164 m
.29062 .55731 L
s
.28965 .55726 m .2875 .55105 L .28851 .55135 L .943 .684 .516 r
F
0 g
.3634 .60502 m
.36791 .60678 L
s
.36791 .60678 m
.39317 .62099 L
s
.27613 .56781 m
.27828 .5743 L
s
.27828 .5743 m
.28004 .57373 L
s
.28259 .58002 m
.28004 .57373 L
s
.29397 .56864 m .29121 .56319 L .29211 .56301 L .943 .684 .516 r
F
.29397 .56864 m .29315 .56906 L .29121 .56319 L F
0 g
.29397 .56864 m
.29617 .57409 L
s
.30245 .59474 m .29837 .59052 L .29887 .58945 L .943 .684 .516 r
F
.30245 .59474 m .30207 .596 L .29837 .59052 L F
0 g
.30207 .596 m
.30596 .60081 L
s
.27613 .56781 m
.27789 .56723 L
s
.29211 .56301 m .29121 .56319 L .28965 .55726 L .943 .684 .516 r
F
0 g
.29211 .56301 m
.29397 .56864 L
s
.29062 .55731 m
.29211 .56301 L
s
.20486 .62827 m
.21097 .63866 L
s
.27789 .56723 m
.27617 .56065 L
s
.15896 .65154 m
.16663 .6644 L
s
.16663 .6644 m
.17058 .66315 L
s
.29989 .5873 m .29617 .58274 L .29679 .58187 L .943 .684 .516 r
F
.29989 .5873 m .29938 .58837 L .29617 .58274 L F
.37484 .53119 m .40783 .51788 L .41638 .52519 L .647 .745 .92 r
F
.36727 .5261 m .40783 .51788 L .37484 .53119 L F
0 g
.37484 .53119 m
.38123 .53663 L
s
.039 .916 .04 r
.34767 .53914 m
.37412 .53066 L
s
.42239 .52324 m .45395 .52583 L .43208 .5329 L .647 .745 .92 r
F
0 g
.41638 .52519 m
.42321 .533 L
s
.43208 .5329 m
.44152 .54254 L
s
.039 .916 .04 r
.43658 .53747 m
.45793 .53062 L
s
.41525 .53475 m
.42286 .53253 L
s
.28364 .54344 m .28229 .53625 L .28334 .537 L .943 .684 .516 r
F
.28468 .54397 m .28364 .54344 L .28334 .537 L F
.28649 .55075 m .28468 .54397 L .28572 .54451 L F
.2875 .55105 m .28649 .55075 L .28572 .54451 L F
.039 .916 .04 r
.42286 .53253 m
.42954 .53035 L
s
0 g
.31358 .59054 m
.31725 .59511 L
s
.31725 .59511 m
.32659 .59213 L
s
.28004 .57373 m
.27789 .56723 L
s
.32659 .59213 m
.33037 .59601 L
s
.33037 .59601 m
.35086 .5974 L
s
.29544 .57474 m .29233 .56948 L .29315 .56906 L .943 .684 .516 r
F
.29544 .57474 m .29471 .57539 L .29233 .56948 L F
0 g
.18364 .55622 m
.18498 .56828 L
s
.29742 .581 m .29398 .57604 L .29471 .57539 L .943 .684 .516 r
F
.29742 .581 m .29679 .58187 L .29398 .57604 L F
.28965 .55726 m .28869 .5572 L .2875 .55105 L F
.29121 .56319 m .28869 .5572 L .28965 .55726 L F
0 0 0 r
2 Mabswid
.37412 .53066 Mdot
0 g
.5 Mabswid
.32872 .48834 m
.34064 .46218 L
s
.32872 .48834 m
.32619 .49257 L
s
.28869 .5572 m .28649 .55075 L .2875 .55105 L .943 .684 .516 r
F
0 g
.13266 .56196 m
.13659 .56065 L
s
.13266 .56196 m
.13423 .57696 L
s
.29501 .5279 m .30431 .52482 L .31266 .52828 L .647 .745 .92 r
F
0 g
.29501 .5279 m
.29571 .52245 L
s
.29501 .5279 m
.29992 .53249 L
s
.29481 .53383 m
.29501 .5279 L
s
.41616 .51358 m
.41638 .52519 L
s
.29315 .56906 m .29031 .56338 L .29121 .56319 L .943 .684 .516 r
F
.29315 .56906 m .29233 .56948 L .29031 .56338 L F
.31266 .52828 m .32572 .51829 L .33148 .52377 L .647 .745 .92 r
F
0 g
.33148 .52377 m
.33722 .52921 L
s
.30431 .52482 m .32572 .51829 L .31266 .52828 L .647 .745 .92 r
F
.039 .916 .04 r
.31929 .53147 m
.33449 .52662 L
s
0 g
.31266 .52828 m
.32027 .53198 L
s
.29121 .56319 m .29031 .56338 L .28869 .5572 L .943 .684 .516 r
F
.29938 .58837 m .29554 .58362 L .29617 .58274 L F
.29938 .58837 m .29887 .58945 L .29554 .58362 L F
.28364 .54344 m .2826 .54291 L .28229 .53625 L F
0 g
.28229 .53625 m
.28252 .52999 L
s
.28548 .55045 m .28364 .54344 L .28468 .54397 L .943 .684 .516 r
F
.28649 .55075 m .28548 .55045 L .28468 .54397 L F
0 g
.17058 .66315 m
.16291 .65028 L
s
.42307 .50808 m .44477 .51596 L .42239 .52324 L .528 .308 .524 r
F
.42307 .50808 m .44493 .50092 L .44477 .51596 L F
0 g
.42307 .50808 m
.42357 .49309 L
s
.44402 .48634 m
.44493 .50092 L
s
.29471 .57539 m .2915 .5699 L .29233 .56948 L .943 .684 .516 r
F
.29471 .57539 m .29398 .57604 L .2915 .5699 L F
.29679 .58187 m .29325 .57669 L .29398 .57604 L F
.29679 .58187 m .29617 .58274 L .29325 .57669 L F
.28869 .5572 m .28772 .55714 L .28649 .55075 L F
.29031 .56338 m .28772 .55714 L .28869 .5572 L F
.28772 .55714 m .28548 .55045 L .28649 .55075 L F
.29887 .58945 m .29492 .58449 L .29554 .58362 L F
.29887 .58945 m .29837 .59052 L .29492 .58449 L F
0 g
.29837 .59052 m
.30207 .596 L
s
.13816 .57565 m
.13659 .56065 L
s
.29233 .56948 m .2894 .56356 L .29031 .56338 L .943 .684 .516 r
F
.29233 .56948 m .2915 .5699 L .2894 .56356 L F
.29031 .56338 m .2894 .56356 L .28772 .55714 L F
.28446 .55015 m .2826 .54291 L .28364 .54344 L F
.28548 .55045 m .28446 .55015 L .28364 .54344 L F
.29617 .58274 m .29252 .57734 L .29325 .57669 L F
.29617 .58274 m .29554 .58362 L .29252 .57734 L F
.29398 .57604 m .29068 .57032 L .2915 .5699 L F
.29398 .57604 m .29325 .57669 L .29068 .57032 L F
0 g
.45167 .63221 m
.45771 .62958 L
s
.45771 .62958 m
.46333 .62786 L
s
.28772 .55714 m .28676 .55708 L .28548 .55045 L .943 .684 .516 r
F
.2894 .56356 m .28676 .55708 L .28772 .55714 L F
0 g
.35982 .60381 m
.35536 .60109 L
s
.28676 .55708 m .28446 .55015 L .28548 .55045 L .943 .684 .516 r
F
0 g
.35143 .58865 m
.352 .57993 L
s
.19934 .61706 m
.20486 .62827 L
s
.31007 .58534 m
.31358 .59054 L
s
.31358 .59054 m
.32292 .58755 L
s
.039 .916 .04 r
.45793 .53062 m
.89619 .36903 L
s
0 0 0 r
2 Mabswid
.45793 .53062 Mdot
.33449 .52662 Mdot
.3779 .55526 m .40666 .56376 L .37441 .56521 L .528 .308 .524 r
F
.3779 .55526 m .41174 .55026 L .40666 .56376 L F
0 g
.5 Mabswid
.3779 .55526 m
.38014 .54574 L
s
.2915 .5699 m .2885 .56374 L .2894 .56356 L .943 .684 .516 r
F
.2915 .5699 m .29068 .57032 L .2885 .56374 L F
.2894 .56356 m .2885 .56374 L .28676 .55708 L F
0 g
.18498 .56828 m
.18726 .58062 L
s
.29481 .53383 m
.30412 .53076 L
s
.29481 .53383 m
.29512 .54015 L
s
.28446 .55015 m .28345 .54985 L .2826 .54291 L .943 .684 .516 r
F
0 g
.28229 .53625 m
.2826 .54291 L
s
.32292 .58755 m
.32659 .59213 L
s
.32659 .59213 m
.3464 .59279 L
s
.3221 .50058 m
.32402 .49562 L
s
.29554 .58362 m .29178 .578 L .29252 .57734 L .943 .684 .516 r
F
.29554 .58362 m .29492 .58449 L .29178 .578 L F
0 g
.29492 .58449 m
.29837 .59052 L
s
.15204 .63763 m
.15896 .65154 L
s
.15896 .65154 m
.16291 .65028 L
s
.29325 .57669 m .28985 .57074 L .29068 .57032 L .943 .684 .516 r
F
.29325 .57669 m .29252 .57734 L .28985 .57074 L F
.28676 .55708 m .28579 .55702 L .28446 .55015 L F
.2885 .56374 m .28579 .55702 L .28676 .55708 L F
.30431 .52482 m .31993 .5128 L .32572 .51829 L .647 .745 .92 r
F
0 g
.30431 .52482 m
.31993 .5128 L
s
.29501 .5279 m
.30431 .52482 L
s
.30431 .52482 m
.305 .51937 L
s
.30431 .52482 m
.31266 .52828 L
s
.305 .51937 m
.32073 .50634 L
s
.30619 .5145 m
.3221 .50058 L
s
.30412 .53076 m
.30431 .52482 L
s
.28579 .55702 m .28345 .54985 L .28446 .55015 L .943 .684 .516 r
F
0 g
.3873 .41657 m
.39286 .41466 L
s
.3873 .41657 m
.38095 .41829 L
s
.13423 .57696 m
.13816 .57565 L
s
.13423 .57696 m
.13701 .59231 L
s
.39886 .62186 m
.39317 .62099 L
s
.29068 .57032 m .2876 .56393 L .2885 .56374 L .943 .684 .516 r
F
.29068 .57032 m .28985 .57074 L .2876 .56393 L F
.2885 .56374 m .2876 .56393 L .28579 .55702 L F
0 g
.46333 .62786 m
.45731 .63049 L
s
.36727 .5261 m .3975 .51109 L .40783 .51788 L .647 .745 .92 r
F
.35843 .52139 m .3975 .51109 L .36727 .5261 L F
.039 .916 .04 r
.38123 .53663 m
.41638 .52519 L
s
0 g
.36727 .5261 m
.37484 .53119 L
s
.039 .916 .04 r
.34107 .53287 m
.36558 .52511 L
s
0 g
.35877 .6022 m
.3634 .60502 L
s
.29252 .57734 m .28903 .57116 L .28985 .57074 L .943 .684 .516 r
F
.29252 .57734 m .29178 .578 L .28903 .57116 L F
0 g
.29178 .578 m
.29492 .58449 L
s
.19451 .60524 m
.19934 .61706 L
s
.28579 .55702 m .28482 .55696 L .28345 .54985 L .943 .684 .516 r
F
0 g
.2826 .54291 m
.28345 .54985 L
s
.2876 .56393 m .28482 .55696 L .28579 .55702 L .943 .684 .516 r
F
0 g
.30681 .57961 m
.31007 .58534 L
s
.31007 .58534 m
.31942 .58234 L
s
.16291 .65028 m
.15599 .63636 L
s
.18726 .58062 m
.19046 .59301 L
s
.32619 .49257 m
.3242 .49772 L
s
.29512 .54015 m
.30444 .53708 L
s
.29512 .54015 m
.29593 .54674 L
s
0 0 0 r
2 Mabswid
.36558 .52511 Mdot
.28985 .57074 m .28669 .56411 L .2876 .56393 L .943 .684 .516 r
F
.28985 .57074 m .28903 .57116 L .28669 .56411 L F
0 g
.5 Mabswid
.34064 .46218 m
.34463 .4579 L
s
.2876 .56393 m .28669 .56411 L .28482 .55696 L .943 .684 .516 r
F
0 g
.28345 .54985 m
.28482 .55696 L
s
.14095 .59101 m
.13816 .57565 L
s
.32572 .51829 m
.33148 .52377 L
s
.28903 .57116 m
.29178 .578 L
s
.38653 .41637 m
.39286 .41466 L
s
.31942 .58234 m
.32292 .58755 L
s
.32292 .58755 m
.34207 .58734 L
s
.19046 .59301 m
.19451 .60524 L
s
.28482 .55696 m
.28669 .56411 L
s
.146 .62294 m
.15204 .63763 L
s
.15204 .63763 m
.15599 .63636 L
s
.30412 .53076 m
.31973 .51984 L
s
.30412 .53076 m
.30444 .53708 L
s
.37441 .56521 m .39936 .57803 L .36953 .57564 L .528 .308 .524 r
F
.37441 .56521 m .40666 .56376 L .39936 .57803 L F
0 g
.37441 .56521 m
.3779 .55526 L
s
.28669 .56411 m
.28903 .57116 L
s
.13701 .59231 m
.14095 .59101 L
s
.13701 .59231 m
.14096 .60773 L
s
.30384 .57345 m
.30681 .57961 L
s
.30681 .57961 m
.31616 .5766 L
s
0 0 0 r
2 Mabswid
.41638 .52519 Mdot
0 g
.5 Mabswid
.41493 .53742 m
.41638 .52519 L
s
.29593 .54674 m
.29724 .55349 L
s
.30526 .54368 m
.29593 .54674 L
s
.35086 .5974 m
.35143 .58865 L
s
.35086 .5974 m
.35536 .60109 L
s
.42239 .52324 m .44477 .51596 L .45395 .52583 L .647 .745 .92 r
F
0 g
.45395 .52583 m
.462 .53596 L
s
.15599 .63636 m
.14995 .62166 L
s
.14096 .60773 m
.146 .62294 L
s
.146 .62294 m
.14995 .62166 L
s
.14096 .60773 m
.1449 .60645 L
s
.30123 .56696 m
.30384 .57345 L
s
.30384 .57345 m
.31319 .57042 L
s
.32073 .50634 m
.3221 .50058 L
s
.1449 .60645 m
.14095 .59101 L
s
.29724 .55349 m
.30658 .55043 L
s
.29724 .55349 m
.29901 .56027 L
s
.31616 .5766 m
.31942 .58234 L
s
.31942 .58234 m
.33793 .58115 L
s
.29901 .56027 m
.30123 .56696 L
s
.30123 .56696 m
.31058 .56392 L
s
.30444 .53708 m
.32013 .52734 L
s
.30444 .53708 m
.30526 .54368 L
s
.29901 .56027 m
.30836 .55722 L
s
.35843 .52139 m .38523 .50489 L .3975 .51109 L .647 .745 .92 r
F
.34817 .51712 m .38523 .50489 L .35843 .52139 L F
.039 .916 .04 r
.37412 .53066 m
.40838 .5183 L
s
0 g
.35843 .52139 m
.36727 .5261 L
s
.039 .916 .04 r
.33449 .52662 m
.35549 .52005 L
s
.42239 .52324 m .44356 .53145 L .42154 .53856 L .528 .308 .524 r
F
.42239 .52324 m .44477 .51596 L .44356 .53145 L F
.41246 .51355 m .44477 .51596 L .42239 .52324 L .647 .745 .92 r
F
0 0 0 r
2 Mabswid
.42239 .52324 Mdot
0 g
.5 Mabswid
.42279 .51432 m
.42307 .50808 L
s
.039 .916 .04 r
.44401 .52567 m
.45164 .5232 L
s
.41638 .52519 m
.42239 .52324 L
s
0 g
.40783 .51788 m
.41638 .52519 L
s
.14995 .62166 m
.1449 .60645 L
s
.36953 .57564 m .38921 .59323 L .36294 .58663 L .528 .308 .524 r
F
.36953 .57564 m .39936 .57803 L .38921 .59323 L F
0 g
.36953 .57564 m
.37441 .56521 L
s
.039 .916 .04 r
.45164 .5232 m
.89622 .36906 L
s
0 0 0 r
2 Mabswid
.45164 .5232 Mdot
.35549 .52005 Mdot
0 g
.5 Mabswid
.3242 .49772 m
.32278 .5037 L
s
.31319 .57042 m
.31616 .5766 L
s
.31616 .5766 m
.33407 .57432 L
s
.30526 .54368 m
.32112 .53518 L
s
.30526 .54368 m
.30658 .55043 L
s
.31058 .56392 m
.31319 .57042 L
s
.31319 .57042 m
.33056 .56698 L
s
.39317 .62099 m
.38719 .61866 L
s
.30658 .55043 m
.32269 .54321 L
s
.30658 .55043 m
.30836 .55722 L
s
.3464 .59279 m
.35086 .5974 L
s
.44503 .63301 m
.45167 .63221 L
s
.45167 .63221 m
.45731 .63049 L
s
.30836 .55722 m
.31058 .56392 L
s
.31058 .56392 m
.32745 .55925 L
s
.30836 .55722 m
.32482 .55128 L
s
.36294 .58663 m .37483 .60979 L .3541 .59836 L .528 .308 .524 r
F
0 g
.3541 .59836 m
.35877 .6022 L
s
.36294 .58663 m .38921 .59323 L .37483 .60979 L .528 .308 .524 r
F
0 g
.3634 .60502 m
.38719 .61866 L
s
.35877 .6022 m
.38105 .61491 L
s
.36294 .58663 m
.36953 .57564 L
s
.3541 .59836 m
.36294 .58663 L
s
.31993 .5128 m
.32073 .50634 L
s
.33728 .46778 m
.34064 .46218 L
s
.34817 .51712 m .37071 .49937 L .38523 .50489 L .647 .745 .92 r
F
.3362 .5134 m .37071 .49937 L .34817 .51712 L F
0 g
.34817 .51712 m
.35843 .52139 L
s
.41174 .55026 m
.41493 .53742 L
s
.039 .916 .04 r
.40838 .5183 m
.41511 .51611 L
s
0 0 0 r
2 Mabswid
.40838 .5183 Mdot
0 g
.5 Mabswid
.38095 .41829 m
.38653 .41637 L
s
.38095 .41829 m
.37522 .42185 L
s
.34947 .59357 m
.3541 .59836 L
s
.3541 .59836 m
.37483 .60979 L
s
.45731 .63049 m
.45068 .63128 L
s
.3464 .59279 m
.34207 .58734 L
s
.38081 .41993 m
.38653 .41637 L
s
0 0 0 r
2 Mabswid
.41511 .51611 Mdot
.3362 .5134 m .35331 .49477 L .37071 .49937 L .647 .745 .92 r
F
.039 .916 .04 r
.5 Mabswid
.35549 .52005 m
.38729 .50581 L
s
.36558 .52511 m
.39875 .51183 L
s
.32195 .51041 m .35331 .49477 L .3362 .5134 L .647 .745 .92 r
F
0 g
.3362 .5134 m
.34817 .51712 L
s
.31993 .5128 m
.32572 .51829 L
s
.31973 .51984 m
.31993 .5128 L
s
.41246 .51355 m .43445 .50635 L .44477 .51596 L .647 .745 .92 r
F
0 0 0 r
2 Mabswid
.44477 .51596 Mdot
.039 .916 .04 r
.5 Mabswid
.44477 .51596 m
.89623 .36908 L
s
.42239 .52324 m
.44477 .51596 L
s
0 g
.44477 .51596 m
.44493 .50092 L
s
.44477 .51596 m
.45395 .52583 L
s
.42154 .53856 m .44126 .54739 L .42053 .55403 L .528 .308 .524 r
F
.42154 .53856 m .44356 .53145 L .44126 .54739 L F
0 g
.42154 .53856 m
.42239 .52324 L
s
.44356 .53145 m
.44477 .51596 L
s
.34497 .5879 m
.34947 .59357 L
s
.34947 .59357 m
.36866 .60338 L
s
.40666 .56376 m
.41174 .55026 L
s
.40228 .50383 m .43445 .50635 L .41246 .51355 L .647 .745 .92 r
F
0 g
.41246 .51355 m
.42239 .52324 L
s
.039 .916 .04 r
.41511 .51611 m
.43728 .50885 L
s
0 g
.3975 .51109 m
.40783 .51788 L
s
.38719 .61866 m
.38105 .61491 L
s
.32195 .51041 m .33167 .49156 L .35331 .49477 L .647 .745 .92 r
F
0 g
.32195 .51041 m
.33167 .49156 L
s
.3242 .49772 m
.33464 .47462 L
s
.32278 .5037 m
.33275 .48259 L
s
.32195 .51041 m
.32278 .5037 L
s
.32195 .51041 m
.3362 .5134 L
s
.32619 .49257 m
.33728 .46778 L
s
.32174 .51772 m
.32195 .51041 L
s
.34207 .58734 m
.33793 .58115 L
s
.32013 .52734 m
.31973 .51984 L
s
.039 .916 .04 r
.39875 .51183 m
.40766 .50895 L
s
0 0 0 r
2 Mabswid
.39875 .51183 Mdot
0 g
.5 Mabswid
.33464 .47462 m
.33728 .46778 L
s
.38523 .50489 m
.3975 .51109 L
s
.34067 .58147 m
.34497 .5879 L
s
.34497 .5879 m
.36265 .59578 L
s
.43788 .63194 m
.44503 .63301 L
s
.44503 .63301 m
.45068 .63128 L
s
.33793 .58115 m
.33407 .57432 L
s
.32174 .51772 m
.33141 .50137 L
s
.32174 .51772 m
.32216 .52553 L
s
.32112 .53518 m
.32013 .52734 L
s
0 0 0 r
2 Mabswid
.40766 .50895 Mdot
0 g
.5 Mabswid
.39936 .57803 m
.40666 .56376 L
s
.37522 .42185 m
.38081 .41993 L
s
.37522 .42185 m
.37019 .42721 L
s
.45068 .63128 m
.44355 .63019 L
s
.039 .916 .04 r
.43728 .50885 m
.89624 .36909 L
s
0 0 0 r
2 Mabswid
.43728 .50885 Mdot
0 g
.5 Mabswid
.33407 .57432 m
.33056 .56698 L
s
.32269 .54321 m
.32112 .53518 L
s
.33666 .57437 m
.34067 .58147 L
s
.34067 .58147 m
.3569 .58713 L
s
.32216 .52553 m
.33199 .51184 L
s
.32216 .52553 m
.32319 .53367 L
s
.42053 .55403 m .43785 .56379 L .41933 .56968 L .528 .308 .524 r
F
.42053 .55403 m .44126 .54739 L .43785 .56379 L F
0 g
.42053 .55403 m
.42154 .53856 L
s
.44126 .54739 m
.44356 .53145 L
s
.37483 .60979 m
.38105 .61491 L
s
0 0 0 r
2 Mabswid
.38729 .50581 Mdot
0 g
.5 Mabswid
.37581 .42528 m
.38081 .41993 L
s
.33056 .56698 m
.32745 .55925 L
s
.32482 .55128 m
.32269 .54321 L
s
.37071 .49937 m
.38523 .50489 L
s
.32745 .55925 m
.32482 .55128 L
s
.40228 .50383 m .42297 .49701 L .43445 .50635 L .647 .745 .92 r
F
0 g
.43445 .50635 m
.44477 .51596 L
s
.33275 .48259 m
.33464 .47462 L
s
.33301 .56673 m
.33666 .57437 L
s
.33666 .57437 m
.35152 .57758 L
s
.38921 .59323 m
.39936 .57803 L
s
.32319 .53367 m
.33339 .52279 L
s
.32319 .53367 m
.32483 .54202 L
s
.39185 .49409 m .42297 .49701 L .40228 .50383 L .647 .745 .92 r
F
0 g
.40228 .50383 m
.41246 .51355 L
s
.039 .916 .04 r
.40766 .50895 m
.42913 .50187 L
s
.38729 .50581 m
.40001 .5017 L
s
0 g
.32978 .5587 m
.33301 .56673 L
s
.33301 .56673 m
.34662 .5673 L
s
.32483 .54202 m
.3356 .53402 L
s
.32483 .54202 m
.32704 .55041 L
s
.32704 .55041 m
.32978 .5587 L
s
.32978 .5587 m
.34228 .55648 L
s
.32704 .55041 m
.33858 .54532 L
s
0 0 0 r
2 Mabswid
.40001 .5017 Mdot
0 g
.5 Mabswid
.37483 .60979 m
.38921 .59323 L
s
.039 .916 .04 r
.42913 .50187 m
.89627 .36912 L
s
0 0 0 r
2 Mabswid
.42913 .50187 Mdot
0 g
.5 Mabswid
.43036 .62898 m
.43788 .63194 L
s
.43788 .63194 m
.44355 .63019 L
s
.35331 .49477 m
.37071 .49937 L
s
.36866 .60338 m
.37483 .60979 L
s
.33167 .49156 m
.33275 .48259 L
s
.37019 .42721 m
.37581 .42528 L
s
.37019 .42721 m
.36599 .4343 L
s
.41933 .56968 m .43329 .58065 L .41797 .58548 L .528 .308 .524 r
F
.41933 .56968 m .43785 .56379 L .43329 .58065 L F
0 g
.41933 .56968 m
.42053 .55403 L
s
.43785 .56379 m
.44126 .54739 L
s
.44355 .63019 m
.43605 .62723 L
s
.37162 .43237 m
.37581 .42528 L
s
.39185 .49409 m .41032 .48797 L .42297 .49701 L .647 .745 .92 r
F
.039 .916 .04 r
.40001 .5017 m
.42024 .49496 L
s
0 g
.42297 .49701 m
.43445 .50635 L
s
.33167 .49156 m
.35331 .49477 L
s
.36866 .60338 m
.36265 .59578 L
s
.38116 .48432 m .41032 .48797 L .39185 .49409 L .647 .745 .92 r
F
0 g
.39185 .49409 m
.40228 .50383 L
s
.039 .916 .04 r
.42024 .49496 m
.89628 .36914 L
s
0 0 0 r
2 Mabswid
.42024 .49496 Mdot
0 g
.5 Mabswid
.33141 .50137 m
.33167 .49156 L
s
.42259 .62418 m
.43036 .62898 L
s
.43036 .62898 m
.43605 .62723 L
s
.41797 .58548 m .42751 .59798 L .41642 .60146 L .528 .308 .524 r
F
.41797 .58548 m .43329 .58065 L .42751 .59798 L F
0 g
.41797 .58548 m
.41933 .56968 L
s
.43329 .58065 m
.43785 .56379 L
s
.36265 .59578 m
.3569 .58713 L
s
.36599 .4343 m
.37162 .43237 L
s
.36599 .4343 m
.36268 .44301 L
s
.43605 .62723 m
.42829 .62241 L
s
.33199 .51184 m
.33141 .50137 L
s
.38116 .48432 m .39643 .47923 L .41032 .48797 L .647 .745 .92 r
F
0 g
.41032 .48797 m
.42297 .49701 L
s
.36833 .44108 m
.37162 .43237 L
s
.3569 .58713 m
.35152 .57758 L
s
.33339 .52279 m
.33199 .51184 L
s
.37022 .47453 m .39643 .47923 L .38116 .48432 L .647 .745 .92 r
F
0 g
.38116 .48432 m
.39185 .49409 L
s
.35152 .57758 m
.34662 .5673 L
s
.42259 .62418 m
.42829 .62241 L
s
.41642 .60146 m .42042 .61582 L .4147 .61759 L .528 .308 .524 r
F
0 g
.4147 .61759 m
.42259 .62418 L
s
.41642 .60146 m .42751 .59798 L .42042 .61582 L .528 .308 .524 r
F
0 g
.41642 .60146 m
.41797 .58548 L
s
.4147 .61759 m
.41642 .60146 L
s
.42751 .59798 m
.43329 .58065 L
s
.3356 .53402 m
.33339 .52279 L
s
.36268 .44301 m
.36833 .44108 L
s
.36268 .44301 m
.36034 .45321 L
s
.34662 .5673 m
.34228 .55648 L
s
.42042 .61582 m
.42829 .62241 L
s
.33858 .54532 m
.3356 .53402 L
s
.34228 .55648 m
.33858 .54532 L
s
.37022 .47453 m .38125 .47082 L .39643 .47923 L .647 .745 .92 r
F
0 g
.39643 .47923 m
.41032 .48797 L
s
.36601 .45128 m
.36833 .44108 L
s
.42042 .61582 m
.42751 .59798 L
s
.35902 .46471 m .38125 .47082 L .37022 .47453 L .647 .745 .92 r
F
0 g
.37022 .47453 m
.38116 .48432 L
s
.40684 .60932 m
.4147 .61759 L
s
.4147 .61759 m
.42042 .61582 L
s
.36034 .45321 m
.36601 .45128 L
s
.41257 .60753 m
.42042 .61582 L
s
.35902 .46471 m .36471 .46279 L .38125 .47082 L .647 .745 .92 r
F
0 g
.36471 .46279 m
.38125 .47082 L
s
.35902 .46471 m
.36034 .45321 L
s
.38125 .47082 m
.39643 .47923 L
s
.35902 .46471 m
.37022 .47453 L
s
.36471 .46279 m
.36601 .45128 L
s
.39917 .59951 m
.40684 .60932 L
s
.40684 .60932 m
.41257 .60753 L
s
.35902 .46471 m
.36471 .46279 L
s
.35876 .47733 m
.35902 .46471 L
s
.41257 .60753 m
.4049 .59771 L
s
.36446 .47542 m
.36471 .46279 L
s
.3918 .58832 m
.39917 .59951 L
s
.39917 .59951 m
.4049 .59771 L
s
.35876 .47733 m
.36446 .47542 L
s
.35876 .47733 m
.35956 .49084 L
s
.4049 .59771 m
.39755 .5865 L
s
.36528 .48893 m
.36446 .47542 L
s
.3849 .57595 m
.3918 .58832 L
s
.3918 .58832 m
.39755 .5865 L
s
.35956 .49084 m
.36528 .48893 L
s
.35956 .49084 m
.36143 .50499 L
s
.39755 .5865 m
.39065 .57412 L
s
.36716 .50309 m
.36528 .48893 L
s
.37859 .56263 m
.3849 .57595 L
s
.3849 .57595 m
.39065 .57412 L
s
.36143 .50499 m
.36716 .50309 L
s
.36143 .50499 m
.36433 .51951 L
s
.39065 .57412 m
.38434 .56079 L
s
.37006 .51763 m
.36716 .50309 L
s
.37299 .54861 m
.37859 .56263 L
s
.37859 .56263 m
.38434 .56079 L
s
.36433 .51951 m
.37006 .51763 L
s
.36433 .51951 m
.3682 .53415 L
s
.37873 .54675 m
.37299 .54861 L
s
.3682 .53415 m
.37299 .54861 L
s
.3682 .53415 m
.37394 .53227 L
s
.38434 .56079 m
.37873 .54675 L
s
.37394 .53227 m
.37006 .51763 L
s
.37873 .54675 m
.37394 .53227 L
s
0 0 0 r
2 Mabswid
.89628 .36914 Mdot
.89627 .36912 Mdot
.89624 .36909 Mdot
.89623 .36908 Mdot
.89622 .36906 Mdot
.89619 .36903 Mdot
.89618 .36901 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.431973 0.0136054 0.97619 0.557823 MathSubStart
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.25637 .59749 m
.25244 .58315 L
s
.25244 .58315 m
.25636 .58191 L
s
.25244 .58315 m
.24771 .56901 L
s
.24771 .56901 m
.25162 .56776 L
s
.24771 .56901 m
.24224 .55529 L
s
.25943 .61183 m
.25637 .59749 L
s
.25637 .59749 m
.26028 .59626 L
s
.25636 .58191 m
.26028 .59626 L
s
.25162 .56776 m
.25636 .58191 L
s
.24615 .55404 m
.25162 .56776 L
s
.26028 .59626 m
.26335 .6106 L
s
.24224 .55529 m
.24615 .55404 L
s
.24224 .55529 m
.23612 .54222 L
s
.26156 .62593 m
.25943 .61183 L
s
.25943 .61183 m
.26335 .6106 L
s
.24003 .54096 m
.24615 .55404 L
s
.26335 .6106 m
.26549 .62471 L
s
.23612 .54222 m
.24003 .54096 L
s
.23612 .54222 m
.22944 .52998 L
s
.23336 .52871 m
.24003 .54096 L
s
.26274 .63957 m
.26156 .62593 L
s
.26156 .62593 m
.26549 .62471 L
s
.26549 .62471 m
.26668 .63836 L
s
.22944 .52998 m
.23336 .52871 L
s
.22944 .52998 m
.2223 .51878 L
s
.22622 .51751 m
.23336 .52871 L
s
.26274 .63957 m
.26668 .63836 L
s
.2223 .51878 m
.22622 .51751 L
s
.2223 .51878 m
.2148 .5088 L
s
.21873 .50752 m
.22622 .51751 L
s
.24489 .64584 m .26689 .65134 L .26294 .65255 L .664 .758 .92 r
F
0 g
.26215 .66465 m
.26294 .65255 L
s
.26274 .63957 m
.26291 .65035 L
s
.24489 .64584 m .25402 .64303 L .26689 .65134 L .664 .758 .92 r
F
0 g
.26611 .66345 m
.26689 .65134 L
s
.26668 .63836 m
.26689 .65134 L
s
.26294 .65255 m
.26689 .65134 L
s
.2148 .5088 m
.21873 .50752 L
s
.26037 .67568 m
.26215 .66465 L
s
.26215 .66465 m
.26611 .66345 L
s
.22851 .63852 m .25402 .64303 L .24489 .64584 L .664 .758 .92 r
F
0 g
.24489 .64584 m
.26294 .65255 L
s
.26611 .66345 m
.26435 .67447 L
s
.28349 .58544 m
.28029 .57376 L
s
.28029 .57376 m
.30183 .56607 L
s
.28029 .57376 m
.27644 .56225 L
s
.27644 .56225 m
.29931 .55855 L
s
.27644 .56225 m
.27201 .55108 L
s
.286 .5971 m
.28349 .58544 L
s
.28349 .58544 m
.30392 .5737 L
s
.27201 .55108 m
.29642 .55125 L
s
.27201 .55108 m
.26706 .54044 L
s
.22851 .63852 m .24165 .63445 L .25402 .64303 L .664 .758 .92 r
F
0 g
.25402 .64303 m
.26689 .65134 L
s
.28778 .60855 m
.286 .5971 L
s
.286 .5971 m
.30558 .58132 L
s
.20707 .50021 m .20725 .51555 L .19813 .51853 L .558 .338 .538 r
F
.20707 .50021 m .21101 .49892 L .20725 .51555 L F
0 g
.20999 .50345 m
.2148 .5088 L
s
.20707 .50021 m
.21101 .49892 L
s
.21101 .49892 m
.21873 .50752 L
s
.19923 .49316 m
.20707 .50021 L
s
.20317 .49185 m
.21101 .49892 L
s
.26706 .54044 m
.26167 .53048 L
s
.28878 .61962 m
.28778 .60855 L
s
.25762 .68543 m
.26037 .67568 L
s
.26037 .67568 m
.26435 .67447 L
s
.21362 .63065 m .24165 .63445 L .22851 .63852 L .664 .758 .92 r
F
0 g
.22851 .63852 m
.24489 .64584 L
s
.26435 .67447 m
.26161 .68423 L
s
.26167 .53048 m
.25592 .52137 L
s
.19813 .51853 m .20406 .5321 L .19094 .53636 L .558 .338 .538 r
F
.19813 .51853 m .20725 .51555 L .20406 .5321 L F
0 g
.19813 .51853 m
.20707 .50021 L
s
.20725 .51555 m
.21101 .49892 L
s
.21362 .63065 m .22975 .62563 L .24165 .63445 L .664 .758 .92 r
F
0 g
.24165 .63445 m
.25402 .64303 L
s
.19923 .49316 m
.20317 .49185 L
s
.19923 .49316 m
.19139 .48777 L
s
.25592 .52137 m
.24991 .51327 L
s
.19535 .48646 m
.20317 .49185 L
s
.26557 .62735 m .3076 .60281 L .289 .63013 L .664 .758 .92 r
F
0 g
.28842 .63991 m
.289 .63013 L
s
.25394 .69375 m
.25762 .68543 L
s
.25762 .68543 m
.26161 .68423 L
s
.19094 .53636 m .20143 .54857 L .18531 .55377 L .558 .338 .538 r
F
.19094 .53636 m .20406 .5321 L .20143 .54857 L F
0 g
.19094 .53636 m
.19813 .51853 L
s
.20406 .5321 m
.20725 .51555 L
s
.20011 .62224 m .22975 .62563 L .21362 .63065 L .664 .758 .92 r
F
0 g
.21362 .63065 m
.22851 .63852 L
s
.039 .916 .04 r
.16089 .63946 m
.20646 .62637 L
s
0 g
.26161 .68423 m
.25794 .69254 L
s
.26557 .62735 m .29354 .60059 L .3076 .60281 L .664 .758 .92 r
F
0 g
.29517 .60085 m
.30675 .58879 L
s
.30266 .60203 m
.30743 .59599 L
s
.24706 .623 m .29354 .60059 L .26557 .62735 L .664 .758 .92 r
F
0 g
.26557 .62735 m
.289 .63013 L
s
.28705 .64879 m
.28842 .63991 L
s
.19139 .48777 m
.19535 .48646 L
s
.19139 .48777 m
.18369 .48417 L
s
.20011 .62224 m .21835 .61654 L .22975 .62563 L .664 .758 .92 r
F
0 g
.22975 .62563 m
.24165 .63445 L
s
.18767 .48285 m
.19535 .48646 L
s
.18531 .55377 m .19938 .56497 L .18115 .57081 L .558 .338 .538 r
F
.18531 .55377 m .20143 .54857 L .19938 .56497 L F
0 g
.18531 .55377 m
.19094 .53636 L
s
.20143 .54857 m
.20406 .5321 L
s
.24706 .623 m .28212 .59754 L .29354 .60059 L .664 .758 .92 r
F
0 g
.28842 .63991 m
.30725 .60914 L
s
.289 .63013 m
.3076 .60281 L
s
.23169 .61763 m .28212 .59754 L .24706 .623 L .664 .758 .92 r
F
0 g
.24706 .623 m
.26557 .62735 L
s
.24373 .5063 m .26896 .53326 L .22773 .52405 L .558 .338 .538 r
F
.24373 .5063 m .27816 .52208 L .26896 .53326 L F
0 g
.26955 .53254 m
.28971 .53779 L
s
.27365 .52755 m
.286 .53186 L
s
.2764 .52422 m
.28213 .52659 L
s
.24373 .5063 m
.27816 .52208 L
s
.23747 .5006 m
.24373 .5063 L
s
.24936 .70047 m
.25394 .69375 L
s
.25394 .69375 m
.25794 .69254 L
s
.18792 .61332 m .21835 .61654 L .20011 .62224 L .664 .758 .92 r
F
.039 .916 .04 r
.20646 .62637 m
.22311 .62041 L
s
0 g
.20011 .62224 m
.21362 .63065 L
s
.039 .916 .04 r
.15311 .63184 m
.19572 .6192 L
s
0 g
.25794 .69254 m
.25338 .69926 L
s
.22773 .52405 m .26241 .5436 L .21669 .54022 L .558 .338 .538 r
F
.22773 .52405 m .26896 .53326 L .26241 .5436 L F
0 g
.22773 .52405 m
.24373 .5063 L
s
.26706 .54044 m
.29321 .54429 L
s
.28491 .65662 m
.28705 .64879 L
s
.28705 .64879 m
.3064 .61487 L
s
.23169 .61763 m .27252 .59389 L .28212 .59754 L .664 .758 .92 r
F
.21871 .61145 m .27252 .59389 L .23169 .61763 L F
0 g
.23169 .61763 m
.24706 .623 L
s
.039 .916 .04 r
.22311 .62041 m
.23146 .61753 L
s
.18115 .57081 m .19789 .5813 L .1784 .58751 L .558 .338 .538 r
F
.18115 .57081 m .19938 .56497 L .19789 .5813 L F
0 g
.18115 .57081 m
.18531 .55377 L
s
.19938 .56497 m
.20143 .54857 L
s
.21669 .54022 m .2577 .55337 L .20883 .5554 L .558 .338 .538 r
F
.21669 .54022 m .26241 .5436 L .2577 .55337 L F
0 g
.21669 .54022 m
.22773 .52405 L
s
.18369 .48417 m
.18767 .48285 L
s
.18369 .48417 m
.17626 .48243 L
s
.23747 .5006 m
.27416 .5184 L
s
.23747 .5006 m
.23124 .49626 L
s
.18792 .61332 m .20742 .60719 L .21835 .61654 L .664 .758 .92 r
F
0 g
.21835 .61654 m
.22975 .62563 L
s
.039 .916 .04 r
.19572 .6192 m
.21402 .61292 L
s
0 g
.18025 .4811 m
.18767 .48285 L
s
.30183 .56607 m
.30392 .5737 L
s
.29931 .55855 m
.30183 .56607 L
s
.30393 .5737 m
.30183 .56607 L
s
.30183 .56607 m
.32619 .55809 L
s
.30183 .56607 m
.29931 .55855 L
s
.29642 .55125 m
.29931 .55855 L
s
.29931 .55855 m
.3241 .55183 L
s
.29931 .55855 m
.29642 .55125 L
s
.30392 .5737 m
.30558 .58132 L
s
.30558 .58132 m
.30393 .5737 L
s
.30393 .5737 m
.32794 .56444 L
s
.28201 .66326 m
.28491 .65662 L
s
.28491 .65662 m
.30504 .61989 L
s
.20883 .5554 m .25445 .56271 L .20341 .56986 L .558 .338 .538 r
F
.20883 .5554 m .2577 .55337 L .25445 .56271 L F
0 g
.20883 .5554 m
.21669 .54022 L
s
.29321 .54429 m
.29642 .55125 L
s
.29642 .55125 m
.3217 .54575 L
s
.29642 .55125 m
.29321 .54429 L
s
.24397 .70547 m
.24936 .70047 L
s
.24936 .70047 m
.25338 .69926 L
s
.30558 .58132 m
.30675 .58879 L
s
.30675 .58879 m
.30558 .58132 L
s
.30558 .58132 m
.32932 .57078 L
s
.17701 .60388 m .20742 .60719 L .18792 .61332 L .664 .758 .92 r
F
0 g
.18792 .61332 m
.20011 .62224 L
s
.039 .916 .04 r
.14513 .6242 m
.18592 .61171 L
s
0 g
.28971 .53779 m
.29321 .54429 L
s
.29321 .54429 m
.31904 .53995 L
s
.29321 .54429 m
.28972 .53779 L
s
.25338 .69926 m
.248 .70426 L
s
.21871 .61145 m .26435 .58976 L .27252 .59389 L .664 .758 .92 r
F
.20775 .60457 m .26435 .58976 L .21871 .61145 L F
0 g
.21871 .61145 m
.23169 .61763 L
s
.039 .916 .04 r
.21402 .61292 m
.21859 .61139 L
s
0 g
.30675 .58879 m
.30743 .59599 L
s
.30743 .59599 m
.30675 .58879 L
s
.1784 .58751 m .19697 .59757 L .17701 .60388 L .558 .338 .538 r
F
.1784 .58751 m .19789 .5813 L .19697 .59757 L F
0 g
.1784 .58751 m
.18115 .57081 L
s
.19789 .5813 m
.19938 .56497 L
s
.286 .53186 m
.28971 .53779 L
s
.28972 .53779 m
.31615 .53454 L
s
.28972 .53779 m
.286 .53186 L
s
.23124 .49626 m
.27019 .51561 L
s
.23124 .49626 m
.22515 .49337 L
s
.30743 .59599 m
.3076 .60281 L
s
.20341 .56986 m .25248 .57166 L .20007 .58372 L .558 .338 .538 r
F
.20341 .56986 m .25445 .56271 L .25248 .57166 L F
0 g
.20341 .56986 m
.20883 .5554 L
s
.17626 .48243 m
.18025 .4811 L
s
.17626 .48243 m
.16923 .4826 L
s
.28213 .52659 m
.286 .53186 L
s
.286 .53186 m
.28213 .52659 L
s
.17701 .60388 m .19697 .59757 L .20742 .60719 L .664 .758 .92 r
F
.039 .916 .04 r
.18592 .61171 m
.20532 .60532 L
s
0 g
.20742 .60719 m
.21835 .61654 L
s
.27841 .6686 m
.28201 .66326 L
s
.28201 .66326 m
.3032 .62412 L
s
.17323 .48127 m
.18025 .4811 L
s
.30725 .60914 m
.3076 .60281 L
s
.30258 .59778 m .33107 .58863 L .3076 .60281 L .664 .758 .92 r
F
0 g
.30725 .60914 m
.3076 .60281 L
s
.29354 .60059 m
.3076 .60281 L
s
.30743 .59599 m
.30744 .59622 L
s
.47173 .52844 m
.46792 .51486 L
s
.46792 .51486 m
.47354 .51308 L
s
.46792 .51486 m
.46346 .50143 L
s
.19863 .59704 m .25744 .58521 L .20775 .60457 L .664 .758 .92 r
F
.039 .916 .04 r
.20532 .60532 m
.2077 .60454 L
s
.20775 .60457 m .25744 .58521 L .26435 .58976 L .664 .758 .92 r
F
0 g
.20775 .60457 m
.21871 .61145 L
s
.46346 .50143 m
.46908 .49964 L
s
.46346 .50143 m
.45843 .48837 L
s
.47483 .54198 m
.47173 .52844 L
s
.47173 .52844 m
.47735 .52668 L
s
.27816 .52208 m
.28213 .52659 L
s
.23783 .70862 m
.24397 .70547 L
s
.24397 .70547 m
.248 .70426 L
s
.28212 .59754 m
.29354 .60059 L
s
.47354 .51308 m
.47735 .52668 L
s
.46908 .49964 m
.47354 .51308 L
s
.20007 .58372 m .25168 .58027 L .19863 .59704 L .558 .338 .538 r
F
.039 .916 .04 r
.23146 .61753 m
.27798 .5961 L
s
.20007 .58372 m .25248 .57166 L .25168 .58027 L .558 .338 .538 r
F
0 g
.20007 .58372 m
.20341 .56986 L
s
.46405 .48657 m
.46908 .49964 L
s
.45843 .48837 m
.46405 .48657 L
s
.45843 .48837 m
.4529 .47588 L
s
.17701 .60388 m .19662 .61377 L .17699 .61994 L .558 .338 .538 r
F
.17701 .60388 m .19697 .59757 L .19662 .61377 L F
.16738 .59392 m .19697 .59757 L .17701 .60388 L .664 .758 .92 r
F
0 0 0 r
2 Mabswid
.17701 .60388 Mdot
.039 .916 .04 r
.5 Mabswid
.13693 .61655 m
.17701 .60388 L
s
0 g
.17774 .5952 m
.1784 .58751 L
s
.22515 .49337 m
.26632 .51378 L
s
.22515 .49337 m
.21929 .49199 L
s
.30725 .60914 m
.3064 .61487 L
s
.3064 .61486 m
.30725 .60914 L
s
.47735 .52668 m
.48046 .54022 L
s
.248 .70426 m
.24187 .70741 L
s
.47718 .55525 m
.47483 .54198 L
s
.47483 .54198 m
.48046 .54022 L
s
.45852 .47407 m
.46405 .48657 L
s
.30258 .59778 m .31977 .58666 L .33107 .58863 L .664 .758 .92 r
F
0 g
.32318 .58725 m
.3309 .58297 L
s
.29754 .59271 m .31977 .58666 L .30258 .59778 L .664 .758 .92 r
F
0 g
.30258 .59778 m
.3076 .60281 L
s
.30675 .58879 m
.33032 .57698 L
s
.30725 .60914 m
.33082 .59387 L
s
.41893 .52971 m
.42191 .54036 L
s
.38918 .53854 m
.41893 .52971 L
s
.41543 .51918 m
.41893 .52971 L
s
.48046 .54022 m
.48282 .5535 L
s
.38655 .53062 m
.41543 .51918 L
s
.41146 .50895 m
.41543 .51918 L
s
.4529 .47588 m
.45852 .47407 L
s
.4529 .47588 m
.44695 .46415 L
s
.27416 .5184 m
.27816 .52208 L
s
.27816 .52208 m .29938 .53064 L .27799 .53035 L .558 .338 .538 r
F
0 g
.26896 .53326 m
.27816 .52208 L
s
.27816 .52208 m .30665 .52146 L .29938 .53064 L .558 .338 .538 r
F
0 g
.30342 .52554 m
.30991 .52522 L
s
.27416 .5184 m
.27816 .52208 L
s
.32794 .56444 m
.32619 .55809 L
s
.32619 .55809 m
.32798 .55753 L
s
.32619 .55809 m
.3241 .55183 L
s
.27252 .59389 m
.28212 .59754 L
s
.3241 .55183 m
.32589 .55126 L
s
.3241 .55183 m
.3217 .54575 L
s
.42191 .54036 m
.4243 .55098 L
s
.39141 .54656 m
.42191 .54036 L
s
.32932 .57078 m
.32794 .56444 L
s
.32794 .56444 m
.32973 .56388 L
s
.32798 .55753 m
.32973 .56388 L
s
.32589 .55126 m
.32798 .55753 L
s
.32349 .54518 m
.32589 .55126 L
s
.27415 .67252 m
.27841 .6686 L
s
.27841 .6686 m
.30091 .62749 L
s
.33992 .55382 m .34063 .55364 L .34253 .56052 L .963 .689 .469 r
F
.33773 .54725 m .34063 .55364 L .33992 .55382 L F
.33773 .54725 m .33837 .54685 L .34063 .55364 L F
0 g
.32973 .56388 m
.33112 .57021 L
s
.3217 .54575 m
.32349 .54518 L
s
.3217 .54575 m
.31904 .53995 L
s
.33523 .54088 m .33837 .54685 L .33773 .54725 L .963 .689 .469 r
F
.33523 .54088 m .33578 .54027 L .33837 .54685 L F
0 g
.33837 .54685 m
.34063 .55364 L
s
.38355 .52292 m
.41146 .50895 L
s
.40708 .49918 m
.41146 .50895 L
s
.34176 .56047 m .34253 .56052 L .34404 .56738 L .963 .689 .469 r
F
.33992 .55382 m .34253 .56052 L .34176 .56047 L F
0 g
.34063 .55364 m
.34253 .56052 L
s
.47873 .56805 m
.47718 .55525 L
s
.47718 .55525 m
.48282 .5535 L
s
.33032 .57698 m
.32932 .57078 L
s
.32932 .57078 m
.33112 .57021 L
s
.32083 .53938 m
.32349 .54518 L
s
.45258 .46233 m
.45852 .47407 L
s
.26241 .5436 m
.26896 .53326 L
s
.3064 .61487 m
.30504 .61989 L
s
.30504 .61989 m
.3064 .61486 L
s
.3064 .61486 m
.33014 .59861 L
s
.33245 .53481 m .33578 .54027 L .33523 .54088 L .963 .689 .469 r
F
.33245 .53481 m .3329 .53399 L .33578 .54027 L F
0 g
.33578 .54027 m
.33837 .54685 L
s
.4243 .55098 m
.42608 .56139 L
s
.3932 .55456 m
.4243 .55098 L
s
.33112 .57021 m
.33211 .57642 L
s
.33922 .55399 m .33992 .55382 L .34176 .56047 L .963 .689 .469 r
F
.3371 .54765 m .33992 .55382 L .33922 .55399 L F
.3371 .54765 m .33773 .54725 L .33992 .55382 L F
0 g
.31904 .53995 m
.32083 .53938 L
s
.31904 .53995 m
.31615 .53454 L
s
.33468 .54149 m .33773 .54725 L .3371 .54765 L .963 .689 .469 r
F
.33468 .54149 m .33523 .54088 L .33773 .54725 L F
.34322 .5671 m .34404 .56738 L .34513 .5741 L F
.34176 .56047 m .34404 .56738 L .34322 .5671 L F
0 g
.34253 .56052 m
.34404 .56738 L
s
.34099 .56042 m .34176 .56047 L .34322 .5671 L .963 .689 .469 r
F
.33922 .55399 m .34176 .56047 L .34099 .56042 L F
0 g
.16923 .4826 m
.17323 .48127 L
s
.16923 .4826 m
.16272 .48472 L
s
.31795 .53397 m
.32083 .53938 L
s
.16738 .59392 m .18701 .58768 L .19697 .59757 L .664 .758 .92 r
F
0 0 0 r
2 Mabswid
.19697 .59757 Mdot
.039 .916 .04 r
.5 Mabswid
.12852 .60889 m
.16897 .5957 L
s
.17701 .60388 m
.19697 .59757 L
s
0 g
.19697 .59757 m
.20742 .60719 L
s
.19697 .59757 m
.19789 .5813 L
s
.3309 .58297 m
.33032 .57698 L
s
.33032 .57698 m
.33211 .57642 L
s
.48282 .5535 m
.48439 .56631 L
s
.33199 .53563 m .33523 .54088 L .33468 .54149 L .963 .689 .469 r
F
.33199 .53563 m .33245 .53481 L .33523 .54088 L F
.32944 .52913 m .3329 .53399 L .33245 .53481 L F
.32944 .52913 m .32979 .52812 L .3329 .53399 L F
0 g
.3329 .53399 m
.33578 .54027 L
s
.38023 .51558 m
.40708 .49918 L
s
.40235 .49002 m
.40708 .49918 L
s
.33851 .55416 m .33922 .55399 L .34099 .56042 L .963 .689 .469 r
F
.33647 .54805 m .33922 .55399 L .33851 .55416 L F
.33647 .54805 m .3371 .54765 L .33922 .55399 L F
.19863 .59704 m .25203 .58855 L .19907 .60985 L .558 .338 .538 r
F
.19863 .59704 m .25168 .58027 L .25744 .58521 L .664 .758 .92 r
F
.19863 .59704 m .25168 .58027 L .25203 .58855 L .558 .338 .538 r
F
.19133 .58886 m .25168 .58027 L .19863 .59704 L .664 .758 .92 r
F
0 0 0 r
2 Mabswid
.19863 .59704 Mdot
.039 .916 .04 r
.5 Mabswid
.19697 .59757 m
.19863 .59704 L
s
0 g
.19964 .58768 m
.20007 .58372 L
s
.039 .916 .04 r
.21859 .61139 m
.26756 .59152 L
s
0 g
.33211 .57642 m
.3327 .58241 L
s
.33413 .54211 m .3371 .54765 L .33647 .54805 L .963 .689 .469 r
F
.33413 .54211 m .33468 .54149 L .3371 .54765 L F
.34322 .5671 m .34513 .5741 L .34427 .5736 L F
.3424 .56682 m .34322 .5671 L .34427 .5736 L F
.34099 .56042 m .34322 .5671 L .3424 .56682 L F
.34022 .56037 m .34099 .56042 L .3424 .56682 L F
.33851 .55416 m .34099 .56042 L .34022 .56037 L F
0 g
.16674 .48338 m
.17323 .48127 L
s
.44695 .46415 m
.45258 .46233 L
s
.44695 .46415 m
.44068 .45337 L
s
.34427 .5736 m .34513 .5741 L .34578 .58058 L .963 .689 .469 r
F
0 g
.34404 .56738 m
.34513 .5741 L
s
.31615 .53454 m
.31795 .53397 L
s
.31615 .53454 m
.31309 .5296 L
s
.26435 .58976 m
.27252 .59389 L
s
.2577 .55337 m
.26241 .5436 L
s
.33154 .53645 m .33468 .54149 L .33413 .54211 L .963 .689 .469 r
F
.33154 .53645 m .33199 .53563 L .33468 .54149 L F
.27799 .53035 m .29415 .53918 L .27782 .53866 L .558 .338 .538 r
F
.27799 .53035 m .29938 .53064 L .29415 .53918 L F
0 g
.29931 .53075 m
.31309 .5296 L
s
.27799 .53035 m
.27816 .52208 L
s
.27019 .51561 m
.27416 .5184 L
s
.27416 .5184 m
.30337 .5184 L
s
.27416 .5184 m
.27019 .51561 L
s
.32909 .53015 m .33245 .53481 L .33199 .53563 L .963 .689 .469 r
F
.32909 .53015 m .32944 .52913 L .33245 .53481 L F
0 g
.42608 .56139 m
.42722 .57143 L
s
.39451 .56239 m
.42608 .56139 L
s
.29247 .58763 m .31049 .58404 L .29754 .59271 L .664 .758 .92 r
F
.039 .916 .04 r
.27798 .5961 m
.29541 .59058 L
s
.29754 .59271 m .31049 .58404 L .31977 .58666 L .664 .758 .92 r
F
0 g
.29754 .59271 m
.30258 .59778 L
s
.3378 .55434 m .33851 .55416 L .34022 .56037 L .963 .689 .469 r
F
.33583 .54844 m .33851 .55416 L .3378 .55434 L F
.33583 .54844 m .33647 .54805 L .33851 .55416 L F
0 g
.31489 .52903 m
.31795 .53397 L
s
.33358 .54272 m .33647 .54805 L .33583 .54844 L .963 .689 .469 r
F
.33358 .54272 m .33413 .54211 L .33647 .54805 L F
.3424 .56682 m .34427 .5736 L .34341 .5731 L F
.34158 .56655 m .3424 .56682 L .34341 .5731 L F
.34022 .56037 m .3424 .56682 L .34158 .56655 L F
.33945 .56031 m .34022 .56037 L .34158 .56655 L F
.3378 .55434 m .34022 .56037 L .33945 .56031 L F
0 g
.3309 .58297 m
.3327 .58241 L
s
.34427 .5736 m .34578 .58058 L .3449 .57987 L .963 .689 .469 r
F
.34341 .5731 m .34427 .5736 L .3449 .57987 L F
.32625 .52395 m .32979 .52812 L .32944 .52913 L F
.32625 .52395 m .32649 .52276 L .32979 .52812 L F
0 g
.32979 .52812 m
.3329 .53399 L
s
.33108 .53727 m .33413 .54211 L .33358 .54272 L .963 .689 .469 r
F
.33108 .53727 m .33154 .53645 L .33413 .54211 L F
0 g
.44631 .45154 m
.45258 .46233 L
s
.32873 .53116 m .33199 .53563 L .33154 .53645 L .963 .689 .469 r
F
.32873 .53116 m .32909 .53015 L .33199 .53563 L F
.17699 .61994 m .19686 .62992 L .17837 .63569 L .558 .338 .538 r
F
.17699 .61994 m .19662 .61377 L .19686 .62992 L F
0 g
.17699 .61994 m
.17701 .60388 L
s
.19662 .61377 m
.19697 .59757 L
s
.21929 .49199 m
.26262 .51294 L
s
.21929 .49199 m
.21376 .49217 L
s
0 0 0 r
2 Mabswid
.16897 .5957 Mdot
.33709 .55452 m .3378 .55434 L .33945 .56031 L .963 .689 .469 r
F
.33519 .54884 m .3378 .55434 L .33709 .55452 L F
.33519 .54884 m .33583 .54844 L .3378 .55434 L F
0 g
.5 Mabswid
.47873 .56805 m
.48439 .56631 L
s
.34158 .56655 m .34341 .5731 L .34256 .57261 L .963 .689 .469 r
F
.34076 .56627 m .34158 .56655 L .34256 .57261 L F
.33945 .56031 m .34158 .56655 L .34076 .56627 L F
0 g
.35239 .55695 m
.35058 .55042 L
s
.35058 .55042 m
.36005 .54743 L
s
.35058 .55042 m
.34843 .54397 L
s
.33303 .54334 m .33583 .54844 L .33519 .54884 L .963 .689 .469 r
F
.33303 .54334 m .33358 .54272 L .33583 .54844 L F
0 g
.34843 .54397 m
.3579 .54097 L
s
.34843 .54397 m
.34598 .53771 L
s
.33867 .56026 m .33945 .56031 L .34076 .56627 L .963 .689 .469 r
F
.33709 .55452 m .33945 .56031 L .33867 .56026 L F
0 g
.30504 .61989 m
.3032 .62412 L
s
.3032 .62412 m
.30504 .61989 L
s
.30504 .61989 m
.32906 .60275 L
s
.34341 .5731 m .3449 .57987 L .34402 .57916 L .963 .689 .469 r
F
.34256 .57261 m .34341 .5731 L .34402 .57916 L F
.3449 .57987 m .34578 .58058 L .34598 .58671 L F
0 g
.34513 .5741 m
.34578 .58058 L
s
.35383 .56347 m
.35239 .55695 L
s
.35239 .55695 m
.36186 .55397 L
s
.326 .52514 m .32944 .52913 L .32909 .53015 L .963 .689 .469 r
F
.326 .52514 m .32625 .52395 L .32944 .52913 L F
0 g
.37664 .50871 m
.40235 .49002 L
s
.39736 .48163 m
.40235 .49002 L
s
.31309 .5296 m
.31489 .52903 L
s
.31309 .5296 m
.30991 .52522 L
s
.33063 .5381 m .33358 .54272 L .33303 .54334 L .963 .689 .469 r
F
.33063 .5381 m .33108 .53727 L .33358 .54272 L F
.32838 .53218 m .33154 .53645 L .33108 .53727 L F
.32838 .53218 m .32873 .53116 L .33154 .53645 L F
0 0 0 r
2 Mabswid
.26756 .59152 Mdot
0 g
.5 Mabswid
.34598 .53771 m
.35544 .5347 L
s
.34598 .53771 m
.34325 .53174 L
s
.23104 .70986 m
.23783 .70862 L
s
.23783 .70862 m
.24187 .70741 L
s
.33637 .55469 m .33709 .55452 L .33867 .56026 L .963 .689 .469 r
F
.33456 .54924 m .33709 .55452 L .33637 .55469 L F
.33456 .54924 m .33519 .54884 L .33709 .55452 L F
0 g
.3117 .52464 m
.31489 .52903 L
s
.34076 .56627 m .34256 .57261 L .3417 .57211 L .963 .689 .469 r
F
.33993 .56599 m .34076 .56627 L .3417 .57211 L F
.33867 .56026 m .34076 .56627 L .33993 .56599 L F
.33248 .54396 m .33519 .54884 L .33456 .54924 L F
.33248 .54396 m .33303 .54334 L .33519 .54884 L F
0 g
.25445 .56271 m
.2577 .55337 L
s
.3449 .57987 m .34598 .58671 L .34509 .5858 L .963 .689 .469 r
F
.34402 .57916 m .3449 .57987 L .34509 .5858 L F
0 g
.35487 .56985 m
.35383 .56347 L
s
.35383 .56347 m
.3633 .56049 L
s
.3379 .56021 m .33867 .56026 L .33993 .56599 L .963 .689 .469 r
F
.33637 .55469 m .33867 .56026 L .3379 .56021 L F
.34256 .57261 m .34402 .57916 L .34314 .57845 L F
.3417 .57211 m .34256 .57261 L .34314 .57845 L F
.32576 .52634 m .32909 .53015 L .32873 .53116 L F
.32576 .52634 m .326 .52514 L .32909 .53015 L F
.15905 .58341 m .18701 .58768 L .16738 .59392 L .664 .758 .92 r
F
.039 .916 .04 r
.16897 .5957 m
.18893 .58965 L
s
0 g
.16738 .59392 m
.17701 .60388 L
s
.31977 .58666 m .33287 .58807 L .33107 .58863 L .664 .758 .92 r
F
0 g
.33082 .59387 m
.33107 .58863 L
s
.3309 .58297 m
.33105 .58787 L
s
.3076 .60281 m
.33107 .58863 L
s
.39141 .54656 m
.38918 .53854 L
s
.38918 .53854 m
.38655 .53062 L
s
.33017 .53892 m .33303 .54334 L .33248 .54396 L .963 .689 .469 r
F
.33017 .53892 m .33063 .5381 L .33303 .54334 L F
0 g
.38655 .53062 m
.38355 .52292 L
s
.32293 .51935 m .32649 .52276 L .32625 .52395 L .963 .689 .469 r
F
.32293 .51935 m .32306 .518 L .32649 .52276 L F
0 g
.32649 .52276 m
.32979 .52812 L
s
.32803 .5332 m .33108 .53727 L .33063 .5381 L .963 .689 .469 r
F
.32803 .5332 m .32838 .53218 L .33108 .53727 L F
0 g
.24187 .70741 m
.2351 .70864 L
s
.31977 .58666 m .32875 .58385 L .33287 .58807 L .664 .758 .92 r
F
0 g
.33262 .59331 m
.33287 .58807 L
s
.3327 .58241 m
.33287 .58807 L
s
.33107 .58863 m
.33287 .58807 L
s
.3932 .55456 m
.39141 .54656 L
s
.34325 .53174 m
.35272 .52873 L
s
.34325 .53174 m
.34031 .52617 L
s
.33456 .54924 m
.33637 .55469 L
s
.33993 .56599 m .3417 .57211 L .34084 .57161 L .963 .689 .469 r
F
.33911 .56571 m .33993 .56599 L .34084 .57161 L F
.3379 .56021 m .33993 .56599 L .33911 .56571 L F
0 g
.33637 .55469 m
.3379 .56021 L
s
.3849 .53983 m
.38705 .54756 L
s
.36005 .54743 m
.3849 .53983 L
s
.38236 .5322 m
.3849 .53983 L
s
.33248 .54396 m
.33456 .54924 L
s
.34402 .57916 m .34509 .5858 L .34421 .58488 L .963 .689 .469 r
F
.34314 .57845 m .34402 .57916 L .34421 .58488 L F
0 g
.3579 .54097 m
.38236 .5322 L
s
.37947 .52479 m
.38236 .5322 L
s
.3417 .57211 m .34314 .57845 L .34226 .57773 L .963 .689 .469 r
F
.34084 .57161 m .3417 .57211 L .34226 .57773 L F
.32551 .52753 m .32873 .53116 L .32838 .53218 L F
.32551 .52753 m .32576 .52634 L .32873 .53116 L F
.27782 .53866 m .29038 .54726 L .27765 .547 L .558 .338 .538 r
F
.27782 .53866 m .29415 .53918 L .29038 .54726 L F
0 g
.27782 .53866 m
.27799 .53035 L
s
.36186 .55397 m
.36005 .54743 L
s
.36005 .54743 m
.3579 .54097 L
s
.25744 .58521 m
.26435 .58976 L
s
.38705 .54756 m
.38877 .55526 L
s
.36186 .55397 m
.38705 .54756 L
s
.3579 .54097 m
.35544 .5347 L
s
.38355 .52292 m
.38023 .51558 L
s
.3228 .5207 m .32625 .52395 L .326 .52514 L .963 .689 .469 r
F
.3228 .5207 m .32293 .51935 L .32625 .52395 L F
0 g
.3555 .576 m
.35487 .56985 L
s
.35487 .56985 m
.36435 .56688 L
s
.44068 .45337 m
.44631 .45154 L
s
.44068 .45337 m
.43418 .44373 L
s
.3633 .56049 m
.36186 .55397 L
s
.32767 .53422 m .33063 .5381 L .33017 .53892 L .963 .689 .469 r
F
.32767 .53422 m .32803 .5332 L .33063 .5381 L F
0 g
.33017 .53892 m
.33248 .54396 L
s
.2693 .67495 m
.27415 .67252 L
s
.27415 .67252 m
.29821 .62994 L
s
.34509 .5858 m .34598 .58671 L .34572 .59239 L .963 .689 .469 r
F
0 g
.34578 .58058 m
.34598 .58671 L
s
.26632 .51378 m
.27019 .51561 L
s
.27019 .51561 m
.30012 .51609 L
s
.27019 .51561 m
.26632 .51378 L
s
.30991 .52522 m
.3117 .52464 L
s
.35544 .5347 m
.37947 .52479 L
s
.37627 .51772 m
.37947 .52479 L
s
.39451 .56239 m
.3932 .55456 L
s
.34314 .57845 m .34421 .58488 L .34332 .58397 L .963 .689 .469 r
F
.34226 .57773 m .34314 .57845 L .34332 .58397 L F
.33911 .56571 m .34084 .57161 L .33998 .57111 L F
0 g
.3379 .56021 m
.33911 .56571 L
s
.35544 .5347 m
.35272 .52873 L
s
.32527 .52873 m .32838 .53218 L .32803 .5332 L .963 .689 .469 r
F
.32527 .52873 m .32551 .52753 L .32838 .53218 L F
.34084 .57161 m .34226 .57773 L .34138 .57702 L F
.33998 .57111 m .34084 .57161 L .34138 .57702 L F
.32266 .52205 m .326 .52514 L .32576 .52634 L F
.32266 .52205 m .3228 .5207 L .326 .52514 L F
.29247 .58763 m .30266 .58095 L .31049 .58404 L .664 .758 .92 r
F
.28738 .58252 m .30266 .58095 L .29247 .58763 L F
0 g
.29247 .58763 m
.29754 .59271 L
s
.039 .916 .04 r
.26756 .59152 m
.28943 .58457 L
s
0 g
.38877 .55526 m
.39003 .56281 L
s
.3633 .56049 m
.38877 .55526 L
s
.31049 .58404 m .32875 .58385 L .31977 .58666 L .664 .758 .92 r
F
.039 .916 .04 r
.29541 .59058 m
.3133 .58494 L
s
0 g
.31977 .58666 m
.33107 .58863 L
s
.34509 .5858 m .34572 .59239 L .34485 .59128 L .963 .689 .469 r
F
.34421 .58488 m .34509 .5858 L .34485 .59128 L F
0 g
.36435 .56688 m
.3633 .56049 L
s
.34031 .52617 m
.34977 .52314 L
s
.34031 .52617 m
.33718 .52107 L
s
.19907 .60985 m .25358 .59649 L .20144 .62214 L .558 .338 .538 r
F
.19907 .60985 m .25203 .58855 L .25358 .59649 L F
0 g
.19863 .59704 m
.19907 .60985 L
s
.039 .916 .04 r
.25205 .58863 m
.2588 .58621 L
s
0 g
.37285 .50243 m
.39736 .48163 L
s
.39218 .47414 m
.39736 .48163 L
s
.38023 .51558 m
.37664 .50871 L
s
.34226 .57773 m .34332 .58397 L .34243 .58305 L .963 .689 .469 r
F
.34138 .57702 m .34226 .57773 L .34243 .58305 L F
0 g
.43982 .44189 m
.44631 .45154 L
s
.33014 .59861 m
.33082 .59387 L
s
.33082 .59387 m
.33262 .59331 L
s
.25248 .57166 m
.25445 .56271 L
s
.32502 .52992 m .32803 .5332 L .32767 .53422 L .963 .689 .469 r
F
0 g
.32767 .53422 m
.33017 .53892 L
s
.32502 .52992 m .32527 .52873 L .32803 .5332 L .963 .689 .469 r
F
.33998 .57111 m .34138 .57702 L .3405 .57631 L F
0 g
.33911 .56571 m
.33998 .57111 L
s
.32253 .5234 m .32576 .52634 L .32551 .52753 L .963 .689 .469 r
F
.32253 .5234 m .32266 .52205 L .32576 .52634 L F
0 g
.35272 .52873 m
.37627 .51772 L
s
.35272 .52873 m
.34977 .52314 L
s
.31953 .51541 m .32306 .518 L .32293 .51935 L .963 .689 .469 r
F
.31953 .51541 m .31955 .51392 L .32306 .518 L F
0 g
.32306 .518 m
.32649 .52276 L
s
.34421 .58488 m .34485 .59128 L .34397 .59018 L .963 .689 .469 r
F
.34332 .58397 m .34421 .58488 L .34397 .59018 L F
0 g
.37282 .5111 m
.37627 .51772 L
s
.3555 .576 m
.36499 .57304 L
s
.3032 .62412 m
.30091 .62749 L
s
.30092 .62749 m
.3032 .62412 L
s
.3032 .62412 m
.32757 .60624 L
s
.33262 .59331 m
.33195 .59805 L
s
.039 .916 .04 r
.18893 .58965 m
.19136 .5889 L
s
0 0 0 r
2 Mabswid
.18893 .58965 Mdot
0 g
.5 Mabswid
.39533 .56995 m
.39451 .56239 L
s
.47214 .57078 m .48513 .57844 L .47947 .58018 L .664 .758 .92 r
F
0 g
.47935 .59145 m
.47947 .58018 L
s
.47873 .56805 m
.47915 .57491 L
s
.34138 .57702 m .34243 .58305 L .34154 .58213 L .963 .689 .469 r
F
.3405 .57631 m .34138 .57702 L .34154 .58213 L F
0 g
.36499 .57304 m
.36435 .56688 L
s
.36435 .56688 m
.39003 .56281 L
s
.39003 .56281 m
.39081 .57008 L
s
.31951 .51689 m .32293 .51935 L .3228 .5207 L .963 .689 .469 r
F
.31951 .51689 m .31953 .51541 L .32293 .51935 L F
.3224 .52476 m .32551 .52753 L .32527 .52873 L F
.3224 .52476 m .32253 .5234 L .32551 .52753 L F
0 0 0 r
2 Mabswid
.19136 .5889 Mdot
.19133 .58886 m .24705 .57494 L .25168 .58027 L .664 .758 .92 r
F
.18591 .58 m .24705 .57494 L .19133 .58886 L F
0 g
.5 Mabswid
.19133 .58886 m
.19863 .59704 L
s
0 0 0 r
2 Mabswid
.3133 .58494 Mdot
.34332 .58397 m .34397 .59018 L .34309 .58908 L .963 .689 .469 r
F
.34243 .58305 m .34332 .58397 L .34309 .58908 L F
.39897 .5691 m .42769 .58094 L .39564 .57709 L .664 .758 .92 r
F
0 g
.5 Mabswid
.39533 .56995 m
.39856 .5701 L
s
.39897 .5691 m .43482 .56954 L .42769 .58094 L .664 .758 .92 r
F
0 g
.39564 .57709 m
.42769 .58094 L
s
.42749 .58975 m
.42769 .58094 L
s
.34485 .59128 m .34572 .59239 L .34502 .59752 L .963 .689 .469 r
F
0 g
.34572 .59239 m
.34598 .58671 L
s
0 0 0 r
2 Mabswid
.2588 .58621 Mdot
.31049 .58404 m .32461 .57961 L .32875 .58385 L .664 .758 .92 r
F
0 g
.5 Mabswid
.32875 .58385 m
.33287 .58807 L
s
.33718 .52107 m
.34666 .51804 L
s
.33718 .52107 m
.33393 .51655 L
s
.3405 .57631 m .34154 .58213 L .34065 .58122 L .963 .689 .469 r
F
0 g
.33998 .57111 m
.3405 .57631 L
s
.30665 .52146 m .30835 .52776 L .29938 .53064 L .558 .338 .538 r
F
.30665 .52146 m .30845 .52088 L .30835 .52776 L F
0 g
.27816 .52208 m
.30665 .52146 L
s
.30841 .52349 m
.30991 .52522 L
s
.30665 .52146 m
.30845 .52088 L
s
.30845 .52088 m
.3117 .52464 L
s
.30337 .5184 m
.30665 .52146 L
s
.3195 .51838 m .3228 .5207 L .32266 .52205 L .963 .689 .469 r
F
.3195 .51838 m .31951 .51689 L .3228 .5207 L F
0 g
.37664 .50871 m
.37285 .50243 L
s
.34977 .52314 m
.37282 .5111 L
s
.34977 .52314 m
.34666 .51804 L
s
.32227 .52611 m .32527 .52873 L .32502 .52992 L .963 .689 .469 r
F
0 g
.32502 .52992 m
.32767 .53422 L
s
.32227 .52611 m .3224 .52476 L .32527 .52873 L .963 .689 .469 r
F
.34243 .58305 m .34309 .58908 L .3422 .58797 L F
.34154 .58213 m .34243 .58305 L .3422 .58797 L F
.27765 .547 m .28779 .55499 L .27748 .55538 L .558 .338 .538 r
F
.27765 .547 m .29038 .54726 L .28779 .55499 L F
0 g
.27765 .547 m
.27782 .53866 L
s
.30266 .58095 m .32461 .57961 L .31049 .58404 L .664 .758 .92 r
F
0 g
.31049 .58404 m
.31977 .58666 L
s
.039 .916 .04 r
.3133 .58494 m
.32588 .58091 L
s
.47214 .57078 m .4832 .56736 L .48513 .57844 L .664 .758 .92 r
F
0 g
.48504 .58971 m
.48513 .57844 L
s
.48439 .56631 m
.48513 .57844 L
s
.47947 .58018 m
.48513 .57844 L
s
.16272 .48472 m
.16674 .48338 L
s
.16272 .48472 m
.15685 .48877 L
s
.30517 .51782 m
.30845 .52088 L
s
.34485 .59128 m .34502 .59752 L .34416 .59624 L .963 .689 .469 r
F
.34397 .59018 m .34485 .59128 L .34416 .59624 L F
.15905 .58341 m .17753 .5775 L .18701 .58768 L .664 .758 .92 r
F
0 g
.18701 .58768 m
.19697 .59757 L
s
.039 .916 .04 r
.11991 .60123 m
.1618 .58713 L
s
0 g
.36916 .50505 m
.37282 .5111 L
s
.25168 .58027 m
.25744 .58521 L
s
.31948 .51987 m .32266 .52205 L .32253 .5234 L .963 .689 .469 r
F
.31948 .51987 m .3195 .51838 L .32266 .52205 L F
.3515 .57747 m .3652 .57886 L .3557 .58182 L .664 .758 .92 r
F
0 g
.35547 .58721 m
.3557 .58182 L
s
.3555 .576 m
.35556 .57788 L
s
.36499 .57304 m
.39081 .57008 L
s
.34154 .58213 m .3422 .58797 L .34132 .58687 L .963 .689 .469 r
F
.34065 .58122 m .34154 .58213 L .34132 .58687 L F
0 g
.39533 .56995 m
.39564 .57709 L
s
.21376 .49217 m
.25914 .5131 L
s
.21376 .49217 m
.20867 .49391 L
s
.34397 .59018 m .34416 .59624 L .3433 .59497 L .963 .689 .469 r
F
.34309 .58908 m .34397 .59018 L .3433 .59497 L F
0 g
.32906 .60275 m
.33014 .59861 L
s
.33014 .59861 m
.33195 .59805 L
s
.29938 .53064 m .30826 .53467 L .29415 .53918 L .558 .338 .538 r
F
.29938 .53064 m .30835 .52776 L .30826 .53467 L F
0 g
.29938 .53064 m
.30665 .52146 L
s
.30835 .52776 m
.30845 .52088 L
s
.26262 .51294 m
.26632 .51378 L
s
.26632 .51378 m
.29696 .51457 L
s
.26632 .51378 m
.26262 .51294 L
s
.16089 .48743 m
.16674 .48338 L
s
.25168 .58027 m
.25248 .57166 L
s
.31612 .51219 m .31955 .51392 L .31953 .51541 L .963 .689 .469 r
F
.31612 .51219 m .31602 .51059 L .31955 .51392 L F
0 g
.31955 .51392 m
.32306 .518 L
s
.31947 .52136 m .32253 .5234 L .3224 .52476 L .963 .689 .469 r
F
.31947 .52136 m .31948 .51987 L .32253 .5234 L F
.17837 .63569 m .19769 .64601 L .18121 .65112 L .558 .338 .538 r
F
.17837 .63569 m .19686 .62992 L .19769 .64601 L F
0 g
.17699 .61994 m
.17837 .63569 L
s
.19662 .61377 m
.19686 .62992 L
s
.33195 .59805 m
.33086 .60219 L
s
0 0 0 r
2 Mabswid
.1618 .58713 Mdot
.34065 .58122 m .34132 .58687 L .34044 .58576 L .963 .689 .469 r
F
0 g
.5 Mabswid
.3405 .57631 m
.34065 .58122 L
s
.34309 .58908 m .3433 .59497 L .34245 .59369 L .963 .689 .469 r
F
.3422 .58797 m .34309 .58908 L .34245 .59369 L F
0 g
.43418 .44373 m
.43982 .44189 L
s
.36892 .49683 m
.39218 .47414 L
s
.28738 .58252 m .296 .57747 L .30266 .58095 L .664 .758 .92 r
F
.28227 .57738 m .296 .57747 L .28738 .58252 L F
0 g
.28738 .58252 m
.29247 .58763 L
s
.039 .916 .04 r
.2588 .58621 m
.28332 .57843 L
s
0 g
.34666 .51804 m
.36916 .50505 L
s
.34666 .51804 m
.34342 .5135 L
s
.31622 .51379 m .31953 .51541 L .31951 .51689 L .963 .689 .469 r
F
.31622 .51379 m .31612 .51219 L .31953 .51541 L F
.31945 .52285 m .3224 .52476 L .32227 .52611 L F
0 g
.32227 .52611 m
.32502 .52992 L
s
.31945 .52285 m .31947 .52136 L .3224 .52476 L .963 .689 .469 r
F
0 g
.33393 .51655 m
.34342 .5135 L
s
.039 .916 .04 r
.32588 .58091 m
.33689 .57734 L
s
0 0 0 r
2 Mabswid
.32588 .58091 Mdot
.3422 .58797 m .34245 .59369 L .34159 .59242 L .963 .689 .469 r
F
.34132 .58687 m .3422 .58797 L .34159 .59242 L F
0 g
.5 Mabswid
.37285 .50243 m
.36892 .49683 L
s
.31632 .51539 m .31951 .51689 L .3195 .51838 L .963 .689 .469 r
F
.31632 .51539 m .31622 .51379 L .31951 .51689 L F
.34416 .59624 m .34502 .59752 L .34387 .60201 L F
0 g
.34502 .59752 m
.34572 .59239 L
s
.36537 .49967 m
.36916 .50505 L
s
.30337 .5184 m
.30517 .51782 L
s
.30337 .5184 m
.30012 .51609 L
s
.29415 .53918 m .30817 .54159 L .29038 .54726 L .558 .338 .538 r
F
.29415 .53918 m .30826 .53467 L .30817 .54159 L F
0 g
.29415 .53918 m
.29938 .53064 L
s
.30091 .62749 m
.29821 .62994 L
s
.29821 .62993 m
.30092 .62749 L
s
.30092 .62749 m
.32572 .60901 L
s
.30266 .58095 m .32045 .57536 L .32461 .57961 L .664 .758 .92 r
F
0 g
.32461 .57961 m
.32875 .58385 L
s
.296 .57747 m .32045 .57536 L .30266 .58095 L .664 .758 .92 r
F
0 g
.30266 .58095 m
.31049 .58404 L
s
.039 .916 .04 r
.28943 .58457 m
.30194 .58061 L
s
.36455 .57339 m .3911 .57696 L .3652 .57886 L .664 .758 .92 r
F
0 g
.36499 .57304 m
.365 .57345 L
s
.3515 .57747 m .36455 .57339 L .3652 .57886 L .664 .758 .92 r
F
0 g
.3557 .58182 m
.3652 .57886 L
s
.36499 .58425 m
.3652 .57886 L
s
.34132 .58687 m .34159 .59242 L .34073 .59114 L .963 .689 .469 r
F
.34044 .58576 m .34132 .58687 L .34073 .59114 L F
0 g
.30826 .53467 m
.30835 .52776 L
s
.30192 .51551 m
.30517 .51782 L
s
.34416 .59624 m .34387 .60201 L .34305 .60058 L .963 .689 .469 r
F
.3433 .59497 m .34416 .59624 L .34305 .60058 L F
0 g
.35482 .59207 m
.35547 .58721 L
s
.35547 .58721 m
.36499 .58425 L
s
.31642 .51699 m .3195 .51838 L .31948 .51987 L .963 .689 .469 r
F
.31642 .51699 m .31632 .51539 L .3195 .51838 L F
0 g
.39543 .5837 m
.39564 .57709 L
s
.22371 .70914 m
.23104 .70986 L
s
.23104 .70986 m
.2351 .70864 L
s
.27748 .55538 m .28624 .5624 L .2773 .56378 L .558 .338 .538 r
F
.27748 .55538 m .28779 .55499 L .28624 .5624 L F
0 g
.27748 .55538 m
.27765 .547 L
s
.42749 .58975 m
.4266 .59773 L
s
.39543 .5837 m
.42749 .58975 L
s
.26393 .67582 m
.2693 .67495 L
s
.2693 .67495 m
.29513 .6314 L
s
.34044 .58576 m .34073 .59114 L .33987 .58987 L .963 .689 .469 r
F
0 g
.34044 .58576 m
.34065 .58122 L
s
.36455 .57339 m .38622 .57179 L .3911 .57696 L .664 .758 .92 r
F
0 g
.39089 .58333 m
.3911 .57696 L
s
.3652 .57886 m
.3911 .57696 L
s
.39081 .57008 m
.3911 .57696 L
s
.3433 .59497 m .34305 .60058 L .34223 .59916 L .963 .689 .469 r
F
.34245 .59369 m .3433 .59497 L .34223 .59916 L F
.31652 .51859 m .31948 .51987 L .31947 .52136 L F
.31652 .51859 m .31642 .51699 L .31948 .51987 L F
0 g
.32757 .60624 m
.32906 .60275 L
s
.32906 .60275 m
.33086 .60219 L
s
.4784 .60165 m
.47935 .59145 L
s
.47935 .59145 m
.48504 .58971 L
s
.20144 .62214 m .25642 .60406 L .20596 .63385 L .558 .338 .538 r
F
.20144 .62214 m .25358 .59649 L .25642 .60406 L F
0 g
.19907 .60985 m
.20144 .62214 L
s
.039 .916 .04 r
.19863 .59704 m
.25168 .58027 L
s
.34245 .59369 m .34223 .59916 L .34141 .59774 L .963 .689 .469 r
F
.34159 .59242 m .34245 .59369 L .34141 .59774 L F
.34729 .57309 m .36455 .57339 L .3515 .57747 L .664 .758 .92 r
F
0 g
.3515 .57747 m
.3557 .58182 L
s
.33086 .60219 m
.32939 .60568 L
s
.31662 .5202 m .31947 .52136 L .31945 .52285 L .963 .689 .469 r
F
0 g
.31945 .52285 m
.32227 .52611 L
s
.31662 .5202 m .31652 .51859 L .31947 .52136 L .963 .689 .469 r
F
0 g
.2351 .70864 m
.22778 .70791 L
s
.31274 .50975 m .31602 .51059 L .31612 .51219 L .963 .689 .469 r
F
.31274 .50975 m .31252 .50807 L .31602 .51059 L F
0 g
.31602 .51059 m
.31955 .51392 L
s
.1521 .57233 m .17753 .5775 L .15905 .58341 L .664 .758 .92 r
F
.039 .916 .04 r
.1618 .58713 m
.18117 .58151 L
s
0 g
.15905 .58341 m
.16738 .59392 L
s
.039 .916 .04 r
.11109 .59356 m
.15552 .57814 L
s
0 0 0 r
2 Mabswid
.25168 .58027 Mdot
0 g
.5 Mabswid
.25168 .58027 m
.25203 .58855 L
s
.29038 .54726 m .30807 .54854 L .28779 .55499 L .558 .338 .538 r
F
.29038 .54726 m .30817 .54159 L .30807 .54854 L F
0 g
.29038 .54726 m
.29415 .53918 L
s
.039 .916 .04 r
.33689 .57734 m
.34793 .57376 L
s
.33062 .51267 m .34359 .51555 L .33056 .51974 L .558 .338 .538 r
F
.33062 .51267 m .34011 .50962 L .34359 .51555 L F
0 g
.34342 .5135 m
.36537 .49967 L
s
.32728 .5095 m
.33062 .51267 L
s
.34159 .59242 m .34141 .59774 L .34058 .59631 L .963 .689 .469 r
F
.34073 .59114 m .34159 .59242 L .34058 .59631 L F
.31295 .51144 m .31612 .51219 L .31622 .51379 L F
.31295 .51144 m .31274 .50975 L .31612 .51219 L F
0 g
.25914 .5131 m
.26262 .51294 L
s
.26262 .51294 m
.29395 .51387 L
s
.26262 .51294 m
.25915 .5131 L
s
.48504 .58971 m
.4841 .59992 L
s
.36435 .58911 m
.36499 .58425 L
s
.36499 .58425 m
.39089 .58333 L
s
.039 .916 .04 r
.18117 .58151 m
.18595 .58009 L
s
0 0 0 r
2 Mabswid
.18117 .58151 Mdot
.34073 .59114 m .34058 .59631 L .33976 .59488 L .963 .689 .469 r
F
.33987 .58987 m .34073 .59114 L .33976 .59488 L F
.31317 .51312 m .31622 .51379 L .31632 .51539 L F
.31317 .51312 m .31295 .51144 L .31622 .51379 L F
.296 .57747 m .31628 .57109 L .32045 .57536 L .664 .758 .92 r
F
0 g
.5 Mabswid
.32045 .57536 m
.32461 .57961 L
s
.29035 .57366 m .31628 .57109 L .296 .57747 L .664 .758 .92 r
F
.039 .916 .04 r
.30194 .58061 m
.31997 .57486 L
s
.28227 .57738 m .29035 .57366 L .296 .57747 L .664 .758 .92 r
F
0 g
.296 .57747 m
.30266 .58095 L
s
.34305 .60058 m .34387 .60201 L .34229 .60579 L .963 .689 .469 r
F
0 g
.34387 .60201 m
.34502 .59752 L
s
.30012 .51609 m
.30192 .51551 L
s
.30012 .51609 m
.29696 .51457 L
s
.30817 .54159 m
.30826 .53467 L
s
.35374 .59633 m
.35482 .59207 L
s
.35482 .59207 m
.36435 .58911 L
s
.31339 .51481 m .31632 .51539 L .31642 .51699 L .963 .689 .469 r
F
.31339 .51481 m .31317 .51312 L .31632 .51539 L F
.33987 .58987 m .33976 .59488 L .33894 .59346 L F
0 g
.33987 .58987 m
.34044 .58576 L
s
.27713 .57222 m .29035 .57366 L .28227 .57738 L .664 .758 .92 r
F
0 g
.28227 .57738 m
.28738 .58252 L
s
.039 .916 .04 r
.28332 .57843 m
.29279 .57544 L
s
.3649 .49203 m .38689 .46768 L .40069 .4747 L .558 .338 .538 r
F
0 g
.38158 .46237 m
.38689 .46768 L
s
.29877 .51399 m
.30192 .51551 L
s
.34305 .60058 m .34229 .60579 L .34152 .60424 L .963 .689 .469 r
F
.34223 .59916 m .34305 .60058 L .34152 .60424 L F
0 0 0 r
2 Mabswid
.18595 .58009 Mdot
0 g
.5 Mabswid
.3947 .58968 m
.39543 .5837 L
s
.18591 .58 m .24358 .5692 L .24705 .57494 L .664 .758 .92 r
F
0 g
.24705 .57494 m
.25168 .58027 L
s
.18257 .57038 m .24358 .5692 L .18591 .58 L .664 .758 .92 r
F
.039 .916 .04 r
.19136 .5889 m
.24621 .57376 L
s
0 g
.18591 .58 m
.19133 .58886 L
s
.31361 .5165 m .31642 .51699 L .31652 .51859 L .963 .689 .469 r
F
.31361 .5165 m .31339 .51481 L .31642 .51699 L F
.46457 .56134 m .4832 .56736 L .47214 .57078 L .664 .758 .92 r
F
0 g
.47214 .57078 m
.47947 .58018 L
s
.39089 .58333 m
.39018 .58908 L
s
.34223 .59916 m .34152 .60424 L .34075 .60268 L .963 .689 .469 r
F
.34141 .59774 m .34223 .59916 L .34075 .60268 L F
.34011 .50962 m .36149 .50338 L .34359 .51555 L .558 .338 .538 r
F
.34011 .50962 m .36149 .49505 L .36149 .50338 L F
0 g
.33062 .51267 m
.34011 .50962 L
s
.34011 .50962 m
.36149 .49505 L
s
.33679 .50644 m
.34011 .50962 L
s
.2773 .56378 m .28564 .56953 L .27713 .57222 L .558 .338 .538 r
F
.2773 .56378 m .28624 .5624 L .28564 .56953 L F
0 g
.2773 .56378 m
.27748 .55538 L
s
.29821 .62994 m
.29513 .6314 L
s
.32352 .611 m
.29821 .62993 L
s
.29513 .6314 m
.29821 .62993 L
s
.31382 .51819 m .31652 .51859 L .31662 .5202 L .963 .689 .469 r
F
0 g
.31662 .5202 m
.31945 .52285 L
s
.31382 .51819 m .31361 .5165 L .31652 .51859 L .963 .689 .469 r
F
.28779 .55499 m .30798 .55551 L .28624 .5624 L .558 .338 .538 r
F
.28779 .55499 m .30807 .54854 L .30798 .55551 L F
0 g
.28779 .55499 m
.29038 .54726 L
s
.039 .916 .04 r
.31997 .57486 m
.33103 .5713 L
s
0 0 0 r
2 Mabswid
.31997 .57486 Mdot
0 g
.5 Mabswid
.32572 .60901 m
.32757 .60624 L
s
.32757 .60624 m
.32939 .60568 L
s
.34141 .59774 m .34075 .60268 L .33998 .60113 L .963 .689 .469 r
F
.34058 .59631 m .34141 .59774 L .33998 .60113 L F
.36315 .56813 m .38622 .57179 L .36455 .57339 L .664 .758 .92 r
F
.34729 .57309 m .36315 .56813 L .36455 .57339 L F
0 g
.36455 .57339 m
.3652 .57886 L
s
.42755 .43537 m .43973 .44603 L .42868 .44962 L .558 .338 .538 r
F
.42755 .43537 m .43321 .43352 L .43973 .44603 L F
0 g
.43321 .43352 m
.43982 .44189 L
s
.42755 .43537 m
.43321 .43352 L
s
.42089 .42845 m
.42755 .43537 L
s
.20867 .49391 m
.25596 .51428 L
s
.20867 .49391 m
.2041 .49722 L
s
.32939 .60568 m
.32753 .60844 L
s
.34058 .59631 m .33998 .60113 L .33921 .59958 L .963 .689 .469 r
F
.33976 .59488 m .34058 .59631 L .33921 .59958 L F
.33056 .51974 m .34635 .52175 L .3305 .52683 L .558 .338 .538 r
F
.33056 .51974 m .34359 .51555 L .34635 .52175 L F
0 g
.33056 .51974 m
.33062 .51267 L
s
.32728 .5095 m
.33679 .50644 L
s
.32728 .5095 m
.32398 .50711 L
s
.30946 .50815 m .31252 .50807 L .31274 .50975 L .963 .689 .469 r
F
.30946 .50815 m .30913 .5064 L .31252 .50807 L F
0 g
.31252 .50807 m
.31602 .51059 L
s
.34306 .5687 m .36315 .56813 L .34729 .57309 L .664 .758 .92 r
F
0 g
.34729 .57309 m
.3515 .57747 L
s
.36315 .56813 m .38131 .5666 L .38622 .57179 L .664 .758 .92 r
F
.039 .916 .04 r
.34793 .57376 m
.36338 .56882 L
s
0 g
.38622 .57179 m
.3911 .57696 L
s
.36329 .59337 m
.36435 .58911 L
s
.36435 .58911 m
.39018 .58908 L
s
.33976 .59488 m .33921 .59958 L .33844 .59802 L .963 .689 .469 r
F
.33894 .59346 m .33976 .59488 L .33844 .59802 L F
0 g
.4266 .59773 m
.42505 .60473 L
s
.3947 .58968 m
.4266 .59773 L
s
.25203 .58855 m
.25358 .59649 L
s
.30978 .50989 m .31274 .50975 L .31295 .51144 L .963 .689 .469 r
F
.30978 .50989 m .30946 .50815 L .31274 .50975 L F
0 g
.15685 .48877 m
.16089 .48743 L
s
.15685 .48877 m
.15174 .4947 L
s
.3649 .49203 m .40069 .4747 L .37329 .49798 L .558 .338 .538 r
F
0 g
.36149 .49505 m
.36537 .49967 L
s
.3649 .49203 m
.38689 .46768 L
s
.3649 .49203 m
.36892 .49683 L
s
.36087 .48809 m
.3649 .49203 L
s
.40004 .56178 m .43482 .56954 L .39897 .5691 L .664 .758 .92 r
F
0 g
.39564 .57709 m
.39897 .5691 L
s
.40004 .56178 m .43776 .55935 L .43482 .56954 L .664 .758 .92 r
F
0 g
.42769 .58094 m
.43482 .56954 L
s
.3576 .49126 m
.36149 .49505 L
s
.33894 .59346 m .33844 .59802 L .33767 .59647 L .963 .689 .469 r
F
0 g
.33894 .59346 m
.33987 .58987 L
s
.42657 .42659 m
.43321 .43352 L
s
.31011 .51163 m .31295 .51144 L .31317 .51312 L .963 .689 .469 r
F
.31011 .51163 m .30978 .50989 L .31295 .51144 L F
.1521 .57233 m .16856 .56704 L .17753 .5775 L .664 .758 .92 r
F
0 g
.17753 .5775 m
.18701 .58768 L
s
.039 .916 .04 r
.15552 .57814 m
.17368 .57312 L
s
0 0 0 r
2 Mabswid
.15552 .57814 Mdot
0 g
.5 Mabswid
.30807 .54854 m
.30817 .54159 L
s
.18121 .65112 m .19912 .66205 L .18561 .66621 L .558 .338 .538 r
F
.18121 .65112 m .19769 .64601 L .19912 .66205 L F
0 g
.17837 .63569 m
.18121 .65112 L
s
.19686 .62992 m
.19769 .64601 L
s
.28564 .56953 m .31209 .5668 L .29035 .57366 L .664 .758 .92 r
F
.27713 .57222 m .28564 .56953 L .29035 .57366 L F
.29035 .57366 m .31209 .5668 L .31628 .57109 L F
0 g
.29035 .57366 m
.296 .57747 L
s
.31628 .57109 m
.32045 .57536 L
s
.46457 .56134 m .47997 .55656 L .4832 .56736 L .664 .758 .92 r
F
0 g
.4832 .56736 m
.48513 .57844 L
s
.35226 .59991 m
.35374 .59633 L
s
.35374 .59633 m
.36329 .59337 L
s
.31044 .51338 m .31317 .51312 L .31339 .51481 L .963 .689 .469 r
F
.31044 .51338 m .31011 .51163 L .31317 .51312 L F
0 g
.29696 .51457 m
.29877 .51399 L
s
.29696 .51457 m
.29395 .51387 L
s
.15579 .49336 m
.16089 .48743 L
s
.34152 .60424 m .34229 .60579 L .34031 .60878 L .963 .689 .469 r
F
0 g
.34229 .60579 m
.34387 .60201 L
s
.31077 .51513 m .31339 .51481 L .31361 .5165 L .963 .689 .469 r
F
.31077 .51513 m .31044 .51338 L .31339 .51481 L F
0 g
.25596 .51428 m
.25914 .5131 L
s
.25915 .5131 m
.29113 .51401 L
s
.25915 .5131 m
.25597 .51429 L
s
.28624 .5624 m .30789 .5625 L .28564 .56953 L .558 .338 .538 r
F
.039 .916 .04 r
.29279 .57544 m
.31396 .56871 L
s
.28624 .5624 m .30798 .55551 L .30789 .5625 L .558 .338 .538 r
F
0 g
.28624 .5624 m
.28779 .55499 L
s
.29576 .51329 m
.29877 .51399 L
s
.34152 .60424 m .34031 .60878 L .33961 .60713 L .963 .689 .469 r
F
.34075 .60268 m .34152 .60424 L .33961 .60713 L F
.3111 .51687 m .31361 .5165 L .31382 .51819 L F
0 g
.31382 .51819 m
.31662 .5202 L
s
.3111 .51687 m .31077 .51513 L .31361 .5165 L .963 .689 .469 r
F
0 g
.4766 .61063 m
.4784 .60165 L
s
.4784 .60165 m
.4841 .59992 L
s
.33679 .50644 m
.3335 .50404 L
s
.39018 .58908 m
.38898 .59412 L
s
.39346 .59491 m
.3947 .58968 L
s
0 0 0 r
2 Mabswid
.24621 .57376 Mdot
.34075 .60268 m .33961 .60713 L .3389 .60547 L .963 .689 .469 r
F
.33998 .60113 m .34075 .60268 L .3389 .60547 L F
0 g
.5 Mabswid
.25814 .67511 m
.26393 .67582 L
s
.26393 .67582 m
.29172 .63186 L
s
.33998 .60113 m .3389 .60547 L .3382 .60382 L .963 .689 .469 r
F
.33921 .59958 m .33998 .60113 L .3382 .60382 L F
.27713 .57222 m .28598 .57639 L .27696 .5807 L .558 .338 .538 r
F
.27713 .57222 m .28564 .56953 L .28598 .57639 L F
.27196 .56704 m .28564 .56953 L .27713 .57222 L .664 .758 .92 r
F
0 0 0 r
2 Mabswid
.27713 .57222 Mdot
.039 .916 .04 r
.5 Mabswid
.25168 .58027 m
.27713 .57222 L
s
0 g
.27722 .568 m
.2773 .56378 L
s
.20596 .63385 m .26078 .6112 L .21303 .64487 L .558 .338 .538 r
F
.20596 .63385 m .25642 .60406 L .26078 .6112 L F
0 g
.20144 .62214 m
.20596 .63385 L
s
.32352 .611 m
.32572 .60901 L
s
.32572 .60901 m
.32753 .60844 L
s
.3305 .52683 m .34844 .5282 L .33044 .53394 L .558 .338 .538 r
F
.3305 .52683 m .34635 .52175 L .34844 .5282 L F
0 g
.3305 .52683 m
.33056 .51974 L
s
.34359 .51555 m .36148 .51175 L .34635 .52175 L .558 .338 .538 r
F
.34359 .51555 m .36149 .50338 L .36148 .51175 L F
0 g
.34011 .50962 m
.34359 .51555 L
s
.33679 .50644 m
.3576 .49126 L
s
.36149 .50338 m
.36149 .49505 L
s
.33921 .59958 m .3382 .60382 L .33749 .60216 L .963 .689 .469 r
F
.33844 .59802 m .33921 .59958 L .33749 .60216 L F
0 0 0 r
2 Mabswid
.36338 .56882 Mdot
0 g
.5 Mabswid
.32398 .50711 m
.3335 .50404 L
s
.32398 .50711 m
.32078 .50552 L
s
.32753 .60844 m
.32534 .61043 L
s
.33844 .59802 m .33749 .60216 L .33678 .60051 L .963 .689 .469 r
F
.33767 .59647 m .33844 .59802 L .33678 .60051 L F
0 g
.4841 .59992 m
.48232 .60889 L
s
.36087 .48809 m
.38158 .46237 L
s
.37633 .45829 m
.38158 .46237 L
s
.36183 .59695 m
.36329 .59337 L
s
.36329 .59337 m
.38898 .59412 L
s
.29513 .6314 m
.29172 .63186 L
s
.29173 .63186 m
.29513 .6314 L
s
.29513 .6314 m
.32102 .61217 L
s
.33767 .59647 m .33678 .60051 L .33608 .59885 L .963 .689 .469 r
F
0 g
.33767 .59647 m
.33894 .59346 L
s
.36107 .56305 m .38131 .5666 L .36315 .56813 L .664 .758 .92 r
F
.34306 .5687 m .36107 .56305 L .36315 .56813 L F
0 g
.36315 .56813 m
.36455 .57339 L
s
.30632 .5074 m .30913 .5064 L .30946 .50815 L .963 .689 .469 r
F
.30632 .5074 m .30588 .50563 L .30913 .5064 L F
0 g
.30913 .5064 m
.31252 .50807 L
s
.33881 .56429 m .36107 .56305 L .34306 .5687 L .664 .758 .92 r
F
0 g
.34306 .5687 m
.34729 .57309 L
s
.039 .916 .04 r
.33103 .5713 m
.34212 .56773 L
s
0 g
.21596 .70643 m
.22371 .70914 L
s
.22371 .70914 m
.22778 .70791 L
s
.30798 .55551 m
.30807 .54854 L
s
.30676 .50917 m .30946 .50815 L .30978 .50989 L .963 .689 .469 r
F
.30676 .50917 m .30632 .5074 L .30946 .50815 L F
.3072 .51095 m .30978 .50989 L .31011 .51163 L F
.3072 .51095 m .30676 .50917 L .30978 .50989 L F
0 g
.25358 .59649 m
.25642 .60406 L
s
.35376 .48838 m
.3576 .49126 L
s
.36087 .48809 m
.35689 .48509 L
s
.36107 .56305 m .37638 .56138 L .38131 .5666 L .664 .758 .92 r
F
0 g
.38131 .5666 m
.38622 .57179 L
s
.039 .916 .04 r
.36338 .56882 m
.37873 .56386 L
s
.31396 .56871 m
.32507 .56516 L
s
0 0 0 r
2 Mabswid
.31396 .56871 Mdot
.30764 .51272 m .31011 .51163 L .31044 .51338 L .963 .689 .469 r
F
.30764 .51272 m .3072 .51095 L .31011 .51163 L F
.039 .916 .04 r
.5 Mabswid
.17368 .57312 m
.18261 .57054 L
s
0 0 0 r
2 Mabswid
.17368 .57312 Mdot
.28564 .56953 m .30779 .56951 L .28598 .57639 L .558 .338 .538 r
F
.28564 .56953 m .30789 .5625 L .31209 .5668 L .664 .758 .92 r
F
.28564 .56953 m .30789 .5625 L .30779 .56951 L .558 .338 .538 r
F
0 g
.5 Mabswid
.31209 .5668 m
.31628 .57109 L
s
.27196 .56704 m .28185 .56509 L .28564 .56953 L .664 .758 .92 r
F
.28185 .56509 m .30789 .5625 L .28564 .56953 L F
0 g
.28605 .56467 m
.28624 .5624 L
s
.039 .916 .04 r
.27713 .57222 m
.28564 .56953 L
s
0 0 0 r
2 Mabswid
.28564 .56953 Mdot
0 g
.5 Mabswid
.3504 .60274 m
.35226 .59991 L
s
.35226 .59991 m
.36183 .59695 L
s
.22778 .70791 m
.22005 .7052 L
s
.30808 .5145 m .31044 .51338 L .31077 .51513 L .963 .689 .469 r
F
.30808 .5145 m .30764 .51272 L .31044 .51338 L F
0 g
.29395 .51387 m
.29576 .51329 L
s
.29395 .51387 m
.29113 .51401 L
s
.30851 .51627 m .31077 .51513 L .3111 .51687 L .963 .689 .469 r
F
0 g
.3111 .51687 m
.31382 .51819 L
s
.30851 .51627 m .30808 .5145 L .31077 .51513 L .963 .689 .469 r
F
.33961 .60713 m .34031 .60878 L .33796 .61094 L F
0 g
.34031 .60878 m
.34229 .60579 L
s
.29295 .51343 m
.29576 .51329 L
s
.3335 .50404 m
.35376 .48838 L
s
.3335 .50404 m
.33032 .50244 L
s
.33961 .60713 m .33796 .61094 L .33733 .60921 L .963 .689 .469 r
F
.3389 .60547 m .33961 .60713 L .33733 .60921 L F
0 g
.42505 .60473 m
.42284 .61063 L
s
.39346 .59491 m
.42505 .60473 L
s
.3389 .60547 m .33733 .60921 L .3367 .60748 L .963 .689 .469 r
F
.3382 .60382 m .3389 .60547 L .3367 .60748 L F
.1466 .56064 m .16856 .56704 L .1521 .57233 L .664 .758 .92 r
F
0 g
.1521 .57233 m
.15905 .58341 L
s
.33044 .53394 m .34991 .53487 L .33038 .54108 L .558 .338 .538 r
F
.33044 .53394 m .34844 .5282 L .34991 .53487 L F
0 g
.33044 .53394 m
.3305 .52683 L
s
.38898 .59412 m
.38731 .59836 L
s
.42089 .42845 m
.42657 .42659 L
s
.42089 .42845 m
.41433 .4231 L
s
.18257 .57038 m .24139 .56302 L .24358 .5692 L .664 .758 .92 r
F
0 g
.24358 .5692 m
.24705 .57494 L
s
.3382 .60382 m .3367 .60748 L .33608 .60575 L .963 .689 .469 r
F
.33749 .60216 m .3382 .60382 L .33608 .60575 L F
.42868 .44962 m .44504 .45906 L .42966 .46404 L .558 .338 .538 r
F
.42868 .44962 m .43973 .44603 L .44504 .45906 L F
0 g
.42755 .43537 m
.42868 .44962 L
s
.43321 .43352 m
.43973 .44603 L
s
.39174 .59931 m
.39346 .59491 L
s
.25313 .51647 m
.25596 .51428 L
s
.25597 .51429 m
.28856 .51499 L
s
.25597 .51429 m
.25313 .51647 L
s
.27696 .5807 m .28729 .58297 L .27678 .5892 L .558 .338 .538 r
F
.27696 .5807 m .28598 .57639 L .28729 .58297 L F
0 g
.27696 .5807 m
.27713 .57222 L
s
.33749 .60216 m .33608 .60575 L .33545 .60402 L .963 .689 .469 r
F
.33678 .60051 m .33749 .60216 L .33545 .60402 L F
.37329 .49798 m .41035 .48315 L .37943 .5047 L .558 .338 .538 r
F
.37329 .49798 m .40069 .4747 L .41035 .48315 L F
0 g
.3649 .49203 m
.37329 .49798 L
s
.38689 .46768 m
.40069 .4747 L
s
.32102 .61217 m
.32352 .611 L
s
.32352 .611 m
.32534 .61043 L
s
.33678 .60051 m .33545 .60402 L .33482 .60229 L .963 .689 .469 r
F
.33608 .59885 m .33678 .60051 L .33482 .60229 L F
0 0 0 r
2 Mabswid
.18261 .57054 Mdot
0 g
.5 Mabswid
.2041 .49722 m
.25313 .51647 L
s
.2041 .49722 m
.20015 .50204 L
s
.34635 .52175 m .36147 .52015 L .34844 .5282 L .558 .338 .538 r
F
.34635 .52175 m .36148 .51175 L .36147 .52015 L F
0 g
.34359 .51555 m
.34635 .52175 L
s
.36148 .51175 m
.36149 .50338 L
s
.18172 .55986 m .24139 .56302 L .18257 .57038 L .664 .758 .92 r
F
.039 .916 .04 r
.18595 .58009 m
.24251 .56671 L
s
0 g
.18257 .57038 m
.18591 .58 L
s
.45678 .55187 m .47997 .55656 L .46457 .56134 L .664 .758 .92 r
F
0 g
.46457 .56134 m
.47214 .57078 L
s
.33608 .59885 m .33482 .60229 L .33419 .60056 L .963 .689 .469 r
F
0 g
.33608 .59885 m
.33767 .59647 L
s
.32078 .50552 m
.33032 .50244 L
s
.32078 .50552 m
.31773 .50479 L
s
0 0 0 r
2 Mabswid
.37873 .56386 Mdot
0 g
.5 Mabswid
.32534 .61043 m
.32284 .61161 L
s
.35998 .59978 m
.36183 .59695 L
s
.36183 .59695 m
.38731 .59836 L
s
.26677 .56183 m .28185 .56509 L .27196 .56704 L .664 .758 .92 r
F
0 g
.27196 .56704 m
.27713 .57222 L
s
.039 .916 .04 r
.24621 .57376 m
.27091 .56597 L
s
0 0 0 r
2 Mabswid
.32507 .56516 Mdot
0 g
.5 Mabswid
.42002 .42122 m
.42657 .42659 L
s
.33881 .56429 m .35835 .55815 L .36107 .56305 L .664 .758 .92 r
F
.33455 .55987 m .35835 .55815 L .33881 .56429 L F
0 g
.33881 .56429 m
.34306 .5687 L
s
.039 .916 .04 r
.32507 .56516 m
.33622 .5616 L
s
.30339 .50753 m .30588 .50563 L .30632 .5074 L .963 .689 .469 r
F
.30339 .50753 m .30285 .50576 L .30588 .50563 L F
0 g
.30588 .50563 m
.30913 .5064 L
s
.28598 .57639 m .3077 .57655 L .28729 .58297 L .558 .338 .538 r
F
.28598 .57639 m .30779 .56951 L .3077 .57655 L F
0 g
.28564 .56953 m
.28598 .57639 L
s
.30393 .50931 m .30632 .5074 L .30676 .50917 L .963 .689 .469 r
F
.30393 .50931 m .30339 .50753 L .30632 .5074 L F
0 0 0 r
2 Mabswid
.27091 .56597 Mdot
.30447 .51108 m .30676 .50917 L .3072 .51095 L .963 .689 .469 r
F
.30447 .51108 m .30393 .50931 L .30676 .50917 L F
0 g
.5 Mabswid
.29172 .63186 m
.28805 .6313 L
s
.28805 .63129 m
.29173 .63186 L
s
.29173 .63186 m
.31825 .61252 L
s
.35835 .55815 m .37638 .56138 L .36107 .56305 L .664 .758 .92 r
F
.039 .916 .04 r
.34212 .56773 m
.36048 .56187 L
s
0 g
.36107 .56305 m
.36315 .56813 L
s
.39939 .55495 m .43776 .55935 L .40004 .56178 L .664 .758 .92 r
F
0 g
.39897 .5691 m
.40004 .56178 L
s
0 0 0 r
2 Mabswid
.24251 .56671 Mdot
.30501 .51285 m .3072 .51095 L .30764 .51272 L .963 .689 .469 r
F
.30501 .51285 m .30447 .51108 L .3072 .51095 L F
.30555 .51462 m .30764 .51272 L .30808 .5145 L F
.30555 .51462 m .30501 .51285 L .30764 .51272 L F
0 g
.5 Mabswid
.34819 .60478 m
.3504 .60274 L
s
.3504 .60274 m
.35998 .59978 L
s
.35004 .48646 m
.35376 .48838 L
s
.28185 .56509 m .30366 .55818 L .30789 .5625 L .664 .758 .92 r
F
0 g
.30789 .5625 m
.30798 .55551 L
s
.30789 .5625 m
.31209 .5668 L
s
.27902 .56032 m .30366 .55818 L .28185 .56509 L .664 .758 .92 r
F
.039 .916 .04 r
.28564 .56953 m
.30789 .5625 L
s
.26677 .56183 m .27902 .56032 L .28185 .56509 L .664 .758 .92 r
F
.039 .916 .04 r
.27091 .56597 m
.28044 .56296 L
s
0 g
.28185 .56509 m
.28564 .56953 L
s
.30609 .5164 m .30808 .5145 L .30851 .51627 L .963 .689 .469 r
F
0 g
.30851 .51627 m
.3111 .51687 L
s
.30609 .5164 m .30555 .51462 L .30808 .5145 L .963 .689 .469 r
F
0 g
.35689 .48509 m
.37633 .45829 L
s
.35689 .48509 m
.35303 .48309 L
s
.29113 .51401 m
.29295 .51343 L
s
.29113 .51401 m
.28856 .51499 L
s
.15174 .4947 m
.15579 .49336 L
s
.15174 .4947 m
.14748 .50245 L
s
.47398 .61821 m
.4766 .61063 L
s
.4766 .61063 m
.48232 .60889 L
s
.37124 .45553 m
.37633 .45829 L
s
.35835 .55815 m .37143 .55613 L .37638 .56138 L .664 .758 .92 r
F
0 g
.37638 .56138 m
.38131 .5666 L
s
.33038 .54108 m .35077 .54175 L .33032 .54824 L .558 .338 .538 r
F
.33038 .54108 m .34991 .53487 L .35077 .54175 L F
0 g
.33038 .54108 m
.33044 .53394 L
s
.039 .916 .04 r
.36048 .56187 m
.37304 .55784 L
s
.39939 .55495 m .43786 .54996 L .43776 .55935 L .664 .758 .92 r
F
0 g
.43482 .56954 m
.43776 .55935 L
s
.039 .916 .04 r
.37873 .56386 m
.39974 .55697 L
s
0 g
.33032 .50244 m
.35004 .48646 L
s
.33032 .50244 m
.32728 .5017 L
s
.29038 .51441 m
.29295 .51343 L
s
.18561 .66621 m .20118 .67803 L .19172 .68092 L .558 .338 .538 r
F
.18561 .66621 m .19912 .66205 L .20118 .67803 L F
0 g
.18121 .65112 m
.18561 .66621 L
s
.19769 .64601 m
.19912 .66205 L
s
.33733 .60921 m .33796 .61094 L .33528 .61222 L .963 .689 .469 r
F
0 g
.33796 .61094 m
.34031 .60878 L
s
.25201 .67281 m
.25814 .67511 L
s
.33733 .60921 m .33528 .61222 L .33474 .61044 L .963 .689 .469 r
F
.3367 .60748 m .33733 .60921 L .33474 .61044 L F
.3367 .60748 m .33474 .61044 L .3342 .60867 L F
.33608 .60575 m .3367 .60748 L .3342 .60867 L F
.33608 .60575 m .3342 .60867 L .33366 .60689 L F
.33545 .60402 m .33608 .60575 L .33366 .60689 L F
0 g
.15155 .5011 m
.15579 .49336 L
s
.33545 .60402 m .33366 .60689 L .33312 .60512 L .963 .689 .469 r
F
.33482 .60229 m .33545 .60402 L .33312 .60512 L F
.1466 .56064 m .16009 .55628 L .16856 .56704 L .664 .758 .92 r
F
0 g
.16856 .56704 m
.17753 .5775 L
s
.27678 .5892 m .28964 .58924 L .2766 .59774 L .558 .338 .538 r
F
.27678 .5892 m .28729 .58297 L .28964 .58924 L F
0 g
.27678 .5892 m
.27696 .5807 L
s
.33482 .60229 m .33312 .60512 L .33257 .60334 L .963 .689 .469 r
F
.33419 .60056 m .33482 .60229 L .33257 .60334 L F
.039 .916 .04 r
.30789 .5625 m
.31906 .55897 L
s
0 0 0 r
2 Mabswid
.30789 .5625 Mdot
0 g
.5 Mabswid
.30779 .56951 m
.30789 .5625 L
s
.33419 .60056 m .33257 .60334 L .33203 .60156 L .963 .689 .469 r
F
0 g
.33419 .60056 m
.33608 .59885 L
s
.38731 .59836 m
.38519 .60171 L
s
.48232 .60889 m
.47972 .61647 L
s
.21303 .64487 m .26704 .61779 L .22348 .65495 L .558 .338 .538 r
F
.21303 .64487 m .26078 .6112 L .26704 .61779 L F
0 g
.20596 .63385 m
.21303 .64487 L
s
.25814 .67511 m
.28805 .6313 L
s
.25642 .60406 m
.26078 .6112 L
s
.34844 .5282 m .36146 .52859 L .34991 .53487 L .558 .338 .538 r
F
.34844 .5282 m .36147 .52015 L .36146 .52859 L F
0 g
.34635 .52175 m
.34844 .5282 L
s
.36147 .52015 m
.36148 .51175 L
s
.31825 .61252 m
.32102 .61217 L
s
.32102 .61217 m
.32284 .61161 L
s
0 0 0 r
2 Mabswid
.28044 .56296 Mdot
.45678 .55187 m .47551 .54603 L .47997 .55656 L .664 .758 .92 r
F
0 g
.5 Mabswid
.47997 .55656 m
.4832 .56736 L
s
.38955 .6028 m
.39174 .59931 L
s
.39174 .59931 m
.42284 .61063 L
s
.31773 .50479 m
.32728 .5017 L
s
.31773 .50479 m
.31488 .50491 L
s
.35779 .60181 m
.35998 .59978 L
s
.35998 .59978 m
.38519 .60171 L
s
.2507 .51962 m
.25313 .51647 L
s
.25313 .51647 m
.28628 .5168 L
s
.25313 .51647 m
.2507 .51962 L
s
.32284 .61161 m
.32007 .61195 L
s
.28729 .58297 m .3076 .58361 L .28964 .58924 L .558 .338 .538 r
F
.28729 .58297 m .3077 .57655 L .3076 .58361 L F
0 g
.28598 .57639 m
.28729 .58297 L
s
.18172 .55986 m .24068 .55633 L .24139 .56302 L .664 .758 .92 r
F
0 g
.24139 .56302 m
.24358 .5692 L
s
.039 .916 .04 r
.18261 .57054 m
.24077 .55915 L
s
0 g
.42284 .61063 m
.42002 .61532 L
s
.33455 .55987 m .355 .55342 L .35835 .55815 L .664 .758 .92 r
F
.33026 .55542 m .355 .55342 L .33455 .55987 L F
0 g
.33455 .55987 m
.33881 .56429 L
s
.26156 .55659 m .27902 .56032 L .26677 .56183 L .664 .758 .92 r
F
0 g
.26677 .56183 m
.27196 .56704 L
s
.37943 .5047 m .41723 .49258 L .38389 .51202 L .558 .338 .538 r
F
.37943 .5047 m .41035 .48315 L .41723 .49258 L F
0 g
.37329 .49798 m
.37943 .5047 L
s
.40069 .4747 m
.41035 .48315 L
s
.30072 .50855 m .30285 .50576 L .30339 .50753 L .963 .689 .469 r
F
.30072 .50855 m .30009 .50681 L .30285 .50576 L F
0 g
.30285 .50576 m
.30588 .50563 L
s
.30136 .51029 m .30339 .50753 L .30393 .50931 L .963 .689 .469 r
F
.30136 .51029 m .30072 .50855 L .30339 .50753 L F
.30199 .51203 m .30393 .50931 L .30447 .51108 L F
.30199 .51203 m .30136 .51029 L .30393 .50931 L F
.30262 .51377 m .30447 .51108 L .30501 .51285 L F
.30262 .51377 m .30199 .51203 L .30447 .51108 L F
.30326 .51551 m .30501 .51285 L .30555 .51462 L F
.30326 .51551 m .30262 .51377 L .30501 .51285 L F
.30389 .51725 m .30555 .51462 L .30609 .5164 L F
0 g
.30609 .5164 m
.30851 .51627 L
s
.30389 .51725 m .30326 .51551 L .30555 .51462 L .963 .689 .469 r
F
0 g
.20793 .70177 m
.21596 .70643 L
s
.21596 .70643 m
.22005 .7052 L
s
0 0 0 r
2 Mabswid
.37304 .55784 Mdot
.33032 .54824 m .35104 .54885 L .33026 .55542 L .558 .338 .538 r
F
.33032 .54824 m .35077 .54175 L .35104 .54885 L F
0 g
.5 Mabswid
.33032 .54824 m
.33038 .54108 L
s
.35779 .60181 m
.34819 .60478 L
s
.34567 .60598 m
.34819 .60478 L
s
.355 .55342 m .37143 .55613 L .35835 .55815 L .664 .758 .92 r
F
0 g
.35835 .55815 m
.36107 .56305 L
s
.28805 .6313 m
.28417 .62971 L
s
.28418 .62971 m
.28805 .63129 L
s
.28856 .51499 m
.29038 .51441 L
s
.28856 .51499 m
.28628 .5168 L
s
.26156 .55659 m .27721 .55519 L .27902 .56032 L .664 .758 .92 r
F
.039 .916 .04 r
.24251 .56671 m
.26469 .55973 L
s
.27902 .56032 m .29942 .55384 L .30366 .55818 L .664 .758 .92 r
F
0 g
.30366 .55818 m
.30789 .5625 L
s
.27721 .55519 m .29942 .55384 L .27902 .56032 L .664 .758 .92 r
F
.039 .916 .04 r
.28044 .56296 m
.30178 .55625 L
s
0 g
.27902 .56032 m
.28185 .56509 L
s
0 0 0 r
2 Mabswid
.31906 .55897 Mdot
0 g
.5 Mabswid
.34649 .48554 m
.35004 .48646 L
s
.42966 .46404 m .44919 .47258 L .43048 .4786 L .558 .338 .538 r
F
.42966 .46404 m .44504 .45906 L .44919 .47258 L F
0 g
.42868 .44962 m
.42966 .46404 L
s
.43973 .44603 m
.44504 .45906 L
s
.32728 .5017 m
.34649 .48554 L
s
.32728 .5017 m
.32444 .50182 L
s
.2881 .51622 m
.29038 .51441 L
s
.3077 .57655 m
.30779 .56951 L
s
.22005 .7052 m
.21203 .70053 L
s
.35303 .48309 m
.37124 .45553 L
s
.35303 .48309 m
.34935 .48212 L
s
.41433 .4231 m
.42002 .42122 L
s
.41433 .4231 m
.40795 .41942 L
s
.33203 .60156 m .33009 .60363 L .32965 .60184 L .963 .689 .469 r
F
.33203 .60156 m .33257 .60334 L .33009 .60363 L F
0 g
.33203 .60156 m
.33419 .60056 L
s
.33257 .60334 m .33053 .60542 L .33009 .60363 L .963 .689 .469 r
F
.33257 .60334 m .33312 .60512 L .33053 .60542 L F
.33312 .60512 m .33098 .60721 L .33053 .60542 L F
.33312 .60512 m .33366 .60689 L .33098 .60721 L F
0 g
.20015 .50204 m
.2507 .51962 L
s
.20015 .50204 m
.19689 .5083 L
s
.33366 .60689 m .33142 .609 L .33098 .60721 L .963 .689 .469 r
F
.33366 .60689 m .3342 .60867 L .33142 .609 L F
.3342 .60867 m .33186 .6108 L .33142 .609 L F
.3342 .60867 m .33474 .61044 L .33186 .6108 L F
.33474 .61044 m .3323 .61259 L .33186 .6108 L F
.33474 .61044 m .33528 .61222 L .3323 .61259 L F
0 g
.33528 .61222 m
.33796 .61094 L
s
0 0 0 r
2 Mabswid
.26469 .55973 Mdot
.2766 .59774 m .29321 .59517 L .27643 .60632 L .558 .338 .538 r
F
.2766 .59774 m .28964 .58924 L .29321 .59517 L F
0 g
.5 Mabswid
.2766 .59774 m
.27678 .5892 L
s
.355 .55342 m .36645 .55086 L .37143 .55613 L .664 .758 .92 r
F
0 g
.37143 .55613 m
.37638 .56138 L
s
.039 .916 .04 r
.33622 .5616 m
.35635 .55521 L
s
.34991 .53487 m .36146 .53706 L .35077 .54175 L .558 .338 .538 r
F
.34991 .53487 m .36146 .52859 L .36146 .53706 L F
0 g
.34844 .5282 m
.34991 .53487 L
s
.36146 .52859 m
.36147 .52015 L
s
.39731 .54852 m .43786 .54996 L .39939 .55495 L .664 .758 .92 r
F
0 g
.39939 .55495 m
.40004 .56178 L
s
.31526 .61201 m
.31825 .61252 L
s
.31825 .61252 m
.32007 .61195 L
s
.35528 .603 m
.35779 .60181 L
s
.35779 .60181 m
.38265 .60412 L
s
.32007 .61195 m
.31708 .61144 L
s
.31488 .50491 m
.32444 .50182 L
s
.31488 .50491 m
.31228 .5059 L
s
.38519 .60171 m
.38265 .60412 L
s
.41367 .41753 m
.42002 .42122 L
s
0 0 0 r
2 Mabswid
.24077 .55915 Mdot
.28964 .58924 m .30751 .5907 L .29321 .59517 L .558 .338 .538 r
F
.28964 .58924 m .3076 .58361 L .30751 .5907 L F
0 g
.5 Mabswid
.28729 .58297 m
.28964 .58924 L
s
.44874 .54237 m .47551 .54603 L .45678 .55187 L .664 .758 .92 r
F
0 g
.45678 .55187 m
.46457 .56134 L
s
.36638 .45415 m
.37124 .45553 L
s
.38692 .60531 m
.38955 .6028 L
s
.38955 .6028 m
.42002 .61532 L
s
.24871 .5237 m
.2507 .51962 L
s
.2507 .51962 m
.28433 .51942 L
s
.2507 .51962 m
.24871 .5237 L
s
.30194 .51883 m .30326 .51551 L .30389 .51725 L .963 .689 .469 r
F
0 g
.30389 .51725 m
.30609 .5164 L
s
.33026 .55542 m .35072 .55616 L .33021 .56263 L .558 .338 .538 r
F
.33026 .55542 m .35104 .54885 L .355 .55342 L .664 .758 .92 r
F
.33026 .55542 m .35104 .54885 L .35072 .55616 L .558 .338 .538 r
F
.32596 .55096 m .35104 .54885 L .33026 .55542 L .664 .758 .92 r
F
0 0 0 r
2 Mabswid
.33026 .55542 Mdot
.039 .916 .04 r
.5 Mabswid
.31906 .55897 m
.33026 .55542 L
s
0 g
.3303 .55059 m
.33032 .54824 L
s
.30122 .51715 m .30262 .51377 L .30326 .51551 L .963 .689 .469 r
F
.30194 .51883 m .30122 .51715 L .30326 .51551 L F
.039 .916 .04 r
.30178 .55625 m
.31301 .55273 L
s
0 0 0 r
2 Mabswid
.30178 .55625 Mdot
.3005 .51547 m .30199 .51203 L .30262 .51377 L .963 .689 .469 r
F
.30122 .51715 m .3005 .51547 L .30262 .51377 L F
.18417 .54818 m .24068 .55633 L .18172 .55986 L .664 .758 .92 r
F
0 g
.5 Mabswid
.18172 .55986 m
.18257 .57038 L
s
.29979 .51379 m .30136 .51029 L .30199 .51203 L .963 .689 .469 r
F
.3005 .51547 m .29979 .51379 L .30199 .51203 L F
.29907 .51211 m .30072 .50855 L .30136 .51029 L F
.29979 .51379 m .29907 .51211 L .30136 .51029 L F
.29835 .51043 m .30009 .50681 L .30072 .50855 L F
.29907 .51211 m .29835 .51043 L .30072 .50855 L F
.14271 .54829 m .16009 .55628 L .1466 .56064 L .664 .758 .92 r
F
0 g
.1466 .56064 m
.1521 .57233 L
s
.29835 .51043 m .29764 .50875 L .30009 .50681 L .963 .689 .469 r
F
0 g
.30009 .50681 m
.30285 .50576 L
s
.3076 .58361 m
.3077 .57655 L
s
.24566 .66893 m
.25201 .67281 L
s
.25201 .67281 m
.28417 .62971 L
s
.34287 .60631 m
.34567 .60598 L
s
.34567 .60598 m
.35528 .603 L
s
.25632 .55133 m .27721 .55519 L .26156 .55659 L .664 .758 .92 r
F
.039 .916 .04 r
.26469 .55973 m
.27735 .55573 L
s
0 g
.26156 .55659 m
.26677 .56183 L
s
.47057 .62426 m
.47398 .61821 L
s
.47398 .61821 m
.47972 .61647 L
s
.28628 .5168 m
.2881 .51622 L
s
.28628 .5168 m
.28433 .51942 L
s
.35104 .54885 m .36645 .55086 L .355 .55342 L .664 .758 .92 r
F
0 g
.355 .55342 m
.35835 .55815 L
s
.039 .916 .04 r
.35635 .55521 m
.36727 .55173 L
s
0 0 0 r
2 Mabswid
.27735 .55573 Mdot
.38389 .51202 m .42191 .5028 L .38695 .51982 L .558 .338 .538 r
F
.38389 .51202 m .41723 .49258 L .42191 .5028 L F
0 g
.5 Mabswid
.37943 .5047 m
.38389 .51202 L
s
.41035 .48315 m
.41723 .49258 L
s
.32965 .60184 m .32741 .60316 L .32708 .60138 L .963 .689 .469 r
F
.32965 .60184 m .33009 .60363 L .32741 .60316 L F
0 g
.32965 .60184 m
.33203 .60156 L
s
.28615 .51883 m
.2881 .51622 L
s
.33009 .60363 m .32775 .60493 L .32741 .60316 L .963 .689 .469 r
F
.33009 .60363 m .33053 .60542 L .32775 .60493 L F
0 g
.32444 .50182 m
.34317 .48564 L
s
.32444 .50182 m
.32186 .5028 L
s
.14748 .50245 m
.15155 .5011 L
s
.14748 .50245 m
.14416 .51188 L
s
.28417 .62971 m
.28016 .62712 L
s
.28016 .62712 m
.28418 .62971 L
s
.33053 .60542 m .32808 .60671 L .32775 .60493 L .963 .689 .469 r
F
.33053 .60542 m .33098 .60721 L .32808 .60671 L F
.27721 .55519 m .29517 .54948 L .29942 .55384 L .664 .758 .92 r
F
0 g
.29942 .55384 m
.30366 .55818 L
s
.2766 .54966 m .29517 .54948 L .27721 .55519 L .664 .758 .92 r
F
.039 .916 .04 r
.27735 .55573 m
.29566 .54999 L
s
.25632 .55133 m .2766 .54966 L .27721 .55519 L .664 .758 .92 r
F
0 g
.27721 .55519 m
.27902 .56032 L
s
.18417 .54818 m .24185 .54899 L .24068 .55633 L .664 .758 .92 r
F
.039 .916 .04 r
.24077 .55915 m
.25852 .55354 L
s
0 g
.24068 .55633 m
.24139 .56302 L
s
.39731 .54852 m .43572 .54119 L .43786 .54996 L .664 .758 .92 r
F
0 g
.43776 .55935 m
.43786 .54996 L
s
.039 .916 .04 r
.37304 .55784 m
.39783 .54979 L
s
.39974 .55697 m
.43766 .54855 L
s
.35077 .54175 m .36145 .54556 L .35104 .54885 L .558 .338 .538 r
F
.35077 .54175 m .36146 .53706 L .36145 .54556 L F
0 g
.34991 .53487 m
.35077 .54175 L
s
.36146 .53706 m
.36146 .52859 L
s
.33098 .60721 m .32842 .60848 L .32808 .60671 L .963 .689 .469 r
F
.33098 .60721 m .33142 .609 L .32842 .60848 L F
0 g
.34317 .48564 m
.34649 .48554 L
s
.33142 .609 m .32875 .61026 L .32842 .60848 L .963 .689 .469 r
F
.33142 .609 m .33186 .6108 L .32875 .61026 L F
.27643 .60632 m .29829 .60065 L .27625 .61493 L .558 .338 .538 r
F
0 g
.28805 .63129 m
.31526 .61201 L
s
.27643 .60632 m .29321 .59517 L .29829 .60065 L .558 .338 .538 r
F
0 g
.27643 .60632 m
.2766 .59774 L
s
.33186 .6108 m .32909 .61204 L .32875 .61026 L .963 .689 .469 r
F
.33186 .6108 m .3323 .61259 L .32909 .61204 L F
0 g
.3323 .61259 m
.33528 .61222 L
s
0 0 0 r
2 Mabswid
.36727 .55173 Mdot
0 g
.5 Mabswid
.42002 .61532 m
.41661 .61872 L
s
.47972 .61647 m
.47634 .62252 L
s
.3121 .61066 m
.31526 .61201 L
s
.31526 .61201 m
.31708 .61144 L
s
.34935 .48212 m
.36638 .45415 L
s
.34935 .48212 m
.34591 .48222 L
s
.14824 .51053 m
.15155 .5011 L
s
.19172 .68092 m .20387 .69396 L .19975 .69521 L .558 .338 .538 r
F
.19172 .68092 m .20118 .67803 L .20387 .69396 L F
0 g
.18561 .66621 m
.19172 .68092 L
s
.19912 .66205 m
.20118 .67803 L
s
.19172 .68092 m
.19975 .69521 L
s
0 0 0 r
2 Mabswid
.31301 .55273 Mdot
.35104 .54885 m .36145 .54556 L .36645 .55086 L .664 .758 .92 r
F
0 g
.5 Mabswid
.36645 .55086 m
.37143 .55613 L
s
.31708 .61144 m
.31393 .61009 L
s
.3525 .60334 m
.35528 .603 L
s
.35528 .603 m
.37974 .60555 L
s
.31228 .5059 m
.32186 .5028 L
s
.31228 .5059 m
.30997 .50775 L
s
.33021 .56263 m .3498 .56369 L .33015 .56987 L .558 .338 .538 r
F
.33021 .56263 m .35072 .55616 L .3498 .56369 L F
0 g
.33021 .56263 m
.33026 .55542 L
s
.30027 .5211 m .30122 .51715 L .30194 .51883 L .963 .689 .469 r
F
0 g
.30194 .51883 m
.30389 .51725 L
s
.22348 .65495 m .27607 .62357 L .2392 .66355 L .558 .338 .538 r
F
.22348 .65495 m .26704 .61779 L .27607 .62357 L F
0 g
.21303 .64487 m
.22348 .65495 L
s
.26078 .6112 m
.26704 .61779 L
s
.22348 .65495 m
.2392 .66355 L
s
.29321 .59517 m .30741 .59781 L .29829 .60065 L .558 .338 .538 r
F
.29321 .59517 m .30751 .5907 L .30741 .59781 L F
0 g
.28964 .58924 m
.29321 .59517 L
s
.29948 .51951 m .3005 .51547 L .30122 .51715 L .963 .689 .469 r
F
.30027 .5211 m .29948 .51951 L .30122 .51715 L F
0 g
.26704 .61779 m
.27607 .62357 L
s
0 0 0 r
2 Mabswid
.25852 .55354 Mdot
.2987 .51793 m .29979 .51379 L .3005 .51547 L .963 .689 .469 r
F
.29948 .51951 m .2987 .51793 L .3005 .51547 L F
0 g
.5 Mabswid
.38265 .60412 m
.37974 .60555 L
s
.30751 .5907 m
.3076 .58361 L
s
.14271 .54829 m .15215 .54522 L .16009 .55628 L .664 .758 .92 r
F
0 g
.16009 .55628 m
.16856 .56704 L
s
.32596 .55096 m .34648 .54446 L .35104 .54885 L .664 .758 .92 r
F
.32165 .54648 m .34648 .54446 L .32596 .55096 L F
0 g
.32596 .55096 m
.33026 .55542 L
s
.039 .916 .04 r
.31301 .55273 m
.32427 .5492 L
s
.29791 .51634 m .29907 .51211 L .29979 .51379 L .963 .689 .469 r
F
.2987 .51793 m .29791 .51634 L .29979 .51379 L F
0 g
.19689 .5083 m
.24871 .5237 L
s
.24721 .52863 m
.24871 .5237 L
s
.24871 .5237 m
.28274 .52279 L
s
.24871 .5237 m
.24721 .52863 L
s
.44874 .54237 m .46985 .53576 L .47551 .54603 L .664 .758 .92 r
F
.039 .916 .04 r
.43766 .54855 m
.45052 .54445 L
s
0 g
.47551 .54603 m
.47997 .55656 L
s
.39395 .54245 m .43572 .54119 L .39731 .54852 L .664 .758 .92 r
F
.039 .916 .04 r
.36727 .55173 m
.39434 .54306 L
s
0 g
.39731 .54852 m
.39939 .55495 L
s
.29712 .51475 m .29835 .51043 L .29907 .51211 L .963 .689 .469 r
F
.29791 .51634 m .29712 .51475 L .29907 .51211 L F
.43048 .4786 m .45223 .48658 L .43113 .49333 L .558 .338 .538 r
F
.43048 .4786 m .44919 .47258 L .45223 .48658 L F
0 g
.42966 .46404 m
.43048 .4786 L
s
.44504 .45906 m
.44919 .47258 L
s
.29633 .51316 m .29764 .50875 L .29835 .51043 L .963 .689 .469 r
F
.29712 .51475 m .29633 .51316 L .29835 .51043 L F
0 g
.41661 .61872 m
.38692 .60531 L
s
.38391 .60679 m
.38692 .60531 L
s
.32708 .60138 m .32458 .60192 L .32436 .60019 L .963 .689 .469 r
F
.32708 .60138 m .32741 .60316 L .32458 .60192 L F
0 g
.32708 .60138 m
.32965 .60184 L
s
.19689 .5083 m
.19438 .51592 L
s
.28433 .51942 m
.28615 .51883 L
s
.28433 .51942 m
.28274 .52279 L
s
.19975 .69521 m
.20793 .70177 L
s
.20793 .70177 m
.21203 .70053 L
s
.29633 .51316 m .29554 .51157 L .29764 .50875 L .963 .689 .469 r
F
0 g
.29764 .50875 m
.30009 .50681 L
s
.33984 .60578 m
.34287 .60631 L
s
.34287 .60631 m
.3525 .60334 L
s
.32741 .60316 m .3248 .60365 L .32458 .60192 L .963 .689 .469 r
F
.32741 .60316 m .32775 .60493 L .3248 .60365 L F
.35104 .54885 m .36144 .5541 L .35072 .55616 L .558 .338 .538 r
F
.35104 .54885 m .36145 .54556 L .36144 .5541 L F
.34648 .54446 m .36145 .54556 L .35104 .54885 L .664 .758 .92 r
F
0 0 0 r
2 Mabswid
.35104 .54885 Mdot
.039 .916 .04 r
.5 Mabswid
.33026 .55542 m
.35104 .54885 L
s
0 g
.35077 .54175 m
.35089 .54478 L
s
.20118 .67803 m
.20387 .69396 L
s
.28457 .52221 m
.28615 .51883 L
s
.32775 .60493 m .32502 .60538 L .3248 .60365 L .963 .689 .469 r
F
.32775 .60493 m .32808 .60671 L .32502 .60538 L F
.32808 .60671 m .32524 .60711 L .32502 .60538 L F
.32808 .60671 m .32842 .60848 L .32524 .60711 L F
0 0 0 r
2 Mabswid
.32427 .5492 Mdot
0 g
.5 Mabswid
.32186 .5028 m
.34016 .48677 L
s
.32186 .5028 m
.31958 .50465 L
s
.25105 .54604 m .2766 .54966 L .25632 .55133 L .664 .758 .92 r
F
0 g
.25632 .55133 m
.26156 .55659 L
s
.039 .916 .04 r
.29566 .54999 m
.30695 .54649 L
s
0 g
.40795 .41942 m
.41367 .41753 L
s
.40795 .41942 m
.40188 .41749 L
s
.27607 .62357 m
.28016 .62712 L
s
.24566 .66893 m
.28016 .62712 L
s
.20387 .69396 m
.21203 .70053 L
s
.27625 .61493 m .30548 .60551 L .27607 .62357 L .558 .338 .538 r
F
0 g
.27607 .62357 m
.28016 .62712 L
s
.27625 .61493 m .29829 .60065 L .30548 .60551 L .558 .338 .538 r
F
0 g
.28418 .62971 m
.3121 .61066 L
s
.27625 .61493 m
.27643 .60632 L
s
.28016 .62712 m
.30882 .60848 L
s
.27607 .62357 m
.27625 .61493 L
s
.32842 .60848 m .32547 .60884 L .32524 .60711 L .963 .689 .469 r
F
.32842 .60848 m .32875 .61026 L .32547 .60884 L F
.38695 .51982 m .4247 .5137 L .38875 .52807 L .558 .338 .538 r
F
.38695 .51982 m .42191 .5028 L .4247 .5137 L F
0 g
.38389 .51202 m
.38695 .51982 L
s
.41723 .49258 m
.42191 .5028 L
s
.36185 .45418 m
.36638 .45415 L
s
.2766 .54966 m .29089 .5451 L .29517 .54948 L .664 .758 .92 r
F
0 g
.29517 .54948 m
.29942 .55384 L
s
.32875 .61026 m .32569 .61057 L .32547 .60884 L .963 .689 .469 r
F
.32875 .61026 m .32909 .61204 L .32569 .61057 L F
0 g
.32909 .61204 m
.3323 .61259 L
s
.30882 .60848 m
.3121 .61066 L
s
.3121 .61066 m
.31393 .61009 L
s
.33015 .56987 m .34827 .57142 L .33009 .57712 L .558 .338 .538 r
F
.33015 .56987 m .3498 .56369 L .34827 .57142 L F
0 g
.33015 .56987 m
.33021 .56263 L
s
.27748 .54363 m .29089 .5451 L .2766 .54966 L .664 .758 .92 r
F
.25105 .54604 m .27748 .54363 L .2766 .54966 L F
0 g
.2766 .54966 m
.27721 .55519 L
s
.039 .916 .04 r
.25852 .55354 m
.2767 .54778 L
s
.29892 .52403 m .29948 .51951 L .30027 .5211 L .963 .689 .469 r
F
0 g
.30027 .5211 m
.30194 .51883 L
s
.31393 .61009 m
.31065 .60791 L
s
.34016 .48677 m
.34317 .48564 L
s
.29808 .52256 m .2987 .51793 L .29948 .51951 L .963 .689 .469 r
F
.29892 .52403 m .29808 .52256 L .29948 .51951 L F
0 g
.40761 .41559 m
.41367 .41753 L
s
.30997 .50775 m
.31958 .50465 L
s
.30997 .50775 m
.30801 .51042 L
s
.34948 .60279 m
.3525 .60334 L
s
.3525 .60334 m
.3765 .60595 L
s
.2392 .66355 m
.24566 .66893 L
s
.29723 .5211 m .29791 .51634 L .2987 .51793 L .963 .689 .469 r
F
.29808 .52256 m .29723 .5211 L .2987 .51793 L F
0 g
.34591 .48222 m
.36185 .45418 L
s
.34591 .48222 m
.34279 .48338 L
s
.34648 .54446 m .35642 .54024 L .36145 .54556 L .664 .758 .92 r
F
0 0 0 r
2 Mabswid
.36145 .54556 Mdot
.039 .916 .04 r
.5 Mabswid
.35104 .54885 m
.36145 .54556 L
s
0 g
.36145 .54556 m
.36146 .53706 L
s
.36145 .54556 m
.36645 .55086 L
s
.29639 .51963 m .29712 .51475 L .29791 .51634 L .963 .689 .469 r
F
.29723 .5211 m .29639 .51963 L .29791 .51634 L F
.32436 .60019 m .32164 .59994 L .32153 .59829 L F
.32436 .60019 m .32458 .60192 L .32164 .59994 L F
0 g
.32436 .60019 m
.32708 .60138 L
s
.29829 .60065 m .30732 .60494 L .30548 .60551 L .558 .338 .538 r
F
.29829 .60065 m .30741 .59781 L .30732 .60494 L F
0 g
.29321 .59517 m
.29829 .60065 L
s
.29829 .60065 m
.30548 .60551 L
s
.30741 .59781 m
.30751 .5907 L
s
.32165 .54648 m .3413 .54023 L .34648 .54446 L .664 .758 .92 r
F
.31731 .54197 m .3413 .54023 L .32165 .54648 L F
0 g
.32165 .54648 m
.32596 .55096 L
s
.19182 .53469 m .24185 .54899 L .18417 .54818 L .664 .758 .92 r
F
0 g
.18172 .55986 m
.18417 .54818 L
s
.19182 .53469 m .24575 .54073 L .24185 .54899 L .664 .758 .92 r
F
0 g
.24068 .55633 m
.24185 .54899 L
s
.24185 .54899 m
.24575 .54073 L
s
.44046 .53284 m .46985 .53576 L .44874 .54237 L .664 .758 .92 r
F
.039 .916 .04 r
.45052 .54445 m
.47122 .53804 L
s
0 g
.44874 .54237 m
.45678 .55187 L
s
.29554 .51816 m .29633 .51316 L .29712 .51475 L .963 .689 .469 r
F
.29639 .51963 m .29554 .51816 L .29712 .51475 L F
0 0 0 r
2 Mabswid
.2767 .54778 Mdot
0 g
.5 Mabswid
.24721 .52863 m
.28155 .52688 L
s
.24721 .52863 m
.24622 .53434 L
s
.19438 .51592 m
.24721 .52863 L
s
.24621 .53434 m
.24721 .52863 L
s
.32458 .60192 m .32174 .60159 L .32164 .59994 L .963 .689 .469 r
F
.32458 .60192 m .3248 .60365 L .32174 .60159 L F
.35072 .55616 m .36143 .56267 L .3498 .56369 L .558 .338 .538 r
F
.35072 .55616 m .36144 .5541 L .36143 .56267 L F
0 g
.35072 .55616 m
.35104 .54885 L
s
.36144 .5541 m
.36145 .54556 L
s
.28274 .52279 m
.28457 .52221 L
s
.28274 .52279 m
.28155 .52688 L
s
.039 .916 .04 r
.30695 .54649 m
.31827 .54297 L
s
0 0 0 r
2 Mabswid
.30695 .54649 Mdot
.29469 .51669 m .29554 .51157 L .29633 .51316 L .963 .689 .469 r
F
.29554 .51816 m .29469 .51669 L .29633 .51316 L F
0 g
.5 Mabswid
.37974 .60555 m
.3765 .60595 L
s
.3248 .60365 m .32185 .60324 L .32174 .60159 L .963 .689 .469 r
F
.3248 .60365 m .32502 .60538 L .32185 .60324 L F
0 g
.41661 .61872 m
.41268 .62075 L
s
.33663 .60437 m
.33984 .60578 L
s
.33984 .60578 m
.34948 .60279 L
s
.28338 .52629 m
.28457 .52221 L
s
.29469 .51669 m .29385 .51522 L .29554 .51157 L .963 .689 .469 r
F
0 g
.29554 .51157 m
.29764 .50875 L
s
.3413 .54023 m .35642 .54024 L .34648 .54446 L .664 .758 .92 r
F
.039 .916 .04 r
.32427 .5492 m
.34457 .54282 L
s
0 g
.34648 .54446 m
.35104 .54885 L
s
.46642 .62866 m
.47057 .62426 L
s
.47057 .62426 m
.47634 .62252 L
s
.32502 .60538 m .32195 .6049 L .32185 .60324 L .963 .689 .469 r
F
.32502 .60538 m .32524 .60711 L .32195 .6049 L F
0 g
.14416 .51188 m
.14824 .51053 L
s
.14416 .51188 m
.14186 .52286 L
s
.39395 .54245 m .43163 .53296 L .43572 .54119 L .664 .758 .92 r
F
0 g
.43572 .54119 m
.43786 .54996 L
s
.38938 .53673 m .43163 .53296 L .39395 .54245 L .664 .758 .92 r
F
0 g
.39395 .54245 m
.39731 .54852 L
s
.039 .916 .04 r
.39783 .54979 m
.43535 .54024 L
s
0 g
.38055 .60721 m
.38391 .60679 L
s
.38391 .60679 m
.41268 .62075 L
s
.31958 .50465 m
.33749 .48891 L
s
.31958 .50465 m
.31763 .50732 L
s
.32524 .60711 m .32205 .60655 L .32195 .6049 L .963 .689 .469 r
F
.32524 .60711 m .32547 .60884 L .32205 .60655 L F
.29792 .52757 m .29808 .52256 L .29892 .52403 L F
0 g
.29892 .52403 m
.30027 .5211 L
s
.27199 .61912 m
.27607 .62357 L
s
.27607 .62357 m
.30548 .60551 L
s
.27199 .61912 m
.27607 .62357 L
s
.2392 .66355 m
.27607 .62357 L
s
.33009 .57712 m .34609 .57939 L .33003 .58441 L .558 .338 .538 r
F
.33009 .57712 m .34827 .57142 L .34609 .57939 L F
0 g
.33009 .57712 m
.33015 .56987 L
s
.30548 .60551 m
.30882 .60848 L
s
.30882 .60848 m
.31065 .60791 L
s
.27748 .54363 m .2866 .54071 L .29089 .5451 L .664 .758 .92 r
F
0 g
.29089 .5451 m
.29517 .54948 L
s
.32547 .60884 m .32216 .60821 L .32205 .60655 L .963 .689 .469 r
F
.32547 .60884 m .32569 .61057 L .32216 .60821 L F
0 g
.32569 .61057 m
.32909 .61204 L
s
.29703 .52625 m .29723 .5211 L .29808 .52256 L .963 .689 .469 r
F
.29792 .52757 m .29703 .52625 L .29808 .52256 L F
0 g
.30732 .60494 m
.31065 .60791 L
s
.30732 .60494 m
.30741 .59781 L
s
.039 .916 .04 r
.43535 .54024 m
.44441 .53736 L
s
0 g
.18417 .54818 m
.19182 .53469 L
s
.24576 .54073 m .27748 .54363 L .25105 .54604 L .664 .758 .92 r
F
.039 .916 .04 r
.2767 .54778 m
.28958 .54376 L
s
0 g
.25105 .54604 m
.25632 .55133 L
s
.14596 .52151 m
.14824 .51053 L
s
.38875 .52807 m .42573 .52524 L .38938 .53673 L .558 .338 .538 r
F
.38875 .52807 m .4247 .5137 L .42573 .52524 L F
0 g
.38695 .51982 m
.38875 .52807 L
s
.47634 .62252 m
.47221 .62691 L
s
0 0 0 r
2 Mabswid
.34457 .54282 Mdot
.29614 .52493 m .29639 .51963 L .29723 .5211 L .963 .689 .469 r
F
.29703 .52625 m .29614 .52493 L .29723 .5211 L F
.32153 .59829 m .31865 .59724 L .31866 .5957 L F
.32153 .59829 m .32164 .59994 L .31865 .59724 L F
0 g
.5 Mabswid
.32153 .59829 m
.32436 .60019 L
s
.19438 .51592 m
.19268 .52477 L
s
.30801 .51042 m
.31763 .50732 L
s
.30801 .51042 m
.30643 .51388 L
s
0 0 0 r
2 Mabswid
.31827 .54297 Mdot
.039 .916 .04 r
.5 Mabswid
.47122 .53804 m
.91502 .37045 L
s
0 0 0 r
2 Mabswid
.47122 .53804 Mdot
0 g
.5 Mabswid
.34629 .60138 m
.34948 .60279 L
s
.34948 .60279 m
.37298 .60531 L
s
.29525 .52361 m .29554 .51816 L .29639 .51963 L .963 .689 .469 r
F
.29614 .52493 m .29525 .52361 L .29639 .51963 L F
.43113 .49333 m .45418 .50105 L .43162 .50822 L .558 .338 .538 r
F
.43113 .49333 m .45223 .48658 L .45418 .50105 L F
0 g
.43048 .4786 m
.43113 .49333 L
s
.44919 .47258 m
.45223 .48658 L
s
.039 .916 .04 r
.28958 .54376 m
.30092 .54027 L
s
0 0 0 r
2 Mabswid
.28958 .54376 Mdot
.3498 .56369 m .36142 .57128 L .34827 .57142 L .558 .338 .538 r
F
.3498 .56369 m .36143 .56267 L .36142 .57128 L F
0 g
.5 Mabswid
.3498 .56369 m
.35072 .55616 L
s
.14063 .53519 m .15215 .54522 L .14271 .54829 L .664 .758 .92 r
F
0 g
.14271 .54829 m
.1466 .56064 L
s
.32164 .59994 m .31863 .59879 L .31865 .59724 L .963 .689 .469 r
F
.32164 .59994 m .32174 .60159 L .31863 .59879 L F
0 g
.33749 .48891 m
.34016 .48677 L
s
.36143 .56267 m
.36144 .5541 L
s
.28155 .52688 m
.28338 .52629 L
s
.28155 .52688 m
.28079 .5316 L
s
.28046 .53689 m .2866 .54071 L .27748 .54363 L .664 .758 .92 r
F
.24576 .54073 m .28046 .53689 L .27748 .54363 L F
0 g
.2766 .54966 m
.27748 .54363 L
s
.24576 .54073 m
.25105 .54604 L
s
.29436 .52229 m .29469 .51669 L .29554 .51816 L .963 .689 .469 r
F
.29525 .52361 m .29436 .52229 L .29554 .51816 L F
0 g
.24622 .53434 m
.28079 .5316 L
s
.24576 .54073 m
.24622 .53434 L
s
.19268 .52477 m
.24621 .53434 L
s
.24575 .54073 m
.24621 .53434 L
s
.42191 .5028 m
.4247 .5137 L
s
.32174 .60159 m .31861 .60034 L .31863 .59879 L .963 .689 .469 r
F
.32174 .60159 m .32185 .60324 L .31861 .60034 L F
.31731 .54197 m .33549 .53619 L .3413 .54023 L .664 .758 .92 r
F
.31295 .53745 m .33549 .53619 L .31731 .54197 L F
0 g
.31731 .54197 m
.32165 .54648 L
s
.28262 .53102 m
.28338 .52629 L
s
.29347 .52096 m .29385 .51522 L .29469 .51669 L .963 .689 .469 r
F
.29436 .52229 m .29347 .52096 L .29469 .51669 L F
0 g
.19158 .68685 m
.19975 .69521 L
s
.19975 .69521 m
.20387 .69396 L
s
.3413 .54023 m .35137 .53489 L .35642 .54024 L .664 .758 .92 r
F
0 g
.35642 .54024 m
.36145 .54556 L
s
.34279 .48338 m
.35772 .45564 L
s
.34279 .48338 m
.34002 .4856 L
s
.29728 .53166 m .29703 .52625 L .29792 .52757 L .963 .689 .469 r
F
0 g
.29792 .52757 m
.29892 .52403 L
s
.32185 .60324 m .3186 .60188 L .31861 .60034 L .963 .689 .469 r
F
.32185 .60324 m .32195 .6049 L .3186 .60188 L F
0 g
.3333 .60212 m
.33663 .60437 L
s
.33663 .60437 m
.34629 .60138 L
s
.35772 .45564 m
.36185 .45418 L
s
.29347 .52096 m .29258 .51964 L .29385 .51522 L .963 .689 .469 r
F
0 g
.29385 .51522 m
.29554 .51157 L
s
.33549 .53619 m .35137 .53489 L .3413 .54023 L .664 .758 .92 r
F
.039 .916 .04 r
.34457 .54282 m
.35559 .53936 L
s
0 g
.3413 .54023 m
.34648 .54446 L
s
.039 .916 .04 r
.31827 .54297 m
.33693 .53713 L
s
0 g
.30215 .60179 m
.30548 .60551 L
s
.30548 .60551 m
.30732 .60494 L
s
.33003 .58441 m .34322 .58758 L .32997 .59171 L .558 .338 .538 r
F
.33003 .58441 m .34609 .57939 L .34322 .58758 L F
0 g
.33003 .58441 m
.33009 .57712 L
s
.32195 .6049 m .31858 .60343 L .3186 .60188 L .963 .689 .469 r
F
.32195 .6049 m .32205 .60655 L .31858 .60343 L F
.44046 .53284 m .46303 .52574 L .46985 .53576 L .664 .758 .92 r
F
0 g
.46985 .53576 m
.47551 .54603 L
s
.26798 .61383 m
.27199 .61912 L
s
.27199 .61912 m
.30215 .60179 L
s
.27199 .61912 m
.26798 .61384 L
s
.23274 .65673 m
.27199 .61912 L
s
.29636 .53051 m .29614 .52493 L .29703 .52625 L .963 .689 .469 r
F
.29728 .53166 m .29636 .53051 L .29703 .52625 L F
0 0 0 r
2 Mabswid
.35559 .53936 Mdot
0 g
.5 Mabswid
.19571 .68559 m
.20387 .69396 L
s
.23274 .65673 m
.2392 .66355 L
s
.30398 .60122 m
.30732 .60494 L
s
.3765 .60595 m
.37298 .60531 L
s
.31763 .50732 m
.33523 .49204 L
s
.31763 .50732 m
.31606 .51078 L
s
.31866 .5957 m .31565 .59388 L .31579 .59247 L .963 .689 .469 r
F
.31866 .5957 m .31865 .59724 L .31565 .59388 L F
0 g
.31866 .5957 m
.32153 .59829 L
s
.32205 .60655 m .31856 .60498 L .31858 .60343 L .963 .689 .469 r
F
.32205 .60655 m .32216 .60821 L .31856 .60498 L F
0 g
.32216 .60821 m
.32569 .61057 L
s
.14063 .53519 m .14474 .53384 L .15215 .54522 L .664 .758 .92 r
F
0 g
.15215 .54522 m
.16009 .55628 L
s
.14063 .53519 m
.14271 .54829 L
s
.14474 .53384 m
.15215 .54522 L
s
.29544 .52936 m .29525 .52361 L .29614 .52493 L .963 .689 .469 r
F
.29636 .53051 m .29544 .52936 L .29614 .52493 L F
0 0 0 r
2 Mabswid
.30092 .54027 Mdot
.28046 .53689 m .28229 .5363 L .2866 .54071 L .664 .758 .92 r
F
0 g
.5 Mabswid
.28229 .5363 m
.2866 .54071 L
s
.27748 .54363 m
.28046 .53689 L
s
.2866 .54071 m
.29089 .5451 L
s
.40188 .41749 m
.40761 .41559 L
s
.40188 .41749 m
.39622 .41737 L
s
.34827 .57142 m .36142 .57992 L .34609 .57939 L .558 .338 .538 r
F
.34827 .57142 m .36142 .57128 L .36142 .57992 L F
0 g
.34827 .57142 m
.3498 .56369 L
s
.31865 .59724 m .31551 .59529 L .31565 .59388 L .963 .689 .469 r
F
.31865 .59724 m .31863 .59879 L .31551 .59529 L F
.29452 .52821 m .29436 .52229 L .29525 .52361 L F
.29544 .52936 m .29452 .52821 L .29525 .52361 L F
0 g
.37691 .60655 m
.38055 .60721 L
s
.38055 .60721 m
.40829 .62135 L
s
.38938 .53673 m .42504 .53738 L .38885 .54579 L .558 .338 .538 r
F
.38938 .53673 m .42573 .52524 L .43163 .53296 L .664 .758 .92 r
F
.38938 .53673 m .42573 .52524 L .42504 .53738 L .558 .338 .538 r
F
0 g
.43163 .53296 m
.43572 .54119 L
s
.38363 .53134 m .42573 .52524 L .38938 .53673 L .664 .758 .92 r
F
0 0 0 r
2 Mabswid
.38938 .53673 Mdot
0 g
.5 Mabswid
.38875 .52807 m
.38894 .53057 L
s
.039 .916 .04 r
.42522 .53424 m
.43133 .5325 L
s
.36145 .54556 m
.38938 .53673 L
s
0 g
.28079 .5316 m
.28262 .53102 L
s
.28046 .53689 m
.28079 .5316 L
s
.30643 .51388 m
.31606 .51078 L
s
.30643 .51388 m
.30525 .51807 L
s
.34298 .59912 m
.34629 .60138 L
s
.34629 .60138 m
.36925 .60364 L
s
.31863 .59879 m .31538 .5967 L .31551 .59529 L .963 .689 .469 r
F
.31863 .59879 m .31861 .60034 L .31538 .5967 L F
0 g
.24576 .54073 m
.28046 .53689 L
s
.24576 .54073 m
.24584 .54768 L
s
.19182 .53469 m
.24575 .54073 L
s
.24575 .54073 m
.24584 .54768 L
s
.29361 .52706 m .29347 .52096 L .29436 .52229 L .963 .689 .469 r
F
.29452 .52821 m .29361 .52706 L .29436 .52229 L F
0 g
.28229 .5363 m
.28262 .53102 L
s
.29701 .53624 m .29636 .53051 L .29728 .53166 L .963 .689 .469 r
F
0 g
.29728 .53166 m
.29792 .52757 L
s
.41268 .62075 m
.40829 .62135 L
s
.36142 .57128 m
.36143 .56267 L
s
.40197 .41546 m
.40761 .41559 L
s
0 0 0 r
2 Mabswid
.33693 .53713 Mdot
.31861 .60034 m .31524 .59812 L .31538 .5967 L .963 .689 .469 r
F
.31861 .60034 m .3186 .60188 L .31524 .59812 L F
.29269 .52591 m .29258 .51964 L .29347 .52096 L F
.29361 .52706 m .29269 .52591 L .29347 .52096 L F
0 g
.5 Mabswid
.29887 .5974 m
.30215 .60179 L
s
.30215 .60179 m
.30398 .60122 L
s
.29608 .53528 m .29544 .52936 L .29636 .53051 L .963 .689 .469 r
F
.29701 .53624 m .29608 .53528 L .29636 .53051 L F
.31295 .53745 m .32901 .53233 L .33549 .53619 L .664 .758 .92 r
F
.30858 .53291 m .32901 .53233 L .31295 .53745 L F
0 g
.31295 .53745 m
.31731 .54197 L
s
.039 .916 .04 r
.30092 .54027 m
.31229 .53676 L
s
.31579 .59247 m .31271 .5899 L .31297 .58865 L .963 .689 .469 r
F
.31579 .59247 m .31565 .59388 L .31271 .5899 L F
0 g
.31579 .59247 m
.31866 .5957 L
s
.3333 .60212 m
.34298 .59912 L
s
.33523 .49204 m
.33749 .48891 L
s
.32997 .59171 m .3396 .59604 L .32991 .59905 L .558 .338 .538 r
F
0 g
.32991 .59905 m
.3333 .60212 L
s
.32997 .59171 m .34322 .58758 L .3396 .59604 L .558 .338 .538 r
F
0 g
.32997 .59171 m
.33003 .58441 L
s
.32991 .59905 m
.32997 .59171 L
s
.26412 .60781 m
.26798 .61383 L
s
.26798 .61383 m
.29887 .5974 L
s
.26798 .61384 m
.26412 .60781 L
s
.2264 .64859 m
.26798 .61384 L
s
.30398 .60122 m
.30071 .59682 L
s
.29269 .52591 m .29177 .52476 L .29258 .51964 L .963 .689 .469 r
F
0 g
.29258 .51964 m
.29385 .51522 L
s
.3186 .60188 m .3151 .59953 L .31524 .59812 L .963 .689 .469 r
F
.3186 .60188 m .31858 .60343 L .3151 .59953 L F
0 g
.14186 .52286 m
.14596 .52151 L
s
.14063 .53519 m
.14186 .52286 L
s
.43194 .52327 m .46303 .52574 L .44046 .53284 L .664 .758 .92 r
F
0 g
.44046 .53284 m
.44874 .54237 L
s
.039 .916 .04 r
.44441 .53736 m
.46642 .53048 L
s
.33549 .53619 m .34629 .52951 L .35137 .53489 L .664 .758 .92 r
F
0 g
.35137 .53489 m
.35642 .54024 L
s
.32901 .53233 m .34629 .52951 L .33549 .53619 L .664 .758 .92 r
F
.039 .916 .04 r
.33693 .53713 m
.34972 .53314 L
s
0 g
.33549 .53619 m
.3413 .54023 L
s
0 0 0 r
2 Mabswid
.31229 .53676 Mdot
0 g
.5 Mabswid
.19182 .53469 m
.19268 .52477 L
s
.29515 .53432 m .29452 .52821 L .29544 .52936 L .963 .689 .469 r
F
.29608 .53528 m .29515 .53432 L .29544 .52936 L F
.34609 .57939 m .36141 .58859 L .34322 .58758 L .558 .338 .538 r
F
.34609 .57939 m .36142 .57992 L .36141 .58859 L F
0 g
.34609 .57939 m
.34827 .57142 L
s
.31565 .59388 m .31245 .59115 L .31271 .5899 L .963 .689 .469 r
F
.31565 .59388 m .31551 .59529 L .31245 .59115 L F
.039 .916 .04 r
.43133 .5325 m
.43823 .53031 L
s
0 0 0 r
2 Mabswid
.43133 .5325 Mdot
.31858 .60343 m .31496 .60095 L .3151 .59953 L .963 .689 .469 r
F
.31858 .60343 m .31856 .60498 L .31496 .60095 L F
0 g
.5 Mabswid
.31856 .60498 m
.32216 .60821 L
s
.31606 .51078 m
.33341 .49611 L
s
.31606 .51078 m
.3149 .51497 L
s
.34002 .4856 m
.35407 .45852 L
s
.34002 .4856 m
.33768 .48885 L
s
.28046 .53689 m
.28229 .5363 L
s
.28046 .53689 m
.28057 .54264 L
s
.4616 .63131 m
.46642 .62866 L
s
.46642 .62866 m
.47221 .62691 L
s
.29422 .53337 m .29361 .52706 L .29452 .52821 L .963 .689 .469 r
F
.29515 .53432 m .29422 .53337 L .29452 .52821 L F
0 g
.14474 .53384 m
.14596 .52151 L
s
.29712 .54122 m .29608 .53528 L .29701 .53624 L .963 .689 .469 r
F
0 g
.29701 .53624 m
.29728 .53166 L
s
.31551 .59529 m .31219 .59241 L .31245 .59115 L .963 .689 .469 r
F
.31551 .59529 m .31538 .5967 L .31219 .59241 L F
.039 .916 .04 r
.46642 .53048 m
.91503 .37047 L
s
0 0 0 r
2 Mabswid
.46642 .53048 Mdot
0 g
.5 Mabswid
.24584 .54768 m
.28057 .54264 L
s
.24584 .54768 m
.24647 .55508 L
s
.19183 .54552 m
.24584 .54768 L
s
.24647 .55508 m
.24584 .54768 L
s
.28229 .5363 m
.2824 .54205 L
s
.43162 .50822 m .45504 .51597 L .43194 .52327 L .558 .338 .538 r
F
.43162 .50822 m .45418 .50105 L .45504 .51597 L F
0 g
.43113 .49333 m
.43162 .50822 L
s
.45223 .48658 m
.45418 .50105 L
s
.37298 .60531 m
.36925 .60364 L
s
.30525 .51807 m
.3149 .51497 L
s
.30525 .51807 m
.30449 .52293 L
s
.29329 .53241 m .29269 .52591 L .29361 .52706 L .963 .689 .469 r
F
.29422 .53337 m .29329 .53241 L .29361 .52706 L F
.2962 .54047 m .29515 .53432 L .29608 .53528 L F
.29712 .54122 m .2962 .54047 L .29608 .53528 L F
.31297 .58865 m .30987 .58538 L .31024 .58431 L F
.31297 .58865 m .31271 .5899 L .30987 .58538 L F
0 g
.31297 .58865 m
.31579 .59247 L
s
.29571 .59239 m
.29887 .5974 L
s
.29887 .5974 m
.30071 .59682 L
s
.38885 .54579 m .42255 .55015 L .38713 .55527 L .558 .338 .538 r
F
.38885 .54579 m .42504 .53738 L .42255 .55015 L F
0 g
.38885 .54579 m
.38938 .53673 L
s
.31538 .5967 m .31194 .59366 L .31219 .59241 L .963 .689 .469 r
F
.31538 .5967 m .31524 .59812 L .31194 .59366 L F
0 g
.34298 .59912 m
.36537 .60096 L
s
0 0 0 r
2 Mabswid
.34972 .53314 Mdot
0 g
.5 Mabswid
.26048 .60115 m
.26412 .60781 L
s
.26412 .60781 m
.29571 .59239 L
s
.26412 .60781 m
.26047 .60116 L
s
.22029 .63927 m
.26412 .60781 L
s
.2264 .64859 m
.23274 .65673 L
s
.47221 .62691 m
.46741 .62956 L
s
.30071 .59682 m
.29755 .59182 L
s
.29236 .53144 m .29177 .52476 L .29269 .52591 L .963 .689 .469 r
F
.29329 .53241 m .29236 .53144 L .29269 .52591 L F
0 g
.18357 .67682 m
.19158 .68685 L
s
.19158 .68685 m
.19571 .68559 L
s
.29527 .53972 m .29422 .53337 L .29515 .53432 L .963 .689 .469 r
F
.2962 .54047 m .29527 .53972 L .29515 .53432 L F
0 g
.36142 .57992 m
.36142 .57128 L
s
.31271 .5899 m .3095 .58645 L .30987 .58538 L .963 .689 .469 r
F
.31271 .5899 m .31245 .59115 L .3095 .58645 L F
0 g
.35407 .45852 m
.35772 .45564 L
s
.38363 .53134 m .41806 .518 L .42573 .52524 L .664 .758 .92 r
F
0 g
.4247 .5137 m
.42573 .52524 L
s
.42573 .52524 m
.43163 .53296 L
s
.37667 .52631 m .41806 .518 L .38363 .53134 L .664 .758 .92 r
F
0 g
.38363 .53134 m
.38938 .53673 L
s
.039 .916 .04 r
.38938 .53673 m
.42573 .52524 L
s
.35559 .53936 m
.38298 .53082 L
s
.31524 .59812 m .31168 .59492 L .31194 .59366 L .963 .689 .469 r
F
.31524 .59812 m .3151 .59953 L .31168 .59492 L F
0 g
.37304 .60482 m
.37691 .60655 L
s
.37691 .60655 m
.4035 .62052 L
s
.29762 .54652 m .2962 .54047 L .29712 .54122 L .963 .689 .469 r
F
0 g
.29701 .53624 m
.29712 .54122 L
s
.32651 .59521 m
.32991 .59905 L
s
.34322 .58758 m .3614 .59731 L .3396 .59604 L .558 .338 .538 r
F
0 g
.32991 .59905 m
.3396 .59604 L
s
.3396 .59604 m
.34298 .59912 L
s
.34322 .58758 m .36141 .58859 L .3614 .59731 L .558 .338 .538 r
F
0 g
.34322 .58758 m
.34609 .57939 L
s
.3396 .59604 m
.34322 .58758 L
s
.29236 .53144 m .29142 .53048 L .29177 .52476 L .963 .689 .469 r
F
0 g
.29177 .52476 m
.29258 .51964 L
s
.28057 .54264 m
.2824 .54205 L
s
.28057 .54264 m
.28112 .54876 L
s
0 0 0 r
2 Mabswid
.38298 .53082 Mdot
.30858 .53291 m .32183 .52868 L .32901 .53233 L .664 .758 .92 r
F
.32901 .53233 m .34118 .52411 L .34629 .52951 L F
0 g
.5 Mabswid
.34629 .52951 m
.35137 .53489 L
s
.32183 .52868 m .34118 .52411 L .32901 .53233 L .664 .758 .92 r
F
0 g
.32901 .53233 m
.33549 .53619 L
s
.30419 .52836 m .32183 .52868 L .30858 .53291 L .664 .758 .92 r
F
.039 .916 .04 r
.31229 .53676 m
.3281 .53183 L
s
0 g
.30858 .53291 m
.31295 .53745 L
s
.24647 .55508 m
.28112 .54876 L
s
.24647 .55508 m
.24764 .5628 L
s
.19272 .55706 m
.24647 .55508 L
s
.24763 .5628 m
.24647 .55508 L
s
.29435 .53897 m .29329 .53241 L .29422 .53337 L .963 .689 .469 r
F
.29527 .53972 m .29435 .53897 L .29422 .53337 L F
0 g
.19571 .68559 m
.1877 .67556 L
s
.31245 .59115 m .30912 .58752 L .3095 .58645 L .963 .689 .469 r
F
.31245 .59115 m .31219 .59241 L .30912 .58752 L F
.3151 .59953 m .31142 .59617 L .31168 .59492 L F
.3151 .59953 m .31496 .60095 L .31142 .59617 L F
0 g
.31496 .60095 m
.31856 .60498 L
s
.28296 .54817 m
.2824 .54205 L
s
.31024 .58431 m .30718 .58039 L .30767 .57952 L .963 .689 .469 r
F
.31024 .58431 m .30987 .58538 L .30718 .58039 L F
0 g
.31024 .58431 m
.31297 .58865 L
s
.29671 .54599 m .29527 .53972 L .2962 .54047 L .963 .689 .469 r
F
.29762 .54652 m .29671 .54599 L .2962 .54047 L F
0 0 0 r
2 Mabswid
.3281 .53183 Mdot
0 g
.5 Mabswid
.29755 .59182 m
.29571 .59239 L
s
.29272 .58687 m
.29571 .59239 L
s
.25712 .59398 m
.26048 .60115 L
s
.26048 .60115 m
.29272 .58687 L
s
.26047 .60116 m
.25711 .59398 L
s
.21453 .62894 m
.26047 .60116 L
s
.33341 .49611 m
.33523 .49204 L
s
.29342 .53822 m .29236 .53144 L .29329 .53241 L .963 .689 .469 r
F
.29435 .53897 m .29342 .53822 L .29329 .53241 L F
0 g
.29755 .59182 m
.29456 .5863 L
s
.31219 .59241 m .30875 .58859 L .30912 .58752 L .963 .689 .469 r
F
.31219 .59241 m .31194 .59366 L .30875 .58859 L F
.29848 .55204 m .29671 .54599 L .29762 .54652 L F
0 g
.29712 .54122 m
.29762 .54652 L
s
.30987 .58538 m .3067 .58126 L .30718 .58039 L .963 .689 .469 r
F
.30987 .58538 m .3095 .58645 L .3067 .58126 L F
.29581 .54547 m .29435 .53897 L .29527 .53972 L F
.29671 .54599 m .29581 .54547 L .29527 .53972 L F
0 g
.28112 .54876 m
.28296 .54817 L
s
.28112 .54876 m
.28211 .55513 L
s
.30767 .57952 m .3047 .57502 L .30528 .57437 L .963 .689 .469 r
F
.30767 .57952 m .30718 .58039 L .3047 .57502 L F
0 g
.30767 .57952 m
.31024 .58431 L
s
.24764 .5628 m
.28211 .55513 L
s
.24764 .5628 m
.24932 .57069 L
s
.24763 .5628 m
.19446 .5691 L
s
.24932 .57069 m
.24763 .5628 L
s
.19182 .53469 m
.19183 .54552 L
s
.29249 .53747 m .29142 .53048 L .29236 .53144 L .963 .689 .469 r
F
.29342 .53822 m .29249 .53747 L .29236 .53144 L F
0 g
.33621 .59219 m
.3396 .59604 L
s
.3396 .59604 m
.3614 .59731 L
s
.31194 .59366 m .30838 .58967 L .30875 .58859 L .963 .689 .469 r
F
.31194 .59366 m .31168 .59492 L .30838 .58967 L F
.43194 .52327 m .45504 .51597 L .46303 .52574 L .664 .758 .92 r
F
.039 .916 .04 r
.43823 .53031 m
.46104 .52314 L
s
0 g
.46303 .52574 m
.46985 .53576 L
s
.38713 .55527 m .41811 .56359 L .38413 .56517 L .558 .338 .538 r
F
.38713 .55527 m .42255 .55015 L .41811 .56359 L F
0 g
.38713 .55527 m
.38885 .54579 L
s
.28395 .55455 m
.28296 .54817 L
s
.40829 .62135 m
.4035 .62052 L
s
.29762 .55175 m .29581 .54547 L .29671 .54599 L .963 .689 .469 r
F
.29848 .55204 m .29762 .55175 L .29671 .54599 L F
.3095 .58645 m .30622 .58213 L .3067 .58126 L F
.3095 .58645 m .30912 .58752 L .30622 .58213 L F
0 g
.28996 .58093 m
.29272 .58687 L
s
.29272 .58687 m
.29456 .5863 L
s
.33768 .48885 m
.35098 .46278 L
s
.33768 .48885 m
.33579 .49307 L
s
.2541 .58642 m
.25712 .59398 L
s
.25712 .59398 m
.28996 .58093 L
s
.25711 .59398 m
.2541 .58642 L
s
.20923 .61777 m
.25711 .59398 L
s
.29971 .55768 m .29762 .55175 L .29848 .55204 L .963 .689 .469 r
F
0 g
.29762 .54652 m
.29848 .55204 L
s
.2949 .54494 m .29342 .53822 L .29435 .53897 L .963 .689 .469 r
F
.29581 .54547 m .2949 .54494 L .29435 .53897 L F
0 g
.39622 .41737 m
.40197 .41546 L
s
.39622 .41737 m
.39107 .41908 L
s
.32317 .59068 m
.32651 .59521 L
s
.32651 .59521 m
.33621 .59219 L
s
.29249 .53747 m .29156 .53672 L .29142 .53048 L .963 .689 .469 r
F
0 g
.29142 .53048 m
.29177 .52476 L
s
.29456 .5863 m
.2918 .58035 L
s
.36925 .60364 m
.36537 .60096 L
s
.30528 .57437 m .30247 .56937 L .30314 .56895 L .963 .689 .469 r
F
.30528 .57437 m .3047 .57502 L .30247 .56937 L F
0 g
.30528 .57437 m
.30767 .57952 L
s
.30718 .58039 m .30412 .57568 L .3047 .57502 L .963 .689 .469 r
F
.30718 .58039 m .3067 .58126 L .30412 .57568 L F
0 g
.14063 .53519 m
.14474 .53384 L
s
.1405 .54866 m
.14063 .53519 L
s
.24932 .57069 m
.28352 .56166 L
s
.24932 .57069 m
.25149 .57861 L
s
.19704 .58142 m
.24932 .57069 L
s
.25148 .57861 m
.24932 .57069 L
s
.31168 .59492 m .308 .59074 L .30838 .58967 L .963 .689 .469 r
F
.31168 .59492 m .31142 .59617 L .308 .59074 L F
0 g
.31142 .59617 m
.31496 .60095 L
s
.28211 .55513 m
.28395 .55455 L
s
.28211 .55513 m
.28352 .56166 L
s
.25149 .57861 m
.2541 .58642 L
s
.2541 .58642 m
.28748 .57467 L
s
.2541 .58642 m
.25148 .57861 L
s
.2045 .60599 m
.2541 .58642 L
s
.29971 .55768 m .29889 .55763 L .29762 .55175 L .963 .689 .469 r
F
.30127 .56336 m .29889 .55763 L .29971 .55768 L F
0 g
.29848 .55204 m
.29971 .55768 L
s
.30912 .58752 m .30574 .583 L .30622 .58213 L .963 .689 .469 r
F
.30912 .58752 m .30875 .58859 L .30574 .583 L F
0 g
.36141 .58859 m
.36142 .57992 L
s
.29675 .55145 m .2949 .54494 L .29581 .54547 L .963 .689 .469 r
F
.29762 .55175 m .29675 .55145 L .29581 .54547 L F
0 g
.25149 .57861 m
.28532 .56821 L
s
.20041 .59379 m
.25148 .57861 L
s
.29399 .54441 m .29249 .53747 L .29342 .53822 L .963 .689 .469 r
F
.2949 .54494 m .29399 .54441 L .29342 .53822 L F
.30314 .56895 m .30052 .56354 L .30127 .56336 L F
.30314 .56895 m .30247 .56937 L .30052 .56354 L F
0 g
.30314 .56895 m
.30528 .57437 L
s
.32183 .52868 m .33606 .51868 L .34118 .52411 L .664 .758 .92 r
F
0 g
.34118 .52411 m
.34629 .52951 L
s
.31387 .52525 m .33606 .51868 L .32183 .52868 L .664 .758 .92 r
F
.039 .916 .04 r
.3281 .53183 m
.34386 .52694 L
s
0 g
.30449 .52293 m
.31416 .51982 L
s
.31416 .51982 m
.3149 .51497 L
s
.30419 .52836 m .31387 .52525 L .32183 .52868 L .664 .758 .92 r
F
0 g
.32183 .52868 m
.32901 .53233 L
s
.30419 .52836 m
.30449 .52293 L
s
.30419 .52836 m
.30858 .53291 L
s
.29889 .55763 m .29675 .55145 L .29762 .55175 L .963 .689 .469 r
F
0 g
.28748 .57467 m
.28996 .58093 L
s
.28996 .58093 m
.2918 .58035 L
s
.30127 .56336 m .30052 .56354 L .29889 .55763 L .963 .689 .469 r
F
0 g
.30127 .56336 m
.30314 .56895 L
s
.29971 .55768 m
.30127 .56336 L
s
.28536 .56107 m
.28395 .55455 L
s
0 0 0 r
2 Mabswid
.42573 .52524 Mdot
0 g
.5 Mabswid
.42504 .53738 m
.42573 .52524 L
s
.22029 .63927 m
.2264 .64859 L
s
.3067 .58126 m .30354 .57633 L .30412 .57568 L .963 .689 .469 r
F
.3067 .58126 m .30622 .58213 L .30354 .57633 L F
.3047 .57502 m .30179 .5698 L .30247 .56937 L F
.3047 .57502 m .30412 .57568 L .30179 .5698 L F
0 g
.14462 .54732 m
.14474 .53384 L
s
.2918 .58035 m
.28932 .57409 L
s
.28352 .56166 m
.28536 .56107 L
s
.28352 .56166 m
.28532 .56821 L
s
.37667 .52631 m .40856 .51129 L .41806 .518 L .664 .758 .92 r
F
.36839 .52165 m .40856 .51129 L .37667 .52631 L F
0 g
.37667 .52631 m
.38363 .53134 L
s
.039 .916 .04 r
.34972 .53314 m
.3751 .52533 L
s
0 g
.39684 .41717 m
.40197 .41546 L
s
.28532 .56821 m
.28748 .57467 L
s
.28748 .57467 m
.28932 .57409 L
s
.30875 .58859 m .30525 .58387 L .30574 .583 L .963 .689 .469 r
F
.30875 .58859 m .30838 .58967 L .30525 .58387 L F
0 g
.36901 .60203 m
.37304 .60482 L
s
.30419 .52836 m
.30433 .53427 L
s
.29587 .55116 m .29399 .54441 L .2949 .54494 L .963 .689 .469 r
F
.29675 .55145 m .29587 .55116 L .2949 .54494 L F
.29889 .55763 m .29807 .55758 L .29675 .55145 L F
.30052 .56354 m .29807 .55758 L .29889 .55763 L F
.29308 .54388 m .29156 .53672 L .29249 .53747 L F
.29399 .54441 m .29308 .54388 L .29249 .53747 L F
0 g
.28532 .56821 m
.28716 .56763 L
s
0 0 0 r
2 Mabswid
.34386 .52694 Mdot
0 g
.5 Mabswid
.28716 .56763 m
.28536 .56107 L
s
.039 .916 .04 r
.46104 .52314 m
.91505 .3705 L
s
0 0 0 r
2 Mabswid
.46104 .52314 Mdot
.30247 .56937 m .29976 .56373 L .30052 .56354 L .963 .689 .469 r
F
.30247 .56937 m .30179 .5698 L .29976 .56373 L F
.29807 .55758 m .29587 .55116 L .29675 .55145 L F
.30052 .56354 m .29976 .56373 L .29807 .55758 L F
0 g
.5 Mabswid
.28932 .57409 m
.28716 .56763 L
s
.30622 .58213 m .30295 .57698 L .30354 .57633 L .963 .689 .469 r
F
.30622 .58213 m .30574 .583 L .30295 .57698 L F
0 0 0 r
2 Mabswid
.3751 .52533 Mdot
.30412 .57568 m .30112 .57022 L .30179 .5698 L .963 .689 .469 r
F
.30412 .57568 m .30354 .57633 L .30112 .57022 L F
0 g
.5 Mabswid
.33287 .58765 m
.33621 .59219 L
s
.33621 .59219 m
.35742 .59274 L
s
.43194 .52327 m .45482 .53134 L .43209 .53849 L .558 .338 .538 r
F
.43194 .52327 m .45504 .51597 L .45482 .53134 L F
.42317 .51368 m .45504 .51597 L .43194 .52327 L .664 .758 .92 r
F
0 0 0 r
2 Mabswid
.43194 .52327 Mdot
.039 .916 .04 r
.5 Mabswid
.42573 .52524 m
.43194 .52327 L
s
0 g
.43162 .50822 m
.43175 .5143 L
s
.41806 .518 m
.42573 .52524 L
s
.30838 .58967 m .30477 .58474 L .30525 .58387 L .963 .689 .469 r
F
.30838 .58967 m .308 .59074 L .30477 .58474 L F
0 g
.308 .59074 m
.31142 .59617 L
s
.17586 .6653 m
.18357 .67682 L
s
.18357 .67682 m
.1877 .67556 L
s
.29308 .54388 m .29217 .54336 L .29156 .53672 L .963 .689 .469 r
F
0 g
.29142 .53048 m
.29156 .53672 L
s
.31994 .58552 m
.32317 .59068 L
s
.32317 .59068 m
.33287 .58765 L
s
.295 .55087 m .29308 .54388 L .29399 .54441 L .963 .689 .469 r
F
.29587 .55116 m .295 .55087 L .29399 .54441 L F
0 g
.33206 .50106 m
.33341 .49611 L
s
.29807 .55758 m .29725 .55752 L .29587 .55116 L .963 .689 .469 r
F
.29976 .56373 m .29725 .55752 L .29807 .55758 L F
.38413 .56517 m .41137 .57779 L .37967 .57556 L .558 .338 .538 r
F
.38413 .56517 m .41811 .56359 L .41137 .57779 L F
0 g
.38413 .56517 m
.38713 .55527 L
s
.30179 .5698 m .29901 .56391 L .29976 .56373 L .963 .689 .469 r
F
.30179 .5698 m .30112 .57022 L .29901 .56391 L F
.29725 .55752 m .295 .55087 L .29587 .55116 L F
.29976 .56373 m .29901 .56391 L .29725 .55752 L F
.30574 .583 m .30237 .57764 L .30295 .57698 L F
.30574 .583 m .30525 .58387 L .30237 .57764 L F
.30354 .57633 m .30044 .57064 L .30112 .57022 L F
.30354 .57633 m .30295 .57698 L .30044 .57064 L F
0 g
.35098 .46278 m
.35407 .45852 L
s
.45617 .63214 m
.4616 .63131 L
s
.4616 .63131 m
.46741 .62956 L
s
.19183 .54552 m
.19272 .55706 L
s
.1877 .67556 m
.18 .66403 L
s
.29413 .55057 m .29217 .54336 L .29308 .54388 L .963 .689 .469 r
F
.295 .55087 m .29413 .55057 L .29308 .54388 L F
.29725 .55752 m .29643 .55747 L .295 .55087 L F
.29901 .56391 m .29643 .55747 L .29725 .55752 L F
0 g
.30433 .53427 m
.31402 .53117 L
s
.30433 .53427 m
.30493 .54056 L
s
.31387 .52525 m .3309 .51322 L .33606 .51868 L .664 .758 .92 r
F
0 g
.31387 .52525 m
.31402 .53117 L
s
.31387 .52525 m
.3309 .51322 L
s
.30419 .52836 m
.31387 .52525 L
s
.31387 .52525 m
.31416 .51982 L
s
.31416 .51982 m
.33122 .50679 L
s
.31387 .52525 m
.32183 .52868 L
s
.3149 .51497 m
.33206 .50106 L
s
.29643 .55747 m .29413 .55057 L .295 .55087 L .963 .689 .469 r
F
.30112 .57022 m .29826 .5641 L .29901 .56391 L F
.30112 .57022 m .30044 .57064 L .29826 .5641 L F
.29901 .56391 m .29826 .5641 L .29643 .55747 L F
0 g
.33606 .51868 m
.34118 .52411 L
s
.33579 .49307 m
.3344 .4982 L
s
.30525 .58387 m .30178 .57829 L .30237 .57764 L .963 .689 .469 r
F
.30525 .58387 m .30477 .58474 L .30178 .57829 L F
0 g
.30477 .58474 m
.308 .59074 L
s
.30295 .57698 m .29977 .57107 L .30044 .57064 L .963 .689 .469 r
F
.30295 .57698 m .30237 .57764 L .29977 .57107 L F
0 g
.3614 .59731 m
.36141 .58859 L
s
.29413 .55057 m .29326 .55028 L .29217 .54336 L .963 .689 .469 r
F
0 g
.29156 .53672 m
.29217 .54336 L
s
.31688 .57982 m
.31994 .58552 L
s
.31994 .58552 m
.32965 .58248 L
s
.46741 .62956 m
.462 .63038 L
s
.29643 .55747 m .29561 .55741 L .29413 .55057 L .963 .689 .469 r
F
.29826 .5641 m .29561 .55741 L .29643 .55747 L F
0 g
.32965 .58248 m
.33287 .58765 L
s
.33287 .58765 m
.35349 .58734 L
s
.29561 .55741 m .29326 .55028 L .29413 .55057 L .963 .689 .469 r
F
0 g
.21453 .62894 m
.22029 .63927 L
s
.30044 .57064 m .2975 .56429 L .29826 .5641 L .963 .689 .469 r
F
.30044 .57064 m .29977 .57107 L .2975 .56429 L F
.29826 .5641 m .2975 .56429 L .29561 .55741 L F
.30237 .57764 m .29909 .57149 L .29977 .57107 L F
.30237 .57764 m .30178 .57829 L .29909 .57149 L F
0 g
.30178 .57829 m
.30477 .58474 L
s
.36839 .52165 m .39705 .50515 L .40856 .51129 L .664 .758 .92 r
F
.35864 .51744 m .39705 .50515 L .36839 .52165 L F
.039 .916 .04 r
.38298 .53082 m
.41856 .51841 L
s
0 g
.36839 .52165 m
.37667 .52631 L
s
.039 .916 .04 r
.34386 .52694 m
.36561 .52033 L
s
0 g
.1405 .54866 m
.14462 .54732 L
s
.1405 .54866 m
.14149 .56302 L
s
.37967 .57556 m .40169 .59295 L .37346 .58653 L .558 .338 .538 r
F
.37967 .57556 m .41137 .57779 L .40169 .59295 L F
0 g
.37967 .57556 m
.38413 .56517 L
s
.30493 .54056 m
.31463 .53747 L
s
.30493 .54056 m
.30596 .54713 L
s
.29561 .55741 m .29479 .55736 L .29326 .55028 L .963 .689 .469 r
F
0 g
.29217 .54336 m
.29326 .55028 L
s
.2975 .56429 m .29479 .55736 L .29561 .55741 L .963 .689 .469 r
F
0 g
.4035 .62052 m
.39841 .61824 L
s
.42255 .55015 m
.42504 .53738 L
s
.29977 .57107 m .29675 .56447 L .2975 .56429 L .963 .689 .469 r
F
.29977 .57107 m .29909 .57149 L .29675 .56447 L F
0 g
.31402 .53117 m
.33111 .52024 L
s
.31402 .53117 m
.31463 .53747 L
s
.2975 .56429 m .29675 .56447 L .29479 .55736 L .963 .689 .469 r
F
0 g
.29326 .55028 m
.29479 .55736 L
s
.31405 .5737 m
.31688 .57982 L
s
.31688 .57982 m
.3266 .57677 L
s
.29909 .57149 m
.30178 .57829 L
s
.14562 .56169 m
.14462 .54732 L
s
.33122 .50679 m
.33206 .50106 L
s
0 0 0 r
2 Mabswid
.36561 .52033 Mdot
.039 .916 .04 r
.5 Mabswid
.41856 .51841 m
.42552 .51622 L
s
0 0 0 r
2 Mabswid
.41856 .51841 Mdot
0 g
.5 Mabswid
.19272 .55706 m
.19446 .5691 L
s
.29479 .55736 m
.29675 .56447 L
s
.3266 .57677 m
.32965 .58248 L
s
.32965 .58248 m
.34969 .5812 L
s
.30596 .54713 m
.31567 .54404 L
s
.30596 .54713 m
.30742 .55384 L
s
.29675 .56447 m
.29909 .57149 L
s
.1686 .65249 m
.17586 .6653 L
s
.17586 .6653 m
.18 .66403 L
s
.31151 .56725 m
.31405 .5737 L
s
.31405 .5737 m
.32378 .57064 L
s
.42317 .51368 m .44589 .50646 L .45504 .51597 L .664 .758 .92 r
F
0 0 0 r
2 Mabswid
.45504 .51597 Mdot
.039 .916 .04 r
.5 Mabswid
.45504 .51597 m
.91506 .37052 L
s
.43194 .52327 m
.45504 .51597 L
s
0 g
.45418 .50105 m
.45504 .51597 L
s
.45504 .51597 m
.46303 .52574 L
s
.37346 .58653 m .38762 .60949 L .36489 .59824 L .558 .338 .538 r
F
0 g
.36489 .59824 m
.36901 .60203 L
s
.3614 .59731 m
.36537 .60096 L
s
.37346 .58653 m .40169 .59295 L .38762 .60949 L .558 .338 .538 r
F
0 g
.37304 .60482 m
.39841 .61824 L
s
.37346 .58653 m
.37967 .57556 L
s
.36901 .60203 m
.39308 .61455 L
s
.36489 .59824 m
.37346 .58653 L
s
.30742 .55384 m
.31714 .55076 L
s
.30742 .55384 m
.30928 .56059 L
s
.20923 .61777 m
.21453 .62894 L
s
.31463 .53747 m
.33185 .52771 L
s
.31463 .53747 m
.31567 .54404 L
s
.35742 .59274 m
.3614 .59731 L
s
.32123 .56418 m
.31151 .56725 L
s
.30928 .56059 m
.31151 .56725 L
s
.3344 .4982 m
.33353 .50416 L
s
.39107 .41908 m
.39684 .41717 L
s
.39107 .41908 m
.38652 .42262 L
s
.18 .66403 m
.17275 .65121 L
s
.30928 .56059 m
.319 .55751 L
s
0 0 0 r
2 Mabswid
.42552 .51622 Mdot
0 g
.5 Mabswid
.32378 .57064 m
.3266 .57677 L
s
.3266 .57677 m
.34609 .57442 L
s
.43209 .53849 m .45349 .54717 L .43208 .55386 L .558 .338 .538 r
F
.43209 .53849 m .45482 .53134 L .45349 .54717 L F
0 g
.43194 .52327 m
.43209 .53849 L
s
.45482 .53134 m
.45504 .51597 L
s
.35864 .51744 m .3832 .49971 L .39705 .50515 L .664 .758 .92 r
F
.3471 .51377 m .3832 .49971 L .35864 .51744 L F
.039 .916 .04 r
.3751 .52533 m
.40972 .51201 L
s
0 g
.35864 .51744 m
.36839 .52165 L
s
.19446 .5691 m
.19704 .58142 L
s
.31567 .54404 m
.33311 .53551 L
s
.31567 .54404 m
.31714 .55076 L
s
.34848 .46836 m
.35098 .46278 L
s
.14149 .56302 m
.14562 .56169 L
s
.14149 .56302 m
.14358 .57802 L
s
.39232 .4207 m
.39684 .41717 L
s
.36076 .5935 m
.36489 .59824 L
s
.36489 .59824 m
.38762 .60949 L
s
.32123 .56418 m
.32378 .57064 L
s
.32378 .57064 m
.34274 .56712 L
s
.2045 .60599 m
.20923 .61777 L
s
.3309 .51322 m
.33122 .50679 L
s
.31714 .55076 m
.33486 .54349 L
s
.31714 .55076 m
.319 .55751 L
s
.33972 .55945 m
.32123 .56418 L
s
.319 .55751 m
.32123 .56418 L
s
.41811 .56359 m
.42255 .55015 L
s
.41416 .50406 m .44589 .50646 L .42317 .51368 L .664 .758 .92 r
F
.039 .916 .04 r
.42552 .51622 m
.44841 .50894 L
s
0 g
.42317 .51368 m
.43194 .52327 L
s
.40856 .51129 m
.41806 .518 L
s
.14771 .57669 m
.14562 .56169 L
s
.319 .55751 m
.33708 .55152 L
s
.19704 .58142 m
.20041 .59379 L
s
.16194 .63863 m
.1686 .65249 L
s
.1686 .65249 m
.17275 .65121 L
s
.20041 .59379 m
.2045 .60599 L
s
.35742 .59274 m
.35349 .58734 L
s
.45021 .63111 m
.45617 .63214 L
s
.45617 .63214 m
.462 .63038 L
s
.39841 .61824 m
.39308 .61455 L
s
.17275 .65121 m
.16609 .63733 L
s
.039 .916 .04 r
.40972 .51201 m
.41893 .50912 L
s
0 0 0 r
2 Mabswid
.40972 .51201 Mdot
.3471 .51377 m .36636 .49518 L .3832 .49971 L .664 .758 .92 r
F
.3332 .51084 m .36636 .49518 L .3471 .51377 L F
0 g
.5 Mabswid
.3471 .51377 m
.35864 .51744 L
s
.3309 .51322 m
.33606 .51868 L
s
.14358 .57802 m
.14771 .57669 L
s
.14358 .57802 m
.14673 .59337 L
s
.39705 .50515 m
.40856 .51129 L
s
.462 .63038 m
.45607 .62934 L
s
.35668 .58788 m
.36076 .5935 L
s
.36076 .5935 m
.38213 .60314 L
s
.3309 .51322 m
.33111 .52024 L
s
.156 .62397 m
.16194 .63863 L
s
.16194 .63863 m
.16609 .63733 L
s
.15087 .59205 m
.14771 .57669 L
s
.039 .916 .04 r
.44841 .50894 m
.91507 .37053 L
s
0 0 0 r
2 Mabswid
.44841 .50894 Mdot
.41893 .50912 Mdot
0 g
.5 Mabswid
.35349 .58734 m
.34969 .5812 L
s
.41137 .57779 m
.41811 .56359 L
s
.16609 .63733 m
.16015 .62266 L
s
.14673 .59337 m
.15087 .59205 L
s
.14673 .59337 m
.1509 .60879 L
s
.16015 .62266 m
.156 .62397 L
s
.1509 .60879 m
.156 .62397 L
s
.3332 .51084 m .34511 .49204 L .36636 .49518 L .664 .758 .92 r
F
0 g
.3332 .51084 m
.34511 .49204 L
s
.3344 .4982 m
.34665 .47518 L
s
.33353 .50416 m
.34552 .48311 L
s
.3332 .51084 m
.33353 .50416 L
s
.3332 .51084 m
.3471 .51377 L
s
.039 .916 .04 r
.36561 .52033 m
.39899 .50607 L
s
0 g
.33579 .49307 m
.34848 .46836 L
s
.3332 .51084 m
.33342 .51812 L
s
.34665 .47518 m
.34848 .46836 L
s
.1509 .60879 m
.15505 .60747 L
s
.43208 .55386 m .45101 .56346 L .43189 .5694 L .558 .338 .538 r
F
.43208 .55386 m .45349 .54717 L .45101 .56346 L F
0 g
.43208 .55386 m
.43209 .53849 L
s
.45349 .54717 m
.45482 .53134 L
s
.15505 .60747 m
.15087 .59205 L
s
.41416 .50406 m .43555 .49722 L .44589 .50646 L .664 .758 .92 r
F
0 g
.44589 .50646 m
.45504 .51597 L
s
.33185 .52771 m
.33111 .52024 L
s
.16015 .62266 m
.15505 .60747 L
s
.38652 .42262 m
.39232 .4207 L
s
.38652 .42262 m
.38267 .42796 L
s
.35274 .5815 m
.35668 .58788 L
s
.35668 .58788 m
.37669 .59562 L
s
.34969 .5812 m
.34609 .57442 L
s
0 0 0 r
2 Mabswid
.39899 .50607 Mdot
0 g
.5 Mabswid
.38762 .60949 m
.39308 .61455 L
s
.38849 .42603 m
.39232 .4207 L
s
.33342 .51812 m
.34543 .5018 L
s
.33342 .51812 m
.33419 .52589 L
s
.40169 .59295 m
.41137 .57779 L
s
.3832 .49971 m
.39705 .50515 L
s
.33311 .53551 m
.33185 .52771 L
s
.40489 .4944 m .43555 .49722 L .41416 .50406 L .664 .758 .92 r
F
.039 .916 .04 r
.39899 .50607 m
.41215 .50194 L
s
0 g
.41416 .50406 m
.42317 .51368 L
s
.039 .916 .04 r
.41893 .50912 m
.44111 .50203 L
s
0 g
.34609 .57442 m
.34274 .56712 L
s
.34899 .57445 m
.35274 .5815 L
s
.35274 .5815 m
.37142 .58704 L
s
.039 .916 .04 r
.44111 .50203 m
.91509 .37056 L
s
0 0 0 r
2 Mabswid
.44111 .50203 Mdot
0 g
.5 Mabswid
.44384 .62822 m
.45021 .63111 L
s
.45021 .63111 m
.45607 .62934 L
s
.33486 .54349 m
.33311 .53551 L
s
.33419 .52589 m
.34649 .51223 L
s
.33419 .52589 m
.3355 .534 L
s
.34274 .56712 m
.33972 .55945 L
s
0 0 0 r
2 Mabswid
.41215 .50194 Mdot
0 g
.5 Mabswid
.34552 .48311 m
.34665 .47518 L
s
.33708 .55152 m
.33486 .54349 L
s
.45607 .62934 m
.44971 .62645 L
s
.38762 .60949 m
.40169 .59295 L
s
.34552 .56687 m
.34899 .57445 L
s
.34899 .57445 m
.36641 .57757 L
s
.33972 .55945 m
.33708 .55152 L
s
.3355 .534 m
.34826 .52312 L
s
.3355 .534 m
.33733 .5423 L
s
.43189 .5694 m .44735 .58022 L .43153 .5851 L .558 .338 .538 r
F
.43189 .5694 m .45101 .56346 L .44735 .58022 L F
0 g
.43189 .5694 m
.43208 .55386 L
s
.45101 .56346 m
.45349 .54717 L
s
.34238 .55888 m
.34552 .56687 L
s
.34552 .56687 m
.36176 .56736 L
s
.38213 .60314 m
.38762 .60949 L
s
.36636 .49518 m
.3832 .49971 L
s
.33733 .5423 m
.35073 .53429 L
s
.33733 .5423 m
.33963 .55064 L
s
.35754 .55662 m
.34238 .55888 L
s
.33963 .55064 m
.34238 .55888 L
s
.33963 .55064 m
.35384 .54552 L
s
.40489 .4944 m .424 .48827 L .43555 .49722 L .664 .758 .92 r
F
.039 .916 .04 r
.41215 .50194 m
.43307 .49519 L
s
0 g
.43555 .49722 m
.44589 .50646 L
s
.38267 .42796 m
.38849 .42603 L
s
.38267 .42796 m
.37959 .43501 L
s
.039 .916 .04 r
.43307 .49519 m
.9151 .37058 L
s
0 0 0 r
2 Mabswid
.43307 .49519 Mdot
0 g
.5 Mabswid
.38543 .43308 m
.38849 .42603 L
s
.34511 .49204 m
.34552 .48311 L
s
.39537 .48472 m .424 .48827 L .40489 .4944 L .664 .758 .92 r
F
0 g
.40489 .4944 m
.41416 .50406 L
s
.34511 .49204 m
.36636 .49518 L
s
.43715 .6235 m
.44384 .62822 L
s
.44384 .62822 m
.44971 .62645 L
s
.38213 .60314 m
.37669 .59562 L
s
.43153 .5851 m .44244 .59746 L .43099 .60097 L .558 .338 .538 r
F
.43153 .5851 m .44735 .58022 L .44244 .59746 L F
0 g
.43153 .5851 m
.43189 .5694 L
s
.44735 .58022 m
.45101 .56346 L
s
.44971 .62645 m
.44305 .62171 L
s
.34511 .49204 m
.34543 .5018 L
s
.39537 .48472 m .41118 .47962 L .424 .48827 L .664 .758 .92 r
F
0 g
.424 .48827 m
.43555 .49722 L
s
.37959 .43501 m
.38543 .43308 L
s
.37959 .43501 m
.37734 .44367 L
s
.37669 .59562 m
.37142 .58704 L
s
.38321 .44175 m
.38543 .43308 L
s
.34649 .51223 m
.34543 .5018 L
s
.43715 .6235 m
.44305 .62171 L
s
.38559 .47501 m .41118 .47962 L .39537 .48472 L .664 .758 .92 r
F
0 g
.39537 .48472 m
.40489 .4944 L
s
.43099 .60097 m .43618 .6152 L .43027 .617 L .558 .338 .538 r
F
0 g
.43027 .617 m
.43715 .6235 L
s
.43099 .60097 m .44244 .59746 L .43618 .6152 L .558 .338 .538 r
F
0 g
.43099 .60097 m
.43153 .5851 L
s
.43027 .617 m
.43099 .60097 L
s
.44244 .59746 m
.44735 .58022 L
s
.37142 .58704 m
.36641 .57757 L
s
.43618 .6152 m
.44305 .62171 L
s
.34826 .52312 m
.34649 .51223 L
s
.43618 .6152 m
.44244 .59746 L
s
.36641 .57757 m
.36176 .56736 L
s
.38559 .47501 m .39702 .4713 L .41118 .47962 L .664 .758 .92 r
F
0 g
.41118 .47962 m
.424 .48827 L
s
.37734 .44367 m
.38321 .44175 L
s
.37734 .44367 m
.37599 .45382 L
s
.35073 .53429 m
.34826 .52312 L
s
.36176 .56736 m
.35754 .55662 L
s
.38187 .45189 m
.38321 .44175 L
s
.35384 .54552 m
.35073 .53429 L
s
.35754 .55662 m
.35384 .54552 L
s
.42331 .60883 m
.43027 .617 L
s
.43027 .617 m
.43618 .6152 L
s
.37555 .46526 m .39702 .4713 L .38559 .47501 L .664 .758 .92 r
F
0 g
.38559 .47501 m
.39537 .48472 L
s
.42924 .60702 m
.43618 .6152 L
s
.37599 .45382 m
.38187 .45189 L
s
.37555 .46526 m .38145 .46334 L .39702 .4713 L .664 .758 .92 r
F
0 g
.38145 .46334 m
.39702 .4713 L
s
.37555 .46526 m
.37599 .45382 L
s
.39702 .4713 m
.41118 .47962 L
s
.37555 .46526 m
.38559 .47501 L
s
.38145 .46334 m
.38187 .45189 L
s
.41641 .59912 m
.42331 .60883 L
s
.42331 .60883 m
.42924 .60702 L
s
.42924 .60702 m
.42235 .5973 L
s
.37555 .46526 m
.38145 .46334 L
s
.37555 .46526 m
.37605 .47781 L
s
.38145 .46334 m
.38196 .4759 L
s
.40969 .58804 m
.41641 .59912 L
s
.41641 .59912 m
.42235 .5973 L
s
.42235 .5973 m
.41564 .5862 L
s
.37605 .47781 m
.38196 .4759 L
s
.37605 .47781 m
.37748 .49125 L
s
.38341 .48933 m
.38196 .4759 L
s
.40328 .57578 m
.40969 .58804 L
s
.40969 .58804 m
.41564 .5862 L
s
.41564 .5862 m
.40924 .57393 L
s
.37748 .49125 m
.38341 .48933 L
s
.37748 .49125 m
.37983 .50531 L
s
.39731 .56257 m
.40328 .57578 L
s
.40328 .57578 m
.40924 .57393 L
s
.38577 .50341 m
.38341 .48933 L
s
.40924 .57393 m
.40326 .56071 L
s
.37983 .50531 m
.38577 .50341 L
s
.37983 .50531 m
.38305 .51975 L
s
.39188 .54865 m
.39731 .56257 L
s
.39731 .56257 m
.40326 .56071 L
s
.389 .51785 m
.38577 .50341 L
s
.38305 .51975 m
.389 .51785 L
s
.38305 .51975 m
.38709 .53429 L
s
.40326 .56071 m
.39783 .54678 L
s
.38709 .53429 m
.39188 .54865 L
s
.39188 .54865 m
.39783 .54678 L
s
.38709 .53429 m
.39305 .5324 L
s
.39305 .5324 m
.389 .51785 L
s
.39783 .54678 m
.39305 .5324 L
s
0 0 0 r
2 Mabswid
.9151 .37058 Mdot
.91509 .37056 Mdot
.91507 .37053 Mdot
.91506 .37052 Mdot
.91505 .3705 Mdot
.91503 .37047 Mdot
.91502 .37045 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{839, 227.625},
  ImageMargins->{{2, 0}, {0, 0}},
  ImageRegion->{{-0.0913108, 1.06922}, {-0.808684, 1.63501}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000=70000hb000`400?l00000o`00003oo`3ooooo
0?ooool0ooooBP3oool00?l0ooooo`3ooooo0?ooodX0oooo003o0?ooool0ooooo`3ooom:0?ooo`00
o`3ooooo0?ooool0ooooBP3oool00?l0ooooo`3ooooo0?ooodX0oooo003o0?ooool0ooooo`3ooom:
0?ooo`00o`3ooooo0?ooool0ooooBP3oool00?l0ooooo`3ooooo0?ooodX0oooo003o0?ooool0oooo
o`3ooom:0?ooo`00o`3ooooo0?ooool0ooooBP3oool00?l0ooooo`3ooooo0?ooodX0oooo003o0?oo
ool0ooooo`3ooom:0?ooo`00o`3ooooo0?ooool0ooooBP3oool00?l0ooooo`3ooooo0?ooodX0oooo
003o0?ooool0ooooo`3ooom:0?ooo`00o`3ooooo0?ooool0ooooBP3oool00?l0ooooo`3ooooo0?oo
odX0oooo003o0?ooool0ooooo`3ooom:0?ooo`00o`3ooooo0?ooool0ooooBP3oool00?l0ooooo`3o
oooo0?ooodX0oooo003o0?ooool0ooooo`3ooom:0?ooo`00o`3ooooo0?ooool0ooooBP3oool00?l0
ooooo`3ooooo0?ooodX0oooo003o0?ooool0ooooo`3ooom:0?ooo`00o`3ooonS0?ooo`802NX:0P00
003o0?oooiD0oooo0P00000;0?ooo`00o`3ooonO0?ooo`D02NX:00<0oooo000000000000o`3ooonD
0?ooo`0300WZ2P000000000000/0oooo003o0?oooi`0oooo1@09jP[o0?oooiH0oooo1@09jPX=0?oo
o`00o`3ooonH0?ooo`L02NX:o`3ooonD0?ooo`H02NX:403oool00?l0ooooU03oool800WZ2_l0oooo
T`3oool700WZ2Q<0oooo003o0?oooi00oooo2P09jP[o0?oooi80oooo2009jPXE0?ooo`00o`3ooon=
0?ooo`X02NX:o`3ooonA0?ooo`T02NX:603oool00?l0ooooR@3oool<00WZ2_l0ooooS`3oool:00WZ
2Q/0oooo003o0?ooohD0oooo3@09jP[o0?ooohh0oooo3009jPXM0?ooo`00o`3ooon10?ooo`h02NX:
o`3ooon=0?ooo`d02NX:803oool00?l0ooooOP3oool?00WZ2_l0ooooR`3oool?00WZ2R80oooo003o
0?ooogX0oooo4009jP[o0?ooohX0oooo4009jPXU0?ooo`00o`3ooomf0?oooa802NX:o`3ooon90?oo
oa002NX::03oool00?l0ooooLP3ooolC00WZ2_l0ooooR03ooolB00WZ2RX0oooo003o0?ooofl0oooo
5009jP[o0?ooohH0oooo4`09jPX]0?ooo`00o`3ooom[0?oooaD02NX:o`3ooon50?oooa@02NX:<03o
ool00?l0ooooI`3oool;00WZ2P030?ooo`09jPX02NX:00T02NX:o`3ooon30?ooo`L02NX:00<0oooo
00WZ2P09jPX03009jPXb0?ooo`00o`3ooomS0?ooo`P02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0;
00WZ2_l0ooooPP3ooolG00WZ2SD0oooo003o0?ooof00oooo0`09jPX01@3oool02NX:00WZ2P09jPX0
oooo00@02NX:00<0oooo00WZ2P09jPX02P09jP[o0?oooh00oooo2009jPX01@3oool02NX:00WZ2P09
jPX0oooo00/02NX:>03oool00?l0ooooG03oool800WZ2P050?ooo`09jPX02NX:00WZ2P3oool01`09
jPX0103oool02NX:00WZ2P3oool200WZ2_l0ooooP03oool300WZ2P050?ooo`09jPX02NX:00WZ2P3o
ool01009jPX00`3oool02NX:00WZ2P0:00WZ2SX0oooo003o0?oooeP0oooo1009jPX0103oool02NX:
00WZ2P09jPX20?ooo`<02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0300WZ2P030?ooo`09jPX02NX:
00@02NX:o`3ooomn0?ooo`P02NX:00D0oooo00WZ2P09jPX02NX:0?ooo`0700WZ2P040?ooo`09jPX0
2NX:0?ooo`802NX:?@3oool00?l0ooooE03oool400WZ2P030?ooo`09jPX02NX:00802NX:0P3oool3
00WZ2P050?ooo`09jPX02NX:00WZ2P3oool00`09jPX01@3oool02NX:00WZ2P09jPX0oooo00802NX:
o`3ooomm0?ooo`P02NX:0P3oool300WZ2P050?ooo`09jPX02NX:00WZ2P3oool00`09jPX00`3oool0
2NX:00WZ2P0400WZ2Sl0oooo003o0?oooe40oooo0`09jPX20?ooo`<02NX:0P3oool400WZ2P040?oo
o`09jPX02NX:00WZ2P80oooo0P09jPX20?ooo`802NX:00@0oooo00WZ2P09jPX02NX:o`3ooomk0?oo
o`@02NX:00@0oooo00WZ2P09jPX02NX:0P3oool400WZ2P050?ooo`09jPX02NX:00WZ2P3oool00`09
jPX00`3oool02NX:00WZ2P0400WZ2T80oooo003o0?ooodd0oooo1009jPX00`3oool02NX:00WZ2P02
00WZ2P80oooo0`09jPX20?ooo`<02NX:0P3oool300WZ2P030?ooo`09jPX02NX:00@02NX:o`3ooomj
0?ooo`@02NX:00<0oooo00WZ2P09jPX00P09jPX20?ooo`<02NX:0P3oool300WZ2P050?ooo`09jPX0
2NX:00WZ2P3oool00`09jPX00`3oool02NX:00WZ2P150?ooo`00V@3oool800000:L0oooo1009jPX2
0?ooo`<02NX:0`3oool300WZ2P80oooo0`09jPX20?ooo`<02NX:00D0oooo00WZ2P09jPX02NX:0?oo
o`0200WZ2_l0ooooN@3oool400WZ2P80oooo0`09jPX20?ooo`@02NX:0P3oool300WZ2P050?ooo`09
jPX02NX:00WZ2P3oool00`09jPX0103oool02NX:00WZ2P09jPY70?ooo`00UP3oool8000000<0oooo
0`00002P0?ooo`@02NX:0P3oool400WZ2P<0oooo0`09jPX20?ooo`<02NX:0P3oool300WZ2P80oooo
0P09jPX0103oool02NX:00WZ2P09jP[50?ooo`L00000ZP3oool400WZ2P80oooo1009jPX20?ooo`<0
2NX:0`3oool300WZ2P040?ooo`09jPX02NX:00WZ2P80oooo0P09jPX0103oool02NX:00WZ2P09jPY:
0?ooo`00T`3oool3000000P0oooo0`0000030?ooo`800000V`3oool300WZ2P<0oooo0`09jPX30?oo
o`@02NX:0P3oool300WZ2P80oooo0`09jPX20?ooo`<02NX:00<0oooo00WZ2P09jPX0a@3oool70000
0080oooo0`00002T0?ooo`@02NX:0P3oool400WZ2P<0oooo0`09jPX30?ooo`<02NX:00@0oooo00WZ
2P09jPX02NX:0P3oool300WZ2P030?ooo`09jPX02NX:04d0oooo002B0?ooo`<00000303oool20000
0080oooo0`00002E0?ooo`@02NX:0P3oool400WZ2P<0oooo0`09jPX30?ooo`<02NX:0P3oool300WZ
2P80oooo0`09jPX0103oool02NX:00WZ2P09jP[40?ooo`<000001`3oool2000000<0oooo00<00000
0?ooo`3oool0WP3oool300WZ2P<0oooo0`09jPX30?ooo`@02NX:0P3oool400WZ2P040?ooo`09jPX0
2NX:00WZ2P80oooo0`09jPX0103oool02NX:00WZ2P09jPY?0?ooo`00T@3oool3000000l0oooo0P00
00030?ooo`030000003oool0oooo08h0oooo1009jPX30?ooo`<02NX:103oool300WZ2P<0oooo0`09
jPX20?ooo`<02NX:0P3oool300WZ2P80oooo0P09jP[60?ooo`80000000<0oooo0000003oool0203o
ool00`000000oooo0?ooo`03000009X0oooo1009jPX20?ooo`@02NX:0`3oool300WZ2P<0oooo0`09
jPX30?ooo`802NX:0P3oool300WZ2P040?ooo`09jPX02NX:00WZ2U80oooo002@0?ooo`030000003o
ool000000180oooo00D000000?ooo`3oool0oooo0000002;0?ooo`@02NX:0`3oool400WZ2P@0oooo
0`09jPX30?ooo`<02NX:0P3oool300WZ2P<0oooo0P09jPX20?ooo`<02NX:a`3oool010000000oooo
0?ooo`00000;0?ooo`8000000`3oool00`000000oooo0?ooo`2C0?ooo`@02NX:0P3oool400WZ2P@0
oooo0`09jPX30?ooo`<02NX:0`3oool300WZ2P80oooo0P09jPX20?ooo`802NX:E@3oool008l0oooo
0`00000D0?ooo`030000003oool0oooo00800000Q`3oool300WZ2P@0oooo0`09jPX40?ooo`@02NX:
0`3oool300WZ2P<0oooo0P09jPX30?ooo`<02NX:0P3oool200WZ2/T0oooo1000000>0?ooo`050000
003oool0oooo0?ooo`000000T03oool400WZ2P<0oooo0`09jPX40?ooo`@02NX:0`3oool300WZ2P<0
oooo0`09jPX20?ooo`<02NX:00@0oooo00WZ2P09jPX02NX:E`3oool008h0oooo0P0000000`3oool0
00000?ooo`0D0?ooo`8000000P3oool00`000000oooo0?ooo`200?ooo`@02NX:0`3oool400WZ2P@0
oooo0`09jPX40?ooo`<02NX:0`3oool300WZ2P80oooo0`09jPX20?ooo`<02NX:bP3oool200000080
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`02000008/0oooo1009jPX30?ooo`@0
2NX:103oool300WZ2P@0oooo0`09jPX30?ooo`<02NX:0P3oool300WZ2P040?ooo`09jPX02NX:00WZ
2UX0oooo002>0?ooo`030000003oool0000001L0oooo00D000000?ooo`3oool0oooo0000001m0?oo
o`@02NX:103oool300WZ2PD0oooo0`09jPX40?ooo`<02NX:0`3oool300WZ2P<0oooo0P09jPX30?oo
o`802NX:c@3oool010000000oooo0?ooo`00000A0?ooo`8000000P3oool00`000000oooo0?ooo`24
0?ooo`@02NX:0`3oool400WZ2P@0oooo1009jPX40?ooo`<02NX:0`3oool300WZ2P80oooo0`09jPX2
0?ooo`802NX:G@3oool008d0oooo00@000000?ooo`3oool00000603oool01@000000oooo0?ooo`3o
ool0000007P0oooo1009jPX40?ooo`@02NX:103oool400WZ2P@0oooo0`09jPX30?ooo`<02NX:0`3o
ool300WZ2P80oooo0`09jP[?0?ooo`040000003oool0oooo00000180oooo00D000000?ooo`3oool0
oooo000000210?ooo`@02NX:103oool300WZ2PD0oooo0`09jPX40?ooo`@02NX:0`3oool300WZ2P80
oooo0`09jPX20?ooo`<02NX:G`3oool008d0oooo0`00000J0?ooo`030000003oool0oooo00800000
M03oool300WZ2PD0oooo0`09jPX50?ooo`<02NX:1@3oool300WZ2P<0oooo0`09jPX30?ooo`<02NX:
0`3oool200WZ2]40oooo00@000000?ooo`0000000000503oool00`000000oooo0?ooo`02000007d0
oooo0`09jPX40?ooo`@02NX:1@3oool300WZ2P@0oooo0`09jPX40?ooo`<02NX:0`3oool200WZ2P<0
oooo0P09jPYR0?ooo`00S03oool2000000030?ooo`000000oooo01X0oooo0P0000000`27CXH00000
0000001_0?ooo`@02NX:103oool400WZ2PD0oooo0`09jPX50?ooo`<02NX:0`3oool300WZ2P@0oooo
0P09jPX30?ooo`<02NX:d`3oool2000000030?ooo`000000oooo01@0oooo0P0000000`2>EXT00000
0?ooo`1h0?ooo`@02NX:0`3oool400WZ2PD0oooo1009jPX40?ooo`<02NX:103oool300WZ2P<0oooo
0`09jPX20?ooo`<02NX:I03oool008`0oooo00<000000?ooo`000000703oool010000000Qdj608M>
QP27CXH2000006X0oooo1009jPX50?ooo`<02NX:1P3oool300WZ2PD0oooo0`09jPX30?ooo`<02NX:
103oool300WZ2P<0oooo0P09jP[F0?ooo`040000003oool0oooo000001D0oooo00D0000008iFR@2>
EXT0SUJ90000001d0?ooo`@02NX:103oool300WZ2PH0oooo0`09jPX50?ooo`<02NX:103oool300WZ
2P<0oooo0`09jPX20?ooo`<02NX:I`3oool008/0oooo00@000000?ooo`3oool00000703oool01`00
0000Qdj608M>QP27CXH000000?ooo`000000IP3oool300WZ2PD0oooo1009jPX50?ooo`@02NX:1@3o
ool300WZ2P@0oooo0P09jPX40?ooo`<02NX:0`3oool300WZ2]P0oooo00<000000?ooo`0000005P3o
ool010000000SUJ908iFR@2>EXT2000006l0oooo1009jPX40?ooo`@02NX:1@3oool400WZ2PD0oooo
0`09jPX40?ooo`<02NX:0`3oool300WZ2P<0oooo0P09jPYZ0?ooo`00R`3oool3000001d0oooo00<0
000008M>QP27CXH00P27CXH300000640oooo1009jPX50?ooo`<02NX:1P3oool300WZ2PH0oooo0`09
jPX40?ooo`<02NX:103oool200WZ2P<0oooo0`09jP[J0?ooo`040000003oool0oooo000001H0oooo
00<0000008iFR@2>EXT00P2>EXT2000006X0oooo1009jPX50?ooo`<02NX:1P3oool300WZ2PH0oooo
0`09jPX40?ooo`<02NX:0`3oool300WZ2P<0oooo0`09jPY/0?ooo`00RP3oool2000000030?ooo`00
0000oooo01`0oooo00<0000008M>QP27CXH00P27CXH00`000000oooo0000001M0?ooo`@02NX:1@3o
ool400WZ2PH0oooo0`09jPX50?ooo`@02NX:103oool300WZ2P@0oooo0`09jPX30?ooo`802NX:g@3o
ool010000000oooo00000000000F0?ooo`030000002>EXT0SUJ900<0SUJ90P00001U0?ooo`@02NX:
1@3oool400WZ2PH0oooo0`09jPX50?ooo`@02NX:103oool300WZ2P@0oooo0P09jPX30?ooo`<02NX:
K`3oool008X0oooo00@000000?ooo`3oool000007@3oool00`000000Qdj608M>QP0208M>QP040000
003oool0oooo000005P0oooo1009jPX60?ooo`<02NX:1`3oool300WZ2PD0oooo0`09jPX50?ooo`<0
2NX:103oool300WZ2P<0oooo0`09jP[O0?ooo`80000000<0oooo0000003oool05P3oool00`000000
SUJ908iFR@0208iFR@800000H@3oool400WZ2PD0oooo1009jPX60?ooo`@02NX:1@3oool300WZ2PD0
oooo0`09jPX40?ooo`<02NX:0`3oool200WZ2W80oooo002:0?ooo`040000003oool0oooo000001d0
oooo00<0000008M>QP27CXH00`27CXH00`000000oooo0000001E0?ooo`<02NX:1P3oool400WZ2PH0
oooo1009jPX50?ooo`<02NX:1@3oool300WZ2PD0oooo0P09jPX40?ooo`802NX:hP3oool010000000
oooo0?ooo`00000G0?ooo`030000002>EXT0SUJ900<0SUJ90P00001M0?ooo`<02NX:1P3oool300WZ
2PL0oooo0`09jPX60?ooo`<02NX:1@3oool300WZ2P@0oooo0`09jPX30?ooo`<02NX:M03oool008X0
oooo00<000000?ooo`0000007P3oool00`000000Qdj608M>QP0308M>QP040000003oool0oooo0000
0500oooo1009jPX60?ooo`<02NX:1`3oool300WZ2PH0oooo0`09jPX50?ooo`<02NX:1@3oool300WZ
2P<0oooo0`09jP[T0?ooo`030000003oool0000001P0oooo00<0000008iFR@2>EXT00`2>EXT00`00
0000oooo0000001H0?ooo`@02NX:1@3oool400WZ2PL0oooo0`09jPX60?ooo`<02NX:1@3oool300WZ
2P@0oooo0`09jPX30?ooo`<02NX:M`3oool008T0oooo00@000000?ooo`3oool000007P3oool00`00
0000Qdj608M>QP0308M>QP80000000<0oooo0000003oool0B`3oool400WZ2PH0oooo1009jPX70?oo
o`<02NX:1P3oool300WZ2PD0oooo0`09jPX50?ooo`<02NX:103oool200WZ2^H0oooo00@000000?oo
o`3oool00000603oool00`000000SUJ908iFR@0308iFR@030000003oool0000005@0oooo1009jPX5
0?ooo`@02NX:1`3oool400WZ2PH0oooo0`09jPX50?ooo`<02NX:103oool300WZ2P@0oooo0P09jPYj
0?ooo`00R@3oool010000000oooo00000000000N0?ooo`0300000027CXH0Qdj600@0Qdj610000017
0?ooo`@02NX:1`3oool300WZ2PL0oooo1009jPX60?ooo`<02NX:1@3oool300WZ2PD0oooo0`09jPX4
0?ooo`<02NX:j03oool010000000oooo00000000000H0?ooo`030000002>EXT0SUJ900@0SUJ90`00
001?0?ooo`@02NX:1P3oool300WZ2PP0oooo0`09jPX70?ooo`<02NX:1@3oool300WZ2PD0oooo0P09
jPX40?ooo`<02NX:O03oool008D0oooo2000000N0?ooo`0300000027CXH0Qdj600@0Qdj60P000000
0`3oool000000?ooo`130?ooo`<02NX:1`3oool400WZ2PL0oooo0`09jPX70?ooo`<02NX:1P3oool2
00WZ2PH0oooo0P09jPX50?ooo`802NX:hP3oool6000000<0oooo0P0000000`3oool000000?ooo`0G
0?ooo`030000002>EXT0SUJ900@0SUJ900<000000?ooo`000000B`3oool400WZ2PH0oooo1009jPX7
0?ooo`@02NX:1`3oool300WZ2PD0oooo0`09jPX50?ooo`<02NX:0`3oool300WZ2Wl0oooo00220?oo
o`<0000000D0oooo0000003oool0oooo000000020?ooo`<00000703oool00`000000Qdj608M>QP04
08M>QP050000003oool000000?ooo`000000?`3oool400WZ2PL0oooo0`09jPX80?ooo`<02NX:1`3o
ool300WZ2PH0oooo0`09jPX50?ooo`<02NX:103oool300WZ2^80oooo0P0000001P3oool000000?oo
o`3oool000000?ooo`@000000P3oool00`000000oooo0?ooo`0F0?ooo`030000002>EXT0SUJ900@0
SUJ900@000000?ooo`3oool00000AP3oool400WZ2PH0oooo1009jPX80?ooo`<02NX:1`3oool400WZ
2PD0oooo0`09jPX50?ooo`<02NX:103oool200WZ2X80oooo00210?ooo`050000003oool000000?oo
o`0000000P3oool200000080oooo00<000000?ooo`3oool00P00000J0?ooo`0300000027CXH0Qdj6
00D0Qdj60P0000020?ooo`030000003oool0oooo03P0oooo1009jPX70?ooo`@02NX:203oool300WZ
2PL0oooo0`09jPX60?ooo`<02NX:1@3oool300WZ2PD0oooo0P09jP[T0?ooo`040000003oool00000
00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000H0?ooo`030000
002>EXT0SUJ900D0SUJ900@000000?ooo`3oool00000@@3oool400WZ2PL0oooo0`09jPX90?ooo`<0
2NX:1`3oool300WZ2PH0oooo0`09jPX50?ooo`<02NX:103oool300WZ2X@0oooo00200?ooo`<00000
0P3oool01`000000oooo0000003oool000000?ooo`0000000`3oool00`000000oooo0000000I0?oo
o`0300000027CXH0Qdj600D0Qdj600<000000?ooo`0000000P3oool00`000000oooo0?ooo`0c0?oo
o`@02NX:203oool300WZ2PP0oooo1009jPX70?ooo`<02NX:1P3oool300WZ2PH0oooo0P09jPX50?oo
o`<02NX:iP3oool2000000040?ooo`000000oooo00000080oooo00@000000?ooo`3oool0oooo0P00
00000`3oool000000?ooo`0G0?ooo`030000002>EXT0SUJ900D0SUJ900@000000?ooo`3oool00000
?@3oool400WZ2PL0oooo1009jPX80?ooo`@02NX:1`3oool300WZ2PH0oooo0`09jPX60?ooo`802NX:
1@3oool200WZ2XL0oooo001o0?ooo`80000000@0oooo0000003oool000000P3oool2000000030?oo
o`00000000000080oooo00D000000?ooo`3oool0oooo0000000H0?ooo`0300000027CXH0Qdj600D0
Qdj600<000000?ooo`0000000P3oool200000340oooo0`09jPX80?ooo`@02NX:203oool300WZ2PP0
oooo0`09jPX60?ooo`<02NX:1P3oool300WZ2PD0oooo0P09jP[X0?ooo`040000003oool000000000
0080oooo00<000000?ooo`0000000`3oool2000000030?ooo`000000000001P0oooo00<0000008iF
R@2>EXT01@2>EXT00`000000oooo0?ooo`02000003T0oooo0`09jPX80?ooo`<02NX:2@3oool300WZ
2PP0oooo0`09jPX60?ooo`<02NX:1P3oool300WZ2P@0oooo0`09jPZ90?ooo`00O`3oool300000080
oooo00@000000?ooo`000000oooo1P0000040?ooo`8000005`3oool00`000000Qdj608M>QP0508M>
QP030000003oool0oooo0080000000<0oooo0000003oool0;03oool400WZ2PP0oooo0`09jPX90?oo
o`<02NX:203oool300WZ2PH0oooo0`09jPX60?ooo`<02NX:1@3oool300WZ2^X0oooo0P000000103o
ool000000?ooo`0000020?ooo`070000003oool0oooo0000003oool000000?ooo`03000001L0oooo
00<0000008iFR@2>EXT01P2>EXT2000000030?ooo`000000oooo03@0oooo1009jPX70?ooo`@02NX:
2@3oool300WZ2PP0oooo0`09jPX60?ooo`<02NX:1P3oool300WZ2P@0oooo0`09jPZ<0?ooo`00OP3o
ool2000000040?ooo`000000oooo00000080oooo00L000000?ooo`00000000000:Fnj`000000YKk[
008000000P3oool010000000oooo0?ooo`00000F0?ooo`0300000027CXH0Qdj600D0Qdj600@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`0V0?ooo`@02NX:203oool400WZ2PT0oooo0`09
jPX80?ooo`<02NX:1P3oool300WZ2PL0oooo0P09jPX60?ooo`802NX:k03oool400000080oooo00<0
00000?ooo`0000000`3oool01`000000oooo000000000000ZL;[0000002Y`^/00P00000E0?ooo`03
0000002>EXT0SUJ900H0SUJ900D000000?ooo`3oool0oooo0000000`0?ooo`@02NX:1`3oool400WZ
2PT0oooo1009jPX80?ooo`<02NX:1P3oool300WZ2PH0oooo0`09jPX50?ooo`802NX:S`3oool007d0
oooo100000020?ooo`030000003oool000000080oooo00@000000?ooo`00000000000`2U_^/30000
00<0oooo0P00000D0?ooo`0300000027CXH0Qdj600H0Qdj600@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`0R0?ooo`@02NX:203oool400WZ2PT0oooo1009jPX80?ooo`<02NX:1`3oool2
00WZ2PL0oooo0`09jPX50?ooo`<02NX:kP3oool2000000060?ooo`000000oooo0000003oool00000
0`3oool00`000000oooo0?ooo`02000000030:W2j`000000ZL;[0080ZL;[0P00000C0?ooo`030000
002>EXT0SUJ900L0SUJ900@000000?ooo`3oool00000;03oool400WZ2PP0oooo0`09jPX:0?ooo`<0
2NX:203oool400WZ2PH0oooo0`09jPX60?ooo`<02NX:1@3oool300WZ2Y40oooo001m0?ooo`800000
00H0oooo0000003oool000000?ooo`0000020?ooo`8000000P3oool00`000000YKk[0:Fnj`040:Fn
j`80000000<0oooo00000027CXH00P00000B0?ooo`0300000027CXH0Qdj600H0Qdj600D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01h0oooo0`09jPX90?ooo`<02NX:2P3oool3
00WZ2PT0oooo0`09jPX70?ooo`<02NX:1P3oool300WZ2PD0oooo0`09jP[`0?ooo`@0000000D0oooo
0000003oool0oooo000000020?ooo`040000003oool0oooo0?ooo`@000001@2Y`^/200000140oooo
00<0000008iFR@2>EXT01`2>EXT01@000000oooo0?ooo`3oool0000002L0oooo1009jPX80?ooo`@0
2NX:2@3oool400WZ2PP0oooo0`09jPX70?ooo`<02NX:1`3oool200WZ2PD0oooo0`09jPZD0?ooo`00
O03oool4000000050?ooo`000000oooo0?ooo`0000000P3oool2000000040?ooo`00000000000000
00L0YKk[0P00000308M>QP030000003oool0oooo00l0oooo00<0000008M>QP27CXH01P27CXH01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool400WZ2PP0oooo1009jPX:
0?ooo`<02NX:2@3oool300WZ2PL0oooo0`09jPX70?ooo`802NX:1P3oool200WZ2_<0oooo0`000002
0?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000002Y
`^/0ZL;[00D0ZL;[0P00000?0?ooo`030000002>EXT0SUJ900L0SUJ90P0000030?ooo`030000003o
ool0oooo0200oooo1009jPX80?ooo`@02NX:2P3oool300WZ2PT0oooo0`09jPX70?ooo`<02NX:1`3o
ool300WZ2PD0oooo0P09jPZG0?ooo`00O03oool2000000060?ooo`000000oooo0000003oool00000
0P3oool010000000oooo0000003oool2000000030?ooo`000000YKk[00L0YKk[0P00000208M>QP80
00003`3oool00`000000Qdj608M>QP0608M>QP030000003oool0oooo0080oooo00<000000?ooo`00
0000603oool400WZ2PT0oooo0`09jPX:0?ooo`@02NX:2@3oool300WZ2PL0oooo0`09jPX70?ooo`<0
2NX:1@3oool300WZ2_@0oooo0P000000103oool000000?ooo`0000020?ooo`040000003oool0oooo
000000<0oooo0P0000020?ooo`800000202Y`^/00`000000oooo0?ooo`0=0?ooo`030000002>EXT0
SUJ900L0SUJ90P0000020?ooo`030000003oool0oooo01`0oooo1009jPX90?ooo`<02NX:2`3oool3
00WZ2PT0oooo0`09jPX80?ooo`802NX:1`3oool300WZ2PD0oooo0`09jPZI0?ooo`00N`3oool40000
00070?ooo`000000oooo0?ooo`000000oooo000000020?ooo`@0000000@0oooo0000000000000000
202U_^/200000080Qdj60P00000=0?ooo`0300000027CXH0Qdj600H0Qdj600<000000?ooo`3oool0
0`3oool3000001<0oooo1009jPX90?ooo`@02NX:2P3oool300WZ2PX0oooo0`09jPX70?ooo`<02NX:
1`3oool300WZ2PH0oooo0P09jP[g0?ooo`<000000P3oool00`000000oooo000000020?ooo`070000
003oool0oooo0?ooo`000000oooo000000020?ooo`030000002>EXT0000000P0ZL;[0P00000=0?oo
o`030000002>EXT0SUJ900L0SUJ90P0000020?ooo`8000006P3oool300WZ2PT0oooo1009jPX:0?oo
o`@02NX:2@3oool300WZ2PP0oooo0`09jPX60?ooo`<02NX:1@3oool300WZ2Y`0oooo001k0?ooo`@0
000000H0oooo0000003oool000000?ooo`0000030?ooo`80000000<0oooo0000000000000`3oool0
0`000000YKk[0:Fnj`070:Fnj`8000000P27CXH00`000000oooo0?ooo`0:0?ooo`0300000027CXH0
Qdj600H0Qdj600<000000?ooo`3oool00`3oool00`000000oooo0000000@0?ooo`<02NX:2P3oool3
00WZ2P/0oooo0`09jPX:0?ooo`<02NX:1`3oool300WZ2PP0oooo0P09jPX60?ooo`<02NX:n03oool2
000000060?ooo`000000oooo0000003oool000000`3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0000000000080SUJ900<000000:W2j`2Y`^/01`2Y`^/2000000/0oooo00<0000008iF
R@2>EXT01`2>EXT01P000000oooo000000000000oooo000001H0oooo1009jPX80?ooo`@02NX:2`3o
ool300WZ2PX0oooo0`09jPX80?ooo`<02NX:1P3oool300WZ2PH0oooo0P09jPZO0?ooo`00NP3oool4
000000040?ooo`000000oooo00000080oooo00<000000?ooo`3oool00P0000020?ooo`030000003o
ool0oooo0080oooo0P00000:0:Fnj`80000000<0Qdj60000003oool02P3oool00`000000Qdj608M>
QP0608M>QP030000003oool0oooo00@0oooo00<000000?ooo`0000002`3oool400WZ2PT0oooo1009
jPX;0?ooo`<02NX:2@3oool400WZ2PL0oooo0`09jPX80?ooo`<02NX:1P3oool200WZ2_/0oooo0`00
00001@3oool000000?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`80
000000<0SUJ90000002>EXT00P2>EXT00`000000ZL;[0:W2j`080:W2j`030000003oool0oooo00P0
oooo00<0000008iFR@2>EXT01`2>EXT00`000000oooo000000030?ooo`030000003oool0oooo00l0
oooo1009jPX90?ooo`<02NX:2`3oool400WZ2PX0oooo0`09jPX80?ooo`<02NX:1`3oool200WZ2PH0
oooo0`09jPZQ0?ooo`00903oool:000004`0oooo100000001P3oool000000?ooo`000000oooo0000
00<0oooo0P0000020?ooo`050000003oool0oooo0?ooo`0000000P27CXH00`000000YKk[0:Fnj`09
0:Fnj`0300000027CXH0000000X0oooo00<0000008M>QP27CXH01`27CXH00`000000oooo0?ooo`03
0?ooo`040000003oool0oooo000000H0oooo1009jPX:0?ooo`<02NX:2`3oool400WZ2PT0oooo0`09
jPX80?ooo`<02NX:203oool300WZ2PH0oooo0`09jPZU0?ooo`@00000D`3oool4000000040?ooo`00
0000oooo00000080oooo00D000000?ooo`3oool0oooo000000030?ooo`040000002>EXT0SUJ90000
00@0SUJ900<000000:W2j`2Y`^/0202Y`^/2000000P0oooo00<0000008iFR@2>EXT0202>EXT00`00
0000oooo000000020?ooo`030000003oool0oooo00/0oooo1009jPX90?ooo`@02NX:2`3oool300WZ
2PX0oooo1009jPX80?ooo`<02NX:1`3oool300WZ2PH0oooo0P09jPZT0?ooo`008@3oool;00000080
oooo0`0000190?ooo`/0000000D0oooo0000003oool000000?ooo`0200000080oooo00<0000008M>
QP27CXH00P27CXH00`000000YKk[0:Fnj`090:Fnj`<000002@3oool00`000000Qdj608M>QP0708M>
QP030000003oool0oooo00@0oooo00<000000?ooo`0000000P3oool400WZ2PX0oooo1009jPX;0?oo
o`<02NX:2P3oool300WZ2PT0oooo0P09jPX80?ooo`<02NX:1`3oool200WZ2Z80oooo200000020?oo
o`<00000D03oool7000000<0oooo00@000000?ooo`3oool000000`3oool200000080SUJ900<00000
08iFR@2>EXT00`2>EXT00`000000ZL;[0:W2j`090:W2j`030000003oool0oooo00D0oooo00<00000
08iFR@2>EXT0202>EXT00`000000oooo000000020?ooo`030000003oool0oooo00L0oooo1009jPX:
0?ooo`<02NX:303oool300WZ2PX0oooo0`09jPX90?ooo`<02NX:1`3oool300WZ2PH0oooo0`09jPZV
0?ooo`007`3oool3000000X0oooo200000150?ooo`<000000P3oool3000000@0oooo00<000000?oo
o`3oool00P0000020?ooo`8000001P27CXH2000000/0YKk[0P0000080?ooo`0300000027CXH0Qdj6
00L0Qdj600<000000?ooo`3oool0103oool00`000000oooo00WZ2P0200WZ2P/0oooo0`09jPX<0?oo
o`<02NX:2P3oool300WZ2PT0oooo0`09jPX80?ooo`802NX:1`3oool300WZ2Z40oooo1@0000060?oo
o`<000000P3oool2000004h0oooo00<000000?ooo`000000103oool00`000000oooo000000020?oo
o`070000003oool0oooo0?ooo`000000SUJ90000000308iFR@030000002>EXT0SUJ900<0SUJ900<0
00000:W2j`2Y`^/02@2Y`^/2000000D0oooo00<0000008iFR@2>EXT0202>EXT010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo0080oooo1009jPX:0?ooo`@02NX:2`3oool400WZ2PX0oooo
0`09jPX90?ooo`<02NX:1`3oool300WZ2PH0oooo0`09jPZY0?ooo`007@3oool200000180oooo1@00
00130?ooo`D000000P3oool3000000<0oooo00@000000?ooo`00000000000P3oool00`000000Qdj6
08M>QP0708M>QP030000002U_^/0YKk[00X0YKk[00<000000?ooo`3oool01@3oool00`000000Qdj6
08M>QP0708M>QP030000003oool0oooo0080oooo1009jPX00`3oool00000000000070?ooo`@02NX:
303oool300WZ2PX0oooo0`09jPX90?ooo`<02NX:203oool300WZ2PL0oooo0P09jPZS0?ooo`030000
003oool0000000`0oooo0P000000103oool0000000000000001:0?ooo`P000000P3oool200000003
0?ooo`000000oooo0080oooo00D0000008iFR@2>EXT0SUJ90000000208iFR@030000002>EXT0SUJ9
00@0SUJ900<000000:W2j`2Y`^/02P2Y`^/00`000000oooo0?ooo`020?ooo`030000002>EXT0SUJ9
00P0SUJ900D000000?ooo`3oool000000?ooo`02000000@02NX:2P3oool400WZ2P`0oooo0`09jPX;
0?ooo`<02NX:2@3oool300WZ2PP0oooo0P09jPX70?ooo`802NX:[03oool001`0oooo0P00000F0?oo
o`030000003oool000000440oooo0`0000001@3oool000000?ooo`3oool000000080oooo0P000003
0?ooo`040000003oool000000?ooo`8000002P27CXH00`000000YKk[0:Fnj`0:0:Fnj`8000001@3o
ool00`000000Qdj608M>QP0708M>QP0300000009jPX02NX:00802NX:0`3oool2000000030?ooo`00
0000oooo00<0oooo0`09jPX<0?ooo`@02NX:2P3oool300WZ2PT0oooo0`09jPX80?ooo`<02NX:1`3o
ool300WZ2Z@0oooo0`00000?0?ooo`8000000P3oool2000004L0oooo00<000000?ooo`0000000`00
00020?ooo`8000000`3oool01@000000oooo0?ooo`3oool0000000@0SUJ900@0000008iFR@2>EXT0
00001`2>EXT00`000000ZL;[0:W2j`0:0:W2j`8000000P3oool00`000000SUJ908iFR@0808iFR@04
0000003oool0oooo0?ooo`<02NX:2`3oool300WZ2Pd0oooo0`09jPX;0?ooo`<02NX:2@3oool300WZ
2PP0oooo0`09jPX60?ooo`<02NX:[P3oool001/0oooo0P00000H0?ooo`030000003oool000000400
oooo100000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0oooo1@00000;
08M>QP030000002U_^/0YKk[00/0YKk[00<000000?ooo`3oool00P3oool00`000000Qdj608M>QP04
08M>QP@02NX:1`3oool010000000oooo0?ooo`00000400WZ2P`0oooo0`09jPX;0?ooo`<02NX:2@3o
ool300WZ2PT0oooo0P09jPX80?ooo`802NX:Y`3oool00`000000oooo0000000A0?ooo`050000003o
ool0oooo0?ooo`000000A@3oool7000000050?ooo`000000oooo0?ooo`0000000`3oool00`000000
oooo0000000508iFR@040000002>EXT00000000000P0SUJ900<000000:W2j`2Y`^/02`2Y`^/00`00
0000oooo0000000:08iFR@@02NX:00@000000?ooo`3oool000001P3oool400WZ2P`0oooo1009jPX;
0?ooo`<02NX:2@3oool300WZ2PP0oooo0`09jPX60?ooo`<02NX:/@3oool001X0oooo0P00000J0?oo
o`h00000<P3oool800000080oooo00@000000?ooo`3oool0oooo0`0000020?ooo`80000000<0Qdj6
00000027CXH02`27CXH00`000000YKk[0:Fnj`0;0:Fnj`050000003oool0oooo0?ooo`0000000`27
CXH300WZ2P<0Qdj600<000000?ooo`3oool01@3oool01@0000002NX:00WZ2P09jPX0000000`0oooo
0`09jPX;0?ooo`<02NX:2@3oool300WZ2PT0oooo0`09jPX70?ooo`<02NX:Z03oool00`000000oooo
0000000C0?ooo`030000003oool0oooo008000000`3oool7000003T0oooo1P0000000`3oool00000
00000002000000030?ooo`000000000000<0oooo0P00000508iFR@80000000<0SUJ90000002>EXT0
202>EXT00`000000ZL;[0:W2j`0;0:W2j`8000001P2>EXT400WZ2P050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`0400WZ2Pd0oooo0`09jPX;0?ooo`@02NX:2@3oool300WZ2PP0
oooo0`09jPX70?ooo`802NX:]03oool001T0oooo00<000000?ooo`0000006P3oool3000000040?oo
o`00000000000?ooo`80000000<0oooo0000000000000P3oool2000002l0oooo1P0000030:Fnj`H0
00000`3oool00`000000oooo00000003000000d0Qdj600<000000:Fnj`2U_^/02`2U_^/200000003
0?ooo`09jPX02NX:00802NX:1P27CXH00`000000oooo0?ooo`020?ooo`@02NX:00@000000?ooo`3o
ool000002@3oool300WZ2P/0oooo0`09jPX90?ooo`<02NX:2@3oool300WZ2PP0oooo0P09jPZZ0?oo
o`<000005@3oool200000080oooo0`0000030?ooo`80000000<0oooo0000000000000P00000e0?oo
o`@0000000D0oooo0000003oool0oooo000000030:W2j`D0000000<0oooo0000003oool00P000003
08iFR@040000002>EXT0SUJ9000000X0SUJ900<000000:W2j`2Y`^/02`2Y`^/3000000@02NX:102>
EXT00`000000oooo0?ooo`020?ooo`030000003oool02NX:00802NX:3@3oool400WZ2P/0oooo0`09
jPX:0?ooo`<02NX:203oool300WZ2PL0oooo0`09jPZf0?ooo`006@3oool2000001X0oooo0P000002
0?ooo`80000000@0oooo0000003oool0oooo0P000000103oool000000000003oool3000002`0oooo
1`0000080:Fnj`L0000000<0oooo0000000000003P27CXH00`000000YKk[0:Fnj`090:Fnj`0500WZ
2P000000000000WZ2P0000002P27CXH0100000002NX:00WZ2P09jPX40?ooo`040000003oool0oooo
000000D0oooo1009jPX;0?ooo`<02NX:2P3oool200WZ2PX0oooo0P09jPX80?ooo`<02NX:Z`3oool2
000000030?ooo`000000oooo01H0oooo00D000000?ooo`00000000000?ooo`02000000<0oooo0P00
00000`3oool000000000000200000380oooo0`000000103oool000000000003oool3000000P0ZL;[
1P00000208iFR@040000002>EXT0SUJ9000000X0SUJ900<000000:W2j`2Y`^/02P2Y`^/200WZ2P80
00002@2>EXT00`000000oooo00WZ2P0300WZ2P030?ooo`000000oooo00X0oooo0`09jPX<0?ooo`<0
2NX:2P3oool300WZ2PT0oooo0P09jPX70?ooo`<02NX:^@3oool001P0oooo0P00000J0?ooo`030000
003oool0oooo0080000000<0oooo0000000000000P0000030?ooo`80000000@0oooo000000000000
oooo0P00000Z0?ooo`D0000000<0oooo0000000000003P2U_^/5000000h0Qdj600<000000:Fnj`2U
_^/0102U_^/400WZ2P<0YKk[0P00000708M>QP@02NX:1`3oool01P000000oooo0?ooo`3oool00000
0?ooo`<02NX:303oool300WZ2PX0oooo0`09jPX90?ooo`<02NX:1`3oool300WZ2Zh0oooo00<00000
0?ooo`0000006@3oool2000000040?ooo`000000oooo0?ooo`<000000P3oool7000002l0oooo2@00
00000`2Y`^/000000:W2j`0<0:W2j`D000000P2>EXT00`000000SUJ908iFR@0808iFR@030000002Y
`^/0ZL;[00D0ZL;[1009jPX30:W2j`8000001P2>EXT400WZ2P80oooo00@000000?ooo`3oool00000
203oool300WZ2P`0oooo0`09jPX:0?ooo`<02NX:2@3oool300WZ2PL0oooo0P09jPZl0?ooo`005`3o
ool2000001X0oooo00<000000?ooo`3oool00`3oool30000000408M>QP0000000000000000<0oooo
0P000000103oool000000000003oool2000002L0oooo1@000000103oool000000:Fnj`00000?0:Fn
j`030000002U_^/0YKk[00@000003027CXH00`000000YKk[0:Fnj`0300WZ2PT0YKk[00@0000008M>
QP27CXH0Qdj60`09jPX308M>QP030000003oool0oooo00H0oooo00<000000?ooo`09jPX00P09jPX<
0?ooo`<02NX:2P3oool300WZ2PT0oooo0`09jPX80?ooo`802NX:/03oool00`000000oooo0000000I
0?ooo`030000003oool0000000<00000103oool2000000<0oooo1P00000/0?ooo`<0000000<0oooo
0000000000000P000000103oool000000:W2j`00000A0:W2j`@000002`2>EXT010000000ZL;[0:W2
j`2Y`^/300WZ2PT0ZL;[00<0000008iFR@2>EXT00`09jPX208iFR@030000003oool0oooo0080oooo
00@000000?ooo`00000000000`3oool400WZ2P`0oooo0`09jPX:0?ooo`<02NX:2@3oool300WZ2PL0
oooo0`09jPZn0?ooo`005P3oool00`000000oooo0000000I0?ooo`8000001`3oool4000000030?oo
o`000000000000<0oooo1@0000000`3oool000000000000T0?ooo`P0000000<0YKk[0000002U_^/0
3P2U_^/010000000YKk[0:Fnj`0000030:Fnj`<000002027CXH200WZ2P0300000009jPX0YKk[00`0
YKk[0P0000000`09jPX0Qdj608M>QP0408M>QP030000003oool0oooo00@0oooo1009jPX00`3oool0
00000?ooo`090?ooo`<02NX:2P3oool300WZ2PX0oooo0P09jPX80?ooo`<02NX:/P3oool2000001T0
oooo0P0000020?ooo`030000002>EXT0000000<000000`3oool2000000<0oooo1P00000Y0?ooo`P0
000000D0oooo0000002Y`^/0ZL;[0000000A0:W2j`030000002Y`^/0ZL;[00@000002@2>EXT00`00
00002NX:00WZ2P0<0:W2j`0300WZ2P000000000000D0SUJ900<000000?ooo`3oool00P3oool20000
00030?ooo`0000002NX:00802NX:3@3oool300WZ2PX0oooo0`09jPX90?ooo`<02NX:1`3oool300WZ
2/40oooo000F0?ooo`8000006P3oool00`000000oooo00000002000000<0oooo00@0000008M>QP00
0000oooo0P0000020?ooo`<000000`3oool700000200oooo1`0000001@3oool000000:Fnj`2U_^/0
000000l0YKk[00@000000:Fnj`00000000001P2U_^/2000000<0Qdj60`09jPX208M>QP8000002P2U
_^/300WZ2P8000001`27CXH010000000oooo0?ooo`3oool300WZ2P80oooo00D000000?ooo`3oool0
oooo000000060?ooo`<02NX:2P3oool300WZ2PX0oooo0`09jPX80?ooo`802NX:]03oool00`000000
oooo0000000I0?ooo`030000003oool0000000@0000000<0oooo0000003oool00P0000030?ooo`<0
00000P3oool6000002@0oooo100000000`3oool0000000000003000000030?ooo`000000ZL;[0080
ZL;[00<000000:W2j`2Y`^/03`2Y`^/010000000ZL;[0000000000030:W2j`800000102>EXT300WZ
2P0308iFR@000000000000T0ZL;[0`09jPX00`2Y`^/000000000000508iFR@030000003oool0oooo
0080oooo1009jPX00`000000oooo0?ooo`0:0?ooo`<02NX:2P3oool300WZ2PT0oooo0`09jPX80?oo
o`802NX:a03oool001D0oooo00<000000?ooo`0000006@3oool00`000000oooo0?ooo`030?ooo`@0
000000<0Qdj60000000000000P3oool300000080oooo0P0000030?ooo`L000005P3ooolA00000003
0:Fnj`000000000000l0YKk[0P0000000`2U_^/000000:Fnj`070:Fnj`0300000009jPX02NX:00L0
Qdj600<000000:Fnj`2U_^/0102U_^/300WZ2PD0YKk[00<0000008M>QP27CXH01027CXH010000000
2NX:00WZ2P09jPX60?ooo`040000003oool0oooo000000<0oooo0`09jPX:0?ooo`<02NX:2P3oool3
00WZ2PP0oooo0`09jPZf0?ooo`030000003oool0000001P0oooo00H000000?ooo`3oool0oooo0000
002>EXT3000000040?ooo`000000oooo0?ooo`<000000`3oool200000080oooo1P00000J0?ooo`@0
00000P3oool=000000<0ZL;[0P00000A0:W2j`80000000<0ZL;[0000002Y`^/0102Y`^/200000080
2NX:1@2>EXT00`000000ZL;[0:W2j`040:W2j`<02NX:1P2Y`^/00`000000SUJ908iFR@0208iFR@03
0000003oool02NX:00802NX:00D0oooo0000003oool0oooo000000080?ooo`@02NX:2P3oool300WZ
2PX0oooo0P09jPX80?ooo`<02NX:aP3oool001D0oooo00<000000?ooo`000000603oool3000000H0
oooo100000000`3oool000000?ooo`02000000030?ooo`00000000000080oooo0P0000030?ooo`L0
00004`3oool00`000000lJn40?6_Q0020?6_Q0D0000000<0oooo0000003oool0100000020:Fnj`80
00003`2U_^/010000000YKk[0:Fnj`0000060:Fnj`802NX:00<0YKk[0000000000000P00000608M>
QP030000002U_^/0YKk[00<02NX:2@2U_^/200000080Qdj60`09jPX90?ooo`040000003oool0oooo
0?ooo`<02NX:2P3oool300WZ2P/0oooo0P09jPX90?ooo`802NX:^03oool00`000000oooo0000000I
0?ooo`080000003oool0oooo0?ooo`000000SUJ90000003oool4000000@0oooo0P0000030?ooo`80
000000<0oooo0000000000001000000H0?ooo`030000003f/7P0m[1h0080m[1h1P0000000`3oool0
00000000000600000080ZL;[00<000000:W2j`0000004@2Y`^/010000000ZL;[0:W2j`0000050:W2
j`802NX:0P00000608iFR@030000002Y`^/0ZL;[00<02NX:2P2Y`^/00`000000SUJ908iFR@0300WZ
2P@0oooo00D000000?ooo`3oool0oooo000000040?ooo`<02NX:2`3oool300WZ2PX0oooo0`09jPX8
0?ooo`802NX:b@3oool001D0oooo0P00000I0?ooo`030000003oool0oooo00<000000`3oool01000
0000Qdj60000003oool300000080oooo00<000000?ooo`3oool00P0000020?ooo`80000000<0oooo
00000027CXH01`00000?0?ooo`8000001@3a[h@2000000070?6_Q000000000000000003oool00000
0?ooo`03000000040:Fnj`000000YKk[000000l0YKk[00@000000:Fnj`2U_^/00000102U_^/200WZ
2PL0YKk[0P00000408M>QP<02NX:3@2U_^/20000000400WZ2P27CXH0Qdj6000000X0oooo0`09jPX0
0`000000oooo0?ooo`070?ooo`<02NX:2`3oool300WZ2PP0oooo0`09jPZj0?ooo`030000003oool0
000001P0oooo0`0000001@3oool0000008iFR@2>EXT000000080oooo00<000000?ooo`0000000P00
00040?ooo`<000000P3oool20000000308iFR@000000000000@000005@3oool00`000000m[1h0?J`
N0030?J`N0<0000000@0oooo0000003oool000000P3oool500000080ZL;[00@000000:W2j`2Y`^/0
00004@2Y`^/01P000000ZL;[0:W2j`2Y`^/000000:W2j`<02NX:102Y`^/2000000D0SUJ900<00000
00WZ2P2Y`^/0302Y`^/01@09jPX000000000002>EXT0000000H0oooo00D000000?ooo`3oool00000
0?ooo`0300WZ2P/0oooo0`09jPX:0?ooo`<02NX:203oool300WZ2//0oooo000D0?ooo`030000003o
ool0000001P0oooo00<000000?ooo`3oool0103oool300000080Qdj600<000000?ooo`3oool00P3o
ool4000000<0oooo0P0000020?ooo`<000000P27CXH7000000`0oooo00<000000?6_Q03a[h@00`3a
[h@5000000040?6_Q0000000000000000080oooo1`00000?0:Fnj`040000002U_^/0YKk[00000080
YKk[0P09jPX;0:Fnj`8000000P09jPX00`27CXH000000000000:0:Fnj`<02NX:0`00000208M>QP03
0000003oool0oooo00D0oooo0`09jPX010000000oooo0?ooo`0000070?ooo`802NX:2`3oool300WZ
2PT0oooo0P09jPZm0?ooo`<00000603oool00`000000oooo0?ooo`030000000508iFR@000000oooo
0?ooo`0000000P3oool00`000000oooo00000002000000@0oooo0`0000000`2>EXT0000000000007
00000180oooo00<000000?J`N03f/7P00`3f/7P00`000000m[1h0?J`N002000000060?ooo`000000
oooo0?ooo`000000oooo1P0000030:W2j`030000002Y`^/0ZL;[0100ZL;[00D000000:W2j`2Y`^/0
000000WZ2P090:W2j`8000000`09jPX2000000X0ZL;[0`09jPX00`2Y`^/000000000000208iFR@03
0000003oool0oooo00<0oooo00<000000?ooo`09jPX00P09jPX;0?ooo`<02NX:2P3oool300WZ2PP0
oooo0`09jP[>0?ooo`00503oool2000001T0oooo00<000000?ooo`3oool01P3oool4000000D0oooo
00<000000?ooo`0000000P0000030?ooo`<000000P27CXH20000000308M>QP000000000001400000
103a[h@300000080lJn40P000000103a[h@000000000003oool3000000040?ooo`000000000008M>
QPD000002`2U_^/01P000000YKk[0:Fnj`2U_^/0000000WZ2P`0YKk[00@02NX:0000000000000000
1027CXH00`000000YKk[0:Fnj`040:Fnj`<02NX:1P2U_^/00`000000Qdj6000000040?ooo`<02NX:
0`3oool00`000000oooo0?ooo`02000000<0oooo0`09jPX;0?ooo`802NX:2@3oool300WZ2[h0oooo
0P0000000`3oool000000?ooo`0G0?ooo`040000003oool0oooo00000080SUJ9100000001@3oool0
00000?ooo`3oool0000000<0oooo0`0000020?ooo`040000002>EXT0000000000080SUJ90P000000
0`2>EXT000000000000;000000L0oooo00<000000?J`N03f/7P0103f/7P3000000040?J`N0000000
00000?ooo`8000000P3oool300000080SUJ91@00000B0:W2j`0400000009jPX02NX:000000X0ZL;[
0`00000408iFR@030000002Y`^/0ZL;[00@0ZL;[0`09jPX60:W2j`030000002>EXT0000000@0oooo
0`09jPX00`3oool00000000000080?ooo`<02NX:2P3oool300WZ2PT0oooo0P09jP[A0?ooo`004`3o
ool00`000000oooo0000000H0?ooo`<000001P3oool01@000000Qdj608M>QP000000oooo00<00000
0`3oool00`000000oooo0?ooo`0500000080Qdj60P0000000`27CXH000000000000B000000D0lJn4
00@000000?6_Q03a[h@0lJn40P0000001P3a[h@000000?6_Q03a[h@000000:Fnj`<0000000@0oooo
00000027CXH000000`27CXH4000000T0YKk[00@0000000WZ2P09jPX000002P2U_^/300WZ2P@0YKk[
00<0000008M>QP27CXH00P27CXH00`000000YKk[0:Fnj`0300WZ2PX0YKk[0P000000103oool02NX:
00WZ2P09jPX70?ooo`80000000<0oooo00000009jPX00P09jPX;0?ooo`<02NX:2@3oool200WZ2/40
oooo00<000000?ooo`000000603oool010000000oooo0?ooo`00000308iFR@040000003oool0oooo
0?ooo`<0000000<0oooo0000003oool01@3oool2000000@0SUJ90`0000000`2>EXT000000000000D
000000D0m[1h00@000000?J`N03f/7P0m[1h0P0000000`3f/7P000000?ooo`020?ooo`060000002Y
`^/000000000002>EXT000000P2>EXT00`000000SUJ900000003000000`0ZL;[0`09jPX010000000
ZL;[0:W2j`0000070:W2j`<02NX:0`2Y`^/00`000000SUJ908iFR@0208iFR@030000002Y`^/00000
00<02NX:2P2Y`^/2000000040?ooo`09jPX02NX:00WZ2P80oooo0P0000000`3oool000000?ooo`04
0?ooo`<02NX:2`3oool200WZ2PT0oooo0`09jP[C0?ooo`004`3oool00`000000oooo0000000H0?oo
o`030000003oool0oooo00@000000P3oool010000000Qdj608M>QP0000040?ooo`<0000000<0oooo
0000003oool00P0000000`3oool00000000000020000000308M>QP00000000000180000000<0oooo
0000003a[h@0103a[h@700000080lJn400<000000:Fnj`2U_^/00`000000103oool0000000000000
000308M>QP0400000027CXH0Qdj608M>QP<000001@2U_^/01@09jPX000000:Fnj`2U_^/0000000P0
YKk[0P09jPX80:Fnj`0400000027CXH0Qdj608M>QP<02NX:3@2U_^/00`09jPX0000000WZ2P0:0?oo
o`0400000009jPX02NX:00WZ2P/0oooo0`09jPX90?ooo`<02NX:``3oool00`000000oooo0000000H
0?ooo`@000000`2>EXT00`000000oooo0?ooo`040?ooo`@00000103oool00`000000SUJ900000002
000000@0SUJ95`0000050?J`N0@0000000L0m[1h000000000000m[1h0000003oool000000080ZL;[
0`00000408iFR@8000000`2>EXT3000000L0ZL;[0P09jPX30:W2j`050000002Y`^/0ZL;[0:W2j`00
00000`2Y`^/300WZ2PL0ZL;[00<0000008iFR@2>EXT00P09jPX00`0000002NX:0:W2j`0<0:W2j`03
00WZ2P0000002NX:00D0oooo00@000000?ooo`3oool000000P3oool300WZ2P/0oooo0`09jPX80?oo
o`<02NX:eP3oool001<0oooo0P00000I0?ooo`030000003oool0oooo00@0oooo100000000`27CXH0
00000?ooo`060?ooo`<0000000<0oooo0000000000001027CXHF000000D0lJn42P0000030:Fnj`80
000000<0YKk[0000000000000P27CXH010000000Qdj608M>QP00000608M>QP80000000H0YKk[00WZ
2P09jPX0YKk[0000002U_^/2000000D0YKk[0`09jPX;0:Fnj`80000000@02NX:08M>QP27CXH00000
2P2U_^/300WZ2P0308M>QP000000000000P0oooo0`09jPX30?ooo`030000003oool0oooo00D0oooo
0`09jPX:0?ooo`802NX:a@3oool010000000oooo0?ooo`00000H0?ooo`030000003oool0000000D0
00001`3oool7000000D0SUJ90`0000000`2>EXT0000008iFR@0608iFR@h00000103f/7P3000000<0
oooo0P0000020?J`N08000000`2Y`^/2000000040:W2j`000000SUJ908iFR@<000001P2>EXT20000
0080ZL;[0`09jPX60:W2j`040000002Y`^/00000000000<02NX:2P2Y`^/00`09jPX0000000000002
08iFR@8000002P2Y`^/300WZ2P0308iFR@000000oooo00D0oooo00<000000?ooo`3oool00`09jPX;
0?ooo`<02NX:2@3oool200WZ2]T0oooo000B0?ooo`<00000603oool00`000000oooo0?ooo`060?oo
o`0300000027CXH0Qdj600@000001`3oool4000000@0Qdj600<0000008M>QP27CXH03027CXH40000
0080oooo00<000000?6_Q03a[h@00P3a[h@010000000oooo0000003oool300000080oooo00@00000
0:Fnj`2U_^/0YKk[0`0000000`2U_^/000000000000208M>QP0500000027CXH0Qdj608M>QP000000
1@27CXH00`09jPX0000000WZ2P030:Fnj`80000000<0YKk[0000002U_^/00P2U_^/200WZ2P/0YKk[
0`09jPX300000080Qdj60P0000060:Fnj`<02NX:1027CXH00`000000YKk[000000040?ooo`<02NX:
0`3oool010000000oooo0?ooo`0000050?ooo`802NX:2P3oool300WZ2/L0oooo00<000000?ooo`00
00006@3oool00`000000oooo0000000408iFR@@00000103oool00`000000oooo000000020?ooo`D0
00001@2>EXTC000000<0oooo00<000000?J`N03f/7P00P3f/7P4000000040?ooo`00000000000?oo
o`800000102Y`^/300000080ZL;[0P00000208iFR@8000001P2>EXT20000000300WZ2P000000ZL;[
00L0ZL;[0P0000000`09jPX000000:W2j`090:W2j`<02NX:00<0ZL;[0000000000000P2>EXT00`00
0000oooo000000060:W2j`<02NX:102>EXT2000000D0oooo0`09jPX00`3oool000000?ooo`080?oo
o`<02NX:2@3oool300WZ2]/0oooo000B0?ooo`030000003oool0000001P0oooo00<000000?ooo`3o
ool01@3oool01@000000Qdj608M>QP27CXH0000000<0oooo100000040?ooo`0300000027CXH0Qdj6
00@000002027CXH>000000@0lJn42@0000030:Fnj`0:0000002U_^/000000000002U_^/000000:Fn
j`000000Qdj6000000<0Qdj600<0000008M>QP09jPX00`09jPX00`27CXH000000000000200000006
0:Fnj`000000YKk[0:Fnj`000000YKk[0P09jPX:0:Fnj`<02NX:1P2U_^/010000000Qdj60000003o
ool2000000040:Fnj`09jPX02NX:00WZ2PL0Qdj600<000000:Fnj`2U_^/00P00000200WZ2PH0oooo
00@000000?ooo`3oool000000P3oool300WZ2PX0oooo0P09jP[:0?ooo`<00000603oool00`000000
oooo0000000408iFR@030000003oool0oooo0080oooo100000000`3oool000000?ooo`02000000D0
SUJ90`00000208iFR@030000002>EXT0SUJ900D0SUJ93`0000030?J`N0H0000000@0oooo0000003o
ool00000102Y`^/010000000ZL;[0000000000020:W2j`8000000P2>EXT2000000@0SUJ90`09jPX0
0`3oool0000000000002000000D0ZL;[00D02NX:00000009jPX0ZL;[000000080:W2j`802NX:1P2Y
`^/00`000000SUJ9000000020?ooo`80000000@0ZL;[00WZ2P09jPX02NX:1`2>EXT010000000ZL;[
00000000000300WZ2P050?ooo`000000oooo0?ooo`0000001`3oool200WZ2PT0oooo0`09jP[N0?oo
o`004P3oool00`000000oooo0000000H0?ooo`@00000103oool01@000000Qdj608M>QP27CXH00000
00L0oooo1000000608M>QPT000002027CXH200000080Qdj600<000000?6_Q03a[h@00P3a[h@00`00
0000Qdj60000000308M>QP<000000P2U_^/200000080YKk[0`0000030:Fnj`80000000<0Qdj600WZ
2P09jPX00P09jPX608M>QPH000000P09jPX00`000000YKk[0:Fnj`070:Fnj`<02NX:2P2U_^/20000
00040?ooo`09jPX0000000WZ2PX0Qdj600<0000000WZ2P09jPX00P0000080?ooo`030000003oool0
oooo00<02NX:2P3oool300WZ2/`0oooo00<000000?ooo`000000603oool3000000@0SUJ900<00000
0?ooo`3oool01P3oool4000000T0SUJ92P00000508iFR@8000000P2>EXT200000080SUJ900D00000
0?J`N03f/7P0m[1h0000000208iFR@<0000000@0oooo00000000000000000`2Y`^/200000080ZL;[
00@000000:W2j`00000000000P2Y`^/01@000000SUJ9000000000000SUJ900<02NX:0P2>EXT30000
00<0oooo0P00000300WZ2P030:W2j`000000ZL;[0080ZL;[00<000000:W2j`2Y`^/00P2Y`^/300WZ
2PT0ZL;[0`00000200WZ2P0300000009jPX0SUJ900T0SUJ900@0000000WZ2P0000000000103oool0
10000000oooo0?ooo`0000040?ooo`<02NX:2@3oool200WZ2^40oooo000B0?ooo`030000003oool0
000001P0oooo00@000000?ooo`3oool0oooo1@00000308M>QP030000003oool0oooo00P0oooo1@00
000208M>QP0300000027CXH0Qdj600D0Qdj62`00000208M>QP030000003a[h@0lJn40080lJn400<0
000008M>QP0000000P27CXH6000000@0YKk[0P0000030:Fnj`0400000009jPX0000000WZ2P<0Qdj6
00<0000008M>QP27CXH01027CXH010000000oooo0?ooo`09jPX5000000L0YKk[0P09jPX<0:Fnj`06
00WZ2P000000000000WZ2P3oool000002P27CXH00`0000002NX:0:Fnj`030:Fnj`030000003oool0
oooo00D0oooo00D0000000WZ2P09jPX0oooo000000080?ooo`<02NX:c`3oool00`000000oooo0000
000H0?ooo`030000003oool0000000D000002P3oool6000000H0SUJ900<0000008iFR@2>EXT02`2>
EXT20000000308iFR@000000000000<0SUJ900D000000?J`N03f/7P0m[1h0000000208iFR@030000
002>EXT0000000@000000P2Y`^/00`000000ZL;[0:W2j`030:W2j`8000000`2Y`^/20000000300WZ
2P0000002NX:00D0SUJ900<000000?ooo`3oool00P3oool300WZ2P8000000`2Y`^/01@000000ZL;[
0:W2j`000000ZL;[00<02NX:2`2Y`^/200WZ2P0500000009jPX0oooo0?ooo`0000002`2>EXT01@00
0000ZL;[0:W2j`2Y`^/0000000@0oooo00@000000?ooo`3oool000000`09jPX90?ooo`<02NX:h`3o
ool00180oooo0P00000I0?ooo`030000003oool0oooo00@0oooo00<0000008M>QP0000001@000007
0?ooo`0300000027CXH0Qdj600<0Qdj62P00000808M>QP<000000P27CXH01@000000lJn40?6_Q03a
[h@000000080Qdj60`0000020:Fnj`H0000000T0YKk[00000000000000000:Fnj`09jPX0000000WZ
2P2U_^/00P00000308M>QP0300000027CXH0Qdj600@0Qdj60`09jPX20?ooo`@00000102U_^/300WZ
2P/0YKk[0`09jPX208M>QP040000003oool0oooo000000X0Qdj600<000000:Fnj`2U_^/00`2U_^/0
0`000000oooo0?ooo`030?ooo`<02NX:00@000000?ooo`00000000001P3oool200WZ2]80oooo00<0
00000?ooo`000000603oool2000000D0SUJ91P0000050?ooo`030000002>EXT0SUJ900<0SUJ91000
00000`2>EXT0000008iFR@0708iFR@/000000`2>EXT01P000000m[1h0?J`N03f/7P0000008iFR@@0
00000P2Y`^/010000000ZL;[0000000000050:W2j`<000000P2Y`^/01009jPX0000000WZ2P2>EXT2
000000D0SUJ900<000000?ooo`09jPX00P09jPX01P3oool00000000000000000oooo00000080ZL;[
00D000000:W2j`2Y`^/0000000WZ2P0;0:W2j`<02NX:0P2>EXT01@000000oooo0?ooo`3oool00000
00/0SUJ900D000000:W2j`2Y`^/0ZL;[000000040?ooo`0400000009jPX02NX:00WZ2PX0oooo0P09
jP[V0?ooo`004@3oool00`000000oooo0000000H0?ooo`030000003oool0oooo00D0oooo00D00000
08M>QP27CXH0Qdj6000000030?ooo`L000001`27CXH00`000000Qdj608M>QP0=08M>QP@000000P27
CXH01@000000lJn40?6_Q03a[h@000000080Qdj600@000000:Fnj`2U_^/0YKk[0P0000050:Fnj`@0
000000<02NX:0000002U_^/00`2U_^/200000080Qdj600@0000008M>QP27CXH0Qdj60`09jPX00`00
0000oooo0?ooo`03000000<0oooo00@0000000WZ2P09jPX02NX:2`2U_^/300WZ2PD0Qdj60P000000
0`3oool0000008M>QP0908M>QP030000002U_^/0YKk[00@0YKk[0P00000300WZ2P<0oooo0P000000
0`3oool000000?ooo`020?ooo`<02NX:e03oool00`000000oooo0000000H0?ooo`800000102>EXT0
0`000000oooo0?ooo`040?ooo`D000002P2>EXT:000000@0SUJ900D000000?ooo`3oool0000008iF
R@02000000<0SUJ900@000000?J`N03f/7P0m[1h0P0000000`2>EXT000000:W2j`030:W2j`800000
0P2Y`^/5000000030:W2j`000000000000802NX:00<000000:W2j`2Y`^/00`00000408iFR@<02NX:
00@0oooo00000000000000001@3oool3000000802NX:00<000000:W2j`2Y`^/01`2Y`^/300WZ2PD0
SUJ90P0000020?ooo`030000002>EXT0SUJ900T0SUJ900<000000:W2j`2Y`^/00P2Y`^/2000000<0
2NX:0P3oool00`000000oooo0?ooo`050?ooo`<02NX:j03oool00140oooo00<000000?ooo`000000
603oool00`000000oooo0?ooo`040?ooo`0300000027CXH0Qdj60080Qdj600<000000?ooo`3oool0
1P3oool600000080Qdj600<0000008M>QP27CXH01P27CXH<00000080Qdj600H000000?6_Q03a[h@0
lJn400000027CXH6000000@0YKk[0P00000200WZ2P<000001@2U_^/00`000000YKk[000000020000
00<02NX:0`27CXH3000000<0oooo00<0000000WZ2P0000000P00000:0:Fnj`<02NX:2027CXH01000
0000YKk[00000000000:08M>QP030000002U_^/0YKk[00<0YKk[00<02NX:0000000000001P3oool0
1@000000oooo0?ooo`000000oooo00802NX:e`3oool00`000000oooo0000000H0?ooo`030000002>
EXT0SUJ900<0SUJ900<000000?ooo`3oool0203oool5000000L0SUJ900<0000008iFR@2>EXT02@2>
EXT8000000<0SUJ900<000000?J`N03f/7P00P00000208iFR@8000000P2Y`^/2000000@0ZL;[1000
00000`09jPX000000:W2j`02000000@0ZL;[0`00000300WZ2P0408iFR@0000000000000000L0oooo
00@02NX:00000009jPX000000`2Y`^/00`000000ZL;[0:W2j`030:W2j`<02NX:202>EXT00`000000
ZL;[00000002000000/0SUJ900D000000:W2j`2Y`^/0ZL;[00WZ2P0200000080oooo00@000000?oo
o`3oool00000103oool300WZ2^/0oooo000A0?ooo`<00000603oool500000080oooo00<0000008M>
QP27CXH00P27CXH00`000000oooo0?ooo`060?ooo`0300000027CXH0Qdj600<0Qdj62`00000608M>
QP030000003oool0oooo00<000000P27CXH01P000000lJn40?6_Q03a[h@0000008M>QPH000000P2U
_^/2000000802NX:00<0YKk[0000000000000`0000030:Fnj`80000000D02NX:00000009jPX02NX:
0000000408M>QP8000000`3oool200WZ2P80000000@0oooo00000000000000001P2U_^/300WZ2PX0
Qdj600@000000:Fnj`09jPX000002`27CXH00`000000YKk[00WZ2P0300WZ2P<0YKk[00<000000?oo
o`3oool00`3oool00`000000oooo00WZ2P0200WZ2]T0oooo0`00000H0?ooo`030000002>EXT0SUJ9
00<0SUJ900<000000?ooo`3oool01`3oool00`000000SUJ908iFR@0308iFR@D0000000<0SUJ90000
002>EXT00`2>EXT=0000000308iFR@000000000000<0SUJ900<000000?J`N03f/7P00P00000208iF
R@@0000000<0ZL;[0000002Y`^/00P2Y`^/00`0000002NX:00WZ2P02000000040:W2j`000000ZL;[
000000@0ZL;[0`09jPX00`000000SUJ908iFR@0208iFR@030000003oool0oooo00<0oooo1009jPX0
0`3oool000000?ooo`02000000030:W2j`00000000000080ZL;[0`09jPX;08iFR@030000002Y`^/0
2NX:008000002`2>EXT0100000002NX:00WZ2P09jPX30:W2j`030000003oool000000080oooo00<0
00000?ooo`3oool00P09jP[^0?ooo`004@3oool00`000000YKk[0000000H0?ooo`030000002U_^/0
YKk[0080YKk[200000070?ooo`0300000027CXH0Qdj600H0Qdj600<0000008M>QP27CXH03027CXH2
000000040?ooo`000000000000000080Qdj600@000000?6_Q03a[h@000000P27CXH00`000000Qdj6
08M>QP0208M>QP<0000000<02NX:0:Fnj`2U_^/00P2U_^/300000080YKk[00D000000:Fnj`000000
2NX:000000030:Fnj`8000001027CXH00`0000002NX:00WZ2P0200WZ2P80oooo0`0000000`3oool0
00000?ooo`03000000<02NX:3@27CXH0100000002NX:0:Fnj`00000;08M>QP0300000009jPX0YKk[
00L0YKk[00<000000?ooo`3oool00P3oool200WZ2P80oooo00<000000?ooo`3oool0e`3oool00`00
0000ZL;[0000000H0?ooo`L00000203oool00`000000SUJ908iFR@0908iFR@H000001`2>EXT00`00
0000oooo0?ooo`020?ooo`<00000102>EXT010000000m[1h0?J`N000000308iFR@030000002>EXT0
000000H000001@2Y`^/4000000040:W2j`09jPX02NX:00WZ2P80ZL;[0P00000408iFR@030000003o
ool0oooo00<02NX:00<000000?ooo`3oool00`3oool00`000000oooo00000003000000802NX:3P2>
EXT00`0000002NX:0:W2j`02000000/0SUJ900<000000:W2j`2Y`^/01@2Y`^/200000080oooo0`09
jP[`0?ooo`004@3oool010000000YKk[00000000000F0?ooo`8000002`2U_^/8000000T0Qdj600<0
000008M>QP27CXH02`27CXH700000080Qdj600D000000?6_Q03a[h@0000008M>QP0200000080Qdj6
0P09jPX2000000@0YKk[0P000000102U_^/000000000002U_^/200WZ2P050000002U_^/0YKk[0:Fn
j`0000000`2U_^/00`000000Qdj608M>QP0300WZ2P@0oooo0P0000001@3oool000000?ooo`3oool0
000000@02NX:4027CXH010000000YKk[0:Fnj`00000;08M>QP030000002U_^/0YKk[00L0YKk[0P00
000300WZ2P050?ooo`000000oooo0?ooo`000000f@3oool010000000ZL;[00000000000F0?ooo`80
00001@2Y`^/:000000`0SUJ900<0000008iFR@2>EXT0202>EXT00`000000oooo0?ooo`07000000<0
SUJ900@000000?J`N03f/7P000000`2>EXT00`000000SUJ90000000200WZ2P8000001@2Y`^/20000
00030:W2j`000000ZL;[008000000`2Y`^/2000000030:W2j`00000000000080SUJ91009jPX00`00
0000oooo0?ooo`060?ooo`0300000009jPX0000000802NX:00<0000008iFR@2>EXT03P2>EXT01@00
0000ZL;[0:W2j`2Y`^/0000000/0SUJ900<000000:W2j`2Y`^/01@2Y`^/2000000802NX:00<0oooo
0000003oool0l03oool00140oooo0`0000000`2U_^/000000?ooo`0D0?ooo`8000004P2U_^/70000
00<0Qdj600<0000008M>QP27CXH00P27CXH9000000@0YKk[00<000000:Fnj`0000000P27CXH01`00
0000lJn40?6_Q0000000Qdj600000009jPX0100000001027CXH000000000002U_^/2000000<0YKk[
00L0000000WZ2P000000YKk[0000002U_^/000000080YKk[00@000000:Fnj`2U_^/0YKk[0`09jPX2
08M>QP030000003oool00000008000000`3oool01@0000002NX:00WZ2P000000oooo008000004@27
CXH010000000YKk[0:Fnj`00000;08M>QP030000002U_^/0YKk[00H0YKk[00<02NX:000000000000
103oool010000000oooo0?ooo`00003I0?ooo`050000002Y`^/000000:W2j`0000005@3oool20000
00h0ZL;[2@00000408iFR@030000002>EXT0SUJ90080SUJ92@0000040:W2j`80000000D0ZL;[0000
002>EXT0SUJ9000000020?J`N0030000002>EXT000000080000000<02NX:0000000000000`000003
0:W2j`8000000`09jPX00`000000ZL;[00000002000000030:W2j`000000ZL;[0080ZL;[00D00000
00WZ2P09jPX02NX:08iFR@02000000L0oooo1009jPX300000080SUJ900<0000008iFR@2>EXT03@2>
EXT01@000000ZL;[0:W2j`2Y`^/0000000/0SUJ900<000000:W2j`2Y`^/00`2Y`^/200WZ2P<00000
0P3oool00`000000oooo0?ooo`3_0?ooo`004@3oool300000080YKk[00<000000?ooo`3oool04@3o
ool00`000000YKk[0000000I0:Fnj`P00000302U_^/200000080YKk[0`0000020?6_Q00300000009
jPX00000008000001027CXH300000080YKk[0`09jPX0102U_^/000000000000000030:Fnj`<00000
0`09jPX01@2U_^/00000000000000000Qdj6008000000`3oool300WZ2P030000003oool000000080
000000<0oooo00000027CXH04027CXH010000000YKk[0:Fnj`00000:08M>QP030000002U_^/0YKk[
00<0YKk[1009jPX30:Fnj`060000003oool0oooo0?ooo`000000oooo0P00003I0?ooo`050000002Y
`^/000000:W2j`000000503oool3000001L0ZL;[2@00000<0:W2j`<000000P2Y`^/01P000000SUJ9
0?J`N0000000m[1h000000<02NX:0`0000020?ooo`8000000P2Y`^/00`0000002NX:00WZ2P040:W2
j`030000002Y`^/00000008000000P2Y`^/300WZ2P<0000000<0SUJ90000003oool0103oool300WZ
2P8000000P3oool00`000000oooo0000000208iFR@030000002>EXT0SUJ900d0SUJ900D000000:W2
j`2Y`^/02NX:0000000:08iFR@030000002Y`^/0ZL;[00@02NX:0`2Y`^/2000000030?ooo`000000
00000?40oooo000A0?ooo`<000000`2U_^/00`000000oooo0?ooo`0@0?ooo`030000002U_^/00000
01`0YKk[00<0000008M>QP0000002P2U_^/600000080YKk[00<02NX:0000000000000P3a[h@20000
0080Qdj600@0000008M>QP27CXH0Qdj60P000000103oool0000000WZ2P09jPX30:Fnj`<00000102U
_^/01009jPX000000000000000060:Fnj`<000000`09jPX20?ooo`<000000P3oool00`000000oooo
0000000@08M>QP050000002U_^/02NX:00WZ2P0000002P27CXH00`000000YKk[0:Fnj`0300WZ2PL0
YKk[00@000000?ooo`3oool0oooo0P0000000`3oool000000?ooo`3G0?ooo`040000003oool00000
00000080ZL;[00<000000?ooo`3oool04@3oool00`000000ZL;[0000000K0:W2j`8000003@2Y`^/5
000000<0ZL;[0`0000000`3f/7P0000008iFR@0208iFR@030000002>EXT000000080000000@0oooo
00000000000000001P2Y`^/2000000060:W2j`0000002NX:00WZ2P0000002NX:0`2Y`^/00`000000
ZL;[0:W2j`02000000030?ooo`09jPX02NX:00802NX:0P0000050?ooo`030000003oool000000080
SUJ900<0000008iFR@2>EXT03@2>EXT01@0000002NX:00WZ2P2Y`^/0000000X0SUJ900<0000000WZ
2P09jPX0202Y`^/2000000030?ooo`000000oooo0?00oooo000A0?ooo`030000003oool0000000@0
YKk[00<000000?ooo`3oool03`3oool00`000000YKk[0000000>000000d0YKk[00@0000008M>QP27
CXH0Qdj62P0000030:Fnj`<000000P09jPX00`2U_^/00000000000020?6_Q00400000027CXH0Qdj6
08M>QP@0000000<02NX:00000009jPX00P3oool01@000000YKk[000000000000YKk[008000001009
jPX20:Fnj`<000001@2U_^/300WZ2P030000003oool00000008000000P3oool01P000000oooo0?oo
o`0000002NX:00000100Qdj600D0000000WZ2P2U_^/0YKk[0000000:08M>QP80000000<02NX:0:Fn
j`2U_^/02@2U_^/010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0=H0oooo00@00000
0?ooo`00000000000`2Y`^/00`000000oooo0?ooo`0?0?ooo`030000002Y`^/0ZL;[00P000004`2Y
`^/20000000308iFR@000000ZL;[00D0ZL;[1P0000020:W2j`<0000000<0ZL;[00WZ2P09jPX00`00
00020?J`N0040000002>EXT0SUJ908iFR@80000000<02NX:0000000000000`0000040:W2j`800000
00@0ZL;[00000009jPX000000P2Y`^/3000000030:W2j`00000000000080ZL;[0`09jPX3000000T0
oooo00<02NX:0000002>EXT00P2>EXT00`000000SUJ908iFR@0;08iFR@030000002Y`^/0ZL;[0080
ZL;[00<0000008iFR@2>EXT0202>EXT00`000000ZL;[0:W2j`080:W2j`040000003oool0oooo0000
0?40oooo000A0?ooo`<00000102U_^/00`000000oooo0?ooo`0>0?ooo`040000002U_^/0YKk[0000
00h0YKk[4`00000:0:Fnj`0300WZ2P0000002NX:008000000`2U_^/010000000lJn40?6_Q0000003
08M>QP0400000009jPX02NX:00WZ2P80000000<0oooo0000000000000P0000020:Fnj`0400WZ2P00
00002NX:000000<0YKk[0P0000001@2U_^/000000:Fnj`000000YKk[00<02NX:1@0000050?ooo`03
00000009jPX02NX:00<000004027CXH01@000000YKk[0:Fnj`2U_^/0000000X0Qdj60`00000<0:Fn
j`030000003oool000000080oooo00<000000?ooo`3oool0eP3oool010000000oooo000000000003
0:W2j`030000003oool0oooo00l0oooo00@000000:W2j`2Y`^/000001`2Y`^/>000000D0ZL;[0P00
000208iFR@H000001`2Y`^/20000000300WZ2P000000000000<0ZL;[0P0000020?J`N0040000002>
EXT0SUJ900WZ2P<000000P3oool7000000<02NX:00<000000:W2j`0000000`2Y`^/3000000050:W2
j`0000002NX:00WZ2P2>EXT00P0000090?ooo`<02NX:0`0000000`2>EXT000000000000=08iFR@03
0000002Y`^/0ZL;[0080ZL;[00<0000008iFR@2>EXT0202>EXT00`000000ZL;[0:W2j`090:W2j`03
0000003oool000000?40oooo000A0?ooo`030000003oool0000000D0YKk[00<000000?ooo`3oool0
3@3oool010000000YKk[0:Fnj`00000J0:Fnj`8000001@27CXH00`000000YKk[0:Fnj`040:Fnj`<0
2NX:1@0000030:Fnj`050000003a[h@0lJn400000027CXH00P09jPX010000000Qdj608M>QP27CXH5
000000040?ooo`09jPX02NX:00WZ2P80YKk[0P0000000`2U_^/00000000000040:Fnj`0300000009
jPX0000000@0Qdj600<000000:Fnj`000000103oool300WZ2P80000000<0oooo0000000000003`27
CXH00`000000YKk[0:Fnj`020:Fnj`0300000027CXH0Qdj600P0Qdj600@000000?ooo`3oool00000
2`2U_^/00`000000oooo000000030?ooo`030000003oool0oooo0=D0oooo100000040:W2j`030000
003oool0oooo00d0oooo00D000000:W2j`2Y`^/0ZL;[0000000E0:W2j`T0000000<0SUJ90000002Y
`^/02@2Y`^/00`09jPX0000000000003000000@0ZL;[00@000000?J`N03f/7P000000P09jPX00`2>
EXT0000000000003000000030?ooo`0000000000008000000P09jPX40:W2j`030000002Y`^/00000
008000000P2Y`^/01009jPX0000008iFR@00000208iFR@030000002Y`^/0000000D0oooo0`09jPX0
0`3oool00000000000040000000308iFR@000000SUJ900`0SUJ900<000000:W2j`2Y`^/00P2Y`^/0
0`000000SUJ908iFR@0808iFR@030000002Y`^/0ZL;[00T0ZL;[00@000000?ooo`3oool00000l03o
ool00140oooo00@000000?ooo`00000000001@2U_^/00`000000oooo0?ooo`0<0?ooo`040000002U
_^/0YKk[000001X0YKk[0P00000608M>QP030000002U_^/0YKk[00H0000000<0YKk[0000002U_^/0
0P0000030:Fnj`050000003a[h@0lJn40?6_Q00000000P27CXH010000000Qdj608M>QP27CXH30000
00<02NX:00<0oooo0000000000000P2U_^/00`000000YKk[000000040:Fnj`802NX:0`00000408M>
QP040000002U_^/0YKk[000000<02NX:0P3oool6000000l0Qdj600<000000:Fnj`2U_^/00P2U_^/0
0`000000Qdj608M>QP0808M>QP050000003oool0oooo0?ooo`0000002`2U_^/00`000000oooo0000
00020?ooo`030000003oool0oooo0=D0oooo00@000000?ooo`00000000001@2Y`^/00`000000oooo
0?ooo`0<0?ooo`050000002Y`^/0ZL;[0:W2j`0000006@2Y`^/00`000000SUJ90000000408iFR@03
0000002Y`^/0ZL;[00@0ZL;[1@0000020:W2j`800000102Y`^/010000000m[1h0?J`N000000308iF
R@8000000`3oool2000000802NX:0P0000050:W2j`040000002Y`^/000000:W2j`<02NX:0P000000
1@2>EXT0000008iFR@2>EXT000000080ZL;[0P00000300WZ2P@000000P3oool3000000<0SUJ900<0
000008iFR@2>EXT02P2>EXT00`000000ZL;[00WZ2P0200WZ2P030000002>EXT0SUJ900P0SUJ90P00
000;0:W2j`030000003oool000000?00oooo000A0?ooo`040000003oool00000000000H0YKk[00<0
00000?ooo`3oool02`3oool010000000YKk[0:Fnj`00000J0:Fnj`0300000027CXH000000080Qdj6
1P0000080:Fnj`<000000P2U_^/00`09jPX000000?6_Q0020?6_Q08000000P27CXH6000000D0oooo
100000000`2U_^/000000:Fnj`0300WZ2P80Qdj600<0000008M>QP0000001027CXH010000000YKk[
00WZ2P09jPX500000080oooo00@000000?ooo`00000000003`27CXH00`0000002NX:00WZ2P0200WZ
2P0300000027CXH0Qdj600L0Qdj600<000000?ooo`3oool00`3oool00`000000YKk[0:Fnj`080:Fn
j`030000003oool000000080oooo00<000000?ooo`3oool0e@3oool010000000oooo0?ooo`000005
0:W2j`030000003oool0oooo00/0oooo00<000000:W2j`2Y`^/00P2Y`^/00`000000ZL;[0:W2j`0G
0:W2j`030000002>EXT0000000D0SUJ91P0000040:W2j`030000002Y`^/0ZL;[0080000000D0ZL;[
00WZ2P09jPX02NX:000000020?J`N0030000002>EXT0SUJ90080SUJ9100000000`09jPX000000?oo
o`04000000<0ZL;[0P0000000`09jPX0000000WZ2P0408iFR@030000002>EXT000000080SUJ900<0
00000:W2j`09jPX00P09jPX2000000L0oooo00@0000008iFR@2>EXT000000P2>EXT00`000000SUJ9
08iFR@0:08iFR@0300000009jPX0ZL;[0080ZL;[00<0000008iFR@2>EXT0202>EXT00`000000oooo
0000000:0:W2j`030000003oool000000?00oooo000A0?ooo`050000003oool000000?ooo`000000
1P2U_^/00`000000oooo0?ooo`090?ooo`050000002U_^/0YKk[0:Fnj`0000003P2U_^/A000000<0
2NX:00<0Qdj60000000000001`2U_^/4000000802NX:00<0YKk[0000003a[h@00P3a[h@00`000000
YKk[00000002000000<02NX:0P0000000`3oool00000000000060000000300WZ2P0000002NX:00H0
Qdj600<0000008M>QP27CXH00`27CXH00`0000002NX:0:Fnj`020:Fnj`030000003oool0oooo00<0
oooo00@0000000WZ2P00000000003`27CXH00`000000YKk[0:Fnj`020:Fnj`0300000027CXH0Qdj6
00L0Qdj600<000000?ooo`3oool0103oool00`000000YKk[0:Fnj`080:Fnj`80000000<0oooo0000
00000000e`3oool010000000oooo0?ooo`0000060:W2j`030000003oool0oooo00X0oooo00<00000
0:W2j`2Y`^/00P2Y`^/00`000000ZL;[0:W2j`0F0:W2j`050000002>EXT0SUJ90000002>EXT01@00
000200WZ2PP0ZL;[00D000000:W2j`000000000000WZ2P030:W2j`030000003f/7P0m[1h00800000
0P2>EXT00`09jPX0000000WZ2P0500000080oooo00<000000?ooo`0000000P0000001009jPX00000
08iFR@00000508iFR@070000002>EXT0SUJ90000002>EXT0000000WZ2P030:W2j`030000003oool0
oooo00<0oooo0`09jPX010000000SUJ908iFR@00000208iFR@030000002>EXT0SUJ900T0SUJ900<0
00000:W2j`2Y`^/00`2Y`^/00`000000SUJ908iFR@0808iFR@030000003oool0000000X0ZL;[0`00
003`0?ooo`004@3oool01@000000oooo0000003oool0000000L0YKk[00<000000?ooo`3oool0203o
ool010000000YKk[0:Fnj`2U_^/?000000`0YKk[00<0000008M>QP0000000P09jPX508M>QP800000
00<0YKk[0000000000000`0000001009jPX000000000000000040:Fnj`040000003a[h@0lJn40000
00802NX:0P00000208M>QPL0000000<0oooo00WZ2P09jPX00P09jPX00`000000Qdj60000000308M>
QP@000001@27CXH00`000000YKk[0:Fnj`030:Fnj`80000000<0oooo00WZ2P09jPX00P00000208M>
QP0300000027CXH0Qdj600/0Qdj600<000000:Fnj`2U_^/00`2U_^/00`000000Qdj608M>QP0708M>
QP030000003oool0oooo00D0oooo00<000000:Fnj`2U_^/01`2U_^/3000000030?ooo`000000oooo
0=H0oooo00@000000?ooo`3oool000001`2Y`^/00`000000oooo0?ooo`090?ooo`030000002Y`^/0
ZL;[0080ZL;[00<000000:W2j`2Y`^/02`2Y`^/@000000<02NX:00@0SUJ90000003oool00000202Y
`^/4000000D0ZL;[00<000000?J`N03f/7P00P0000001009jPX0SUJ90000000000040?ooo`030000
003oool00000008000000P09jPX308iFR@030000002>EXT0000000@0SUJ9100000000`2>EXT00000
0:W2j`040:W2j`8000000`09jPX0103oool0000000000000000308iFR@040000002>EXT0SUJ90000
00X0SUJ900<000000:W2j`2Y`^/00`2Y`^/00`000000SUJ908iFR@0708iFR@050000003oool0oooo
0?ooo`0000002P2Y`^/200000?00oooo000A0?ooo`050000003oool000000?ooo`000000202U_^/0
0`000000oooo0?ooo`070?ooo`050000002U_^/0YKk[0:Fnj`000000602U_^/400WZ2P0300000027
CXH0Qdj600@0Qdj61@000000102U_^/02NX:00WZ2P09jPX20:Fnj`030000002U_^/0000000<0YKk[
00@000000?6_Q03a[h@000000`2U_^/20000000308M>QP0000000000008000001009jPX20?ooo`<0
000000<0Qdj60000000000000P00000308M>QP0300000027CXH0Qdj600<0Qdj600<000000:Fnj`2U
_^/00P2U_^/01009jPX0000000WZ2P09jPX400000080Qdj600<0000008M>QP27CXH02`27CXH00`00
0000YKk[0:Fnj`030:Fnj`0300000027CXH0Qdj600L0Qdj600<000000?ooo`3oool01P3oool00`00
0000YKk[0:Fnj`070:Fnj`040000003oool0oooo00000=P0oooo00@000000?ooo`00000000001P2Y
`^/00`000000oooo0?ooo`080?ooo`030000002Y`^/0ZL;[00<0ZL;[3P00000;0:W2j`80000000<0
2NX:00000009jPX0102>EXT00`000000oooo0?ooo`09000000030:W2j`000000000000D0ZL;[00<0
00000?J`N03f/7P00`0000000`2>EXT00000000000020?ooo`@000000`09jPX2000000<0SUJ900@0
000008iFR@000000SUJ91000000208iFR@030000002>EXT0000000@0ZL;[0`09jPX400000080oooo
00D0000008iFR@2>EXT0SUJ90000000208iFR@030000002>EXT0SUJ900L0SUJ900<000000:W2j`2Y
`^/0102Y`^/00`000000SUJ908iFR@0708iFR@030000003oool0oooo0080oooo00<000000:W2j`2Y
`^/01`2Y`^/200000?00oooo000A0?ooo`<000000P3oool00`000000YKk[0:Fnj`060:Fnj`030000
003oool0oooo00H0oooo00D000000:Fnj`2U_^/0YKk[0000000C0:Fnj`D02NX:0P2U_^/300000003
08M>QP000000000000<0000000<0Qdj600000009jPX00P0000000`09jPX0YKk[0:Fnj`030:Fnj`<0
00000`09jPX010000000lJn40?6_Q00000040:Fnj`<000000P09jPX00`000000oooo000000040000
00030?ooo`0000000000008000001P27CXH2000000<0Qdj600<000000:Fnj`2U_^/00`09jPX30:Fn
j`050000003oool0oooo0?ooo`0000000P27CXH00`000000Qdj608M>QP0;08M>QP030000002U_^/0
YKk[00<0YKk[00<0000008M>QP27CXH01`27CXH00`000000oooo0?ooo`070?ooo`030000002U_^/0
YKk[00H0YKk[00@000000?ooo`3oool00000f03oool010000000oooo0000000000070:W2j`030000
003oool0oooo00L0oooo00<000000:W2j`2Y`^/00`2Y`^/00`000000ZL;[0:W2j`0D0:W2j`802NX:
00@0000000WZ2P2>EXT00000102>EXT00`000000oooo0?ooo`04000000H0ZL;[00D000000:W2j`00
000000000:W2j`0300WZ2P040000003f/7P0m[1h00000080ZL;[1@0000001009jPX0000000000009
jPX20?ooo`<000000P2>EXT5000000<0SUJ900@0000008iFR@2>EXT0SUJ90P000000102Y`^/02NX:
00WZ2P09jPX20:W2j`030000003oool0oooo00<0oooo00<0000008iFR@2>EXT00P2>EXT010000000
SUJ908iFR@00000908iFR@030000002Y`^/0ZL;[00@0ZL;[00<0000008iFR@2>EXT01`2>EXT00`00
0000oooo0?ooo`030?ooo`030000002Y`^/0ZL;[00L0ZL;[00<000000?ooo`3oool0kP3oool00140
oooo00<000000?ooo`0000000P3oool00`000000YKk[0:Fnj`070:Fnj`030000003oool0oooo00D0
oooo00D000000:Fnj`2U_^/0YKk[0000000>0:Fnj`D02NX:1@2U_^/6000000<0Qdj61009jPX0103o
ool000000?ooo`0000040:Fnj`@00000102U_^/010000000lJn40?6_Q00000030:Fnj`<000000`3o
ool80000000408M>QP000000Qdj6000000@0Qdj600<0000008M>QP0000000`27CXH00`0000002NX:
00WZ2P070:Fnj`040000003oool0000000000080Qdj60P00000;08M>QP030000002U_^/0YKk[00@0
YKk[00<0000008M>QP27CXH01P27CXH00`000000oooo0?ooo`090?ooo`030000002U_^/0YKk[00H0
YKk[00@000000?ooo`3oool00000e`3oool4000000P0ZL;[00<000000?ooo`3oool01P3oool00`00
0000ZL;[0:W2j`030:W2j`030000002Y`^/0ZL;[00l0ZL;[1@09jPX30:W2j`050000002>EXT0SUJ9
0000002>EXT01@0000001009jPX0oooo0?ooo`0000060:W2j`@0000000<02NX:0:W2j`2Y`^/00P2Y
`^/00`000000m[1h000000020:W2j`<0000000<02NX:0000000000000P3oool00`000000oooo0?oo
o`0500000080SUJ90P00000308iFR@030000002>EXT0SUJ90080SUJ90P0000000`09jPX0ZL;[0:W2
j`040:W2j`030000003oool0oooo00802NX:00<0000008iFR@2>EXT00`2>EXT4000000P0SUJ900<0
00000:W2j`2Y`^/0102Y`^/00`000000SUJ908iFR@0708iFR@030000003oool0oooo00@0oooo00<0
00000:W2j`2Y`^/01P2Y`^/200000>l0oooo000A0?ooo`030000003oool0000000<0oooo00<00000
0:Fnj`2U_^/01`2U_^/00`000000oooo0?ooo`040?ooo`050000002U_^/0YKk[0:Fnj`0000002@2U
_^/500WZ2P<0YKk[1`0000030:Fnj`8000001009jPX208M>QP80000000<0oooo0000003oool01@00
00001009jPX0YKk[0000000000040:Fnj`050000003a[h@0lJn40000002U_^/00P09jPX800000080
oooo0P0000001P3oool0000008M>QP000000Qdj6000000@0Qdj600<0000008M>QP0000000`27CXH3
000000L0YKk[0P09jPX01P000000Qdj6000000000000Qdj6000000/0Qdj600<000000:Fnj`2U_^/0
0`2U_^/00`000000Qdj608M>QP0708M>QP030000003oool0oooo00T0oooo00<000000:Fnj`2U_^/0
1P2U_^/010000000oooo0?ooo`00003G0?ooo`050000003oool000000?ooo`0000001`2Y`^/00`00
0000oooo0?ooo`060?ooo`030000002Y`^/0ZL;[00<0ZL;[00<000000:W2j`2Y`^/02P2Y`^/500WZ
2PH0ZL;[1`00000300WZ2PH0oooo00<000000:W2j`2Y`^/00`0000001009jPX00000000000000005
0:W2j`030000003f/7P0000000802NX:0`0000040?ooo`D0000000<02NX:0000002>EXT00`2>EXT0
0`000000SUJ90000000208iFR@030000002>EXT0SUJ90080SUJ90P0000070:W2j`<02NX:00<0oooo
0000000000001@2>EXT010000000SUJ908iFR@00000708iFR@030000002Y`^/0ZL;[00@0ZL;[00<0
000008iFR@2>EXT0202>EXT00`000000oooo0?ooo`040?ooo`030000002Y`^/0ZL;[00H0ZL;[0P00
003_0?ooo`004@3oool00`000000oooo000000030?ooo`030000002U_^/0YKk[00P0YKk[00<00000
0?ooo`3oool0103oool010000000YKk[0:Fnj`0000040:Fnj`D02NX:00<0YKk[0000000000001@00
00080:Fnj`<02NX:00<0000008M>QP27CXH01027CXH5000000040?ooo`09jPX00000000000@0YKk[
0P0000030:Fnj`050000003a[h@0lJn400000009jPX00`27CXH4000000030?ooo`000000oooo0080
oooo00@0000000WZ2P09jPX000000P27CXH2000000@0Qdj600@0000008M>QP27CXH000000P27CXH0
0`000000YKk[000000040:Fnj`<02NX:00D0YKk[000000000000Qdj60000000308M>QP0300000027
CXH0Qdj600P0Qdj600<000000:Fnj`2U_^/00`2U_^/00`000000Qdj608M>QP0708M>QP030000003o
ool0oooo00X0oooo00<000000:Fnj`2U_^/01@2U_^/010000000oooo0?ooo`00003G0?ooo`050000
003oool000000?ooo`000000202Y`^/00`000000oooo0?ooo`050?ooo`030000002Y`^/0ZL;[00@0
ZL;[00<000000:W2j`2Y`^/0102Y`^/500WZ2P80ZL;[2@0000020:W2j`80000000<02NX:00000009
jPX00P2>EXT00`000000oooo0?ooo`030?ooo`@0000000H02NX:0:W2j`2Y`^/0ZL;[0000002Y`^/2
000000<0ZL;[00@02NX:0000003f/7P000000`2>EXT6000000030?ooo`0000002NX:00802NX:0P00
000508iFR@8000000P2>EXT00`000000SUJ908iFR@0308iFR@030000002Y`^/0ZL;[0080ZL;[0`09
jPX00`2Y`^/0000000000002000000L0SUJ900@0000008iFR@2>EXT000001P2>EXT00`000000ZL;[
0:W2j`040:W2j`030000002>EXT0SUJ900P0SUJ900<000000?ooo`3oool01@3oool00`000000ZL;[
0:W2j`060:W2j`030000003oool0oooo0>d0oooo000A0?ooo`030000003oool0000000@0oooo00<0
00000:Fnj`2U_^/01`2U_^/00`000000oooo0?ooo`040?ooo`040000002U_^/0YKk[000000<02NX:
1`00000;0:Fnj`@02NX:0P2U_^/30000000308M>QP000000000000@0000000D0oooo00WZ2P09jPX0
2NX:0?ooo`0300000080YKk[1@0000000`09jPX000000?6_Q0020?6_Q00500000027CXH0Qdj608M>
QP0000000P2U_^/3000000<02NX:00@000000?ooo`000000Qdj60`0000000`27CXH0000000000006
00000080Qdj600@000000:Fnj`2U_^/000000`09jPX50:Fnj`0400000027CXH0Qdj600000080Qdj6
00<0000008M>QP27CXH01`27CXH00`000000YKk[0:Fnj`040:Fnj`0300000027CXH0Qdj600L0Qdj6
00<000000?ooo`3oool02`3oool00`000000YKk[0:Fnj`050:Fnj`<00000e`3oool00`000000oooo
000000020?ooo`030000002Y`^/0ZL;[00H0ZL;[00<000000?ooo`3oool01@3oool00`000000ZL;[
0:W2j`030:W2j`030000002Y`^/02NX:00802NX:2@0000090:W2j`@02NX:00<0SUJ90000002>EXT0
0P2>EXT00`000000oooo0000000300000080oooo0P0000050:W2j`<000000`09jPX01@2>EXT00000
0?J`N03f/7P000000080SUJ900<000000:W2j`0000000P00000200WZ2P040000003oool0oooo0?oo
o`8000000`2>EXT30000000308iFR@000000000000P000000`09jPX60:W2j`8000001`2>EXT01@00
0000SUJ908iFR@2>EXT0000000@0SUJ900<000000:W2j`2Y`^/01@2Y`^/00`000000SUJ908iFR@08
08iFR@030000003oool0oooo00H0oooo00<000000:W2j`2Y`^/01@2Y`^/00`000000oooo0?ooo`3]
0?ooo`004@3oool010000000oooo0?ooo`0000030?ooo`030000002U_^/0YKk[00P0YKk[00<00000
0?ooo`3oool00P3oool01009jPX0000000WZ2P09jPX4000000h0YKk[1009jPX60:Fnj`@000000`27
CXH01P0000002NX:00WZ2P09jPX0oooo000000@0oooo0`0000001@2U_^/000000000000000002NX:
0080Qdj600@000000?6_Q03a[h@000000`27CXH010000000YKk[00WZ2P09jPX3000000030?ooo`00
0000000000<000000P27CXH00`000000Qdj60000000208M>QP0500000027CXH0Qdj608M>QP000000
0P27CXH01@0000002NX:00WZ2P09jPX0000000H0YKk[00D0000008M>QP27CXH0Qdj60000000308M>
QP0300000027CXH0Qdj600H0Qdj600<000000:Fnj`2U_^/0102U_^/00`000000Qdj608M>QP0608M>
QP030000003oool0oooo00d0oooo00<000000:Fnj`2U_^/0102U_^/00`000000oooo0000003G0?oo
o`030000003oool000000080oooo00<000000:W2j`2Y`^/01`2Y`^/00`000000oooo0?ooo`030?oo
o`8000000P2Y`^/300WZ2PD000003P2Y`^/400WZ2P<0ZL;[00D0000008iFR@2>EXT0000008iFR@03
0000000300WZ2P3oool0oooo00D0oooo00<000000:W2j`0000000P0000000`09jPX0000000000005
08iFR@030000003f/7P000000080SUJ900<0000000WZ2P0000000P0000030?ooo`030000003oool0
oooo00D000000P2>EXT010000000SUJ900000000000608iFR@0300000009jPX0000000P0ZL;[00<0
000008iFR@2>EXT01`2>EXT010000000SUJ908iFR@00000408iFR@030000002Y`^/0ZL;[00D0ZL;[
00<0000008iFR@2>EXT01`2>EXT00`000000oooo0?ooo`080?ooo`030000002Y`^/0ZL;[00@0ZL;[
00<000000?ooo`3oool0k@3oool00180oooo00<000000?ooo`000000103oool00`000000YKk[0:Fn
j`080:Fnj`8000000P09jPX01@3oool000000000002U_^/0000000d0YKk[1009jPX50:Fnj`D00000
00<0YKk[0000000000000P27CXH300WZ2P80oooo00@000000?ooo`000000oooo0`0000001`3oool0
2NX:00000009jPX0000008M>QP0000000`27CXH01`000000lJn40?6_Q0000000Qdj600WZ2P27CXH0
0P0000020:Fnj`@000000`3oool00`000000Qdj608M>QP0208M>QP0500000027CXH0000008M>QP00
00001027CXH00`000000Qdj6000000030:Fnj`030000002U_^/0YKk[00<0YKk[00<0000008M>QP27
CXH00`27CXH010000000Qdj608M>QP00000708M>QP030000002U_^/0YKk[00D0YKk[00<0000008M>
QP27CXH01P27CXH00`000000oooo0?ooo`0>0?ooo`030000002U_^/0YKk[00@0YKk[0P00003G0?oo
o`060000003oool0oooo0000003oool000002P2Y`^/01@000000oooo0?ooo`3oool02NX:00800000
0P09jPX30:W2j`030000002Y`^/0ZL;[00/0ZL;[1@09jPX70:W2j`D0000000<02NX:0?ooo`3oool0
1`3oool4000000802NX:00<0SUJ90000000000001@2>EXT00`000000m[1h0000000208iFR@030000
002Y`^/0ZL;[00P0000000<02NX:0000002>EXT01@2>EXT00`000000SUJ90000000608iFR@<00000
202Y`^/00`000000SUJ908iFR@0708iFR@050000002>EXT0SUJ908iFR@0000000`2>EXT00`000000
ZL;[0:W2j`050:W2j`030000002>EXT0SUJ900L0SUJ900<000000?ooo`3oool02@3oool00`000000
ZL;[0:W2j`030:W2j`030000003oool0oooo0>d0oooo000B0?ooo`030000003oool0000000@0oooo
00<000000:Fnj`2U_^/01`2U_^/00`09jPX00000000000040?ooo`040000002U_^/0YKk[000000P0
YKk[1009jPX40:Fnj`D000001P2U_^/01009jPX0000000WZ2P09jPX208M>QP030000003oool0oooo
00@0000000D0oooo00WZ2P09jPX02NX:0?ooo`020000000308M>QP000000000000<0Qdj600D00000
0?6_Q03a[h@0lJn40000000208M>QP@000000P2U_^/3000000802NX:00<0000008M>QP27CXH00P27
CXH01@000000Qdj600000027CXH0000000@0Qdj600<0000008M>QP0000000`2U_^/00`000000YKk[
0:Fnj`030:Fnj`0300000027CXH0Qdj600<0Qdj600@0000008M>QP27CXH000001`27CXH00`000000
YKk[0:Fnj`050:Fnj`0300000027CXH0Qdj600H0Qdj600<000000?ooo`3oool03`3oool00`000000
YKk[0:Fnj`030:Fnj`800000f03oool00`000000oooo000000020?ooo`030000002Y`^/0ZL;[00H0
ZL;[00<02NX:0000000000000P09jPX00`3oool00000000000050:W2j`030000002Y`^/0ZL;[00L0
ZL;[1009jPX70:W2j`D000000`09jPX00`000000SUJ9000000060?ooo`<0000000@0oooo00WZ2P09
jPX000000`2>EXT3000000@0SUJ900H000000?J`N03f/7P0000008iFR@0000020:W2j`H000000P09
jPX2000000H0SUJ900<0000008iFR@0000001P2>EXT00`000000ZL;[000000080:W2j`030000002>
EXT0SUJ900L0SUJ900<0000008iFR@2>EXT00`0000000`2>EXT000000:W2j`070:W2j`030000002>
EXT0SUJ900L0SUJ900<000000?ooo`3oool02@3oool00`000000ZL;[0:W2j`030:W2j`800000kP3o
ool00180oooo0`0000050?ooo`040000002U_^/0YKk[0:Fnj`D02NX:0`2U_^/00`000000oooo0?oo
o`020?ooo`030000002U_^/0000000@0YKk[1009jPX40:Fnj`@00000202U_^/300WZ2P030:Fnj`00
0000000000<0Qdj61@00000300WZ2P@0oooo00<0000008M>QP0000000P00000408M>QP040000003a
[h@0lJn400000080Qdj60P0000050:Fnj`<0000000<0oooo00000027CXH01@0000000`27CXH00000
000000030000000408M>QP000000Qdj6000000<0YKk[00<000000:Fnj`2U_^/00P2U_^/00`000000
Qdj608M>QP0408M>QP0300000027CXH0Qdj6008000001@27CXH00`000000YKk[0:Fnj`060:Fnj`03
00000027CXH0Qdj600H0Qdj600<000000?ooo`3oool0403oool00`000000YKk[0:Fnj`020:Fnj`80
0000f03oool00`000000oooo000000020?ooo`030000002Y`^/0ZL;[00<0ZL;[0`09jPX0102Y`^/0
00000000000000020?ooo`8000001@2Y`^/00`000000ZL;[0:W2j`030:W2j`@02NX:1@2Y`^/60000
00040:W2j`09jPX02NX:00WZ2P80ZL;[0`0000000`2>EXT000000?ooo`020?ooo`<0000000@0oooo
00WZ2P09jPX02NX:0P3oool010000000SUJ908iFR@2>EXT3000000D0SUJ900<000000?J`N03f/7P0
0P0000020:W2j`030000002Y`^/02NX:0080000000D0oooo0000003oool0oooo0000000208iFR@h0
000000<0ZL;[0000002Y`^/01P2Y`^/00`000000SUJ908iFR@0908iFR@8000000P2>EXT00`000000
SUJ9000000080:W2j`030000002>EXT0SUJ900L0SUJ900<000000?ooo`3oool02P3oool00`000000
ZL;[000000030:W2j`030000003oool0oooo0>`0oooo000B0?ooo`030000003oool0000000D0oooo
00@02NX:00000009jPX02NX:2@2U_^/200000080oooo00<000000:Fnj`0000001009jPX30:Fnj`D0
0000202U_^/400WZ2PD0YKk[1@0000020?ooo`802NX:00<0oooo0000003oool00`3oool300000003
08M>QP000000000000@0Qdj600X000000?6_Q03a[h@0lJn400000027CXH000000:Fnj`000000YKk[
0P09jPX7000000@0Qdj600<0000008M>QP0000001027CXH4000000@0YKk[00D000000:Fnj`2U_^/0
YKk[0000000708M>QP80000000<0Qdj600000027CXH01027CXH00`000000YKk[0:Fnj`060:Fnj`03
00000027CXH0Qdj600H0Qdj600<000000?ooo`3oool04@3oool00`000000YKk[000000020:Fnj`03
0000003oool0oooo0=H0oooo0`0000030?ooo`8000000`09jPX70:W2j`8000000P2>EXT00`000000
ZL;[0:W2j`030:W2j`0300000009jPX02NX:00802NX:0`2Y`^/6000000<0ZL;[1009jPX60:W2j`04
0000002>EXT000000?ooo`<000001009jPX50?ooo`L000001@2>EXT00`000000m[1h0?J`N0020000
00040:W2j`09jPX02NX:000000<0ZL;[1`00000508iFR@030000002>EXT0000000D0SUJ910000005
0:W2j`8000002`2>EXT00`000000SUJ908iFR@0208iFR@800000202Y`^/00`000000SUJ908iFR@07
08iFR@030000003oool0oooo00/0oooo00<000000:W2j`2Y`^/00P2Y`^/00`000000oooo0?ooo`3/
0?ooo`004P3oool00`000000oooo000000020?ooo`<02NX:00<0oooo000000000000302U_^/01`00
0000oooo0000000000002NX:0000002U_^/01@00000:0:Fnj`<02NX:1`2U_^/6000000<02NX:00@0
oooo0000003oool0oooo100000000`3oool0000008M>QP0208M>QP8000001027CXH010000000lJn4
0?6_Q03a[h@2000000802NX:0`0000020:Fnj`040000002U_^/0YKk[000000H0Qdj60`00000508M>
QP8000000`2U_^/5000000P0Qdj600D0000008M>QP27CXH0Qdj60000000308M>QP/000001`27CXH0
0`000000oooo0?ooo`0C0?ooo`030000002U_^/0YKk[00800000f03oool00`000000oooo00000002
0?ooo`0300WZ2P000000000000X0ZL;[0P00000208iFR@030000002Y`^/02NX:00<02NX:00<00000
0:W2j`2Y`^/01@0000050:W2j`@02NX:2P2Y`^/4000000<02NX:1`3oool3000000<0SUJ900@00000
08iFR@00000000001@2>EXT01@000000m[1h0?J`N00000002NX:0080ZL;[00<000000:W2j`000000
100000000`09jPX0000008iFR@0608iFR@80000000<0SUJ90000002>EXT00`2>EXT:000000d0SUJ9
00@0000008iFR@2>EXT0SUJ91@0000040:W2j`800000202>EXT00`000000oooo0?ooo`0=0?ooo`03
0000002Y`^/0ZL;[00800000kP3oool00180oooo00<000000?ooo`0000000P09jPX60?ooo`030000
002U_^/0YKk[00L0YKk[0P09jPX4000000030:Fnj`000000000000/0YKk[1009jPX70:Fnj`<00000
0P2U_^/01@0000002NX:00WZ2P09jPX0000000@0oooo0`0000030?ooo`0400WZ2P000000Qdj608M>
QP<000001027CXH010000000lJn40?6_Q03a[h@200000080YKk[00<000000:Fnj`2U_^/00`2U_^/0
0`0000002NX:0000000308M>QPD0000000<0Qdj60000000000001027CXH4000000050?ooo`000000
oooo0?ooo`0000002@27CXH01@000000Qdj608M>QP27CXH000000080Qdj600<000000?ooo`3oool0
1`3oool00`000000Qdj608M>QP0508M>QP030000003oool0oooo01@0oooo0P0000000`3oool00000
0?ooo`3G0?ooo`030000003oool0000000802NX:0P3oool00`000000ZL;[0:W2j`080:W2j`0600WZ
2P000000000000WZ2P0000002NX:102Y`^/3000000L0ZL;[0`09jPX;0:W2j`<000000P09jPX00`00
00002NX:000000060?ooo`<000000P09jPX00`000000SUJ908iFR@0208iFR@<000001@2>EXT01000
0000m[1h0?J`N00000040:W2j`040000002Y`^/0ZL;[00WZ2P@00000102>EXT60000000:08iFR@00
000000000000002>EXT000000?ooo`000000oooo000000@0oooo00<0000008iFR@2>EXT02`2>EXT0
10000000SUJ908iFR@2>EXT2000000<0oooo100000000`3oool0000008iFR@0708iFR@030000003o
ool0oooo00h0oooo0P0000000`3oool000000?ooo`3]0?ooo`004@3oool01009jPX0000000WZ2P00
00090?ooo`030000002U_^/0YKk[00<0YKk[0`09jPX20:Fnj`<0000000<0Qdj60000000000002@2U
_^/300WZ2PL0YKk[100000030:Fnj`802NX:00D0000008M>QP27CXH000000:Fnj`05000000030?oo
o`0000002NX:00802NX:00D0oooo000000000000000008M>QP02000000D0Qdj600@000000?6_Q03a
[h@0lJn40`000000102U_^/000000:Fnj`2U_^/200WZ2PH000000`27CXH20000000308M>QP000000
Qdj600<0000000<0Qdj60000000000000`3oool00`000000oooo0000000;08M>QP0600000027CXH0
Qdj600000027CXH000002P3oool00`000000Qdj608M>QP0508M>QP030000003oool0oooo01@0oooo
00@000000?ooo`3oool00000e`3oool01@09jPX0000000WZ2P3oool0000000<0oooo00<000000:W2
j`2Y`^/01@2Y`^/300WZ2P050:W2j`000000000008iFR@0000001@2Y`^/00`000000ZL;[0:W2j`03
0:W2j`@02NX:2`2Y`^/3000000<02NX:0P2>EXT010000000ZL;[0000000000020?ooo`<000000`09
jPX20?ooo`030000002>EXT0000000D000001P2>EXT010000000m[1h0?J`N00000030:W2j`040000
0009jPX02NX:0:W2j`P000000`2>EXT01@000000SUJ90000002>EXT000000080SUJ9100000020?oo
o`040000003oool0oooo000000l0SUJ900D0000008iFR@000000oooo000000060?ooo`030000003o
ool0000000P0SUJ900<000000?ooo`3oool03P3oool010000000oooo0?ooo`00003^0?ooo`003`3o
ool200WZ2P050?ooo`000000oooo0?ooo`000000203oool3000000<02NX:202U_^/00`000000Qdj6
000000050:Fnj`@02NX:1`2U_^/3000000@0YKk[0`09jPX308M>QP0300000027CXH0000000D00000
0`09jPX20?ooo`<000001027CXH2000000D0Qdj600@000000?6_Q03a[h@000000P2U_^/200000005
00WZ2P00000000000000002U_^/00P00000608M>QP0500000027CXH0000008M>QP0000000`27CXH3
00000080oooo1000000;08M>QP0400000027CXH0Qdj608M>QP8000002P3oool00`000000Qdj608M>
QP0408M>QP030000003oool0oooo01D0oooo00@000000?ooo`3oool00000e03oool300WZ2P80oooo
00<000000?ooo`000000103oool010000000ZL;[0:W2j`2Y`^/300WZ2PH0ZL;[00<0000008iFR@00
0000102Y`^/00`000000ZL;[00WZ2P0300WZ2P/0ZL;[1000000300WZ2PD0SUJ90P000000102Y`^/0
000000000000000300WZ2PD0oooo0P00000308iFR@040000002>EXT00000000000D0SUJ900<00000
0?J`N03f/7P00P00000200WZ2P030:W2j`00000000000080000000<0ZL;[0000000000001P2>EXT0
1`000000SUJ908iFR@2>EXT0000008iFR@0000000P2>EXT900000100SUJ900@000000?ooo`3oool0
00001P3oool00`000000oooo0000000708iFR@030000003oool0oooo00l0oooo00@000000?ooo`3o
ool00000kP3oool000`0oooo0`09jPX40?ooo`030000003oool0000000P0oooo0`09jPX<0:Fnj`80
00000P2U_^/300WZ2PL0YKk[100000030:Fnj`@02NX:1@27CXH4000000030:Fnj`09jPX02NX:0080
2NX:00<000000?ooo`0000000P0000000`3oool0000008M>QP0408M>QP<000001027CXH01@000000
lJn40?6_Q03a[h@0000000802NX:0P0000000`2U_^/0000000000003000000H0Qdj600D0000008M>
QP000000Qdj60000000308M>QPD0000000<0oooo0000000000003@27CXH00`000000Qdj600000008
000000@0oooo00<0000008M>QP27CXH01027CXH00`000000oooo0?ooo`0E0?ooo`030000003oool0
00000=80oooo0`09jPX50?ooo`030000003oool0000000D0oooo00<0000000WZ2P09jPX02P2Y`^/0
0`000000SUJ9000000020:W2j`802NX:00<000000:W2j`2Y`^/02P2Y`^/3000000040:W2j`09jPX0
2NX:00WZ2PP0SUJ91000000200WZ2PD0oooo0`00000508iFR@030000002>EXT0000000800000102>
EXT010000000m[1h0?J`N03f/7P2000000030:W2j`000000000000<000000P2Y`^/00`000000SUJ9
08iFR@0408iFR@070000002>EXT0SUJ908iFR@000000SUJ90000000208iFR@030000003oool00000
0080oooo0`00000A08iFR@D000001@3oool00`000000oooo0000000708iFR@030000003oool0oooo
00l0oooo00@000000?ooo`3oool00000kP3oool000T0oooo0`09jPX70?ooo`030000003oool00000
00D0oooo0`09jPX20?ooo`030000002U_^/0YKk[00X0YKk[0`0000000`09jPX0YKk[0:Fnj`050:Fn
j`<00000102U_^/300WZ2PH0Qdj60`0000001@27CXH0000008M>QP0000002NX:00@0YKk[0P000000
1@3oool000000?ooo`3oool0000000<0Qdj60P0000000`27CXH000000000000508M>QP050000003a
[h@0lJn40?6_Q00000000P2U_^/010000000YKk[0:Fnj`2U_^/@0000000908M>QP00000000000?oo
o`000000oooo0000003oool0000000h0Qdj60P0000000`3oool000000?ooo`050?ooo`D000001P27
CXH00`000000oooo0?ooo`0D0?ooo`040000003oool0oooo00000<l0oooo0`09jPX80?ooo`030000
003oool000000080oooo0`09jPX2000000`0ZL;[0`0000000`09jPX0ZL;[0:W2j`02000000L0ZL;[
10000000102Y`^/02NX:00WZ2P09jPX808iFR@D00000102Y`^/00`000000oooo0?ooo`0200000080
oooo00<0000008iFR@2>EXT00`2>EXT20000000308iFR@000000000000D0SUJ900D000000?J`N03f
/7P0m[1h000000030:W2j`80000000<0ZL;[0000000000003@0000001P2>EXT00000000000000000
oooo000000<0oooo0P00000@08iFR@030000003oool0000000H000000P3oool00`000000oooo0000
000708iFR@030000003oool0oooo00l0oooo00@000000?ooo`3oool00000kP3oool000H0oooo0`09
jPX:0?ooo`030000003oool000000080oooo0`09jPX60?ooo`030000002U_^/0YKk[00H0YKk[0`09
jPX4000000<0YKk[100000030:Fnj`@02NX:1P27CXH3000000D0Qdj60P0000030:Fnj`80000000@0
YKk[00000000000000000P09jPX010000000Qdj600000000000308M>QP<000001027CXH01@000000
lJn40?6_Q03a[h@0000000<0YKk[0`0000020:Fnj`8000001027CXH00`000000Qdj608M>QP0308M>
QP0300000027CXH000000080000000<0oooo0000000000000P00000?08M>QP8000000P3oool00`00
0000oooo0?ooo`070?ooo`0300000027CXH0Qdj600<0Qdj600<000000?ooo`3oool05@3oool01000
0000oooo00000000003<0?ooo`<02NX:2`3oool01@000000oooo00WZ2P0000002NX:00D0oooo00<0
00000:W2j`2Y`^/0202Y`^/200WZ2P<000000P2Y`^/00`000000ZL;[0:W2j`030:W2j`<000000P2Y
`^/300WZ2PP0SUJ90`00000308iFR@030000002Y`^/0000000@0ZL;[0`00000300WZ2P040000002>
EXT0SUJ908iFR@80000000@0SUJ90000002>EXT0SUJ90P00000508iFR@040000003f/7P0m[1h0000
00@0ZL;[0`000000103oool0000008iFR@00000408iFR@030000002>EXT0SUJ900<0SUJ90P000000
0`2>EXT000000000000600000100SUJ900<000000?ooo`0000000`3oool00`000000oooo0?ooo`03
000000030?ooo`000000SUJ900D0SUJ900<000000?ooo`3oool0403oool010000000oooo00000000
003^0?ooo`001@3oool00`09jPX0oooo0?ooo`0;0?ooo`<000000P09jPX:0?ooo`030000002U_^/0
YKk[00<0YKk[0P09jPX50:Fnj`0300000027CXH0000000800000102U_^/300WZ2PP0Qdj60P000008
08M>QPD00000102U_^/200WZ2P@000001@27CXH3000000@0Qdj600<000000?6_Q03a[h@00P3a[h@0
10000000YKk[0:Fnj`0000040:Fnj`h0000000<0Qdj60000000000000P0000000`3oool0000008M>
QP0>08M>QP030000003oool0000000@00000203oool00`000000Qdj608M>QP0308M>QP030000003o
ool0oooo01D0oooo0P0000000`3oool000000?ooo`380?ooo`<02NX:3@3oool200WZ2P<000001`3o
ool00`000000ZL;[0:W2j`030:W2j`@02NX:0`2Y`^/2000000<0ZL;[00<000000:W2j`0000000P00
00020:W2j`<02NX:2@2>EXT2000000H0SUJ900@000000:W2j`000000ZL;[0`000000102Y`^/00000
00WZ2P0000020?ooo`040000002>EXT00000000000<0SUJ900<0000008iFR@0000000P00000508iF
R@050000003f/7P0m[1h0?J`N00000000`2Y`^/200000080oooo00<0000008iFR@0000003P000000
0`3oool00000000000020000000308iFR@000000SUJ900h0SUJ90P0000020?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`0000001P2>EXT00`000000oooo0?ooo`0@0?ooo`80000000<0
oooo0000003oool0k@3oool00180oooo00@02NX:00000009jPX000003@3oool2000000<02NX:1`2U
_^/20000000408M>QP000000YKk[0:Fnj`<02NX:2027CXH3000000X0Qdj60P0000040:Fnj`<02NX:
00<0YKk[0000000000000P00000408M>QP80000000@0Qdj600000027CXH000001027CXH00`000000
lJn40?6_Q0020?6_Q0050000002U_^/0YKk[0000002U_^/00`00000208M>QP0300000027CXH00000
00L0Qdj60`0000000`3oool0000000000002000000h0Qdj600D000000?ooo`3oool0oooo00000002
0?ooo`H000000`3oool00`000000Qdj608M>QP0308M>QP030000003oool0oooo01D0oooo00@00000
0?ooo`3oool00000b03oool00`09jPX0oooo0?ooo`0<0?ooo`802NX:0P3oool00`000000oooo0000
00080?ooo`030000002Y`^/02NX:00802NX:202Y`^/200000080ZL;[0P0000020:W2j`<02NX:2@2>
EXT3000000T0SUJ90`000000102Y`^/02NX:00WZ2P09jPX30:W2j`@000001@2>EXT20000000308iF
R@000000000000D0SUJ90P0000030?J`N0060000002Y`^/000000?ooo`000000oooo0`00000208iF
R@030000002>EXT0000000L0SUJ900<0000008iFR@0000001`00000>08iFR@030000003oool0oooo
00D0000000<0oooo0000003oool00P3oool00`000000oooo0000000608iFR@030000003oool0oooo
0100oooo00@000000?ooo`3oool00000kP3oool000l0oooo0`09jPX0103oool000000?ooo`00000<
0?ooo`0300WZ2P000000000000X0YKk[00@000000:Fnj`00000000000P09jPX808M>QP<000002`27
CXH20000000408M>QP000000YKk[0:Fnj`802NX:0P2U_^/2000000<0YKk[00<0000008M>QP27CXH0
0P00000308M>QP80000000<0Qdj600000027CXH00P27CXH2000000@0lJn40P0000001@2U_^/00000
0000003oool000000080Qdj62000000308M>QPD000000P27CXH00`000000Qdj608M>QP0;08M>QP<0
000000<0oooo0000003oool00P3oool00`000000oooo0?ooo`020?ooo`<000001@27CXH00`000000
oooo0?ooo`0F0?ooo`040000003oool0oooo00000=@0oooo0`09jPX40?ooo`030000003oool00000
00L0oooo0P09jPX00`000000ZL;[0:W2j`0:0:W2j`@000000`09jPX:08iFR@8000002`2>EXT20000
000300WZ2P0000002NX:00D0ZL;[0P0000000`2Y`^/0000008iFR@0308iFR@8000000P2>EXT01000
0000SUJ900000000000408iFR@030000002Y`^/0000000<0m[1h00L000000?ooo`3oool0oooo0000
003oool0000000<0SUJ92000000308iFR@D00000102>EXT00`000000SUJ908iFR@0:08iFR@030000
003oool0oooo00@0oooo00<000000?ooo`0000000`000000103oool000000?ooo`00000508iFR@03
0000003oool0oooo0140oooo00<000000?ooo`000000k`3oool000`0oooo0`09jPX50?ooo`030000
003oool0000000P0oooo0`09jPX30?ooo`030000002U_^/0YKk[00P0YKk[00<0000000WZ2P000000
0P00000508M>QP<000003027CXH2000000<0Qdj60P0000000`09jPX0YKk[0:Fnj`02000000D0YKk[
0`00000608M>QP<000000`27CXH2000000H0lJn400<000000?ooo`000000200000030?6_Q0/00000
00<0Qdj600000027CXH02P27CXH200000080oooo0`0000020?ooo`8000001@3oool00`000000Qdj6
08M>QP0308M>QP030000003oool0oooo01H0oooo00<000000?ooo`000000dP3oool300WZ2PL0oooo
00@000000?ooo`3oool000000`3oool300WZ2P<0oooo00<000000:W2j`2Y`^/0202Y`^/200WZ2P04
00000009jPX02NX:000000T0SUJ90`00000;08iFR@80000000D0SUJ90000002Y`^/0ZL;[00000003
0:W2j`80000000@0ZL;[00WZ2P09jPX000000P2>EXT2000000D0SUJ91000000308iFR@030000002Y
`^/0000000@0m[1h0`0000000`3oool000000000000500000080m[1h00@000000?ooo`3oool0oooo
2`0000000`2>EXT0000008iFR@0:08iFR@<000001@3oool00`000000oooo0?ooo`02000000050?oo
o`00000000000?ooo`0000001@2>EXT00`000000oooo0?ooo`0@0?ooo`040000003oool0oooo0000
0>l0oooo000:0?ooo`802NX:203oool00`000000oooo000000040?ooo`@02NX:1`3oool00`000000
YKk[0:Fnj`040:Fnj`<02NX:00@0000008M>QP00000000001027CXH2000000`0Qdj60`00000608M>
QP040000002U_^/00000000000D0YKk[00<02NX:0000000000001P27CXH200000080Qdj60P000002
08M>QP030000003oool0000000H0lJn4100000000`3oool000000000000D000000T0Qdj60`000005
0?ooo`@000001@3oool00`000000Qdj608M>QP0308M>QP030000003oool0oooo01D0oooo00@00000
0?ooo`3oool00000c`3oool300WZ2P/0oooo00<000000?ooo`0000000`09jPX70?ooo`030000002Y
`^/0ZL;[00@0ZL;[0`09jPX208iFR@80000000<0SUJ90000002>EXT01@2>EXT3000000`0SUJ90P00
000408iFR@040000002Y`^/000000:W2j`80000000<0ZL;[00WZ2P09jPX00P2Y`^/3000000H0SUJ9
0`0000000`2>EXT000000000000208iFR@040000002Y`^/00000000000D0m[1h00<000000?ooo`00
00000P0000000`3oool000000000000A0000000408iFR@0000000000000000T0SUJ900@000000?oo
o`3oool0oooo100000020?ooo`80000000L0oooo0000003oool0oooo0000003oool0000000D0SUJ9
00<000000?ooo`3oool0403oool010000000oooo00000000003_0?ooo`00503oool010000000oooo
0000003oool300WZ2P`0oooo0`00000300WZ2P<0Qdj600D0000008M>QP000000000008M>QP030000
00`0Qdj60P00000908M>QP8000001@2U_^/01@09jPX000000000002U_^/0000000@0Qdj60P000004
08M>QP<0000000<0Qdj60000000000000`0000060?6_Q0D000000`3a[h@B000000L0Qdj60P000002
0?ooo`<000000P3oool010000000oooo0?ooo`3oool300000080oooo00<0000008M>QP27CXH00P27
CXH00`000000oooo0?ooo`0F0?ooo`040000003oool0000000000<h0oooo00<02NX:0?ooo`3oool0
303oool00`0000002NX:0000000;0?ooo`030000002Y`^/0ZL;[00<02NX:1@2>EXT20000000308iF
R@000000SUJ900<0SUJ90P00000=08iFR@8000001P2>EXT01@000000ZL;[000000000000ZL;[0080
2NX:0`2Y`^/2000000L0SUJ900@0000008iFR@2>EXT0SUJ9100000000`2>EXT00000000000020?oo
o`030000003f/7P0m[1h00<0m[1h1P0000030?J`N140000000<0SUJ90000000000001`2>EXT30000
00H0oooo0`0000030?ooo`050000003oool000000?ooo`000000102>EXT00`000000oooo0?ooo`0A
0?ooo`80000000<0oooo0000003oool0kP3oool001@0oooo00@0000000WZ2P0000002NX:3P3oool2
00WZ2P0300000009jPX0Qdj600H0Qdj61000000=08M>QP8000002@27CXH20000000308M>QP000000
YKk[0080YKk[00<02NX:0000000000000`2U_^/00`000000Qdj608M>QP02000000@0Qdj60P000002
08M>QP<000000P2U_^/3000000P0lJn400<000000?6_Q00000000P0000000`3a[h@000000000000>
0000000308M>QP000000Qdj600@0Qdj60`0000050?ooo`@000000`3oool00`000000oooo00000002
000000@0Qdj600<000000?ooo`3oool05P3oool2000000030?ooo`000000oooo0=T0oooo0`09jPX0
0`000000oooo0000000;0?ooo`0300WZ2P0000002NX:00P0SUJ90P00000208iFR@@000003@2>EXT2
000000T0SUJ900@000000:W2j`0000002NX:0`2Y`^/2000000030:W2j`000000SUJ900@0SUJ90P00
000308iFR@80000000<0SUJ90000000000000P0000030?ooo`800000203f/7P00`000000m[1h0000
000E0000000308iFR@000000SUJ900@0SUJ900@000000?ooo`3oool0oooo0`0000060?ooo`<00000
00D0oooo0000003oool0oooo0000000408iFR@030000003oool0oooo0140oooo00@000000?ooo`3o
ool00000k`3oool00140oooo0`09jPX0103oool000000?ooo`00000;0?ooo`<02NX:0P3oool00`00
0000Qdj608M>QP0608M>QP<000003027CXH2000000<0Qdj600<02NX:08M>QP27CXH01027CXH01000
0000Qdj608M>QP27CXH20000000300WZ2P000000000000D0YKk[0`00000508M>QP0300000027CXH0
Qdj60080Qdj6100000020:Fnj`030000003oool0000000P0lJn42@0000040?ooo`/000000`27CXH3
000000030?ooo`000000000000H0oooo0P0000030?ooo`040000003oool0oooo000000@0Qdj600<0
00000?ooo`3oool05P3oool010000000oooo0?ooo`00003G0?ooo`<02NX:0`3oool010000000oooo
0?ooo`0000070?ooo`<02NX:0P00000908iFR@8000000P2>EXT00`000000SUJ908iFR@0<08iFR@80
00002@2>EXT30000000400WZ2P2Y`^/000000:W2j`8000000`2Y`^/010000000SUJ908iFR@2>EXT2
000000@0SUJ900<0000008iFR@2>EXT00P2>EXT3000000030?ooo`00000000000080oooo00<00000
0?J`N03f/7P01P3f/7P8000000H0oooo3000000308iFR@@00000103oool3000000@0oooo00<00000
0?ooo`0000000P0000000`3oool0000008iFR@0308iFR@030000003oool0oooo0140oooo00<00000
0?ooo`000000l03oool000l0oooo0P09jPX40?ooo`<00000203oool300WZ2PD0oooo00<0000008M>
QP27CXH01P27CXH3000000X0Qdj60P00000208M>QP802NX:1P27CXH2000000D0Qdj60P0000060:Fn
j`8000001@27CXH2000000@0Qdj600D000000:Fnj`2U_^/000000:Fnj`04000000030?ooo`000000
lJn400X0lJn40P00000=0?ooo`H0000000<0Qdj60000000000000P3oool2000000040?ooo`000000
0000000000D0oooo1@0000000`3oool0000008M>QP0208M>QP030000003oool0oooo01L0oooo00<0
00000?ooo`000000e@3oool300WZ2PL0oooo0`0000040?ooo`<02NX:103oool00`000000SUJ908iF
R@0708iFR@8000000P2>EXT00`000000SUJ908iFR@0;08iFR@030000002>EXT0SUJ900L0SUJ90P00
000308iFR@040000002Y`^/00000000000D0ZL;[00@0000008iFR@0000000000102>EXT2000000@0
SUJ900<000000:W2j`0000000P0000030?ooo`8000002`3f/7P200000100oooo1P000000102>EXT0
00000000000000020?ooo`<00000103oool300000080oooo00<000000?ooo`0000000`00000308iF
R@030000003oool0oooo0140oooo00@000000?ooo`3oool00000l03oool001D0oooo00<000000?oo
o`000000103oool400WZ2PP0oooo00<0000008M>QP27CXH01`27CXH2000000P0Qdj60P00000308M>
QP0300WZ2P27CXH0Qdj600@0Qdj60P00000608M>QP<00000102U_^/2000000030:Fnj`000000Qdj6
0080Qdj60P00000408M>QP8000000`2U_^/500000080oooo0`0000080?6_Q08000004P3oool40000
00030?ooo`00000000000080oooo0P0000020?ooo`800000103oool6000000<0Qdj600<000000?oo
o`3oool05P3oool010000000oooo00000000003C0?ooo`802NX:2P3oool010000000oooo0000003o
ool300WZ2PL0oooo00<0000008iFR@2>EXT01`2>EXT2000000<0SUJ900<0000008iFR@2>EXT0202>
EXT2000000T0SUJ900<0000008iFR@2>EXT00`2>EXT2000000030:W2j`000000ZL;[00@0ZL;[0P00
000408iFR@800000102>EXT2000000030:W2j`000000000000D0000000@0oooo0000000000000000
203f/7P00`000000oooo0?ooo`0B0?ooo`H000000P3oool2000000<0oooo0P0000050?ooo`D00000
0P3oool01@000000SUJ908iFR@2>EXT0000001<0oooo00@000000?ooo`0000000000l03oool001H0
oooo00<000000?ooo`0000000`09jPX<0?ooo`0300000027CXH0Qdj600L0Qdj60P00000508M>QP<0
00002P27CXH2000000H0Qdj60P00000208M>QP80000000<0YKk[0000000000000P2U_^/00`000000
Qdj608M>QP02000000D0Qdj600@000000:Fnj`2U_^/0YKk[0P0000020:Fnj`X000001@3a[h@00`00
0000oooo0?ooo`0C0?ooo`@000000P3oool010000000oooo0?ooo`3oool3000000030?ooo`000000
00000080oooo00D000000?ooo`3oool0oooo0000000308M>QP030000003oool0oooo01L0oooo0P00
00000`3oool000000?ooo`3N0?ooo`0400000009jPX02NX:000000X0oooo00<0000008iFR@2>EXT0
1`2>EXT2000000<0SUJ900<0000008iFR@2>EXT01P2>EXT2000000T0SUJ90P00000608iFR@800000
0P2Y`^/010000000ZL;[0:W2j`2Y`^/2000000<0SUJ90P00000408iFR@8000000P2Y`^/200000003
0?ooo`000000000000T00000103f/7P2000001L0oooo1P0000020?ooo`<000000P3oool3000000D0
oooo0P0000020?ooo`8000000P2>EXT00`000000oooo0?ooo`0A0?ooo`80000000<0oooo0000003o
ool0k`3oool001H0oooo00<0000000WZ2P0000003`3oool00`000000Qdj608M>QP0708M>QP800000
0`27CXH2000000/0Qdj60P00000708M>QP0300000027CXH0Qdj60080Qdj60`0000040:Fnj`<00000
1@27CXH2000000<0YKk[00H000000:Fnj`2U_^/0YKk[0000003oool700000080oooo1@00000H0?oo
o`@0000000<0oooo000000000000103oool2000000030?ooo`0000000000008000000P3oool20000
0080Qdj600<000000?ooo`3oool05`3oool00`000000oooo0000003N0?ooo`<02NX:00<000000?oo
o`0000002P3oool00`000000SUJ908iFR@0708iFR@800000102>EXT00`000000SUJ908iFR@0308iF
R@8000002P2>EXT00`000000SUJ908iFR@0408iFR@80000000H0SUJ90000002Y`^/0ZL;[0000002Y
`^/2000000030:W2j`000000SUJ9008000001@2>EXT010000000ZL;[0:W2j`2Y`^/2000000030?oo
o`00000000000080oooo1@0000030?ooo`@000006`3oool700000080oooo0P0000030?ooo`<00000
00P0oooo0000003oool0oooo0000003oool0000008iFR@800000503oool010000000oooo0?ooo`00
003`0?ooo`00503oool200WZ2P030000003oool0000000d0oooo0P09jPX00`000000Qdj608M>QP07
08M>QP80000000<0Qdj60000000000003027CXH00`000000Qdj608M>QP0608M>QP0300000027CXH0
Qdj600<0Qdj60`0000040:Fnj`0300000027CXH0Qdj600@0Qdj600@000000:Fnj`2U_^/0YKk[0P00
00020:Fnj`<0000000<0oooo0000003oool01000000R0?ooo`@0000000<0oooo000000000000103o
ool200000080oooo0P0000001P3oool0000008M>QP000000Qdj6000001P0oooo00@000000?ooo`3o
ool00000f`3oool300WZ2P<0oooo00<000000?ooo`0000001`3oool300WZ2P030000002>EXT0SUJ9
00L0SUJ900<000000:W2j`0000000`2>EXT010000000SUJ908iFR@2>EXT2000000X0SUJ90P000006
08iFR@030000002>EXT0SUJ90080SUJ900@000000:W2j`00000000000`2Y`^/2000000D0SUJ90P00
00030:W2j`80000000<0oooo0000000000000P3oool4000002H0oooo0`0000020?ooo`8000000P3o
ool2000000@0oooo00<000000?ooo`3oool00P3oool20000000308iFR@000000000001@0oooo00<0
00000?ooo`000000l@3oool001L0oooo00<000000?ooo`0000002@3oool300WZ2P80oooo00<00000
08M>QP27CXH01`27CXH3000000`0Qdj60P00000708M>QP8000001@27CXH00`000000Qdj608M>QP02
000000040:Fnj`0000000000000000@0Qdj60P0000020:Fnj`8000000`2U_^/00`000000YKk[0000
0006000002D0oooo1@0000000`3oool00000000000040?ooo`80000000D0oooo0000000000000000
08M>QP03000001P0oooo0`00003J0?ooo`802NX:1P3oool010000000oooo0?ooo`0000030?ooo`<0
2NX:0`3oool00`000000SUJ908iFR@0708iFR@030000002Y`^/0000000<0SUJ900@0000008iFR@00
000000002P2>EXT2000000L0SUJ900<0000008iFR@2>EXT0102>EXT01@000000ZL;[0:W2j`000000
ZL;[008000001@2>EXT010000000ZL;[0:W2j`2Y`^/3000000030?ooo`000000000000H00000:@3o
ool300000080oooo0P0000020?ooo`80000000<0oooo0000003oool01@3oool2000000030?ooo`00
0000oooo0180oooo00@000000?ooo`0000000000l@3oool001L0oooo00<000000?ooo`0000001P3o
ool300WZ2PD0oooo00<0000008M>QP27CXH01`27CXH00`0000002NX:0000000:08M>QP8000002027
CXH00`000000Qdj608M>QP0408M>QP0300000027CXH0Qdj60080Qdj60P0000020:Fnj`0500000027
CXH0Qdj608M>QP0000000`2U_^/00`000000YKk[0:Fnj`020:Fnj`030000002U_^/0YKk[00H00000
:03oool400000080oooo00<000000?ooo`3oool00P3oool200000080oooo0P0000030?ooo`030000
003oool0oooo01@0oooo0P0000000`3oool000000?ooo`3R0?ooo`030000003oool0000000<02NX:
1P3oool00`000000SUJ908iFR@0708iFR@0300000009jPX0000000@0SUJ900<0000008iFR@2>EXT0
2@2>EXT00`000000SUJ908iFR@0508iFR@8000001P2>EXT00`000000SUJ900000003000000030:W2
j`000000SUJ90080SUJ90P0000030:W2j`030000002Y`^/0ZL;[00P00000;@3oool300000080oooo
0P0000000`3oool00000000000070?ooo`050000003oool0oooo0?ooo`0000004P3oool200000003
0?ooo`000000oooo0?00oooo000G0?ooo`030000003oool0000000<0oooo0`09jPX80?ooo`030000
0027CXH0Qdj600L0Qdj61000000708M>QP8000002027CXH2000000H0Qdj600<0000008M>QP27CXH0
0P27CXH01`000000Qdj608M>QP000000YKk[00000027CXH00P0000020:Fnj`8000000`2U_^/20000
0080YKk[00<000000?ooo`0000000`00000/0?ooo`<0000000D0oooo000000000000oooo00000006
0?ooo`050000003oool0oooo0?ooo`0000005@3oool00`000000oooo0000003T0?ooo`0300000009
jPX0000000T0oooo00<0000008iFR@2>EXT01`2>EXT2000000030:W2j`000000SUJ90080SUJ900<0
000008iFR@2>EXT01`2>EXT2000000L0SUJ900<0000008iFR@2>EXT01@2>EXT010000000SUJ908iF
R@2>EXT3000000030:W2j`000000SUJ9008000000`2Y`^/200000080ZL;[00<000000?ooo`3oool0
1@00000`0?ooo`<0000000<0oooo0000000000002P3oool01@000000oooo0?ooo`3oool000000140
oooo00<000000?ooo`000000lP3oool001P0oooo0`00000200WZ2P/0oooo00<0000008M>QP27CXH0
1P27CXH00`000000oooo0?ooo`02000000D0Qdj60P00000908M>QP0300000027CXH0Qdj600D0Qdj6
00<0000008M>QP27CXH00P27CXH00`000000Qdj608M>QP0208M>QP<000000P2U_^/2000000@0YKk[
00<000000:Fnj`2U_^/01`00000`0?ooo`@00000203oool00`000000oooo0?ooo`0300000180oooo
00<000000?ooo`000000hP3oool300WZ2P040000003oool00000000000P0oooo00<0000008iFR@2>
EXT01`2>EXT010000000oooo00000000000408iFR@030000002>EXT0SUJ900D0SUJ900<0000008iF
R@2>EXT01@2>EXT2000000H0SUJ90P00000308iFR@040000002>EXT0SUJ908iFR@<00000102Y`^/0
0`000000ZL;[0:W2j`0200000080oooo1@00000d0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool00`00000>0?ooo`<00000l`3oool001P0oooo00<0000000WZ2P0000003@3oool00`00
0000Qdj608M>QP0608M>QP060000003oool0oooo00000027CXH000000`27CXH00`000000Qdj608M>
QP0808M>QP0300000027CXH0Qdj600@0Qdj60P00000408M>QP0300000027CXH0Qdj600@0Qdj60P00
00000`2U_^/000000:Fnj`030:Fnj`8000000P2U_^/010000000YKk[0000003oool2000003l0oooo
0P0000030?ooo`030000003oool0oooo00h0oooo0`00003Q0?ooo`802NX:103oool00`000000oooo
000000060?ooo`802NX:00<0000008iFR@2>EXT01`2>EXT010000000oooo0?ooo`00000408iFR@03
0000002>EXT0SUJ900<0SUJ90P00000708iFR@030000002>EXT0SUJ900D0SUJ900<0000008iFR@2>
EXT00P2>EXT00`000000SUJ908iFR@0308iFR@040000002Y`^/0ZL;[0:W2j`8000000P2Y`^/20000
00030?ooo`000000000000@00000A03oool2000000<0oooo0P00000;0?ooo`<00000m03oool001T0
oooo00<000000?ooo`0000002P3oool200WZ2P0300000027CXH0Qdj600H0Qdj600@000000?ooo`3o
ool0oooo0P0000000`27CXH000000000000908M>QP8000001P27CXH00`000000Qdj608M>QP0308M>
QP0300000027CXH0Qdj600D0Qdj600@000000:Fnj`00000000000`2U_^/00`000000YKk[0:Fnj`08
00000440oooo00D000000?ooo`3oool0oooo0000000>0?ooo`<00000j03oool010000000oooo0?oo
o`0000020?ooo`<02NX:0P3oool00`000000SUJ908iFR@0708iFR@050000003oool0oooo00WZ2P00
0000102>EXT00`000000SUJ908iFR@02000000P0SUJ900<0000008iFR@2>EXT01@2>EXT00`000000
SUJ908iFR@0208iFR@030000002>EXT0SUJ900@0SUJ90P000000102Y`^/000000:W2j`2Y`^/20000
00030:W2j`000000000000@00000B03oool200000080oooo0`0000080?ooo`<00000m@3oool001T0
oooo00<000000?ooo`0000001`3oool300WZ2P80oooo00<0000008M>QP27CXH01P27CXH01`000000
oooo0?ooo`09jPX0000008M>QP0000002P27CXH00`000000Qdj608M>QP0508M>QP0300000027CXH0
Qdj600<0Qdj600<0000008M>QP27CXH01@27CXH800000080YKk[00@000000:Fnj`000000YKk[1000
00130?ooo`030000003oool0oooo00@000002P3oool300000>X0oooo00<000000?ooo`0000000P09
jPX50?ooo`030000002>EXT0SUJ900L0SUJ900D0000000WZ2P09jPX0oooo0000000408iFR@030000
002>EXT0000000P0SUJ90P00000708iFR@030000002>EXT0SUJ90080SUJ900<0000008iFR@2>EXT0
102>EXT5000000040:W2j`000000ZL;[0:W2j`H00000B`3oool2000000<0oooo00<000000?ooo`3o
ool00`3oool300000?L0oooo000I0?ooo`040000003oool0oooo000000<0oooo0`09jPX50?ooo`03
00000027CXH0Qdj600H0Qdj600L0000000WZ2P09jPX0oooo00000027CXH0000000P0Qdj60P000007
08M>QP0300000027CXH0Qdj600<0Qdj600<0000008M>QP27CXH01@27CXH2000000030?ooo`000000
oooo0080oooo300000140?ooo`<000000`3oool4000000<0oooo1000003[0?ooo`0400WZ2P000000
2NX:000000L0oooo00<0000008iFR@2>EXT01`2>EXT01@000000oooo0?ooo`3oool0000000D0SUJ9
00<0000008iFR@2>EXT01P2>EXT00`000000SUJ908iFR@0608iFR@030000002>EXT0SUJ90080SUJ9
00<0000008iFR@2>EXT0102>EXT010000000oooo0?ooo`3oool6000000030?ooo`000000000000<0
0000C@3oool00`000000oooo0?ooo`0800000?P0oooo000J0?ooo`040000003oool000000?ooo`80
2NX:203oool00`000000Qdj608M>QP0608M>QP030000003oool0oooo0080oooo00<0000008M>QP00
00001P27CXH00`000000Qdj608M>QP0608M>QP0300000027CXH0Qdj600<0Qdj600<0000008M>QP27
CXH01@27CXH01P000000oooo000000000000oooo00000080oooo00<000000?ooo`00000020000018
0?ooo`@000000`3oool300000>d0oooo0P09jPX01@3oool000000?ooo`3oool0000000H0oooo00<0
000008iFR@2>EXT01`2>EXT00`000000oooo0?ooo`020?ooo`030000002>EXT0SUJ90080SUJ900<0
000008iFR@2>EXT01@2>EXT00`000000SUJ908iFR@0508iFR@800000102>EXT00`000000SUJ908iF
R@0408iFR@050000003oool0oooo0?ooo`0000000P3oool00`000000oooo00000006000004l0oooo
2000003j0?ooo`006P3oool00`000000oooo0000000;0?ooo`0300000027CXH0Qdj600H0Qdj600<0
00000?ooo`3oool00P3oool00`000000Qdj60000000508M>QP0300000027CXH0Qdj600H0Qdj600<0
000008M>QP27CXH00`27CXH00`000000Qdj608M>QP0508M>QP030000003oool0oooo0080000000@0
oooo0000003oool000000P3oool010000000oooo0000003oool5000004`0oooo0`00003d0?ooo`03
0000003oool0000000H0oooo00<0000008iFR@2>EXT01`2>EXT00`000000oooo0?ooo`020?ooo`03
0000002>EXT0SUJ900<0SUJ900<0000008iFR@2>EXT00P2>EXT2000000L0SUJ900<0000008iFR@2>
EXT00`2>EXT00`000000SUJ908iFR@0408iFR@050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`0700000?l0ooooDP3oool001X0oooo00@000000?ooo`00000000002@3oool00`09
jPX0000008M>QP0708M>QP030000003oool0oooo0080oooo00@0000008M>QP27CXH000000P27CXH2
000000P0Qdj600<0000008M>QP27CXH00`27CXH00`000000Qdj608M>QP0508M>QP070000003oool0
oooo0000003oool000000?ooo`0200000080oooo00@000000?ooo`000000oooo1@00003o0?ooodD0
oooo00<000000?ooo`0000000P3oool400WZ2P030000002>EXT0SUJ900L0SUJ900<000000?ooo`3o
ool00P3oool00`000000SUJ908iFR@0408iFR@040000002>EXT0SUJ9000000P0SUJ900<0000008iF
R@2>EXT00`2>EXT00`000000SUJ908iFR@0408iFR@050000003oool0oooo0?ooo`0000000P3oool0
1`000000oooo0?ooo`000000oooo0000003oool00`00003o0?oooe<0oooo000K0?ooo`030000003o
ool0000000H0oooo0`09jPX00`3oool0000008M>QP0708M>QP030000003oool0oooo00<0oooo00D0
000008M>QP000000Qdj60000000808M>QP8000001@27CXH00`000000Qdj608M>QP0508M>QP060000
003oool0oooo0?ooo`000000oooo0`0000020?ooo`030000003oool000000080oooo1@00003o0?oo
odD0oooo00D000000?ooo`000000000000WZ2P040?ooo`030000002>EXT0SUJ900L0SUJ900<00000
0?ooo`3oool00`3oool00`000000SUJ908iFR@0308iFR@030000002>EXT0000000P0SUJ900<00000
08iFR@2>EXT00`2>EXT00`000000SUJ908iFR@0408iFR@8000000P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0000000D00000o`3ooomC0?ooo`006`3oool010000000oooo0?ooo`00
00030?ooo`802NX:103oool00`000000Qdj608M>QP0608M>QP030000003oool0oooo00<0oooo00@0
000008M>QP27CXH000002027CXH00`000000Qdj608M>QP0408M>QP0300000027CXH0Qdj600D0Qdj6
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool000000080oooo00H000000?ooo`00
0000oooo0000003oool300000?l0ooooAP3oool01009jPX000000?ooo`0000050?ooo`030000002>
EXT0SUJ900P0SUJ900<000000?ooo`3oool00`3oool00`000000SUJ908iFR@0308iFR@030000002>
EXT0SUJ900D0SUJ90P00000508iFR@030000002>EXT0SUJ900@0SUJ90`0000000`3oool000000?oo
o`020?ooo`050000003oool0oooo0000003oool01@00003o0?oooe@0oooo000L0?ooo`030000003o
ool0000000T0oooo00<0000008M>QP27CXH01P27CXH00`000000oooo0?ooo`040?ooo`0300000027
CXH0000000L0Qdj600<0000008M>QP27CXH01027CXH00`000000Qdj608M>QP0508M>QP8000000P3o
ool010000000oooo0?ooo`3oool3000000070?ooo`000000oooo0000003oool000000?ooo`040000
0?l0ooooA`3oool010000000oooo0?ooo`0000050?ooo`030000002>EXT0SUJ900L0SUJ900<00000
0?ooo`3oool00`3oool00`000000SUJ908iFR@0308iFR@030000002>EXT0SUJ900@0SUJ900<00000
08iFR@2>EXT0102>EXT00`000000SUJ908iFR@0408iFR@80000000@0oooo0000003oool000000P3o
ool01`000000oooo0?ooo`000000oooo0000003oool01000003o0?oooe@0oooo000L0?ooo`040000
003oool0oooo000000P0oooo00<0000008M>QP27CXH01P27CXH00`000000oooo0?ooo`040?ooo`04
00000027CXH0Qdj6000000D0Qdj600<0000008M>QP27CXH01027CXH00`000000Qdj608M>QP0508M>
QP030000002U_^/0YKk[00800000103oool010000000oooo0000000000020?ooo`040000003oool0
00000?ooo`<00000o`3ooom90?ooo`030000003oool0000000D0oooo00<0000008iFR@2>EXT01`2>
EXT00`000000oooo0?ooo`040?ooo`030000002>EXT0SUJ900<0SUJ900<0000008iFR@2>EXT00P2>
EXT00`000000SUJ908iFR@0408iFR@030000002>EXT0SUJ900@0SUJ900@000000?ooo`000000oooo
0P0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`0000000P00003o0?oooeD0
oooo000M0?ooo`030000003oool0000000T0oooo00<0000008M>QP27CXH01@27CXH00`000000oooo
0?ooo`050?ooo`0400000027CXH0Qdj6000000<0Qdj600<0000008M>QP27CXH01027CXH00`000000
Qdj608M>QP0508M>QP8000000`2U_^/3000000030?ooo`0000000000008000000P3oool010000000
oooo0000003oool400000?l0ooooB@3oool010000000oooo0?ooo`0000040?ooo`030000002>EXT0
SUJ900L0SUJ900<000000?ooo`3oool01@3oool00`000000SUJ908iFR@0308iFR@040000002>EXT0
SUJ9000000H0SUJ900<0000008iFR@2>EXT0102>EXT2000000040?ooo`000000oooo00000080oooo
00P000000?ooo`3oool0oooo0000003oool000000?ooo`<00000o`3ooomF0?ooo`007@3oool01000
0000oooo0?ooo`0000080?ooo`0300000027CXH0Qdj600D0Qdj600<000000?ooo`3oool01P3oool0
1P000000Qdj608M>QP000000Qdj6000000H0Qdj600<0000008M>QP27CXH01@27CXH00`000000oooo
0?ooo`03000000<0YKk[1@0000001P3oool000000?ooo`3oool000000?ooo`@00000o`3ooom:0?oo
o`030000003oool0000000@0oooo00<0000008iFR@2>EXT01`2>EXT00`000000oooo0?ooo`060?oo
o`030000002>EXT0SUJ90080SUJ900<0000008iFR@0000001P2>EXT00`000000SUJ908iFR@0508iF
R@030000002Y`^/0000000<000000P3oool01P000000oooo0?ooo`000000oooo00000080oooo0`00
003o0?oooeH0oooo000N0?ooo`030000003oool0000000P0oooo00<0000008M>QP27CXH01@27CXH0
0`000000oooo0?ooo`070?ooo`0400000027CXH0Qdj6000000H0Qdj600<0000008M>QP27CXH01@27
CXH00`000000oooo0?ooo`020?ooo`@0000000<0YKk[0000000000000P0000020?ooo`040000003o
ool000000?ooo`@00000o`3ooom;0?ooo`030000003oool0000000D0oooo00<0000008iFR@2>EXT0
1P2>EXT00`000000oooo0?ooo`070?ooo`030000002>EXT0SUJ90080SUJ900<0000008iFR@2>EXT0
102>EXT00`000000SUJ908iFR@0508iFR@040000002Y`^/0ZL;[0:W2j`<0000000D0oooo0000003o
ool0oooo000000020?ooo`030000003oool0000000800000o`3ooomG0?ooo`007P3oool010000000
oooo0000000000070?ooo`0300000027CXH0Qdj600D0Qdj600<000000?ooo`3oool0203oool00`00
0000Qdj60000000508M>QP0300000027CXH0Qdj600D0Qdj600<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`80000000D0YKk[000000000000oooo000000020?ooo`030000003oool0
000000<00000o`3ooom;0?ooo`040000003oool00000000000@0oooo00<0000008iFR@2>EXT01P2>
EXT00`000000oooo0?ooo`080?ooo`050000002>EXT0SUJ908iFR@0000001@2>EXT00`000000SUJ9
08iFR@0508iFR@030000003oool0000000H000000`3oool00`000000oooo000000020?ooo`<00000
o`3ooomG0?ooo`007`3oool00`000000oooo000000070?ooo`0300000027CXH0Qdj600D0Qdj600<0
00000?ooo`3oool02@3oool00`000000Qdj60000000308M>QP0300000027CXH0Qdj600D0Qdj600<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0000000D0
oooo0000003oool000000?ooo`0400000?l0ooooC@3oool00`000000oooo000000040?ooo`030000
002>EXT0SUJ900H0SUJ900<000000?ooo`3oool02@3oool01@000000SUJ908iFR@2>EXT0000000<0
SUJ900<0000008iFR@2>EXT01@2>EXT00`000000oooo0?ooo`020?ooo`80000000<0oooo0000003o
ool00P3oool01@000000oooo0?ooo`000000oooo00<00000o`3ooomH0?ooo`007`3oool010000000
oooo0?ooo`0000060?ooo`0300000027CXH0Qdj600D0Qdj600<000000?ooo`3oool02P3oool30000
000308M>QP000000Qdj600H0Qdj600<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?oo
o`050000003oool0oooo0000003oool00P0000001@3oool000000?ooo`000000oooo00<00000o`3o
oom=0?ooo`040000003oool0oooo000000<0oooo00<0000008iFR@2>EXT01P2>EXT00`000000oooo
0?ooo`0:0?ooo`8000000P2>EXT00`000000SUJ90000000708iFR@030000003oool0oooo0080oooo
00D000000?ooo`000000oooo000000020?ooo`070000003oool0oooo0000003oool000000?ooo`02
00000?l0ooooF03oool00200oooo00<000000?ooo`0000001P3oool00`000000Qdj608M>QP0508M>
QP030000003oool0oooo00`0oooo0P00000708M>QP030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`02000000060?ooo`000000oooo0?ooo`000000oooo1000
003o0?ooodl0oooo00<000000?ooo`000000103oool00`000000SUJ908iFR@0508iFR@030000003o
ool0oooo00`0oooo0P0000000`2>EXT0000008iFR@0608iFR@030000003oool0oooo0080oooo00<0
00000?ooo`3oool00`0000020?ooo`030000003oool000000080oooo0`00003o0?oooeT0oooo000Q
0?ooo`030000003oool0000000D0oooo00<0000008M>QP27CXH01@27CXH00`000000oooo0?ooo`0=
0?ooo`8000001@27CXH00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool0oooo0P0000001`3oool000000?ooo`000000oooo0000003oool00`00003o0?ooodl0
oooo00@000000?ooo`3oool000000`3oool00`000000SUJ908iFR@0508iFR@030000003oool0oooo
00h0oooo0`00000508iFR@030000003oool0oooo0080oooo00T000000?ooo`3oool0oooo0000003o
ool000000?ooo`0000000P3oool010000000oooo0000003oool200000?l0ooooF@3oool00240oooo
00@000000?ooo`3oool000001@3oool00`000000Qdj608M>QP0408M>QP030000003oool0oooo00l0
oooo00D0000008M>QP27CXH0Qdj6000000050?ooo`030000003oool0oooo00<0oooo00D000000?oo
o`3oool000000?ooo`03000000030?ooo`000000oooo0080000000<0oooo0000003oool0o`3ooom@
0?ooo`040000003oool0oooo00000080oooo00<0000008iFR@2>EXT01@2>EXT00`000000oooo0?oo
o`0@0?ooo`8000000`2>EXT00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00L0
00000?ooo`000000oooo0000003oool000000080oooo0`00003o0?oooeX0oooo000R0?ooo`030000
003oool0000000D0oooo00<0000008M>QP27CXH01027CXH00`000000oooo0?ooo`0@0?ooo`030000
0027CXH0000000H0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`@0
000000<0oooo0000003oool00`00003o0?oooe80oooo00<000000?ooo`0000000P3oool00`000000
SUJ908iFR@0508iFR@030000003oool0oooo0140oooo0P0000000`2>EXT000000?ooo`040?ooo`04
0000003oool0oooo0?ooo`80000000<0oooo0000000000000P3oool010000000oooo0000003oool2
00000?l0ooooFP3oool002<0oooo0`0000040?ooo`0300000027CXH0Qdj600@0Qdj600<000000?oo
o`3oool04@3oool2000000D0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0
00000080oooo100000000`3oool000000000000200000?l0ooooD`3oool010000000oooo00000000
00020?ooo`030000002>EXT0SUJ900@0SUJ900<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`030?ooo`060000003oool0oooo0?ooo`000000oooo0`0000020?ooo`030000003oool0oooo00<0
0000o`3ooomK0?ooo`008`3oool00`000000oooo000000040?ooo`0300000027CXH0Qdj600@0Qdj6
00<000000?ooo`3oool04`3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`80000000H0oooo0000003oool000000?ooo`00003o0?oooeH0oooo00<0
00000?ooo`0000000P3oool00`000000SUJ908iFR@0408iFR@030000003oool0oooo01@0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`080000003oool0oooo0000003oool000000?ooo`000002
0?ooo`040000003oool0000000000?l0ooooF`3oool002@0oooo00<000000?ooo`0000000`3oool0
0`000000Qdj608M>QP0408M>QP030000003oool0oooo01@0oooo00<000000?ooo`0000001@3oool0
10000000oooo0?ooo`0000030?ooo`050000003oool000000000003oool00P00003o0?oooeL0oooo
00H000000?ooo`3oool000000?ooo`00000708iFR@030000003oool0oooo01@0oooo00<000000?oo
o`000000103oool00`000000oooo0?ooo`03000000040?ooo`000000oooo0?ooo`<00000o`3ooomL
0?ooo`009@3oool00`000000oooo000000030?ooo`0300000027CXH0Qdj600<0Qdj600<000000?oo
o`3oool05@3oool2000000@0oooo00@000000?ooo`3oool000000`3oool2000000030?ooo`000000
oooo00800000o`3ooomI0?ooo`060000003oool0oooo0000003oool000001P2>EXT00`000000oooo
0?ooo`0E0?ooo`8000000`3oool01P000000oooo0?ooo`3oool000000?ooo`8000000P3oool30000
0?l0ooooG@3oool002D0oooo00<000000?ooo`0000000`3oool00`000000Qdj608M>QP0408M>QP03
0000003oool0oooo01H0oooo0P0000000`3oool000000?ooo`020?ooo`040000003oool0oooo0?oo
o`@0000000<0oooo0000003oool0o`3ooomJ0?ooo`050000003oool000000?ooo`0000001P2>EXT0
0`000000oooo0?ooo`0G0?ooo`030000003oool0000000<0oooo0`0000001P3oool000000?ooo`00
0000oooo00000?l0ooooGP3oool002H0oooo00<000000?ooo`0000000P3oool00`000000Qdj608M>
QP0408M>QP030000003oool0oooo01P0oooo0`0000000`3oool000000?ooo`020?ooo`80000000@0
oooo0000000000000000o`3ooomL0?ooo`060000003oool0oooo0000003oool000001@2>EXT00`00
0000oooo0?ooo`0H0?ooo`<000000P3oool010000000oooo0000000000020?ooo`800000o`3ooomO
0?ooo`009`3oool300000080oooo00<0000008M>QP27CXH00`27CXH00`000000oooo0?ooo`0K0?oo
o`T00000o`3ooomO0?ooo`030000003oool00000008000001@2>EXT00`000000oooo0?ooo`0K0?oo
o`P00000o`3ooomQ0?ooo`009`3oool01P000000oooo0?ooo`000000oooo000000D0Qdj600<00000
0?ooo`3oool08@3oool00`000000oooo0000003o0?ooof00oooo00D000000?ooo`000000oooo0000
000508iFR@030000003oool0oooo01`0oooo00<000000?ooo`000000o`3ooomT0?ooo`00:03oool0
0`000000oooo0?ooo`02000000D0Qdj600<000000?ooo`3oool0803oool00`000000oooo0000003o
0?ooof40oooo00<000000?ooo`3oool00P00000508iFR@030000003oool0oooo01/0oooo00<00000
0?ooo`000000o`3ooomU0?ooo`00:@3oool00`000000oooo0?ooo`02000000@0Qdj600<000000?oo
o`3oool0803oool00`000000oooo0000003o0?ooof80oooo00<000000?ooo`3oool00P00000408iF
R@030000003oool0oooo01/0oooo00<000000?ooo`000000o`3ooomU0?ooo`00:P3oool010000000
oooo0?ooo`00000408M>QP030000003oool0oooo0200oooo00<000000?ooo`000000o`3ooomS0?oo
o`040000003oool0oooo000000@0SUJ900<000000?ooo`3oool06`3oool00`000000oooo0000003o
0?ooofD0oooo000[0?ooo`040000003oool00000000000<0Qdj600<000000?ooo`3oool07`3oool3
00000?l0ooooI@3oool010000000oooo0?ooo`00000308iFR@030000003oool0oooo01X0oooo0`00
003o0?ooofH0oooo000/0?ooo`040000003oool00000000000<0Qdj600<000000?ooo`3oool07P3o
ool00`000000oooo0000003o0?ooofH0oooo1000000208iFR@030000003oool0oooo01X0oooo00<0
00000?ooo`000000o`3ooomV0?ooo`00;@3oool010000000oooo00000000000208M>QP030000003o
ool0oooo01d0oooo00<000000?ooo`000000o`3ooomX0?ooo`040000003oool0000000000080SUJ9
00<000000?ooo`3oool0603oool010000000oooo0?ooo`00003o0?ooofH0oooo000^0?ooo`800000
00@0Qdj600000027CXH000007`3oool00`000000oooo0000003o0?ooofT0oooo0P000000102>EXT0
000008iFR@00000J0?ooo`030000003oool000000?l0ooooI`3oool002l0oooo00<0000008M>QP27
CXH00P00000O0?ooo`800000o`3ooom[0?ooo`80000000<0SUJ90000000000006P3oool300000?l0
ooooI`3oool00300oooo1@00000M0?ooo`030000003oool000000?l0ooooK03oool00`000000SUJ9
00000002000001P0oooo0P0000000`3oool000000?ooo`3o0?ooofH0oooo000b0?ooo`040000003o
ool0oooo000001/0oooo00<000000?ooo`000000o`3ooom^0?ooo`8000000P3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool000000?l0ooooJ03oool003<0oooo00@000000?ooo`3oool00000
6@3oool00`000000oooo0000003o0?ooog40oooo00@000000?ooo`3oool000005@3oool00`000000
oooo0000003o0?ooofT0oooo000d0?ooo`030000003oool00000008000005@3oool400000?l0oooo
L`3oool00`000000oooo0000000200000180oooo0`00003o0?ooofX0oooo000e0?ooo`8000000P3o
ool200000180oooo0`00003o0?ooogH0oooo0P0000020?ooo`030000003oool0oooo00h0oooo0P00
003o0?ooof`0oooo000g0?ooo`<0000000<0oooo0000003oool03`3oool200000?l0ooooNP3oool0
10000000oooo0?ooo`00000>0?ooo`800000o`3ooom]0?ooo`00>P3oool6000000X0oooo0P00003o
0?ooogd0oooo00<000000?ooo`000000100000080?ooo`800000o`3ooom_0?ooo`00?03oool30000
00030?ooo`0000000000008000000`3oool300000?l0ooooP03oool3000000<0oooo100000020?oo
o`<00000o`3ooom`0?ooo`00?`3oool900000?l0ooooQ@3oool:00000?l0ooooLP3oool00?l0oooo
o`3ooooo0?ooodX0oooo003o0?ooool0ooooo`3ooom:0?ooo`00o`3ooooo0?ooool0ooooBP3oool0
0?l0ooooo`3ooooo0?ooodX0oooo003o0?ooool0ooooo`3ooom:0?ooo`00o`3ooooo0?ooool0oooo
BP3oool00?l0ooooo`3ooooo0?ooodX0oooo003o0?ooool0ooooo`3ooom:0?ooo`00o`3ooooo0?oo
ool0ooooBP3oool00?l0ooooo`3ooooo0?ooodX0oooo003o0?ooool0ooooo`3ooom:0?ooo`00o`3o
oooo0?ooool0ooooBP3oool00?l0ooooo`3ooooo0?ooodX0oooo003o0?ooool0ooooo`3ooom:0?oo
o`00o`3ooooo0?ooool0ooooBP3oool00?l0ooooo`3ooooo0?ooodX0oooo003o0?ooool0ooooo`3o
oom:0?ooo`00o`3ooooo0?ooool0ooooBP3oool00?l0ooooo`3ooooo0?ooodX0oooo003o0?ooool0
ooooo`3ooom:0?ooo`00o`3ooooo0?ooool0ooooBP3oool00?l0ooooo`3ooooo0?ooodX0oooo0000
\
\>"],
  ImageRangeCache->{{{-76.5625, 896.062}, {410.688, -144.5}} -> {0.114342, \
-0.340908, 0.00216146, 0.00216146}, {{-52.875, 475.812}, {397.438, -131.25}} -> \
{0.100008, -0.298388, 0.0018915, 0.0018915}, {{343.625, 872.375}, {397.438, \
-131.25}} -> {-0.650029, -0.298388, 0.0018915, 0.0018915}},
  CellTags->"CompoundLens"]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Macintosh",
ScreenRectangle->{{0, 1920}, {0, 1174}},
WindowSize->{900, 676},
WindowMargins->{{9, Automatic}, {Automatic, 21}},
StyleDefinitions -> "Default.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CompoundLens"->{
    Cell[1776, 53, 98, 1, 56, "Section",
      CellTags->"CompoundLens"],
    Cell[1877, 56, 324, 10, 50, "Text",
      CellTags->"CompoundLens"],
    Cell[2204, 68, 252, 8, 32, "Text",
      CellTags->"CompoundLens"],
    Cell[2481, 80, 57, 1, 27, "Input",
      CellTags->"CompoundLens"],
    Cell[3911, 105, 487, 14, 50, "Text",
      CellTags->"CompoundLens"],
    Cell[4470, 125, 1856, 112, 1662, "Input",
      CellTags->"CompoundLens"],
    Cell[6430, 246, 73, 1, 27, "Input",
      CellTags->"CompoundLens"],
    Cell[6506, 249, 4037, 70, 331, "Output",
      CellTags->"CompoundLens"],
    Cell[10695, 330, 283, 9, 32, "Text",
      CellTags->"CompoundLens"],
    Cell[11003, 343, 99, 4, 27, "Input",
      CellTags->"CompoundLens"],
    Cell[12164, 366, 138, 5, 32, "Text",
      CellTags->"CompoundLens"],
    Cell[12327, 375, 158, 5, 27, "Input",
      CellTags->"CompoundLens"],
    Cell[12488, 382, 1861, 35, 139, "Output",
      CellTags->"CompoundLens"],
    Cell[14364, 420, 469, 11, 50, "Text",
      CellTags->"CompoundLens"],
    Cell[14836, 433, 276, 8, 32, "Text",
      CellTags->"CompoundLens"],
    Cell[15137, 445, 58, 1, 27, "Input",
      CellTags->"CompoundLens"],
    Cell[15198, 448, 1945, 26, 327, "Print",
      CellTags->{"Info3251825220-2418144", "CompoundLens"}],
    Cell[17158, 477, 285, 7, 50, "Text",
      CellTags->"CompoundLens"],
    Cell[17468, 488, 240, 7, 72, "Input",
      CellTags->"CompoundLens"],
    Cell[17711, 497, 724862, 20482, 407, 568413, 18546, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"CompoundLens"],
    Cell[742588, 20982, 362, 9, 50, "Text",
      CellTags->"CompoundLens"],
    Cell[742953, 20993, 86, 1, 27, "Input",
      CellTags->"CompoundLens"],
    Cell[743042, 20996, 279835, 4328, 515, 279643, 4322, "BoxData", 
    "Graphics3D", "Boxed",
      CellTags->"CompoundLens"],
    Cell[1022880, 25326, 557, 15, 68, "Text",
      CellTags->"CompoundLens"],
    Cell[1023440, 25343, 688, 11, 102, "Input",
      CellTags->"CompoundLens"],
    Cell[1024153, 25358, 240, 7, 72, "Input",
      CellTags->"CompoundLens"],
    Cell[1024396, 25367, 244667, 8766, 493, 117034, 7186, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"CompoundLens"],
    Cell[1269100, 34138, 102, 1, 27, "Input",
      CellTags->"CompoundLens"],
    Cell[1269205, 34141, 178675, 7795, 245, 90312, 6699, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"CompoundLens"],
    Cell[1447895, 41939, 209, 6, 31, "Text",
      CellTags->"CompoundLens"],
    Cell[1448129, 41949, 122, 4, 27, "Input",
      CellTags->"CompoundLens"],
    Cell[1448254, 41955, 340863, 15694, 236, 234577, 14377, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"CompoundLens"]},
  "Info3311933938-1376534"->{
    Cell[2541, 83, 1355, 19, 215, "Print",
      CellTags->"Info3311933938-1376534"]},
  "Info3311933950-5613040"->{
    Cell[11105, 349, 1044, 14, 183, "Print",
      CellTags->"Info3311933950-5613040"]},
  "Info3251825220-2418144"->{
    Cell[15198, 448, 1945, 26, 327, "Print",
      CellTags->{"Info3251825220-2418144", "CompoundLens"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CompoundLens", 1789781, 57670},
  {"Info3311933938-1376534", 1792570, 57740},
  {"Info3311933950-5613040", 1792687, 57743},
  {"Info3251825220-2418144", 1792806, 57746}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 98, 1, 56, "Section",
  CellTags->"CompoundLens"],
Cell[1877, 56, 324, 10, 50, "Text",
  CellTags->"CompoundLens"],
Cell[2204, 68, 252, 8, 32, "Text",
  CellTags->"CompoundLens"],

Cell[CellGroupData[{
Cell[2481, 80, 57, 1, 27, "Input",
  CellTags->"CompoundLens"],
Cell[2541, 83, 1355, 19, 215, "Print",
  CellTags->"Info3311933938-1376534"]
}, Open  ]],
Cell[3911, 105, 487, 14, 50, "Text",
  CellTags->"CompoundLens"],

Cell[CellGroupData[{
Cell[4423, 123, 44, 0, 46, "Subsection"],
Cell[4470, 125, 1856, 112, 1662, "Input",
  CellTags->"CompoundLens"]
}, Closed]],

Cell[CellGroupData[{
Cell[6363, 242, 42, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[6430, 246, 73, 1, 27, "Input",
  CellTags->"CompoundLens"],
Cell[6506, 249, 4037, 70, 331, "Output",
  CellTags->"CompoundLens"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[10592, 325, 100, 3, 28, "Subsection"],
Cell[10695, 330, 283, 9, 32, "Text",
  CellTags->"CompoundLens"],

Cell[CellGroupData[{
Cell[11003, 343, 99, 4, 27, "Input",
  CellTags->"CompoundLens"],
Cell[11105, 349, 1044, 14, 183, "Print",
  CellTags->"Info3311933950-5613040"]
}, Open  ]],
Cell[12164, 366, 138, 5, 32, "Text",
  CellTags->"CompoundLens"],

Cell[CellGroupData[{
Cell[12327, 375, 158, 5, 27, "Input",
  CellTags->"CompoundLens"],
Cell[12488, 382, 1861, 35, 139, "Output",
  CellTags->"CompoundLens"]
}, Open  ]],
Cell[14364, 420, 469, 11, 50, "Text",
  CellTags->"CompoundLens"],
Cell[14836, 433, 276, 8, 32, "Text",
  CellTags->"CompoundLens"],

Cell[CellGroupData[{
Cell[15137, 445, 58, 1, 27, "Input",
  CellTags->"CompoundLens"],
Cell[15198, 448, 1945, 26, 327, "Print",
  CellTags->{"Info3251825220-2418144", "CompoundLens"}]
}, Open  ]],
Cell[17158, 477, 285, 7, 50, "Text",
  CellTags->"CompoundLens"],

Cell[CellGroupData[{
Cell[17468, 488, 240, 7, 72, "Input",
  CellTags->"CompoundLens"],
Cell[17711, 497, 724862, 20482, 407, 568413, 18546, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"CompoundLens"]
}, Open  ]],
Cell[742588, 20982, 362, 9, 50, "Text",
  CellTags->"CompoundLens"],
Cell[742953, 20993, 86, 1, 27, "Input",
  CellTags->"CompoundLens"],
Cell[743042, 20996, 279835, 4328, 515, 279643, 4322, "BoxData", "Graphics3D", \
"Boxed",
  CellTags->"CompoundLens"],
Cell[1022880, 25326, 557, 15, 68, "Text",
  CellTags->"CompoundLens"],
Cell[1023440, 25343, 688, 11, 102, "Input",
  CellTags->"CompoundLens"],

Cell[CellGroupData[{
Cell[1024153, 25358, 240, 7, 72, "Input",
  CellTags->"CompoundLens"],
Cell[1024396, 25367, 244667, 8766, 493, 117034, 7186, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"CompoundLens"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1269100, 34138, 102, 1, 27, "Input",
  CellTags->"CompoundLens"],
Cell[1269205, 34141, 178675, 7795, 245, 90312, 6699, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"CompoundLens"]
}, Open  ]],
Cell[1447895, 41939, 209, 6, 31, "Text",
  CellTags->"CompoundLens"],

Cell[CellGroupData[{
Cell[1448129, 41949, 122, 4, 27, "Input",
  CellTags->"CompoundLens"],
Cell[1448254, 41955, 340863, 15694, 236, 234577, 14377, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"CompoundLens"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

