(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    770046,      28982]*)
(*NotebookOutlinePosition[    771207,      29018]*)
(*  CellTagsIndexPosition[    771071,      29011]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
SRL Optical Layout. Dahl-Kirkham telescope elliptical primary and \
spherical secondary\
\>", "Subtitle"],

Cell["Contributed by Dave Whiteman: NASA.", "Text"],

Cell[BoxData[
    \(\(SRLPrimary = 
        AsphericMirror[{\(-0.0003281\), \(-0.596\)}, 780, 75, 
          Hole \[Rule] 50, Labels \[Rule] "\<Primary\>", 
          SurfaceRayIntersections \[Rule] Solve];\)\)], "Input",
  ShowGroupOpenCloseIcon->True],

Cell[BoxData[
    \(\(\(\ \)\(SRLSecondary = 
        SphericalMirror[1740.04, 266.7, 25, 
          Labels \[Rule] "\<Secondary\>"];\)\)\)], "Input"],

Cell[BoxData[
    \(\(SRLFieldStop = 
        PinHole[25, 7.5, \ Labels \[Rule] "\<\>"];\)\)], "Input"],

Cell[BoxData[
    \(\(SRLFieldLens = 
        PlanoConvexLens[34.65, 25, 5.08, Labels \[Rule] "\<Field\>", 
          ComponentMedium \[Rule] FusedSilica];\)\)], "Input"],

Cell[BoxData[
    \(\(SRLCollLens1 = 
        SphericalLens[\(-112.6\), \(-70.6\), 50, 6.17, 
          Labels \[Rule] "\<Coll Set\>", 
          ComponentMedium \[Rule] FusedSilica];\)\)], "Input"],

Cell[BoxData[
    \(\(SRLCollLens2 = 
        SphericalLens[154.2, 113.5, 50, 5.28, Labels \[Rule] "\<\>", 
          ComponentMedium \[Rule] FusedSilica];\)\)], "Input"],

Cell[BoxData[
    \(\(SRLCollLens3 = 
        SphericalLens[430, \(-86.82\), 50, 10.95, Labels \[Rule] "\<\>", 
          ComponentMedium \[Rule] FusedSilica];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?LinearPolarizer\)\)], "Input"],

Cell[BoxData[
    \("LinearPolarizer[axisangle, aperture, thickness, label, options] is a \
flat surface optic used to create linearly polarized rays along an axis of \
alignment given by axisangle. \n\nIf the thickness parameter is zero or is \
omitted, then the optic will be created without any thickness. \
LinearPolarizer[surfacefunction, axisangle, aperture, thickness, options] can \
also be used to specify a thickness to the polarizer and a nonplaner custom \
surfacefunction. The axisangle parameter, given in Degrees, determines the \
direction of the first polarization state along the optical surface with \
respect to the horizontal axis of the local surface coordinate system. The \
Transmittance -> {first, second} option can be also used to weight the \
outgoing intensity of each polarization direction, where first and second can \
be either a number between 0 and 100, a list of {wavelength, transmission} \
values, or a Function-headed expression that depends on ray options such as \
WaveLength. Otherwise, ModelIntensity[componentmedium] = {first, second} can \
be defined to hold two absorption functions or two lists of {wavelength, \
transmission} values. ComponentMedium -> {polarizationmaterial, \
refractivematerial} can also be used to indicate that the polarization \
material is mounted on a refractive substrate. The SplitRays -> True option \
can be used to create two orthogonally polarized rays. SplitRays -> \
Reflection produces a reflected vertically polarized ray and a transmitted \
horizontally polarized ray. The user-named label parameter is optional and \
can be omitted. When it is present, its text content is used to identify the \
object in both the rendered graphics and the output cell expression. When it \
is omitted, Optica uses the default setting of the Labels option with the \
rendered graphics.\n \nSee also: SplitRays, Polarization, LinearPolarization, \
RetardationPlate, and JonesMatrixOptic."\)], "Print",
  CellTags->"Info3251831079-3187082"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?SplitRays\)\)], "Input"],

Cell[BoxData[
    \("SplitRays is an option of Polarization that indicates whether each \
incoming ray is to be split into two outgoing rays that contain two different \
polarization states denoted by the Reflectance and Transmittance options. \n\n\
The SplitRays -> True creates two polarized rays that propagate in the same \
direction. SplitRays -> Reflection produces a reflected polarized ray and a \
transmitted polarized ray."\)], "Print",
  CellTags->"Info3251831079-1006014"]
}, Open  ]],

Cell[BoxData[
    \(\(SRLBS1 = 
        LinearPolarizer[0, 75, 
          Transmittance \[Rule] {{{0.351, 0}, {0.371, 100}, {0.382, 
                  100}, {0.403, 0}}, \[IndentingNewLine]{{0.351, 0}, {0.371, 
                  100}, {0.382, 100}, {0.403, 0}}}, 
          Reflectance \[Rule] {{{0.351, 100}, {0.371, 0}, {0.382, 0}, {0.403, 
                  100}}, \[IndentingNewLine]{{0.351, 100}, {0.371, 
                  0}, {0.382, 0}, {0.403, 100}}}, 
          SplitRays \[Rule] Reflection, 
          Labels \[Rule] "\<BS1\>"];\)\)], "Input"],

Cell[BoxData[
    \(\(SRLBS2 = 
        LinearPolarizer[0, 75, 
          Transmittance \[Rule] {{{0.351, 0}, {0.371, 100}, {0.382, 
                  0}, {0.403, 0}}, \[IndentingNewLine]{{0.351, 0}, {0.371, 
                  100}, {0.382, 0}, {0.403, 0}}}, 
          Reflectance \[Rule] {{{0.351, 0}, {0.371, 0}, {0.382, 100}, {0.403, 
                  0}}, \[IndentingNewLine]{{0.351, 0}, {0.371, 0}, {0.382, 
                  100}, {0.403, 0}}}, SplitRays \[Rule] Reflection, 
          Labels \[Rule] "\<BS2\>"];\)\)], "Input"],

Cell[BoxData[
    \(\(SRLBS3 = 
        LinearPolarizer[0, 75, 
          Transmittance \[Rule] {{{0.351, 100}, {0.371, 0}, {0.382, 
                  0}, {0.403, 0}}, \[IndentingNewLine]{{0.351, 100}, {0.371, 
                  0}, {0.382, 0}, {0.403, 0}}}, 
          Reflectance \[Rule] {{{0.351, 0}, {0.371, 0}, {0.382, 0}, {0.403, 
                  100}}, \[IndentingNewLine]{{0.351, 0}, {0.371, 0}, {0.382, 
                  0}, {0.403, 100}}}, SplitRays \[Rule] Reflection, 
          Labels \[Rule] "\<BS3\>"];\)\)], "Input"],

Cell[BoxData[
    \(\(SRLFocusLens = 
        PlanoConvexLens[115, \ 50, 7, Labels \[Rule] "\<FL\>", 
          ComponentMedium \[Rule] FusedSilica];\)\)], "Input"],

Cell[BoxData[
    \(\(\(\(SRLSecondaryX = 100;\)\[IndentingNewLine]
    \(SRLPrimaryX = SRLSecondaryX + 1023.622;\)\[IndentingNewLine]
    \(SRLFieldStopX = SRLPrimaryX + 153;\)\[IndentingNewLine]
    \(SRLFieldLensX = SRLFieldStopX + 1;\)\[IndentingNewLine]
    \(SRLCollLens1X = SRLFieldLensX + 5.08 + 132.0;\)\[IndentingNewLine]
    \(SRLCollLens2X = SRLCollLens1X + 8.29;\)\[IndentingNewLine]
    \(SRLCollLens3X = SRLCollLens2X + 7;\)\[IndentingNewLine]
    \(SRLBS1X = SRLCollLens3X + 150;\)\[IndentingNewLine]
    \(SRLBS2X = SRLCollLens3X + 300;\)\[IndentingNewLine]
    \(SRLBS3Y = 150;\)\[IndentingNewLine]
    \(SRLFocusLensX = SRLCollLens3X + 489;\)\[IndentingNewLine]
    \(BSFLDelta = 189;\)\)\(\ \)\( (*\ 
      distance\ from\ BS\ to\ Focus\ Lens\ *) \)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(testsys = 
        AnalyzeSystem[{\[IndentingNewLine]LineOfRays[700, 
              NumberOfRays \[Rule] 5, WaveLength \[Rule]  .351, 
              RayLineRGB \[Rule] {0, 0, 1}], 
            LineOfRays[710, NumberOfRays \[Rule] 6, WaveLength \[Rule]  .371, 
              RayLineRGB \[Rule] {0, 1, 0}], \[IndentingNewLine]LineOfRays[
              720, NumberOfRays \[Rule] 7, WaveLength \[Rule]  .382, 
              RayLineRGB \[Rule] {1, 0, 0}], 
            LineOfRays[730, NumberOfRays \[Rule] 8, WaveLength \[Rule]  .403, 
              RayLineRGB \[Rule] {1, 0, 1}], 
            Resonate[{Move[SRLPrimary, {SRLPrimaryX, 0}], 
                Move[SRLSecondary, {SRLSecondaryX, 0}, 180]}], 
            Move[SRLFieldStop, {SRLFieldStopX, 0}], 
            Move[SRLFieldLens, {SRLFieldLensX, 0}], 
            Move[SRLCollLens1, {SRLCollLens1X, 0}], 
            Move[SRLCollLens2, {SRLCollLens2X, 0}], 
            Move[SRLCollLens3, {SRLCollLens3X, 0}], 
            Move[SRLBS1, {SRLBS1X, 0}, 30], Move[SRLBS2, {SRLBS2X, 0}, 30], 
            Move[SRLBS3, {SRLBS1X - SRLBS3Y/Sqrt[3], \(-SRLBS3Y\)}, 30], 
            Move[SRLFocusLens, {SRLFocusLensX, 0}], 
            Move[SRLFocusLens, {SRLBS1X - SRLBS3Y/Sqrt[3] + 
                  BSFLDelta, \(-SRLBS3Y\)}, 0], 
            Boundary[{0, \(-450\), \(-450\)}, {2150, 450, 450}]}, 
          PlotType \[Rule] Full3D, ColorView \[Rule] Automatic, 
          ShowArrows \[Rule] False];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .75029 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.0133867 1.01339 -0.10751 1.01339 [
[ 0 0 0 0 ]
[ 1 .75029 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .75029 L
0 .75029 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.2208 .73453 m
.23759 .45989 L
s
.18378 .49358 m
.17863 .48198 L
s
.18747 .50594 m
.18378 .49358 L
s
.18375 .49513 m .18998 .49159 L .18483 .47998 L .954 .682 .483 r
F
0 g
.18378 .49358 m
.18387 .49355 L
s
1 0 1 r
.17097 .54131 m
.2013 .53178 L
s
0 0 1 r
.17476 .54464 m
.20483 .53522 L
s
0 1 0 r
.18247 .55144 m
.21201 .54222 L
s
1 0 0 r
.18792 .55624 m
.21708 .54717 L
s
.18623 .50343 m .18998 .49159 L .18375 .49513 L .956 .689 .488 r
F
.18623 .50343 m .19368 .50397 L .18998 .49159 L F
1 0 1 r
.19209 .55991 m
.21999 .55125 L
s
.18757 .5117 m .19368 .50397 L .18623 .50343 L .957 .695 .496 r
F
.18757 .5117 m .19569 .51631 L .19368 .50397 L F
0 g
.18849 .51222 m
.18947 .51828 L
s
.18998 .49159 m
.19368 .50397 L
s
.1803 .48736 m .18483 .47998 L .17856 .46991 L .951 .675 .481 r
F
0 g
.17863 .48198 m
.17973 .48163 L
s
.17235 .47192 m
.17863 .48198 L
s
.18375 .49513 m .18483 .47998 L .1803 .48736 L .954 .682 .483 r
F
0 g
.18483 .47998 m
.18998 .49159 L
s
.18768 .51939 m .19569 .51631 L .18757 .5117 L .958 .701 .506 r
F
.18768 .51939 m .19586 .52781 L .19569 .51631 L F
0 g
.19368 .50397 m
.19569 .51631 L
s
.19586 .52781 m .18963 .52977 L .18054 .52165 L .656 .751 .92 r
F
0 g
.18951 .52128 m
.18957 .52528 L
s
.17609 .48062 m .17856 .46991 L .17157 .46203 L .947 .67 .481 r
F
0 g
.17235 .47192 m
.17386 .47143 L
s
.1803 .48736 m .17856 .46991 L .17609 .48062 L .951 .675 .481 r
F
0 g
.17856 .46991 m
.18483 .47998 L
s
.19586 .52781 m .18054 .52165 L .18768 .51939 L .656 .751 .92 r
F
.18654 .52599 m .19586 .52781 L .18768 .51939 L .956 .706 .517 r
F
.18654 .52599 m .19419 .53771 L .19586 .52781 L F
0 g
.19569 .51631 m
.19586 .52781 L
s
1 0 0 r
.16351 .53473 m
.18691 .52734 L
s
0 g
.18794 .53967 m
.1895 .53053 L
s
.02403 .57391 m
.2208 .73453 L
s
.17157 .46203 m .16536 .46406 L .16429 .47769 L .544 .324 .532 r
F
0 g
.16882 .46795 m
.17235 .47192 L
s
1 0 1 r
.1939 .52515 m
.51335 .39719 L
s
.19349 .52531 m
.1939 .52515 L
s
0 0 0 r
2 Mabswid
.19349 .52531 Mdot
1 0 1 r
.5 Mabswid
.19349 .52531 m
.194 .52524 L
s
1 0 0 r
.19359 .52484 m
.51331 .39714 L
s
.19318 .525 m
.19359 .52484 L
s
0 0 0 r
2 Mabswid
.19318 .525 Mdot
1 0 0 r
.5 Mabswid
.19318 .525 m
.19368 .52492 L
s
0 1 0 r
.19328 .52453 m
.51326 .39708 L
s
.19288 .52469 m
.19328 .52453 L
s
0 0 0 r
2 Mabswid
.19288 .52469 Mdot
0 1 0 r
.5 Mabswid
.19288 .52469 m
.19337 .52461 L
s
0 0 1 r
.19297 .52422 m
.51321 .39703 L
s
.19258 .52437 m
.19297 .52422 L
s
0 0 0 r
2 Mabswid
.19258 .52437 Mdot
0 0 1 r
.5 Mabswid
.19258 .52437 m
.19306 .5243 L
s
.1771 .49883 m .18375 .49513 L .1803 .48736 L .949 .684 .5 r
F
.17835 .503 m .18375 .49513 L .1771 .49883 L .95 .688 .503 r
F
.17835 .503 m .18623 .50343 L .18375 .49513 L F
.17902 .50715 m .18623 .50343 L .17835 .503 L .951 .691 .508 r
F
.17902 .50715 m .18757 .5117 L .18623 .50343 L F
.17609 .48062 m .17157 .46203 L .17142 .47538 L .947 .67 .481 r
F
.17157 .46203 m .16429 .47769 L .17142 .47538 L .544 .324 .532 r
F
.17142 .47538 m .17157 .46203 L .16433 .4569 L .942 .665 .485 r
F
0 g
.16536 .46406 m
.16689 .46356 L
s
.17157 .46203 m
.17856 .46991 L
s
.1581 .45894 m
.16536 .46406 L
s
.17537 .49493 m .1803 .48736 L .17609 .48062 L .947 .68 .498 r
F
.1771 .49883 m .1803 .48736 L .17537 .49493 L .949 .684 .5 r
F
.17907 .51101 m .18757 .5117 L .17902 .50715 L .951 .695 .513 r
F
.17907 .51101 m .18768 .51939 L .18757 .5117 L F
.18423 .53105 m .19419 .53771 L .18654 .52599 L .954 .708 .527 r
F
.18423 .53105 m .19075 .54533 L .19419 .53771 L F
0 g
.19419 .53771 m
.19586 .52781 L
s
.18794 .53967 m
.18813 .5396 L
s
.18449 .54729 m
.18794 .53967 L
s
.18768 .51939 m .18054 .52165 L .17137 .51346 L .656 .751 .92 r
F
0 g
.18054 .52165 m
.18621 .52671 L
s
.17325 .49155 m .17609 .48062 L .17142 .47538 L .944 .677 .499 r
F
.17537 .49493 m .17609 .48062 L .17325 .49155 L .947 .68 .498 r
F
.18768 .51939 m .17137 .51346 L .17907 .51101 L .656 .751 .92 r
F
.17849 .51431 m .18768 .51939 L .17907 .51101 L .95 .697 .519 r
F
.17849 .51431 m .18654 .52599 L .18768 .51939 L F
0 g
.18768 .51939 m
.19586 .52781 L
s
0 1 0 r
.15339 .52581 m
.17686 .51836 L
s
1 0 1 r
.14947 .52236 m
.17296 .51488 L
s
.17142 .47538 m .16429 .47769 L .16321 .4914 L .544 .324 .532 r
F
0 g
.16429 .47769 m
.16536 .46406 L
s
1 0 1 r
.18713 .51877 m
.51241 .39614 L
s
.18708 .51879 m
.18713 .51877 L
s
0 0 0 r
2 Mabswid
.18708 .51879 Mdot
1 0 1 r
.5 Mabswid
.18708 .51879 m
.18714 .51878 L
s
1 0 0 r
.18578 .5175 m
.18593 .51744 L
s
0 0 0 r
2 Mabswid
.18578 .5175 Mdot
1 0 0 r
.5 Mabswid
.18578 .5175 m
.18595 .51746 L
s
.16658 .47198 m .16433 .4569 L .15732 .45487 L .938 .663 .491 r
F
0 g
.1581 .45894 m
.1593 .45854 L
s
.17142 .47538 m .16433 .4569 L .16658 .47198 L .942 .665 .485 r
F
0 g
.16433 .4569 m
.17157 .46203 L
s
.17325 .49155 m .17142 .47538 L .1709 .48893 L .944 .677 .499 r
F
.17142 .47538 m .16321 .4914 L .1709 .48893 L .544 .324 .532 r
F
.1709 .48893 m .17142 .47538 L .16658 .47198 L .942 .674 .501 r
F
0 g
.17142 .47538 m
.17157 .46203 L
s
0 1 0 r
.18407 .51582 m
.18419 .51578 L
s
0 0 0 r
2 Mabswid
.18407 .51582 Mdot
0 1 0 r
.5 Mabswid
.18407 .51582 m
.1842 .51579 L
s
.17732 .51684 m .18654 .52599 L .17849 .51431 L .949 .699 .525 r
F
0 1 0 r
.18419 .51578 m
.512 .39568 L
s
.17732 .51684 m .18423 .53105 L .18654 .52599 L .949 .699 .525 r
F
1 0 0 r
.18593 .51744 m
.51223 .39594 L
s
.18089 .53422 m .19075 .54533 L .18423 .53105 L .951 .709 .537 r
F
.18089 .53422 m .18577 .55014 L .19075 .54533 L F
0 g
.19075 .54533 m
.19419 .53771 L
s
.18449 .54729 m
.18486 .54717 L
s
.17948 .5521 m
.18449 .54729 L
s
0 0 1 r
.18186 .51338 m
.51168 .39533 L
s
.18164 .51346 m
.18186 .51338 L
s
0 0 0 r
2 Mabswid
.18164 .51346 Mdot
0 0 1 r
.5 Mabswid
.18164 .51346 m
.18188 .51341 L
s
.17907 .51101 m .17137 .51346 L .16213 .50521 L .656 .751 .92 r
F
0 g
.17137 .51346 m
.17898 .52026 L
s
.17003 .50268 m .1771 .49883 L .17537 .49493 L .943 .685 .515 r
F
.17003 .50268 m .17835 .503 L .1771 .49883 L .944 .686 .516 r
F
.17003 .50268 m .17902 .50715 L .17835 .503 L .944 .687 .518 r
F
.17003 .50268 m .17537 .49493 L .17325 .49155 L .943 .684 .515 r
F
0 0 0 r
2 Mabswid
.13857 .51275 Mdot
.13857 .51275 Mdot
.17003 .50268 m .17907 .51101 L .17902 .50715 L .944 .688 .52 r
F
1 0 1 r
.5 Mabswid
.18044 .51232 m
.51153 .39516 L
s
0 0 0 r
2 Mabswid
.18044 .51232 Mdot
.1709 .48893 m .16321 .4914 L .16213 .50521 L .544 .324 .532 r
F
0 g
.5 Mabswid
.16321 .4914 m
.16429 .47769 L
s
.16658 .47198 m .15732 .45487 L .1619 .47066 L .938 .663 .491 r
F
0 g
.15107 .45692 m
.1581 .45894 L
s
.16848 .48724 m .16658 .47198 L .1619 .47066 L .939 .672 .504 r
F
.1709 .48893 m .16658 .47198 L .16848 .48724 L .942 .674 .501 r
F
.17003 .50268 m .17325 .49155 L .1709 .48893 L .942 .683 .515 r
F
.17907 .51101 m .16213 .50521 L .17003 .50268 L .656 .751 .92 r
F
.17003 .50268 m .17849 .51431 L .17907 .51101 L .944 .689 .522 r
F
0 g
.17907 .51101 m
.18768 .51939 L
s
.17564 .5184 m .18423 .53105 L .17732 .51684 L .947 .7 .531 r
F
.17564 .5184 m .18089 .53422 L .18423 .53105 L F
.1709 .48893 m .16213 .50521 L .17003 .50268 L .544 .324 .532 r
F
.17003 .50268 m .1709 .48893 L .16848 .48724 L .941 .682 .515 r
F
0 g
.1709 .48893 m
.17142 .47538 L
s
.17003 .50268 m .17732 .51684 L .17849 .51431 L .943 .69 .524 r
F
.1619 .47066 m .15732 .45487 L .151 .45613 L .934 .661 .499 r
F
0 g
.15107 .45692 m
.15149 .45678 L
s
.15732 .45487 m
.16433 .4569 L
s
.17326 .55375 m
.17948 .5521 L
s
.16848 .48724 m .1619 .47066 L .16614 .4866 L .939 .672 .504 r
F
.17003 .50268 m .16848 .48724 L .16614 .4866 L .94 .681 .516 r
F
.1619 .47066 m .151 .45613 L .15771 .47154 L .934 .661 .499 r
F
0 g
.14473 .45819 m
.15107 .45692 L
s
.16614 .4866 m .1619 .47066 L .15771 .47154 L .937 .671 .508 r
F
.17003 .50268 m .17564 .5184 L .17732 .51684 L .943 .69 .526 r
F
.17674 .53528 m .18577 .55014 L .18089 .53422 L .947 .709 .545 r
F
.17674 .53528 m .17956 .55178 L .18577 .55014 L F
0 g
.18577 .55014 m
.19075 .54533 L
s
.17948 .5521 m
.18577 .55014 L
s
.17003 .50268 m .16213 .50521 L .16105 .51911 L .544 .324 .532 r
F
0 g
.16651 .50912 m
.17137 .51346 L
s
.17003 .50268 m .16213 .50521 L .15282 .49689 L .656 .751 .92 r
F
0 g
.16253 .50016 m
.16321 .4914 L
s
1 0 0 r
.13857 .51275 m
.16213 .50521 L
s
.17356 .51891 m .18089 .53422 L .17564 .5184 L .944 .699 .536 r
F
.17356 .51891 m .17674 .53528 L .18089 .53422 L F
.16614 .4866 m .15771 .47154 L .16405 .48706 L .937 .671 .508 r
F
.17003 .50268 m .16614 .4866 L .16405 .48706 L .939 .681 .518 r
F
.17003 .50268 m .17356 .51891 L .17564 .5184 L .942 .69 .527 r
F
0 0 0 r
2 Mabswid
.12757 .50306 Mdot
.17003 .50268 m .16116 .4911 L .16055 .4944 L .938 .681 .523 r
F
.17003 .50268 m .16235 .48859 L .16116 .4911 L .938 .681 .522 r
F
.17003 .50268 m .16405 .48706 L .16235 .48859 L .939 .681 .52 r
F
.17003 .50268 m .17122 .51831 L .17356 .51891 L .941 .69 .529 r
F
.17003 .50268 m .16878 .51665 L .17122 .51831 L .94 .689 .53 r
F
.17003 .50268 m .16105 .51911 L .16878 .51665 L .544 .324 .532 r
F
.17003 .50268 m .16641 .51403 L .16878 .51665 L .939 .688 .53 r
F
.17003 .50268 m .16427 .51063 L .16641 .51403 L .939 .687 .53 r
F
.17003 .50268 m .16251 .50669 L .16427 .51063 L .938 .686 .529 r
F
.17003 .50268 m .16126 .50248 L .16251 .50669 L .938 .684 .528 r
F
.17003 .50268 m .15282 .49689 L .16055 .4944 L .656 .751 .92 r
F
.17003 .50268 m .16059 .49829 L .16126 .50248 L .937 .683 .527 r
F
.17003 .50268 m .16055 .4944 L .16059 .49829 L .937 .682 .525 r
F
0 g
.5 Mabswid
.17003 .50268 m
.17907 .51101 L
s
.17003 .50268 m
.1709 .48893 L
s
.16405 .48706 m .15428 .47457 L .16235 .48859 L .934 .671 .514 r
F
.16405 .48706 m .15771 .47154 L .15428 .47457 L F
.15771 .47154 m .14583 .46062 L .15428 .47457 L .93 .661 .508 r
F
.15771 .47154 m .151 .45613 L .14583 .46062 L F
0 g
.14473 .45819 m
.151 .45613 L
s
.151 .45613 m
.15732 .45487 L
s
.05524 .28803 m
.23759 .45989 L
s
.17122 .51831 m .17674 .53528 L .17356 .51891 L .942 .698 .54 r
F
0 g
.16622 .55208 m
.17326 .55375 L
s
0 0 0 r
2 Mabswid
.12357 .49953 Mdot
.17206 .53412 m .17956 .55178 L .17674 .53528 L .942 .706 .552 r
F
.17122 .51831 m .17206 .53412 L .17674 .53528 L .942 .698 .54 r
F
.16235 .48859 m .15187 .47956 L .16116 .4911 L .933 .672 .519 r
F
.16235 .48859 m .15428 .47457 L .15187 .47956 L F
0 g
.5 Mabswid
.02403 .57391 m
.05524 .28803 L
s
.16878 .51665 m .16105 .51911 L .15995 .5331 L .544 .324 .532 r
F
0 g
.16105 .51911 m
.16212 .50537 L
s
.16878 .51665 m .17206 .53412 L .17122 .51831 L .939 .696 .543 r
F
.17206 .53412 m .17254 .5501 L .17956 .55178 L .942 .706 .552 r
F
0 g
.17956 .55178 m
.18577 .55014 L
s
.17326 .55375 m
.17956 .55178 L
s
.16055 .4944 m .15282 .49689 L .14344 .48851 L .656 .751 .92 r
F
0 g
.15282 .49689 m
.16205 .50514 L
s
1 0 1 r
.12757 .50306 m
.1512 .49545 L
s
.16116 .4911 m .15065 .48618 L .16055 .4944 L .931 .674 .525 r
F
.16116 .4911 m .15187 .47956 L .15065 .48618 L F
.54042 .37431 m .55085 .36674 L .56205 .40357 L .976 .672 .338 r
F
0 g
.57106 .35206 m
.9419 .23216 L
s
.23759 .45989 m
.57106 .35206 L
s
.53033 .34993 m .55085 .36674 L .54042 .37431 L .972 .657 .326 r
F
.53033 .34993 m .53641 .33177 L .55085 .36674 L F
0 g
.55085 .36674 m
.58455 .35588 L
s
.16878 .51665 m .16717 .53081 L .17206 .53412 L .939 .696 .543 r
F
.16878 .51665 m .15995 .5331 L .16717 .53081 L .544 .324 .532 r
F
.16641 .51403 m .16717 .53081 L .16878 .51665 L .937 .693 .544 r
F
0 g
.16878 .51665 m
.17003 .50268 L
s
.15428 .47457 m .14217 .46808 L .15187 .47956 L .927 .663 .517 r
F
.15428 .47457 m .14583 .46062 L .14217 .46808 L F
0 g
.14583 .46062 m
.151 .45613 L
s
.13954 .46268 m
.14473 .45819 L
s
.54824 .40002 m .56205 .40357 L .56934 .44009 L .981 .688 .357 r
F
.54042 .37431 m .56205 .40357 L .54824 .40002 L .976 .672 .338 r
F
0 g
.55085 .36674 m
.56205 .40357 L
s
.16055 .4944 m .1507 .49397 L .16059 .49829 L .931 .676 .531 r
F
.16055 .4944 m .14344 .48851 L .15065 .48618 L .656 .751 .92 r
F
.16055 .4944 m .15065 .48618 L .1507 .49397 L .931 .676 .531 r
F
0 g
.16055 .4944 m
.17003 .50268 L
s
0 1 0 r
.12357 .49953 m
.14723 .49189 L
s
0 g
.13954 .46268 m
.13587 .47014 L
s
.13954 .46268 m
.14583 .46062 L
s
.16641 .51403 m .16241 .52558 L .16717 .53081 L .937 .693 .544 r
F
.16427 .51063 m .16241 .52558 L .16641 .51403 L .934 .69 .544 r
F
.16717 .53081 m .17254 .5501 L .17206 .53412 L .938 .702 .556 r
F
1 0 1 r
.15906 .49311 m
.50899 .39235 L
s
.15904 .49312 m
.15906 .49311 L
s
0 0 0 r
2 Mabswid
.15904 .49312 Mdot
1 0 1 r
.5 Mabswid
.15904 .49312 m
.15906 .49311 L
s
.16059 .49829 m .15204 .50239 L .16126 .50248 L .931 .679 .535 r
F
.16059 .49829 m .1507 .49397 L .15204 .50239 L F
.16427 .51063 m .1581 .51877 L .16241 .52558 L .934 .69 .544 r
F
.16251 .50669 m .1581 .51877 L .16427 .51063 L .933 .686 .542 r
F
.16126 .50248 m .15456 .51085 L .16251 .50669 L .931 .682 .539 r
F
.16126 .50248 m .15204 .50239 L .15456 .51085 L F
0 0 1 r
.15816 .49185 m
.50883 .39218 L
s
.15769 .49198 m
.15816 .49185 L
s
0 0 0 r
2 Mabswid
.15769 .49198 Mdot
0 0 1 r
.5 Mabswid
.15769 .49198 m
.15811 .49181 L
s
.16251 .50669 m .15456 .51085 L .1581 .51877 L .933 .686 .542 r
F
.16717 .53081 m .15995 .5331 L .15885 .54718 L .544 .324 .532 r
F
0 g
.15995 .5331 m
.16074 .52295 L
s
.51857 .3284 m .53641 .33177 L .53033 .34993 L .968 .646 .325 r
F
.51857 .3284 m .51956 .30077 L .53641 .33177 L F
0 g
.53641 .33177 m
.55085 .36674 L
s
.53641 .33177 m
.57012 .32072 L
s
.15187 .47956 m .1403 .478 L .15065 .48618 L .925 .666 .526 r
F
.15187 .47956 m .14217 .46808 L .1403 .478 L F
0 g
.14217 .46808 m
.14583 .46062 L
s
0 0 0 r
2 Mabswid
.1131 .49031 Mdot
0 1 0 r
.5 Mabswid
.15491 .48967 m
.50851 .39183 L
s
0 0 0 r
2 Mabswid
.15491 .48967 Mdot
.16717 .53081 m .16518 .54519 L .17254 .5501 L .938 .702 .556 r
F
0 g
.5 Mabswid
.16622 .55208 m
.17254 .5501 L
s
.17254 .5501 m
.17956 .55178 L
s
.16717 .53081 m .15885 .54718 L .16518 .54519 L .544 .324 .532 r
F
.16241 .52558 m .16518 .54519 L .16717 .53081 L .934 .697 .557 r
F
0 g
.16717 .53081 m
.16878 .51665 L
s
.15885 .54718 m
.16622 .55208 L
s
.15065 .48618 m .14344 .48851 L .13398 .48006 L .656 .751 .92 r
F
0 g
.14344 .48851 m
.15089 .49517 L
s
1 0 0 r
.15308 .48798 m
.50827 .39157 L
s
.15291 .48802 m
.15308 .48798 L
s
0 0 0 r
2 Mabswid
.15291 .48802 Mdot
1 0 0 r
.5 Mabswid
.15291 .48802 m
.15306 .48796 L
s
.55329 .42549 m .56934 .44009 L .57224 .47411 L .985 .705 .384 r
F
.54824 .40002 m .56934 .44009 L .55329 .42549 L .981 .688 .357 r
F
0 g
.56205 .40357 m
.56934 .44009 L
s
.56934 .44009 m
.60326 .42954 L
s
.56205 .40357 m
.59582 .39289 L
s
1 0 1 r
.15151 .48672 m
.50809 .39137 L
s
.15137 .48676 m
.15151 .48672 L
s
0 0 0 r
2 Mabswid
.15137 .48676 Mdot
1 0 1 r
.5 Mabswid
.15137 .48676 m
.15148 .48671 L
s
0 g
.13587 .47014 m
.14217 .46808 L
s
.15065 .48618 m .13398 .48006 L .1403 .478 L .656 .751 .92 r
F
0 g
.13398 .48006 m
.13587 .47014 L
s
1 0 0 r
.1131 .49031 m
.13683 .48261 L
s
.15065 .48618 m .14036 .48972 L .1507 .49397 L .924 .67 .535 r
F
.15065 .48618 m .1403 .478 L .14036 .48972 L F
0 g
.1403 .478 m
.15065 .48618 L
s
.15065 .48618 m
.16055 .4944 L
s
.13398 .48006 m
.14034 .48574 L
s
.58455 .35588 m
.59582 .39289 L
s
.57012 .32072 m
.58455 .35588 L
s
.16241 .52558 m .158 .53734 L .16518 .54519 L .934 .697 .557 r
F
0 g
.15885 .54718 m
.15949 .53897 L
s
.16518 .54519 m
.16717 .53081 L
s
.16518 .54519 m
.17254 .5501 L
s
.1581 .51877 m .158 .53734 L .16241 .52558 L .93 .692 .557 r
F
0 g
.59582 .39289 m
.60326 .42954 L
s
.1403 .478 m
.14217 .46808 L
s
.15885 .54718 m
.16518 .54519 L
s
.15166 .53934 m
.15885 .54718 L
s
1 0 1 r
.10526 .4834 m
.1349 .47374 L
s
.1507 .49397 m .14236 .50241 L .15204 .50239 L .924 .675 .543 r
F
.1507 .49397 m .14036 .48972 L .14236 .50241 L F
0 0 0 r
2 Mabswid
.13683 .48261 Mdot
.1581 .51877 m .15151 .5271 L .158 .53734 L .93 .692 .557 r
F
.15456 .51085 m .15151 .5271 L .1581 .51877 L .927 .686 .554 r
F
0 g
.5 Mabswid
.158 .53734 m
.16518 .54519 L
s
.15204 .50239 m .14617 .51517 L .15456 .51085 L .925 .68 .549 r
F
.15204 .50239 m .14236 .50241 L .14617 .51517 L F
0 0 1 r
.14457 .48133 m
.50727 .39048 L
s
0 0 0 r
2 Mabswid
.14457 .48133 Mdot
.15456 .51085 m .14617 .51517 L .15151 .5271 L .927 .686 .554 r
F
0 1 0 r
.5 Mabswid
.14418 .48102 m
.50722 .39043 L
s
0 0 0 r
2 Mabswid
.14418 .48102 Mdot
1 0 0 r
.5 Mabswid
.14379 .48072 m
.50717 .39037 L
s
0 0 0 r
2 Mabswid
.14379 .48072 Mdot
1 0 1 r
.5 Mabswid
.14341 .48042 m
.50713 .39032 L
s
0 0 0 r
2 Mabswid
.14341 .48042 Mdot
0 g
.5 Mabswid
.55338 .28951 m
.57012 .32072 L
s
.13398 .48006 m
.1403 .478 L
s
.13398 .48006 m
.13402 .49177 L
s
0 0 1 r
.10125 .47987 m
.13053 .47029 L
s
.50587 .31113 m .51956 .30077 L .51857 .3284 L .964 .638 .333 r
F
.50587 .31113 m .50129 .27569 L .51956 .30077 L F
0 g
.51956 .30077 m
.53641 .33177 L
s
.51956 .30077 m
.55338 .28951 L
s
.41608 .1585 m
.80123 .02024 L
s
.05524 .28803 m
.41608 .1585 L
s
.15166 .53934 m
.158 .53734 L
s
.14516 .52912 m
.15166 .53934 L
s
.1403 .478 m
.14036 .48972 L
s
.15151 .5271 m
.158 .53734 L
s
.13402 .49177 m
.13601 .50445 L
s
.13402 .49177 m
.14036 .48972 L
s
.14516 .52912 m
.15151 .5271 L
s
.13982 .5172 m
.14516 .52912 L
s
.55329 .42549 m .57224 .47411 L .55523 .4491 L .985 .705 .384 r
F
.55523 .4491 m .57224 .47411 L .5705 .5035 L .987 .718 .414 r
F
0 0 1 r
.19306 .5243 m
.56024 .46693 L
s
0 1 0 r
.19337 .52461 m
.56054 .468 L
s
1 0 0 r
.19368 .52492 m
.56084 .46907 L
s
1 0 1 r
.194 .52524 m
.56114 .47014 L
s
0 0 1 r
.20987 .57558 m
.5605 .46785 L
s
0 1 0 r
.21086 .57645 m
.56081 .46899 L
s
1 0 0 r
.21184 .57732 m
.56113 .47013 L
s
1 0 1 r
.21283 .57819 m
.56145 .47126 L
s
.564 .46161 m .60639 .46366 L .57224 .47411 L .656 .751 .92 r
F
0 g
.56934 .44009 m
.5712 .46196 L
s
1 0 1 r
.56878 .46902 m
.56891 .46897 L
s
1 0 0 r
.56808 .46799 m
.56824 .46795 L
s
0 1 0 r
.56739 .46697 m
.56756 .46692 L
s
0 0 1 r
.56669 .46595 m
.56688 .46589 L
s
1 0 1 r
.56876 .469 m
.56891 .46897 L
s
1 0 0 r
.56807 .46797 m
.56824 .46795 L
s
0 1 0 r
.56737 .46695 m
.56756 .46692 L
s
0 0 1 r
.56668 .46592 m
.56688 .46589 L
s
0 g
.14036 .48972 m
.14236 .50241 L
s
.13601 .50445 m
.13982 .5172 L
s
.13601 .50445 m
.14236 .50241 L
s
.13982 .5172 m
.14617 .51517 L
s
.14617 .51517 m
.15151 .5271 L
s
.14236 .50241 m
.14617 .51517 L
s
0 0 0 r
2 Mabswid
.56891 .46897 Mdot
.56824 .46795 Mdot
.56756 .46692 Mdot
.56688 .46589 Mdot
.528 .38265 m .54042 .37431 L .54824 .40002 L .976 .681 .384 r
F
.52239 .36914 m .54042 .37431 L .528 .38265 L .974 .672 .378 r
F
.52239 .36914 m .53033 .34993 L .54042 .37431 L F
.53233 .39691 m .54824 .40002 L .55329 .42549 L .979 .69 .396 r
F
.528 .38265 m .54824 .40002 L .53233 .39691 L .976 .681 .384 r
F
.564 .46161 m .59583 .45181 L .60639 .46366 L .656 .751 .92 r
F
0 g
.5 Mabswid
.60494 .4931 m
.60639 .46366 L
s
.60326 .42954 m
.60639 .46366 L
s
.57224 .47411 m
.60639 .46366 L
s
.55523 .4491 m .59583 .45181 L .564 .46161 L .656 .751 .92 r
F
0 g
.564 .46161 m
.57224 .47411 L
s
.50129 .27569 m .53549 .28263 L .50378 .29325 L .544 .324 .532 r
F
0 g
.51206 .29048 m
.51956 .30077 L
s
.50129 .27569 m .5353 .26421 L .53549 .28263 L .544 .324 .532 r
F
0 g
.5353 .26421 m
.55338 .28951 L
s
.49303 .29928 m .50129 .27569 L .50587 .31113 L .96 .633 .349 r
F
.49303 .29928 m .4827 .25822 L .50129 .27569 L F
0 g
.50129 .27569 m
.5353 .26421 L
s
.51587 .35727 m .53033 .34993 L .52239 .36914 L .971 .665 .376 r
F
.51587 .35727 m .51857 .3284 L .53033 .34993 L F
.5351 .41101 m .55329 .42549 L .55523 .4491 L .981 .699 .411 r
F
.53233 .39691 m .55329 .42549 L .5351 .41101 L .979 .69 .396 r
F
.55392 .46935 m .5705 .5035 L .56409 .52629 L .987 .729 .444 r
F
0 g
.57808 .63349 m
.97468 .52133 L
s
.2208 .73453 m
.57808 .63349 L
s
.55523 .4491 m .5705 .5035 L .55392 .46935 L .987 .718 .414 r
F
0 g
.5705 .5035 m
.57224 .47411 L
s
.5705 .5035 m
.60494 .4931 L
s
.50885 .34783 m .51857 .3284 L .51587 .35727 L .967 .659 .38 r
F
.50885 .34783 m .50587 .31113 L .51857 .3284 L F
.55523 .4491 m .58514 .43982 L .59583 .45181 L .656 .751 .92 r
F
0 g
.59583 .45181 m
.60639 .46366 L
s
.51697 .24653 m
.5353 .26421 L
s
.50378 .29325 m .53569 .30122 L .50587 .31113 L .544 .324 .532 r
F
.50378 .29325 m .53549 .28263 L .53569 .30122 L F
0 g
.50129 .27569 m
.50378 .29325 L
s
.5353 .26421 m
.53549 .28263 L
s
.5351 .41101 m .55523 .4491 L .53614 .42403 L .981 .699 .411 r
F
.53614 .42403 m .55523 .4491 L .55392 .46935 L .981 .707 .428 r
F
1 0 0 r
.18595 .51746 m
.54422 .44464 L
s
0 1 0 r
.1842 .51579 m
.54192 .43876 L
s
1 0 0 r
.21708 .54717 m
.54448 .44529 L
s
0 1 0 r
.21201 .54222 m
.54208 .43918 L
s
1 0 1 r
.18714 .51878 m
.54598 .44911 L
s
.21999 .55125 m
.54631 .44995 L
s
.54595 .43657 m .58514 .43982 L .55523 .4491 L .656 .751 .92 r
F
0 g
.55523 .4491 m
.564 .46161 L
s
1 0 0 r
.55083 .44331 m
.55098 .44327 L
s
.55082 .4433 m
.55098 .44327 L
s
1 0 1 r
.55405 .44755 m
.5541 .44753 L
s
.55405 .44754 m
.5541 .44753 L
s
0 g
.80123 .02024 m
.9419 .23216 L
s
.9419 .23216 m
.97468 .52133 L
s
0 0 0 r
2 Mabswid
.5541 .44753 Mdot
0 g
.5 Mabswid
.60494 .4931 m
.59888 .5159 L
s
0 0 0 r
2 Mabswid
.55098 .44327 Mdot
.50587 .31113 m .53589 .31999 L .50756 .32932 L .544 .324 .532 r
F
.50587 .31113 m .53569 .30122 L .53589 .31999 L F
0 g
.5 Mabswid
.53549 .28263 m
.53569 .30122 L
s
.5018 .34145 m .50587 .31113 L .50885 .34783 L .964 .655 .388 r
F
.5018 .34145 m .49303 .29928 L .50587 .31113 L F
0 g
.50378 .29325 m
.50587 .31113 L
s
.54595 .43657 m .57434 .4277 L .58514 .43982 L .656 .751 .92 r
F
0 g
.58514 .43982 m
.59583 .45181 L
s
0 1 0 r
.54659 .43775 m
.54681 .43771 L
s
.5466 .43777 m
.54681 .43771 L
s
.48087 .29374 m .4827 .25822 L .49303 .29928 L .956 .632 .37 r
F
.48087 .29374 m .46498 .24971 L .4827 .25822 L F
0 g
.4827 .25822 m
.50129 .27569 L
s
.4827 .25822 m
.51697 .24653 L
s
0 0 0 r
2 Mabswid
.54681 .43771 Mdot
.53614 .42403 m .57434 .4277 L .54595 .43657 L .656 .751 .92 r
F
0 g
.5 Mabswid
.54595 .43657 m
.55523 .4491 L
s
.55392 .46935 m .56409 .52629 L .54937 .48487 L .987 .729 .444 r
F
.53535 .43511 m .55392 .46935 L .54937 .48487 L .981 .713 .446 r
F
.53614 .42403 m .55392 .46935 L .53535 .43511 L .981 .707 .428 r
F
1 0 1 r
.2013 .53178 m
.53595 .42661 L
s
0 0 1 r
.20483 .53522 m
.53561 .4315 L
s
.18188 .51341 m
.53564 .43107 L
s
1 0 1 r
.18044 .51232 m
.53596 .42648 L
s
0 0 1 r
.54062 .42991 m
.54077 .42987 L
s
.54062 .42992 m
.54077 .42987 L
s
.51253 .38945 m .528 .38265 L .5135 .39178 L .971 .682 .421 r
F
.51253 .38945 m .52239 .36914 L .528 .38265 L F
.5135 .39178 m .528 .38265 L .53233 .39691 L .972 .685 .423 r
F
.51425 .39425 m .53233 .39691 L .5351 .41101 L .973 .689 .428 r
F
.5135 .39178 m .53233 .39691 L .51425 .39425 L .972 .685 .423 r
F
.54937 .48487 m .56409 .52629 L .5533 .54081 L .984 .734 .471 r
F
0 g
.56409 .52629 m
.59888 .5159 L
s
.56409 .52629 m
.5705 .5035 L
s
.5114 .38741 m .52239 .36914 L .51253 .38945 L .97 .679 .42 r
F
.5114 .38741 m .51587 .35727 L .52239 .36914 L F
0 0 0 r
2 Mabswid
.54077 .42987 Mdot
.50756 .32932 m .53609 .33893 L .50885 .34783 L .544 .324 .532 r
F
.50756 .32932 m .53589 .31999 L .53609 .33893 L F
0 g
.5 Mabswid
.50587 .31113 m
.50756 .32932 L
s
.53569 .30122 m
.53589 .31999 L
s
.51473 .39668 m .5351 .41101 L .53614 .42403 L .974 .693 .434 r
F
.51425 .39425 m .5351 .41101 L .51473 .39668 L .973 .689 .428 r
F
0 g
.49956 .23785 m
.51697 .24653 L
s
.53614 .42403 m .56342 .41545 L .57434 .4277 L .656 .751 .92 r
F
1 0 1 r
.53769 .42607 m
.53775 .42605 L
s
.53768 .42606 m
.53775 .42605 L
s
0 g
.57434 .4277 m
.58514 .43982 L
s
0 0 0 r
2 Mabswid
.53775 .42605 Mdot
.51019 .3858 m .51587 .35727 L .5114 .38741 L .968 .676 .421 r
F
.51019 .3858 m .50885 .34783 L .51587 .35727 L F
.49517 .3386 m .49303 .29928 L .5018 .34145 L .961 .654 .4 r
F
.49517 .3386 m .48087 .29374 L .49303 .29928 L F
.51473 .39668 m .53614 .42403 L .5149 .39892 L .974 .693 .434 r
F
.5149 .39892 m .53614 .42403 L .53535 .43511 L .974 .696 .44 r
F
.52579 .41148 m .56342 .41545 L .53614 .42403 L .656 .751 .92 r
F
0 g
.5 Mabswid
.53614 .42403 m
.54595 .43657 L
s
.59888 .5159 m
.58845 .53036 L
s
.54937 .48487 m .5533 .54081 L .5418 .49453 L .984 .734 .471 r
F
.53277 .4435 m .54937 .48487 L .5418 .49453 L .979 .717 .463 r
F
.53535 .43511 m .54937 .48487 L .53277 .4435 L .981 .713 .446 r
F
.50885 .34783 m .53629 .35805 L .50973 .36665 L .544 .324 .532 r
F
.50885 .34783 m .53609 .33893 L .53629 .35805 L F
0 g
.53589 .31999 m
.53609 .33893 L
s
.50898 .38473 m .50885 .34783 L .51019 .3858 L .967 .675 .424 r
F
.50898 .38473 m .5018 .34145 L .50885 .34783 L F
0 g
.50756 .32932 m
.50885 .34783 L
s
.51475 .40081 m .53535 .43511 L .53277 .4435 L .973 .698 .447 r
F
0 g
.53213 .41917 m
.53614 .42403 L
s
.5149 .39892 m .53535 .43511 L .51475 .40081 L .974 .696 .44 r
F
.52579 .41148 m .55237 .40306 L .56342 .41545 L .656 .751 .92 r
F
0 g
.56342 .41545 m
.57434 .4277 L
s
.47025 .29504 m .46498 .24971 L .48087 .29374 L .951 .634 .394 r
F
.47025 .29504 m .44933 .25105 L .46498 .24971 L F
0 g
.46498 .24971 m
.4827 .25822 L
s
.46498 .24971 m
.49956 .23785 L
s
.5149 .39892 m .55237 .40306 L .52579 .41148 L .656 .751 .92 r
F
0 g
.52579 .41148 m
.53213 .41917 L
s
.50786 .38427 m .5018 .34145 L .50898 .38473 L .965 .674 .428 r
F
0 g
.50885 .34783 m
.50919 .35513 L
s
.50786 .38427 m .49517 .3386 L .5018 .34145 L .965 .674 .428 r
F
.50973 .36665 m .53649 .37735 L .51019 .3858 L .544 .324 .532 r
F
.50973 .36665 m .53629 .35805 L .53649 .37735 L F
0 g
.50919 .35513 m
.50973 .36665 L
s
.50973 .36665 m
.51019 .3858 L
s
.53609 .33893 m
.53629 .35805 L
s
.53277 .4435 m .5418 .49453 L .52855 .44861 L .979 .717 .463 r
F
.51429 .40222 m .53277 .4435 L .52855 .44861 L .972 .699 .454 r
F
.51475 .40081 m .53277 .4435 L .51429 .40222 L .973 .698 .447 r
F
0 g
.52069 .40561 m
.52579 .41148 L
s
.48944 .33952 m .48087 .29374 L .49517 .3386 L .958 .654 .414 r
F
.48944 .33952 m .47025 .29504 L .48087 .29374 L F
.5418 .49453 m .5533 .54081 L .53868 .54576 L .98 .735 .494 r
F
0 g
.5533 .54081 m
.58845 .53036 L
s
.5533 .54081 m
.56409 .52629 L
s
.48425 .23905 m
.49956 .23785 L
s
.5149 .39892 m .5412 .39052 L .55237 .40306 L .656 .751 .92 r
F
0 g
.5412 .39052 m
.55237 .40306 L
s
.51597 .40015 m
.52069 .40561 L
s
.55237 .40306 m
.56342 .41545 L
s
.5149 .39892 m
.51597 .40015 L
s
.5418 .49453 m .53868 .54576 L .53167 .49754 L .98 .735 .494 r
F
.52855 .44861 m .5418 .49453 L .53167 .49754 L .976 .718 .477 r
F
.50689 .38447 m .49517 .3386 L .50786 .38427 L .964 .674 .434 r
F
.50689 .38447 m .48944 .33952 L .49517 .3386 L F
0 g
.5135 .39178 m
.51425 .39425 L
s
.51355 .39176 m
.53979 .38336 L
s
.51352 .39177 m
.51355 .39176 L
s
.5135 .39178 m
.51352 .39177 L
s
.51253 .38945 m
.5135 .39178 L
s
.51425 .39425 m
.51473 .39668 L
s
.51435 .39422 m
.54054 .38584 L
s
.5143 .39423 m
.51435 .39422 L
s
.51427 .39424 m
.5143 .39423 L
s
.51425 .39425 m
.51427 .39424 L
s
.53629 .35805 m
.53649 .37735 L
s
.51255 .38944 m
.53881 .38102 L
s
.51253 .38945 m
.51255 .38944 L
s
.5114 .38741 m
.51253 .38945 L
s
.51473 .39668 m
.5149 .39892 L
s
.51482 .39665 m
.54102 .38828 L
s
.51473 .39668 m
.51482 .39665 L
s
.5114 .38741 m
.53769 .37897 L
s
.51019 .3858 m
.5114 .38741 L
s
.5149 .39892 m
.5412 .39052 L
s
.51475 .40081 m
.5149 .39892 L
s
.51019 .3858 m
.53649 .37735 L
s
.50898 .38473 m
.51019 .3858 L
s
.52855 .44861 m .53167 .49754 L .52296 .45004 L .976 .718 .477 r
F
.51356 .40306 m .52855 .44861 L .52296 .45004 L .971 .7 .46 r
F
.51429 .40222 m .52855 .44861 L .51356 .40306 L .972 .699 .454 r
F
0 g
.51429 .40222 m
.51475 .40081 L
s
0 0 0 r
2 Mabswid
.51335 .39719 Mdot
.51331 .39714 Mdot
.51326 .39708 Mdot
.51321 .39703 Mdot
0 g
.5 Mabswid
.50786 .38427 m
.50898 .38473 L
s
0 0 0 r
2 Mabswid
.51241 .39614 Mdot
.51223 .39594 Mdot
.512 .39568 Mdot
.51168 .39533 Mdot
.51153 .39516 Mdot
0 g
.5 Mabswid
.58845 .53036 m
.5742 .53522 L
s
.51356 .40306 m .52296 .45004 L .5126 .40327 L .971 .7 .46 r
F
0 g
.51356 .40306 m
.51429 .40222 L
s
.50615 .38529 m .48944 .33952 L .50689 .38447 L .962 .674 .44 r
F
0 g
.50689 .38447 m
.50786 .38427 L
s
.5126 .40327 m .51637 .44764 L .51147 .40283 L .97 .699 .465 r
F
0 g
.51356 .40306 m
.51357 .40306 L
s
.5126 .40327 m .52296 .45004 L .51637 .44764 L .97 .699 .465 r
F
0 g
.5126 .40327 m
.51356 .40306 L
s
0 0 0 r
2 Mabswid
.50899 .39235 Mdot
.50883 .39218 Mdot
0 g
.5 Mabswid
.53979 .38336 m
.54054 .38584 L
s
.53881 .38102 m
.53979 .38336 L
s
.54054 .38584 m
.54102 .38828 L
s
0 0 0 r
2 Mabswid
.50851 .39183 Mdot
0 g
.5 Mabswid
.53769 .37897 m
.53881 .38102 L
s
0 0 0 r
2 Mabswid
.50827 .39157 Mdot
0 g
.5 Mabswid
.54102 .38828 m
.5412 .39052 L
s
.50615 .38529 m .48499 .34419 L .48944 .33952 L .962 .674 .44 r
F
.50569 .3867 m .48499 .34419 L .50615 .38529 L .962 .676 .447 r
F
0 g
.50615 .38529 m
.50689 .38447 L
s
.50615 .38529 m
.50617 .38529 L
s
0 0 0 r
2 Mabswid
.50809 .39137 Mdot
.51147 .40283 m .50921 .44154 L .51026 .40177 L .968 .698 .469 r
F
.51147 .40283 m .51637 .44764 L .50921 .44154 L F
0 g
.5 Mabswid
.51147 .40283 m
.5126 .40327 L
s
.5126 .40327 m
.51261 .40327 L
s
.51357 .40306 m
.51361 .40305 L
s
.53649 .37735 m
.53769 .37897 L
s
.48499 .34419 m .47025 .29504 L .48944 .33952 L .955 .657 .43 r
F
0 g
.54107 .39242 m
.5412 .39052 L
s
0 0 0 r
2 Mabswid
.50727 .39048 Mdot
.50722 .39043 Mdot
.50717 .39037 Mdot
.50713 .39032 Mdot
.50569 .3867 m .48216 .35234 L .48499 .34419 L .962 .676 .447 r
F
.50553 .38859 m .48216 .35234 L .50569 .3867 L .961 .678 .453 r
F
0 g
.5 Mabswid
.50569 .3867 m
.50615 .38529 L
s
.50569 .3867 m
.5057 .38669 L
s
.53529 .37627 m
.53649 .37735 L
s
.51026 .40177 m .50198 .43211 L .50904 .40016 L .966 .696 .471 r
F
.51026 .40177 m .50921 .44154 L .50198 .43211 L F
.51026 .40177 m .53687 .41298 L .50995 .42149 L .544 .324 .532 r
F
.51026 .40177 m .53666 .39335 L .53687 .41298 L F
0 g
.53668 .39509 m
.54063 .39383 L
s
.53667 .39479 m
.53786 .39442 L
s
.53668 .39559 m
.53897 .39487 L
s
.53668 .39569 m
.53991 .39467 L
s
.51026 .40177 m
.53666 .39335 L
s
.53666 .39382 m
.54107 .39242 L
s
.54107 .39242 m
.54063 .39383 L
s
.50553 .38859 m .48117 .36344 L .48216 .35234 L .961 .678 .453 r
F
.5057 .39084 m .48117 .36344 L .50553 .38859 L .961 .681 .459 r
F
.49363 .37602 m .53193 .38011 L .50553 .38859 L .656 .751 .92 r
F
0 g
.50553 .38859 m
.50558 .38857 L
s
1 0 1 r
.51335 .39719 m
.53825 .38722 L
s
1 0 0 r
.51331 .39714 m
.53823 .38718 L
s
0 1 0 r
.51326 .39708 m
.5382 .38715 L
s
0 0 1 r
.51321 .39703 m
.53817 .38712 L
s
1 0 1 r
.51241 .39614 m
.53771 .3866 L
s
1 0 0 r
.51223 .39594 m
.53761 .38649 L
s
0 1 0 r
.512 .39568 m
.53748 .38635 L
s
0 0 1 r
.51168 .39533 m
.53731 .38615 L
s
1 0 1 r
.51153 .39516 m
.53723 .38606 L
s
0 g
.52761 .37965 m
.53206 .37822 L
s
1 0 1 r
.50713 .39032 m
.53489 .38344 L
s
1 0 0 r
.50717 .39037 m
.53492 .38348 L
s
0 1 0 r
.50722 .39043 m
.53495 .38351 L
s
0 0 1 r
.50727 .39048 m
.53498 .38354 L
s
1 0 1 r
.50809 .39137 m
.53544 .38406 L
s
0 g
.52467 .37934 m
.53251 .37681 L
s
1 0 0 r
.50827 .39157 m
.53554 .38417 L
s
0 1 0 r
.50851 .39183 m
.53567 .38431 L
s
0 0 1 r
.50883 .39218 m
.53584 .38451 L
s
1 0 1 r
.50899 .39235 m
.53592 .3846 L
s
0 g
.52329 .37919 m
.53323 .37599 L
s
.52357 .37922 m
.53418 .37581 L
s
.52548 .37942 m
.53529 .37627 L
s
.46191 .30325 m .44933 .25105 L .47025 .29504 L .947 .639 .419 r
F
.48499 .34419 m .46191 .30325 L .47025 .29504 L .955 .657 .43 r
F
.50904 .40016 m .49521 .42001 L .50791 .39811 L .964 .694 .472 r
F
.50904 .40016 m .50198 .43211 L .49521 .42001 L F
0 g
.50904 .40016 m
.51026 .40177 L
s
.50904 .40016 m
.53545 .39173 L
s
.53418 .37581 m
.53529 .37627 L
s
.54063 .39383 m
.53991 .39467 L
s
.5057 .39084 m .48209 .37674 L .48117 .36344 L .961 .681 .459 r
F
.50617 .39329 m .48209 .37674 L .5057 .39084 L .961 .684 .464 r
F
0 g
.50437 .38737 m
.50553 .38859 L
s
.50553 .38859 m
.5057 .39084 L
s
.5057 .39084 m
.50579 .39081 L
s
.50791 .39811 m .48937 .40607 L .50693 .39577 L .963 .69 .471 r
F
.50791 .39811 m .49521 .42001 L .48937 .40607 L F
0 g
.50791 .39811 m
.50904 .40016 L
s
.50791 .39811 m
.53432 .38967 L
s
.52296 .45004 m .5196 .49353 L .51637 .44764 L .972 .716 .489 r
F
.52296 .45004 m .53167 .49754 L .5196 .49353 L F
1 0 1 r
.53825 .38722 m
.56438 .37675 L
s
0 0 0 r
2 Mabswid
.53825 .38722 Mdot
1 0 0 r
.5 Mabswid
.53823 .38718 m
.56437 .37674 L
s
0 0 0 r
2 Mabswid
.53823 .38718 Mdot
0 1 0 r
.5 Mabswid
.5382 .38715 m
.56436 .37673 L
s
0 0 0 r
2 Mabswid
.5382 .38715 Mdot
.50617 .39329 m .48489 .39129 L .48209 .37674 L .961 .684 .464 r
F
0 g
.5 Mabswid
.50579 .39081 m
.5321 .38237 L
s
.49923 .38193 m
.50437 .38737 L
s
.50693 .39577 m .48489 .39129 L .50617 .39329 L .962 .687 .468 r
F
0 g
.5057 .39084 m
.50617 .39329 L
s
0 0 1 r
.53817 .38712 m
.56435 .37672 L
s
0 0 0 r
2 Mabswid
.53817 .38712 Mdot
.50693 .39577 m .48937 .40607 L .48489 .39129 L .962 .687 .468 r
F
0 g
.5 Mabswid
.50693 .39577 m
.53334 .38731 L
s
.50693 .39577 m
.50791 .39811 L
s
.50617 .39329 m
.50693 .39577 L
s
.50617 .39329 m
.53259 .38482 L
s
.46191 .30325 m .43691 .26251 L .44933 .25105 L .947 .639 .419 r
F
0 g
.44933 .25105 m
.48425 .23905 L
s
.44933 .25105 m
.46498 .24971 L
s
1 0 1 r
.53771 .3866 m
.56424 .3766 L
s
0 0 0 r
2 Mabswid
.53771 .3866 Mdot
1 0 0 r
.5 Mabswid
.53761 .38649 m
.56422 .37658 L
s
0 0 0 r
2 Mabswid
.53761 .38649 Mdot
0 g
.5 Mabswid
.53323 .37599 m
.53418 .37581 L
s
0 1 0 r
.53748 .38635 m
.5642 .37656 L
s
0 0 0 r
2 Mabswid
.53748 .38635 Mdot
0 0 1 r
.5 Mabswid
.53731 .38615 m
.56418 .37653 L
s
0 0 0 r
2 Mabswid
.53731 .38615 Mdot
1 0 1 r
.5 Mabswid
.53723 .38606 m
.56418 .37653 L
s
0 0 0 r
2 Mabswid
.53723 .38606 Mdot
0 g
.5 Mabswid
.53991 .39467 m
.53897 .39487 L
s
.53251 .37681 m
.53323 .37599 L
s
1 0 1 r
.53592 .3846 m
.56413 .37648 L
s
0 0 0 r
2 Mabswid
.53592 .3846 Mdot
0 0 1 r
.5 Mabswid
.53584 .38451 m
.56413 .37647 L
s
0 0 0 r
2 Mabswid
.53584 .38451 Mdot
0 1 0 r
.5 Mabswid
.53567 .38431 m
.56411 .37645 L
s
0 0 0 r
2 Mabswid
.53567 .38431 Mdot
0 g
.5 Mabswid
.53897 .39487 m
.53786 .39442 L
s
1 0 0 r
.53554 .38417 m
.56409 .37642 L
s
0 0 0 r
2 Mabswid
.53554 .38417 Mdot
1 0 1 r
.5 Mabswid
.53544 .38406 m
.56407 .3764 L
s
0 0 0 r
2 Mabswid
.53544 .38406 Mdot
.53498 .38354 Mdot
.53495 .38351 Mdot
.53492 .38348 Mdot
1 0 1 r
.5 Mabswid
.53489 .38344 m
.56393 .37625 L
s
0 0 0 r
2 Mabswid
.53489 .38344 Mdot
0 g
.5 Mabswid
.53206 .37822 m
.53251 .37681 L
s
.53167 .49754 m .52113 .54047 L .5196 .49353 L .973 .732 .512 r
F
.53167 .49754 m .53868 .54576 L .52113 .54047 L F
0 g
.53868 .54576 m
.5533 .54081 L
s
.53666 .39335 m
.53786 .39442 L
s
.53545 .39173 m
.53666 .39335 L
s
.48216 .35234 m .46191 .30325 L .48499 .34419 L .953 .661 .445 r
F
.49363 .37602 m .52052 .36732 L .53193 .38011 L .656 .751 .92 r
F
0 g
.53193 .38011 m
.5321 .38237 L
s
.53193 .38011 m
.53206 .37822 L
s
.50558 .38857 m
.53193 .38011 L
s
.56536 .37575 m .56573 .37552 L .56611 .37677 L .971 .686 .432 r
F
.56499 .37485 m .56573 .37552 L .56536 .37575 L F
.56499 .37485 m .56524 .37435 L .56573 .37552 L F
.56565 .37671 m .56611 .37677 L .56635 .378 L F
.56536 .37575 m .56611 .37677 L .56565 .37671 L F
0 g
.56573 .37552 m
.56611 .37677 L
s
.53545 .39173 m
.53432 .38967 L
s
.56456 .37406 m .56524 .37435 L .56499 .37485 L .971 .686 .432 r
F
.56456 .37406 m .56468 .37331 L .56524 .37435 L F
0 g
.56524 .37435 m
.56573 .37552 L
s
.56584 .37765 m .56635 .378 L .56645 .37912 L .971 .686 .432 r
F
.56565 .37671 m .56635 .378 L .56584 .37765 L F
0 g
.56611 .37677 m
.56635 .378 L
s
.5641 .37343 m .56468 .37331 L .56456 .37406 L .971 .686 .432 r
F
.5641 .37343 m .56409 .3725 L .56468 .37331 L F
0 g
.56468 .37331 m
.56524 .37435 L
s
.56788 .37483 m
.56826 .37608 L
s
.56823 .37472 m
.56788 .37483 L
s
.5674 .37365 m
.56788 .37483 L
s
.56826 .37608 m
.56851 .37731 L
s
.56861 .37597 m
.56826 .37608 L
s
.53259 .38482 m
.5321 .38237 L
s
.56584 .37765 m .56645 .37912 L .56591 .37851 L .971 .686 .432 r
F
.56591 .37851 m .56645 .37912 L .56639 .38007 L F
0 g
.56635 .378 m
.56645 .37912 L
s
.56499 .37598 m .56536 .37575 L .56565 .37671 L .971 .686 .432 r
F
.56473 .37535 m .56536 .37575 L .56499 .37598 L F
.56473 .37535 m .56499 .37485 L .56536 .37575 L F
0 g
.56861 .37597 m
.56823 .37472 L
s
.56823 .37472 m
.56774 .37354 L
s
.5652 .37664 m .56565 .37671 L .56584 .37765 L .971 .686 .432 r
F
.56499 .37598 m .56565 .37671 L .5652 .37664 L F
0 g
.56885 .3772 m
.56861 .37597 L
s
.50995 .42149 m .53707 .43281 L .50921 .44154 L .544 .324 .532 r
F
.50995 .42149 m .53687 .41298 L .53707 .43281 L F
0 g
.50995 .42149 m
.51026 .40177 L
s
.53666 .39335 m
.53687 .41298 L
s
.56774 .37354 m
.5674 .37365 L
s
.56684 .37262 m
.5674 .37365 L
s
.56444 .3748 m .56499 .37485 L .56473 .37535 L .971 .686 .432 r
F
.56444 .3748 m .56456 .37406 L .56499 .37485 L F
0 g
.53432 .38967 m
.53334 .38731 L
s
.56885 .3772 m
.56851 .37731 L
s
.56774 .37354 m
.56718 .37251 L
s
.56533 .3773 m .56584 .37765 L .56591 .37851 L .971 .686 .432 r
F
.5652 .37664 m .56584 .37765 L .56533 .3773 L F
.56365 .37301 m .56409 .3725 L .5641 .37343 L F
.56365 .37301 m .56349 .37195 L .56409 .3725 L F
0 g
.56409 .3725 m
.56468 .37331 L
s
.56412 .37436 m .56456 .37406 L .56444 .3748 L .971 .686 .432 r
F
.56412 .37436 m .5641 .37343 L .56456 .37406 L F
0 g
.53334 .38731 m
.53259 .38482 L
s
.56718 .37251 m
.56684 .37262 L
s
.53868 .54576 m
.5742 .53522 L
s
.56591 .37851 m .56639 .38007 L .56587 .37924 L .971 .686 .432 r
F
.56533 .3773 m .56591 .37851 L .56538 .3779 L F
.56538 .3779 m .56591 .37851 L .56587 .37924 L F
.56587 .37924 m .56639 .38007 L .56618 .38077 L F
0 g
.56639 .38007 m
.56645 .37912 L
s
.56687 .37787 m .56861 .37843 L .56895 .37832 L .656 .751 .92 r
F
0 g
.56885 .3772 m
.56895 .37832 L
s
.56851 .37731 m
.56859 .37824 L
s
.56687 .37787 m .56784 .37756 L .56861 .37843 L .656 .751 .92 r
F
0 g
.56861 .37843 m
.56895 .37832 L
s
.56855 .37938 m
.56861 .37843 L
s
.56889 .37927 m
.56895 .37832 L
s
.56463 .37621 m .56499 .37598 L .5652 .37664 L .971 .686 .432 r
F
.56448 .37585 m .56499 .37598 L .56463 .37621 L F
.56448 .37585 m .56473 .37535 L .56499 .37598 L F
.56474 .37658 m .5652 .37664 L .56533 .3773 L F
.56463 .37621 m .5652 .37664 L .56474 .37658 L F
.56431 .37554 m .56473 .37535 L .56448 .37585 L F
.56431 .37554 m .56444 .3748 L .56473 .37535 L F
.5638 .37408 m .5641 .37343 L .56412 .37436 L F
.5638 .37408 m .56365 .37301 L .5641 .37343 L F
.56481 .37695 m .56533 .3773 L .56538 .3779 L F
.56474 .37658 m .56533 .3773 L .56481 .37695 L F
.56587 .37924 m .56618 .38077 L .56571 .37978 L F
.56535 .3784 m .56587 .37924 L .56571 .37978 L F
.56538 .3779 m .56587 .37924 L .56535 .3784 L F
.56659 .3717 m .56624 .37181 L .56627 .37314 L .544 .324 .532 r
F
0 g
.56649 .37214 m
.56684 .37262 L
s
.56413 .3753 m .56444 .3748 L .56431 .37554 L .971 .686 .432 r
F
.56413 .3753 m .56412 .37436 L .56444 .3748 L F
.56323 .37284 m .56349 .37195 L .56365 .37301 L F
.56323 .37284 m .56295 .37172 L .56349 .37195 L F
0 g
.56349 .37195 m
.56409 .3725 L
s
.56481 .37695 m .56538 .3779 L .56484 .37729 L .971 .686 .432 r
F
.56484 .37729 m .56538 .3779 L .56535 .3784 L F
.56659 .3717 m .56627 .37314 L .5653 .37345 L .544 .324 .532 r
F
0 g
.566 .37115 m
.56659 .3717 L
s
.56659 .3717 m
.56718 .37251 L
s
.56624 .37181 m
.56659 .3717 L
s
.56565 .37126 m
.56624 .37181 L
s
.56547 .3772 m .56784 .37756 L .56687 .37787 L .656 .751 .92 r
F
0 g
.56687 .37787 m
.56895 .37832 L
s
.56855 .37938 m
.56834 .38008 L
s
.56889 .37927 m
.56855 .37938 L
s
.56571 .37978 m .56618 .38077 L .56583 .38119 L .971 .686 .432 r
F
0 g
.56618 .38077 m
.56639 .38007 L
s
.56868 .37997 m
.56889 .37927 L
s
.56396 .37514 m .56412 .37436 L .56413 .3753 L .971 .686 .432 r
F
.56396 .37514 m .5638 .37408 L .56412 .37436 L F
.56351 .37395 m .56365 .37301 L .5638 .37408 L F
.56351 .37395 m .56323 .37284 L .56365 .37301 L F
.5653 .37345 m .56629 .37447 L .56468 .37499 L .544 .324 .532 r
F
.5653 .37345 m .56627 .37314 L .56629 .37447 L F
0 g
.5653 .37345 m
.56659 .3717 L
s
.56624 .37181 m
.56627 .37314 L
s
.56547 .3772 m .56708 .37668 L .56784 .37756 L .656 .751 .92 r
F
0 g
.56784 .37756 m
.56861 .37843 L
s
.56535 .3784 m .56571 .37978 L .56523 .37878 L .971 .686 .432 r
F
.56483 .37757 m .56535 .3784 L .56523 .37878 L F
.56484 .37729 m .56535 .3784 L .56483 .37757 L F
0 g
.56463 .37621 m
.56474 .37658 L
s
.56448 .37585 m
.56463 .37621 L
s
.56474 .37658 m
.56481 .37695 L
s
.51637 .44764 m .5064 .48259 L .50921 .44154 L .967 .713 .497 r
F
.51637 .44764 m .5196 .49353 L .5064 .48259 L F
0 g
.56431 .37554 m
.56448 .37585 L
s
.56481 .37695 m
.56484 .37729 L
s
.56571 .37978 m .56583 .38119 L .56544 .38009 L .971 .686 .432 r
F
.56523 .37878 m .56571 .37978 L .56544 .38009 L F
0 g
.56413 .3753 m
.56431 .37554 L
s
.56379 .37507 m .5638 .37408 L .56396 .37514 L .971 .686 .432 r
F
.56379 .37507 m .56351 .37395 L .5638 .37408 L F
0 g
.566 .37115 m
.56565 .37126 L
s
.56511 .37103 m
.56565 .37126 L
s
.56451 .37639 m .56708 .37668 L .56547 .3772 L .656 .751 .92 r
F
0 g
.56547 .3772 m
.56687 .37787 L
s
.56396 .37514 m
.56413 .3753 L
s
.566 .37115 m
.56545 .37092 L
s
.56523 .37878 m .56544 .38009 L .56505 .379 L .971 .686 .432 r
F
.56476 .37778 m .56523 .37878 L .56505 .379 L F
.56483 .37757 m .56523 .37878 L .56476 .37778 L F
0 g
.56483 .37757 m
.56484 .37729 L
s
.56287 .37291 m .56295 .37172 L .56323 .37284 L .971 .686 .432 r
F
.56287 .37291 m .56248 .37181 L .56295 .37172 L F
0 g
.56295 .37172 m
.56349 .37195 L
s
.56468 .37499 m .56631 .37581 L .56451 .37639 L .544 .324 .532 r
F
.56468 .37499 m .56629 .37447 L .56631 .37581 L F
0 g
.56468 .37499 m
.5653 .37345 L
s
.56627 .37314 m
.56629 .37447 L
s
.56834 .38008 m
.56799 .3805 L
s
.56868 .37997 m
.56834 .38008 L
s
.56326 .374 m .56323 .37284 L .56351 .37395 L .971 .686 .432 r
F
.56326 .374 m .56287 .37291 L .56323 .37284 L F
0 g
.56833 .38039 m
.56868 .37997 L
s
.56476 .37778 m .56505 .379 L .56466 .37791 L .971 .686 .432 r
F
0 g
.56476 .37778 m
.56483 .37757 L
s
.56365 .37509 m .56351 .37395 L .56379 .37507 L .971 .686 .432 r
F
0 g
.56379 .37507 m
.56396 .37514 L
s
.56365 .37509 m .56326 .374 L .56351 .37395 L .971 .686 .432 r
F
.56544 .38009 m .56583 .38119 L .56536 .38128 L F
0 g
.56583 .38119 m
.56618 .38077 L
s
0 0 0 r
2 Mabswid
.56438 .37675 Mdot
.56437 .37674 Mdot
.56544 .38009 m .56536 .38128 L .56508 .38017 L .971 .686 .432 r
F
.56505 .379 m .56544 .38009 L .56508 .38017 L F
0 0 0 r
.56436 .37673 Mdot
.56435 .37672 Mdot
.56451 .37639 m .56631 .37581 L .56708 .37668 L .656 .751 .92 r
F
0 0 1 r
.5 Mabswid
.56435 .37672 m
.5647 .37659 L
s
0 1 0 r
.56436 .37673 m
.56471 .37659 L
s
1 0 0 r
.56437 .37674 m
.56471 .3766 L
s
1 0 1 r
.56438 .37675 m
.56472 .37661 L
s
0 g
.56708 .37668 m
.56784 .37756 L
s
.56505 .379 m .56508 .38017 L .5648 .37905 L .971 .686 .432 r
F
.56466 .37791 m .56505 .379 L .5648 .37905 L F
1 0 1 r
.56424 .3766 m
.56458 .37647 L
s
0 0 0 r
2 Mabswid
.56424 .3766 Mdot
.56466 .37791 m .5648 .37905 L .56452 .37794 L .971 .686 .432 r
F
0 g
.5 Mabswid
.56466 .37791 m
.56476 .37778 L
s
1 0 0 r
.56422 .37658 m
.56457 .37645 L
s
0 0 0 r
2 Mabswid
.56422 .37658 Mdot
0 1 0 r
.5 Mabswid
.5642 .37656 m
.56455 .37643 L
s
0 0 0 r
2 Mabswid
.5642 .37656 Mdot
0 0 1 r
.5 Mabswid
.56418 .37653 m
.56453 .37641 L
s
0 0 0 r
2 Mabswid
.56418 .37653 Mdot
1 0 1 r
.5 Mabswid
.56418 .37653 m
.56452 .3764 L
s
0 0 0 r
2 Mabswid
.56418 .37653 Mdot
.56413 .37648 Mdot
.56413 .37647 Mdot
.56411 .37645 Mdot
.56409 .37642 Mdot
.56355 .37522 m .56326 .374 L .56365 .37509 L .971 .686 .432 r
F
0 g
.5 Mabswid
.56365 .37509 m
.56379 .37507 L
s
0 0 0 r
2 Mabswid
.56407 .3764 Mdot
0 g
.5 Mabswid
.56545 .37092 m
.56511 .37103 L
s
.56464 .37112 m
.56511 .37103 L
s
.56451 .37639 m .56634 .37715 L .56473 .37766 L .544 .324 .532 r
F
.56451 .37639 m .56631 .37581 L .56634 .37715 L F
1 0 1 r
.56632 .37599 m
.56643 .37594 L
s
1 0 0 r
.56632 .37598 m
.56642 .37594 L
s
0 1 0 r
.56632 .37597 m
.56642 .37593 L
s
0 0 1 r
.56632 .37596 m
.56641 .37592 L
s
1 0 1 r
.56631 .37584 m
.56633 .37583 L
s
1 0 0 r
.56631 .37582 m
.56632 .37582 L
s
.56394 .37545 m .56631 .37581 L .56451 .37639 L .656 .751 .92 r
F
0 g
.56461 .37555 m
.56468 .37499 L
s
1 0 1 r
.56407 .3764 m
.56444 .37631 L
s
1 0 0 r
.56409 .37642 m
.56446 .37632 L
s
0 1 0 r
.56411 .37645 m
.56447 .37634 L
s
0 0 1 r
.56413 .37647 m
.56449 .37636 L
s
1 0 1 r
.56413 .37648 m
.5645 .37637 L
s
1 0 0 r
.53492 .38348 m
.56394 .37626 L
s
0 1 0 r
.53495 .38351 m
.56395 .37627 L
s
0 0 1 r
.53498 .38354 m
.56396 .37628 L
s
1 0 1 r
.5645 .37637 m
.56536 .37611 L
s
.56631 .37583 m
.56633 .37583 L
s
0 0 0 r
2 Mabswid
.5645 .37637 Mdot
0 0 1 r
.5 Mabswid
.56449 .37636 m
.56561 .37604 L
s
.56631 .37583 m
.56633 .37582 L
s
0 0 0 r
2 Mabswid
.56449 .37636 Mdot
0 1 0 r
.5 Mabswid
.56447 .37634 m
.56615 .37586 L
s
.56631 .37582 m
.56632 .37581 L
s
0 0 0 r
2 Mabswid
.56447 .37634 Mdot
.56308 .37422 m .56287 .37291 L .56326 .374 L .971 .686 .432 r
F
.56355 .37522 m .56308 .37422 L .56326 .374 L F
.56452 .37794 m .56451 .37893 L .56435 .37787 L F
.56452 .37794 m .5648 .37905 L .56451 .37893 L F
0 g
.5 Mabswid
.56452 .37794 m
.56466 .37791 L
s
0 0 0 r
2 Mabswid
.56446 .37632 Mdot
.56444 .37631 Mdot
0 g
.5 Mabswid
.56545 .37092 m
.56498 .37101 L
s
0 0 1 r
.56396 .37628 m
.56434 .37618 L
s
0 0 0 r
2 Mabswid
.56396 .37628 Mdot
0 1 0 r
.5 Mabswid
.56395 .37627 m
.56434 .37617 L
s
0 0 0 r
2 Mabswid
.56395 .37627 Mdot
.5626 .37322 m .56248 .37181 L .56287 .37291 L .971 .686 .432 r
F
.56308 .37422 m .5626 .37322 L .56287 .37291 L F
1 0 0 r
.5 Mabswid
.56394 .37626 m
.56433 .37616 L
s
0 0 0 r
2 Mabswid
.56394 .37626 Mdot
1 0 1 r
.5 Mabswid
.56393 .37625 m
.56432 .37615 L
s
0 0 0 r
2 Mabswid
.56393 .37625 Mdot
.5626 .37322 m .56213 .37222 L .56248 .37181 L .971 .686 .432 r
F
0 g
.5 Mabswid
.56248 .37181 m
.56295 .37172 L
s
.5648 .37905 m .56466 .37999 L .56451 .37893 L .971 .686 .432 r
F
.5648 .37905 m .56508 .38017 L .56466 .37999 L F
0 0 0 r
2 Mabswid
.56434 .37618 Mdot
.56434 .37617 Mdot
.56433 .37616 Mdot
.56432 .37615 Mdot
.56348 .37543 m .56308 .37422 L .56355 .37522 L .971 .686 .432 r
F
0 g
.5 Mabswid
.56355 .37522 m
.56365 .37509 L
s
.56799 .3805 m
.56752 .38059 L
s
.56833 .38039 m
.56799 .3805 L
s
.56435 .37787 m .56419 .37864 L .56418 .3777 L .971 .686 .432 r
F
.56435 .37787 m .56451 .37893 L .56419 .37864 L F
0 g
.56435 .37787 m
.56452 .37794 L
s
.56508 .38017 m .56482 .38105 L .56466 .37999 L .971 .686 .432 r
F
.56508 .38017 m .56536 .38128 L .56482 .38105 L F
0 g
.56536 .38128 m
.56583 .38119 L
s
.48117 .36344 m .52052 .36732 L .49363 .37602 L .656 .751 .92 r
F
0 g
.48603 .36835 m
.49363 .37602 L
s
.49363 .37602 m
.49923 .38193 L
s
.56787 .38048 m
.56833 .38039 L
s
0 0 0 r
2 Mabswid
.56643 .37594 Mdot
.56642 .37594 Mdot
.56642 .37593 Mdot
.56641 .37592 Mdot
.56348 .37543 m .56296 .3746 L .56308 .37422 L .971 .686 .432 r
F
.56347 .37571 m .56296 .3746 L .56348 .37543 L F
0 g
.5 Mabswid
.56348 .37543 m
.56355 .37522 L
s
.56296 .3746 m .5626 .37322 L .56308 .37422 L .971 .686 .432 r
F
.56418 .3777 m .56387 .3782 L .564 .37746 L F
.56418 .3777 m .56419 .37864 L .56387 .3782 L F
0 g
.56418 .3777 m
.56435 .37787 L
s
1 0 1 r
.56633 .37583 m
.56673 .37568 L
s
0 0 0 r
2 Mabswid
.56633 .37583 Mdot
.56633 .37583 Mdot
.56633 .37582 Mdot
1 0 0 r
.5 Mabswid
.56632 .37582 m
.56649 .37575 L
s
0 0 0 r
2 Mabswid
.56632 .37582 Mdot
.56632 .37581 Mdot
.56394 .37545 m .56555 .37493 L .56631 .37581 L .656 .751 .92 r
F
1 0 1 r
.5 Mabswid
.56432 .37615 m
.5662 .37568 L
s
1 0 0 r
.56433 .37616 m
.5662 .37568 L
s
0 1 0 r
.56434 .37617 m
.56621 .37569 L
s
0 0 1 r
.56434 .37618 m
.56622 .3757 L
s
1 0 1 r
.56444 .37631 m
.5663 .37579 L
s
1 0 0 r
.56446 .37632 m
.56631 .3758 L
s
0 g
.56631 .37581 m
.56708 .37668 L
s
1 0 1 r
.56536 .37611 m
.5663 .37579 L
s
0 0 1 r
.56561 .37604 m
.5663 .3758 L
s
0 1 0 r
.56615 .37586 m
.56631 .37581 L
s
0 g
.56629 .37447 m
.56631 .37581 L
s
0 0 0 r
2 Mabswid
.56631 .37581 Mdot
.56631 .3758 Mdot
.5663 .3758 Mdot
.5663 .37579 Mdot
.5663 .37579 Mdot
.56451 .37893 m .56421 .37958 L .56419 .37864 L .971 .686 .432 r
F
.56451 .37893 m .56466 .37999 L .56421 .37958 L F
0 g
.5 Mabswid
.4722 .25041 m
.48425 .23905 L
s
.56347 .37571 m .56293 .3751 L .56296 .3746 L .971 .686 .432 r
F
.56349 .37605 m .56293 .3751 L .56347 .37571 L F
0 g
.56347 .37571 m
.56348 .37543 L
s
0 0 0 r
2 Mabswid
.56622 .3757 Mdot
.56621 .37569 Mdot
.5662 .37568 Mdot
.5662 .37568 Mdot
.564 .37746 m .56357 .37765 L .56383 .37715 L .971 .686 .432 r
F
.564 .37746 m .56387 .3782 L .56357 .37765 L F
0 g
.5 Mabswid
.564 .37746 m
.56418 .3777 L
s
.56244 .37376 m .56213 .37222 L .5626 .37322 L .971 .686 .432 r
F
.56296 .3746 m .56244 .37376 L .5626 .37322 L F
.56473 .37766 m .56636 .37848 L .56539 .37879 L .544 .324 .532 r
F
.56473 .37766 m .56634 .37715 L .56636 .37848 L F
0 g
.56451 .37639 m
.56473 .37766 L
s
.56631 .37581 m
.56634 .37715 L
s
.56349 .37605 m .56298 .3757 L .56293 .3751 L .971 .686 .432 r
F
.56357 .37642 m .56298 .3757 L .56349 .37605 L F
0 g
.56347 .37571 m
.56349 .37605 L
s
.56383 .37715 m .56331 .37702 L .56368 .37679 L .971 .686 .432 r
F
.56383 .37715 m .56357 .37765 L .56331 .37702 L F
0 g
.56383 .37715 m
.564 .37746 L
s
.56498 .37101 m
.56464 .37112 L
s
.56429 .37153 m
.56464 .37112 L
s
.56368 .37679 m .56311 .37636 L .56357 .37642 L .971 .686 .432 r
F
.56357 .37642 m .56311 .37636 L .56298 .3757 L F
0 g
.56349 .37605 m
.56357 .37642 L
s
.56368 .37679 m .56331 .37702 L .56311 .37636 L .971 .686 .432 r
F
0 g
.56357 .37642 m
.56368 .37679 L
s
.56368 .37679 m
.56383 .37715 L
s
.56293 .3751 m .56244 .37376 L .56296 .3746 L .971 .686 .432 r
F
.56381 .37437 m .56555 .37493 L .56394 .37545 L .656 .751 .92 r
F
0 g
.56394 .37545 m
.56451 .37639 L
s
.56466 .37999 m .56422 .38051 L .56421 .37958 L .971 .686 .432 r
F
.56466 .37999 m .56482 .38105 L .56422 .38051 L F
0 g
.56482 .38105 m
.56536 .38128 L
s
.56498 .37101 m
.56463 .37142 L
s
.56419 .37864 m .56375 .37895 L .56387 .3782 L .971 .686 .432 r
F
.56419 .37864 m .56421 .37958 L .56375 .37895 L F
.56244 .37376 m .56192 .37293 L .56213 .37222 L F
0 g
.56213 .37222 m
.56248 .37181 L
s
.56752 .38059 m
.56698 .38036 L
s
.56787 .38048 m
.56752 .38059 L
s
.56732 .38025 m
.56787 .38048 L
s
.56293 .3751 m .56239 .37449 L .56244 .37376 L .971 .686 .432 r
F
.56298 .3757 m .56239 .37449 L .56293 .3751 L F
.56387 .3782 m .56332 .37816 L .56357 .37765 L F
.56387 .3782 m .56375 .37895 L .56332 .37816 L F
.56239 .37449 m .56192 .37293 L .56244 .37376 L F
.56381 .37437 m .56478 .37406 L .56555 .37493 L .656 .751 .92 r
F
0 g
.56555 .37493 m
.56631 .37581 L
s
.56298 .3757 m .56247 .37535 L .56239 .37449 L .971 .686 .432 r
F
.56311 .37636 m .56247 .37535 L .56298 .3757 L F
.56421 .37958 m .56363 .3797 L .56375 .37895 L F
.56421 .37958 m .56422 .38051 L .56363 .3797 L F
0 g
.56422 .38051 m
.56482 .38105 L
s
.56357 .37765 m .56295 .37725 L .56331 .37702 L .971 .686 .432 r
F
.56357 .37765 m .56332 .37816 L .56295 .37725 L F
.56311 .37636 m .56266 .3763 L .56247 .37535 L F
.56331 .37702 m .56266 .3763 L .56311 .37636 L F
.56331 .37702 m .56295 .37725 L .56266 .3763 L F
.56539 .37879 m .56639 .37982 L .56673 .37971 L .544 .324 .532 r
F
.56539 .37879 m .56636 .37848 L .56639 .37982 L F
0 g
.56473 .37766 m
.56539 .37879 L
s
.56539 .37879 m
.56673 .37971 L
s
.56634 .37715 m
.56636 .37848 L
s
.56463 .37142 m
.56429 .37153 L
s
.56408 .37223 m
.56429 .37153 L
s
.56239 .37449 m .56186 .37388 L .56192 .37293 L .971 .686 .432 r
F
0 g
.56192 .37293 m
.56213 .37222 L
s
.56463 .37142 m
.56442 .37212 L
s
.56247 .37535 m .56186 .37388 L .56239 .37449 L .971 .686 .432 r
F
0 g
.56639 .37982 m
.56698 .38036 L
s
.56732 .38025 m
.56698 .38036 L
s
.56436 .37307 m .56478 .37406 L .56381 .37437 L .656 .751 .92 r
F
0 g
.56381 .37437 m
.56394 .37545 L
s
.56375 .37895 m .56307 .37866 L .56332 .37816 L .971 .686 .432 r
F
.56375 .37895 m .56363 .3797 L .56307 .37866 L F
0 g
.56636 .37848 m
.56639 .37982 L
s
.56363 .3797 m
.56422 .38051 L
s
.56673 .37971 m
.56732 .38025 L
s
.56247 .37535 m .56195 .375 L .56186 .37388 L .971 .686 .432 r
F
0 g
.56186 .37388 m
.56192 .37293 L
s
.56266 .3763 m .56195 .375 L .56247 .37535 L .971 .686 .432 r
F
.56436 .37307 m .56402 .37318 L .56478 .37406 L .656 .751 .92 r
F
0 g
.56402 .37318 m
.56478 .37406 L
s
.56478 .37406 m
.56555 .37493 L
s
.56381 .37437 m
.56436 .37307 L
s
.56332 .37816 m .56258 .37748 L .56295 .37725 L .971 .686 .432 r
F
.56332 .37816 m .56307 .37866 L .56258 .37748 L F
.56266 .3763 m .5622 .37623 L .56195 .375 L F
.56295 .37725 m .5622 .37623 L .56266 .3763 L F
.56295 .37725 m .56258 .37748 L .5622 .37623 L F
0 g
.56186 .37388 m
.56195 .375 L
s
.56442 .37212 m
.56408 .37223 L
s
.56402 .37318 m
.56408 .37223 L
s
.56436 .37307 m
.56442 .37212 L
s
.56307 .37866 m
.56363 .3797 L
s
.56579 .37901 m
.56639 .37982 L
s
.56639 .37982 m
.56673 .37971 L
s
.56613 .3789 m
.56673 .37971 L
s
.56195 .375 m
.5622 .37623 L
s
.56258 .37748 m
.56307 .37866 L
s
.56402 .37318 m
.56436 .37307 L
s
.56402 .37318 m
.56411 .37431 L
s
.5622 .37623 m
.56258 .37748 L
s
.56436 .37307 m
.56446 .3742 L
s
.56579 .37901 m
.56523 .37797 L
s
.56613 .3789 m
.56579 .37901 L
s
.56557 .37786 m
.56613 .3789 L
s
.56446 .3742 m
.56411 .37431 L
s
.56436 .37554 m
.56411 .37431 L
s
.56523 .37797 m
.56474 .37679 L
s
.56557 .37786 m
.56523 .37797 L
s
.56446 .3742 m
.5647 .37543 L
s
.56508 .37668 m
.56557 .37786 L
s
.5647 .37543 m
.56436 .37554 L
s
.56474 .37679 m
.56436 .37554 L
s
.56508 .37668 m
.56474 .37679 L
s
.5647 .37543 m
.56508 .37668 L
s
.48216 .35234 m .45652 .31797 L .46191 .30325 L .953 .661 .445 r
F
.48117 .36344 m .45652 .31797 L .48216 .35234 L .951 .666 .46 r
F
.45652 .31797 m .43691 .26251 L .46191 .30325 L .944 .645 .443 r
F
.50921 .44154 m .49301 .46539 L .50198 .43211 L .963 .707 .501 r
F
.50921 .44154 m .5064 .48259 L .49301 .46539 L F
.50921 .44154 m .53729 .45282 L .50803 .4619 L .544 .324 .532 r
F
.50921 .44154 m .53707 .43281 L .53729 .45282 L F
0 g
.50921 .44154 m
.50995 .42149 L
s
.53687 .41298 m
.53707 .43281 L
s
.61628 .36161 m
.61552 .3591 L
s
.61552 .3591 m
.6171 .3586 L
s
.61552 .3591 m
.61455 .35673 L
s
.61679 .36407 m
.61628 .36161 L
s
.61628 .36161 m
.61787 .3611 L
s
.61455 .35673 m
.61613 .35622 L
s
.61455 .35673 m
.61345 .35465 L
s
.6171 .3586 m
.61787 .3611 L
s
.61613 .35622 m
.6171 .3586 L
s
.48117 .36344 m .50898 .35438 L .52052 .36732 L .656 .751 .92 r
F
0 g
.52052 .36732 m
.53193 .38011 L
s
.61787 .3611 m
.61837 .36356 L
s
.61679 .36407 m
.61837 .36356 L
s
.5742 .53522 m
.55698 .52977 L
s
.61503 .35414 m
.61613 .35622 L
s
.61345 .35465 m
.61503 .35414 L
s
.621 .36009 m
.62024 .35759 L
s
.62024 .35759 m
.62241 .3569 L
s
.62024 .35759 m
.61927 .35522 L
s
.61607 .36438 m .61859 .36582 L .61701 .36633 L .656 .751 .92 r
F
0 g
.61692 .36823 m
.61701 .36633 L
s
.61679 .36407 m
.61686 .36483 L
s
.62151 .36256 m
.621 .36009 L
s
.621 .36009 m
.62317 .3594 L
s
.61927 .35522 m
.62144 .35452 L
s
.61927 .35522 m
.61817 .35313 L
s
.61607 .36438 m .61802 .36376 L .61859 .36582 L .656 .751 .92 r
F
0 g
.6185 .36772 m
.61859 .36582 L
s
1 0 1 r
.5662 .37568 m
.61609 .36442 L
s
0 g
.61837 .36356 m
.61859 .36582 L
s
.61701 .36633 m
.61859 .36582 L
s
.62151 .36256 m
.62368 .36187 L
s
.62305 .35944 m
.62229 .35694 L
s
.62229 .35694 m
.62464 .35618 L
s
.62229 .35694 m
.62132 .35456 L
s
.62241 .3569 m
.62317 .3594 L
s
.62144 .35452 m
.62241 .3569 L
s
.62356 .36191 m
.62305 .35944 L
s
.62305 .35944 m
.62541 .35869 L
s
.62317 .3594 m
.62368 .36187 L
s
.61227 .353 m .61486 .35486 L .61292 .35549 L .544 .324 .532 r
F
.61227 .353 m .61386 .35249 L .61486 .35486 L F
0 g
.61386 .35249 m
.61503 .35414 L
s
.61227 .353 m
.61386 .35249 L
s
.61111 .35189 m
.61227 .353 L
s
.62132 .35456 m
.62367 .35381 L
s
.62132 .35456 m
.62021 .35248 L
s
.62033 .35244 m
.62144 .35452 L
s
.61817 .35313 m
.62033 .35244 L
s
.62356 .36191 m
.62591 .36115 L
s
.61653 .36964 m
.61692 .36823 L
s
.61692 .36823 m
.6185 .36772 L
s
.62464 .35618 m
.62541 .35869 L
s
.62367 .35381 m
.62464 .35618 L
s
.6127 .35138 m
.61386 .35249 L
s
.62541 .35869 m
.62591 .36115 L
s
.61983 .36318 m .6239 .36413 L .62173 .36482 L .656 .751 .92 r
F
0 g
.62164 .36672 m
.62173 .36482 L
s
.62356 .36191 m
.62377 .3641 L
s
.62151 .36256 m
.62161 .3636 L
s
.62257 .35172 m
.62367 .35381 L
s
.62021 .35248 m
.62257 .35172 L
s
.6185 .36772 m
.61811 .36913 L
s
.5196 .49353 m .50179 .52494 L .5064 .48259 L .966 .726 .523 r
F
.5196 .49353 m .52113 .54047 L .50179 .52494 L F
0 g
.52113 .54047 m
.53868 .54576 L
s
0 0 0 r
2 Mabswid
.61609 .36442 Mdot
.61491 .3625 m .61802 .36376 L .61607 .36438 L .656 .751 .92 r
F
1 0 1 r
.5 Mabswid
.61609 .36442 m
.6181 .36397 L
s
0 g
.61607 .36438 m
.61701 .36633 L
s
1 0 0 r
.5662 .37568 m
.61606 .36435 L
s
0 1 0 r
.56621 .37569 m
.61602 .36428 L
s
0 0 1 r
.56622 .3757 m
.61598 .36422 L
s
1 0 0 r
.61606 .36435 m
.61807 .3639 L
s
0 0 0 r
2 Mabswid
.61606 .36435 Mdot
0 1 0 r
.5 Mabswid
.61602 .36428 m
.61805 .36383 L
s
0 0 0 r
2 Mabswid
.61602 .36428 Mdot
.61598 .36422 Mdot
.62214 .36244 m .62613 .36341 L .62378 .36417 L .656 .751 .92 r
F
0 g
.5 Mabswid
.62369 .36607 m
.62378 .36417 L
s
.62368 .36187 m
.62378 .36284 L
s
.61983 .36318 m .62185 .36254 L .6239 .36413 L .656 .751 .92 r
F
0 g
.62381 .36603 m
.6239 .36413 L
s
.62173 .36482 m
.6239 .36413 L
s
1 0 1 r
.6181 .36397 m
.62013 .36345 L
s
.617 .35148 m .61869 .35364 L .61667 .35428 L .544 .324 .532 r
F
.617 .35148 m .61916 .35078 L .61869 .35364 L F
0 g
.61584 .35037 m
.617 .35148 L
s
.61914 .35095 m
.62021 .35248 L
s
.61111 .35189 m
.6127 .35138 L
s
.61111 .35189 m
.61005 .3514 L
s
1 0 0 r
.61807 .3639 m
.62005 .36339 L
s
0 1 0 r
.61805 .36383 m
.61998 .36332 L
s
.61292 .35549 m .61548 .35736 L .61333 .35805 L .544 .324 .532 r
F
.61292 .35549 m .61486 .35486 L .61548 .35736 L F
0 g
.61227 .353 m
.61292 .35549 L
s
.61386 .35249 m
.61486 .35486 L
s
.61491 .3625 m .61706 .36182 L .61802 .36376 L .656 .751 .92 r
F
0 0 1 r
.61598 .36422 m
.61802 .36376 L
s
0 1 0 r
.56632 .37581 m
.61495 .36257 L
s
1 0 0 r
.56631 .3758 m
.61515 .36285 L
s
1 0 1 r
.5663 .37579 m
.6153 .36308 L
s
0 g
.61802 .36376 m
.61859 .36582 L
s
0 0 1 r
.61802 .36376 m
.61991 .36326 L
s
0 g
.62126 .36813 m
.62164 .36672 L
s
.62164 .36672 m
.62381 .36603 L
s
.48117 .36344 m .45451 .33829 L .45652 .31797 L .951 .666 .46 r
F
.48209 .37674 m .45451 .33829 L .48117 .36344 L .951 .672 .473 r
F
1 0 1 r
.1349 .47374 m
.47263 .36354 L
s
.15906 .49311 m
.47293 .36397 L
s
.46813 .35086 m .50898 .35438 L .48117 .36344 L .656 .751 .92 r
F
0 g
.48117 .36344 m
.48603 .36835 L
s
1 0 1 r
.47905 .36145 m
.47911 .36142 L
s
0 0 1 r
.15811 .49181 m
.46994 .3598 L
s
1 0 1 r
.47905 .36144 m
.47911 .36142 L
s
0 0 1 r
.13053 .47029 m
.46965 .35939 L
s
0 g
.61163 .35089 m
.6127 .35138 L
s
.62214 .36244 m .62539 .36141 L .62613 .36341 L .656 .751 .92 r
F
0 g
.62605 .36531 m
.62613 .36341 L
s
.62378 .36417 m
.62613 .36341 L
s
.62591 .36115 m
.62613 .36341 L
s
.61586 .37046 m
.61653 .36964 L
s
.61653 .36964 m
.61811 .36913 L
s
.61904 .35082 m .62223 .3525 L .61898 .35354 L .544 .324 .532 r
F
.61904 .35082 m .6214 .35006 L .62223 .3525 L F
0 g
.617 .35148 m
.61916 .35078 L
s
.6214 .35006 m
.62257 .35172 L
s
.61904 .35082 m
.6214 .35006 L
s
.61789 .34971 m
.61904 .35082 L
s
.61801 .34967 m
.61916 .35078 L
s
.61809 .36149 m .62185 .36254 L .61983 .36318 L .656 .751 .92 r
F
0 0 1 r
.61991 .36326 m
.62196 .36263 L
s
0 1 0 r
.61998 .36332 m
.62204 .36269 L
s
1 0 0 r
.62005 .36339 m
.62211 .36276 L
s
1 0 1 r
.62013 .36345 m
.62219 .36282 L
s
0 g
.61983 .36318 m
.62173 .36482 L
s
1 0 1 r
.6153 .36308 m
.61746 .36252 L
s
0 g
.61811 .36913 m
.61745 .36996 L
s
.62331 .36748 m
.62369 .36607 L
s
.62369 .36607 m
.62605 .36531 L
s
1 0 1 r
.62219 .36282 m
.62244 .36276 L
s
0 g
.62381 .36603 m
.62343 .36744 L
s
1 0 0 r
.62211 .36276 m
.62237 .36269 L
s
0 1 0 r
.62204 .36269 m
.62231 .36263 L
s
0 0 1 r
.62196 .36263 m
.62225 .36256 L
s
.61667 .35428 m .61844 .35642 L .6165 .35704 L .544 .324 .532 r
F
.61667 .35428 m .61869 .35364 L .61844 .35642 L F
0 g
.61667 .35428 m
.617 .35148 L
s
.61869 .35364 m
.61916 .35078 L
s
.61809 .36149 m .62002 .36087 L .62185 .36254 L .656 .751 .92 r
F
0 g
.62185 .36254 m
.6239 .36413 L
s
.62025 .34896 m
.6214 .35006 L
s
1 0 1 r
.61746 .36252 m
.61875 .36216 L
s
.61352 .3607 m .61706 .36182 L .61491 .3625 L .656 .751 .92 r
F
0 1 0 r
.61495 .36257 m
.61716 .36197 L
s
1 0 0 r
.61515 .36285 m
.61733 .36228 L
s
0 g
.61491 .3625 m
.61607 .36438 L
s
0 0 1 r
.56633 .37582 m
.61469 .36219 L
s
1 0 1 r
.56633 .37583 m
.61456 .36202 L
s
.62056 .3607 m .62539 .36141 L .62214 .36244 L .656 .751 .92 r
F
0 0 1 r
.62225 .36256 m
.6255 .36165 L
s
0 1 0 r
.62231 .36263 m
.62553 .36173 L
s
1 0 0 r
.62237 .36269 m
.62556 .36181 L
s
1 0 1 r
.62244 .36276 m
.6256 .36189 L
s
0 g
.62214 .36244 m
.62378 .36417 L
s
.61584 .35037 m
.61801 .34967 L
s
.61584 .35037 m
.61478 .34988 L
s
1 0 0 r
.61733 .36228 m
.61853 .36194 L
s
.61333 .35805 m .61574 .35999 L .61352 .3607 L .544 .324 .532 r
F
.61333 .35805 m .61548 .35736 L .61574 .35999 L F
0 g
.61292 .35549 m
.61333 .35805 L
s
.61486 .35486 m
.61548 .35736 L
s
.61005 .3514 m
.61163 .35089 L
s
.61005 .3514 m
.60915 .35157 L
s
1 0 1 r
.61875 .36216 m
.62072 .36155 L
s
0 0 0 r
2 Mabswid
.61875 .36216 Mdot
0 g
.5 Mabswid
.62605 .36531 m
.62567 .36672 L
s
0 1 0 r
.61716 .36197 m
.61825 .36166 L
s
0 g
.62059 .36896 m
.62126 .36813 L
s
.62126 .36813 m
.62343 .36744 L
s
1 0 1 r
.6256 .36189 m
.67296 .34615 L
s
0 0 0 r
2 Mabswid
.6256 .36189 Mdot
.61898 .35354 m .62275 .35503 L .61897 .35624 L .544 .324 .532 r
F
.61898 .35354 m .62223 .3525 L .62275 .35503 L F
0 g
.5 Mabswid
.61898 .35354 m
.61904 .35082 L
s
.6214 .35006 m
.62223 .3525 L
s
.61352 .3607 m .61574 .35999 L .61706 .36182 L .656 .751 .92 r
F
0 0 1 r
.61469 .36219 m
.61691 .36157 L
s
0 g
.61706 .36182 m
.61802 .36376 L
s
1 0 0 r
.62556 .36181 m
.67297 .34603 L
s
0 0 0 r
2 Mabswid
.62556 .36181 Mdot
0 g
.5 Mabswid
.61789 .34971 m
.62025 .34896 L
s
.61789 .34971 m
.61683 .34922 L
s
0 1 0 r
.62553 .36173 m
.67298 .34593 L
s
0 0 0 r
2 Mabswid
.62553 .36173 Mdot
0 g
.5 Mabswid
.61695 .34919 m
.61801 .34967 L
s
.61074 .35106 m
.61163 .35089 L
s
0 0 1 r
.6255 .36165 m
.673 .34581 L
s
0 0 0 r
2 Mabswid
.6255 .36165 Mdot
0 g
.5 Mabswid
.61497 .37065 m
.61586 .37046 L
s
.61586 .37046 m
.61745 .36996 L
s
1 0 1 r
.62072 .36155 m
.6212 .36142 L
s
.6165 .35974 m .62002 .36087 L .61809 .36149 L .656 .751 .92 r
F
0 0 1 r
.61691 .36157 m
.61789 .36128 L
s
0 1 0 r
.61825 .36166 m
.6202 .36105 L
s
1 0 1 r
.61456 .36202 m
.61679 .36138 L
s
1 0 0 r
.61853 .36194 m
.62049 .36133 L
s
0 g
.61809 .36149 m
.61983 .36318 L
s
.50198 .43211 m .48041 .44307 L .49521 .42001 L .959 .701 .502 r
F
.50198 .43211 m .49301 .46539 L .48041 .44307 L F
0 0 0 r
2 Mabswid
.47911 .36142 Mdot
.62056 .3607 m .62433 .35949 L .62539 .36141 L .656 .751 .92 r
F
0 g
.5 Mabswid
.62539 .36141 m
.62613 .36341 L
s
1 0 1 r
.61679 .36138 m
.61772 .3611 L
s
1 0 0 r
.62049 .36133 m
.62099 .36119 L
s
0 g
.62265 .3683 m
.62331 .36748 L
s
.62331 .36748 m
.62567 .36672 L
s
.62343 .36744 m
.62277 .36826 L
s
.6165 .35704 m .61841 .35913 L .6165 .35974 L .544 .324 .532 r
F
.6165 .35704 m .61844 .35642 L .61841 .35913 L F
0 g
.6165 .35704 m
.61667 .35428 L
s
.61844 .35642 m
.61869 .35364 L
s
.61745 .36996 m
.61655 .37014 L
s
0 1 0 r
.6202 .36105 m
.62073 .3609 L
s
0 g
.61919 .34847 m
.62025 .34896 L
s
.6165 .35974 m .61841 .35913 L .62002 .36087 L .656 .751 .92 r
F
0 g
.62002 .36087 m
.62185 .36254 L
s
.61903 .35893 m .62433 .35949 L .62056 .3607 L .656 .751 .92 r
F
0 0 1 r
.61789 .36128 m
.61982 .36067 L
s
1 0 1 r
.61772 .3611 m
.61965 .3605 L
s
0 1 0 r
.62073 .3609 m
.6245 .35977 L
s
1 0 0 r
.62099 .36119 m
.6247 .36009 L
s
0 g
.62056 .3607 m
.62214 .36244 L
s
1 0 1 r
.6212 .36142 m
.62485 .36035 L
s
.61352 .3607 m .61564 .36272 L .61349 .36341 L .544 .324 .532 r
F
.61352 .3607 m .61574 .35999 L .61564 .36272 L F
.6119 .35896 m .61574 .35999 L .61352 .3607 L .656 .751 .92 r
F
0 g
.61333 .35805 m
.61342 .35936 L
s
.61478 .34988 m
.61695 .34919 L
s
.61478 .34988 m
.61388 .35005 L
s
0 0 1 r
.61982 .36067 m
.62039 .36051 L
s
1 0 1 r
.61965 .3605 m
.62023 .36033 L
s
0 g
.62567 .36672 m
.62501 .36755 L
s
.61897 .35624 m .62298 .35767 L .61903 .35893 L .544 .324 .532 r
F
.61897 .35624 m .62275 .35503 L .62298 .35767 L F
0 g
.61897 .35624 m
.61898 .35354 L
s
.62223 .3525 m
.62275 .35503 L
s
.60915 .35157 m
.61074 .35106 L
s
.60915 .35157 m
.60848 .35239 L
s
1 0 1 r
.62485 .36035 m
.67317 .34443 L
s
0 0 0 r
2 Mabswid
.62485 .36035 Mdot
0 g
.5 Mabswid
.6197 .36914 m
.62059 .36896 L
s
.62059 .36896 m
.62277 .36826 L
s
1 0 0 r
.6247 .36009 m
.67321 .34412 L
s
0 0 0 r
2 Mabswid
.6247 .36009 Mdot
0 g
.5 Mabswid
.61683 .34922 m
.61919 .34847 L
s
.61683 .34922 m
.61593 .34939 L
s
.61606 .34935 m
.61695 .34919 L
s
.6119 .35896 m .61406 .35827 L .61574 .35999 L .656 .751 .92 r
F
0 0 1 r
.5663 .3758 m
.61219 .35925 L
s
1 0 1 r
.5663 .37579 m
.61236 .35941 L
s
0 g
.61574 .35999 m
.61706 .36182 L
s
.61548 .35736 m
.61574 .35999 L
s
.61007 .35188 m
.61074 .35106 L
s
.6139 .37017 m
.61497 .37065 L
s
.61497 .37065 m
.61655 .37014 L
s
.45652 .31797 m .42872 .28362 L .43691 .26251 L .944 .645 .443 r
F
0 g
.43691 .26251 m
.4722 .25041 L
s
.43691 .26251 m
.44933 .25105 L
s
0 1 0 r
.6245 .35977 m
.67325 .34376 L
s
0 0 0 r
2 Mabswid
.6245 .35977 Mdot
.6165 .35974 m .6186 .36178 L .61667 .3624 L .544 .324 .532 r
F
.6165 .35974 m .61841 .35913 L .6186 .36178 L F
.61508 .35794 m .61841 .35913 L .6165 .35974 L .656 .751 .92 r
F
0 g
.5 Mabswid
.6165 .35845 m
.6165 .35704 L
s
.61903 .35893 m .62298 .35767 L .62433 .35949 L .656 .751 .92 r
F
1 0 1 r
.62023 .36033 m
.6241 .35914 L
s
0 0 1 r
.62039 .36051 m
.62423 .35934 L
s
0 g
.62433 .35949 m
.62539 .36141 L
s
.62176 .36848 m
.62265 .3683 L
s
.62265 .3683 m
.62501 .36755 L
s
.62277 .36826 m
.62188 .36845 L
s
0 0 0 r
2 Mabswid
.61236 .35941 Mdot
0 0 1 r
.5 Mabswid
.62423 .35934 m
.67331 .34328 L
s
0 0 0 r
2 Mabswid
.62423 .35934 Mdot
0 g
.5 Mabswid
.61655 .37014 m
.61549 .36967 L
s
.61829 .34863 m
.61919 .34847 L
s
.61349 .36341 m .61518 .36558 L .61323 .36621 L .544 .324 .532 r
F
.61349 .36341 m .61564 .36272 L .61518 .36558 L F
0 g
.61349 .36341 m
.61352 .3607 L
s
.61564 .36272 m
.61574 .35999 L
s
0 0 0 r
2 Mabswid
.61219 .35925 Mdot
1 0 1 r
.5 Mabswid
.6241 .35914 m
.67333 .34309 L
s
0 0 0 r
2 Mabswid
.6241 .35914 Mdot
.61508 .35794 m .61702 .35732 L .61841 .35913 L .656 .751 .92 r
F
0 g
.5 Mabswid
.61841 .35913 m
.62002 .36087 L
s
.61841 .35913 m
.61844 .35642 L
s
.61006 .35729 m .61406 .35827 L .6119 .35896 L .656 .751 .92 r
F
0 0 1 r
.61219 .35925 m
.6143 .35848 L
s
1 0 1 r
.61236 .35941 m
.61448 .35865 L
s
0 g
.6119 .35896 m
.61352 .3607 L
s
0 1 0 r
.56631 .37581 m
.61184 .3589 L
s
1 0 0 r
.56649 .37575 m
.61157 .35864 L
s
1 0 1 r
.56673 .37568 m
.61135 .35843 L
s
.61903 .35893 m .62292 .3604 L .61914 .36161 L .544 .324 .532 r
F
.61903 .35893 m .62298 .35767 L .62292 .3604 L F
.61756 .35715 m .62298 .35767 L .61903 .35893 L .656 .751 .92 r
F
0 g
.61897 .35624 m
.61899 .35729 L
s
0 0 0 r
2 Mabswid
.61184 .3589 Mdot
0 g
.5 Mabswid
.61388 .35005 m
.61606 .34935 L
s
.61388 .35005 m
.61321 .35086 L
s
.62501 .36755 m
.62412 .36773 L
s
1 0 1 r
.61448 .35865 m
.61539 .35834 L
s
0 0 0 r
2 Mabswid
.61448 .35865 Mdot
.61157 .35864 Mdot
0 g
.5 Mabswid
.60848 .35239 m
.61007 .35188 L
s
.60848 .35239 m
.60808 .35379 L
s
0 0 1 r
.6143 .35848 m
.61525 .35816 L
s
0 0 0 r
2 Mabswid
.6143 .35848 Mdot
.61135 .35843 Mdot
.61539 .35834 Mdot
0 g
.5 Mabswid
.61864 .36866 m
.6197 .36914 L
s
.6197 .36914 m
.62188 .36845 L
s
.61006 .35729 m .61201 .35666 L .61406 .35827 L .656 .751 .92 r
F
1 0 1 r
.61135 .35843 m
.61334 .35766 L
s
1 0 0 r
.61157 .35864 m
.6136 .35786 L
s
0 1 0 r
.61184 .3589 m
.6139 .35813 L
s
1 0 0 r
.56642 .37594 m
.61009 .35731 L
s
0 1 0 r
.56642 .37593 m
.61016 .35737 L
s
0 0 1 r
.56641 .37592 m
.61023 .35743 L
s
0 g
.61406 .35827 m
.61574 .35999 L
s
.50803 .4619 m .5375 .47303 L .5064 .48259 L .544 .324 .532 r
F
.50803 .4619 m .53729 .45282 L .5375 .47303 L F
0 g
.50803 .4619 m
.50921 .44154 L
s
.53707 .43281 m
.53729 .45282 L
s
.61667 .3624 m .61902 .36436 L .61699 .36501 L .544 .324 .532 r
F
.61667 .3624 m .6186 .36178 L .61902 .36436 L F
0 g
.6165 .35974 m
.61667 .3624 L
s
.61841 .35913 m
.6186 .36178 L
s
.61593 .34939 m
.61829 .34863 L
s
.61593 .34939 m
.61527 .3502 L
s
.61539 .35016 m
.61606 .34935 L
s
0 0 0 r
2 Mabswid
.61525 .35816 Mdot
.6139 .35813 Mdot
0 g
.5 Mabswid
.60967 .35328 m
.61007 .35188 L
s
.6139 .37017 m
.61549 .36967 L
s
.61382 .35608 m .61702 .35732 L .61508 .35794 L .656 .751 .92 r
F
0 1 0 r
.6139 .35813 m
.61495 .35776 L
s
0 0 1 r
.61525 .35816 m
.61717 .35753 L
s
1 0 1 r
.61539 .35834 m
.6173 .35772 L
s
0 g
.61508 .35794 m
.6165 .35974 L
s
.61323 .36621 m .61433 .36857 L .61274 .36908 L .544 .324 .532 r
F
0 g
.61274 .36908 m
.6139 .37017 L
s
.61323 .36621 m .61518 .36558 L .61433 .36857 L .544 .324 .532 r
F
0 g
.61323 .36621 m
.61349 .36341 L
s
.61274 .36908 m
.61323 .36621 L
s
.61518 .36558 m
.61564 .36272 L
s
1 0 0 r
.6136 .35786 m
.61474 .35746 L
s
0 0 0 r
2 Mabswid
.6136 .35786 Mdot
.48209 .37674 m .45611 .36282 L .45451 .33829 L .951 .672 .473 r
F
0 0 1 r
.5 Mabswid
.47501 .35763 m
.47516 .35758 L
s
.47502 .35764 m
.47516 .35758 L
s
0 1 0 r
.15491 .48967 m
.45559 .35481 L
s
.09299 .47259 m
.4555 .35348 L
s
.48489 .39129 m .45611 .36282 L .48209 .37674 L .951 .679 .485 r
F
0 0 0 r
2 Mabswid
.61495 .35776 Mdot
.6173 .35772 Mdot
.61756 .35715 m .62134 .35594 L .62298 .35767 L .656 .751 .92 r
F
1 0 1 r
.5 Mabswid
.6173 .35772 m
.61786 .35753 L
s
0 g
.62275 .35503 m
.62298 .35767 L
s
.62298 .35767 m
.62433 .35949 L
s
.6207 .36801 m
.62176 .36848 L
s
.62176 .36848 m
.62412 .36773 L
s
0 0 0 r
2 Mabswid
.61334 .35766 Mdot
0 g
.5 Mabswid
.62188 .36845 m
.62082 .36797 L
s
.61433 .36857 m
.61549 .36967 L
s
0 0 0 r
2 Mabswid
.47516 .35758 Mdot
0 0 1 r
.5 Mabswid
.61717 .35753 m
.61771 .35734 L
s
0 0 0 r
2 Mabswid
.61717 .35753 Mdot
.61786 .35753 Mdot
0 g
.5 Mabswid
.61763 .34944 m
.61829 .34863 L
s
0 0 0 r
2 Mabswid
.61474 .35746 Mdot
.61914 .36161 m .62257 .36323 L .61931 .36427 L .544 .324 .532 r
F
.61914 .36161 m .62292 .3604 L .62257 .36323 L F
0 g
.5 Mabswid
.61903 .35893 m
.61914 .36161 L
s
.62292 .3604 m
.62298 .35767 L
s
0 0 0 r
2 Mabswid
.61023 .35743 Mdot
.61016 .35737 Mdot
.61771 .35734 Mdot
.61382 .35608 m .61585 .35543 L .61702 .35732 L .656 .751 .92 r
F
1 0 1 r
.5 Mabswid
.61334 .35766 m
.61457 .35721 L
s
0 g
.61702 .35732 m
.61841 .35913 L
s
0 0 0 r
2 Mabswid
.61009 .35731 Mdot
.60799 .35569 m .61201 .35666 L .61006 .35729 L .656 .751 .92 r
F
0 0 1 r
.5 Mabswid
.61023 .35743 m
.61202 .35666 L
s
0 g
.61006 .35729 m
.6119 .35896 L
s
1 0 1 r
.56643 .37594 m
.61002 .35725 L
s
0 g
.61433 .36857 m
.61518 .36558 L
s
0 0 0 r
2 Mabswid
.61002 .35725 Mdot
.61457 .35721 Mdot
.61614 .35534 m .62134 .35594 L .61756 .35715 L .656 .751 .92 r
F
1 0 1 r
.5 Mabswid
.61457 .35721 m
.61652 .35657 L
s
0 1 0 r
.61495 .35776 m
.61689 .35713 L
s
1 0 0 r
.61474 .35746 m
.61668 .35682 L
s
0 0 1 r
.61771 .35734 m
.62148 .35607 L
s
1 0 1 r
.61786 .35753 m
.62166 .35625 L
s
0 g
.61756 .35715 m
.61903 .35893 L
s
0 1 0 r
.61689 .35713 m
.61739 .35694 L
s
0 0 0 r
2 Mabswid
.61689 .35713 Mdot
0 g
.5 Mabswid
.61321 .35086 m
.61539 .35016 L
s
.61321 .35086 m
.61282 .35227 L
s
.60808 .35379 m
.60967 .35328 L
s
0 0 0 r
2 Mabswid
.61739 .35694 Mdot
0 g
.5 Mabswid
.62412 .36773 m
.62306 .36726 L
s
1 0 0 r
.61668 .35682 m
.61716 .35664 L
s
0 0 0 r
2 Mabswid
.61668 .35682 Mdot
.61699 .36501 m .61966 .36687 L .61748 .36756 L .544 .324 .532 r
F
.61699 .36501 m .61902 .36436 L .61966 .36687 L F
0 g
.5 Mabswid
.61667 .3624 m
.61699 .36501 L
s
.61699 .36501 m
.61748 .36756 L
s
.6186 .36178 m
.61902 .36436 L
s
0 0 0 r
2 Mabswid
.61202 .35666 Mdot
.60799 .35569 m .60958 .35518 L .61201 .35666 L .656 .751 .92 r
F
0 g
.5 Mabswid
.60958 .35518 m
.61201 .35666 L
s
.60799 .35569 m
.60808 .35379 L
s
1 0 1 r
.61002 .35725 m
.61177 .3565 L
s
0 1 0 r
.61016 .35737 m
.61194 .35661 L
s
0 g
.61201 .35666 m
.61406 .35827 L
s
1 0 0 r
.61009 .35731 m
.61185 .35655 L
s
0 g
.60799 .35569 m
.61006 .35729 L
s
0 0 0 r
2 Mabswid
.61716 .35664 Mdot
.61194 .35661 Mdot
0 g
.5 Mabswid
.61748 .36756 m
.61864 .36866 L
s
.61864 .36866 m
.62082 .36797 L
s
.61274 .36908 m
.61433 .36857 L
s
.61156 .36743 m
.61274 .36908 L
s
1 0 1 r
.61652 .35657 m
.61697 .3564 L
s
0 0 0 r
2 Mabswid
.61652 .35657 Mdot
.61185 .35655 Mdot
.49521 .42001 m .46955 .41724 L .48937 .40607 L .955 .694 .5 r
F
.49521 .42001 m .48041 .44307 L .46955 .41724 L F
0 g
.5 Mabswid
.60958 .35518 m
.60967 .35328 L
s
0 0 0 r
2 Mabswid
.61177 .3565 Mdot
0 g
.5 Mabswid
.61527 .3502 m
.61763 .34944 L
s
.61527 .3502 m
.61487 .35161 L
s
.615 .35157 m
.61539 .35016 L
s
0 0 0 r
2 Mabswid
.61697 .3564 Mdot
1 0 1 r
.5 Mabswid
.62166 .35625 m
.67373 .33988 L
s
0 0 0 r
2 Mabswid
.62166 .35625 Mdot
.61273 .35417 m .61585 .35543 L .61382 .35608 L .656 .751 .92 r
F
1 0 1 r
.5 Mabswid
.61177 .3565 m
.61363 .35577 L
s
1 0 0 r
.61185 .35655 m
.61368 .35585 L
s
0 1 0 r
.61194 .35661 m
.61372 .35592 L
s
0 0 1 r
.61202 .35666 m
.61377 .35599 L
s
0 g
.61382 .35608 m
.61508 .35794 L
s
0 0 1 r
.62148 .35607 m
.67376 .33971 L
s
0 0 0 r
2 Mabswid
.62148 .35607 Mdot
0 g
.5 Mabswid
.61315 .36692 m
.61433 .36857 L
s
0 0 0 r
2 Mabswid
.61377 .35599 Mdot
0 g
.5 Mabswid
.6207 .36801 m
.62306 .36726 L
s
.61614 .35534 m .6194 .35429 L .62134 .35594 L .656 .751 .92 r
F
1 0 0 r
.61716 .35664 m
.62075 .3554 L
s
0 1 0 r
.61739 .35694 m
.62107 .35569 L
s
0 g
.62134 .35594 m
.62298 .35767 L
s
.61931 .36427 m .6219 .36615 L .61954 .36691 L .544 .324 .532 r
F
0 g
.61954 .36691 m
.6207 .36801 L
s
.61931 .36427 m .62257 .36323 L .6219 .36615 L .544 .324 .532 r
F
0 g
.61914 .36161 m
.61931 .36427 L
s
.61902 .36436 m
.61966 .36687 L
s
.61931 .36427 m
.61954 .36691 L
s
.62257 .36323 m
.62292 .3604 L
s
0 0 0 r
2 Mabswid
.61372 .35592 Mdot
0 g
.5 Mabswid
.61966 .36687 m
.62082 .36797 L
s
0 0 0 r
2 Mabswid
.61368 .35585 Mdot
.61363 .35577 Mdot
0 g
.5 Mabswid
.61724 .35085 m
.61763 .34944 L
s
.60799 .35569 m
.60958 .35518 L
s
.60799 .35569 m
.6082 .35796 L
s
0 1 0 r
.62107 .35569 m
.67381 .33923 L
s
0 0 0 r
2 Mabswid
.62107 .35569 Mdot
0 g
.5 Mabswid
.61282 .35227 m
.615 .35157 L
s
.61273 .35417 m .6149 .35347 L .61585 .35543 L .656 .751 .92 r
F
0 g
.61273 .35417 m
.61282 .35227 L
s
.61585 .35543 m
.61702 .35732 L
s
.61273 .35417 m
.61382 .35608 L
s
1 0 0 r
.62075 .3554 m
.67386 .33887 L
s
0 0 0 r
2 Mabswid
.62075 .3554 Mdot
0 g
.5 Mabswid
.61045 .36534 m
.61156 .36743 L
s
.61156 .36743 m
.61315 .36692 L
s
.61478 .35351 m .6194 .35429 L .61614 .35534 L .656 .751 .92 r
F
0 0 1 r
.61377 .35599 m
.61579 .35532 L
s
0 1 0 r
.61372 .35592 m
.61575 .35525 L
s
1 0 0 r
.61368 .35585 m
.6157 .35517 L
s
1 0 1 r
.61363 .35577 m
.61566 .35509 L
s
0 g
.61614 .35534 m
.61756 .35715 L
s
1 0 1 r
.61697 .3564 m
.62049 .35518 L
s
0 0 1 r
.61579 .35532 m
.61605 .35521 L
s
0 0 0 r
2 Mabswid
.61579 .35532 Mdot
0 1 0 r
.5 Mabswid
.61575 .35525 m
.61599 .35515 L
s
0 0 0 r
2 Mabswid
.61575 .35525 Mdot
.61605 .35521 Mdot
0 g
.5 Mabswid
.60958 .35518 m
.60979 .35745 L
s
.6219 .36615 m
.62306 .36726 L
s
1 0 1 r
.62049 .35518 m
.6739 .33857 L
s
0 0 0 r
2 Mabswid
.62049 .35518 Mdot
1 0 0 r
.5 Mabswid
.6157 .35517 m
.61594 .35507 L
s
0 0 0 r
2 Mabswid
.6157 .35517 Mdot
.61599 .35515 Mdot
1 0 1 r
.5 Mabswid
.61566 .35509 m
.61589 .355 L
s
0 0 0 r
2 Mabswid
.61566 .35509 Mdot
.61594 .35507 Mdot
0 g
.5 Mabswid
.61748 .36756 m
.61966 .36687 L
s
.61631 .36591 m
.61748 .36756 L
s
0 0 0 r
2 Mabswid
.61589 .355 Mdot
0 g
.5 Mabswid
.6219 .36615 m
.62257 .36323 L
s
.61487 .35161 m
.61724 .35085 L
s
.61315 .36692 m
.61204 .36483 L
s
.6082 .35796 m
.60979 .35745 L
s
.6082 .35796 m
.60871 .36043 L
s
.48489 .39129 m .46124 .3898 L .45611 .36282 L .951 .679 .485 r
F
.48937 .40607 m .46124 .3898 L .48489 .39129 L .953 .686 .494 r
F
0 g
.60947 .36295 m
.61045 .36534 L
s
.61045 .36534 m
.61204 .36483 L
s
.61836 .36526 m
.61954 .36691 L
s
.61954 .36691 m
.6219 .36615 L
s
.46813 .35086 m .49731 .34128 L .50898 .35438 L .656 .751 .92 r
F
0 g
.50898 .35438 m
.52052 .36732 L
s
.61849 .36522 m
.61966 .36687 L
s
.61478 .35351 m .61715 .35275 L .6194 .35429 L .656 .751 .92 r
F
0 g
.61715 .35275 m
.6194 .35429 L
s
.6149 .35347 m
.615 .35157 L
s
.61478 .35351 m
.61487 .35161 L
s
1 0 1 r
.61589 .355 m
.61887 .35391 L
s
1 0 0 r
.61594 .35507 m
.61896 .35397 L
s
0 1 0 r
.61599 .35515 m
.61905 .35403 L
s
0 0 1 r
.61605 .35521 m
.61913 .35409 L
s
0 g
.6194 .35429 m
.62134 .35594 L
s
.6149 .35347 m
.61585 .35543 L
s
.61478 .35351 m
.61614 .35534 L
s
.6103 .35992 m
.60979 .35745 L
s
.60871 .36043 m
.6103 .35992 L
s
.60871 .36043 m
.60947 .36295 L
s
.48937 .40607 m .46955 .41724 L .46124 .3898 L .953 .686 .494 r
F
0 g
.61273 .35417 m
.6149 .35347 L
s
.61273 .35417 m
.61294 .35643 L
s
.60947 .36295 m
.61106 .36244 L
s
0 0 1 r
.61913 .35409 m
.67406 .33723 L
s
0 0 0 r
2 Mabswid
.61913 .35409 Mdot
0 g
.5 Mabswid
.61715 .35275 m
.61724 .35085 L
s
0 1 0 r
.61905 .35403 m
.67408 .33711 L
s
0 0 0 r
2 Mabswid
.61905 .35403 Mdot
0 g
.5 Mabswid
.61204 .36483 m
.61106 .36244 L
s
1 0 0 r
.61896 .35397 m
.67409 .33701 L
s
0 0 0 r
2 Mabswid
.61896 .35397 Mdot
1 0 1 r
.5 Mabswid
.61887 .35391 m
.67411 .33689 L
s
0 0 0 r
2 Mabswid
.61887 .35391 Mdot
0 g
.5 Mabswid
.61519 .36382 m
.61631 .36591 L
s
.61631 .36591 m
.61849 .36522 L
s
.61106 .36244 m
.6103 .35992 L
s
.62073 .3645 m
.6219 .36615 L
s
.61478 .35351 m
.61715 .35275 L
s
.61478 .35351 m
.615 .35578 L
s
.6149 .35347 m
.61512 .35574 L
s
.61294 .35643 m
.61512 .35574 L
s
.61294 .35643 m
.61345 .35891 L
s
.61725 .36316 m
.61836 .36526 L
s
.61836 .36526 m
.62073 .3645 L
s
.61849 .36522 m
.61737 .36312 L
s
.61422 .36143 m
.61519 .36382 L
s
.61519 .36382 m
.61737 .36312 L
s
.67228 .34341 m
.6723 .34724 L
s
.67235 .33946 m
.67228 .34341 L
s
.61715 .35275 m
.61736 .35502 L
s
.45451 .33829 m .42872 .28362 L .45652 .31797 L .941 .653 .466 r
F
0 g
.6725 .33564 m
.67235 .33946 L
s
.61345 .35891 m
.61563 .35821 L
s
.61345 .35891 m
.61422 .36143 L
s
.61422 .36143 m
.6164 .36074 L
s
.615 .35578 m
.61736 .35502 L
s
.615 .35578 m
.61551 .35825 L
s
.61563 .35821 m
.61512 .35574 L
s
.62073 .3645 m
.61962 .36241 L
s
.61628 .36077 m
.61725 .36316 L
s
.61725 .36316 m
.61962 .36241 L
s
.61737 .36312 m
.6164 .36074 L
s
.6723 .34724 m
.67239 .35067 L
s
.61551 .35825 m
.61787 .3575 L
s
.61551 .35825 m
.61628 .36077 L
s
.6164 .36074 m
.61563 .35821 L
s
.61628 .36077 m
.61864 .36002 L
s
.67272 .33221 m
.6725 .33564 L
s
.61787 .3575 m
.61736 .35502 L
s
.52113 .54047 m
.55698 .52977 L
s
.61962 .36241 m
.61864 .36002 L
s
.61864 .36002 m
.61787 .3575 L
s
.45451 .33829 m .49731 .34128 L .46813 .35086 L .656 .751 .92 r
F
0 g
.46813 .35086 m
.48117 .36344 L
s
1 0 0 r
.46079 .34421 m
.46093 .34415 L
s
.15306 .48796 m
.45507 .34688 L
s
.46077 .3442 m
.46093 .34415 L
s
.08708 .46739 m
.45502 .34609 L
s
0 1 0 r
.46671 .3498 m
.46692 .34973 L
s
.46673 .34982 m
.46692 .34973 L
s
0 g
.67239 .35067 m
.67257 .35349 L
s
.67239 .35067 m
.67277 .34762 L
s
.67239 .35067 m
.67239 .35067 L
s
.673 .32941 m
.67272 .33221 L
s
0 0 0 r
2 Mabswid
.46692 .34973 Mdot
0 g
.5 Mabswid
.67257 .35349 m
.67281 .3555 L
s
.46436 .2715 m
.4722 .25041 L
s
.67331 .32743 m
.673 .32941 L
s
.673 .32941 m
.673 .32941 L
s
.67318 .33343 m
.673 .32941 L
s
.02403 .57391 m
.41208 .45114 L
s
.5064 .48259 m .48206 .50001 L .49301 .46539 L .959 .717 .529 r
F
.5064 .48259 m .50179 .52494 L .48206 .50001 L F
.5064 .48259 m .53771 .49344 L .50433 .5036 L .544 .324 .532 r
F
.5064 .48259 m .5375 .47303 L .53771 .49344 L F
0 g
.5064 .48259 m
.50803 .4619 L
s
.53729 .45282 m
.5375 .47303 L
s
.67277 .34762 m
.67315 .34455 L
s
1 0 1 r
.67296 .34615 m
.61444 .32285 L
s
0 0 0 r
2 Mabswid
.67296 .34615 Mdot
0 g
.5 Mabswid
.67281 .3555 m
.6731 .35656 L
s
1 0 0 r
.67297 .34603 m
.72832 .32761 L
s
0 0 0 r
2 Mabswid
.67297 .34603 Mdot
0 g
.5 Mabswid
.67336 .33745 m
.67318 .33343 L
s
0 1 0 r
.67298 .34593 m
.72834 .32749 L
s
0 0 0 r
2 Mabswid
.67298 .34593 Mdot
0 0 1 r
.5 Mabswid
.673 .34581 m
.61449 .32242 L
s
0 0 0 r
2 Mabswid
.673 .34581 Mdot
0 g
.5 Mabswid
.67364 .32639 m
.67331 .32743 L
s
.67315 .34455 m
.67353 .34148 L
s
1 0 1 r
.67317 .34443 m
.61459 .3213 L
s
0 0 0 r
2 Mabswid
.67317 .34443 Mdot
.46093 .34415 Mdot
1 0 0 r
.5 Mabswid
.67321 .34412 m
.72858 .3259 L
s
0 0 0 r
2 Mabswid
.67321 .34412 Mdot
0 1 0 r
.5 Mabswid
.67325 .34376 m
.72863 .32557 L
s
0 0 0 r
2 Mabswid
.67325 .34376 Mdot
0 g
.5 Mabswid
.67353 .34148 m
.67336 .33745 L
s
0 0 1 r
.67331 .34328 m
.61469 .32028 L
s
0 0 0 r
2 Mabswid
.67331 .34328 Mdot
0 g
.5 Mabswid
.6731 .35656 m
.67343 .35659 L
s
1 0 1 r
.67333 .34309 m
.6147 .32018 L
s
0 0 0 r
2 Mabswid
.67333 .34309 Mdot
0 g
.5 Mabswid
.67397 .32639 m
.67364 .32639 L
s
.67371 .34552 m
.67353 .34148 L
s
.67353 .34148 m
.67392 .3384 L
s
.45451 .33829 m .48551 .32804 L .49731 .34128 L .656 .751 .92 r
F
1 0 1 r
.4562 .33988 m
.45625 .33986 L
s
.08254 .46338 m
.45465 .34039 L
s
.4562 .33989 m
.45625 .33986 L
s
.15148 .48671 m
.45466 .34063 L
s
0 g
.49731 .34128 m
.50898 .35438 L
s
.67343 .35659 m
.67376 .35559 L
s
1 0 1 r
.67373 .33988 m
.61494 .31773 L
s
0 0 0 r
2 Mabswid
.67373 .33988 Mdot
.45625 .33986 Mdot
0 g
.5 Mabswid
.67426 .32741 m
.67397 .32639 L
s
0 0 1 r
.67376 .33971 m
.61495 .31763 L
s
0 0 0 r
2 Mabswid
.67376 .33971 Mdot
0 1 0 r
.5 Mabswid
.67381 .33923 m
.72916 .32197 L
s
0 0 0 r
2 Mabswid
.67381 .33923 Mdot
0 g
.5 Mabswid
.67389 .34957 m
.67371 .34552 L
s
1 0 0 r
.67386 .33887 m
.7292 .32165 L
s
0 0 0 r
2 Mabswid
.67386 .33887 Mdot
1 0 1 r
.5 Mabswid
.6739 .33857 m
.61505 .31663 L
s
0 0 0 r
2 Mabswid
.6739 .33857 Mdot
0 g
.5 Mabswid
.67392 .3384 m
.6743 .33531 L
s
.45451 .33829 m .42551 .31316 L .42872 .28362 L .941 .653 .466 r
F
0 g
.42872 .28362 m
.43691 .26251 L
s
.45611 .36282 m .42551 .31316 L .45451 .33829 L .94 .663 .486 r
F
.44031 .32572 m .48551 .32804 L .45451 .33829 L .656 .751 .92 r
F
0 g
.45451 .33829 m
.46813 .35086 L
s
.50433 .5036 m .53793 .51404 L .50179 .52494 L .544 .324 .532 r
F
0 g
.50179 .52494 m
.52113 .54047 L
s
.50433 .5036 m .53771 .49344 L .53793 .51404 L .544 .324 .532 r
F
0 g
.50433 .5036 m
.5064 .48259 L
s
.53793 .51404 m
.55698 .52977 L
s
.50179 .52494 m
.50433 .5036 L
s
.5375 .47303 m
.53771 .49344 L
s
.67376 .35559 m
.67407 .35362 L
s
0 0 1 r
.67406 .33723 m
.61515 .31554 L
s
0 0 0 r
2 Mabswid
.67406 .33723 Mdot
0 1 0 r
.5 Mabswid
.67408 .33711 m
.72943 .32009 L
s
0 0 0 r
2 Mabswid
.67408 .33711 Mdot
1 0 0 r
.5 Mabswid
.67409 .33701 m
.72945 .31997 L
s
0 0 0 r
2 Mabswid
.67409 .33701 Mdot
0 g
.5 Mabswid
.67407 .35362 m
.67389 .34957 L
s
1 0 1 r
.67411 .33689 m
.6152 .31511 L
s
0 0 0 r
2 Mabswid
.67411 .33689 Mdot
0 g
.5 Mabswid
.67451 .3294 m
.67426 .32741 L
s
.6743 .33531 m
.67468 .33222 L
s
.72735 .32579 m
.72738 .32964 L
s
.72742 .32181 m
.72735 .32579 L
s
.7276 .31795 m
.72742 .32181 L
s
.67407 .35362 m
.67435 .35082 L
s
.67407 .35362 m
.67407 .35362 L
s
.49301 .46539 m .46343 .46733 L .48041 .44307 L .952 .707 .529 r
F
.49301 .46539 m .48206 .50001 L .46343 .46733 L F
0 g
.42872 .28362 m
.46436 .2715 L
s
.72738 .32964 m
.72752 .33309 L
s
.72786 .31449 m
.7276 .31795 L
s
.67468 .33222 m
.67451 .3294 L
s
.72752 .33309 m
.72774 .33592 L
s
.72752 .33309 m
.72797 .32999 L
s
.72752 .33309 m
.72752 .33309 L
s
.72819 .31165 m
.72786 .31449 L
s
.67435 .35082 m
.67458 .34738 L
s
.67479 .33568 m
.67468 .33222 L
s
.67468 .33222 m
.67468 .33222 L
s
.72774 .33592 m
.72805 .33792 L
s
.67458 .34738 m
.67473 .34353 L
s
.6748 .33953 m
.67479 .33568 L
s
.72857 .30963 m
.72819 .31165 L
s
.72819 .31165 m
.72819 .31165 L
s
.72842 .31568 m
.72819 .31165 L
s
.61385 .32101 m
.61385 .32486 L
s
.61392 .31702 m
.61385 .32101 L
s
.61405 .31315 m
.61392 .31702 L
s
.67473 .34353 m
.6748 .33953 L
s
.72797 .32999 m
.72843 .32688 L
s
.61385 .32486 m
.61391 .32832 L
s
.61424 .30968 m
.61405 .31315 L
s
.72805 .33792 m
.72842 .33896 L
s
.72866 .31971 m
.72842 .31568 L
s
.61391 .32832 m
.61403 .33115 L
s
.61391 .32832 m
.61421 .32521 L
s
.61391 .32832 m
.61391 .32832 L
s
.44031 .32572 m .47356 .31464 L .48551 .32804 L .656 .751 .92 r
F
0 g
.48551 .32804 m
.49731 .34128 L
s
.61446 .30683 m
.61424 .30968 L
s
.72897 .30856 m
.72857 .30963 L
s
.45611 .36282 m .42766 .34911 L .42551 .31316 L .94 .663 .486 r
F
0 0 1 r
.14457 .48133 m
.4263 .32637 L
s
.46124 .3898 m .42766 .34911 L .45611 .36282 L .941 .673 .502 r
F
0 0 0 r
2 Mabswid
.72832 .32761 Mdot
.72834 .32749 Mdot
0 g
.5 Mabswid
.50179 .52494 m
.53793 .51404 L
s
.48206 .50001 m
.50179 .52494 L
s
.72843 .32688 m
.72889 .32376 L
s
.53771 .49344 m
.53793 .51404 L
s
.61403 .33115 m
.61421 .33315 L
s
.72889 .32376 m
.72866 .31971 L
s
0 0 0 r
2 Mabswid
.72858 .3259 Mdot
0 g
.5 Mabswid
.61471 .30479 m
.61446 .30683 L
s
.61446 .30683 m
.61446 .30683 L
s
.61458 .31086 m
.61446 .30683 L
s
.42551 .31316 m .47356 .31464 L .44031 .32572 L .656 .751 .92 r
F
1 0 1 r
.43152 .31837 m
.43167 .31832 L
s
.05938 .44297 m
.42593 .32024 L
s
1 0 0 r
.43272 .31941 m
.43288 .31935 L
s
.0605 .44396 m
.42602 .32165 L
s
0 1 0 r
.43392 .32044 m
.4341 .32038 L
s
.06162 .44495 m
.4261 .32306 L
s
0 0 1 r
.43512 .32148 m
.43531 .32142 L
s
.06273 .44593 m
.42619 .32446 L
s
1 0 1 r
.43155 .31839 m
.43167 .31832 L
s
.14341 .48042 m
.42601 .3215 L
s
1 0 0 r
.43275 .31943 m
.43288 .31935 L
s
.14379 .48072 m
.42611 .32313 L
s
0 1 0 r
.43395 .32047 m
.4341 .32038 L
s
.14418 .48102 m
.42621 .32476 L
s
0 0 1 r
.43515 .32151 m
.43531 .32142 L
s
0 g
.44031 .32572 m
.45451 .33829 L
s
0 0 0 r
2 Mabswid
.72863 .32557 Mdot
0 g
.5 Mabswid
.72842 .33896 m
.72881 .33897 L
s
.48041 .44307 m .44736 .4293 L .46955 .41724 L .947 .695 .524 r
F
.48041 .44307 m .46343 .46733 L .44736 .4293 L F
0 g
.61421 .32521 m
.61452 .32208 L
s
.72937 .30853 m
.72897 .30856 L
s
.72913 .32781 m
.72889 .32376 L
s
.72889 .32376 m
.72935 .32063 L
s
.61421 .33315 m
.61443 .33419 L
s
.6147 .3149 m
.61458 .31086 L
s
.61496 .30372 m
.61471 .30479 L
s
0 0 0 r
2 Mabswid
.61444 .32285 Mdot
0 g
.5 Mabswid
.72881 .33897 m
.72922 .33794 L
s
0 0 1 r
.61449 .32242 m
.49157 .27328 L
s
0 0 0 r
2 Mabswid
.61449 .32242 Mdot
0 g
.5 Mabswid
.61452 .32208 m
.61482 .31895 L
s
.72974 .30954 m
.72937 .30853 L
s
0 0 0 r
2 Mabswid
.72916 .32197 Mdot
.46124 .3898 m .43512 .38884 L .42766 .34911 L .941 .673 .502 r
F
.46955 .41724 m .43512 .38884 L .46124 .3898 L .943 .684 .515 r
F
0 0 0 r
.7292 .32165 Mdot
0 g
.5 Mabswid
.72936 .33187 m
.72913 .32781 L
s
0 0 0 r
2 Mabswid
.43531 .32142 Mdot
.61459 .3213 Mdot
0 g
.5 Mabswid
.61482 .31895 m
.6147 .3149 L
s
.46955 .41724 m .44736 .4293 L .43512 .38884 L .943 .684 .515 r
F
0 g
.41208 .45114 m
.8259 .32023 L
s
.61443 .33419 m
.61468 .33419 L
s
.72935 .32063 m
.72982 .31749 L
s
0 0 0 r
2 Mabswid
.4341 .32038 Mdot
0 0 1 r
.5 Mabswid
.61469 .32028 m
.49336 .27267 L
s
0 0 0 r
2 Mabswid
.61469 .32028 Mdot
0 g
.5 Mabswid
.61521 .30368 m
.61496 .30372 L
s
0 0 0 r
2 Mabswid
.6147 .32018 Mdot
.72943 .32009 Mdot
.72945 .31997 Mdot
0 g
.5 Mabswid
.72922 .33794 m
.7296 .33594 L
s
0 0 0 r
2 Mabswid
.43288 .31935 Mdot
0 g
.5 Mabswid
.7296 .33594 m
.72936 .33187 L
s
.73005 .31152 m
.72974 .30954 L
s
.61494 .32301 m
.61482 .31895 L
s
.61482 .31895 m
.61513 .31581 L
s
0 0 0 r
2 Mabswid
.43167 .31832 Mdot
.61494 .31773 Mdot
0 g
.5 Mabswid
.61468 .33419 m
.61494 .33315 L
s
0 0 1 r
.61495 .31763 m
.49432 .27235 L
s
0 0 0 r
2 Mabswid
.61495 .31763 Mdot
0 g
.5 Mabswid
.72982 .31749 m
.73028 .31435 L
s
.61543 .30469 m
.61521 .30368 L
s
.7296 .33594 m
.72994 .3331 L
s
.7296 .33594 m
.7296 .33594 L
s
.61507 .32707 m
.61494 .32301 L
s
0 0 0 r
2 Mabswid
.61505 .31663 Mdot
0 g
.5 Mabswid
.73028 .31435 m
.73005 .31152 L
s
.61513 .31581 m
.61544 .31266 L
s
.51841 .48888 m
.53793 .51404 L
s
0 0 1 r
.61515 .31554 m
.49615 .27173 L
s
0 0 0 r
2 Mabswid
.61515 .31554 Mdot
.6152 .31511 Mdot
0 g
.5 Mabswid
.61494 .33315 m
.61519 .33114 L
s
.72994 .3331 m
.7302 .32962 L
s
.42551 .31316 m .46148 .30108 L .47356 .31464 L .656 .751 .92 r
F
0 g
.46148 .30108 m
.47356 .31464 L
s
.46148 .30108 m
.46436 .2715 L
s
.47356 .31464 m
.48551 .32804 L
s
.42551 .31316 m
.42872 .28362 L
s
.42551 .31316 m
.44031 .32572 L
s
.73042 .31782 m
.73028 .31435 L
s
.73028 .31435 m
.73028 .31435 L
s
.61519 .33114 m
.61507 .32707 L
s
.61562 .30667 m
.61543 .30469 L
s
.42551 .31316 m
.46148 .30108 L
s
.42551 .31316 m
.42766 .34911 L
s
.7302 .32962 m
.73038 .32573 L
s
.73045 .32171 m
.73042 .31782 L
s
.61544 .31266 m
.61574 .3095 L
s
.73038 .32573 m
.73045 .32171 L
s
.61519 .33114 m
.61542 .32829 L
s
.61519 .33114 m
.61519 .33114 L
s
.61574 .3095 m
.61562 .30667 L
s
.61542 .32829 m
.6156 .3248 L
s
.61581 .31298 m
.61574 .3095 L
s
.61574 .3095 m
.61574 .3095 L
s
.6156 .3248 m
.61573 .3209 L
s
.6158 .31687 m
.61581 .31298 L
s
.46343 .46733 m
.48206 .50001 L
s
.48206 .50001 m
.51841 .48888 L
s
.80556 .30106 m
.80477 .29849 L
s
.80477 .29849 m
.80504 .2984 L
s
.80477 .29849 m
.80381 .29604 L
s
.80612 .30357 m
.80556 .30106 L
s
.80556 .30106 m
.80583 .30097 L
s
.80504 .2984 m
.80583 .30097 L
s
.80408 .29595 m
.80504 .2984 L
s
.61573 .3209 m
.6158 .31687 L
s
.80583 .30097 m
.8064 .30348 L
s
.80381 .29604 m
.80408 .29595 L
s
.80381 .29604 m
.80274 .29388 L
s
.80302 .29379 m
.80408 .29595 L
s
.80612 .30357 m
.8064 .30348 L
s
.80274 .29388 m
.80302 .29379 L
s
.80368 .30444 m .8067 .30578 L .80643 .30586 L .656 .751 .92 r
F
0 g
.80643 .30586 m
.80645 .30778 L
s
.80612 .30357 m
.8064 .30564 L
s
.80368 .30444 m .80532 .30391 L .8067 .30578 L .656 .751 .92 r
F
0 g
.8067 .30578 m
.80672 .30769 L
s
.8064 .30348 m
.8067 .30578 L
s
.80643 .30586 m
.8067 .30578 L
s
.80164 .29215 m .80212 .29477 L .80049 .29529 L .544 .324 .532 r
F
.80164 .29215 m .80192 .29206 L .80212 .29477 L F
0 g
.80196 .29265 m
.80274 .29388 L
s
.80192 .29206 m
.80302 .29379 L
s
.80164 .29215 m
.80192 .29206 L
s
.80059 .29097 m
.80164 .29215 L
s
.80086 .29088 m
.80192 .29206 L
s
.80619 .30918 m
.80645 .30778 L
s
.80645 .30778 m
.80672 .30769 L
s
.80153 .30282 m .80532 .30391 L .80368 .30444 L .656 .751 .92 r
F
0 g
.80368 .30444 m
.80643 .30586 L
s
.80672 .30769 m
.80646 .3091 L
s
.80153 .30282 m .80393 .30205 L .80532 .30391 L .656 .751 .92 r
F
0 1 0 r
.72834 .32749 m
.80178 .30304 L
s
0 g
.80532 .30391 m
.8067 .30578 L
s
.80049 .29529 m .80233 .29747 L .79993 .29824 L .544 .324 .532 r
F
.80049 .29529 m .80212 .29477 L .80233 .29747 L F
0 g
.80049 .29529 m
.80164 .29215 L
s
.80192 .29206 m
.80212 .29477 L
s
.80059 .29097 m
.80086 .29088 L
s
.80059 .29097 m
.79964 .29043 L
s
.79992 .29034 m
.80086 .29088 L
s
.79988 .30103 m .80393 .30205 L .80153 .30282 L .656 .751 .92 r
F
0 1 0 r
.80178 .30304 m
.80404 .3022 L
s
0 g
.80153 .30282 m
.80368 .30444 L
s
.80566 .30998 m
.80619 .30918 L
s
.80619 .30918 m
.80646 .3091 L
s
.80646 .3091 m
.80593 .3099 L
s
.69084 .29616 m
.69005 .29359 L
s
.69005 .29359 m
.69032 .2935 L
s
.69005 .29359 m
.68907 .29114 L
s
.69138 .29868 m
.69084 .29616 L
s
.69084 .29616 m
.6911 .29608 L
s
.69032 .2935 m
.6911 .29608 L
s
.68933 .29105 m
.69032 .2935 L
s
.79993 .29824 m .80254 .30018 L .79988 .30103 L .544 .324 .532 r
F
.79993 .29824 m .80233 .29747 L .80254 .30018 L F
0 g
.79993 .29824 m
.80049 .29529 L
s
.80212 .29477 m
.80233 .29747 L
s
.6911 .29608 m
.69164 .29859 L
s
.68907 .29114 m
.68933 .29105 L
s
.68907 .29114 m
.68795 .28897 L
s
0 1 0 r
.80404 .3022 m
.88631 .26937 L
s
0 0 0 r
2 Mabswid
.80404 .3022 Mdot
0 g
.5 Mabswid
.68822 .28888 m
.68933 .29105 L
s
.79988 .30103 m .80254 .30018 L .80393 .30205 L .656 .751 .92 r
F
0 1 0 r
.72863 .32557 m
.80062 .30192 L
s
0 g
.80393 .30205 m
.80532 .30391 L
s
.69138 .29868 m
.69164 .29859 L
s
0 1 0 r
.80062 .30192 m
.80318 .30104 L
s
0 g
.79964 .29043 m
.79992 .29034 L
s
.79964 .29043 m
.79888 .29055 L
s
.79915 .29046 m
.79992 .29034 L
s
.68795 .28897 m
.68822 .28888 L
s
.46148 .30108 m
.46389 .33714 L
s
0 1 0 r
.80318 .30104 m
.88749 .27104 L
s
0 0 0 r
2 Mabswid
.80318 .30104 Mdot
.79988 .30103 m .80275 .30289 L .80034 .30366 L .544 .324 .532 r
F
.79988 .30103 m .80254 .30018 L .80275 .30289 L F
.79874 .29908 m .80254 .30018 L .79988 .30103 L .656 .751 .92 r
F
0 g
.5 Mabswid
.79991 .29942 m
.79993 .29824 L
s
.68881 .29954 m .6919 .30089 L .69163 .30098 L .656 .751 .92 r
F
0 g
.69158 .30289 m
.69163 .30098 L
s
.69138 .29868 m
.69161 .30076 L
s
.8049 .31012 m
.80566 .30998 L
s
.80566 .30998 m
.80593 .3099 L
s
.68881 .29954 m .69042 .29902 L .6919 .30089 L .656 .751 .92 r
F
0 g
.69185 .3028 m
.6919 .30089 L
s
.69164 .29859 m
.6919 .30089 L
s
.69163 .30098 m
.6919 .30089 L
s
.80593 .3099 m
.80517 .31003 L
s
.79874 .29908 m .80115 .29831 L .80254 .30018 L .656 .751 .92 r
F
0 1 0 r
.72916 .32197 m
.79926 .3001 L
s
0 g
.80254 .30018 m
.80393 .30205 L
s
.80233 .29747 m
.80254 .30018 L
s
0 1 0 r
.79926 .3001 m
.8019 .29932 L
s
0 0 0 r
2 Mabswid
.79926 .3001 Mdot
.68679 .28723 m .68719 .28985 L .68558 .29038 L .539 .317 .526 r
F
1 0 0 r
.5 Mabswid
.55121 .25309 m
.6747 .29943 L
s
.54981 .25357 m
.67252 .30014 L
s
.67252 .30014 m
.7292 .32165 L
s
.54908 .25382 m
.66806 .30159 L
s
.66806 .30159 m
.72858 .3259 L
s
.5477 .25428 m
.66594 .30228 L
s
.66594 .30228 m
.72832 .32761 L
s
.68679 .28723 m .68706 .28715 L .68719 .28985 L .539 .317 .526 r
F
0 g
.68708 .28767 m
.68795 .28897 L
s
.68706 .28715 m
.68822 .28888 L
s
.68679 .28723 m
.68706 .28715 L
s
.68565 .28605 m
.68679 .28723 L
s
.68592 .28596 m
.68706 .28715 L
s
.79888 .29055 m
.79915 .29046 L
s
.79888 .29055 m
.79834 .29133 L
s
.69124 .3043 m
.69158 .30289 L
s
.69158 .30289 m
.69185 .3028 L
s
.68656 .29792 m .69042 .29902 L .68881 .29954 L .656 .751 .92 r
F
1 0 0 r
.6747 .29943 m
.72945 .31997 L
s
0 g
.68881 .29954 m
.69163 .30098 L
s
.79861 .29125 m
.79915 .29046 L
s
.69185 .3028 m
.6915 .30421 L
s
.80034 .30366 m .80296 .30561 L .80132 .30613 L .544 .324 .532 r
F
.80034 .30366 m .80275 .30289 L .80296 .30561 L F
0 g
.79988 .30103 m
.80034 .30366 L
s
.80254 .30018 m
.80275 .30289 L
s
0 1 0 r
.8019 .29932 m
.8897 .27421 L
s
0 0 0 r
2 Mabswid
.8019 .29932 Mdot
.79812 .29696 m .80115 .29831 L .79874 .29908 L .656 .751 .92 r
F
0 g
.5 Mabswid
.79874 .29908 m
.79988 .30103 L
s
0 1 0 r
.72943 .32009 m
.79863 .29881 L
s
0 g
.80395 .30959 m
.8049 .31012 L
s
.8049 .31012 m
.80517 .31003 L
s
.68656 .29792 m .68894 .29715 L .69042 .29902 L .656 .751 .92 r
F
1 0 1 r
.61444 .32285 m
.687 .29828 L
s
0 g
.69042 .29902 m
.6919 .30089 L
s
.80517 .31003 m
.80423 .3095 L
s
.68558 .29038 m .68732 .29256 L .68495 .29333 L .539 .317 .526 r
F
.68558 .29038 m .68719 .28985 L .68732 .29256 L F
0 g
.68558 .29038 m
.68679 .28723 L
s
.68706 .28715 m
.68719 .28985 L
s
0 0 0 r
2 Mabswid
.79863 .29881 Mdot
0 g
.5 Mabswid
.68565 .28605 m
.68592 .28596 L
s
.68565 .28605 m
.68461 .2855 L
s
.68488 .28541 m
.68592 .28596 L
s
.79812 .29696 m .79976 .29643 L .80115 .29831 L .656 .751 .92 r
F
0 1 0 r
.79863 .29881 m
.80104 .29816 L
s
0 g
.80115 .29831 m
.80254 .30018 L
s
0 1 0 r
.80104 .29816 m
.89087 .27589 L
s
0 0 0 r
2 Mabswid
.80104 .29816 Mdot
.68483 .29612 m .68894 .29715 L .68656 .29792 L .656 .751 .92 r
F
1 0 1 r
.5 Mabswid
.687 .29828 m
.68917 .29745 L
s
0 g
.68656 .29792 m
.68881 .29954 L
s
1 0 1 r
.61459 .3213 m
.68594 .29735 L
s
0 g
.69061 .30509 m
.69124 .3043 L
s
.69124 .3043 m
.6915 .30421 L
s
.6915 .30421 m
.69088 .30501 L
s
.79834 .29133 m
.79861 .29125 L
s
.79834 .29133 m
.79807 .29273 L
s
.79834 .29264 m
.79861 .29125 L
s
.68495 .29333 m .68745 .29527 L .68483 .29612 L .539 .317 .526 r
F
.68495 .29333 m .68732 .29256 L .68745 .29527 L F
0 g
.68495 .29333 m
.68558 .29038 L
s
.68719 .28985 m
.68732 .29256 L
s
.80132 .30613 m .80317 .30833 L .80289 .30842 L .544 .324 .532 r
F
.80132 .30613 m .80296 .30561 L .80317 .30833 L F
0 g
.80034 .30366 m
.80132 .30613 L
s
.80132 .30613 m
.80289 .30842 L
s
.80275 .30289 m
.80296 .30561 L
s
0 0 0 r
2 Mabswid
.68917 .29745 Mdot
0 g
.5 Mabswid
.42766 .34911 m
.46389 .33714 L
s
.42766 .34911 m
.43512 .38884 L
s
.80289 .30842 m
.80395 .30959 L
s
.80395 .30959 m
.80423 .3095 L
s
.68483 .29612 m .68745 .29527 L .68894 .29715 L .656 .751 .92 r
F
1 0 1 r
.68594 .29735 m
.6884 .29647 L
s
.6147 .32018 m
.68534 .29672 L
s
0 g
.68894 .29715 m
.69042 .29902 L
s
.80317 .30833 m
.80423 .3095 L
s
.80296 .30561 m
.80317 .30833 L
s
.79809 .29465 m .79976 .29643 L .79812 .29696 L .656 .751 .92 r
F
0 g
.79812 .29696 m
.79874 .29908 L
s
.68461 .2855 m
.68488 .28541 L
s
.68461 .2855 m
.68375 .28562 L
s
.68402 .28553 m
.68488 .28541 L
s
0 0 0 r
2 Mabswid
.6884 .29647 Mdot
.79809 .29465 m .79836 .29456 L .79976 .29643 L .656 .751 .92 r
F
0 g
.5 Mabswid
.79836 .29456 m
.79976 .29643 L
s
1 0 1 r
.6884 .29647 m
.86026 .23203 L
s
0 g
.79976 .29643 m
.80115 .29831 L
s
1 0 1 r
.68917 .29745 m
.85751 .22809 L
s
0 g
.79809 .29465 m
.79812 .29696 L
s
.68483 .29612 m .68758 .29799 L .68521 .29876 L .539 .317 .526 r
F
.68483 .29612 m .68745 .29527 L .68758 .29799 L F
1 0 1 r
.68749 .29599 m
.68791 .29584 L
s
.68359 .29417 m .68745 .29527 L .68483 .29612 L .656 .751 .92 r
F
0 g
.6849 .29454 m
.68495 .29333 L
s
1 0 1 r
.61494 .31773 m
.68437 .29551 L
s
0 g
.79807 .29273 m
.79834 .29264 L
s
.79807 .29273 m
.79809 .29465 L
s
.68975 .30523 m
.69061 .30509 L
s
.69061 .30509 m
.69088 .30501 L
s
.79834 .29264 m
.79836 .29456 L
s
.69088 .30501 m
.69002 .30514 L
s
1 0 1 r
.68791 .29584 m
.86215 .23475 L
s
0 0 0 r
2 Mabswid
.68791 .29584 Mdot
0 g
.5 Mabswid
.80179 .30669 m
.80289 .30842 L
s
.80289 .30842 m
.80317 .30833 L
s
0 0 0 r
2 Mabswid
.68437 .29551 Mdot
0 g
.5 Mabswid
.80206 .3066 m
.80317 .30833 L
s
.51841 .48888 m
.4999 .45596 L
s
.68359 .29417 m .68596 .29339 L .68745 .29527 L .656 .751 .92 r
F
1 0 1 r
.68437 .29551 m
.687 .29469 L
s
.61505 .31663 m
.68394 .29482 L
s
0 g
.68745 .29527 m
.68894 .29715 L
s
.68732 .29256 m
.68745 .29527 L
s
0 0 0 r
2 Mabswid
.68394 .29482 Mdot
1 0 1 r
.5 Mabswid
.687 .29469 m
.8662 .24055 L
s
0 0 0 r
2 Mabswid
.687 .29469 Mdot
0 g
.5 Mabswid
.68375 .28562 m
.68402 .28553 L
s
.68375 .28562 m
.68312 .2864 L
s
.79809 .29465 m
.79836 .29456 L
s
.79809 .29465 m
.79839 .29695 L
s
.68339 .28631 m
.68402 .28553 L
s
.79836 .29456 m
.79866 .29686 L
s
.68521 .29876 m .68771 .3007 L .6861 .30123 L .539 .317 .526 r
F
.68521 .29876 m .68758 .29799 L .68771 .3007 L F
0 g
.68483 .29612 m
.68521 .29876 L
s
.68745 .29527 m
.68758 .29799 L
s
.80072 .30452 m
.80179 .30669 L
s
.80179 .30669 m
.80206 .3066 L
s
.80206 .3066 m
.80099 .30443 L
s
.68286 .29204 m .68596 .29339 L .68359 .29417 L .656 .751 .92 r
F
1 0 1 r
.68394 .29482 m
.6865 .29407 L
s
0 g
.68359 .29417 m
.68483 .29612 L
s
1 0 1 r
.6152 .31511 m
.68339 .29373 L
s
0 g
.68872 .30469 m
.68975 .30523 L
s
.68975 .30523 m
.69002 .30514 L
s
1 0 1 r
.6865 .29407 m
.86808 .24324 L
s
0 0 0 r
2 Mabswid
.6865 .29407 Mdot
0 g
.5 Mabswid
.69002 .30514 m
.68899 .3046 L
s
.44736 .4293 m
.46343 .46733 L
s
.46343 .46733 m
.4999 .45596 L
s
0 0 0 r
2 Mabswid
.68339 .29373 Mdot
0 g
.5 Mabswid
.79839 .29695 m
.79866 .29686 L
s
.79839 .29695 m
.79896 .29948 L
s
.79923 .29939 m
.79866 .29686 L
s
.79975 .30206 m
.80072 .30452 L
s
.80072 .30452 m
.80099 .30443 L
s
.68286 .29204 m .68447 .29151 L .68596 .29339 L .656 .751 .92 r
F
1 0 1 r
.68339 .29373 m
.68572 .29309 L
s
0 g
.68596 .29339 m
.68745 .29527 L
s
.80099 .30443 m
.80003 .30197 L
s
1 0 1 r
.68572 .29309 m
.8708 .24713 L
s
0 0 0 r
2 Mabswid
.68572 .29309 Mdot
0 g
.5 Mabswid
.79896 .29948 m
.79923 .29939 L
s
.79896 .29948 m
.79975 .30206 L
s
.79975 .30206 m
.80003 .30197 L
s
.80003 .30197 m
.79923 .29939 L
s
.68312 .2864 m
.68339 .28631 L
s
.68312 .2864 m
.68276 .2878 L
s
.68303 .28771 m
.68339 .28631 L
s
.6861 .30123 m .68784 .30343 L .68757 .30352 L .539 .317 .526 r
F
.6861 .30123 m .68771 .3007 L .68784 .30343 L F
0 g
.68521 .29876 m
.6861 .30123 L
s
.6861 .30123 m
.68757 .30352 L
s
.68758 .29799 m
.68771 .3007 L
s
.68757 .30352 m
.68872 .30469 L
s
.68872 .30469 m
.68899 .3046 L
s
.68784 .30343 m
.68899 .3046 L
s
.68771 .3007 m
.68784 .30343 L
s
.68271 .28971 m .68447 .29151 L .68286 .29204 L .656 .751 .92 r
F
0 g
.68286 .29204 m
.68359 .29417 L
s
.68271 .28971 m .68298 .28962 L .68447 .29151 L .656 .751 .92 r
F
0 g
.68298 .28962 m
.68447 .29151 L
s
.68447 .29151 m
.68596 .29339 L
s
.68271 .28971 m
.68286 .29204 L
s
.68276 .2878 m
.68303 .28771 L
s
.68271 .28971 m
.68276 .2878 L
s
.68298 .28962 m
.68303 .28771 L
s
.6864 .30178 m
.68757 .30352 L
s
.68757 .30352 m
.68784 .30343 L
s
.68667 .30169 m
.68784 .30343 L
s
.97468 .52133 m
.8259 .32023 L
s
.68271 .28971 m
.68298 .28962 L
s
.68271 .28971 m
.68296 .29201 L
s
.68298 .28962 m
.68323 .29193 L
s
.68529 .2996 m
.6864 .30178 L
s
.6864 .30178 m
.68667 .30169 L
s
.68667 .30169 m
.68556 .29952 L
s
.68296 .29201 m
.68323 .29193 L
s
.68296 .29201 m
.6835 .29455 L
s
.68377 .29446 m
.68323 .29193 L
s
.6843 .29714 m
.68529 .2996 L
s
.68529 .2996 m
.68556 .29952 L
s
.43512 .38884 m
.47152 .37704 L
s
.43512 .38884 m
.44736 .4293 L
s
.68556 .29952 m
.68457 .29705 L
s
.6835 .29455 m
.68377 .29446 L
s
.6835 .29455 m
.6843 .29714 L
s
.6843 .29714 m
.68457 .29705 L
s
.68457 .29705 m
.68377 .29446 L
s
.44736 .4293 m
.48385 .4177 L
s
.47152 .37704 m
.46389 .33714 L
s
.4999 .45596 m
.48385 .4177 L
s
.48385 .4177 m
.47152 .37704 L
s
0 0 0 r
2 Mabswid
.89087 .27589 Mdot
.8897 .27421 Mdot
.49157 .27328 Mdot
.49336 .27267 Mdot
.49432 .27235 Mdot
.49615 .27173 Mdot
.88749 .27104 Mdot
.88631 .26937 Mdot
0 g
.5 Mabswid
.8259 .32023 m
.80123 .02024 L
s
0 0 0 r
2 Mabswid
.5477 .25428 Mdot
.54908 .25382 Mdot
.54981 .25357 Mdot
.55121 .25309 Mdot
.8708 .24713 Mdot
.86808 .24324 Mdot
.8662 .24055 Mdot
.86215 .23475 Mdot
.86026 .23203 Mdot
.85751 .22809 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{725, 543.812},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;E00027b000`400?l00000o`00003oo`3ooooo
0?ooomL0oooo003o0?ooool0ooooe`3oool00?l0ooooo`3ooooG0?ooo`00o`3ooooo0?ooomL0oooo
003o0?ooool0ooooe`3oool00?l0ooooo`3ooooG0?ooo`00o`3ooooo0?ooomL0oooo003o0?ooool0
ooooe`3oool00?l0ooooo`3ooooG0?ooo`00o`3ooooo0?ooomL0oooo003o0?ooool0ooooe`3oool0
0?l0ooooo`3ooooG0?ooo`00o`3ooooo0?ooomL0oooo003o0?ooool0ooooe`3oool00?l0ooooo`3o
oom40?ooo`800000T@3oool00?l0ooooo`3ooom10?ooo`<0000000<0oooo0000003oool0T03oool0
0?l0ooooo`3oooln0?ooo`<00000103oool200000900oooo003o0?ooool0oooo>`3oool3000000L0
oooo00<000000?ooo`000000S`3oool00?l0ooooo`3ooolh0?ooo`<000002P3oool00`000000oooo
0000002?0?ooo`00o`3ooooo0?ooocH0oooo0P00000=0?ooo`040000003oool0oooo000008h0oooo
003o0?ooool0oooo<`3oool3000000l0oooo00D000000?ooo`3oool0oooo0000002=0?ooo`00o`3o
oooo0?oooc00oooo0`00000C0?ooo`040000003oool0oooo000008d0oooo003o0?ooool0oooo;@3o
ool3000001H0oooo00D000000?ooo`3oool0oooo0000002<0?ooo`00o`3ooooo0?ooob/0oooo0P00
000I0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0R@3oool00?l0ooooo`3ooolX
0?ooo`<000006`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo08T0oooo003o0?oo
ool0oooo9@3oool3000001h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`280?oo
o`00o`3ooooo0?ooob80oooo0`00000Q0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0Q`3oool00?l0ooooo`3ooolO0?ooo`<00000903oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo08L0oooo003o0?ooool0oooo7@3oool2000002L0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`260?ooo`00o`3ooooo0?oooaX0oooo0`00000Y0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0Q@3oool00?l0ooooo`3ooolG0?ooo`<00000;03oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo08D0oooo003o0?ooool0oooo503oool3000002l0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`240?ooo`00o`3ooooo0?oooa80oooo
0P00000b0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0P`3oool00?l0ooooo`3o
ool?0?ooo`<00000=@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo08<0oooo003o
0?ooool0oooo303oool3000003P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`22
0?ooo`00o`3ooooo0?ooo`T0oooo0`00000k0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0P@3oool00?l0ooooo`3oool60?ooo`<00000?P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo0840oooo003o0?ooool0oooo103oool200000440oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`200?ooo`00o`3ooooo0?ooo`40oooo0`0000130?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool0O`3oool00?l0ooooo@3oool3000004H0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`1o0?ooo`00o`3ooooj0?ooo`<00000B@3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo07h0oooo003o0?ooooP0oooo0P00001<0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0O@3oool00?l0oooom@3oool3000004h0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1m0?ooo`00o`3oooob0?ooo`<00000D@3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo07`0oooo003o0?ooonl0oooo0`00001D
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0N`3oool00?l0ooook03oool30000
05P0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1k0?ooo`00o`3ooooZ0?ooo`80
0000F`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo07X0oooo003o0?ooonL0oooo
0`00001M0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0N@3oool00?l0ooooi03o
ool300000600oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1i0?ooo`00o`3ooooQ
0?ooo`<00000H`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo07P0oooo003o0?oo
oml0oooo0P00001V0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0M`3oool00?l0
oooog03oool3000006P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1g0?ooo`00
o`3ooooI0?ooo`<00000J`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo07H0oooo
003o0?ooomH0oooo0`00001^0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0M@3o
ool00?l0ooood`3oool300000740oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1e
0?ooo`00o`3ooooA0?ooo`800000M03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
07@0oooo003o0?ooolh0oooo0`00001f0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool0M03oool00?l0oooob`3oool3000007X0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`1c0?ooo`00o`3oooo80?ooo`<00000O@3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo0780oooo003o0?ooolH0oooo0P0000200?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool0LP3oool00?l0oooo``3oool300000880oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`1a0?ooo`00o`3oooo00?ooo`<00000Q@3oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo0700oooo003o0?oookd0oooo0`0000280?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool0L03oool00?l0oooo^P3oool3000008/0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`1_0?ooo`00o`3ooonh0?ooo`800000SP3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo06h0oooo003o0?oookD0oooo0`00002@0?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool0KP3oool00?l0oooo/P3oool3000009<0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`1]0?ooo`00o`3ooon_0?ooo`<00000UP3oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo06`0oooo003o0?oooj`0oooo0`00002I0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool0K03oool00?l0ooooZP3oool2000009d0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`1[0?ooo`00o`3ooonW0?ooo`<00000W`3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo06X0oooo003o0?oooj@0oooo0`00002R0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0JP3oool00?l0ooooX@3oool300000:D0oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1Y0?ooo`00o`3ooonO0?ooo`800000Z03o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo06P0oooo003o0?oooi`0oooo0`00002Z
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0J03oool00?l0ooooV@3oool30000
0:d0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1W0?ooo`00o`3ooonF0?ooo`<0
0000/03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo06H0oooo003o0?oooi<0oooo
0`00002c0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0IP3oool00?l0ooooT@3o
ool200000;H0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`1U0?ooo`00o`3ooon>
0?ooo`<00000^03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06@0oooo003o0?oo
oh/0oooo0`00002k0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0I03oool00?l0
ooooR03oool300000;l0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1S0?ooo`00
o`3ooon60?ooo`800000`P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0680oooo
003o0?oooh<0oooo0`0000340?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0HP3o
ool00?l0ooooP03oool300000<L0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`1Q
0?ooo`00o`3ooomm0?ooo`<00000bP3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo
0600oooo003o0?ooogX0oooo0`00003=0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3o
ool0H03oool00?l0ooooN03oool200000=00oooo00<000000?ooo`3oool09`3oool00`000000oooo
0?ooo`1O0?ooo`00o`3ooome0?ooo`<00000dP3oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo05h0oooo003o0?ooog80oooo0`00003E0?ooo`030000003oool0oooo02P0oooo00<00000
0?ooo`3oool0GP3oool00?l0ooooK`3oool300000=P0oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`1M0?ooo`00o`3ooom]0?ooo`800000f`3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo05`0oooo003o0?ooofX0oooo0`00003M0?ooo`030000003oool0oooo02X0oooo
00<000000?ooo`3oool0G03oool00?l0ooooI`3oool300000>40oooo00<000000?ooo`3oool0:P3o
ool00`000000oooo0?ooo`1K0?ooo`00o`3ooomT0?ooo`<00000i03oool00`000000oooo0?ooo`0[
0?ooo`030000003oool0oooo05X0oooo003o0?ooof40oooo0`00003W0?ooo`030000003oool0oooo
02/0oooo00<000000?ooo`3oool0FP3oool00?l0ooooG`3oool200000>X0oooo00<000000?ooo`3o
ool0;03oool00`000000oooo0?ooo`1I0?ooo`00o`3ooomL0?ooo`<00000k03oool00`000000oooo
0?ooo`0]0?ooo`030000003oool0oooo05P0oooo003o0?oooeT0oooo0`00003_0?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool0F03oool00?l0ooooEP3oool300000?80oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`1G0?ooo`00o`3ooomD0?ooo`800000m@3oool00`00
0000oooo0?ooo`0_0?ooo`030000003oool0oooo05H0oooo003o0?oooe40oooo0`00003g0?ooo`03
0000003oool0oooo02l0oooo00<000000?ooo`3oool0EP3oool00?l0ooooCP3oool300000?X0oooo
00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`1E0?ooo`00o`3ooom;0?ooo`<00000o@3o
ool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo05@0oooo003o0?ooodP0oooo0`00003o
0?ooo`40oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`1D0?ooo`00o`3ooom60?oo
o`800000o`3oool50?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0D`3oool00?l0
oooo@`3oool300000?l0oooo1`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0580
oooo003o0?oood00oooo0`00003o0?ooo`X0oooo00<000000?ooo`3oool0<P3oool00`000000oooo
0?ooo`1B0?ooo`00o`3ooolm0?ooo`<00000o`3oool=0?ooo`030000003oool0oooo03<0oooo00<0
00000?ooo`3oool0D@3oool00?l0oooo>`3oool200000?l0oooo403oool00`000000oooo0?ooo`0d
0?ooo`030000003oool0oooo0500oooo003o0?ooocP0oooo0`00003o0?oooa80oooo00<000000?oo
o`3oool0=03oool00`000000oooo0?ooo`1@0?ooo`00o`3ooole0?ooo`<00000o`3ooolE0?ooo`03
0000003oool0oooo03D0oooo00<000000?ooo`3oool0C`3oool00?l0oooo<P3oool300000?l0oooo
603oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo04h0oooo003o0?ooobl0oooo0`00
003o0?oooa/0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`1>0?ooo`00o`3oool]
0?ooo`800000o`3ooolN0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0C@3oool0
0?l0oooo:P3oool300000?l0oooo803oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo
04`0oooo003o0?ooobL0oooo0`00003o0?ooob<0oooo00<000000?ooo`3oool0>03oool00`000000
oooo0?ooo`1<0?ooo`00o`3ooolT0?ooo`<00000o`3ooolW0?ooo`030000003oool0oooo03P0oooo
00<000000?ooo`3oool0B`3oool00?l0oooo8P3oool200000?l0oooo:P3oool00`000000oooo0?oo
o`0i0?ooo`030000003oool0oooo04X0oooo003o0?oooal0oooo0`00003o0?ooob`0oooo00<00000
0?ooo`3oool0>@3oool00`000000oooo0?ooo`1:0?ooo`00o`3ooolL0?ooo`<00000o`3oool_0?oo
o`030000003oool0oooo03X0oooo00<000000?ooo`3oool0B@3oool00?l0oooo6@3oool300000?l0
oooo<P3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo04P0oooo003o0?oooaH0oooo
0`00003o0?ooocD0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`180?ooo`00o`3o
oolD0?ooo`800000o`3ooolh0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0A`3o
ool00?l0oooo4@3oool300000?l0oooo>P3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0
oooo04H0oooo003o0?ooo`h0oooo0`00003o0?ooocd0oooo00<000000?ooo`3oool0?@3oool00`00
0000oooo0?ooo`160?ooo`00o`3oool;0?ooo`<00000o`3ooom00?ooo`030000003oool0oooo03h0
oooo00<000000?ooo`3oool0A@3oool00?l0oooo2@3oool200000?l0oooo@`3oool00`000000oooo
0?ooo`0o0?ooo`030000003oool0oooo04@0oooo003o0?ooo`H0oooo0`00003o0?ooodD0oooo00<0
00000?ooo`3oool0?`3oool00`000000oooo0?ooo`140?ooo`00o`3oool30?ooo`<00000o`3ooom8
0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0@`3oool00?l0oooo0`00003o0?oo
od`0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`120?ooo`00o03oool300000?l0
ooooC`3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0480oooo003j0?ooo`800000
o`3ooomB0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0@@3oool00?L0oooo0`00
003o0?oooe@0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`110?ooo`00m03oool3
00000?l0ooooE`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0400oooo003a0?oo
o`<00000o`3ooomJ0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0?`3oool00>l0
oooo0P00003o0?oooed0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0o0?ooo`00
k03oool300000?l0ooooG`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo03h0oooo
003Y0?ooo`<00000o`3ooomR0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0?@3o
ool00>H0oooo0`00003o0?ooofD0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0m
0?ooo`00h`3oool300000?l0ooooJ03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
03`0oooo003Q0?ooo`800000o`3ooom[0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3o
ool0>`3oool00=h0oooo0`00003o0?ooofh0oooo00<000000?ooo`3oool0AP3oool00`000000oooo
0?ooo`0k0?ooo`00f`3oool300000?l0ooooL@3oool00`000000oooo0?ooo`170?ooo`030000003o
ool0oooo03X0oooo003H0?ooo`<00000o`3ooomd0?ooo`030000003oool0oooo04P0oooo00<00000
0?ooo`3oool0>@3oool00=H0oooo0P00003o0?ooogL0oooo00<000000?ooo`3oool0B03oool00`00
0000oooo0?ooo`0i0?ooo`00d`3oool300000?l0ooooN@3oool00`000000oooo0?ooo`190?ooo`03
0000003oool0oooo03P0oooo003@0?ooo`<00000o`3oooml0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0=`3oool00<d0oooo0`00003o0?ooogl0oooo00<000000?ooo`3oool0BP3o
ool00`000000oooo0?ooo`0g0?ooo`00bP3oool300000?l0ooooPP3oool00`000000oooo0?ooo`1;
0?ooo`030000003oool0oooo03H0oooo00380?ooo`800000o`3ooon50?ooo`030000003oool0oooo
04`0oooo00<000000?ooo`3oool0=@3oool00<D0oooo0`00003o0?ooohL0oooo00<000000?ooo`3o
ool0C03oool00`000000oooo0?ooo`0e0?ooo`00`P3oool300000?l0ooooRP3oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo03@0oooo002o0?ooo`<00000o`3ooon=0?ooo`030000003o
ool0oooo04h0oooo00<000000?ooo`3oool0<`3oool00;d0oooo0P00003o0?oooi40oooo00<00000
0?ooo`3oool0C@3oool00`000000oooo0?ooo`0c0?ooo`00^P3oool300000?l0ooooT`3oool00`00
0000oooo0?ooo`1>0?ooo`030000003oool0oooo0380oooo002g0?ooo`<00000o`3ooonF0?ooo`03
0000003oool0oooo04l0oooo00<000000?ooo`3oool0<@3oool00;@0oooo0`00003o0?oooiT0oooo
00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0a0?ooo`00/@3oool300000?l0ooooW03o
ool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0300oooo002_0?ooo`800000o`3ooonO
0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0;`3oool00:`0oooo0`00003o0?oo
oj40oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0_0?ooo`00Z@3oool300000?l0
ooooY03oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo02h0oooo002V0?ooo`<00000
o`3ooonW0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0;@3oool00:@0oooo0P00
003o0?ooojX0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0]0?ooo`00X@3oool3
00000?l0oooo[03oool00`000000oooo0?ooo`0J0?ooo`800000>03oool00`000000oooo0?ooo`0/
0?ooo`00WP3oool300000?l0oooo[`3oool00`000000oooo0?ooo`0I0?ooo`030?l0o`0000000000
03T0oooo00<000000?ooo`3oool0:`3oool009/0oooo0`00003o0?oook<0oooo00<000000?ooo`3o
ool05@3oool30?l0oc`0oooo00<000000?ooo`3oool0:`3oool009P0oooo0`00003o0?oookH0oooo
00<000000?ooo`3oool04`3oool20?l0o`H0oooo0P00000h0?ooo`030000003oool0oooo02X0oooo
002F0?ooo`800000o`3oooni0?ooo`030000003oool0oooo0100oooo0`3o0?l70?ooo`030?l0o`00
0000000003L0oooo0`00000[0?ooo`00T`3oool300000?l0oooo^`3oool00`000000oooo0?ooo`0>
0?ooo`80o`3o1`3oool30?l0o`80oooo0P00000c0?ooo`<000000P3oool00`000000oooo0?ooo`0Y
0?ooo`00T03oool300000?l0oooo_P3oool00`000000oooo0?ooo`0<0?ooo`80o`3o1P3oool30?l0
o`D0oooo0P00000`0?ooo`<000001@3oool00`000000oooo0?ooo`0Y0?ooo`00S@3oool300000?l0
oooo`@3oool00`000000oooo0?ooo`090?ooo`<0o`3o1P3oool20?l0o`D0oooo0`3o0?l_0?ooo`<0
0000203oool00`000000oooo0?ooo`0Y0?ooo`00R`3oool200000=L0oooo1`00003U0?ooo`030000
003oool0oooo00L0oooo0P3o0?l60?ooo`<0o`3o103oool30?l0obl0oooo0`00000;0?ooo`030000
003oool0oooo02T0oooo00280?ooo`<00000d@3oool;000000@0oooo0P00003S0?ooo`030000003o
ool0oooo00@0oooo0`3o0?l50?ooo`<0o`3o103oool30?l0o`T0oooo0P00000T0?ooo`<000003`3o
ool00`000000oooo0?ooo`0X0?ooo`00Q@3oool300000=40oooo100000040?ooo`<000002@3oool2
00000>40oooo00<000000?ooo`3oool00P3oool20?l0o`D0oooo0`3o0?l40?ooo`<0o`3o2P3oool2
0?l0o`8000008@3oool300000180oooo00<000000?ooo`3oool0:03oool00880oooo0`00003A0?oo
o`<000000P3oool00`000000oooo0?ooo`03000000h0oooo0`00003N0?ooo`030000003oool0o`3o
0080o`3o1@3oool20?l0o`@0oooo0`3o0?l:0?ooo`<0o`3o0`3oool2000001d0oooo0`00000E0?oo
o`030000003oool0oooo02P0oooo001o0?ooo`<00000d@3oool3000000@0oooo1000000D0?ooo`80
0000g03oool00`000000o`3o0?ooo`040?ooo`<0o`3o0`3oool30?l0o`X0oooo0`3o0?l50?ooo`03
0?l0o`000000000001X0oooo0`00000H0?ooo`030000003oool0oooo02P0oooo001m0?ooo`800000
d@3oool3000000D0oooo0`00000I0?ooo`800000e`3oool30?l0o`040000003oool0oooo0?ooo`<0
o`3o0`3oool30?l0o`T0oooo103o0?l40?ooo`@0o`3o6@3oool4000001/0oooo00<000000?ooo`3o
ool0:03oool007X0oooo0`00003@0?ooo`<000001@3oool4000001`0oooo0P00003D0?ooo`80o`3o
103oool00`000000o`3o0?l0o`030?ooo`<0o`3o2@3oool30?l0o`D0oooo0`3o0?l60?ooo`030?l0
o`00000000000140oooo0`00000O0?ooo`030000003oool0oooo02P0oooo001g0?ooo`<00000d03o
ool3000000D0oooo0`0000020?ooo`030000003oool0oooo01P0oooo0`0000020?ooo`030000003o
ool0oooo0<l0oooo0P3o0?l40?ooo`80o`3o00@000000?ooo`3oool0oooo0P3o0?l90?ooo`<0o`3o
103oool40?l0o`D0oooo103o0?l00`3oool000000000000>0?ooo`<000008P3oool00`000000oooo
0?ooo`0X0?ooo`00M03oool300000=00oooo0`0000000`3oool0000000000005000000@0oooo00<0
00000?ooo`3oool05P3oool3000000H0oooo00<000000?ooo`3oool0b`3oool30?l0o`<0oooo0`3o
0?l20?ooo`040000003o0?l0o`3o0?l0o`L0oooo103o0?l30?ooo`@0o`3o1@3oool40?l0oa80oooo
0`00000U0?ooo`030000003oool0oooo02P0oooo001b0?ooo`800000d@3oool6000000D0lj9T0P3d
XEh4000001H0oooo0`00000:0?ooo`030000003oool0oooo0<P0oooo0P3o0?l40?ooo`80o`3o0`3o
ool20?l0o`030000003oool0oooo00D0oooo0`3o0?l40?ooo`<0o`3o1@3oool40?l0oa<0oooo0`00
000X0?ooo`030000003oool0oooo02P0oooo001_0?ooo`<00000dP3oool00`000000lj9T0?>RI00:
0?>RI0D000004`3oool3000000h0oooo00<000000?ooo`3oool04@3oool200000;40oooo0`3o0?l3
0?ooo`<0o`3o0P3oool30?l0o`80oooo00<000000?ooo`3oool00P3oool30?l0o`<0oooo103o0?l4
0?ooo`@0o`3o503oool3000002`0oooo00<000000?ooo`3oool09`3oool006`0oooo0`00003D0?oo
o`030000003bXf/0lZ=[00P0lj9T0`0000030?BQGP040000003dXEh00000000000l0oooo0P00000B
0?ooo`030000003oool0oooo00h0oooo100000000`3o0000oooo0?ooo`2/0?ooo`80o`3o0`3oool3
0?l0o`80oooo0`3o0?l50?ooo`030000003oool0o`3o0080o`3o0P3oool40?l0o`@0oooo103o0?lE
0?ooo`<00000;`3oool00`000000oooo0?ooo`0W0?ooo`00J@3oool300000=H0oooo00@000000?:S
J`3bXf/0lZ=[1@3cXV@3000000<0lj9T0`3dXEh01@000000m:5N0?BQGP3dXEh0000000/0oooo0`00
000E0?ooo`030000003oool0oooo00d0oooo0`0000050?l00:P0oooo0`3o0?l30?ooo`80o`3o0P3o
ool30?l0o`H0oooo0P3o0?l010000000o`3o0?ooo`3oool30?l0o`@0oooo103o0?lF0?ooo`<00000
<P3oool00`000000oooo0?ooo`0W0?ooo`00IP3oool300000=P0oooo00<000000?:SJ`3bXf/00`3b
Xf/0103cXV@000000000000000070?>RI080m:5N00<000000?BQGP3dXEh00P3dXEh2000000H0oooo
0`00000I0?ooo`030000003oool0oooo00h0oooo0`3o00000`3oool0o`000?l000030?l00:<0oooo
0P3o0?l30?ooo`<0o`3o00@0oooo0?l0o`3o0?l0o`3o1P3oool30?l0o`80oooo00@000000?l0o`3o
0?l0o`3o0`3oool40?l0oaH0oooo1000000e0?ooo`030000003oool0oooo02L0oooo001T0?ooo`80
0000fP3oool00`000000lZ=[0?:SJ`030?:SJ`8000002P3cXV@00`3dXEh000000?BQGP060?BQGP80
000000@0oooo00000000000000007@3oool00`000000oooo0?ooo`0@0?ooo`80o`0000<0oooo0?l0
003o00000`3o002O0?ooo`80o`3o0P3oool30?l0o`040?ooo`3o0?l0o`3o0?l0o`H0oooo0`3o0?l0
0`3oool0o`3o0?l0o`020?l0o`030000003oool0oooo00@0o`3o5`3oool3000003T0oooo00<00000
0?ooo`3oool09`3oool00640oooo0`00003K0?ooo`040000003bXf/0lZ=[0?:SJ`<000000P3bXf/:
0?>RI0030?BQGP000000m:5N00P0m:5N0P00000P0?ooo`030000003oool0oooo0140oooo0`3o0000
0`3oool0o`000?l000030?l009T0oooo0`3o0?l01@3oool0o`3o0?l0o`3o0?l0oooo00<0o`3o1@3o
ool40?l0o`040?ooo`3o0?l0o`3o0?l0o`@0oooo00<000000?l0o`3o0?l0603oool3000003`0oooo
00<000000?ooo`3oool09`3oool005h0oooo0`00003M0?ooo`030000003bXf/00000008000001@3b
Xf/;0?>RI0030000003dXEh0m:5N00L0m:5N0P3eXUT00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo01<0oooo0P3o00000`3oool0o`000?l000040?l009@0oooo0P3o0?l20?ooo`80o`3o0P3o
ool20?l0o`D0oooo0`3o0?l00`3oool0o`3o0?l0o`020?l0o`<0oooo103o0?l00`000000oooo0?oo
o`0E0?ooo`<00000?`3oool00`000000oooo0?ooo`0W0?ooo`00F`3oool300000=l0oooo0`000009
0?:SJ`T0lj9T00<000000?BQGP3dXEh0203dXEh30?FRF@030000003oool0oooo01h0oooo00<00000
0?ooo`3oool0503oool30?l000030?ooo`3o0000o`0000@0o`00SP3oool30?l0o`050?ooo`3o0?l0
o`3o0?l0o`3oool00`3o0?l40?ooo`L0o`3o0`3oool40?l0o`@0oooo00<000000?ooo`3oool04P3o
ool300000480oooo00<000000?ooo`3oool09`3oool005T0oooo0P00003Q0?ooo`030000003bXf/0
lZ=[00X0lZ=[2@3cXV@00`000000lj9T0?BQGP090?BQGP<0mJ9I00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`0F0?ooo`80o`0000<0oooo0?l0003o0000103o002:0?ooo`80o`3o00D0oooo
0?l0o`3o0?l0o`3o0?ooo`030?l0o`<0oooo1`3o0?l30?ooo`@0o`3o2@3oool00`000000oooo0?oo
o`0>0?ooo`<00000A@3oool00`000000oooo0?ooo`0W0?ooo`00EP3oool300000><0oooo00<00000
0?:SJ`3bXf/02P3bXf/90?>RI0030000003cXV@0m:5N00T0m:5N103eXUT00`000000oooo0?ooo`0L
0?ooo`<000006@3oool:0?l008@0oooo0`3o0?l0103oool0o`3o0?l0o`3oool30?l0o`<0oooo1`3o
0?l20?ooo`@0o`3o3@3oool00`000000oooo0?ooo`0;0?ooo`<00000B@3oool00`000000oooo0?oo
o`0V0?ooo`00D`3oool300000>D0oooo00<000000?6UL@3bXf/0303bXf/70?>RI0030000003cXV@0
lj9T00X0m:5N1@3eXUT00`000000oooo0?ooo`0H0?ooo`<000000P2;DXP00`000000oooo0?ooo`0J
0?ooo`X0o`00O`3oool20?l0o`030?ooo`3o0?l0o`3o00@0o`3o0`3oool60?l0o`80oooo103o0?lA
0?ooo`030000003oool0oooo00P0oooo0`00001<0?ooo`030000003oool0oooo02H0oooo001@0?oo
o`<00000j03oool00`000000lJEa0?6UL@0<0?:SJ`L0lj9T00@000000?>RI03cXV@0lj9T2@3dXEh6
0?FRF@030000003oool0oooo01@0oooo0`00000508]BR08000007P3oool90?l007X0oooo2@3o0?l2
0?ooo`H0o`3o0P3oool40?l0oaD0oooo00<000000?ooo`3oool01@3oool3000004l0oooo00<00000
0?ooo`3oool09P3oool004d0oooo0`00003[0?ooo`030000003aYG40lJEa00d0lZ=[1P3cXV@01000
0000lj9T0?>RI03cXV@:0?BQGPH0mJ9I00<000000?ooo`3oool0403oool3000000P0Re:800<00000
0?ooo`0000007`3oool:0?l007D0oooo0P3o0?l00`3oool0o`3o0?l0o`030?l0o`80oooo1P3o0?l0
0`3oool0o`3o0?l0o`020?l0oaT0oooo00@000000?ooo`3oool0oooo1000000V0?ooo`800000:P3o
ool00`000000oooo0?ooo`0V0?ooo`00B`3oool200000>d0oooo00<000000?6UL@3aYG400P3aYG4<
0?:SJ`D0lj9T00<000000?>RI03cXV@00P3cXV@:0?BQGPL0mJ9I00<000000?ooo`3oool0303oool3
000000/0Re:800@000000?ooo`3oool000008@3oool:0?l00700oooo1`3o0?l20?ooo`D0o`3o00<0
oooo0?l0o`3o0?l00P3o0?lM0?ooo`@00000:P3oool3000002T0oooo00<000000?ooo`3oool09P3o
ool004P0oooo0`00003_0?ooo`030000003aYG40lJEa0080lJEa3@3bXf/30?>RI08000001@3cXV@9
0?BQGPD0mJ9I100000000`000?l0oooo0?ooo`070?ooo`<000003P2;DXP010000000oooo0?ooo`00
000S0?ooo`X0o`00J`3oool70?l0o`80oooo103o0?l00`3oool0o`3o0?l0o`020?l0oal0oooo0`00
000Z0?ooo`<00?l000<0oooo000000000000:@3oool00`000000oooo0?ooo`0V0?ooo`00A@3oool3
00000?40oooo00<000000?6UL@3aYG40103aYG4<0?:SJ`<0000000<0lj9T0000003cXV@0103cXV@9
0?BQGP@0mJ9I1P0000030000o`<0oooo0`00000A08]BR0050000003oool0oooo0?ooo`0000009@3o
ool:0?l006H0oooo403o0?lP0?ooo`<000000P3oool00`000000oooo0?ooo`0U0?ooo`<00?l000@0
oooo003o0000o`000?l0:`3oool00`000000oooo0?ooo`0V0?ooo`00@P3oool300000?@0oooo00<0
00000?6UL@3aYG401@3aYG480?:SJ`<0000000D0lZ=[0?>RI03cXV@0lj9T000000060?>RI0T0m:5N
0`3eXUT2000000D0003o0P3oool30000oa@0Re:800<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0T0?ooo`D0o`0000<0oooo0?l0003o00000`3o001P0?ooo`l0o`3o8@3oool3000000D0oooo
00<000000?ooo`3oool08`3oool2003o00040?ooo`00o`000?l0003o00<0oooo0P00o`02000002L0
oooo00<000000?ooo`3oool09P3oool00400oooo0P00003g0?ooo`030000003aYG40lJEa00D0lJEa
1@3bXf/3000000@0lZ=[0`3cXV@00`000000lj9T0?>RI0040?>RI0T0m:5N203eXUT50000o`80Re:8
0P000?lB08]BR0030000003oool0oooo0080oooo00<000000?ooo`3oool09`3oool;0?l005/0oooo
3@3o0?lR0?ooo`<00000203oool00`000000oooo0?ooo`0P0?ooo`H00?l00`3oool3003o00030?oo
o`00o`000000008000009`3oool00`000000oooo0?ooo`0U0?ooo`00?@3oool300000?P0oooo00<0
00000?6UL@3aYG401`3aYG40103bXf/000000000000000080?:SJ`80lj9T00<000000?>RI03cXV@0
103cXV@90?BQGPX0mJ9I1P000?l0102;DXP0003o0000o`000?l?08]BR0030000003oool0oooo00<0
oooo00<000000?ooo`3oool0:03oool50?l000040?ooo`3o0000o`000?ooo`80o`00EP3oool<0?l0
ob<0oooo0`00000;0?ooo`030000003oool0oooo01h0oooo1@00o`020?ooo`P00?l00P3oool20000
02L0oooo00<000000?ooo`3oool09@3oool003X0oooo0`00003k0?ooo`030000003aYG40lJEa00D0
lJEa0`00000;0?:SJ`80lj9T00<000000?>RI03cXV@01@3cXV@80?BQGPX0mJ9I00<0000008]BR02;
DXP01@000?l208]BR0<0003o302;DXP00`000000oooo0?ooo`040?ooo`030000003oool0oooo02X0
oooo103o00000`3oool0o`000?l000040?l00540oooo2P3o0?lT0?ooo`<000003P3oool00`000000
oooo0?ooo`0K0?ooo`D00?l00P3oool7003o02l0oooo00<000000?ooo`3oool09@3oool003L0oooo
0`00003m0?ooo`030000003aYG40lJEa00<0lJEa0`0000030?6UL@`0lZ=[00<000000?>RI03cXV@0
1P3cXV@90?BQGPT0mJ9I00<0000008]BR02;DXP00P2;DXP60000o`80Re:80P000?l:08]BR0030000
003oool0oooo00D0oooo00<000000?ooo`3oool0:`3oool50?l000040?ooo`3o0000o`000?ooo`<0
o`00B`3oool90?l0ob@0oooo1000000B0?ooo`030000003oool0oooo01L0oooo1@00o`000`3oool0
0?l0003o0005003o03<0oooo00<000000?ooo`3oool09@3oool003@0oooo0`00003o0?ooo`40oooo
00<000000?6UL@3aYG400`0000070?6UL@/0lZ=[00<000000?>RI03cXV@01P3cXV@90?BQGPX0mJ9I
00<0000008]BR02;DXP0102;DXP60000o`0408]BR0000?l0003o0000o`L0Re:800<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0^0?ooo`@0o`0000D0oooo0?l0003o0000o`000?ooo`020?l0
04L0oooo1`3o0?lU0?ooo`<000005P3oool00`000000oooo0?ooo`0E0?ooo`@00?l000<0oooo003o
0000o`001000o`0g0?ooo`030000003oool0oooo02D0oooo000b0?ooo`800000o`3oool40?ooo`<0
00002P3aYG4;0?:SJ`030000003cXV@0lj9T00L0lj9T203dXEh:0?FRF@030000002;DXP0Re:800H0
Re:81`000?l0102;DXP0003o0000o`000?l408]BR0030000003oool0oooo00H0oooo00<000000?oo
o`3oool0;`3oool50?l000030?ooo`3o0000o`0000@0o`00@@3oool60?l0obH0oooo0`00000I0?oo
o`030000003oool0oooo0180oooo2P00o`0k0?ooo`030000003oool0oooo02D0oooo000_0?ooo`<0
0000o`3oool50?ooo`030000003aYG40lJEa00`0lJEa2P3bXf/00`000000lj9T0?>RI0070?>RI0P0
m:5N2P3eXUT00`000000Re:808]BR00908]BR0H0003o0P2;DXP30000o`0308]BR0000000oooo00P0
oooo00<000000?ooo`3oool0<@3oool40?l00080oooo0P3o0000103oool0o`000?l0003o000k0?oo
o`H0o`3o9P3oool3000001`0oooo00<000000?ooo`3oool0403oool8003o03l0oooo00<000000?oo
o`3oool09@3oool002`0oooo0`00003o0?ooo`P0oooo00<000000?6UL@3aYG403@3aYG490?:SJ`03
0000003cXV@0lj9T00P0lj9T1`3dXEh:0?FRF@030000002;DXP0Re:800/0Re:80P000?l00`2;DXP0
003o0000o`020000o`80Re:80P000?l90?ooo`030000003oool0oooo03<0oooo1@3o00001@3oool0
o`000?l0003o0000oooo0080o`007`3oool2000001@0oooo1P3o0?lW0?ooo`<000007`3oool00`00
0000oooo0?ooo`0=0?ooo`L00?l0@`3oool00`000000oooo0?ooo`0U0?ooo`00:@3oool300000?l0
oooo2`3oool00`000000lJEa0?6UL@0=0?6UL@T0lZ=[00<000000?:SJ`3cXV@0203cXV@80?BQGPT0
mJ9I00<0000008]BR02;DXP03@2;DXP80000o`04000000000?l0003o0000o`L0oooo00<000000?oo
o`3oool0=@3oool40?l00080oooo0P3o0000103oool0o`000?l0003o000L0?ooo`040000003oool0
0000000000h0oooo1`3o0?lW0?ooo`<000008P3oool00`000000oooo0?ooo`0:0?ooo`H00?l0A`3o
ool00`000000oooo0?ooo`0U0?ooo`00:03oool200000?l0oooo3@3oool00`000000l:Mg0?6UL@0>
0?6UL@P0lZ=[00<000000?:SJ`3cXV@0203cXV@80?BQGPT0mJ9I00<0000008]BR02;DXP0402;DXP2
0000o`0308]BR0000?l0003o00<0003o00@0oooo0000o`000?l0003o1@3oool00`000000oooo0?oo
o`0f0?ooo`D0o`0000D0oooo0?l0003o0000o`000?ooo`030?l001T0oooo00@000000?ooo`3oool0
00002`3oool70?l0obL0oooo0`00000U0?ooo`030000003oool0oooo00L0oooo1@00o`1<0?ooo`03
0000003oool0oooo02@0oooo000X0?ooo`030000003oool000000?l0oooo303oool00`000000l:Mg
0?2WM`0>0?6UL@P0lZ=[00<000000?:SJ`3bXf/02@3cXV@70?BQGPT0mJ9I00<0000008]BR02;DXP0
4P2;DXP80000o`80oooo0P000?l30?ooo`800000>P3oool40?l00080oooo0`3o00000`3oool0o`00
0?l0000G0?ooo`030000003oool00000008000001P3oool90?l0obH0oooo0`00000X0?ooo`030000
003oool0oooo00<0oooo1@00o`1@0?ooo`030000003oool0oooo02@0oooo000X0?ooo`040000003o
ool0oooo00000?l0oooo2`3oool010000000l:Mg0?2WM`3`YgL>0?6UL@L0lZ=[00<000000?:SJ`3b
Xf/02@3cXV@70?BQGPX0mJ9I00<0000008]BR02;DXP00`2;DXP00`000000Re:808]BR00>08]BR080
003o00<0oooo0000o`000?l00`000?l01P3oool0003o0000o`000?l0oooo000003d0oooo103o0002
0?ooo`80o`0000@0oooo0?l0003o0000o`00503oool00`000000oooo0000000200000080oooo2P3o
0?lV0?ooo`<000006@3oool3000000l0oooo00<000000?ooo`00o`001@00o`1C0?ooo`030000003o
ool0oooo02@0oooo000X0?ooo`050000003oool0oooo0?ooo`000000o`3oool90?ooo`030000003`
YgL0l:Mg0080l:Mg3`3aYG460?:SJ`040000003bXf/0lZ=[0?:SJ`P0lj9T203dXEh90?FRF@030000
002;DXP0Re:801@0Re:800<000000?ooo`000?l00P000?l00`3oool0003o0000o`030000o`040?oo
o`000?l0003o0000och0oooo103o00020?ooo`<0o`0000@0oooo0?l0003o0000o`004@3oool40000
00/0o`3o903oool4000001`0oooo00@000000?ooo`3oool00000303oool2003o000300000000o`00
0?l000<00?l0E@3oool00`000000oooo0?ooo`0T0?ooo`00:03oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0?l0oooo1P3oool00`000000l:Mg0?2WM`030?2WM`h0lJEa1P3bXf/01000
0000lZ=[0?:SJ`3bXf/90?>RI0L0m:5N2@3eXUT00`000000Re:808]BR00D08]BR0030000003oool0
oooo008000000P000?l00`3oool0003o0000o`040000o`03000000000?l0003o03l0oooo0`3o0003
0?ooo`80o`000P3oool30?l000`0oooo0P3o0?l3000000030?l0o`3oool0o`3o00L0o`3o8`3oool3
00000200oooo00<000000?ooo`3oool00P0000070?ooo`H00?l000<00000003o0000o`00F03oool0
0`000000oooo0?ooo`0T0?ooo`009`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0?l0oooo1@3oool00`000000l:Mg0?2WM`040?2WM`h0lJEa103bXf/00`000000lZ=[0?:SJ`030?:S
J`@0lj9T103eYfT20?JWIPD0m:5N2@3eXUT00`000000Re:808]BR00D08]BR0<00000103oool30000
o`040?ooo`000?l0003o0?ooo`80003o00@0oooo0000o`000?l0003o?P3oool40?l00080oooo0`3o
00020?ooo`80o`001`3oool30?l0o`030?ooo`3o0?l0000000<000001P3o0?lS0?ooo`<000008`3o
ool00`000000oooo00000002000000<0oooo2P00o`000`000000oooo0?ooo`1H0?ooo`030000003o
ool0oooo02@0oooo000W0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3oool4
0?ooo`030000003`YgL0l:Mg00D0l:Mg3P3aYG430?:SJ`030000003bXf/0lZ=[00<0lZ=[203eYfT4
0?JWIP<0m:5N2@3eXUT00`000000Re:808]BR00D08]BR0030000003oool0oooo00L0oooo0P000?l0
0`3oool0003o0000o`040000o`040?ooo`000?l0003o0000och0oooo0`3o00030?ooo`<0o`0000D0
oooo0?l0003o0000o`000?ooo`030?l0o`030?ooo`3o0?l0o`3o0080o`3o0P0000000`29DHH00000
000000030?l0ob80oooo0`00000V0?ooo`@000003000o`030?ooo`030000003oool0oooo05L0oooo
00<000000?ooo`3oool0903oool002L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`3o0?ooo`<0oooo00<000000?2WM`3`YgL01P3`YgL=0?6UL@<0lZ=[00<000000?:SJ`3bXf/00P3b
Xf/20?BXKPP0mJMY1@3fYfH20?BQGPP0mJ9I00<0000008]BR02;DXP0502;DXP00`000000oooo0?oo
o`090?ooo`<0003o00@0oooo0000o`000?l0oooo0`000?l00`3oool0003o0000o`0n0?ooo`@0o`00
0`3oool20?l000<0o`3o00<0o`000?l0o`3o0?l01P3o0?l00`000000RE660000000300000200oooo
0`00000Y0?ooo`D000002000o`060?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0
903oool002L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?ooo`80oooo00<0
00000?2WM`3`YgL01P3`YgL>0?6UL@80lZ=[00@000000?:SJ`3bXf/0lZ=[0`3dZ6h80?FWJ@L0mZMV
2@3eXUT00`000000Re:808]BR00C08]BR0030000003oool0oooo00`0oooo0P000?l01@3oool0003o
0000o`000?l0oooo00H0003o?P3oool30?l000<0o`3o00<0o`000?l0o`3o0?l02@3o0?l6000001d0
oooo0`00000[0?ooo`03003o000000000000008000001`00o`080?ooo`030000003oool0oooo05L0
oooo00<000000?ooo`3oool0903oool002L0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`3o0?ooo`40oooo00<000000?2WM`3`YgL01`3`YgL=0?6UL@80lZ=[00<000000?:SJ`3bXf/0
1@3dZ6h70?FWJ@L0mZMV0P3fYf<70?FRF@030000002;DXP0Re:801<0Re:800<000000?ooo`3oool0
3P3oool30000o`030?ooo`000?l0003o0080oooo0P000?l0103oool0003o0000o`000?lk0?ooo`<0
o`3o00<0o`000?l0o`3o0?l02P3o0?l20?ooo`<000000P3oool00`000000oooo0?ooo`0H0?ooo`<0
0000:`3oool5003o00@000000`00o`0;0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool08`3oool002L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?ooo`030000
003`YgL0l:Mg00P0l:Mg303aYG43000000030?:SJ`3dZ6h0m:Q^00@0m:Q^203eYfT60?JWIP<0mZMS
1P3eXUT00`000000Re:808]BR00C08]BR0030000003oool0oooo00h0oooo00<000000?ooo`3oool0
0P000?l01@3oool0003o0000o`000?l0oooo00<0003o00<0oooo0000o`000?l0=P3oool30?l0o`03
0?ooo`3o0?l0o`3o00X0o`3o00<0o`000?ooo`3oool00`3o000200000080oooo00<000000?ooo`3o
ool05@3oool3000002X0oooo1`00o`000`3oool00?l000000005000000`0oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`0S0?ooo`009`3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo0?h0oooo00<000000?2WM`3`YgL02@3`YgL80?6UL@<000000P2W`>/00`000000m:Q^
0?BXKP050?BXKPP0mJMY1`3fYfH30?JWH`D0mJ9I00<0000008]BR02;DXP04`2;DXP00`000000oooo
0?ooo`0?0?ooo`040000003oool0oooo0?ooo`<0003o00D0oooo0000o`000?l0003o0?ooo`060000
oaH0oooo00<000000?ooo`3oool05`3oool30?l0o`030?ooo`3o0?l0o`3o00X0o`3o00@0o`000?oo
o`3oool0oooo0`3o00020?ooo`050?l000000000oooo0?ooo`000000503oool3000002X0oooo0`00
o`001@3oool00?l0003o0000o`00oooo00<00?l000@0oooo000000000000Re:80`00000<0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool08`3oool002L0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`3m0?ooo`030000003`YgL0l:Mg00X0l:Mg103aYG43000000D0Yl3[
0P0000070?BXKPL0mJMY1`3fYfH40?JWH`@0mJ9I00<0000008]BR02;DXP04`2;DXP00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00@0oooo0P000?l20?ooo`80003o0P3oool60000oa80oooo
0P00000F0?ooo`<0o`3o00<0oooo0?l0o`3o0?l02P3o0?l30?ooo`<0o`00103oool30?l000040?oo
o`000000000000000100oooo1000000Z0?ooo`<00?l000D0oooo003o0000o`000?l00?ooo`03003o
0080oooo0`00o`000`000000Re:800000002000000`0oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`0S0?ooo`009`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?`0
oooo00<000000?2WM`3`YgL02P3`YgL0103aYG4000000000000000080:O0j`030000002W`>/00000
00H0m:Q^203eYfT60?JWIPD0mZMS0`3eXUT00`000000Re:808]BR00C08]BR0030000003oool0oooo
0100oooo00<000000?ooo`3oool01@3oool30000o`040?ooo`000?l0003o0000o`80oooo0P000?l0
103oool0003o0000o`000?l?0?ooo`8000004`3oool@0?l0o`P0oooo103o00040?ooo`80o`0000<0
00000?ooo`3o00000P3o000:0?ooo`<00000:P3oool4003o00050?ooo`00o`000?l0003o003oool0
0`00o`020?ooo`<00?l00`3oool01@000000Re:80000003oool0000000`0oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`0S0?ooo`009P3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo0?X0oooo00<000000?2WM`3`YgL0203`YgL4000000/0Yl3[00@000000:O0j`2W`>/0
00001P3dZ6h70?FWJ@H0mZMV1P3fYf<20?FRF@030000002;DXP0Re:801<0Re:800<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`070?ooo`80003o0P3oool20000o`80oooo0`000?l00`3oool0
003o0000o`0=0?ooo`800000403oool@0?l0o`d0oooo1@3o00030?ooo`<0o`000P3oool20?l000D0
oooo0`00000Z0?ooo`<00?l000<0oooo003o0000o`000P00o`00103oool00?l0003o0000o`020?oo
o`<00?l01`3oool2000000030?ooo`000000oooo00/0oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`0S0?ooo`009P3oool00`000000oooo0?ooo`0?0?ooo`800000nP3oool00`000000
l:Mg0?2WM`050?2WM`<000003`2W`>/01@000000Yl3[0:O0j`2W`>/0000000D0m:Q^1`3eYfT60?JW
IPL0mZMS0P3eXUT00`000000Re:808]BR00B08]BR0030000003oool0oooo0140oooo00<000000?oo
o`3oool02@3oool30000o`040?ooo`000?l0003o0000o`80oooo1P000?l:0?ooo`8000003@3oool@
0?l0oa<0oooo103o00040?ooo`<0o`0000@0oooo0?l0003o0000o`000P00000@0?ooo`030000003o
ool0oooo01H0oooo1000o`00103oool00?l0003o0000o`020?ooo`<00?l00P3oool3003o00/0oooo
00<000000?ooo`000000303oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo02<0oooo
000V0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0m`3oool00`000000l:Mg0?2W
M`020?2WM`<000004P2W`>/00`000000Yl3[0:O0j`020:O0j`030000003dZ6h0m:Q^00<0m:Q^1P3e
YfT70?JWIPL0mZMS00<0mJ9I0000002;DXP04`2;DXP00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo00/0oooo0P000?l20?ooo`80003o0`3oool60000o`L0oooo0P00000:0?oooa00o`3o603o
ool50?l000@0oooo0`3o0000103oool0o`000?l0003o000?0?ooo`800000503oool3003o0080oooo
0`00o`020?ooo`<00?l00P3oool3003o00h0oooo0`00000<0?ooo`030000003oool0oooo05P0oooo
00<000000?ooo`3oool08`3oool002H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`3f0?ooo`030000003`YgL00000008000005@2W`>/00`000000Yl3[0:O0j`030:O0j`030000003d
Z6h0m:Q^0080m:Q^1`3eYfT60?JWIPP0mZMS00<0000008]BR02;DXP04P2;DXP00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo00d0oooo0P000?l20?ooo`<0003o0`3oool20000o`030?ooo`00
0?l0003o00D0oooo0P0000070?oooa00o`3o7@3oool50?l0008000000`3oool20?l00080oooo0P3o
000=0?ooo`8000004@3oool3003o0080oooo0`00o`020?ooo`<00?l00P3oool3003o0200oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0S0?ooo`009P3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo0?D0oooo0P00000H0:O0j`030000002W`>/0Yl3[00@0Yl3[00@00000
0?BXKP3dZ6h0m:Q^1`3eYfT60?JWIPP0mZMS00<0000008]BR02;DXP04P2;DXP00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo00h0oooo0`000?l20?ooo`80003o0`3oool60000o`80oooo0P00
00040?oooa00o`3o8@3oool2000000D0o`00103oool30?l000040?ooo`3o0000o`000?l000X0oooo
0P00000=0?ooo`@00?l00P3oool3003o0080oooo0`00o`020?ooo`<00?l0903oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo0280oooo000V0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool0m03oool00`000000l:Ul0000000G0:O0j`030000002W`>/0Yl3[00D0Yl3[00@0
00000?BXKP3dZ6h0m:Q^1P3eYfT60?JWIPP0mZMS00<0000008]BR02;DXP04P2;DXP00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo0140oooo0P000?l20?ooo`<0003o0`3oool50000o`800000
00<0oooo0?l0o`3o0?l03P3o0?lQ0?ooo`<00000103oool60?l000@0oooo0`3o0000103oool0o`00
0?l0003o00060?ooo`<000002P3oool3003o00<0oooo0`00o`020?ooo`<00?l00P3oool3003o02L0
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0R0?ooo`009P3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo0?<0oooo00@000000?2YO03`ZG`000005P2W`>/00`000000
Yl3[0:O0j`050:O0j`040000003dZ6h0m:Q^0?BXKPL0mJMY1P3fYfH70?JWH`030000002;DXP0Re:8
0180Re:800<000000?ooo`3oool0503oool00`000000oooo0?ooo`0B0?ooo`<0003o0P3oool30000
o`<0oooo0P000?l00`000000o`3o0?l0o`0=0?l0ob00oooo1000000:0?ooo`80o`0000<0oooo0?l0
003o00001@3oool20?l00080oooo0P3o00040?ooo`<000001P3oool4003o0080oooo1000o`020?oo
o`<00?l00P3oool3003o02X0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0R0?oo
o`009P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0?80oooo00@000000?2YO03`
ZG`0l:Ul0P00000D0:O0j`030000002W`>/0Yl3[00H0Yl3[00@000000?BXKP3dZ6h0m:Q^1P3eYfT6
0?JWIPL0mZMS00<0000008]BR02;DXP04P2;DXP00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo01D0oooo0P000?l30?ooo`80003o0`3oool00`000000o`3o0?l0o`0:0?l0ob00oooo0`00000@
0?ooo`80o`0000@0oooo0?l0003o0000o`00103oool30?l000050?ooo`3o0000o`000?l0003oool0
0`0000030?ooo`<00?l00`3oool3003o00<0oooo0`00o`020?ooo`<00?l0;@3oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo0280oooo000V0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool0l@3oool010000000l:Ul0?2YO03`ZG`2000001@0Yl3[00<000000:O0j`2W`>/0
1`2W`>/00`000000m:Q^0?BXKP060?FWJ@H0mZMV1`3fYf<00`000000Re:808]BR00B08]BR0030000
003oool0oooo01D0oooo00<000000?ooo`3oool05P3oool30000o`80oooo0`000?l00`000000o`3o
0?l0o`070?l0ob00oooo0`00000E0?ooo`<0o`0000<0oooo0?l0003o00001@3oool30?l000050?oo
o`3o0000o`000?l0000000000`00o`030?ooo`<00?l00`3oool3003o0080oooo0`00o`0`0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool08P3oool002D0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`3_0?ooo`030?l0o`000000l:Ul0080l:Ul0`00000C0:O0j`030000
002W`>/0Yl3[00P0Yl3[00<000000?BXKP3dZ6h01P3eYfT50?JWIPL0mZMS00<0000008]BR02;DXP0
4P2;DXP00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01T0oooo0P000?l30?ooo``0o`3o
6`3oool3000001/0oooo0P3o0000103oool0o`000?l0003o00050?ooo`<0o`000P00o`030?ooo`<0
0?l00`3oool3003o0080oooo0`00o`0a0?ooo`<00000FP3oool00`000000oooo0?ooo`0R0?ooo`00
9@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0>/0oooo103o0?l00`000000l:Ul
0?2YO0020?2YO0<000004`2W`>/00`000000Yl3[0:O0j`080:O0j`030000003dZ6h0mJMY00D0mJMY
1P3fYfH70?JWH`030000002;DXP0Re:80140Re:800<000000?ooo`3oool05@3oool2000001`0oooo
0`000?l50?l0o`030?ooo`3o0?l0o`3o00<0o`3o00@0003o0?l0o`3o0?l0o`3o5@3oool300000200
oooo0P3o00020?ooo`<0o`0000L00?l00?l0003o0000o`000000003o0000000000<00?l00`3oool3
003o0080oooo0`00o`0a0?ooo`<000000P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0
oooo0280oooo000U0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0i`3oool30?l0
o`050?l0003o0?l0o`3o0?l0000000001@3`ZG`300000180Yl3[00<000000:O0j`2W`>/02@2W`>/0
0`000000m:Q^0?FWJ@040?FWJ@H0mZMV1`3fYf<00`000000Re:808]BR00A08]BR0030000003oool0
oooo0180oooo0`0000000`3oool000000?ooo`0N0?ooo`030?l0o`000000o`3o00@0o`3o0P3oool5
0?l0o`030000o`3o0?l0o`3o0100oooo0`00000U0?ooo`P0o`0000@00?l000000000o`000?l00`3o
ool3003o0080oooo0`00o`0a0?ooo`<000001P3oool00`000000oooo0?ooo`1G0?ooo`030000003o
ool0oooo0280oooo000U0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0h`3oool3
0?l0o`<0o`0000D0o`3o0?l0003o0000003o000000080?2YO0030000002W`>/0Yl3[00l0Yl3[00<0
00000:O0j`2W`>/02P2W`>/00`000000mJMY0?FWJ@040?FWJ@D0mZMV1`3fYf<00`000000Re:808]B
R00A08]BR0030000003oool0oooo00l0oooo0`0000050?ooo`030000003oool0oooo01`0oooo0P00
00030000o`D0o`3o00<0oooo0?l0o`3o0?l00`3o0?l010000?l0o`3o0?l0o`3o0?l:0?ooo`<00000
9`3oool00`00o`00o`000?l000030?l000800?l00`3o0002000000<00?l00P3oool3003o0340oooo
0`00000:0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool08@3oool002D0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`3O0?ooo`<0o`3o0`3o00001000o`00o`3o0?l0
o`3o00020000o`03003o00000000l:Ul00P0l:Ul0P00000?0:O0j`030000002W`>/0Yl3[00/0Yl3[
00<000000?FWJ@3eYfT00`3eYfT50?JWIPL0mZMS00<0000008]BR02;DXP04@2;DXP00`000000oooo
0?ooo`0<0?ooo`<00000203oool00`000000oooo0?ooo`0L0?ooo`8000000`3oool20000o`D0o`3o
0P3oool50?l0o`040000o`3o0?l0o`3o0?l0o`@0oooo0`00000W0?ooo`03003o003o0000o`0000<0
o`000`00o`020?l000050?ooo`00o`0000000?l00000o`000P3oool3003o0340oooo0`00000>0?oo
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool08@3oool002D0oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`3K0?ooo`<0o`3o0`3o0002003o0080o`3o0P3o00001@3oool0
0?l0003o00000?l0000000/0l:Ul00<000000:O0j`2W`>/0302W`>/00`000000Yl3[0:O0j`0<0:O0
j`030000003eYfT0mJMY0080mJMY1@3fYfH70?JWH`030000002;DXP0Re:80140Re:800<000000?oo
o`3oool02@3oool3000000`0oooo00<000000?ooo`3oool06`3oool2000000D0oooo0`000?l50?l0
o`030?ooo`3o0?l0o`3o00@0o`3o00D0003o0?l0o`3o0?l0o`3o0000000@0?ooo`030000003oool0
oooo01@0oooo00<00?l00?l0003o00000`3o0003003o00<0oooo0P00o`030?l0000400000000o`00
0?l0003o0340oooo0`00000A0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool08@3o
ool002D0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`3G0?ooo`<0o`3o0`3o0003
003o0080o`3o0P3o00000`3oool00?l0003o00020000o`030?ooo`000000l:Ul00/0l:Ul00<00000
0:O0j`2W`>/02`2W`>/00`000000Yl3[0:O0j`0=0:O0j`040000003eYfT0mJMY0?FWJ@H0mZMV1P3f
Yf<00`000000Re:808]BR00A08]BR0030000003oool0oooo00H0oooo0`00000?0?ooo`030000003o
ool0oooo01/0oooo0P0000080?ooo`80003o1@3o0?l20?ooo`D0o`3o0P000?l30?l0o`h0oooo0P00
000B0?ooo`H0o`000P00o`040?ooo`<00?l000L0o`000?ooo`3oool00?l00000003o000000000300
oooo0`00000E0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool08@3oool002D0oooo
00<000000?ooo`3oool0803oool00`000000oooo0?ooo`3C0?ooo`<0o`3o0`3o0003003o00030000
o`3o0?l0o`3o0080o`000P3oool00`00o`00003o0000o`030?ooo`030000003`ZG`0l:Ul00/0l:Ul
00<000000:O0j`2W`>/02P2W`>/00`000000Yl3[0:O0j`0=0:O0j`030000003eYfT0mJMY0080mJMY
1@3fYfH60?JWH`030000002;DXP0Re:80140Re:800<000000?ooo`3oool00`3oool300000180oooo
00<000000?ooo`3oool06`3oool2000000X0oooo0`000?l50?l0o`80oooo1@3o0?l20000o`80o`3o
303oool2000000l0oooo1P3o0002003o00@0oooo0`00o`000`3o0000oooo0?ooo`03003o00040?oo
o`0000000000000002`0oooo1000000I0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3o
ool08@3oool002D0oooo00<000000?ooo`3oool08@3oool200000=00oooo0`3o0?l30?l000<00?l0
0`000?l00`3o0?l0o`000?l000020?ooo`800?l000<0003o0?ooo`3oool00`3oool00`000000l:Ul
0?2YO00<0?2YO08000002P2W`>/00`000000Yl3[0:O0j`0>0:O0j`040000003eYfT0mJMY0?FWJ@D0
mZMV1P3fYf<00`000000Re:808]BR00B08]BR0030000003oool00000008000005P3oool00`000000
oooo0?ooo`0J0?ooo`800000303oool00`000000003o0000o`060?l0o`030?ooo`3o0?l0o`3o00@0
o`3o00@0003o0?l0o`3o0?l0o`3o2@3oool2000000`0oooo1P3o0002003o00@0oooo0`00o`000`3o
0000oooo0?ooo`03003o00@0oooo0`00000Y0?ooo`<000007P3oool00`000000oooo0?ooo`1C0?oo
o`030000003oool0oooo0240oooo000T0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool0bP3oool30?l0o`<0o`000`00o`030000o`040?ooo`3o0?l0o`3o0?l00080oooo0P00o`020000
o`L0oooo00<000000?2YO03`ZG`03@3`ZG`00`000000Yl3[0:O0j`070:O0j`030000002W`>/0Yl3[
00l0Yl3[00<000000?FWJ@3eYfT01@3fYfH60?JWH`030000002;DXP0Re:80180Re:80P00000I0?oo
o`030000003oool0oooo01X0oooo0P0000090?ooo`<000000`3oool30000o`D0o`3o0P3oool50?l0
o`80003o0`3o0?l50?ooo`<000002@3oool60?l00003003o003oool0oooo00<0oooo0`00o`000`3o
0000oooo0?ooo`03003o00L0oooo0`00000V0?ooo`<000008@3oool00`000000oooo0?ooo`1C0?oo
o`030000003oool0oooo0240oooo000T0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool0aP3oool30?l0o`<0o`000`00o`030000o`80oooo0P3o0?l20?l000030?ooo`00o`000?l00080
003o2@3oool00`000000l:Ul0?2YO00>0?2YO0030000002W`>/0Yl3[00H0Yl3[00<000000:O0j`2W
`>/0402W`>/00`000000mJMY0?FWJ@050?JWIPD0mZMS00<0000008]BR02;DXP04P2;DXP00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo01T0oooo0P0000060?ooo`<000002@3oool30000o`D0
o`3o0P3oool50?l0o`80003o0`3o0?l20?ooo`<000001P3oool60?l00003003o003oool0oooo00<0
oooo0`00o`000`3o0000oooo0?ooo`03003o00X0oooo0`00000S0?ooo`<000009@3oool00`000000
oooo0?ooo`1B0?ooo`030000003oool0oooo0240oooo000T0?ooo`030000003oool0oooo02H0oooo
00<000000?ooo`3oool0`P3oool30?l0o`<0o`000`00o`030000o`<0oooo0P3o0?l20?l000030?oo
o`00o`000?l00080003o2`3oool00`000000l:Ul0?2YO00?0?2YO0030000002W`>/0Yl3[00D0Yl3[
00<000000:O0j`2W`>/04@2W`>/00`000000mJMY0?JWIP040?JWIPD0mZMS00<0000008]BR02;DXP0
4P2;DXP2000001X0oooo00<000000?ooo`3oool07P3oool3000000l0oooo0P000?l50?l0o`80oooo
1@3o0?l30000o`<0o`3o0P0000030?ooo`H0o`0000<00?l00?ooo`3oool00`3oool3003o00030?l0
003oool0oooo00<00?l03@3oool00`000000oooo0000000P0?ooo`<00000:@3oool00`000000oooo
0?ooo`1A0?ooo`030000003oool0oooo0240oooo000T0?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool0_P3oool30?l0o`<0o`000`00o`030000o`D0oooo00<0o`3o0?l0003o00000P3o
ool00`00o`00003o0000o`0=0?ooo`030000003`ZG`0l:Ul0100l:Ul00<000000:O0j`2W`>/0102W
`>/00`000000Yl3[0:O0j`0B0:O0j`030000003fYfH0mZMV00<0mZMV1@3fYf<00`000000Re:808]B
R00B08]BR08000006`3oool00`000000oooo0?ooo`0J0?ooo`<00000503oool30000o`D0o`3o0P3o
ool50?l0o`<0003o0P0000060?l000H0oooo0`00o`020?l000040?ooo`00o`000?l0003o0100oooo
00<000000?ooo`0000007@3oool3000002d0oooo00<000000?ooo`3oool0D@3oool00`000000oooo
0?ooo`0P0?ooo`00903oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0;X0oooo0`3o
0?l30?l000<00?l00`000?l60?ooo`030?l0o`3o0000o`000080oooo0P00o`000`000?l0oooo0?oo
o`0=0?ooo`030000003`ZG`0l:Ul0140l:Ul00@000000:O0j`2W`>/0Yl3[0`00000E0:O0j`030000
003fYfH0mZMV0080mZMV1@3fYf<00`000000Re:808]BR00B08]BR08000006`3oool00`000000oooo
0?ooo`0G0?ooo`<000006P3oool20000o`D0o`3o0P3oool60?l0o`8000000`3o00060?ooo`<00?l0
0P3o0000103oool00?l0003o0000o`0C0?ooo`8000006`3oool300000300oooo00<000000?ooo`3o
ool0D@3oool00`000000oooo0?ooo`0P0?ooo`00903oool00`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo0;H0oooo0`3o0?l30?l000<00?l00`000?l70?ooo`80o`3o00<0o`000?ooo`3oool0
0P00o`020000oa00oooo00<000000?2YO03`ZG`04@3`ZG`400000080Yl3[00<000000:O0j`2W`>/0
502W`>/010000000mZMV0?JWIP3fYfH60?JWH`030000002;DXP0Re:80140Re:800<000000?RXD`00
00006`3oool00`000000oooo0?ooo`0B0?ooo`@000007`3oool30000o`H0o`3o00@0o`000?l0o`3o
0?l0o`3o0P0000060?ooo`<00?l00P3o0000103oool00?l0003o0000o`0G0?ooo`030000003oool0
oooo01D0oooo1000000d0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0803oool0
02@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`2b0?ooo`<0o`3o0`3o0003003o
00<0003o203oool20?l0o`80o`0000<0oooo003o0000o`000P000?lB0?ooo`030000003`ZG`0l:Ul
00l0l:Ul100000040:O0j`030000002W`>/0Yl3[01D0Yl3[00@000000?JWIP3fYfH0mZMV1@3fYf<0
0`000000Re:808]BR00A08]BR0030000003hZ5<0000001/0oooo00<000000?ooo`3oool03`3oool3
000002H0oooo0P000?l70?l0o`<000000`3oool3003o0080o`0000@0oooo003o0000o`000?l0;`3o
ool3000003T0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0P0?ooo`00903oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0:h0oooo0`3o0?l30?l000<00?l00`000?l:
0?ooo`040?l0o`3o0000o`000?ooo`800?l00P000?lD0?ooo`030000003`ZG`0l:Ul00`0l:Ul0`00
00020?2YO080ljai00<000000:O0j`2W`>/00P2W`>/00`000000Yl3[0:O0j`0E0:O0j`030000003g
[6d0mja]00D0mZMS00<0000008]BR02;DXP04@2;DXP010000000n:QC0?RXD`00000J0?ooo`030000
003oool0oooo00`0oooo0`00000V0?ooo`<0o`3o0P3o00030000o`@0o`3o0`000003003o0080o`00
00@0oooo003o0000o`000?l0;`3oool3000003`0oooo00<000000?ooo`3oool0C`3oool00`000000
oooo0?ooo`0P0?ooo`00903oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0:X0oooo
0`3o0?l30?l000<00?l00`000?l;0?ooo`030?l0o`3o0000o`000080oooo00<00?l00000o`000?l0
5P3oool00`000000l:Ul0?2YO0080?2YO0@000001@3`ZG`30?>/N@<0000000<0Yl3[0000002W`>/0
5P2W`>/00`000000mja]0?N/K@020?N/K0<0mZMS00<0000008]BR02;DXP04@2;DXP010000000n:QC
0?RXD`00000K0?ooo`030000003oool0oooo00P0oooo0`00000V0?ooo`<0o`3o0P3o00060?l0o`80
003o0P3o0?l300000080o`0000@0oooo003o0000o`000?l0;`3oool300000400oooo00<000000?oo
o`3oool0CP3oool00`000000oooo0?ooo`0P0?ooo`008`3oool00`000000oooo0?ooo`0^0?ooo`03
0000003oool0oooo0:H0oooo0`3o0?l30?l000<00?l00`000?l<0?ooo`030?l0o`3o0000o`000080
oooo0P00o`000`000?l0oooo0?ooo`0F0?ooo`030000003`ZG`0l:Ul00D0l:Ul0`0000090?2YO0@0
ljai0P0000000`2W`>/000000:O0j`0G0:O0j`030000003g[6d0mja/0080mja/0P3fYf<00`000000
Re:808]BR00A08]BR0040000003hZ5<0n:QC000001/0oooo00<000000?ooo`3oool01@3oool30000
02H0oooo0`3o0?l00`3o0000oooo0?l0o`050?l0o`@0oooo00<0o`3o0000o`000?l00`000003003o
02l0oooo0`0000140?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0803oool002<0
oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`2R0?ooo`<0o`3o0`3o0003003o00<0
003o3@3oool20?l0o`030?l0003oool0oooo00800?l000<0003o0?ooo`3oool0603oool00`000000
l:Ul0?2YO0020?2YO0<00000303`ZG`00`3o0000ljai0?>/N@020?>/N@030000002W`>/0000001T0
Yl3[00<000000?N/K03g[6`00P3g[6`00`3fYf<0000008]BR00B08]BR0050000003hZ5<0n:QC0?RX
D`0000006`3oool010000000oooo0?ooo`3oool3000002H0oooo0`3o0?l00`3o0000oooo0?l0o`04
0?l0o`D0oooo0`3o0?l20?l000040000o`0000000000000002l0oooo0`0000180?ooo`030000003o
ool0oooo04`0oooo00<000000?ooo`3oool0803oool002<0oooo00<000000?ooo`3oool0<03oool0
0`000000oooo0?ooo`2N0?ooo`<0o`3o0`3o0003003o00<0003o3P3oool20?l0o`80o`0000<0oooo
003o0000o`000P000?lK0?ooo`030000003`ZG`00000008000003`3`ZG`00`3o0000ljai0?>/N@03
0?>/N@8000006P2W`>/00`000000mja/0?N/K0020?N/K0030000002;DXP0Re:80140Re:800D00000
0?RXD`3hZ5<0n:QC0000000K0?ooo`@000009P3oool30?l0o`030?l0003o0?l0o`3o00@0o`3o1@3o
ool30?l0o`80o`000`000?l0103o0?l0000000000000000[0?ooo`@00000B`3oool00`000000oooo
0?ooo`1<0?ooo`030000003oool0oooo0200oooo000S0?ooo`030000003oool0oooo0340oooo00<0
00000?ooo`3oool0VP3oool30?l0o`<0o`000`00o`030000oa00oooo00@0o`3o0?l0003o0000oooo
0P00o`020000oad0oooo0P00000B0?2YO0L0ljai0`00000I0:O0j`050000003g[6`0mja/0?N/K000
00004`2;DXP00`000000n:QC0?RXD`020?RXD`030000003oool0oooo01H0oooo1000000G0?ooo`@0
00002P3oool30?l0o`030?l0003o0?l0o`3o00<0o`3o1P3oool30?l0o`80o`000`000?l0103o0?l0
oooo0?ooo`3oool3000002P0oooo0`00001@0?ooo`030000003oool0oooo04`0oooo00<000000?oo
o`3oool07`3oool002<0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`2F0?ooo`<0
o`3o0`3o0003003o00<0003o4@3oool00`3o0?l0o`000?l000020?ooo`03003o00000?l0003o01`0
oooo0`3o0?l00`000000l:b00?2YO00A0?2YO0P0ljai0P00000J0:O0j`040000003g[6`0mja/0000
01<0Re:800<000000?RXD`3hZ5<00P3hZ5<00`000000oooo0?ooo`0C0?ooo`<000000`3oool00`00
0000oooo0?ooo`0D0?ooo`H000001P3oool30?l0o`030?ooo`3o0?l0o`3o00<0o`3o1P3oool30?l0
o`80o`000`000?l00`3o0?l0oooo0?ooo`040?ooo`<000009@3oool3000005@0oooo00<000000?oo
o`3oool0B`3oool00`000000oooo0?ooo`0O0?ooo`008`3oool00`000000oooo0?ooo`0c0?ooo`80
0000T`3oool30?l0o`<0o`000`00o`030000oa80oooo0P3o0?l00`3o0000oooo0?ooo`02003o0003
0000o`3oool0oooo01T0oooo0`3o0?l30?ooo`040000003`[800l:b00?2/P140l:Ul1`3c[7T30000
01X0Yl3[00<000000?N/K00000004`2;DXP00`000000n:QC0?RXD`020?RXD`030000003oool0oooo
00l0oooo100000060?ooo`030000003oool0oooo0100oooo1`000000102;DXP00000000000000002
0?ooo`<0o`3o00<0oooo0?l0o`3o0?l00`3o0?l60?ooo`<0o`3o0P3o00030000o`030?l0o`3oool0
oooo00L0oooo0`00000R0?ooo`<00000F03oool00`000000oooo0?ooo`1:0?ooo`030000003oool0
oooo01l0oooo000S0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0S@3oool30?l0
o`<0o`000`00o`030000oa<0oooo0P3o0?l20?l000040?ooo`00o`000?l00000oaX0oooo0`3o0?l6
0?ooo`030?l0o`000000l:b000<0l:b03`3`ZG`70?>/N@040000003c[7T0ljai000001X0Yl3[0P00
000C08]BR0030000003hZ5<0n:QC00<0n:QC00<000000?ooo`3oool02`3oool3000000/0oooo00<0
00000?ooo`3oool03`3oool2000000030?ooo`000000000000@0000000D0Re:80?l0o`3o0?l0o`3o
0?ooo`040?l0o`L0oooo0`3o0?l00`3o0000003o0000o`020000o`030?l0o`3oool0oooo00X0oooo
0`00000O0?ooo`<00000F`3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo01l0oooo
000S0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0R@3oool30?l0o`<0o`000`00
o`030000oaD0oooo00@0o`3o0?l0003o0000oooo0P00o`000`000?l0oooo0?ooo`0G0?ooo`<0o`3o
1`3oool20?l0o`030?l000000000l:b000D0l:b03@3`ZG`70?>/N@050000003c[7T0ljai0?>/N@00
00006P2W`>/00`000000Re:808]BR00A08]BR0030000003hZ5<0n:QC00<0n:QC00<000000?ooo`3o
ool0203oool3000000h0oooo00<000000?ooo`3oool03`3oool2000000030?ooo`000000Yl3[00@0
000000<0o`3o0000003o0?l00`3o0?l70?ooo`<0o`3o00@0o`000000o`000?l0003o0P3o0?l?0?oo
o`8000007@3oool3000005l0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0O0?oo
o`008`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo08D0oooo0`3o0?l30?l000<0
0?l00`000?lF0?ooo`040?l0o`3o0000o`000?ooo`800?l00P000?lG0?ooo`<0o`3o203oool20?l0
o`80o`0000<0oooo0000003`[8001`3`[80;0?2YO0P0ljai00D000000?>/N@3c[7T0ljai0000000I
0:O0j`030000002;DXP0Re:80140Re:800<000000?RXD`3hZ5<0103hZ5<00`000000oooo0?ooo`04
0?ooo`<00000403oool300000100oooo1`0000000`2W`>/00000000000020?l0o`030000003oool0
oooo00@0oooo0`3o0?l0103o0000003o0000o`000?l20?l0oa<0oooo00<000000?ooo`3oool0603o
ool3000006<0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0O0?ooo`008P3oool0
0`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0840oooo0`3o0?l30?l000<00?l00`000?lG
0?ooo`030?l0o`3o0000o`000080oooo00<00?l00000o`000?l05P3oool30?l0o`T0oooo0P3o0?l0
0`3o0000oooo0?ooo`020?ooo`030000003`[800l:b000T0l:b0203`ZG`80?>/N@030000003c[7T0
ljai0080ljai0P00000H0:O0j`030000002;DXP0Re:80100Re:800<000000?RXD`3hZ5<0103hZ5<0
10000000oooo0?ooo`3oool300000100oooo0`0000020?ooo`030000003oool0oooo00h0oooo0P00
00000`00o`00000000000003000000050?l0o`00000000000?ooo`0000000`3oool30?l0o`040?l0
00000?l0003o0000o`80o`3o5P3oool00`000000oooo0?ooo`0D0?ooo`@00000I`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo01l0oooo000R0?ooo`030000003oool0oooo03X0oooo
00<000000?ooo`3oool0O@3oool30?l0o`<0o`000`00o`030000oaP0oooo0P3o0?l00`3o0000oooo
0?ooo`02003o00030000o`3oool0oooo01<0oooo0`3o0?l90?ooo`030?l0003o0?l0o`3o00L0oooo
00<000000?2/P03`[8002`3`[8060?2YO0P0ljai00<000000?>/N@3c[7T00P3c[7T2000001T0Yl3[
00<0000008]BR02;DXP03`2;DXP00`000000n:QC0?RXD`040?RXD`@00000403oool3000000D0oooo
00<000000?ooo`3oool0303oool20?l0o`T0000000@0Re:800000000000000000`3o0?l0103o0000
003o0000o`000?l20?l0obd0oooo0`00001[0?ooo`030000003oool0oooo04L0oooo00<000000?oo
o`3oool07`3oool00280oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`1i0?ooo`<0
o`3o0`3o0003003o00<0003o6@3oool20?l0o`80o`0000@0oooo003o0000o`00003o503oool30?l0
o`T0oooo0P3o00020?l0o`P0oooo0P3o00000`000000l:b00?2/P00<0?2/P0@0l:Ul203c[7T00`00
0000ljai0000o`040?>/N@030000002W`>/0Yl3[01L0Yl3[00<0000008]BR02;DXP03P2;DXP00`00
0000n:QC0?RXD`050?RXD`030000003oool0oooo00d0oooo0`0000090?ooo`030000003oool0oooo
00P0oooo1@3o0?l90000000508]BR000000000000000003o00000`000?l20?l0obd0oooo0`00001_
0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool07P3oool00280oooo00<000000?oo
o`3oool0?03oool00`000000oooo0?ooo`1e0?ooo`<0o`3o0`3o0003003o00<0003o6`3oool0103o
0?l0o`000?l0003oool2003o00030000o`3oool0oooo0140oooo0`3o0?l90?ooo`<0o`000P3o0?l8
0?ooo`80o`000P00o`000`000000l:b00?2/P00>0?2/P080l:Ul2@3c[7T00`000000ljai0?>/N@04
0?>/N@800000602W`>/00`000000Re:808]BR00=08]BR0030000003hZ5<0n:QC00D0n:QC00<00000
0?ooo`3oool02P3oool3000000`0oooo00<000000?ooo`3oool01P3oool50?l0o`040?ooo`3o0?l0
000000000080oooo1@0000000`2;DXP000000000000200000080o`3o;@3oool3000007<0oooo00<0
00000?ooo`3oool0AP3oool00`000000oooo0?ooo`0N0?ooo`008P3oool00`000000oooo0?ooo`0m
0?ooo`030000003oool0oooo0740oooo0`3o0?l00`3oool0o`000?l00003003o00<0003o703oool0
103o0?l0o`000?l0003oool2003o0080003o4@3oool30?l0o`T0oooo0`3o00000`3oool0o`3o0?l0
o`070?ooo`<0o`000P00o`020?ooo`030000003`[800l:b00100l:b02@3c[7T00`000000ljai0?>/
N@040?>/N@8000006@2W`>/00`000000Re:808]BR00<08]BR0030000003hZ5<0n:QC00H0n:QC00<0
00000?ooo`3oool01P3oool3000000l0oooo00<000000?ooo`3oool0103oool40?l0o`040?l0003o
0?l0o`3o0?l0o`80oooo0P0000000`3o0?l00000000000030000000308]BR0000000o`3o00800000
;03oool3000007L0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0N0?ooo`008P3o
ool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo06d0oooo0`3o0?l0103oool0o`000?l0
003o0002003o00<0003o7@3oool00`3o0?l0o`000?l000020?ooo`03003o00000?l0003o0100oooo
0`3o0?l90?ooo`<0o`000P3oool20?l0o`L0oooo0P3o0002003o00D0oooo00<000000?2/P03`[800
403`[8020?>]O0L0ljai00@000000?>/N@3c[7T0o`3o1@3c[7T00`000000Yl3[0:O0j`0G0:O0j`03
0000002;DXP0Re:800/0Re:800<000000?RXD`3hZ5<01P3hZ5<00`000000oooo0?ooo`030?ooo`<0
00004`3oool010000000oooo0?ooo`3oool70?l0o`<0oooo0P3o0?l2000000050000o`0000000000
0000002;DXP01P00000Y0?ooo`<00000NP3oool00`000000oooo0?ooo`150?ooo`030000003oool0
oooo01h0oooo000R0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0J@3oool30?l0
o`040?ooo`3o0000o`000?l000800?l00`000?lN0?ooo`80o`3o00<0o`000?ooo`3oool00P00o`00
0`000?l0oooo0?ooo`0=0?ooo`<0o`3o2@3oool30?l000<0oooo0P3o0?l70?ooo`80o`0000<00?l0
0?ooo`3oool01@3oool00`00o`0000000?2/P00A0?2/P0@0ljel1@3c[7T00`000000ljai0?>/N@06
0?>/N@030?J^M@000000Yl3[01P0Yl3[00<0000008]BR02;DXP02P2;DXP00`000000n:QC0?RXD`06
0?RXD`030000003oool0oooo00<000005P3oool00`000000oooo0?l0o`020?l0o`030?l0003o0?l0
o`3o0080oooo1@3o0?l00`000?l000000000000;000002H0oooo0`00001n0?ooo`030000003oool0
oooo04@0oooo00<000000?ooo`3oool07P3oool00280oooo00<000000?ooo`3oool0@03oool00`00
0000oooo0?ooo`1U0?ooo`<0o`3o00@0oooo0?l0003o0000o`000P00o`030000ob00oooo00@0o`3o
0?l0003o0000oooo0P00o`000`000?l0oooo0?ooo`0<0?ooo`<0o`3o2@3oool30?l000@0oooo0P3o
0?l60?ooo`03003o003o0000o`0000P0oooo0P00o`020?ooo`030000003`[800l:b000l0l:b01P3c
[G`30?>/N@030000003c[7T0ljai00H0ljai0P3f[WD00`000000Yl3[0:O0j`0G0:O0j`030000002;
DXP0Re:800T0Re:800<000000?RXD`3hZ5<01`3hZ5<2000001P0oooo0`3o0?l00`3o0000o`3o0?l0
o`020?ooo`@0o`3o0P000?l30?ooo`040000003oool0000008]BR0P000008`3oool400000880oooo
00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0N0?ooo`008P3oool00`000000oooo0?oo
o`110?ooo`030000003oool0oooo0640oooo0`3o0?l0103oool0o`000?l0003o0002003o00<0003o
8@3oool0103o0?l0o`000?l0003oool2003o00030000o`3oool0oooo00/0oooo0`3o0?l90?ooo`<0
o`00103oool30?l0o`D0oooo0P00o`020?l000P0oooo0P00o`040?ooo`030000003`[800l:b00100
l:b01`3c[G`20?>/N@030000003c[7T0ljai00D0ljai0`3f[WD00`000000Yl3[0:O0j`0F0:O0j`03
0000002;DXP0Re:800T0Re:800<000000?RXD`3hZ5<01P3hZ5<00`3i[5H000000?ooo`0F0?ooo`<0
o`3o00<0o`000?l0o`3oool0103o0?l20000o`P0oooo0`0000000`3oool000000000000500000200
oooo0`0000270?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool07P3oool00240oooo
00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`1M0?ooo`<0o`3o00@0oooo0?l0003o0000
o`000P00o`030000ob80oooo00@0o`3o0?l0003o0000oooo0P00o`000`000?l0oooo0?ooo`0:0?oo
o`<0o`3o2@3oool30?l000D0oooo0P3o0?l50?ooo`<00?l00P3o00080?ooo`800?l01P3oool00`00
0000l:b00?2/P00@0?2/P0T0ljel00<000000?>/N@3c[7T01@3c[7T40?J^M@030000002W`>/0Yl3[
01H0Yl3[00<0000008]BR02;DXP0202;DXP00`000000n:QC0?RXD`050?RXD`80nJaF00<000000?oo
o`3oool04P3oool30?l0o`80o`001@3o0?l>0?ooo`L00000803oool3000008X0oooo00<000000?oo
o`3oool0@P3oool00`000000oooo0?ooo`0N0?ooo`008@3oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo05T0oooo0`3o0?l0103oool0o`000?l0003o0002003o00<0003o8`3oool00`3o
0?l0o`000?l000020?ooo`03003o00000?l0003o00X0oooo0`3o0?l90?ooo`<0o`001P3oool20?l0
o`@0oooo0`00o`000`3oool0o`000?l000070?ooo`<00?l0203oool00`000000l:b00?2/P00@0?2/
P0T0ljel00<000000?>/N@3c[7T01P3c[7T40?J^M@030000002W`>/0Yl3[01H0Yl3[00<0000008]B
R02;DXP01`2;DXP00`000000nJaP0?RXD`030?RXD`D0nJaF00<000000?ooo`3oool01P3oool20000
00L0oooo0`3o0?l00`3o0000o`3o0?l0o`020?l0o`030?ooo`000000oooo0140oooo00<000000?oo
o`3oool07`3oool3000008h0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0N0?oo
o`008@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo05D0oooo0`3o0?l0103oool0
o`000?l0003o0002003o00<0003o903oool20?l0o`030?l0003oool0oooo00800?l000<0003o0?oo
o`3oool01`3oool30?l0o`T0oooo0`3o00070?ooo`80o`3o0`3oool3003o00040?ooo`3o0000o`00
0?l000L0oooo0P00o`0:0?ooo`030000o`000000l:b00140l:b02@3c[G`00`000000ljel0?>]O006
0?>/N@D0mZie00<000000:O0j`2W`>/05P2W`>/00`000000Re:808]BR00608]BR0030000003i[600
n:QC0080n:QC1P3i[5H00`000000oooo0?ooo`040?ooo`D000000`3oool40?l0o`040?l0003o0?l0
o`3o0?l0o`@0oooo00<000000?ooo`3oool0;`3oool300000980oooo00<000000?ooo`3oool0@@3o
ool00`000000oooo0?ooo`0M0?ooo`008@3oool00`000000oooo0?ooo`160?ooo`800000DP3oool3
0?l0o`040?ooo`3o0000o`000?l000800?l00`000?lV0?ooo`040?l0o`3o0000o`000?ooo`800?l0
00<0003o0?ooo`3oool01P3oool30?l0o`T0oooo0`3o00080?ooo`80o`3o0P3oool3003o0080oooo
0P3o00080?ooo`800?l02@3oool30000o`80oooo00<000000?2/P03`[8003`3`[8090?>]O0030000
003c[G`0ljel0080ljel103c[7T60?J^M@030000002W`>/0Yl3[01H0Yl3[00<0000008]BR02;DXP0
1@2;DXP010000000nJaP0?V/H03hZ5<70?V/EP030000003oool0oooo00@0oooo00<000000?R_KP00
00000P0000070?l0o`T0oooo00<000000?ooo`3oool0:`3oool3000009D0oooo00<000000?ooo`3o
ool0@@3oool00`000000oooo0?ooo`0M0?ooo`008@3oool00`000000oooo0?ooo`180?ooo`030000
003oool0oooo04`0oooo0`3o0?l0103oool0o`000?l0003o0002003o00<0003o9`3oool0103o0?l0
o`000?l0003oool2003o00030000o`3oool0oooo00D0oooo0`3o0?l90?ooo`<0o`002@3oool20?l0
o`040?ooo`00o`000?l0003o00<0oooo0P3o00080?ooo`800?l0203oool30000o`D0oooo00<00000
0?2/P03`[8003`3`[80:0?>]O0030000003c[G`0ljel00<0ljel0P3c[7T70?J^M@030000002W`>/0
Yl3[01H0Yl3[00<0000008]BR02;DXP0102;DXP00`000000nJaP0?V^HP090?V/EP030000003oool0
oooo00<0oooo0`0000001@000?l0o`3o0?l0o`3o0?l0o`0000d0oooo00<000000?ooo`3oool0:03o
ool3000009T0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0M0?ooo`008@3oool0
0`000000oooo0?ooo`190?ooo`030000003oool0oooo04P0oooo0`3o0?l0103oool0o`000?l0003o
0002003o00<0003o:03oool0103o0?l0o`000?l0003oool2003o00030000o`3oool0oooo00@0oooo
0`3o0?l90?ooo`<0o`002P3oool20?l0o`<00?l0103oool20?l000L0oooo0`00o`070?ooo`<0003o
1@3oool30000o`030000003`[800l:b000l0l:b02@3c[G`2000000L0ljel203f[WD00`000000Yl3[
0:O0j`0F0:O0j`030000002;DXP0000000@000000P3i[V890?V/EP030000003oool0oooo00<0oooo
00H0003o0000000000000?l00?l0o`00000?0?ooo`030000003oool0oooo02@0oooo1000002M0?oo
o`030000003oool0oooo03l0oooo00<000000?ooo`3oool07@3oool00240oooo00<000000?ooo`3o
ool0BP3oool00`000000oooo0?ooo`140?ooo`<0o`3o00@0oooo0?l0003o0000o`000P00o`030000
obT0oooo0P3o0?l0103o0000oooo003o0000o`020000o`@0oooo0`3o0?l90?ooo`<0o`002`3oool2
0?l0o`800?l01@3oool20?l000L0oooo0P00o`060?ooo`@0003o1P3oool20000o`<0o`3o00<00000
0?2/P03`[800403`[8050?>]O0<0000000<0ljel0000003c[G`01P3c[G`20?J_MPL0mZie00<00000
0:O0j`2W`>/05P2W`>/6000000<0nJiR203i[5H00`000000oooo0000o`030000o`030?l0o`000000
000000<00000403oool00`000000oooo0?ooo`0P0?ooo`<00000XP3oool00`000000oooo0?ooo`0n
0?ooo`030000003oool0oooo01d0oooo000Q0?ooo`030000003oool0oooo04/0oooo00<000000?oo
o`3oool0@03oool30?l0o`040?ooo`3o0000o`000?l000800?l00`000?l[0?ooo`050?l0o`3o0000
o`000?ooo`00o`000P000?l30?ooo`<0o`3o2@3oool30?l000`0oooo0P3o0?l00`00o`00oooo0?oo
o`040?ooo`80o`001`3oool2003o00D0oooo0`000?l80?ooo`80003o00<0o`3o0?ooo`3oool00P3o
ool00`000000l:b00?2/P00@0?2/P080ljel0`0000040?>]O0030000003c[G`0ljel00D0ljel103f
[gH60?J^M@030000002W`>/0Yl3[01H0Yl3[0P000000103i[V8000000000000000020?V^HPD0nJaF
1@000?l20?l0o`<0oooo1@00000@0?ooo`030000003oool0oooo01d0oooo0`00002U0?ooo`030000
003oool0oooo03h0oooo00<000000?ooo`3oool07@3oool00240oooo00<000000?ooo`3oool0C03o
ool00`000000oooo0?ooo`0l0?ooo`<0o`3o00@0oooo0?l0003o0000o`000P00o`030000ob`0oooo
00@0o`3o0?l0003o0000oooo0P00o`000`000?l0oooo0?ooo`030?l0o`T0oooo0`3o000<0?ooo`03
003o003o0?l0o`3o00L0oooo0P3o00070?ooo`800?l0103oool30000o`P0oooo0`000?l50?ooo`<0
o`3o00<000000?2/P03`[8003P3`[803000000P0ljel00<000000?>]O03c[G`0103c[G`50?J_MPH0
mZie00<000000:O0j`2W`>/0502W`>/4000000060?V^HP00000000000000003i[V80nJaF10000?l4
0?l0o`030000o`3oool0oooo00@0oooo1000000@0?ooo`030000003oool0oooo01X0oooo0`00002Y
0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool07@3oool00200oooo00<000000?oo
o`3oool0CP3oool00`000000oooo0?ooo`0i0?ooo`80o`3o00@0oooo0?l0003o0000o`000P00o`03
0000obd0oooo00@0o`3o0?l0003o0000oooo0P00o`000`000?l0o`3o0?l0o`020?l0o`T0oooo0`3o
000<0?ooo`800?l00P3o0?l60?ooo`<0o`001`3oool2003o00<0oooo0`000?l80?ooo`030?l0o`00
0?l0003o00H0oooo0P3o0?l30?ooo`030000003`[800l:b000/0l:b00`0000000`3`[800ljel0?>]
O0080?>]O0030000003c[G`0ljel00D0ljel1P3f[gH50?J^M@030000002W`>/0Yl3[0100Yl3[2000
00000`3i[V80003o0000o`020000o`D0o`3o0P000?l00`3i[5H000000?ooo`060?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool05`3oool300000:d0oooo00<000000?ooo`3oool0?03o
ool00`000000oooo0?ooo`0M0?ooo`00803oool00`000000oooo0?ooo`1?0?ooo`030000003oool0
oooo03D0oooo0`3o0?l30?l000800?l00`000?l^0?ooo`040?l0o`3o0000o`000?ooo`800?l000<0
003o0?l0o`3o0?l02P3oool30?l000`0oooo0`00o`020?l0o`H0oooo0P3o00070?ooo`<00?l00P3o
ool30000o`P0oooo00@0o`3o0000o`000?l0003o1P3oool20?l0o`D0oooo00<000000?2/P03`[800
203`[803000000@0l:b02P3c[G`00`000000ljel0?>]O0050?>]O0P0mZmf103f[WD00`000000Yl3[
0:O0j`0<0:O0j`X000000P000?l60?l0o`03003o00000?l0nJaF00<0nJaF00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0C0?ooo`<00000/@3oool00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo01d0oooo000P0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0<@3o
ool30?l0o`<0o`000P00o`030000oc00oooo00<0o`3o0?l0003oool00P00o`000`000?l0o`3o0?oo
o`090?ooo`<0o`00303oool3003o00030?ooo`3o0?l0o`3o00H0oooo0P3o00070?ooo`800?l00P3o
ool30000o`P0oooo0P3o0?l20000o`H0oooo0`3o0?l70?ooo`030000003`[800l:b000D0l:b00`00
00070?2/P0/0ljel00<000000?>]O03c[G`0103c[G`90?J_MP@0mZie00<000000:O0j`2W`>/0202W
`>/700000080003o1`0000020?l0o`03003o00000?l0003o00L0nJaF00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`0?0?ooo`@00000]03oool00`000000oooo0?ooo`0l0?ooo`030000003o
ool0oooo01`0oooo000P0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0;@3oool3
0?l0o`<0o`000P00o`030000oc40oooo00D0o`3o0?l0003o0000o`3o003o00020000o`T0oooo0`3o
000<0?ooo`<00?l000@0oooo0?l0o`3o0?l0o`3o1P3oool20?l000L0oooo0P00o`00103oool0003o
0000o`000?l80?ooo`<0o`3o0P000?l60?ooo`80o`3o2P3oool00`000000l:b00?2/P0020?2/P0<0
00002P3`[80;0?>]O0030000003c[G`0ljel00@0ljel2`3f[gH30?J^M@030000002W`>/0Yl3[00@0
Yl3[1P0000030000o`<000000P3o0?l00`000000nJiR0?l0o`0300000080003o2@3i[5H00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo00`0oooo0`00002i0?ooo`030000003oool0oooo03/0
oooo00<000000?ooo`3oool0703oool00200oooo00<000000?ooo`3oool0DP3oool00`000000oooo
0?ooo`0Y0?ooo`<0o`3o0`3o0002003o00<0003o<P3oool0103o0?l0o`000?l0003o0?l2003o0003
0000o`3oool0oooo00H0oooo0`3o000<0?ooo`<00?l00P3oool20?l0o`L0oooo0P3o00070?ooo`80
0?l00`000?l80?ooo`<0o`3o0`000?l50?ooo`<0o`3o3@3oool4000000h0l:b02P3c[G`00`000000
ljel0?>]O0040?>]O0d0mZmf0P3f[WD00`000000Yl3[0:O0j`06000000<0003o0`0000020?l0o`03
0?R_K03i[V8000000080000000<00?l00000000000000P0000020?V^HPP0nJaF00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`080?ooo`<00000_@3oool00`000000oooo0?ooo`0j0?ooo`03
0000003oool0oooo01`0oooo000P0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0
9@3oool30?l0o`<0o`000P00o`030000oc<0oooo00@0o`3o0?l0003o0000o`3o0P00o`000`000?l0
oooo0?ooo`050?ooo`<0o`00303oool3003o00<0oooo0P3o0?l70?ooo`80o`001`3oool2003o0080
003o203oool30?l0o`030?ooo`000?l0003o00H0oooo0P3o0?l@0?ooo`030000003`[800l:b000l0
l:b02`3c[G`00`000000ljel0?>]O0040?>]O0d0mZmf0P3f[WD500000080003o00@0o`0000000000
000000000P3o0?l20?R_K0<0000000D00?l00000o`000000003o0?V^HP0300000080nJiR2@3i[5H0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo0`0000310?ooo`030000003oool0
oooo03T0oooo00<000000?ooo`3oool0703oool00200oooo00<000000?ooo`3oool0E03oool00`00
0000oooo0?ooo`0Q0?ooo`<0o`3o0`3o0002003o00<0003o=03oool0103o0?l0o`000?l0003oool2
003o00030000o`3oool0oooo00@0oooo0`3o000<0?ooo`<00?l0103oool20?l0o`L0oooo0P3o0006
0?ooo`<00?l000<0003o0?ooo`3oool01P3oool30?l0o`040?ooo`000?l0003o0000o`D0oooo0`3o
0?lB0?ooo`030000003a[h<0lJn300L0lJn3203`[80;0?>]O0030000003c[G`0ljel00@0ljel3`3f
[gH2000000030000o`3o0000003o00<000000P3o0?l20?R_K0<0000000<0o`3o000000000?l02000
00020?V^HPT0nJaF00<000000?ooo`3oool0603oool00`000000oooo0?ooo`020?ooo`<00000a03o
ool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo01`0oooo000P0?ooo`030000003oool0
oooo05D0oooo00<000000?ooo`3oool07@3oool30?l0o`<0o`000P00o`030000oc@0oooo0`3o0?l0
1@3o0000oooo003o0000o`00003o00D0oooo0`3o000<0?ooo`<00?l01@3oool20?l0o`L0oooo0P3o
00060?ooo`800?l000<0003o0?ooo`3oool01@3oool40?l0o`80oooo0P000?l60?ooo`80o`3o5@3o
ool00`000000lJn30?6_P`0?0?6_P`X0ljmn00<0ljel0000003c[G`01@3c[G`?0?J_MP030000003o
00000000008000000P3o0?l20?R_K0<0000000<0o`3o000000000?l0200000020:O0j`030000003i
[V80nJiR00T0nJaF00<000000?ooo`3oool06@3oool400000<P0oooo00<000000?ooo`3oool0>03o
ool00`000000oooo0?ooo`0L0?ooo`00803oool00`000000oooo0?ooo`1F0?ooo`030000003oool0
oooo01T0oooo0`3o0?l30?l000800?l00`000?ld0?ooo`@0o`3o0P3o00000`3oool00?l00000o`04
0?ooo`<0o`00303oool3003o00H0oooo0P3o0?l60?ooo`<0o`001@3oool00`000?l00?l0003o0007
0?ooo`<0o`3o103oool20000o`H0oooo0P3o0?lH0?ooo`030000003a[h<0lJn300h0lJn32`3c[gh0
0`000000ljmn0?>_OP040?>_OPT0mZmg1P3f[gH200000080o`3o00<0oooo0000000000000P000000
0`3o0?l00?l00000o`0;000000040:O0j`000000000000000080nJiR203i[5H00`000000oooo0?oo
o`0G0?ooo`<00000c03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01`0oooo000O
0?ooo`030000003oool0oooo05P0oooo0P00000F0?ooo`<0o`3o0`3o0002003o00<0003o=03oool3
0?l0o`050?ooo`3o0?l0o`000?l0003oool00P00o`000`000?l0oooo0?ooo`030?l000`0oooo0`00
o`070?ooo`80o`3o1P3oool20?l000D0oooo0P000?l2003o00H0oooo0`3o0?l40?ooo`<0003o1@3o
ool30?l0oaX0oooo00<000000?6_P`3a[h<03`3a[h<;0?>_OP030000003c[gh0ljmn00<0ljmn3`3f
[gL00`000000oooo0?ooo`0300000080o`3o00<0n:m/0000000000002@00000208]BR0@0000000<0
Yl3[0000003i[V802@3i[5H00`000000oooo0?ooo`0B0?ooo`@000000P3oool00`000000oooo0?oo
o`3;0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0703oool001l0oooo00<00000
0?ooo`3oool0FP3oool00`000000oooo0?ooo`0@0?ooo`<0o`3o0`3o0002003o00<0003o=03oool3
0?l0o`80oooo00@0o`3o0?l0003o0000oooo0P00o`000`000?l0oooo0?l000020?l000`0oooo0`00
o`080?ooo`80o`3o1P3oool20?l000@0oooo0P000?l3003o00D0oooo0`3o0?l50?ooo`80003o1P3o
ool20?l0oaX0oooo1000000A0?6_P`/0ljmn00<000000?>_OP3c[gh0103c[gh?0?J_M`<0000000<0
o`3o0000000000002P00000508]BR0800000102W`>/00`000000nJaF0?V/EP070?V/EP030000003o
ool0oooo00l0oooo100000050?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool0=P3o
ool00`000000oooo0?ooo`0L0?ooo`007`3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0
oooo00`0oooo0`3o0?l30?l000800?l00`000?ld0?ooo`<0o`3o103oool20?l000040?ooo`00o`00
0?l00000o`<0o`00303oool3003o00T0oooo0P3o0?l60?ooo`80o`000P3oool40000o`800?l01@3o
ool30?l0o`H0oooo0P000?l50?ooo`<0o`3o603oool4000000@0oooo00<000000?6_P`3a[h<03P3a
[h<;0?>_OP030000003c[gh0ljmn00@0ljmn3P3f[gL00`3f/7P000000?l0o`0;000000P0Re:800<0
00000:O0j`2W`>/0102W`>/00`000000nJaF0?V/EP060?V/EP030000003oool0oooo00`0oooo1000
00080?ooo`030000003oool0oooo0<`0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?oo
o`0K0?ooo`007`3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo00P0oooo0`3o0?l3
0?l000800?l00`000?ld0?ooo`<0o`3o1@3oool00`3o0?l0o`000?ooo`02003o00030000o`3o0000
o`0000`0oooo0`00o`0:0?ooo`80o`3o1P3oool20?l000040?ooo`000?l0003o0000o`80oooo0P00
o`040?ooo`<0o`3o1P3oool30000o`D0oooo0P3o0?lH0?ooo`<00000203oool00`000000lJn30?6_
P`0?0?6_P`/0ljmn00<000000?>_OP3c[gh00`3c[gh<0?J_M`<0m[1h0P0000000`000?l000000000
0005000000/0Re:800<000000:O0j`2W`>/01@2W`>/00`000000nJaF0?V/EP060?V/EP030000003o
ool0oooo00P0oooo1000000<0?ooo`030000003oool0oooo0<`0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0K0?ooo`007`3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0
oooo00@0oooo0`3o0?l30?l000800?l00`000?ld0?ooo`<0o`3o1P3oool01`3o0?l0o`000?l0003o
ool00?l00000o`3o0000303oool3003o00/0oooo0P3o0?l60?ooo`80o`000`000?l30?ooo`800?l0
0`3oool30?l0o`L0oooo0P000?l50?ooo`<0o`3o5`3oool3000000/0oooo00<000000?6_P`3a[h<0
3`3a[h<;0?>_OP030000003c[gh0ljmn00@0ljmn2@3f[gL50?J`N0040?JaN000000000000?ooo`<0
00003P2;DXP00`000000Yl3[0:O0j`060:O0j`030000003i[5H0nJaF00D0nJaF00<000000?ooo`3o
ool01@3oool4000000l0oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo01/0oooo000O0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0
0`3o0?l30?l000800?l00`000?ld0?ooo`<0o`3o1`3oool0103o0?l0o`000?l0003o0002003o0003
0000o`3oool0oooo00T0oooo0`00o`0<0?ooo`80o`3o1P3oool20?l00080003o103oool2003o0080
oooo0`3o0?l70?ooo`<0003o1@3oool20?l0oaL0oooo0`00000>0?ooo`030000003a[h<0lJn300l0
lJn32`3c[gh00`000000ljmn0?>_OP040?>_OPL0mZmg1`3f/7P0103f/GP0mk9h00000000000A08]B
R0030000002W`>/0Yl3[00L0Yl3[00<000000?V/EP3i[5H0103i[5H00`000000oooo0?ooo`020?oo
o`@000004P3oool00`000000oooo0?ooo`3=0?ooo`030000003oool0oooo03@0oooo00<000000?oo
o`3oool06`3oool001l0oooo00<000000?ooo`3oool0GP3oool30?l0o`030?ooo`3o0000o`000080
0?l00`000?ld0?ooo`<0o`3o203oool0103o0?l0o`000?l0003o0002003o00030000o`3oool0oooo
00P0oooo0`00o`0=0?ooo`80o`3o1@3oool30?l000030000o`3oool0oooo0080oooo0`00o`00103o
ool0o`3o0?l0o`3o0?l80?ooo`80003o1@3oool30?l0oaH0oooo0`00000B0?ooo`030000003a[h<0
lJn300l0lJn32`3c[gh00`000000ljmn0?>_OP030?>_OPH0mZmg1`3f/7P20?JaN0030?NbN0000000
Re:80140Re:800<000000:O0j`2W`>/0202W`>/00`000000nk1K0?^`F`040?V/EPD000005@3oool0
0`000000oooo0?ooo`3>0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool06`3oool0
01l0oooo00<000000?ooo`3oool0F`3oool30?l0o`050?ooo`3o0000o`000?l00000o`000`000?ld
0?ooo`<0o`3o2P3oool00`3o0?l0o`000?l00002003o00030000o`3oool0oooo00L0oooo0`00o`0=
0?ooo`<0o`3o1@3oool20?l000030000o`3oool0oooo00<0oooo0P00o`00103oool0o`3o0?l0o`3o
0?l90?ooo`80003o1@3oool20?l0oaH0oooo0`00000E0?ooo`030000003a[h<0lJn300l0lJn32`3c
[gh00`000000ljmn0?>_OP040?>_OP<0mZmg2@3f/7P20?JaN0030?NbN0000000Re:80140Re:800<0
00000:O0j`2W`>/0202W`>/010000000nk1K0?^`F`3k/5/5000001P0oooo00<000000?ooo`3oool0
c`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo01/0oooo000O0?ooo`030000003o
ool0oooo05P0oooo0`3o0?l01@3oool0o`000?l0003o00000?l000<0003o=03oool30?l0o`X0oooo
00@0o`000?l0o`3o0000o`000P00o`000`000?l0oooo0?ooo`060?ooo`<00?l03P3oool20?l0o`D0
oooo00<0003o0?l0003o00001P3oool2003o00<0o`3o2@3oool30000o`D0oooo0P3o0?lE0?ooo`<0
0000603oool00`000000lJn30?6_P`0?0?6_P`/0ljmn00<000000?>_OP3c[gh0103c[gh00`3f[gL0
m[1h0?J`N0080?J`N080m[5h0P3g/WP00`000000Re:808]BR00@08]BR0030000002W`>/0Yl3[00T0
Yl3[0`0000030?^`F`030000003oool0oooo01P0oooo00<000000?ooo`3oool0cP3oool00`000000
oooo0?ooo`0b0?ooo`030000003oool0oooo01/0oooo000N0?ooo`030000003oool0oooo05H0oooo
0`3o0?l01@3oool0o`000?l0003o00000?l000<0003o0P3oool00`000000oooo0?ooo`0_0?ooo`<0
o`3o2@3oool30?l000060?l0o`3o0000o`000?ooo`00o`00003o1`3oool3003o00l0oooo0P3o0?l4
0?ooo`80003o0P3o00060?ooo`800?l000<0o`3o0?ooo`3oool02@3oool20000o`D0oooo0`3o0?lD
0?ooo`<000006@3oool20?l0o`030000003a[h<0lJn300l0lJn32`3c[gh00`000000ljmn0?>_OP03
0?>_OP030?BaO`3f/7P0m[1h00P0m[1h0`3f/GP20?NbN0030000002;DXP0Re:80100Re:800<00000
0:O0j`2W`>/01P2W`>/3000000030:O0j`000000nk1K00<0nk1K00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`3?0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool06`3oool0
01h0oooo00<000000?ooo`3oool0D`3oool30?l0o`050?ooo`3o0000o`000?l00000o`000`000?l6
0?ooo`030000003oool0oooo02/0oooo0`3o0?l90?ooo`<0o`0000D0oooo0?l0o`3o0000o`000?oo
o`02003o00H0oooo0`00o`0@0?ooo`80o`3o0`3oool30000o`80o`001@3oool00`3o0?l00?l0003o
000<0?ooo`80003o1@3oool20?l0oa@0oooo0`00000H0?ooo`@0o`3o00@00?l00?ooo`3oool00000
4@3a[h<;0?>_OP030000003c[gh0ljmn00@0m;5o2@3f/7P30?JaN080mk9h00<0000008]BR02;DXP0
402;DXP00`000000Yl3[0:O0j`030:O0j`<000001@2W`>/00`000000nk1K0?^`F`020?^`F`030000
003oool0oooo01L0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo01X0oooo000N0?ooo`030000003oool0oooo0500oooo0`3o0?l01@3oool0o`000?l0
003o00000?l000<0003o2P3oool00`000000oooo0?ooo`0W0?ooo`<0o`3o2@3oool30?l000<0oooo
0P3o0000103oool00?l0003o00000?l40?ooo`<00?l04@3oool20?l0o`80oooo0`000?l00`3oool0
o`000?l000040?ooo`040?l0o`00o`000?l0003o00/0oooo0`000?l40?ooo`<0o`3o4`3oool30000
01L0oooo103o0?l00`00o`00oooo0?ooo`020?ooo`80o`3o00<000000?6_P`3a[h<03`3a[h<;0?>_
OP030000003c[gh0m;5o00@0m;5o203f/7P40?JaN080mk9h00<0000008]BR02;DXP0402;DXP00`00
0000Yl3[0:O0j`03000000T0Yl3[00D000000?^`F`3k/5/0nk1K0000000I0?ooo`030000003oool0
oooo0=40oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0J0?ooo`007P3oool00`00
0000oooo0?ooo`1=0?ooo`<0o`3o00D0oooo0?l0003o0000o`00003o00030000o`h0oooo00<00000
0?ooo`3oool08`3oool30?l0o`T0oooo0`3o00040?ooo`030?l0o`3o0000oooo00800?l000@0003o
0?ooo`3oool0oooo0`00o`0B0?ooo`80o`3o00@0oooo0000o`000?l0003o0P3oool20?l000<0oooo
0P3o0?l2003o00`0oooo0P000?l50?ooo`80o`3o4`3oool3000001H0oooo103o0?l00`00o`00oooo
0?ooo`020?ooo`@0o`3o00<0o`00003o000000004@3a[h<;0?>_OP030000003d/Gl0m;5o00@0m;5o
203f/7P40?JaN080mk9h00<0000008]BR02;DXP0402;DXP3000000d0Yl3[00@000000?^`F`3k/5/0
00006@3oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3o
ool06P3oool001h0oooo00<000000?ooo`3oool0BP3oool30?l0o`050?ooo`3o0000o`000?l00000
o`000`000?lB0?ooo`030000003oool0oooo01l0oooo0`3o0?l90?ooo`<0o`001@3oool00`3o0?l0
o`000?l00002003o00030000o`3oool0oooo00<00?l04`3oool20?l0o`<0003o0P3oool30?l00080
oooo0`3o0?l2003o00/0oooo0`000?l40?ooo`<0o`3o4P3oool3000001D0oooo103o0?l00`00o`00
oooo0?ooo`020?ooo`@0o`3o00<0o`00003o0000o`000P000?l20?l0o`030000003a[h<0lJn300l0
lJn3203c[gh30?BaO`030000003d/Gl0m;5o00@0m;5o1P3f/7P40?JaN0<0mk9h00<0000008]BR02;
DXP03@2;DXP400000100Yl3[00<000000?^`F`0000006P3oool00`000000oooo0?ooo`3A0?ooo`03
0000003oool0oooo02l0oooo00<000000?ooo`3oool06P3oool001h0oooo00<000000?ooo`3oool0
A`3oool30?l0o`050?ooo`3o0000o`000?l00000o`000`000?lF0?ooo`030000003oool0oooo01/0
oooo0`3o0?l90?ooo`<0o`001P3oool01`3o0?l0o`000?l0003oool00?l00000o`3oool00`00o`0D
0?ooo`80o`3o0P000?l30?ooo`80o`000P3oool30?l0o`030?ooo`00o`000?l000/0oooo0P000?l5
0?ooo`80o`3o4@3oool4000001@0oooo103o0?l00`00o`00oooo0?ooo`020?ooo`@0o`3o00<0o`00
003o0000o`000P000?l30?l0o`<0oooo00<000000?6_P`3a[h<03`3a[h<70?>_OP@0m;5o00<00000
0?BaO`3d/Gl0103d/Gl60?J`N0@0m[5h0`3g/WP00`000000Re:808]BR00908]BR0@000000`2;DXP0
0`000000Yl3[0:O0j`0?0:O0j`030000003k/5/0000001T0oooo00<000000?ooo`3oool0dP3oool0
0`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01X0oooo000N0?ooo`030000003oool0oooo
04@0oooo0`3o0?l01@3oool0o`000?l0003o00000?l000<0003o6P3oool00`000000oooo0?ooo`0G
0?ooo`<0o`3o2@3oool30?l000L0oooo00@0o`3o0?l0003o0000oooo1@00o`0D0?ooo`040000o`3o
0?l0o`3o0000o`@0oooo0P3o00001@3oool0o`3o0?l0o`3o0?l0oooo00<00?l02`3oool20000o`@0
oooo0`3o0?l@0?ooo`<00000503oool40?l0o`03003o003oool0oooo00<0oooo0`3o0?l20?l00080
0?l00P000?l30?l0o`H0oooo00<000000?6_P`3a[h<03`3a[h<50?>_OPH0m;5o00<000000?BaO`3d
/Gl0103d/Gl50?J`N0D0m[5h0`3g/WP00`000000Re:808]BR00608]BR0<000001`2;DXP00`000000
Yl3[0:O0j`0@0:O0j`8000006@3oool00`000000oooo0?ooo`3C0?ooo`030000003oool0oooo02d0
oooo00<000000?ooo`3oool06P3oool001h0oooo00<000000?ooo`3oool0@@3oool30?l0o`050?oo
o`3o0000o`000?l00000o`000`000?lN0?ooo`800000503oool30?l0o`T0oooo0`3o00090?ooo`80
o`0000D0oooo003o0000o`00003o003o000D0?ooo`80003o0P3o0?l50?ooo`80o`000`3o0?l20?oo
o`800?l02`3oool30000o`@0oooo0P3o0?l@0?ooo`<000004`3oool40?l0o`03003o003oool0oooo
00<0oooo103o0?l00`3o00000?l0003o00020000o`<0o`3o2P3oool00`000000lJn30?6_P`0@0?6_
P`80ljmn2@3d/Gl00`000000m;5o0?BaO`040?BaO`@0m[1h1@3f/GP30?NbN0030000002;DXP0Re:8
00<0Re:80`00000:08]BR0030000002W`>/0Yl3[0100Yl3[0P00000I0?ooo`030000003oool0oooo
0=<0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0J0?ooo`007P3oool00`000000
oooo0?ooo`0n0?ooo`<0o`3o00D0oooo0?l0003o0000o`00003o00030000ob<0oooo00<000000?oo
o`3oool03P3oool30?l0o`T0oooo0`3o000:0?ooo`030?l0o`3o0000oooo00800?l000<0003o0?oo
o`3oool04P3oool30000o`80o`3o1@3oool20?l00080o`3o0`3oool2003o00/0oooo0P000?l50?oo
o`80o`3o3`3oool300000180oooo103o0?l00`00o`00oooo0?ooo`030?ooo`@0o`3o00<0o`00003o
0000o`000`000?l30?l0o`h0oooo00<000000?6_P`3a[h<03`3a[h<00`3c[gh0m;5o0?BaO`060?Ba
O`<000001P3d/Gl30?J`N0D0m[5h103g/WP00`000000Re:808]BR003000000d0Re:800<000000:O0
j`2W`>/04@2W`>/00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0=@0oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`0J0?ooo`007@3oool00`000000oooo0?ooo`0l0?ooo`<0
o`3o00D0oooo0?l0003o0000o`00003o00030000obL0oooo00<000000?ooo`3oool02P3oool30?l0
o`T0oooo0`3o000;0?ooo`030?l0o`3o0000o`0000800?l000<0003o0?ooo`3oool04@3oool30000
o`030?ooo`3o0?l0o`3o00@0oooo00<0o`3o0?l0003o00001@3oool2003o00/0oooo0P000?l40?oo
o`<0o`3o3P3oool300000140oooo103o0?l00`00o`00oooo0?ooo`030?ooo`@0o`3o0P3o0002003o
0080003o0`3o0?lA0?ooo`030?l0o`000000lJn300l0lJn300<0l[660?BaO`3d/Gl0103d/Gl30000
0080m;5o00<000000?BaO`3d/Gl0103d/Gl20?J`N0H0m[5h103g/WP300000100Re:800<000000:O0
j`2W`>/04P2W`>/00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0=@0oooo00<000000?oo
o`3oool0:`3oool00`000000oooo0?ooo`0J0?ooo`007@3oool00`000000oooo0?ooo`0i0?ooo`<0
o`3o00D0oooo0?l0003o0000o`00003o00030000ob/0oooo00<000000?ooo`3oool01P3oool30?l0
o`T0oooo0`3o000<0?ooo`030?l0o`3o0000o`0000800?l000<0003o0?ooo`3oool0403oool30000
o`80oooo0P3o0?l30?ooo`80o`3o0P3o00050?ooo`800?l02P3oool30000o`@0oooo0P3o0?l>0?oo
o`<00000403oool40?l0o`03003o003oool0oooo00@0oooo0`3o0?l20?l000800?l00`000?l20?l0
oa80oooo0`3o0?l00`000?l000000?6_P`0=0?6_P`@0l[660P3d/Gl3000000H0m;5o00<000000?Ba
O`3d/Gl0103d/Gl00`3f/7P0m[5h0?JaN0040?JaN0030?NbN00000000000008000004P2;DXP00`00
0000Yl3[0:O0j`0C0:O0j`030000003oool0oooo01H0oooo00<000000?ooo`3oool0e@3oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo01T0oooo000M0?ooo`030000003oool0oooo03H0
oooo0`3o0?l01@3oool0o`000?l0003o00000?l000<0003o;`3oool010000000oooo0?ooo`3oool4
0?l0o`T0oooo0`3o000=0?ooo`04003o003o0000o`000?ooo`800?l04@3oool30000o`<0oooo0P3o
0?l20?ooo`<0o`3o0P3o00040?ooo`<00?l02P3oool20000o`@0oooo0`3o0?l=0?ooo`<000003`3o
ool40?l0o`03003o003oool0oooo00@0oooo103o0?l00`3o00000?l0003o00030000o`<0o`3o4P3o
ool30?l0o`050000o`3o0000o`000?l0o`000000303a[h<40?:aQP@000002@3d/Gl00`000000m;5o
0?BaO`040?BaO`D0m[5h0`0000030?NbN0030000002;DXP0Re:80100Re:800<000000:O0j`2W`>/0
502W`>/00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`0I0?ooo`007@3oool00`000000oooo0?ooo`0c0?ooo`<0o`3o00D0
oooo0?l0003o0000o`00003o00030000oc<0oooo0`3o0?l:0?ooo`<0o`003@3oool2003o0080o`00
00<0oooo003o0000o`00403oool30000o`<0oooo0`3o0?l0103oool0o`3o0?l0o`3o0?l30?l000@0
oooo0P00o`0:0?ooo`<0003o103oool20?l0o`d0oooo0`00000>0?ooo`@0o`3o00<00?l00?ooo`3o
ool0103oool40?l0o`80o`000P00o`030000o`80o`3o4`3oool30?l0o`050000o`3o0000o`000?l0
003o0?l00`3oool00`000000lJn30?6_P`070?6_P`<0l[660`0000030?:aQPX0m;5o00<000000?Ba
O`3d/Gl0103d/Gl00`3e/h0000000000000200000080m[5h103g/WP00`000000Re:808]BR00@08]B
R0030000002W`>/0Yl3[01D0Yl3[00<000000?ooo`3oool0503oool00`000000oooo0?ooo`3F0?oo
o`030000003oool0oooo02X0oooo00<000000?ooo`3oool06@3oool001d0oooo00<000000?ooo`3o
ool0<03oool30?l0o`050?ooo`3o0000o`000?l00000o`000`000?lc0?ooo`<0o`3o00<0oooo0000
003oool01`3oool30?l000d0oooo0`00o`000`3o0?l0o`000?ooo`02003o00030000o`3oool0oooo
00`0oooo0`000?l40?ooo`80o`3o00D0oooo0?l0o`3o0?l0o`3o0?ooo`020?l000D0oooo0P00o`0:
0?ooo`80003o103oool30?l0o``0oooo0`00000=0?ooo`@0o`3o00<00?l00?ooo`3oool0103oool4
0?l0o`80o`000P00o`030000o`<0o`3o503oool20?l0o`050000o`3o0000o`000?l0003o0?l00`3o
ool30000o`030000003a[h<0lJn300D0lJn300<0l[660000000000000P0000060?:aQP/0m;5o00@0
00000?BaO`3d/Gl0m;5o0`0000000`3e/h00m[5h0?JaN0020?JaN0D0mk9h00<0000008]BR02;DXP0
402;DXP2000001L0Yl3[00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3G0?ooo`030000
003oool0oooo02T0oooo00<000000?ooo`3oool06@3oool001d0oooo00<000000?ooo`3oool0;@3o
ool30?l0o`050?ooo`3o0000o`000?l00000o`000`000?lc0?ooo`<0o`3o1@3oool00`000000oooo
0?ooo`020?ooo`<0o`003@3oool3003o00040?ooo`3o0?l0o`000?l000800?l000<0003o0?ooo`3o
ool02`3oool30000o`D0oooo1@3o0?l20?ooo`80o`001@3oool2003o00X0oooo0P000?l40?ooo`80
o`3o303oool3000000`0oooo103o0?l00`00o`00oooo0?ooo`050?ooo`<0o`3o0P3o0003003o00<0
003o0P3o0?lE0?ooo`<0o`3o00@0003o0?l0003o0000o`3o103oool20000o`04003o003oool0oooo
000000D0lJn30`00000:0?:aQP/0m;5o100000040?FcP0@0m[5h1@3g/WP00`000000Re:808]BR00@
08]BR0800000602W`>/00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0=L0oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`0I0?ooo`007@3oool00`000000oooo0?ooo`0Z0?oo
o`<0o`3o00D0oooo0?l0003o0000o`00003o00030000oc<0oooo0`3o0?l90?ooo`040000003o0000
o`000?l000d0oooo0`00o`030?ooo`80o`0000<0oooo003o00000?l0303oool30000o`H0oooo103o
0?l30?ooo`80o`001@3oool2003o00T0oooo0`000?l30?ooo`<0o`3o2`3oool3000000/0oooo103o
0?l00`00o`00oooo0?ooo`050?ooo`@0o`3o0P3o0002003o00<0003o0`3o0?lE0?ooo`<0o`3o00D0
003o0?l0003o0000o`000?l0o`030?ooo`<0003o00<0o`3o0?ooo`3oool00`3oool00`000000lJn3
00000002000000h0l[66203d/Gl400000080m;5o1@3e/h030?JaN0D0mk9h00<0000008]BR02;DXP0
402;DXP00`000000nkA]0000000H0:O0j`030000003oool0oooo0180oooo00<000000?ooo`3oool0
e`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01T0oooo000M0?ooo`030000003o
ool0oooo02L0oooo0`3o0?l01@3oool0o`000?l0003o00000?l000<0003o<`3oool30?l0o`X0oooo
0`3o00000`000000oooo0?ooo`0:0?ooo`<00?l0103oool20?l000030?ooo`00o`000?l000/0oooo
0`000?l70?ooo`<0o`3o103oool20?l000@0oooo0`00o`090?ooo`80003o103oool20?l0o`X0oooo
1000000:0?ooo`@0o`3o00<00?l00?ooo`3oool01@3oool40?l0o`80o`000P00o`040000o`80o`3o
5P3oool30?l0o`050000o`3o0000o`000?l0003o0?l0103oool20000o`03003o003oool0oooo00H0
oooo0P00000A0?:aQPD0m;5o0`0000030?BaO`030000003d/Gl0mK>000D0mK>00`3f/GP50?NbN003
0000002;DXP0Re:80100Re:800@000000?^dK@00000000005`2W`>/00`000000oooo0?ooo`0A0?oo
o`800000fP3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo01T0oooo000M0?ooo`03
0000003oool0oooo02@0oooo0`3o0?l01@3oool0o`000?l0003o00000?l000<0003o<`3oool30?l0
o`X0oooo0`3o00040?ooo`030000003oool0oooo00H0oooo0`00o`050?ooo`030?l0o`3o0000oooo
00800?l02P3oool30000o`L0oooo0`3o0?l50?ooo`80o`00103oool2003o00T0oooo0`000?l40?oo
o`80o`3o2@3oool3000000X0oooo103o0?l00`00o`00oooo0?ooo`050?ooo`@0o`3o0P3o0003003o
00<0003o0`3o0?lF0?ooo`<0o`3o00D0003o003o003o0000o`000?l0o`040?ooo`<0003o00<0o`3o
0?ooo`3oool0203oool00`000000l[660?:aQP0A0?:aQP040?BaO`0000000000000000H0m;5o00<0
00000?FcP03e/h001P3e/h020?JaN0D0mk9h00<0000008]BR02;DXP0402;DXP010000000nkA]0000
0000000H0:O0j`030000003oool0oooo00d0oooo0`0000000`3oool000000?ooo`3J0?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool06@3oool001`0oooo00<000000?ooo`3oool08P3o
ool30?l0o`050?ooo`3o0000o`000?l00000o`000`000?lc0?ooo`<0o`3o2P3oool30?l000P0oooo
00<000000?ooo`3oool00P3oool3003o00H0oooo00<0o`3o0?l0003o00000P00o`090?ooo`<0003o
1P3oool50?l0o`D0oooo0P3o00040?ooo`800?l02@3oool20000o`@0oooo0`3o0?l80?ooo`<00000
2@3oool40?l0o`03003o003oool0oooo00H0oooo0`3o0?l30?l000800?l010000?l20?l0oaL0oooo
0`3o0?l00`000?l00?l00?l000020?l000030?l0o`3oool0oooo0080oooo0P000?l00`3o0?l0oooo
0?ooo`0<0?ooo`030000003b/HH0l[6600d0l[661000000:0?BaO`030000003e/h00mK>000H0mK>0
1P3g/WP00`000000Re:808]BR00@08]BR0050000003k]6d0nkA]0?^dK@000000602W`>/00`000000
oooo0?ooo`090?ooo`<00000103oool00`000000oooo0?ooo`3J0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool06@3oool001`0oooo00<000000?ooo`3oool07`3oool30?l0o`050?oo
o`3o0000o`000?l00000o`000`000?lc0?ooo`<0o`3o2P3oool30?l000`0oooo00@00000003o0000
o`000?l01`3oool00`3o0?l0o`000?l00002003o00030000o`3oool0oooo00@0oooo10000?l60?oo
o`<0o`3o00<0oooo0?l0o`3o0?l0103oool30?l000@0oooo0P00o`090?ooo`80003o103oool20?l0
o`P0oooo0`0000080?ooo`@0o`3o00<00?l00?ooo`3oool01P3oool40?l0o`80o`000`00o`030000
o`<0o`3o5`3oool30?l0o`030000o`00o`00o`000080o`0000<0o`3o0?ooo`3oool00P3oool30000
o`030?l0o`3oool0oooo00h0oooo00<000000?:aQP3b/HH02P3b/HH3000000@0l[662@3d/Gl00`3e
/h0000000?FcP0070?FcP0D0mk9h00<0000008]BR02;DXP04@2;DXP01P000000nkA]0?^dK@3k]6d0
nk9Y000001P0Yl3[00<000000?ooo`3oool01@3oool3000000L0oooo00<000000?ooo`3oool0fP3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01P0oooo000L0?ooo`030000003oool0
oooo01`0oooo0`3o0?l01@3oool0o`000?l0003o00000?l000<0003o<`3oool30?l0o`X0oooo0`3o
000=0?ooo`<00?l000<000000?ooo`3oool01P3oool20?l000800?l000<0003o0?ooo`3oool00`3o
ool30000o`L0oooo0`3o0?l20?ooo`80o`3o103oool20?l000@0oooo0`00o`080?ooo`<0003o0`3o
ool30?l0o`L0oooo0`0000060?ooo`D0o`3o00<00?l00?ooo`3oool01P3oool40?l0o`80o`000`00
o`040000o`80o`3o6@3oool20?l0o`80003o00@00?l00?l0003o0000o`3o1@3oool20000o`030?l0
o`3oool0oooo0180oooo00<000000?:aQP3b/HH01P3b/HH3000000L0l[66203d/Gl30?FcP0030000
003e/h00mK>000D0mK>000<0m[B00?NbN03g/WP00P3g/WP00`000000Re:808]BR00A08]BR0030000
003k]6d0nkA]0080nkA]00<000000:O0j`2W`>/05`2W`>/010000000oooo0?ooo`3oool3000000X0
oooo00<000000?ooo`3oool0f`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo01P0
oooo000L0?ooo`030000003oool0oooo01T0oooo0`3o0?l01@3oool0o`000?l0003o00000?l000<0
003o<`3oool30?l0o`X0oooo0`3o000=0?ooo`<00?l0103oool00`000000oooo0?ooo`030?ooo`80
o`0000<0oooo003o00000?l0103oool30000o`L0oooo0`3o0?l30?ooo`80o`3o103oool20?l000@0
oooo0P00o`090?ooo`80003o103oool20?l0o`L0oooo0`0000050?ooo`@0o`3o0P00o`080?ooo`@0
o`3o0`3o0002003o00040?ooo`000?l0003o0000o`<0o`3o6@3oool30?l0o`030000o`00o`00o`00
0080o`0000<0o`3o0?ooo`3oool00P3oool30000o`030?l0o`3oool0oooo01@0oooo00<000000?:a
QP3b/HH00`3b/HH3000000/0l[661P3d/Gl40?FcP0030000003e/h00mK>000D0mK>00P3f]8030?Nb
N0030000002;DXP0Re:80140Re:800<000000?^dK@3k]6d00`3k]6d00`000000Yl3[0:O0j`0G0:O0
j`<000003@3oool00`000000oooo0?ooo`3L0?ooo`030000003oool0oooo02@0oooo00<000000?oo
o`3oool0603oool001`0oooo00<000000?ooo`3oool05P3oool30?l0o`050?ooo`3o0000o`000?l0
0000o`000`000?lc0?ooo`<0o`3o2P3oool30?l000d0oooo0`00o`080?ooo`80000000@0oooo0?l0
o`3o0000oooo0P00o`030?ooo`<0003o1`3oool30?l0o`@0oooo0P3o0?l40?ooo`80o`00103oool2
003o00T0oooo0P000?l30?ooo`<0o`3o1P3oool3000000@0oooo103o0?l3003o00P0oooo0`3o0?l3
0?l000<00?l010000?l20?l0oaX0oooo0`3o0?l00`000?l00?l00?l000020?l000030?l0o`3oool0
oooo00<0oooo0P000?l00`3o0?l0oooo0?ooo`0G0?ooo`030000003b/HH0l[6600<000003P3b/HH6
0?BaO`@0mK>000<000000?FcP03e/h00103e/h040?JdP080mk9h00<0000008]BR02;DXP04@2;DXP0
0`000000nkA]0?^dK@040?^dK@800000602W`>/00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo0=d0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0H0?ooo`00703oool00`00
0000oooo0?ooo`0C0?ooo`<0o`3o00D0oooo0?l0003o0000o`00003o00030000oc<0oooo0`3o0?l:
0?ooo`<0o`003@3oool3003o00`0oooo00<0o`3o0?l0003o00000P00o`020?ooo`<0003o1`3oool3
0?l0o`D0oooo0P3o0?l40?ooo`80o`00103oool2003o00P0oooo0`000?l30?ooo`80o`3o1P3oool3
000000<0oooo103o0?l3003o00P0oooo103o0?l20?l000<00?l000@0oooo0000o`000?l0003o0`3o
0?lJ0?ooo`<0o`3o00<0003o003o0000o`000P3o00000`3o0?l0oooo0?ooo`030?ooo`<0003o00<0
o`3o0?ooo`3oool06@3oool300000140l[661@3d/Gl60?FcP0030000003e/h00mK>000<0mK>0103f
]8020?NbN0030000002;DXP0Re:80140Re:800D000000?^dK@3k]6d0nkA]003o00020?^dK@800000
6@2W`>/00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0=`0oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`0H0?ooo`00703oool00`000000oooo0?ooo`0@0?ooo`<0o`3o00D0
oooo0?l0003o0000o`00003o00030000oc<0oooo0`3o0?l:0?ooo`<0o`003@3oool3003o00h0oooo
0P3o0002003o00@0003o1`3oool30?l0o`H0oooo0P3o0?l40?ooo`80o`00103oool2003o00P0oooo
0P000?l40?ooo`80o`3o1@3oool300000080oooo103o0?l3003o00P0oooo103o0?l30?l000<00?l0
10000?l20?l0oa/0oooo0`3o0?l00`000?l00?l0003o00030?l000030?l0o`3oool0oooo00<0oooo
0P000?l00`3o0?l0oooo0?ooo`0I0?ooo`<0000000<0oooo0000003b/HH04P3b/HH30?BaO`L0mK>0
00<000000?FcP03e/h000`3e/h050?JdP0030?NbN0000000Re:80180Re:800<000000?^dK@3k]6d0
1@3k]6d00`000000Yl3[0:O0j`0H0:O0j`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
g@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01P0oooo000L0?ooo`030000003o
ool0oooo00d0oooo0`3o0?l01@3oool0o`000?l0003o00000?l000<0003o<`3oool30?l0o`X0oooo
0`3o000=0?ooo`<00?l03`3oool20?l000800?l00`000?l70?ooo`<0o`3o1P3oool30?l0o`@0oooo
0P3o00030?ooo`<00?l01`3oool30000o`<0oooo0`3o0?l40?ooo`<0000000<0oooo0?l0o`3o0?l0
0P3o0?l3003o00T0oooo0`3o0?l30?l000<00?l000@0oooo0000o`000?l0003o0`3o0?lK0?ooo`<0
o`3o0P000?l01@00o`00o`000?l0003o0000o`3o00D0oooo0`000?l00`3o0?l0oooo0?ooo`0G0?oo
o`@000001@3oool00`000000l[660?:aQP0@0?:aQP<0m;5o1`3e/h000`000000mK>00?FcP0020?Fc
P0L0m[B000<0000008]BR02;DXP04@2;DXP00`000000nkIb0?^dK@060?^dK@030000002W`>/0Yl3[
01L0Yl3[00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3N0?ooo`030000003oool0oooo
0240oooo00<000000?ooo`3oool0603oool001`0oooo00<000000?ooo`3oool0303oool00`3o0?l0
oooo0?l000020?l00004003o00000?l0003o0000oc<0oooo0`3o0?l:0?ooo`<0o`003@3oool3003o
0100oooo0P3o0000103oool00?l00000o`000?l30?ooo`040000003oool0oooo0?ooo`<0o`3o1`3o
ool20?l0o`@0oooo0`3o00030?ooo`800?l0203oool20000o`@0oooo0P3o0?l40?ooo`<00000103o
0?l3003o00T0oooo103o0?l30?l000800?l00P3oool30000o`80o`3o703oool30?l0o`80003o00@0
0?l00?l0003o0000o`000P3o0?l50?ooo`80003o00<0o`3o0?ooo`3oool05`3oool3000000T0oooo
00<000000?:aQP3b/HH04@3b/HH00`3d/Gl0mK>00?FcP0070?FcP0040000003e/h00mK>00?FcP0L0
m[B000<0000008]BR02;DXP04@2;DXP00`000000nkIb0?^dK@060?^dK@<00000602W`>/00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo0=h0oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`0H0?ooo`006`3oool00`000000oooo0?ooo`0>0?ooo`030?l00000o`00003o0080003o
<`3oool30?l0o`X0oooo0`3o000=0?ooo`<00?l04@3oool00`3o0?l0o`000000o`02003o00L0oooo
0`3o0?l80?ooo`80o`3o103oool20?l000@0oooo0P00o`080?ooo`80003o0`3oool30?l0o`80oooo
0`0000040?l0o`<00?l02@3oool40?l0o`<0o`000`00o`000`3oool0003o0000o`020000o`80o`3o
7@3oool20?l0o`80003o0P00o`020?l00080o`3o1@3oool30000o`030?l0o`3oool0oooo01H0oooo
0`00000=0?ooo`030000003b/HH0l[660100l[662P3e/h0010000000mK>00?FcP03e/h070?JdP003
0000002;DXP0Re:80140Re:800<000000?^fLP3k]W801`3k]6d2000001T0Yl3[00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`3O0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool05`3oool001/0oooo00<000000?ooo`3oool03P3oool00`00o`00003o0?ooo`0b0?ooo`<0o`3o
2P3oool30?l000d0oooo0`00o`0B0?ooo`030?l0o`3o0000o`0000800?l01@3oool40?l0o`030?oo
o`000000oooo00H0oooo0P3o0?l40?ooo`80o`00103oool2003o00L0oooo0`000?l30?ooo`80o`3o
0P3oool2000000@0o`3o0`00o`090?ooo`@0o`3o0`3o0003003o0080oooo0`000?l20?l0oah0oooo
0`3o0?l00`000?l0oooo003o00030?l000030?l0o`3oool0oooo00<0oooo0`000?l00`3o0?l0oooo
0?ooo`0F0?ooo`<00000403oool00`000000l[660?:aQP0@0?:aQP030?>dQ`3e/h00mK>000P0mK>0
00<000000?FcP03e/h001`3f]8000`000000Re:808]BR00A08]BR0030000003k]W80nkIb00<0nkA]
00<0o`000?^dK@3k]6d00P3k]6d00`000000Yl3[0:O0j`0H0:O0j`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0h03oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01L0oooo
000K0?ooo`030000003oool0oooo0400oooo0`3o0?l:0?ooo`<0o`003@3oool3003o01<0oooo00<0
003o0?l0003o00000P00o`040?ooo`<0o`3o1P3oool00`000000oooo0?ooo`020?ooo`80o`3o103o
ool20?l000@0oooo0P00o`070?ooo`80003o0`3oool30?l0o`030?ooo`000000o`3o00<0o`3o0`00
o`0:0?ooo`<0o`3o103o0003003o00030?ooo`000?l0003o0080003o0P3o0?lN0?ooo`<0o`3o00<0
003o0?ooo`00o`000`3o00020?l0o`D0oooo0P000?l00`00o`00o`3o0?ooo`0F0?ooo`<000003P3o
ool50?l0o`030000003b/HH0l[6600l0l[660P3c]8L:0?FcP0030000003e/h00m[B000L0m[B000<0
000008]BR02;DXP04@2;DXP010000000nkIb0?^fLP3k]W870?^dK@<000006@2W`>/00`000000oooo
0?ooo`070?ooo`030000003oool0oooo0>40oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`0G0?ooo`006`3oool00`000000oooo0?ooo`0m0?ooo`<0o`3o2P3oool30?l000d0oooo0`00
o`0C0?ooo`80003o0P3o0002003o00030000o`3oool0oooo00<0o`3o2P3oool010000000oooo0?l0
o`3o0?l40?ooo`80o`000`3oool3003o00L0oooo0P000?l30?ooo`80o`3o00<0oooo0?l0o`3o0?l0
0P3o0?l3003o00X0oooo103o0?l30?l000<00?l00P3oool30000o`80o`3o7`3oool30?l0o`80003o
0P00o`020?l00080o`3o1@3oool30000o`030?l0o`3oool0oooo01D0oooo0`00000=0?ooo`@0o`3o
1P3oool00`000000l[660?:aQP0=0?:aQP@0lkB72@3e/h000`000000mK>00?JdP0070?JdP0030000
002;DXP0Re:80140Re:800@000000?^fLP3k]W80nkIb203k]6d2000001X0Yl3[00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`3Q0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3o
ool05`3oool001/0oooo00<000000?ooo`3oool0>P3oool30?l0o`X0oooo0`3o000=0?ooo`<00?l0
4`3oool30000o`80o`0000@0oooo003o00000?l0oooo0`3o0?l=0?ooo`80o`3o103oool20?l000<0
oooo0P00o`070?ooo`<0003o0P3oool60?l0o`<00?l02P3oool40?l0o`<0o`000`00o`020?ooo`@0
003o0P3o0?lO0?ooo`<0o`3o0P000?l2003o00<0o`0000<0o`3o0?ooo`3oool0103oool20000o`03
003o003o0?l0oooo01D0oooo0`00000<0?ooo`@0o`3o2@3oool00`000?l000000?:aQP0>0?:aQPD0
lkB72@3e/h000`000000m[B00?JdP0060?JdP0030000002;DXP0Re:80140Re:800<000000?^fLP3k
]W800P3k]W820?^dK@030?l0o`3k]6d0nkA]00<0nkA]00<000000:O0j`2W`>/06@2W`>/00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0>80oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`0G0?ooo`006`3oool00`000000oooo0?ooo`0g0?ooo`<0o`3o2P3oool30?l000d0oooo
0`00o`0C0?ooo`<0003o00@0oooo0?l0o`3o0000oooo0P00o`030?l0o`h0oooo0P3o0?l20?ooo`04
0000003oool0o`000?l000<0oooo0P00o`070?ooo`80003o0`3oool40?l0o`<00?l02P3oool40?l0
o`@0o`000`00o`020?ooo`<0003o0P3o0?lP0?ooo`<0o`3o0P000?l00`3oool00?l00?l000020?l0
0080o`3o1@3oool30000o`030?l0o`3oool0oooo01<0oooo1000000;0?ooo`@0o`3o2@3oool40000
o`030?ooo`3o0?l0000000d0l[661P3c]8L90?FcP0030000003f]800m[B000H0m[B000<0000008]B
R02;DXP04@2;DXP00`000000nkIb0?^fLP020?^fLPP0nkA]00<000000:O0j`2W`>/06P2W`>/00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0><0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0G0?ooo`006`3oool00`000000oooo0?ooo`0d0?ooo`<0o`3o2P3oool30?l000d0
oooo0`00o`0B0?ooo`@0003o0`3oool20?l000800?l00P3o0?l?0?ooo`80o`3o0`3oool30?l000<0
oooo0P00o`060?ooo`<0003o00<0oooo0?l0o`3o0?l00P3o0?l3003o00/0oooo0`3o0?l40?l000<0
0?l00P3oool40000o`80o`3o803oool30?l0o`80003o00<0oooo003o0000o`000P3o00020?l0o`H0
oooo0P000?l00`00o`00o`3o0?ooo`0C0?ooo`<000002`3oool40?l0o`T0oooo10000?l20?ooo`<0
o`3o00<0oooo0000003b/HH02`3b/HH80?>dQ`P0mK>000<0m[B00000003f]8001@3f]8000`000000
Re:808]BR00B08]BR0030000003k]W80nkIb00<0nkIb1`3k]6d00`3l]fT000000:O0j`0K0:O0j`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0i03oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo01L0oooo000K0?ooo`030000003oool0oooo0340oooo0`3o0?l:0?ooo`<0o`00
3@3oool3003o0180oooo0`000?l50?ooo`80o`000P00o`000`3o0?l0oooo0?ooo`0>0?ooo`80o`3o
0`3oool20?l000<0oooo0`00o`060?ooo`80003o1P3o0?l00`00o`00oooo0?ooo`090?ooo`@0o`3o
0`3o0004003o0080oooo0`000?l20?l0ob80oooo0P3o0?l20000o`030?ooo`00o`000?l000<0o`00
00<0o`3o0?ooo`3oool0103oool30000o`030?l0o`3oool0oooo0180oooo0`00000:0?ooo`@0o`3o
203oool50000o`80oooo103o0?l50?ooo`030000003b/HH0l[6600T0l[66203c]8L80?FcP0030?Jd
P0000000m[B000D0m[B000<0000008]BR02;DXP04P2;DXP00`000000nkIb0?^fLP040?^fLPH0nkA]
0P3l]fT00`000000Yl3[0:O0j`0I0:O0j`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
i03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01L0oooo000K0?ooo`030000003o
ool0oooo02h0oooo0`3o0?l:0?ooo`<0o`003@3oool3003o00@0oooo1P0000080?ooo`<0003o1P3o
ool20?l000800?l000<0003o0?ooo`3oool03P3oool20?l0o`<0oooo0P3o00030?ooo`800?l000<0
oooo0000003oool0103oool20000o`80o`3o00@00?l00?l0o`3o0?l000002P3oool40?l0o`@0o`00
0`00o`020?ooo`@0003o0P3o0?lR0?ooo`<0o`3o00@0003o0?ooo`00o`000?l00`3o00020?l0o`H0
oooo0P000?l00`00o`00o`3o0?ooo`0B0?ooo`<000002@3oool40?l0o`P0oooo10000?l40?ooo`<0
o`3o2@3oool00`000000l[660?:aQP080?:aQPX0lkB71P3e/h020?JdP0030000003f]800m[B000@0
m[B000<0000008]BR02;DXP04P2;DXP00`000000nkIb0?^fLP040?^fLPH0nkA]0`3l]fT00`000000
Yl3[0:O0j`0I0:O0j`030000003oool0oooo0080oooo00<000000?ooo`3oool0i@3oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo000J0?ooo`030000003oool0oooo02`0oooo
0`3o0?l:0?ooo`<0o`003@3oool3003o0080oooo1@0000020>nYO`@0l:Um0`0000020?ooo`<0003o
1`3oool01@3o0?l0o`000?l0o`00o`00003o0100oooo0P3o0?l30?ooo`80o`000`3oool2003o00@0
oooo00<000000?l0o`000?l00P000?l2003o00<0o`3o2@3oool40?l0o`@0o`000`00o`030?ooo`<0
003o0P3o0?lS0?ooo`<0o`3o0P000?l00`3oool00?l0003o00020?l00080o`3o1P3oool30000o`03
0?l0o`3oool0oooo0140oooo0`0000070?ooo`D0o`3o203oool40000o`D0oooo0`3o0?l90?ooo`<0
003o00<000000?:aQP3b/HH01`3b/HH;0?>dQ`H0mK>000@0m[B000000000000000001@3f]8000`00
0000Re:808]BR00B08]BR0030000003k]W80nkIb00D0nkIb1@3k]6d30?bgJ@030?bdHP000000Yl3[
01X0Yl3[00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3U0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool05P3oool001X0oooo00<000000?ooo`3oool0:@3oool30?l0o`X0
oooo0`3o000=0?ooo`<00?l00P3oool4000000030>jYPP3_ZGl0kjUo00<0kjUo00<0l:Um0000003`
ZGd00P3`ZGd0103aZW`0003o0000o`000?l70?ooo`80o`3o0P3o0002003o0100oooo0P3o0?l30?oo
o`80o`000`3oool2003o00<0oooo0`3o0?l20000o`800?l000<000000?l0o`3o0?l02@3oool30?l0
o`040?ooo`3o0000o`000?l000@00?l00P3oool40000o`80o`3o8`3oool30?l0o`80003o00<0oooo
003o0000o`000`3o00000`3o0?l0oooo0?ooo`050?ooo`80003o00<00?l00?l0o`3oool04@3oool3
000000H0oooo103o0?l80?ooo`D0003o1P3oool30?l0o`T0oooo0`000?l2003o0080oooo00<00000
0?:aQP3b/HH01P3b/HH<0?>dQ`<0mK>00`0000020?JdP0030000003f]800m[B000<0m[B000<00000
08]BR02;DXP04P2;DXP00`000000nkIb0?^fLP050?^fLPD0nkA]103l]fT00`000000Yl3[0:O0j`0J
0:O0j`050000003oool0oooo0?ooo`000000j03oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo01H0oooo000J0?ooo`030000003oool0oooo02H0oooo0`3o0?l:0?ooo`<0o`003@3oool3
003o00@0oooo00@000000?ooo`3oool000000`3^ZH850>nYO`80l:Um0`000?l20?6ZO0040000003o
ool0oooo0?ooo`@0o`3o0P3o0002003o00l0oooo0`3o0?l30?ooo`80o`000`3oool2003o00030?oo
o`3o0?l0o`3o0080o`3o00<00?l00000o`000?l00P3oool30?l0o`L0oooo103o0?l40?l000<00?l0
0`3oool30000o`80o`3o903oool30?l0o`80003o00<0oooo003o0000o`000`3o00020?l0o`H0oooo
0`000?l00`3o0?l0oooo0?ooo`0?0?ooo`@000001@3oool40?l0o`P0oooo10000?l80?ooo`<0o`3o
1`3oool2003o00<0003o1`3oool00`000000l[660?:aQP050?:aQPd0lkB70`0000020?FcP0@0m[B0
00<000000?JdP03f]8000P3f]8000`000000Re:808]BR00B08]BR0030000003k]W80nkIb00H0nkIb
103k]6d50?bgJ@030000002W`>/0Yl3[01X0Yl3[00@000000?ooo`3oool00000j03oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo01H0oooo000J0?ooo`030000003oool0oooo02<0oooo
0`3o0?l:0?ooo`<0o`003@3oool3003o00H0oooo100000040>jYPP@0kjUo0`000?l20?2YO@@0lJYl
0`3o0?l20?ooo`80o`000P00o`0?0?ooo`80o`3o103oool20?l00080oooo0`00o`030?l0o`800?l0
0`000?l20?ooo`80o`3o00<000000?ooo`3oool00`3oool40?l0o`@0o`001000o`020?ooo`@0003o
0P3o0?lT0?ooo`<0o`3o0P000?l20?ooo`800?l00P3o00020?l0o`L0oooo0P000?l00`00o`00o`3o
0?ooo`0?0?ooo`<000001@3oool40?l0o`P0oooo10000?l80?ooo`@0o`3o1P3oool2003o00@0003o
2P3oool00`3o000000000?:aQP040?:aQP/0lkB70`000000103c]8L0mK>00?FcP03e/h060?JdP005
0000003f]800m[B00?JdP0000000502;DXP00`000000n[Mf0?^fLP060?^fLP@0nkA]1@3l]fT00`3l
]68000000:O0j`0K0:O0j`030000003oool000000>T0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`0F0?ooo`006P3oool00`000000oooo0?ooo`0P0?ooo`<0o`3o2P3oool30?l000d0
oooo0`00o`080?ooo`8000000P3oool00`000000kZV20>jYPP030>jYPP<0003o00<0kjUo0?2YO@3`
ZGd00P3`ZGd01`3aZW`0o`3o0?l0o`3o0?l0lJYl0000003oool00P3o0002003o00l0oooo0P3o0?l4
0?ooo`80o`000P3oool2003o0080o`3o0`00o`000`3oool0003o0000o`020?ooo`<0o`3o0P3oool0
0`000000oooo0?l0o`030?l0o`040?ooo`3o0000o`000?l000@00?l00`3oool30000o`80o`3o9@3o
ool30?l0o`80003o0P3oool2003o00<0o`000P3o0?l60?ooo`<0003o00<0o`3o0?ooo`3oool03P3o
ool3000000@0oooo103o0?l70?ooo`D0003o2@3oool30?l0o`D0oooo1000o`030000o`T0oooo1@3o
00000`3oool000000?:aQP040?:aQPL0lkB7100000050?>dQ`80mK>01P3f]8001@000000m[B00?Jd
P03f]800000001@0Re:800<000000?ZgMP3k]W801`3k]W830?^dK@H0o;MY00<0o;AR0000002W`>/0
6`2W`>/200000>X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0F0?ooo`006P3o
ool00`000000oooo0?ooo`0N0?ooo`80o`3o2P3oool30?l000d0oooo0`00o`0;0?ooo`050000003o
ool0oooo0000003]ZH@00P3^ZH830000o`D0kjUo00H0l:Um0?l0o`3o0?l0o`3o0?6ZO00000020?6Z
O0050?l0o`3o0000oooo003o00000?l03P3oool20?l0o`<0oooo0`3o00020?l0o`D00?l00P3oool3
0000o`80oooo0P3o0?l40?ooo`<0o`3o00<0oooo0?l0003o00000P3o0003003o00<0oooo10000?l2
0?l0obH0oooo0P3o0?l30000o`030?ooo`00o`000?l000<0o`000P3o0?l70?ooo`80003o00<00?l0
0?l0o`3oool03P3oool3000000<0oooo103o0?l70?ooo`@0003o2`3oool30?l0o`<0oooo1@00o`00
103oool0003o0000o`000?l70?ooo`D0o`001P3oool00`00o`0000000?:aQP020?:aQPD0lkB70`00
00090?>dQ`80mK>01`3f]80010000000m[B00?JdP000000E08]BR0030000003j]gH0nkIb00H0nkIb
0`3k]6d70?bgJ@030000002W`>/0Yl3[01X0Yl3[0P00003[0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool05P3oool001X0oooo00<000000?ooo`3oool09`3oool30?l000d0oooo0`00
o`0=0?ooo`050000003oool0oooo0?ooo`0000000`000?l40>jYPP80kjUo0`3o0?l30?2YO@<0lJYl
0P3o0002003o00h0oooo0P3o0?l30?ooo`80o`000`3o0?l3003o00@0oooo0P000?l30?ooo`80o`3o
0P3oool40?l0o`@0o`001000o`030?ooo`<0003o0P3o0?lW0?ooo`<0o`3o0P000?l0103oool00?l0
003o0000o`020?l00080o`3o1`3oool30000o`80o`3o3P3oool3000000030?ooo`3o0?l0o`3o00<0
o`3o1`3oool40000o``0oooo0`3o0?l20?ooo`@00?l00`3oool30000o`D0oooo1@3o00080?ooo`<0
0?l000@0oooo0000003b/HH0l[660`3c]8L3000000d0lkB7203f]80010000000m[B00?JdP000000E
08]BR0030000003j]gH0nkIb00L0nkIb0P3k]6d80?bgJ@8000005`2W`>/3000000030?ooo`000000
oooo0>X0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0F0?ooo`006P3oool00`00
0000oooo0?ooo`0T0?ooo`<0o`003@3oool3003o0100oooo00<000000?ooo`000?l00P000?l20>fY
Q0@0kZV20`3o0?l20>nYO`@0l:Um00<0lJYl0?l0003o00000P00o`000`3bZg/000000?ooo`0;0?oo
o`80o`3o00<0oooo0?l0o`3o0?l00P3o0005003o00D0oooo0P000?l20?ooo`L0o`3o00@0oooo0?l0
003o0000o`001000o`030?ooo`@0003o0P3o0?lW0?ooo`<0o`3o0P000?l20?ooo`800?l00`3o0002
0?l0o`L0oooo0P000?l00`00o`00o`3o0?ooo`0=0?ooo`<00000103o0?l70?ooo`D0003o3@3oool3
0?l0o`D00?l0103oool30000o`<0oooo1@3o000:0?ooo`<00?l0103o0?l00`000000l[660?:aQP03
00000100lkB72@3f]8000`000000m[B00000000E08]BR0030000003j]gH0nkIb00P0nkIb00<0nkA]
0?bgJ@3l]fT00P3l]fT010000?l0o;MY0?bgJ@3l]fT3000001<0Yl3[0`0000040?ooo`030000003o
ool0oooo0>X0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`006P3oool0
0`000000oooo0?ooo`0R0?ooo`80o`003@3oool3003o0180oooo0`000?l2000000@0kJV40`3o0?l0
0`3^ZH80kjUo0>nYO`020>nYO`<0l:Um0P3o0002003o00050?6ZO0000000lZ]k0?:[N`0000002@3o
ool50?l0o`80o`001@00o`040?ooo`<0003o0P3oool50?l0o`030?ooo`3o0000o`000080o`000`00
o`00103oool000000?ooo`3oool30000o`80o`3o:03oool30?l0o`80003o0P3oool2003o00<0o`00
0P3o0?l70?ooo`<0003o0P3o0?l=0?ooo`<000000`3o0?l70?ooo`@0003o3P3oool40?l0o`<00?l0
1P3oool30000o`030?ooo`3o0000o`0000<0o`002`3oool2003o00D0o`3o1@3oool2000001<0lkB7
00<0mKN70?JdP03f]8001`3f]802000001D0Re:800<000000?ZgMP3j]gH0203k]W800`3k]6d0o;MY
0?bgJ@020?bgJ@030000o`3l]fT0o;MY0080o;MY0`00000?0:O0j`<000001`3oool00`000000oooo
0?ooo`3[0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05P3oool001T0oooo00<0
00000?ooo`3oool0;`3oool3003o0180oooo0`000?l3000000030?ooo`000000kJV400<0o`3o1@3^
ZH840>nYO`80o`000P00o`030?6ZO0050000003bZg/0lZ]k0?:[N`0000001@3oool40?l0o`800?l0
0P3o00020?ooo`800?l01@3oool20000o`80oooo103o0?l00`3oool0o`000?l000020?l000@00?l0
0`3oool40000o`030?l0o`3oool0oooo02L0oooo0`3o0?l20000o`80oooo0`00o`020?l00080o`3o
203oool20000o`03003o003o0?l0oooo00/0oooo100000020?l0o`L0oooo10000?l?0?ooo`<0o`3o
0`00o`060?ooo`@0003o103o000=0?ooo`D0o`3o2P3oool00`000000lkB70?>dQ`0B0?>dQ`80mKN7
203f]802000001D0Re:800<000000?ZgMP3j]gH02@3k]W840?bgJ@03003o003o0000o;MY0080o;MY
0`00000<0:O0j`<000002P3oool00`000000oooo0?ooo`3/0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool05@3oool001T0oooo00<000000?ooo`3oool0;03oool3003o0180oooo0`00
0?l20?ooo`040000003oool0oooo0?ooo`<0o`3o103]ZH@40>jYPP<0kjUo00@0o`000?2YO@00o`00
l:Um103aZW`00`000000lZ]k0?:[N`020?:[N`030000003o0?l0o`3o00<0o`3o0`00o`020?l00080
oooo0P00o`040?ooo`<0003o00<0oooo0?l0o`3o0?l00P3o0?l01@3oool0o`000?l0003o0000oooo
00<00?l0103oool30000o`80o`3o:@3oool30?l0o`<0003o0P3oool2003o00<0o`000P3o0?l70?oo
o`<0003o0P3o0?l;0?ooo`<000000P3o0?l60?ooo`D0003o3`3oool01@00o`00o`3o0?l0o`3o0?l0
0?l000P0oooo0`000?l40?l000/0oooo1P3o0?l?0?ooo`030?l000000000lkB70140lkB7103e]hL8
0?JdP0030000002;DXP0Re:801<0Re:800@000000?ZgMP3j]gH0n[Mf203k]W840?bgJ@80o`00103l
]fT00`3l]68000000:O0j`080:O0j`<000003@3oool00`000000oooo0?ooo`3/0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool05@3oool001T0oooo00<000000?ooo`3oool0:@3oool3
003o0180oooo0`000?l50?ooo`050000003o0?l0o`3o0?l0o`0000000P3/ZXH50>fYQ0@0kZV20P3o
0002003o0080l:b1103aZW`00`000000lZ]k0?l0o`030?l0o`04003o003o0?l0o`3o003o0080oooo
0P3o00020?ooo`800?l0103oool20000o`D0o`3o103o0004003o00<0oooo10000?l0103o0?l0oooo
0?ooo`00000W0?ooo`<0o`3o0`000?l20?ooo`800?l00`3o00020?l0o`P0oooo0P000?l00`00o`00
o`3o0?ooo`0:0?ooo`<0000000<0o`3o0?ooo`3oool0103oool40000oa00oooo0P00o`030?l0o`T0
oooo0`000?l20?l000/0oooo1@3o0?l3003o00l0oooo0`3o00020?ooo`030000003c]8L0lkB700l0
lkB7103e]hL80?JdP0030000002;DXP0Re:801<0Re:800@000000?ZgMP3j]gH0n[Mf203k]W800`3l
^W40o;MY0?bgJ@020?bgJ@030?l0o`3l]fT0o;MY00<0o;MY00<000000:O0j`2W`>/0102W`>/30000
0100oooo00<000000?ooo`3oool0k@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
01D0oooo000I0?ooo`030000003oool0oooo02L0oooo0P00o`0B0?ooo`<0003o1P3oool30?l0o`<0
oooo00@000000>bZQP3/ZXH0k:Z6103]ZH@20>jYPP80o`000P00o`00103_Zh80l:b10?2/P@3`[842
0?6/P0@0o`3o0`00o`020?l0o`80oooo0`3o0000103oool00?l0003o0000o`040?ooo`80003o103o
0?l30?l000@00?l0103oool30000o`80o`3o1@3oool00`000000oooo0?ooo`0S0?ooo`80o`3o0`00
0?l20?ooo`800?l00`3o00020?l0o`P0oooo0`000?l20?l0o`P0oooo0P3o0?l3000000H0oooo1000
0?l?0?ooo`@00?l00`3o0?l70?ooo`80o`000`000?l;0?ooo`D0o`3o0P3oool3003o00h0oooo103o
00050?ooo`030000003c]8L0lkB700l0lkB71@3e]hL60?JdP0030000002;DXP0000001@0Re:800@0
00000?ZgMP3j]gH0n[Mf1`3k]W820?bjL@/0o;MY00<000000:O0j`2W`>/00`00000C0?ooo`030000
003oool0oooo0>h0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0E0?ooo`006@3o
ool00`000000oooo0?ooo`0h0?ooo`<0003o1P3oool30?l0o`80oooo00D000000?ooo`3oool0oooo
000000040>bZQP<0kJV40P3o0002003o00040>n[P`3_Zh80kj^20>n[PP@0o`3o1000o`001@3bZg/0
o`3o0?l0o`3c[7/000000080o`000P3oool2003o00@0oooo0`000?l01P3o0?l0oooo0?l0o`3o0?l0
o`000?ooo`<00?l0103oool40000o`030?l0o`3oool0oooo00L0oooo00<000000?ooo`3oool0803o
ool30?l0o`80003o0P3oool3003o0080o`000`3o0?l80?ooo`80003o00<00?l00?l0o`3oool01P3o
ool30?l0o`<00000103oool50000o`h0oooo1@00o`040?l0o`D0oooo103o00030000o`T0oooo1@3o
0?l40?ooo`<00?l03P3oool30?l000L0oooo0`3o0?l00`000000lkB70?>dQ`0=0?>dQ`L0mKN71@3f
]80010000000Re:808]BR000000C08]BR0030000003j]gH0n[Mf0080n[Mf1P3k]W830?bjL@/0o;MY
0P00000F0?ooo`030000003oool0oooo0>h0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0E0?ooo`006@3oool00`000000oooo0?ooo`0e0?ooo`<0003o1P3oool30?l0o`@0oooo00<0
00000?ooo`3oool00P3oool00`000000k:Z60>bZQP020>bZQP030>fYQ03o0000o`0000800?l00P3_
Zh<40?l0o`@00?l00P3a[8001@000000o`3o0?l0o`3bZg/0ljak0080o`0000@000000?ooo`00o`00
0?l00P3oool20?l0o`80003o00<0oooo0?l0003o0?l00P3o0?l4003o00@0oooo0`000?l20?l0o``0
oooo00<000000?ooo`3oool07@3oool30?l0o`80003o0`3oool2003o00<0o`000P3o0?l80?ooo`<0
003o0P3o0?l50?ooo`@0o`3o0`0000030?ooo`@0003o3`3oool4003o0080oooo0`3o0?l40?ooo`D0
o`0010000?l70?ooo`D0o`3o1@3oool4003o00h0oooo0`3o00070?ooo`<0o`3o0`3oool00`000000
lkB70?>dQ`0=0?>dQ`P0mKN7103f]80010000000Re:808]BR000000C08]BR0030000003j]gH0n[Mf
0080n[Mf1P3k]W830?bjL@/0o;MY00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`3_0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool05@3oool001T0oooo00<000000?ooo`3o
ool0<P3oool30000o`H0oooo0`3o0?l70?ooo`050000003oool0oooo0?ooo`0000001@3/ZXH00`3o
0000kJV4003o00040?l0o`@00?l00`3`[840103a[800o`3o0?l0o`3o0?l20?:[N`80o`000P3c[7/2
003o00@0o`3o0P000?l20?l00080o`3o0`00o`050?ooo`<0003o00<0o`3o0?ooo`3oool03P3oool0
0`000000oooo0?ooo`0J0?ooo`<0o`3o0`000?l20?ooo`800?l00`3o00030?l0o`L0oooo0`000?l0
0`00o`00o`3o0?ooo`030?ooo`@0o`3o100000020?ooo`@0003o3P3oool5003o00<0oooo0`3o0?l2
0?ooo`D0o`000P3oool30000o`D0oooo1P3o0?l70?ooo`<00?l03`3oool30?l000L0oooo0`3o0?l7
0?ooo`030000003c]8L0lkB700`0lkB72@3e]hL30?JdP0050000002;DXP0Re:808]BR00000004P2;
DXP00`000000n[Mf0?ZgMP030?ZgMP@0nkIb1@3l^W4:0?bgJ@030000003oool0oooo01D0oooo00<0
00000?ooo`3oool0l03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01D0oooo000I
0?ooo`030000003oool0oooo02l0oooo0`000?l60?ooo`<0o`3o2P3oool00`000000oooo00000003
00000080k:Z60P3o0002003o00030?l0o`00o`000?l000800?l00P3_Zh<20>n[PP80l:b10P3o0?l2
0?6/P0050000003o0000o`000?:[N`3c[7/00P00o`020?l0o`050?ooo`000?l0003o0000o`3o0000
0`3o0?l2003o00@0oooo10000?l00`3o0?l0oooo0?ooo`0A0?ooo`030000003oool0oooo01L0oooo
0`3o0?l30000o`80oooo0`00o`020?l000<0o`3o203oool20000o`03003o003o0?l0o`3o0080oooo
103o0?l01@3oool00000000000000000oooo00D0003o3P3oool4003o00D0oooo0`3o0?l50?l000@0
oooo0`000?l30?ooo`D0o`3o2P3oool3003o00l0oooo0`3o00060?ooo`@0o`3o2`3oool00`000000
lkB70?>dQ`0;0?>dQ`T0mKN70`3f]8001@000000Re:808]BR02;DXP000000180Re:800<000000?Zg
MP3j]gH00`3j]gH40?^fLPD0o;Ya2P3l]fT00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
0?80oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0E0?ooo`006@3oool00`000000
oooo0?ooo`0]0?ooo`80003o1P3oool30?l0o`d0oooo0P0000020:O0j`040000003/ZhP000000?l0
00D00?l00`3^[8@30>n[P`80kj^20P3o0?l00`3`[840lJb00?6/P0020?l000070?6]O`00o`000?l0
003o003o0?l0ljak0?l000020000o`050?l00000o`00o`3o0?l0o`00o`001@3oool30000o`030?l0
o`3oool0oooo01D0oooo00<000000?ooo`3oool0503oool30?l0o`<0003o0P3oool3003o00<0o`00
0P3o0?l80?ooo`<0003o00<00?l00?l0o`3oool0103o0?l20?ooo`<0000010000?l>0?ooo`D00?l0
1P3oool30?l0o`<0o`001P3oool30000o`030?ooo`3o0?l0o`3o00<0o`3o303oool3003o00h0oooo
103o00060?ooo`<0o`3o3@3oool20000o`030000003c]8L0lkB700X0lkB72`3e]hL20?JdP0030000
002;DXP0Re:80080Re:800<0000008]BR02;DXP03`2;DXP00`000000n[Mf0?ZgMP040?ZgMP<0nkIb
1P3l^W490?bgJ@030000003oool0oooo01@0oooo00<000000?ooo`3oool0lP3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo01D0oooo000H0?ooo`030000003oool0oooo03<0oooo0`3o
0?l@0?ooo`<0000000H0Yl3[0000003/ZhP00000003o000000040>bZQP@0kZb40P3_Zh<20?l0o`03
0>n[PP3`[840l:b10080o`0000@0o`3o003o0000o`00lJeo0P3o00030000o`04003o003o0?l0o`3o
0?l0o`@0oooo10000?l00`3o0?l0oooo0?ooo`0H0?ooo`030000003oool0oooo0140oooo0`3o0?l3
0000o`<0oooo0P00o`030?l000<0o`3o203oool20000o`03003o003o0?l0o`3o00<0o`3o0`3oool3
000000<0003o3@3oool5003o00P0oooo0`3o0?l00`3o0000oooo0?ooo`060?ooo`<0003o103o0?l>
0?ooo`<00?l03P3oool30?l000L0oooo0`3o0?l:0?ooo`D0003o1000o`000`000000lkB70?>dQ`09
0?>dQ``0mKN700<0m[B00000002;DXP0102;DXP00`000000Re:808]BR00>08]BR0030000003j]gH0
n[Mf00@0n[Mf0P3k]W870?bjL@T0o;MY00<000000?ooo`3oool0503oool00`000000oooo0?ooo`3c
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0503oool001P0oooo00<000000?oo
o`3oool0<@3oool20?l0oa<0oooo0`0000000`2W`>/000000>b[R0030>b[R08000000P3/ZXH0103^
[8H0kZb40>j/Q03^[8@20?l0o`030>n[P`3_Zh80o`000080o`0000<0o`3o003o0000o`000`3o0002
0000o`800?l00P3o0?l0103d[W/000000?ooo`3oool30000o`030?l0o`3oool0oooo01`0oooo00<0
00000?ooo`3oool03`3oool20?l0o`<0003o0`3oool3003o0080o`000`3o0?l80?ooo`80003o103o
0?l50?ooo`<000000P000?l=0?ooo`@00?l0203oool00`3o0000o`3o0?l0o`020?l0o`P0oooo1000
0?l20?l0o`l0oooo1000o`0>0?ooo`<0o`001`3oool30?l0o`L0oooo1@000?l5003o00D0o`0000<0
00000?>dQ`3c]8L02@3c]8L=0?FgQ`030000002;DXP0Re:800<0Re:800<0000008]BR02;DXP03P2;
DXP00`000000n[Mf0?ZgMP040?ZgMP80nkIb203l^W480?bgJ@030000003oool0oooo01@0oooo00<0
00000?ooo`3oool0m03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01@0oooo000H
0?ooo`030000003oool0oooo04<0oooo0`3o00000`000000oooo0?ooo`02000000H0k:^800@00000
0>bZQP3^[8H0kZb60P3o0?l01P3^[8@0o`3o0?l0003o0000kj^20?2/P@800?l00P3o0000103a[Gl0
003o0000o`00o`030?l0o`030?>/N`3d[W/0003o00<0003o00<0o`3o0?ooo`3oool07`3oool00`00
0000oooo0?ooo`0<0?ooo`<0o`3o0P000?l30?ooo`<00?l00`3o00020?l0o`T0oooo1@3o0?l40?oo
o`040000o`0000000000000000d0oooo1@00o`070?ooo`<0o`000`3o0?l70?ooo`80o`3o0`000?l0
0`3o0?l0oooo0?ooo`0?0?ooo`<00?l03`3oool30?l000L0oooo0`3o0?l30?ooo`D0003o1P00o`06
0?l000H0o`3o00<000000?>dQ`3c]8L01`3c]8L>0?FgQ`030000002;DXP0Re:800@0Re:800<00000
08]BR02;DXP03@2;DXP00`000000n[Mf0?ZgMP050?ZgMP030?^fLP3l^W40o;Ya00H0o;Ya203l]fT0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0?D0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0D0?ooo`00603oool00`000000oooo0?ooo`0o0?ooo`@0o`000`3oool01@00
0000oooo0?ooo`3oool0000000L0k:^800<000000?l0o`3o0?l00P3o0?l40?l000800?l000<0l:b1
003o00000?l00P000?l01@3a[Gl0o`3o0?l0o`3b[Wl0ljak00<0003o00<0o`3o0?B^N`0000008`3o
ool00`000000oooo0?ooo`090?ooo`<0o`3o0`000?l30?ooo`800?l00`3o00030?l0o`L0oooo103o
0?l00`00o`00o`3o0?ooo`020?ooo`030000o`0000000000008000002`3oool5003o00L0oooo1@3o
00030?l0o`D0oooo103o0?l30000oa80oooo0`00o`0?0?ooo`<0o`001P3oool40?l0o`D0003o1@00
o`070?l000H0o`3o1`3oool00`000000lkB70?>dQ`060?>dQ`h0mKN700<0000008]BR02;DXP0102;
DXP00`000000Re:808]BR00=08]BR0030000003j]gH0n[Mf00D0n[Mf2P3l^W470?bgJ@030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0m@3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo01@0oooo000H0?ooo`030000003oool0oooo03`0oooo0`3o00070?ooo`050000003oool0
oooo0?ooo`0000001`3/ZhP00`3o0?l00000000000030?l000D00?l00P000?l0103a[80000000?l0
o`3o0?l40000o`030?l0o`3d[W/0m:ik0080m:ik00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`060?ooo`<0o`3o0`000?l30?ooo`<00?l00P3o00030?l0o`H0oooo103o0?l010000?l00?l0
0?l0o`3o0?l30000o`<000002`3oool4003o00L0oooo1@3o00020?ooo`<0o`3o0`3oool50?l0o`04
0?ooo`000?l0003o0000oa80oooo0`00o`0>0?ooo`@0o`001P3oool30?l0o`80003o1@00o`070?l0
00L0o`3o3@3oool00`000000lkB70?>dQ`060?>dQ`h0mKN700<0000008]BR02;DXP01@2;DXP00`00
0000Re:808]BR00<08]BR0030000003j]gH0n[Mf00D0n[Mf00<0nk]h0?bjL@3l^W401`3l^W470?bg
J@030000003oool0oooo01@0oooo00<000000?ooo`3oool0mP3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo01@0oooo000H0?ooo`030000003oool0oooo03T0oooo0`3o000:0?ooo`05
0000003oool0oooo0?ooo`0000001`3/ZhP0103^[HL0o`000?l000000004003o00040>n[P`000?l0
003o0?2^Q0<0o`3o0P000?l0103o0?l0lZio0?:^O`3b[Wl60?B^N`030000003oool0oooo0200oooo
00<000000?ooo`3oool00`3oool30?l0o`<0003o0`3oool3003o00<0o`000P3o0?l50?ooo`@0o`3o
0`000?l00`00o`00003o0000o`020000o`<000002@3oool5003o00H0oooo1@3o00040?ooo`<0o`3o
00<0oooo0?l0o`3o0?l00`3o0?l30?ooo`<0003o4P3oool3003o00h0oooo0`3o00040?ooo`<0003o
0`3o0?l4003o00H0o`001`3o0?lE0?ooo`030000003c]8L0lkB700D0lkB73P3e]hL00`000000Re:8
08]BR00408]BR0<000003@2;DXP00`000000nKMj0?ZgMP040?ZgMP80nk]h2@3l^W470?bgJ@030000
003oool0oooo01@0oooo00<000000?ooo`3oool0m`3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo01@0oooo000H0?ooo`030000003oool0oooo03H0oooo00<000000?l0003o00003@3o
ool00`000000oooo00000002000000L0k:^80P3^[HL0100000000?l00000003^[8H30000o`030?2^
Q@3o0?l0o`3o0080003o00<0o`3o0?6]O`3a[Gl0103b[Wl00`3b[gl0m:ik0?B^N`030?B^N`030000
003oool0oooo0200oooo00<000000?ooo`3oool00`3o0?l30000o`<0oooo0`00o`030?l000<0o`3o
0P3oool50?l0o`80oooo1P000?l0103oool000000000000000080?ooo`@00?l01P3oool50?l000D0
oooo203o0?l50?ooo`<0003o4@3oool4003o00h0oooo0`3o00000`3oool0003o0000o`020000o`80
0?l00`3o0?l70?l000H0o`3o703oool00`000000lkB70?>dQ`040?>dQ`l0mKN700@0000008]BR02;
DXP0Re:80`00000208]BR0030000002;DXP0Re:800/0Re:800<000000?VgNP3j]gH00`3j]gH30?^k
N0X0o;Ya1@3l]fT00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0?P0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0D0?ooo`00603oool00`000000oooo0?ooo`0f0?ooo`80
00003P3oool200000080oooo00<000000>b/R`3/ZhP01@3/ZhP40>j]Q`03000000000?l0kZb600@0
o`3o0P3`[X@00`3`[X<000000?6^P`040?:^O`80lZmo1P3d[W/00`000000oooo0?ooo`0O0?ooo`<0
o`3o00<0oooo0000o`000?l0103oool2003o00030?ooo`3o0000o`0000<0o`3o00<0oooo0?l0o`3o
0?l00P3o0?l40?ooo`D0003o0P3oool3000000H0oooo1@00o`050?ooo`D0o`001`3oool60?l0o`H0
oooo10000?lA0?ooo`<00?l03`3oool30?l00080003o1000o`040?l0o`<0o`001`3o0?lS0?ooo`03
0000003c]8L0lkB700<0lkB73`3e]hL4000000H0Re:800<0000008]BR02;DXP02P2;DXP00`000000
nKMj0?ZgMP020?ZgMPD0nk]h2@3l^W450?bgJ@030000003oool0oooo01D0oooo00<000000?ooo`3o
ool0n03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01@0oooo000H0?ooo`030000
003oool0oooo04H0oooo00D000000?ooo`3oool0oooo000000040>b/R`<0k:^8103^[HL010000000
003o0?l0o`3o0?l30?2^Q@80l:j400<0l:j30000003a[X<0103b[Wl30?:_O`@0m:ik00<0m;1l0000
003oool07P3oool20?l0o`04000000000?l0003o0000o`<0oooo0`00o`030?l000H0o`3o103oool4
0000o`04003o003o0?l0o`3o0?ooo`<00000103oool5003o00H0oooo103o00070?ooo`D0o`3o2@3o
ool30000oa80oooo0`00o`0<0?ooo`<0003o0`3o0003003o00<0o`002P3o0?lZ0?ooo`030000o`00
0000lkB700<0lkB73@3e]hL3000000X0Re:800<0000008]BR02;DXP02@2;DXP00`000000nKMj0?Vg
NP020?ZgMPD0nk]h2P3l^W440?bgJ@030000003oool0oooo01@0oooo0P00003k0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool04`3oool001L0oooo00<000000?ooo`3oool0A`3oool0
1P000000oooo0?ooo`3oool00?l0000000H0k:b;1@3^[HL400000080l:j50P3`[X@0103`[X<00000
0?6^P`3a[h<20?:^O`@0lZmo00<0m:ik0000003d[W/00`3d/7`00`000000oooo0?ooo`0I0?ooo`<0
o`3o0`000?l30?ooo`<00?l00`3o00050?l0o`@0oooo1P000?l20?l0o`040?ooo`00000000000000
00<0oooo1000o`060?ooo`D0o`001P3oool70?l0o`T0oooo0`000?lB0?ooo`<00?l02@3oool40000
o`03003o003o0000o`0000P0o`001P3o0?l^0?ooo`<0003o00<00?l00000003c]8L00`3c]8L90?Fg
Q`@0000000<0mKN70000002;DXP02`2;DXP00`000000Re:808]BR00808]BR0040000003i]gX0nKMj
0?ZgMPH0nk]h2P3l^W440?bgJ@030000003oool0oooo0140oooo0`0000000`3oool000000?ooo`3k
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool04`3oool001L0oooo00<000000?oo
o`3oool0A`3oool01P0000000?l0003o0000o`00oooo000000H0k:b;00<000000>j]R03^[HL0103^
[HL20>n^QP030000003`[XD0l:j50080l:j400D000000?6^P`3a[h<0lJn30?:^O`050?:_O`030?B^
N`3d/7`0m;1l0080m;1l00<000000?ooo`3oool05P3oool30?l0o`<0003o00<0oooo0000003oool0
0`00o`000`3oool0o`000?l000040?l0o`<0oooo1@000?l01@3oool0003o0000o`00o`00o`3o00@0
000000<0oooo003o0000o`000`00o`050?ooo`D0o`001P3oool50?l0o`040?ooo`3o0?l0o`3o0?l0
o`T0oooo0`000?lB0?ooo`<00?l01P3oool30000o`@00?l01`3o00070?l0oc40oooo0`000?l3003o
0080o`0000<000000?>dQ`3c]8L01`3e]hL3000000D0mKN700<0000008]BR02;DXP02P2;DXP00`00
0000Re:808]BR00808]BR0030000003i]gX0n[an00P0nk]h2P3l^W430?bgJ@030000003oool0oooo
00h0oooo0`0000040?ooo`030000003oool0oooo0?/0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0C0?ooo`005`3oool00`000000oooo0?ooo`140?ooo`<00?l000<000000?ooo`3o
ool00P3oool00`000000k:b;0>b/R`040>b/R`D0kZf80P3^[HL30>n^QP050000003`[XD0l:j40?2^
Q00000000`3a[h<50?:_O`030?>`P03d/7`0m;1l00<0m;1l00<000000?ooo`3oool04`3oool30?l0
o`<0003o103oool2003o00030?ooo`3o0000o`3o00@0o`3o0P3oool40000o`<0oooo0`000?l0103o
0?l00000000000000005003o00D0oooo1@3o00060?ooo`D0o`3o0P3oool40?l0o`T0oooo0`000?lB
0?ooo`<00?l00P3oool40000o`@00?l01`3o000:0?l0oc00oooo10000?l3003o00<0o`000P3o0?l0
0`000000lkB70?>dQ`040?FgQ`<00000203e]hL00`000000Re:808]BR00;08]BR0030000002;DXP0
Re:800L0Re:800<000000?ZlOP3j_7h0203k^gP:0?bjL@<0o;MY00<000000?ooo`3oool02`3oool3
000000H0oooo00<000000?ooo`3oool0o03oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo01<0oooo000G0?ooo`030000003oool0oooo0440oooo0`00o`030?ooo`030000003oool0oooo
0080oooo00<000000>b/R`3/[8/0103/[8/70>j]R0@0kjj600@000000?2^Q03`[X@00000103a[h<2
0?:_O`@0lk201@3d/7`00`000000oooo0?ooo`0?0?ooo`<0o`3o00<0oooo0000o`000?l0103oool3
003o00H0o`3o00<0oooo0000o`000?l00P000?l50?ooo`80003o00@00?l000000000000000000`00
o`050?ooo`D0o`001@3oool60?l0o`@0oooo0`3o0?l90?ooo`@0003o4@3oool4003o00<0003o0`00
o`070?l000040?l0o`3o0000o`000?l00080o`3o103oool30?l0oc40oooo0`000?l4003o00<0o`00
0`3o0?l30?ooo`030000003c]8L0mKN700<000002`3e]hL00`000000Re:808]BR00<08]BR0030000
002;DXP0Re:800H0Re:800@000000?ZlOP3j_7h0n[an1`3k^gP;0?bjL@80o;MY00<000000?ooo`3o
ool0203oool3000000T0oooo00<000000?ooo`3oool0o@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo01<0oooo000G0?ooo`030000003oool0oooo03l0oooo0P00o`070?ooo`050000
003o0?l0o`3o0?l0o`0000001`3/[8/60>j]R0D0kjj600<000000?2^Q0000000103a[h<00`3b[gl0
lk200?>`P0030?>`P0D0m;1l00<000000?ooo`3oool0303oool30?l0o`040?ooo`000?l0003o0000
o`<0oooo00<00?l00?l0o`3o0?l00`3o0?l00`000000o`3o0000o`040000o`H0oooo0`000?l30000
00800?l0103oool50?l000D0oooo1@3o0?l70?ooo`<0o`3o2@3oool30000oa80oooo1P00o`070?l0
00@0o`3o103o00060?ooo`<0o`3o<@3oool30000o`<00?l0103o00030?l0o`L0oooo0P00000>0?Fg
Q`030000002;DXP0Re:800d0Re:800<0000008]BR02;DXP01@2;DXP010000000n[an0?ZlOP3j_7h8
0?^kN0X0o;Ya0P3l]fT00`000000oooo0?ooo`050?ooo`<00000303oool00`000000oooo0?ooo`3n
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04`3oool001L0oooo00<000000?oo
o`3oool0?`3oool2000000D0oooo0P3o0?l00`000000oooo0?ooo`020?ooo`030000003/[8/0k:b;
00@0k:b;1P3^[HP60>n^QP8000000`3a[h<00`3a[h@0lk200?>`P0040?>`P0D0m;1l00<000000?oo
o`3oool02@3oool30?l0o`040?ooo`000?l0003o0000o`<0oooo103o0?l30?l000@0003o2@3oool0
0`000?l00?l000000002000000@0oooo1@3o00050?ooo`D0o`3o2@3oool30?l0o`T0oooo0`000?l>
0?ooo`@0003o0`00o`060?l000L0o`3o00@0oooo0?l0003o0000o`001`3oool30?l0oc40oooo0`00
0?l3003o00<0o`0000@0oooo0?l0o`3o0?l0o`3o2P3oool00`000000mKN70?FgQ`0=0?FgQ`030000
002;DXP0Re:800d0Re:800<0000008]BR02;DXP01@2;DXP010000000n[an0?ZlOP3j_7h80?^kN0/0
o;Ya00<0o;MY0000003oool00`3oool3000000l0oooo00<000000?ooo`3oool0o`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo01<0oooo000G0?ooo`030000003oool0oooo0480oooo
00@000000?l0o`3o0?l0o`3o0P3oool010000000oooo0?ooo`3oool2000000H0k:b;1P3^[HP70>n^
QP030000003a[h@0lJn400<0lJn41P3c/8050?B`O0030000003oool0oooo00H0oooo0P3o0?l0103o
ool0003o0000o`000?l20?ooo`@0o`3o00<00?l00?l0003o000010000?l20?ooo`030000003oool0
oooo00@0oooo0`00o`0300000080oooo1@3o00050?ooo`D0o`3o2`3oool30?l0o`T0oooo0`000?l;
0?ooo`<0003o0`00o`00103o00000?l0003o0000o`030?l000H0o`3o1@3oool30?l000L0oooo0`3o
0?l`0?ooo`@0003o0`00o`030?l000@0o`3o3P3oool00`000000mKN70?FgQ`0<0?FgQ`030000002;
DXP0Re:800h0Re:800<0000008]BR02;DXP0102;DXP010000000n[an0?ZlOP3j_7h90?^kN0X0o;Ya
00<0o;MY0000003oool00`00000A0?ooo`030000003oool0oooo0?l0oooo0@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo01<0oooo000G0?ooo`030000003oool0oooo0480oooo00<0
o`3o0000003oool00`3oool4000000030?ooo`000000k:j<00D0k:j<1P3^[XT00`000000l:n70?2_
Q`040?2_Q`800000103a[h@60?>`P0D0m;1l00<000000?ooo`3oool00`3oool30?l0o`<0003o00<0
oooo0?l0o`3o0?l00P3o0?l2003o00D0003o00<0o`3o0?ooo`3oool00`3oool00`000000oooo003o
0003003o00@000001@3o00050?ooo`D0o`3o303oool40?l0o`T0oooo0`000?l80?ooo`<0003o0P00
o`050?l000<00?l01P3o0?l80?ooo`<0o`001P3oool40?l0oc00oooo0`000?l3003o00@0o`000`3o
0?lC0?ooo`030000003e]hL0mKN700/0mKN700<0000008]BR02;DXP03`2;DXP00`000000Re:808]B
R00308]BR0030000003j_7h0n[an0080n[an203k^gP;0?bjL@800000503oool00`000000oooo0?oo
o`3o0?ooo`80oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0C0?ooo`005`3oool0
0`000000oooo0?ooo`180?ooo`030000003oool0oooo00<0oooo00<000000>b^S03/[X`0103/[X`6
0>j^R@030000003`[hL0l:n700<0l:n700<000000?6`Q@0000000`3a[h@60?>`PPD0m;5n00<00000
0?ooo`3oool00`3o0?l30000o`@0o`3o0P00o`040000o`040?ooo`3o0?l0o`3o0?l0o`D0oooo1000
o`00103oool000000000000000040?l000@0oooo1P3o0?l>0?ooo`<0o`3o2P3oool30000o`@0oooo
0`000?l3003o00H0o`0000<0o`3o003o0000o`000P00o`020?l0o``0oooo0`3o00060?ooo`<0o`3o
<@3oool30000o`<00?l00`3o0000103oool0o`3o0?l0o`3o0?lG0?ooo`030000003e]hL0mKN700X0
mKN700<0000008]BR02;DXP03`2;DXP00`000000Re:808]BR00308]BR0030000003j_7h0n[an0080
n[an203k^gP;0?bjL@030000003oool0oooo01<0oooo00<000000?ooo`3oool0o`3oool30?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool04P3oool001H0oooo00<000000?ooo`3oool0
B@3oool00`000000oooo0?ooo`030?ooo`030000003/[X`0k:j<00@0k:j<1P3^[XT00`000000l:n7
0?2_Q`020?2_Q`070?2`Q`000000lK260?6`Q@000000lK250?6_Q0060?>`PPD0m;5n0`3o0?l00`3o
ool0003o0?l0o`030?l0o`80oooo10000?l20?l000<0o`3o0`3oool5003o0080oooo0`0000030?l0
00<0oooo1@3o0?lA0?ooo`<0o`3o2@3oool40000o`040?ooo`000?l0003o0000o`800?l01`3o0004
0?l0o`<00?l03P3oool40?l000H0oooo0`3o0?la0?ooo`<0003o0`00o`030?l000040?ooo`3o0?l0
o`3o0?l0oa/0oooo00<000000?FgQ`3e]hL0203e]hL00`3g^HD0000008]BR00A08]BR0030000002;
DXP0Re:80080Re:800<000000?ZlOP3j_7h00P3j_7h90?^kN0X0o;Ya00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`3o0?ooo`<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0B0?ooo`005P3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0080oooo00<00000
0>b^S03/[X`0103/[X`50>j^R@030>j_RP000000l:n700<0l:n700<0l;270000003a/8H00P3a/8D0
0`000000lK250?>`PP050?>`PP80m;5n203o0?l00`3oool0003o0000o`030000o`<0o`0000@0oooo
0?l0o`3o0?l0oooo1@00o`030?ooo`050?l00000000000000000003o0000203o0?lC0?ooo`<0o`3o
2@3oool40000o`800?l01`3o00070?l0o`040?ooo`00o`000?l0003o00h0oooo0`3o00070?ooo`<0
o`3o<03oool40000o`<00?l00`3o00040?l0oah0oooo00<000000?FgQ`3e]hL0203e]hL00`3g^HD0
000008]BR00B08]BR0050000002;DXP0Re:808]BR0000000103j_7h90?^kN0T0o;Ya00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`3o0?ooo`@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0B0?ooo`005P3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo00<0
oooo00<000000>b^S03/[X`0103/[X`20>j^R@@0kZn:103`[hL0103`/8L000000?6`QP3a/8H20?6`
Q@030000003c/H<0lk6300<0lk221P3o0?l00`000?l0oooo0000o`030000o`800?l000@0oooo0?l0
003o0000oooo0P3o0?l4003o00<0oooo0`3o0003000000030000o`00o`00o`3o00@0o`3o5@3oool3
0?l0o`L0oooo1@000?l60?l000L0o`3o1@3oool3003o00h0oooo0`3o00060?ooo`@0o`3o<03oool3
0000o`<00?l0103o00030?l0ob<0oooo00<000000?FgQ`3e]hL01`3e]hL00`3g^HD0000008]BR00C
08]BR0040000002;DXP0Re:8000000@0n[an2@3k^gP90?bjL@030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0o`3oool60?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04P3o
ool001H0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`020?ooo`030?l000000000
k:j<00D0k:j<00<0kZj90>j_RP3^[hX0103^[hX20?2_Q`030?2`Q`000000l;2700<0lK260P3a/8D2
000000D0o`3o1P000?l0103oool00?l0003o003oool30?l000D00?l00P3oool50?l000<000001@3o
0?l00`3oool000000?ooo`0C0?ooo`@0o`3o103oool20000o`800?l000@0o`000000o`000?l0003o
0`3o00060?l0o`T0oooo0`00o`0>0?ooo`<0o`001P3oool30?l0oc40oooo0`000?l3003o00<0o`00
00@0oooo0?l0o`3o0?l0o`3o9`3oool00`000000mKN70?FgQ`060?FgQ`030000002;DXP0Re:801<0
Re:800@0000008]BR02;DXP000001@3j_7h90?^kN0P0o;Ya00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`3o0?ooo`L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0B0?oo
o`005P3oool00`000000oooo0?ooo`1;0?ooo`060000003o0000o`000?l0003oool000001@3/[X`0
0`3][hd0kZn:0>j_RP050>j_RP80l:n700<0l;270000003`/8L00`3a/8H20?6`Q@030?>bQ03o0?l0
o`3o00H0003o0P3d/Gh3003o0080o`001000o`000`3o0?l0oooo0?l000040?l000030?ooo`000000
0000008000001@3o0?l40?ooo`030000003oool0oooo00l0oooo0`3o0?l20?ooo`80003o0P00o`04
0?l000<0003o1P3o0?l<0?ooo`<00?l03P3oool30?l000H0oooo0`3o0?la0?ooo`<0003o0`00o`03
0?l000@0o`3o:`3oool00`000000mKN70?FgQ`050?FgQ`030000002;DXP0Re:801@0Re:800<00000
08]BR00000001@3j_7h90?^kN0L0o;Ya00<000000?ooo`3oool0503oool00`000000oooo0?ooo`3o
0?ooo`L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0B0?ooo`005P3oool00`00
0000oooo0?ooo`1;0?ooo`800000103oool00`000000k:j<0>b^S0040>f_S@H0kZn:00D0kk2;0?2_
Q`3`/8L000000?2`Q`040?6`QP030?6`Q@3c/X@000000080003o0P3c/H<20?FcP@P00?l000<0o`3o
0?l0003o00000`3o00020?ooo`050?l0o`00000000000000003o0?l00P000?l01000o`00o`3o0?l0
o`3o0?l60?ooo`030000003oool0oooo00`0oooo0`3o0?l2003o00L0o`0010000?l20?l0o`l0oooo
1000o`0=0?ooo`@0o`001P3oool30?l0oc00oooo10000?l2003o00@0o`000`3o0?l_0?ooo`030000
003e]hL0mKN700D0mKN700<0000008]BR02;DXP05@2;DXP2000000D0n[an2P3k^gP60?bjL@030000
003oool0oooo01@0oooo00<000000?ooo`3oool0o`3oool80?ooo`050000003oool0oooo0?ooo`00
0000503oool001H0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`020?ooo`800000
1P3][hd50>j_RP80kk2;0P3`/8L00`000000l;270?6`QP040?6`QP80lk:40`000006003o00H0o`00
0P3oool30?l0o`<0000000D0oooo0000o`000?l0003o003o00020?l0o`T0oooo00<000000?ooo`3o
ool01`3oool20000o`<0o`3o1@3o00040?l0o`<0003o4P3oool3003o00h0oooo0`3o00060?ooo`@0
o`3o<03oool30000o`<00?l00`3o0000103oool0o`3o0?l0o`3o0?lc0?ooo`030000003e]hL0mKN7
00@0mKN700<0000008]BR02;DXP0502;DXP4000000@0n[an2P3k^gP60?bjL@030000003oool0oooo
01<0oooo00<000000?ooo`3oool0o`3oool:0?ooo`040000003oool0oooo000001@0oooo000F0?oo
o`030000003oool0oooo04`0oooo100000000`3oool000000>f_S@050>f_S@@0kZn:0`3_/8/20>na
R`030000003`/8L0l;2700@0lK260`3c/X@00`0000000?l0003o00060?l000030?l0o`3oool0o`3o
00@0o`3o0`0000020?ooo`80003o00@00?l00?l0o`3o0?l0o`3o2`3oool010000000oooo0?ooo`3o
ool20000o`03003o003o0000o`0000<0o`3o00<0o`000?l0o`3o0?l01@3o0?l0103oool0003o0000
o`000?lB0?ooo`<00?l03P3oool30?l000H0oooo0`3o0?la0?ooo`<0003o0`00o`030?l000040?oo
o`3o0?l0o`3o0?l0ocL0oooo00<000000?FgQ`3e]hL00`3e]hL00`000000Re:808]BR00@08]BR0@0
0000103j_7h00`000000n[an0?ZlOP020?ZlOPT0nk]h1@3l^W400`000000oooo0?ooo`0B0?ooo`<0
0000o`3oool=0?ooo`030000003oool0000001@0oooo000F0?ooo`030000003oool0oooo04`0oooo
00<000000?ooo`3oool00`3oool00`000000kJn=0>f_S@040>f_S@80kZn:103_/8/20>naR`030000
003`/8L0l;2700@0lK2600<0l[:60?>bQ03c/X@00P3c/X@20?l000L0o`3o0P3oool300000080oooo
0`000?l00`00o`00o`3o0?l0o`0;0?ooo`80003o00<00?l00?l0003o00000`3o00080?l0o`D0oooo
0`000?lB0?ooo`<00?l03P3oool30?l000H0oooo0`3o0?la0?ooo`<0003o0`00o`030?l000@0o`3o
>`3oool00`000000mKN70?FgQ`020?FgQ`030000002;DXP0Re:800d0Re:80`0000030?VkP`H0n[an
00@000000?ZlOP3j_7h0n[an2P3k^gP40?bjL@030000003oool0oooo00l0oooo0`0000020?ooo`03
0000003oool0oooo0?l0oooo2`3oool010000000oooo0?ooo`00000C0?ooo`005@3oool00`000000
oooo0?ooo`1=0?ooo`030000003oool0oooo00<0oooo00<000000>f_S@3][hd0103][hd00`3^[hX0
kk2;0>n`R`020>n`R`<0kk6;00<000000?2bR`3`/8L00`3a/8H00`000000l[:60?:bQP030?>bQ004
0000003o0?l0o`3o0?l0o`<0mK>1100000030?ooo`80003o00@00?l00?l0o`3o0?l0o`3o1`3oool2
0000o`L0o`001`3o0?l80?ooo`<0003o4P3oool3003o00h0oooo0`3o00060?ooo`<0o`3o<03oool4
0000o`800?l0103o00030?l0od00oooo00D000000?FgQ`3e]hL0mKN70000000;08]BR0@000001P3i
^h<70?ZlOP030000003j_7h0n[an00X0nk]h103l^W400`000000oooo0?ooo`0;0?ooo`@00000103o
ool00`000000oooo0?ooo`3o0?ooo`d0oooo00<000000?ooo`0000004`3oool001D0oooo00<00000
0?ooo`3oool0CP3oool00`000000oooo0?ooo`020?ooo`030000003][hd0kJn=00@0kJn=1@3_/8/3
0>naR`030000003`/X/0lK::0080lK:90P3b/hL00`000000l[:60?:bQP030?>bQ08000000P3e/h43
000000<0oooo0`000?l00`00o`00o`3o0?l0o`040?ooo`030000o`00o`00o`0000D0o`002@3o0?l9
0?ooo`@0003o4@3oool4003o00d0oooo103o00060?ooo`<0o`3o<03oool30000o`<00?l00`3o0000
103oool0o`3o0?l0o`3o0?m30?ooo`040000003e]hL0mKN7000000P0Re:8100000000`3g^HD0nK^3
0?VkP`070?VkP`P0n[an0P00000:0?^kN0<0o;Ya00<000000?ooo`3oool0203oool4000000L0oooo
00<000000?ooo`3oool0o`3oool?0?ooo`8000004`3oool001D0oooo00<000000?ooo`3oool0CP3o
ool00`000000oooo0?ooo`030?ooo`030000003][hd0kJn=00<0kJn=00<0k[6>0>n`R`3_/8/00P3_
/8/30>naR`030000003`/X/0lK::00<0lK:900@0l[>70?:bQP3b/XH0l[:60`3c/X@400000080mK>1
00D000000?ooo`000?l0003o003o00020?l0o`80003o1`3o00060?l0o`<0oooo0`3o0?l00`000000
oooo0?ooo`060?ooo`<0003o4P3oool3003o00h0oooo0`3o00060?ooo`@0o`3o<03oool30000o`<0
0?l00`3o0000103oool0o`3o0?l0o`3o0?m70?ooo`030000003e]hL0000000D0Re:80`0000050?Ni
Q@T0nK^32P3j_7h00`000000nk]h0?^kN0080?^kN080o;Ya00<000000?ooo`3oool01@3oool30000
00X0oooo00<000000?ooo`3oool0o`3oool?0?ooo`<000004`3oool001D0oooo00<000000?ooo`3o
ool0C`3oool00`000000oooo0?ooo`020?ooo`030000003][hd0kJn=0080kJn=0`3^/Hh00`000000
kk2;0>naR`030>naR`040000003`/X/0lK::0?6bRP80lK:90P3b/hL20?:bQP<0000000D0lk:40?Bd
Q03d]8@000000?FcP@030000o`L0o`001`3o0?l60?ooo`<0o`3o0`3oool00`000000oooo0?ooo`03
0?ooo`<0003o4P3oool3003o00h0oooo0`3o00060?ooo`<0o`3o<@3oool30000o`800?l0103o0004
0?l0od/0oooo0P0000000`2;DXP0000000000002000000P0mkV52P3i^h<:0?ZlOP030000003k^gP0
nk]h00L0nk]h0P3l^W4010000000oooo0?ooo`3oool4000000`0oooo00<000000?ooo`3oool0o`3o
ool=0?ooo`<000005P3oool001D0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`02
0?ooo`040000003][hd0kJn=0>f_S@@0k[6>00<000000>n`R`3_/H/00P3_/H/00`000000l;:;0?2b
R`020?6bRP80lK:900@0l[>700000000000000000P3b/XH00`3c/X@0m;B40?BdQ0020?BdQ0040000
o`3o0000o`000?l000L0o`3o2@3oool40?l0o`H0oooo00<000000?ooo`3oool00`000?lB0?ooo`<0
0?l03P3oool30?l000H0oooo0`3o0?l`0?ooo`@0003o0P00o`030?l000040?ooo`3o0?l0o`3o0?l0
oe00oooo0P00000<0?NiQ@X0nK^32P3j_7h00`3k^gP00000000000070?^kN0030?bjL@000000oooo
00<00000403oool00`000000oooo0?ooo`3o0?ooo`T0oooo1000000I0?ooo`005@3oool00`000000
oooo0?ooo`1@0?ooo`030000003oool0oooo0080oooo00<000000>f_S@3^/Hh01@3^/Hh01@3_/8/0
kk6;0>naR`3_/H/000000080l;:;0P3a/XX300000080l[>7103b/XH40?BdQ0040000003o0?l0o`3o
0?l0o`d0oooo0`3o0?l:0?ooo`<0003o4P3oool3003o00h0oooo0`3o00060?ooo`<0o`3o<03oool3
0000o`<00?l00`3o0000103oool0o`3o0?l0o`3o0?mE0?ooo`030000003g^HD0mkV500T0mkV52P3i
^h<:0?ZlOP<0nk]h00<000000?^kN03k^gP01@3k^gP200000180oooo00<000000?ooo`3oool0o`3o
ool70?ooo`<000007@3oool001D0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`03
000000L0k[6>00H0kk:>0>naR`3_/H/0kk6;0000003`/X/3000000<0lK:90P3b/hL40?:bQP030?l0
003d]8@0m;B40080m;B40P00000;0?ooo`<0o`3o2P3oool30000o`030000003oool0oooo00h0oooo
1000o`0=0?ooo`@0o`001@3oool40?l0oc00oooo0`000?l3003o00<0o`00103o0?mI0?ooo`030000
003g^HD0mkV500P0mkV52P3i^h<;0?ZlOP<0nk]h00<000000?^kN03k^gP0103k^gP00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0?l0oooo103oool400000200oooo000E0?ooo`030000003o
ool0oooo0540oooo0P0000020?ooo`030000003^/Hh0k[6>00D0k[6>0P3_/Xh01@3_/H/000000000
00000000l;:;00<0lK::0P3a/XT30?:cQ`<0l[:600<0m;F60?BdQ03d]8@00`3d]8@00`000000oooo
0?ooo`060?ooo`<0o`3o2@3oool40000o`<0oooo00<000000?ooo`3oool02`3oool3003o00h0oooo
0`3o00060?ooo`<0o`3o<@3oool30000o`800?l0103o00030?l0oeh0oooo00<000000?NiQ@3g^HD0
1`3g^HD:0?VkP`/0n[an103k^gP00`000000nk]h0?^kN0020?^kN0030000003oool0oooo0100oooo
00<000000?ooo`3oool0o`3oool20?ooo`<00000903oool001D0oooo00<000000?ooo`3oool0D@3o
ool00`000000oooo0?ooo`020?ooo`030000003^/Hh0k[6>00<0k[6>10000000103_/H/000000?2b
R`3`/X/30?6bRP<0lK:90P3b/hL20?:bQP80m;F61@3d]8@00`000000oooo0?ooo`030?ooo`<0o`3o
2@3oool30000o`L0oooo00<000000?ooo`3oool0203oool3003o00h0oooo0`3o00060?ooo`<0o`3o
<03oool40000o`800?l00`3o0000103oool0o`3o0?l0o`3o0?mR0?ooo`030000003g^HD0mkV500H0
mkV52P3i^h<;0?ZlOP<0nk]h1P00000@0?ooo`<00000o`3oool10?ooo`@000009`3oool001@0oooo
00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`020?ooo`030000003^/Hh0000000800000
1@3_/Xh00`000000l;:;0?2bR`030?6bRP<0lK:90`3b/hL01@3b/XH0m;F60?BeQP3d]HH0000000<0
m;B400<000000?ooo`3o0?l00`3o0?l90?ooo`<0003o2P3oool00`000000oooo0?ooo`050?ooo`<0
0?l03P3oool30?l000H0oooo0`3o0?l`0?ooo`<0003o0`00o`030?l000040?ooo`3o0?l0o`3o0?l0
ofH0oooo00<000000?NiQ@3g^HD01@3g^HD:0?VkP`/0n[an0`0000040?^kN0@000002`3oool40000
0?h0oooo1000000[0?ooo`00503oool00`000000oooo0?ooo`1C0?ooo`040000003oool0oooo0?oo
o`<000000`3^/Hh50>nbSP030000003`/hh0l;:;00<0lK::0`3a/XT30?:cQ`D0m;F60`3d]8@00`00
0000o`3o0?ooo`090?ooo`<0003o3@3oool00`000000oooo0?ooo`020?ooo`<00?l03P3oool30?l0
00D0oooo103o0?l`0?ooo`<0003o0P00o`040?l000@0o`3oJP3oool2000000D0mkV52`3i^h<70?Zl
OP<000001`3k^gP010000000oooo0?ooo`3oool3000000D0oooo1000003n0?ooo`<00000;`3oool0
01@0oooo00<000000?ooo`3oool0E03oool300000080oooo00<000000>jaSP3^/Hh01P3_/Xh00`00
0000l;>>0?2cSP040?6bRP<0lK:900<0l[>70?>eR@3c]HT0103d]HH20?BdQ0030000003oool0oooo
00L0oooo0`000?l@0?ooo`030000003oool00?l000800?l03@3oool40?l000D0oooo0`3o0?la0?oo
o`<0003o0P00o`030?l000040?ooo`3o0?l0o`3o0?l0og00oooo00<000000?NiQ@3g^HD00P3g^HD;
0?VkP`@0n[an0`0000040?ZlOPD0nk]h00<000000?ooo`3oool01@3oool700000?`0oooo1000000b
0?ooo`00503oool00`000000oooo0?ooo`1A0?ooo`@000001@3oool00`000000k[6>0>nbSP040>nb
SP040000003`/hh0l;>>0?2cSP<0lKB=00@0lK::0?6bR@3a/XT0l[F;0`3c]HT50?BeQP030?BdQ000
0000oooo00@0oooo10000?lA0?ooo`@00?l03@3oool30?l000H0oooo0`3o0?l`0?ooo`@0003o0P00
o`030?l000040?ooo`3o0?l0o`3o0?l0og@0oooo00@000000?NiQ@3g^HD0mkV52`3i^h<4000000L0
n[an103k^gP00`000000oooo0?ooo`050?ooo`D00000o03oool3000003H0oooo000D0?ooo`030000
003oool0oooo04h0oooo0`0000040?ooo`030000003oool0oooo0080oooo0P0000050>nbSP040000
003`/hh0l;>>0?2cSP@0lKB=0`3b]H/40?>eR@@0m;F600@0m;B40000003oool0oooo0`000?lB0?oo
o`<00?l00P3oool00`000000oooo0?ooo`090?ooo`<0o`001P3oool30?l0oc00oooo0`000?l3003o
00<0o`0000@0oooo0?l0o`3o0?l0o`3oN03oool00`000000mkV50?NiQ@080?VkP`<000002`3j_7h4
0?^kN0030000003oool0oooo0080oooo1@00003k0?ooo`@00000>@3oool001@0oooo00<000000?oo
o`3oool0B`3oool3000000L0oooo00<000000?ooo`0000000P0000000`3oool000000>nbSP040>nb
SP040000003`/hh0l;>>0?2cSP@0lKB=103b]H/30?>eR@D0m;F600<000000000o`000?l04P3oool3
003o00D0oooo00<000000?ooo`3oool01P3oool30?l000D0oooo103o0?l`0?ooo`<0003o0P00o`04
0?l000@0o`3oO03oool00`000000mkV50?VkP`040?VkP`<000000`3i^h<;0?ZlOP<0nk]h00<00000
0?ooo`3oool01@00003k0?ooo`<00000?@3oool001@0oooo00<000000?ooo`3oool0A`3oool40000
00/0oooo00<000000?ooo`3oool00`3oool00`000000kk:>0>nbSP020>nbSP040000003`/hh0l;>>
0?2cSP@0lKB=103b]H/40?>eR@050000003d]HH0m;F60?BeQP0000004@3oool3003o00P0oooo00<0
00000?ooo`3oool00`3oool30?l000D0oooo0`3o0?la0?ooo`<0003o0P00o`030?l000040?ooo`3o
0?l0o`3o0?l0oh40oooo00<000000?VkP`3i^h<00`0000060?VkP``0n[an00<0nk]h000000000000
1000003j0?ooo`@00000@03oool001@0oooo00<000000?ooo`3oool0A03oool300000100oooo00<0
00000?ooo`3oool00P3oool2000000<0kk:>00@000000?2cSP3`/hh0l;>>1@3a]8d30?:eR`@0lkF9
00@000000?BeQP3d]HH000003`3oool3003o00X0oooo00<000000?ooo`3oool0103o00050?ooo`<0
o`3o<03oool40000o`800?l00`3o0000103oool0o`3o0?l0o`3o0?n50?ooo`<00000203i^h<;0?Zl
OPD00000nP3oool3000004@0oooo000D0?ooo`030000003oool0oooo0440oooo0`00000D0?ooo`09
0000003oool0oooo0?ooo`000000Re:80000003_/Xh0000000@0l;>>1@3a]8d30?:eR`D0lkF90P3d
]HH00`000000oooo0?ooo`0:0?ooo`<00?l03@3oool30?l000H0oooo0`3o0?l`0?ooo`<0003o0P00
o`040?l000@0o`3oR`3oool3000000H0nK^31`3j_7h400000?X0oooo100000170?ooo`004`3oool0
0`000000oooo0?ooo`0o0?ooo`<00000603oool010000000oooo0?ooo`00000208]BR08000001@3`
/hh40?6dS@@0l[F;103c]HT20?BeQP030000003oool0oooo00L0oooo0`00o`0=0?ooo`<0o`0000<0
00000?ooo`3oool00`3oool30?l0oc00oooo0`000?l2003o00<0o`0000@0oooo0?l0o`3o0?l0o`3o
TP3oool3000000<0nK^3103j_7h400000?X0oooo0`00001;0?ooo`004`3oool00`000000oooo0?oo
o`0l0?ooo`<00000703oool00`000000oooo0000000208]BR0<00000103`/hh40?6dS@@0l[F;1@3c
]HT00`000000oooo0?ooo`050?ooo`<00?l03@3oool30?l000<0oooo00<000000?ooo`3o0?l00`3o
0?l`0?ooo`<0003o0P00o`030?l000040?ooo`3o0?l0o`3o0?l0oiP0oooo0`0000000`3j_7h00000
0000000200000?T0oooo1000001>0?ooo`004`3oool00`000000oooo0?ooo`0i0?ooo`<00000803o
ool4000000<0oooo00@000000?2cSP3`/hh0l;>>103a]8d40?:eR`@0lkF900<000000?ooo`3oool0
0`3oool3003o00d0oooo0`3o00050?ooo`<0o`3o<03oool40000o`800?l00`3o0000103oool0o`3o
0?l0o`3o0?nN0?ooo`800000n03oool400000580oooo000C0?ooo`030000003oool0oooo03D0oooo
1000000T0?ooo`8000001@3oool2000000030?2cSP3a]8d0lKB=0080lKB=103b]H/2000000030?>e
R@000000oooo0080oooo0`00o`0<0?ooo`@0o`001@3oool30?l0o`030?ooo`000000oooo02d0oooo
0`000?l2003o00@0o`00103o0?oo0?oooiT0oooo0`00001F0?ooo`004`3oool00`000000oooo0?oo
o`0b0?ooo`<00000:P3oool2000000D0oooo00<000000?6dS@3a]8d00`3a]8d40?:eR`030?>eR@00
0000oooo00<00?l0303oool30?l000H0oooo0`3o0?l40?ooo`030000003oool0oooo02T0oooo0`00
0?l2003o00<0o`0000@0oooo0?l0o`3o0?l0o`3oo`3ooonI0?ooo`@00000F@3oool001<0oooo00<0
00000?ooo`3oool0;`3oool3000002l0oooo00@000000?ooo`3oool0oooo1P0000000`3a]8d0l[F;
0?:eR`03000000800?l02`3oool40?l000H0oooo0`3o0?l70?ooo`030000003oool0oooo02H0oooo
0`000?l2003o00<0o`0000@0oooo0?l0o`3o0?l0o`3oo`3ooonI0?ooo`<00000G@3oool001<0oooo
00<000000?ooo`3oool0;03oool3000003<0oooo100000040?ooo`@000000P00o`0;0?ooo`<0o`00
1`3oool30?l0o`X0oooo00<000000?ooo`3oool08`3oool30000o`03003o003o0000o`000080o`00
00@0oooo0?l0o`3o0?l0o`3oo`3ooonH0?ooo`@00000H03oool001<0oooo00<000000?ooo`3oool0
:@3oool3000003X0oooo1000000=0?ooo`@0o`001`3oool30?l0o`d0oooo00<000000?ooo`3oool0
7`3oool40000o`05003o003o0000o`000?l0003oool0103o0?oo0?oooiP0oooo0`00001T0?ooo`00
4`3oool00`000000oooo0?ooo`0V0?ooo`<00000B`3oool30?l000P0oooo0`3o0?l@0?ooo`030000
003oool0oooo01`0oooo0`000?l2003o00<0o`0000@0oooo0?l0o`3o0?l0o`3oo`3ooonH0?ooo`@0
0000I`3oool00180oooo00<000000?ooo`3oool08`3oool4000004`0oooo0P3o00080?ooo`<0o`3o
4`3oool00`000000oooo0?ooo`0I0?ooo`<0003o0P00o`030?l000040?ooo`3o0?l0o`3o0?l0ool0
ooooV03oool3000006/0oooo000B0?ooo`030000003oool0oooo0200oooo0`00001G0?ooo`<0o`3o
5P3oool00`000000oooo0?ooo`0F0?ooo`<0003o00<00?l00?l0003o00000P3o00040?l0ool0oooo
U`3oool4000006h0oooo000B0?ooo`030000003oool0oooo01d0oooo0`00001G0?ooo`<0o`3o6@3o
ool00`000000oooo0?ooo`0B0?ooo`@0003o00D00?l00?l0003o0000o`000?ooo`030?l0ool0oooo
V03oool300000780oooo000B0?ooo`030000003oool0oooo01X0oooo0`00001I0?ooo`030?l0o`3o
ool0oooo01X0oooo00<000000?ooo`3oool03`3oool30000o`800?l00`3o0000103oool0o`3o0?l0
o`3o0?oo0?oooiL0oooo1000001e0?ooo`004P3oool00`000000oooo0?ooo`0G0?ooo`<00000N@3o
ool00`000000oooo0?ooo`0<0?ooo`<0003o00<00?l00?l0003o00000P3o0000103oool0o`3o0?l0
o`3o0?oo0?oooiH0oooo1000001i0?ooo`004P3oool00`000000oooo0?ooo`0D0?ooo`<00000O03o
ool00`000000oooo0?ooo`090?ooo`<0003o00D00?l00?l0003o0000o`000?ooo`040?l0ool0oooo
UP3oool3000007d0oooo000B0?ooo`030000003oool0oooo0140oooo0`00001n0?ooo`030000003o
ool0oooo00H0oooo10000?l01@00o`00o`000?l0003o0000oooo00<0o`3oo`3ooonF0?ooo`@00000
P03oool00180oooo00<000000?ooo`3oool03@3oool400000840oooo00<000000?ooo`3oool00`3o
ool30000o`800?l00`3o0000103oool0o`3o0?l0o`3o0?oo0?oooiH0oooo0`0000240?ooo`004P3o
ool00`000000oooo0?ooo`0:0?ooo`<00000Q@3oool00`000000oooo0?ooo`030000o`03003o003o
0000o`000080o`0000@0oooo0?l0o`3o0?l0o`3oo`3ooonE0?ooo`@00000Q`3oool00140oooo00<0
00000?ooo`3oool0203oool3000008P0oooo0`000?l01@00o`00o`000?l0003o0000oooo00@0o`3o
o`3ooonE0?ooo`<00000R`3oool00140oooo00<000000?ooo`3oool01@3oool3000008L0oooo1000
0?l01@00o`00o`000?l0003o0000oooo00<0o`3oo`3ooonE0?ooo`@00000SP3oool00140oooo00<0
00000?ooo`3oool00P3oool3000008L0oooo0`000?l00`00o`00o`000?l000020?l000040?ooo`3o
0?l0o`3o0?l0ool0ooooU@3oool300000980oooo000A0?ooo`030000003oool0000000800000Q`3o
ool30000o`05003o003o0000o`000?l0003oool0103o0?oo0?oooi@0oooo1000002E0?ooo`004@3o
ool2000008L0oooo0`000?l01@00o`00o`000?l0003o0000oooo00<0o`3o0P3oool00`000000oooo
0?ooo`3o0?oooi00oooo0`00002I0?ooo`004`3oool00`000000oooo0?ooo`220?ooo`80003o00D0
0?l00?l0003o0000o`000?ooo`030?l0o`D0oooo00<000000?ooo`3oool0o`3ooon<0?ooo`@00000
W03oool001@0oooo00<000000?ooo`3oool0P@3oool01000o`00o`000?l0003oool30?l0o`P0oooo
00<000000?ooo`3oool0o`3ooon80?ooo`@00000X03oool001D0oooo00<000000?ooo`3oool0PP3o
ool20?l0o`/0oooo00<000000?ooo`3oool0o`3ooon50?ooo`<00000Y03oool001H0oooo0P00002?
0?ooo`030000003oool0oooo0?l0ooooP@3oool400000:L0oooo000H0?ooo`030000003oool0oooo
08`0oooo00<000000?ooo`3oool0o`3ooomn0?ooo`<00000Z`3oool001T0oooo00<000000?ooo`3o
ool0R`3oool00`000000oooo0?ooo`3o0?ooogX0oooo1000002^0?ooo`006P3oool00`000000oooo
0?ooo`2:0?ooo`030000003oool0oooo0?l0ooooM`3oool300000;80oooo000K0?ooo`030000003o
ool0oooo08T0oooo00<000000?ooo`3oool0o`3ooomc0?ooo`@00000]@3oool001`0oooo0P000028
0?ooo`030000003oool0oooo0?l0ooooL@3oool300000;T0oooo000N0?ooo`030000003oool0oooo
08D0oooo00<000000?ooo`3oool0o`3ooom]0?ooo`@00000_03oool001l0oooo00<000000?ooo`3o
ool0Q03oool00`000000oooo0?ooo`3o0?ooofX0oooo0`0000300?ooo`00803oool00`000000oooo
0?ooo`230?ooo`030000003oool0oooo0?l0ooooIP3oool400000<<0oooo000Q0?ooo`800000P`3o
ool00`000000oooo0?ooo`3o0?ooof<0oooo0`0000370?ooo`008`3oool00`000000oooo0?ooo`20
0?ooo`030000003oool0oooo0?l0ooooG`3oool400000<X0oooo000T0?ooo`030000003oool0oooo
07l0oooo00<000000?ooo`3oool0o`3ooomK0?ooo`@00000cP3oool002D0oooo00<000000?ooo`3o
ool0OP3oool00`000000oooo0?ooo`3o0?oooeP0oooo0`00003B0?ooo`009P3oool2000007h0oooo
00<000000?ooo`3oool0o`3ooomD0?ooo`@00000e@3oool002P0oooo00<000000?ooo`3oool0N`3o
ool00`000000oooo0?ooo`3o0?oooe40oooo0`00003I0?ooo`00:@3oool00`000000oooo0?ooo`1j
0?ooo`030000003oool0oooo0?l0ooooC@3oool400000=`0oooo000Z0?ooo`030000003oool0oooo
07T0oooo00<000000?ooo`3oool0o`3ooom:0?ooo`<00000h03oool002/0oooo0P00001i0?ooo`03
0000003oool0oooo0?l0ooooAP3oool400000><0oooo000]0?ooo`030000003oool0oooo07H0oooo
00<000000?ooo`3oool0o`3ooom30?ooo`<00000i`3oool002h0oooo00<000000?ooo`3oool0M@3o
ool00`000000oooo0?ooo`3o0?ooocl0oooo1000003Z0?ooo`00;`3oool00`000000oooo0?ooo`1d
0?ooo`030000003oool0oooo0?l0oooo?03oool300000>h0oooo000`0?ooo`030000003oool0oooo
07<0oooo00<000000?ooo`3oool0o`3ooolh0?ooo`@00000l@3oool00340oooo0P00001b0?ooo`03
0000003oool0oooo0?l0oooo=@3oool400000?D0oooo000c0?ooo`030000003oool0oooo06l0oooo
00<000000?ooo`3oool0o`3ooolb0?ooo`<00000n@3oool003@0oooo00<000000?ooo`3oool0KP3o
ool00`000000oooo0?ooo`3o0?ooobh0oooo1000003l0?ooo`00=@3oool00`000000oooo0?ooo`1]
0?ooo`030000003oool0oooo0?l0oooo:`3oool300000?l0oooo0@3oool003H0oooo0P00001]0?oo
o`030000003oool0oooo0?l0oooo9`3oool400000?l0oooo103oool003P0oooo00<000000?ooo`3o
ool0JP3oool00`000000oooo0?ooo`3o0?ooob@0oooo0`00003o0?ooo`P0oooo000i0?ooo`030000
003oool0oooo06T0oooo00<000000?ooo`3oool0o`3ooolP0?ooo`@00000o`3oool;0?ooo`00>P3o
ool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo0?l0oooo7@3oool300000?l0oooo3`3o
ool003/0oooo0P00001X0?ooo`030000003oool0oooo0?l0oooo6@3oool400000?l0oooo4P3oool0
03d0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`3o0?oooaH0oooo0`00003o0?oo
oaH0oooo000n0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0o`3ooolB0?ooo`@0
0000o`3ooolI0?ooo`00?`3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0?l0oooo
3P3oool400000?l0oooo7@3oool00400oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?oo
o`3o0?ooo`/0oooo0`00003o0?ooob40oooo00110?ooo`800000HP3oool00`000000oooo0?ooo`3o
0?ooo`L0oooo1000003o0?ooob@0oooo00130?ooo`030000003oool0oooo05l0oooo00<000000?oo
o`3oool0o`3oool40?ooo`<00000o`3ooolX0?ooo`00A03oool00`000000oooo0?ooo`1N0?ooo`03
0000003oool0oooo0?l0oooo1000003o0?ooob/0oooo00150?ooo`030000003oool0oooo05`0oooo
00<000000?ooo`3oool0o@3oool300000?l0oooo;`3oool004H0oooo0P00001L0?ooo`030000003o
ool0oooo0?T0oooo1000003o0?oooc80oooo00180?ooo`030000003oool0oooo05T0oooo00<00000
0?ooo`3oool0mP3oool300000?l0oooo=P3oool004T0oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`3b0?ooo`@00000o`3oooli0?ooo`00BP3oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo0>l0oooo0`00003o0?ooocd0oooo001;0?ooo`800000E`3oool00`000000oooo
0?ooo`3[0?ooo`@00000o`3ooom00?ooo`00C@3oool00`000000oooo0?ooo`1D0?ooo`030000003o
ool0oooo0>P0oooo0`00003o0?oood@0oooo001>0?ooo`030000003oool0oooo05<0oooo00<00000
0?ooo`3oool0i03oool400000?l0ooooA`3oool004l0oooo00<000000?ooo`3oool0DP3oool00`00
0000oooo0?ooo`3P0?ooo`@00000o`3ooom;0?ooo`00D03oool00`000000oooo0?ooo`1A0?ooo`03
0000003oool0oooo0=d0oooo0`00003o0?ooodl0oooo001A0?ooo`800000D@3oool00`000000oooo
0?ooo`3I0?ooo`@00000o`3ooomB0?ooo`00D`3oool00`000000oooo0?ooo`1>0?ooo`030000003o
ool0oooo0=H0oooo0`00003o0?oooeH0oooo001D0?ooo`030000003oool0oooo04d0oooo00<00000
0?ooo`3oool0dP3oool400000?l0ooooF@3oool005D0oooo00<000000?ooo`3oool0C03oool00`00
0000oooo0?ooo`3?0?ooo`<00000o`3ooomM0?ooo`00EP3oool2000004`0oooo00<000000?ooo`3o
ool0b`3oool400000?l0ooooH03oool005P0oooo00<000000?ooo`3oool0B@3oool00`000000oooo
0?ooo`380?ooo`<00000o`3ooomT0?ooo`00F@3oool00`000000oooo0?ooo`180?ooo`030000003o
ool0oooo0<@0oooo1000003o0?ooofL0oooo001J0?ooo`030000003oool0oooo04H0oooo00<00000
0?ooo`3oool0`P3oool300000?l0ooooJ`3oool005/0oooo0P0000160?ooo`030000003oool0oooo
0;h0oooo1000003o0?ooofh0oooo001M0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3o
ool0^`3oool300000?l0ooooLP3oool005h0oooo00<000000?ooo`3oool0@P3oool00`000000oooo
0?ooo`2g0?ooo`@00000o`3ooome0?ooo`00G`3oool00`000000oooo0?ooo`110?ooo`030000003o
ool0oooo0;@0oooo0`00003o0?ooogT0oooo001P0?ooo`800000@@3oool00`000000oooo0?ooo`2`
0?ooo`@00000o`3oooml0?ooo`00HP3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo
0:`0oooo1000003o0?oooh00oooo001S0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3o
ool0Z@3oool300000?l0ooooQ03oool006@0oooo00<000000?ooo`3oool0?03oool00`000000oooo
0?ooo`2U0?ooo`@00000o`3ooon70?ooo`00I@3oool00`000000oooo0?ooo`0k0?ooo`030000003o
ool0oooo0:80oooo0`00003o0?oooh/0oooo001V0?ooo`800000>`3oool00`000000oooo0?ooo`2N
0?ooo`@00000o`3ooon>0?ooo`00J03oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo
09/0oooo0`00003o0?oooi80oooo001Y0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3o
ool0U`3oool400000?l0ooooU@3oool006X0oooo00<000000?ooo`3oool0=P3oool00`000000oooo
0?ooo`2D0?ooo`<00000o`3ooonI0?ooo`00J`3oool2000003H0oooo00<000000?ooo`3oool0T03o
ool400000?l0ooooW03oool006d0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`2=
0?ooo`<00000o`3ooonP0?ooo`00KP3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo
08T0oooo1000003o0?oooj<0oooo001_0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3o
ool0Q`3oool300000?l0ooooY`3oool00700oooo0P00000`0?ooo`030000003oool0oooo08<0oooo
1000003o0?ooojX0oooo001b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0P03o
ool300000?l0oooo[P3oool007<0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`1l
0?ooo`@00000o`3ooona0?ooo`00M03oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo
07P0oooo1000003o0?oookD0oooo001e0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3o
ool0M@3oool300000?l0oooo^@3oool007H0oooo0P00000Z0?ooo`030000003oool0oooo0740oooo
1000003o0?oook`0oooo001h0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0KP3o
ool300000?l0oooo`03oool007T0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`1Z
0?ooo`@00000o`3oooo30?ooo`00NP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
06L0oooo0`00003o0?ooolL0oooo001k0?ooo`8000009@3oool00`000000oooo0?ooo`1S0?ooo`@0
0000o`3oooo:0?ooo`00O@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0600oooo
0`00003o0?ooolh0oooo001n0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0G03o
ool400000?l0ooood@3oool007l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1I
0?ooo`<00000o`3ooooE0?ooo`00P03oool200000200oooo00<000000?ooo`3oool0E@3oool40000
0?l0oooof03oool00880oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1B0?ooo`<0
0000o`3ooooL0?ooo`00P`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo04l0oooo
1000003o0?oooml0oooo00240?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0C03o
ool300000?l0ooooh`3oool008D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`18
0?ooo`@00000o`3ooooV0?ooo`00QP3oool2000001T0oooo00<000000?ooo`3oool0A03oool40000
0?l0oooojP3oool008P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`110?ooo`<0
0000o`3oooo^0?ooo`00R@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo03d0oooo
1000003o0?oooo40oooo002:0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0>P3o
ool300000?l0oooom@3oool008/0oooo0P00000D0?ooo`030000003oool0oooo03H0oooo1000003o
0?ooooP0oooo002=0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0<`3oool30000
0?l0ooooo03oool008h0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0_0?ooo`@0
0000o`3ooooo0?ooo`00S`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo02`0oooo
0`00003o0?ooool0oooo103oool00900oooo0P00000?0?ooo`030000003oool0oooo02P0oooo1000
003o0?ooool0oooo1`3oool00980oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0U
0?ooo`<00000o`3ooooo0?ooo`/0oooo002C0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool08@3oool400000?l0ooooo`3oool>0?ooo`00U03oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo01h0oooo0`00003o0?ooool0oooo4P3oool009D0oooo0P00000:0?ooo`030000
003oool0oooo01X0oooo1000003o0?ooool0oooo5@3oool009L0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0G0?ooo`<00000o`3ooooo0?oooaT0oooo002H0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0503oool400000?l0ooooo`3ooolL0?ooo`00V@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0100oooo1000003o0?ooool0oooo803oool009X0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`<00000o`3ooooo0?ooob@0
oooo002K0?ooo`8000000`3oool00`000000oooo0?ooo`090?ooo`@00000o`3ooooo0?ooobL0oooo
002M0?ooo`040000003oool0oooo000000P0oooo0`00003o0?ooool0oooo:`3oool009h0oooo00<0
00000?ooo`000000103oool400000?l0ooooo`3oool^0?ooo`00W`3oool2000000040?ooo`000000
000000000?l0ooooo`3ooolb0?ooo`00X03oool200000?l0ooooo`3ooole0?ooo`00o`3ooooo0?oo
omL0oooo003o0?ooool0ooooe`3oool00?l0ooooo`3ooooG0?ooo`00o`3ooooo0?ooomL0oooo003o
0?ooool0ooooe`3oool00?l0ooooo`3ooooG0?ooo`00o`3ooooo0?ooomL0oooo003o0?ooool0oooo
e`3oool00?l0ooooo`3ooooG0?ooo`00o`3ooooo0?ooomL0oooo003o0?ooool0ooooe`3oool00001
\
\>"],
  ImageRangeCache->{{{0, 724}, {542.812, 0}} -> {0.0128436, 0.106086, \
0.00136398, 0.00136398}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ShowSystem[testsys, PlotType \[Rule] TopView, \ 
        PlotRange \[Rule] {{1400, 1500}, {\(-30\), 30}}, 
        ShowArrows \[Rule] False, Frame \[Rule] True];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .6 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-14 0.01 0.3 0.01 [
[.2 -0.0125 -12 -9 ]
[.2 -0.0125 12 0 ]
[.4 -0.0125 -12 -9 ]
[.4 -0.0125 12 0 ]
[.6 -0.0125 -12 -9 ]
[.6 -0.0125 12 0 ]
[.8 -0.0125 -12 -9 ]
[.8 -0.0125 12 0 ]
[1 -0.0125 -12 -9 ]
[1 -0.0125 12 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .1 -18 -4.5 ]
[-0.0125 .1 0 4.5 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .3 -6 -4.5 ]
[-0.0125 .3 0 4.5 ]
[-0.0125 .4 -12 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .5 -12 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .6 -12 -4.5 ]
[-0.0125 .6 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .6 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .6 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(1420)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(1440)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(1460)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(1480)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1500)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .1 m
.00625 .1 L
s
[(-20)] -0.0125 .1 1 0 Mshowa
0 .2 m
.00625 .2 L
s
[(-10)] -0.0125 .2 1 0 Mshowa
0 .3 m
.00625 .3 L
s
[(0)] -0.0125 .3 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(10)] -0.0125 .4 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(20)] -0.0125 .5 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(30)] -0.0125 .6 1 0 Mshowa
.125 Mabswid
0 .02 m
.00375 .02 L
s
0 .04 m
.00375 .04 L
s
0 .06 m
.00375 .06 L
s
0 .08 m
.00375 .08 L
s
0 .12 m
.00375 .12 L
s
0 .14 m
.00375 .14 L
s
0 .16 m
.00375 .16 L
s
0 .18 m
.00375 .18 L
s
0 .22 m
.00375 .22 L
s
0 .24 m
.00375 .24 L
s
0 .26 m
.00375 .26 L
s
0 .28 m
.00375 .28 L
s
0 .32 m
.00375 .32 L
s
0 .34 m
.00375 .34 L
s
0 .36 m
.00375 .36 L
s
0 .38 m
.00375 .38 L
s
0 .42 m
.00375 .42 L
s
0 .44 m
.00375 .44 L
s
0 .46 m
.00375 .46 L
s
0 .48 m
.00375 .48 L
s
0 .52 m
.00375 .52 L
s
0 .54 m
.00375 .54 L
s
0 .56 m
.00375 .56 L
s
0 .58 m
.00375 .58 L
s
.25 Mabswid
0 0 m
0 .6 L
s
0 .59375 m
0 .6 L
s
.2 .59375 m
.2 .6 L
s
.4 .59375 m
.4 .6 L
s
.6 .59375 m
.6 .6 L
s
.8 .59375 m
.8 .6 L
s
.125 Mabswid
.05 .59625 m
.05 .6 L
s
.1 .59625 m
.1 .6 L
s
.15 .59625 m
.15 .6 L
s
.25 .59625 m
.25 .6 L
s
.3 .59625 m
.3 .6 L
s
.35 .59625 m
.35 .6 L
s
.45 .59625 m
.45 .6 L
s
.5 .59625 m
.5 .6 L
s
.55 .59625 m
.55 .6 L
s
.65 .59625 m
.65 .6 L
s
.7 .59625 m
.7 .6 L
s
.75 .59625 m
.75 .6 L
s
.85 .59625 m
.85 .6 L
s
.9 .59625 m
.9 .6 L
s
.95 .59625 m
.95 .6 L
s
.25 Mabswid
0 .6 m
1 .6 L
s
.99375 0 m
1 0 L
s
.99375 .1 m
1 .1 L
s
.99375 .2 m
1 .2 L
s
.99375 .3 m
1 .3 L
s
.99375 .4 m
1 .4 L
s
.99375 .5 m
1 .5 L
s
.125 Mabswid
.99625 .02 m
1 .02 L
s
.99625 .04 m
1 .04 L
s
.99625 .06 m
1 .06 L
s
.99625 .08 m
1 .08 L
s
.99625 .12 m
1 .12 L
s
.99625 .14 m
1 .14 L
s
.99625 .16 m
1 .16 L
s
.99625 .18 m
1 .18 L
s
.99625 .22 m
1 .22 L
s
.99625 .24 m
1 .24 L
s
.99625 .26 m
1 .26 L
s
.99625 .28 m
1 .28 L
s
.99625 .32 m
1 .32 L
s
.99625 .34 m
1 .34 L
s
.99625 .36 m
1 .36 L
s
.99625 .38 m
1 .38 L
s
.99625 .42 m
1 .42 L
s
.99625 .44 m
1 .44 L
s
.99625 .46 m
1 .46 L
s
.99625 .48 m
1 .48 L
s
.99625 .52 m
1 .52 L
s
.99625 .54 m
1 .54 L
s
.99625 .56 m
1 .56 L
s
.99625 .58 m
1 .58 L
s
.25 Mabswid
1 0 m
1 .6 L
s
0 0 m
1 0 L
1 .6 L
0 .6 L
closepath
clip
newpath
.5 g
-3.01371 -3.6 m
-2.01378 -3.6 L
-2.01378 -2.99167 L
-2.94174 -2.99167 L
-3.01371 -3.6 L
F
-2.94174 -2.99167 m
-2.01378 -2.99167 L
-2.01378 -2.38333 L
-2.88199 -2.38333 L
-2.94174 -2.99167 L
F
-2.88199 -2.38333 m
-2.01378 -2.38333 L
-2.01378 -1.775 L
-2.83445 -1.775 L
-2.88199 -2.38333 L
F
-2.83445 -1.775 m
-2.01378 -1.775 L
-2.01378 -1.16667 L
-2.79908 -1.16667 L
-2.83445 -1.775 L
F
-2.79908 -1.16667 m
-2.01378 -1.16667 L
-2.01378 -0.55833 L
-2.77587 -0.55833 L
-2.79908 -1.16667 L
F
-2.77587 -0.55833 m
-2.01378 -0.55833 L
-2.01378 .05 L
-2.76481 .05 L
-2.77587 -0.55833 L
F
0 g
.5 Mabswid
.5 g
-2.76481 .55 m
-2.01378 .55 L
-2.01378 1.15833 L
-2.77587 1.15833 L
-2.76481 .55 L
F
-2.77587 1.15833 m
-2.01378 1.15833 L
-2.01378 1.76667 L
-2.79908 1.76667 L
-2.77587 1.15833 L
F
-2.79908 1.76667 m
-2.01378 1.76667 L
-2.01378 2.375 L
-2.83445 2.375 L
-2.79908 1.76667 L
F
-2.83445 2.375 m
-2.01378 2.375 L
-2.01378 2.98333 L
-2.88199 2.98333 L
-2.83445 2.375 L
F
-2.88199 2.98333 m
-2.01378 2.98333 L
-2.01378 3.59167 L
-2.94174 3.59167 L
-2.88199 2.98333 L
F
-2.94174 3.59167 m
-2.01378 3.59167 L
-2.01378 4.2 L
-3.01371 4.2 L
-2.94174 3.59167 L
F
0 g
.5 g
-3.01371 .3 m
-2.01378 .3 L
-2.01378 .3 L
-2.94174 .3 L
-3.01371 .3 L
F
-2.94174 .3 m
-2.01378 .3 L
-2.01378 .3 L
-2.88199 .3 L
-2.94174 .3 L
F
-2.88199 .3 m
-2.01378 .3 L
-2.01378 .3 L
-2.83445 .3 L
-2.88199 .3 L
F
-2.83445 .3 m
-2.01378 .3 L
-2.01378 .3 L
-2.79908 .3 L
-2.83445 .3 L
F
-2.79908 .3 m
-2.01378 .3 L
-2.01378 .3 L
-2.77587 .3 L
-2.79908 .3 L
F
-2.77587 .3 m
-2.01378 .3 L
-2.01378 .3 L
-2.76481 .3 L
-2.77587 .3 L
F
0 g
.5 g
-2.76481 .3 m
-2.01378 .3 L
-2.01378 .3 L
-2.77587 .3 L
-2.76481 .3 L
F
-2.77587 .3 m
-2.01378 .3 L
-2.01378 .3 L
-2.79908 .3 L
-2.77587 .3 L
F
-2.79908 .3 m
-2.01378 .3 L
-2.01378 .3 L
-2.83445 .3 L
-2.79908 .3 L
F
-2.83445 .3 m
-2.01378 .3 L
-2.01378 .3 L
-2.88199 .3 L
-2.83445 .3 L
F
-2.88199 .3 m
-2.01378 .3 L
-2.01378 .3 L
-2.94174 .3 L
-2.88199 .3 L
F
-2.94174 .3 m
-2.01378 .3 L
-2.01378 .3 L
-3.01371 .3 L
-2.94174 .3 L
F
0 g
.5 g
-13.0512 1.6335 m
-13.25 1.6335 L
-13.25 1.189 L
-13.0227 1.189 L
-13.0512 1.6335 L
F
-13.0227 1.189 m
-13.25 1.189 L
-13.25 .7445 L
-13.0057 .7445 L
-13.0227 1.189 L
F
-13.0057 .7445 m
-13.25 .7445 L
-13.25 .3 L
-13 .3 L
-13.0057 .7445 L
F
-13 .3 m
-13.25 .3 L
-13.25 -0.1445 L
-13.0057 -0.1445 L
-13 .3 L
F
-13.0057 -0.1445 m
-13.25 -0.1445 L
-13.25 -0.589 L
-13.0227 -0.589 L
-13.0057 -0.1445 L
F
-13.0227 -0.589 m
-13.25 -0.589 L
-13.25 -1.0335 L
-13.0512 -1.0335 L
-13.0227 -0.589 L
F
0 g
.5 g
-13.0512 .3 m
-13.25 .3 L
-13.25 .3 L
-13.0227 .3 L
-13.0512 .3 L
F
-13.0227 .3 m
-13.25 .3 L
-13.25 .3 L
-13.0057 .3 L
-13.0227 .3 L
F
-13.0057 .3 m
-13.25 .3 L
-13.25 .3 L
-13 .3 L
-13.0057 .3 L
F
-13 .3 m
-13.25 .3 L
-13.25 .3 L
-13.0057 .3 L
-13 .3 L
F
-13.0057 .3 m
-13.25 .3 L
-13.25 .3 L
-13.0227 .3 L
-13.0057 .3 L
F
-13.0227 .3 m
-13.25 .3 L
-13.25 .3 L
-13.0512 .3 L
-13.0227 .3 L
F
0 g
.5 g
-2.76481 .55 m
-2.79908 1.76667 L
-2.79908 1.71669 L
-2.76481 .54148 L
-2.76481 .55 L
F
-2.76481 .54148 m
-2.79908 1.71669 L
-2.79908 1.57017 L
-2.76481 .51651 L
-2.76481 .54148 L
F
-2.76481 .51651 m
-2.79908 1.57017 L
-2.79908 1.33709 L
-2.76481 .47678 L
-2.76481 .51651 L
F
-2.76481 .47678 m
-2.79908 1.33709 L
-2.79908 1.03333 L
-2.76481 .425 L
-2.76481 .47678 L
F
-2.76481 .425 m
-2.79908 1.03333 L
-2.79908 .6796 L
-2.76481 .3647 L
-2.76481 .425 L
F
-2.76481 .3647 m
-2.79908 .6796 L
-2.79908 .3 L
-2.76481 .3 L
-2.76481 .3647 L
F
-2.76481 .3 m
-2.79908 .3 L
-2.79908 -0.0796 L
-2.76481 .2353 L
-2.76481 .3 L
F
-2.76481 .2353 m
-2.79908 -0.0796 L
-2.79908 -0.43333 L
-2.76481 .175 L
-2.76481 .2353 L
F
-2.76481 .175 m
-2.79908 -0.43333 L
-2.79908 -0.73709 L
-2.76481 .12322 L
-2.76481 .175 L
F
-2.76481 .12322 m
-2.79908 -0.73709 L
-2.79908 -0.97017 L
-2.76481 .08349 L
-2.76481 .12322 L
F
-2.76481 .08349 m
-2.79908 -0.97017 L
-2.79908 -1.11669 L
-2.76481 .05852 L
-2.76481 .08349 L
F
-2.76481 .05852 m
-2.79908 -1.11669 L
-2.79908 -1.16667 L
-2.76481 .05 L
-2.76481 .05852 L
F
-2.76481 .05 m
-2.79908 -1.16667 L
-2.79908 -1.11669 L
-2.76481 .05852 L
-2.76481 .05 L
F
-2.76481 .05852 m
-2.79908 -1.11669 L
-2.79908 -0.97017 L
-2.76481 .08349 L
-2.76481 .05852 L
F
-2.76481 .08349 m
-2.79908 -0.97017 L
-2.79908 -0.73709 L
-2.76481 .12322 L
-2.76481 .08349 L
F
-2.76481 .12322 m
-2.79908 -0.73709 L
-2.79908 -0.43333 L
-2.76481 .175 L
-2.76481 .12322 L
F
-2.76481 .175 m
-2.79908 -0.43333 L
-2.79908 -0.0796 L
-2.76481 .2353 L
-2.76481 .175 L
F
-2.76481 .2353 m
-2.79908 -0.0796 L
-2.79908 .3 L
-2.76481 .3 L
-2.76481 .2353 L
F
-2.76481 .3 m
-2.79908 .3 L
-2.79908 .6796 L
-2.76481 .3647 L
-2.76481 .3 L
F
-2.76481 .3647 m
-2.79908 .6796 L
-2.79908 1.03333 L
-2.76481 .425 L
-2.76481 .3647 L
F
-2.76481 .425 m
-2.79908 1.03333 L
-2.79908 1.33709 L
-2.76481 .47678 L
-2.76481 .425 L
F
-2.76481 .47678 m
-2.79908 1.33709 L
-2.79908 1.57017 L
-2.76481 .51651 L
-2.76481 .47678 L
F
-2.76481 .51651 m
-2.79908 1.57017 L
-2.79908 1.71669 L
-2.76481 .54148 L
-2.76481 .51651 L
F
-2.76481 .54148 m
-2.79908 1.71669 L
-2.79908 1.76667 L
-2.76481 .55 L
-2.76481 .54148 L
F
-2.79908 1.76667 m
-2.88199 2.98333 L
-2.88199 2.8919 L
-2.79908 1.71669 L
-2.79908 1.76667 L
F
-2.79908 1.71669 m
-2.88199 2.8919 L
-2.88199 2.62383 L
-2.79908 1.57017 L
-2.79908 1.71669 L
F
-2.79908 1.57017 m
-2.88199 2.62383 L
-2.88199 2.1974 L
-2.79908 1.33709 L
-2.79908 1.57017 L
F
-2.79908 1.33709 m
-2.88199 2.1974 L
-2.88199 1.64167 L
-2.79908 1.03333 L
-2.79908 1.33709 L
F
-2.79908 1.03333 m
-2.88199 1.64167 L
-2.88199 .9945 L
-2.79908 .6796 L
-2.79908 1.03333 L
F
-2.79908 .6796 m
-2.88199 .9945 L
-2.88199 .3 L
-2.79908 .3 L
-2.79908 .6796 L
F
-2.79908 .3 m
-2.88199 .3 L
-2.88199 -0.3945 L
-2.79908 -0.0796 L
-2.79908 .3 L
F
-2.79908 -0.0796 m
-2.88199 -0.3945 L
-2.88199 -1.04167 L
-2.79908 -0.43333 L
-2.79908 -0.0796 L
F
-2.79908 -0.43333 m
-2.88199 -1.04167 L
-2.88199 -1.5974 L
-2.79908 -0.73709 L
-2.79908 -0.43333 L
F
-2.79908 -0.73709 m
-2.88199 -1.5974 L
-2.88199 -2.02383 L
-2.79908 -0.97017 L
-2.79908 -0.73709 L
F
-2.79908 -0.97017 m
-2.88199 -2.02383 L
-2.88199 -2.2919 L
-2.79908 -1.11669 L
-2.79908 -0.97017 L
F
-2.79908 -1.11669 m
-2.88199 -2.2919 L
-2.88199 -2.38333 L
-2.79908 -1.16667 L
-2.79908 -1.11669 L
F
-2.79908 -1.16667 m
-2.88199 -2.38333 L
-2.88199 -2.2919 L
-2.79908 -1.11669 L
-2.79908 -1.16667 L
F
-2.79908 -1.11669 m
-2.88199 -2.2919 L
-2.88199 -2.02383 L
-2.79908 -0.97017 L
-2.79908 -1.11669 L
F
-2.79908 -0.97017 m
-2.88199 -2.02383 L
-2.88199 -1.5974 L
-2.79908 -0.73709 L
-2.79908 -0.97017 L
F
-2.79908 -0.73709 m
-2.88199 -1.5974 L
-2.88199 -1.04167 L
-2.79908 -0.43333 L
-2.79908 -0.73709 L
F
-2.79908 -0.43333 m
-2.88199 -1.04167 L
-2.88199 -0.3945 L
-2.79908 -0.0796 L
-2.79908 -0.43333 L
F
-2.79908 -0.0796 m
-2.88199 -0.3945 L
-2.88199 .3 L
-2.79908 .3 L
-2.79908 -0.0796 L
F
-2.79908 .3 m
-2.88199 .3 L
-2.88199 .9945 L
-2.79908 .6796 L
-2.79908 .3 L
F
-2.79908 .6796 m
-2.88199 .9945 L
-2.88199 1.64167 L
-2.79908 1.03333 L
-2.79908 .6796 L
F
-2.79908 1.03333 m
-2.88199 1.64167 L
-2.88199 2.1974 L
-2.79908 1.33709 L
-2.79908 1.03333 L
F
-2.79908 1.33709 m
-2.88199 2.1974 L
-2.88199 2.62383 L
-2.79908 1.57017 L
-2.79908 1.33709 L
F
-2.79908 1.57017 m
-2.88199 2.62383 L
-2.88199 2.8919 L
-2.79908 1.71669 L
-2.79908 1.57017 L
F
-2.79908 1.71669 m
-2.88199 2.8919 L
-2.88199 2.98333 L
-2.79908 1.76667 L
-2.79908 1.71669 L
F
-2.88199 2.98333 m
-3.01371 4.2 L
-3.01371 4.06711 L
-2.88199 2.8919 L
-2.88199 2.98333 L
F
-2.88199 2.8919 m
-3.01371 4.06711 L
-3.01371 3.6775 L
-2.88199 2.62383 L
-2.88199 2.8919 L
F
-2.88199 2.62383 m
-3.01371 3.6775 L
-3.01371 3.05772 L
-2.88199 2.1974 L
-2.88199 2.62383 L
F
-2.88199 2.1974 m
-3.01371 3.05772 L
-3.01371 2.25 L
-2.88199 1.64167 L
-2.88199 2.1974 L
F
-2.88199 1.64167 m
-3.01371 2.25 L
-3.01371 1.30939 L
-2.88199 .9945 L
-2.88199 1.64167 L
F
-2.88199 .9945 m
-3.01371 1.30939 L
-3.01371 .3 L
-2.88199 .3 L
-2.88199 .9945 L
F
-2.88199 .3 m
-3.01371 .3 L
-3.01371 -0.70939 L
-2.88199 -0.3945 L
-2.88199 .3 L
F
-2.88199 -0.3945 m
-3.01371 -0.70939 L
-3.01371 -1.65 L
-2.88199 -1.04167 L
-2.88199 -0.3945 L
F
-2.88199 -1.04167 m
-3.01371 -1.65 L
-3.01371 -2.45772 L
-2.88199 -1.5974 L
-2.88199 -1.04167 L
F
-2.88199 -1.5974 m
-3.01371 -2.45772 L
-3.01371 -3.0775 L
-2.88199 -2.02383 L
-2.88199 -1.5974 L
F
-2.88199 -2.02383 m
-3.01371 -3.0775 L
-3.01371 -3.46711 L
-2.88199 -2.2919 L
-2.88199 -2.02383 L
F
-2.88199 -2.2919 m
-3.01371 -3.46711 L
-3.01371 -3.6 L
-2.88199 -2.38333 L
-2.88199 -2.2919 L
F
-2.88199 -2.38333 m
-3.01371 -3.6 L
-3.01371 -3.46711 L
-2.88199 -2.2919 L
-2.88199 -2.38333 L
F
-2.88199 -2.2919 m
-3.01371 -3.46711 L
-3.01371 -3.0775 L
-2.88199 -2.02383 L
-2.88199 -2.2919 L
F
-2.88199 -2.02383 m
-3.01371 -3.0775 L
-3.01371 -2.45772 L
-2.88199 -1.5974 L
-2.88199 -2.02383 L
F
-2.88199 -1.5974 m
-3.01371 -2.45772 L
-3.01371 -1.65 L
-2.88199 -1.04167 L
-2.88199 -1.5974 L
F
-2.88199 -1.04167 m
-3.01371 -1.65 L
-3.01371 -0.70939 L
-2.88199 -0.3945 L
-2.88199 -1.04167 L
F
-2.88199 -0.3945 m
-3.01371 -0.70939 L
-3.01371 .3 L
-2.88199 .3 L
-2.88199 -0.3945 L
F
-2.88199 .3 m
-3.01371 .3 L
-3.01371 1.30939 L
-2.88199 .9945 L
-2.88199 .3 L
F
-2.88199 .9945 m
-3.01371 1.30939 L
-3.01371 2.25 L
-2.88199 1.64167 L
-2.88199 .9945 L
F
-2.88199 1.64167 m
-3.01371 2.25 L
-3.01371 3.05772 L
-2.88199 2.1974 L
-2.88199 1.64167 L
F
-2.88199 2.1974 m
-3.01371 3.05772 L
-3.01371 3.6775 L
-2.88199 2.62383 L
-2.88199 2.1974 L
F
-2.88199 2.62383 m
-3.01371 3.6775 L
-3.01371 4.06711 L
-2.88199 2.8919 L
-2.88199 2.62383 L
F
-2.88199 2.8919 m
-3.01371 4.06711 L
-3.01371 4.2 L
-2.88199 2.98333 L
-2.88199 2.8919 L
F
0 g
.5 g
-13 .3 m
-13.0057 -0.1445 L
-13.0057 -0.12935 L
-13 .3 L
-13 .3 L
F
-13.0057 -0.1445 m
-13.0227 -0.589 L
-13.0227 -0.55871 L
-13.0057 -0.12935 L
-13.0057 -0.1445 L
F
-13.0227 -0.589 m
-13.0512 -1.0335 L
-13.0512 -0.98806 L
-13.0227 -0.55871 L
-13.0227 -0.589 L
F
-13 .3 m
-13.0057 -0.12935 L
-13.0057 -0.08495 L
-13 .3 L
-13 .3 L
F
-13.0057 -0.12935 m
-13.0227 -0.55871 L
-13.0227 -0.4699 L
-13.0057 -0.08495 L
-13.0057 -0.12935 L
F
-13.0227 -0.55871 m
-13.0512 -0.98806 L
-13.0512 -0.85484 L
-13.0227 -0.4699 L
-13.0227 -0.55871 L
F
-13 .3 m
-13.0057 -0.08495 L
-13.0057 -0.01431 L
-13 .3 L
-13 .3 L
F
-13.0057 -0.08495 m
-13.0227 -0.4699 L
-13.0227 -0.32862 L
-13.0057 -0.01431 L
-13.0057 -0.08495 L
F
-13.0227 -0.4699 m
-13.0512 -0.85484 L
-13.0512 -0.64293 L
-13.0227 -0.32862 L
-13.0227 -0.4699 L
F
-13 .3 m
-13.0057 -0.01431 L
-13.0057 .07775 L
-13 .3 L
-13 .3 L
F
-13.0057 -0.01431 m
-13.0227 -0.32862 L
-13.0227 -0.1445 L
-13.0057 .07775 L
-13.0057 -0.01431 L
F
-13.0227 -0.32862 m
-13.0512 -0.64293 L
-13.0512 -0.36675 L
-13.0227 -0.1445 L
-13.0227 -0.32862 L
F
-13 .3 m
-13.0057 .07775 L
-13.0057 .18495 L
-13 .3 L
-13 .3 L
F
-13.0057 .07775 m
-13.0227 -0.1445 L
-13.0227 .06991 L
-13.0057 .18495 L
-13.0057 .07775 L
F
-13.0227 -0.1445 m
-13.0512 -0.36675 L
-13.0512 -0.04514 L
-13.0227 .06991 L
-13.0227 -0.1445 L
F
-13 .3 m
-13.0057 .18495 L
-13.0057 .3 L
-13 .3 L
-13 .3 L
F
-13.0057 .18495 m
-13.0227 .06991 L
-13.0227 .3 L
-13.0057 .3 L
-13.0057 .18495 L
F
-13.0227 .06991 m
-13.0512 -0.04514 L
-13.0512 .3 L
-13.0227 .3 L
-13.0227 .06991 L
F
-13 .3 m
-13.0057 .3 L
-13.0057 .41505 L
-13 .3 L
-13 .3 L
F
-13.0057 .3 m
-13.0227 .3 L
-13.0227 .53009 L
-13.0057 .41505 L
-13.0057 .3 L
F
-13.0227 .3 m
-13.0512 .3 L
-13.0512 .64514 L
-13.0227 .53009 L
-13.0227 .3 L
F
-13 .3 m
-13.0057 .41505 L
-13.0057 .52225 L
-13 .3 L
-13 .3 L
F
-13.0057 .41505 m
-13.0227 .53009 L
-13.0227 .7445 L
-13.0057 .52225 L
-13.0057 .41505 L
F
-13.0227 .53009 m
-13.0512 .64514 L
-13.0512 .96675 L
-13.0227 .7445 L
-13.0227 .53009 L
F
-13 .3 m
-13.0057 .52225 L
-13.0057 .61431 L
-13 .3 L
-13 .3 L
F
-13.0057 .52225 m
-13.0227 .7445 L
-13.0227 .92862 L
-13.0057 .61431 L
-13.0057 .52225 L
F
-13.0227 .7445 m
-13.0512 .96675 L
-13.0512 1.24293 L
-13.0227 .92862 L
-13.0227 .7445 L
F
-13 .3 m
-13.0057 .61431 L
-13.0057 .68495 L
-13 .3 L
-13 .3 L
F
-13.0057 .61431 m
-13.0227 .92862 L
-13.0227 1.0699 L
-13.0057 .68495 L
-13.0057 .61431 L
F
-13.0227 .92862 m
-13.0512 1.24293 L
-13.0512 1.45484 L
-13.0227 1.0699 L
-13.0227 .92862 L
F
-13 .3 m
-13.0057 .68495 L
-13.0057 .72935 L
-13 .3 L
-13 .3 L
F
-13.0057 .68495 m
-13.0227 1.0699 L
-13.0227 1.15871 L
-13.0057 .72935 L
-13.0057 .68495 L
F
-13.0227 1.0699 m
-13.0512 1.45484 L
-13.0512 1.58806 L
-13.0227 1.15871 L
-13.0227 1.0699 L
F
-13 .3 m
-13.0057 .72935 L
-13.0057 .7445 L
-13 .3 L
-13 .3 L
F
-13.0057 .72935 m
-13.0227 1.15871 L
-13.0227 1.189 L
-13.0057 .7445 L
-13.0057 .72935 L
F
-13.0227 1.15871 m
-13.0512 1.58806 L
-13.0512 1.6335 L
-13.0227 1.189 L
-13.0227 1.15871 L
F
-13 .3 m
-13.0057 .7445 L
-13.0057 .72935 L
-13 .3 L
-13 .3 L
F
-13.0057 .7445 m
-13.0227 1.189 L
-13.0227 1.15871 L
-13.0057 .72935 L
-13.0057 .7445 L
F
-13.0227 1.189 m
-13.0512 1.6335 L
-13.0512 1.58806 L
-13.0227 1.15871 L
-13.0227 1.189 L
F
-13 .3 m
-13.0057 .72935 L
-13.0057 .68495 L
-13 .3 L
-13 .3 L
F
-13.0057 .72935 m
-13.0227 1.15871 L
-13.0227 1.0699 L
-13.0057 .68495 L
-13.0057 .72935 L
F
-13.0227 1.15871 m
-13.0512 1.58806 L
-13.0512 1.45484 L
-13.0227 1.0699 L
-13.0227 1.15871 L
F
-13 .3 m
-13.0057 .68495 L
-13.0057 .61431 L
-13 .3 L
-13 .3 L
F
-13.0057 .68495 m
-13.0227 1.0699 L
-13.0227 .92862 L
-13.0057 .61431 L
-13.0057 .68495 L
F
-13.0227 1.0699 m
-13.0512 1.45484 L
-13.0512 1.24293 L
-13.0227 .92862 L
-13.0227 1.0699 L
F
-13 .3 m
-13.0057 .61431 L
-13.0057 .52225 L
-13 .3 L
-13 .3 L
F
-13.0057 .61431 m
-13.0227 .92862 L
-13.0227 .7445 L
-13.0057 .52225 L
-13.0057 .61431 L
F
-13.0227 .92862 m
-13.0512 1.24293 L
-13.0512 .96675 L
-13.0227 .7445 L
-13.0227 .92862 L
F
-13 .3 m
-13.0057 .52225 L
-13.0057 .41505 L
-13 .3 L
-13 .3 L
F
-13.0057 .52225 m
-13.0227 .7445 L
-13.0227 .53009 L
-13.0057 .41505 L
-13.0057 .52225 L
F
-13.0227 .7445 m
-13.0512 .96675 L
-13.0512 .64514 L
-13.0227 .53009 L
-13.0227 .7445 L
F
-13 .3 m
-13.0057 .41505 L
-13.0057 .3 L
-13 .3 L
-13 .3 L
F
-13.0057 .41505 m
-13.0227 .53009 L
-13.0227 .3 L
-13.0057 .3 L
-13.0057 .41505 L
F
-13.0227 .53009 m
-13.0512 .64514 L
-13.0512 .3 L
-13.0227 .3 L
-13.0227 .53009 L
F
-13 .3 m
-13.0057 .3 L
-13.0057 .18495 L
-13 .3 L
-13 .3 L
F
-13.0057 .3 m
-13.0227 .3 L
-13.0227 .06991 L
-13.0057 .18495 L
-13.0057 .3 L
F
-13.0227 .3 m
-13.0512 .3 L
-13.0512 -0.04514 L
-13.0227 .06991 L
-13.0227 .3 L
F
-13 .3 m
-13.0057 .18495 L
-13.0057 .07775 L
-13 .3 L
-13 .3 L
F
-13.0057 .18495 m
-13.0227 .06991 L
-13.0227 -0.1445 L
-13.0057 .07775 L
-13.0057 .18495 L
F
-13.0227 .06991 m
-13.0512 -0.04514 L
-13.0512 -0.36675 L
-13.0227 -0.1445 L
-13.0227 .06991 L
F
-13 .3 m
-13.0057 .07775 L
-13.0057 -0.01431 L
-13 .3 L
-13 .3 L
F
-13.0057 .07775 m
-13.0227 -0.1445 L
-13.0227 -0.32862 L
-13.0057 -0.01431 L
-13.0057 .07775 L
F
-13.0227 -0.1445 m
-13.0512 -0.36675 L
-13.0512 -0.64293 L
-13.0227 -0.32862 L
-13.0227 -0.1445 L
F
-13 .3 m
-13.0057 -0.01431 L
-13.0057 -0.08495 L
-13 .3 L
-13 .3 L
F
-13.0057 -0.01431 m
-13.0227 -0.32862 L
-13.0227 -0.4699 L
-13.0057 -0.08495 L
-13.0057 -0.01431 L
F
-13.0227 -0.32862 m
-13.0512 -0.64293 L
-13.0512 -0.85484 L
-13.0227 -0.4699 L
-13.0227 -0.32862 L
F
-13 .3 m
-13.0057 -0.08495 L
-13.0057 -0.12935 L
-13 .3 L
-13 .3 L
F
-13.0057 -0.08495 m
-13.0227 -0.4699 L
-13.0227 -0.55871 L
-13.0057 -0.12935 L
-13.0057 -0.08495 L
F
-13.0227 -0.4699 m
-13.0512 -0.85484 L
-13.0512 -0.98806 L
-13.0227 -0.55871 L
-13.0227 -0.4699 L
F
-13 .3 m
-13.0057 -0.12935 L
-13.0057 -0.1445 L
-13 .3 L
-13 .3 L
F
-13.0057 -0.12935 m
-13.0227 -0.55871 L
-13.0227 -0.589 L
-13.0057 -0.1445 L
-13.0057 -0.12935 L
F
-13.0227 -0.55871 m
-13.0512 -0.98806 L
-13.0512 -1.0335 L
-13.0227 -0.589 L
-13.0227 -0.55871 L
F
0 g
.5 g
-1.23378 .3375 m
-1.23378 .36667 L
-1.23378 .3644 L
-1.23378 .33622 L
-1.23378 .3375 L
F
-1.23378 .33622 m
-1.23378 .3644 L
-1.23378 .35774 L
-1.23378 .33248 L
-1.23378 .33622 L
F
-1.23378 .33248 m
-1.23378 .35774 L
-1.23378 .34714 L
-1.23378 .32652 L
-1.23378 .33248 L
F
-1.23378 .32652 m
-1.23378 .34714 L
-1.23378 .33333 L
-1.23378 .31875 L
-1.23378 .32652 L
F
-1.23378 .31875 m
-1.23378 .33333 L
-1.23378 .31725 L
-1.23378 .30971 L
-1.23378 .31875 L
F
-1.23378 .30971 m
-1.23378 .31725 L
-1.23378 .3 L
-1.23378 .3 L
-1.23378 .30971 L
F
-1.23378 .3 m
-1.23378 .3 L
-1.23378 .28275 L
-1.23378 .29029 L
-1.23378 .3 L
F
-1.23378 .29029 m
-1.23378 .28275 L
-1.23378 .26667 L
-1.23378 .28125 L
-1.23378 .29029 L
F
-1.23378 .28125 m
-1.23378 .26667 L
-1.23378 .25286 L
-1.23378 .27348 L
-1.23378 .28125 L
F
-1.23378 .27348 m
-1.23378 .25286 L
-1.23378 .24226 L
-1.23378 .26752 L
-1.23378 .27348 L
F
-1.23378 .26752 m
-1.23378 .24226 L
-1.23378 .2356 L
-1.23378 .26378 L
-1.23378 .26752 L
F
-1.23378 .26378 m
-1.23378 .2356 L
-1.23378 .23333 L
-1.23378 .2625 L
-1.23378 .26378 L
F
-1.23378 .2625 m
-1.23378 .23333 L
-1.23378 .2356 L
-1.23378 .26378 L
-1.23378 .2625 L
F
-1.23378 .26378 m
-1.23378 .2356 L
-1.23378 .24226 L
-1.23378 .26752 L
-1.23378 .26378 L
F
-1.23378 .26752 m
-1.23378 .24226 L
-1.23378 .25286 L
-1.23378 .27348 L
-1.23378 .26752 L
F
-1.23378 .27348 m
-1.23378 .25286 L
-1.23378 .26667 L
-1.23378 .28125 L
-1.23378 .27348 L
F
-1.23378 .28125 m
-1.23378 .26667 L
-1.23378 .28275 L
-1.23378 .29029 L
-1.23378 .28125 L
F
-1.23378 .29029 m
-1.23378 .28275 L
-1.23378 .3 L
-1.23378 .3 L
-1.23378 .29029 L
F
-1.23378 .3 m
-1.23378 .3 L
-1.23378 .31725 L
-1.23378 .30971 L
-1.23378 .3 L
F
-1.23378 .30971 m
-1.23378 .31725 L
-1.23378 .33333 L
-1.23378 .31875 L
-1.23378 .30971 L
F
-1.23378 .31875 m
-1.23378 .33333 L
-1.23378 .34714 L
-1.23378 .32652 L
-1.23378 .31875 L
F
-1.23378 .32652 m
-1.23378 .34714 L
-1.23378 .35774 L
-1.23378 .33248 L
-1.23378 .32652 L
F
-1.23378 .33248 m
-1.23378 .35774 L
-1.23378 .3644 L
-1.23378 .33622 L
-1.23378 .33248 L
F
-1.23378 .33622 m
-1.23378 .3644 L
-1.23378 .36667 L
-1.23378 .3375 L
-1.23378 .33622 L
F
-1.23378 .36667 m
-1.23378 .39583 L
-1.23378 .39257 L
-1.23378 .3644 L
-1.23378 .36667 L
F
-1.23378 .3644 m
-1.23378 .39257 L
-1.23378 .38299 L
-1.23378 .35774 L
-1.23378 .3644 L
F
-1.23378 .35774 m
-1.23378 .38299 L
-1.23378 .36776 L
-1.23378 .34714 L
-1.23378 .35774 L
F
-1.23378 .34714 m
-1.23378 .36776 L
-1.23378 .34792 L
-1.23378 .33333 L
-1.23378 .34714 L
F
-1.23378 .33333 m
-1.23378 .34792 L
-1.23378 .3248 L
-1.23378 .31725 L
-1.23378 .33333 L
F
-1.23378 .31725 m
-1.23378 .3248 L
-1.23378 .3 L
-1.23378 .3 L
-1.23378 .31725 L
F
-1.23378 .3 m
-1.23378 .3 L
-1.23378 .2752 L
-1.23378 .28275 L
-1.23378 .3 L
F
-1.23378 .28275 m
-1.23378 .2752 L
-1.23378 .25208 L
-1.23378 .26667 L
-1.23378 .28275 L
F
-1.23378 .26667 m
-1.23378 .25208 L
-1.23378 .23224 L
-1.23378 .25286 L
-1.23378 .26667 L
F
-1.23378 .25286 m
-1.23378 .23224 L
-1.23378 .21701 L
-1.23378 .24226 L
-1.23378 .25286 L
F
-1.23378 .24226 m
-1.23378 .21701 L
-1.23378 .20743 L
-1.23378 .2356 L
-1.23378 .24226 L
F
-1.23378 .2356 m
-1.23378 .20743 L
-1.23378 .20417 L
-1.23378 .23333 L
-1.23378 .2356 L
F
-1.23378 .23333 m
-1.23378 .20417 L
-1.23378 .20743 L
-1.23378 .2356 L
-1.23378 .23333 L
F
-1.23378 .2356 m
-1.23378 .20743 L
-1.23378 .21701 L
-1.23378 .24226 L
-1.23378 .2356 L
F
-1.23378 .24226 m
-1.23378 .21701 L
-1.23378 .23224 L
-1.23378 .25286 L
-1.23378 .24226 L
F
-1.23378 .25286 m
-1.23378 .23224 L
-1.23378 .25208 L
-1.23378 .26667 L
-1.23378 .25286 L
F
-1.23378 .26667 m
-1.23378 .25208 L
-1.23378 .2752 L
-1.23378 .28275 L
-1.23378 .26667 L
F
-1.23378 .28275 m
-1.23378 .2752 L
-1.23378 .3 L
-1.23378 .3 L
-1.23378 .28275 L
F
-1.23378 .3 m
-1.23378 .3 L
-1.23378 .3248 L
-1.23378 .31725 L
-1.23378 .3 L
F
-1.23378 .31725 m
-1.23378 .3248 L
-1.23378 .34792 L
-1.23378 .33333 L
-1.23378 .31725 L
F
-1.23378 .33333 m
-1.23378 .34792 L
-1.23378 .36776 L
-1.23378 .34714 L
-1.23378 .33333 L
F
-1.23378 .34714 m
-1.23378 .36776 L
-1.23378 .38299 L
-1.23378 .35774 L
-1.23378 .34714 L
F
-1.23378 .35774 m
-1.23378 .38299 L
-1.23378 .39257 L
-1.23378 .3644 L
-1.23378 .35774 L
F
-1.23378 .3644 m
-1.23378 .39257 L
-1.23378 .39583 L
-1.23378 .36667 L
-1.23378 .3644 L
F
-1.23378 .39583 m
-1.23378 .425 L
-1.23378 .42074 L
-1.23378 .39257 L
-1.23378 .39583 L
F
-1.23378 .39257 m
-1.23378 .42074 L
-1.23378 .40825 L
-1.23378 .38299 L
-1.23378 .39257 L
F
-1.23378 .38299 m
-1.23378 .40825 L
-1.23378 .38839 L
-1.23378 .36776 L
-1.23378 .38299 L
F
-1.23378 .36776 m
-1.23378 .38839 L
-1.23378 .3625 L
-1.23378 .34792 L
-1.23378 .36776 L
F
-1.23378 .34792 m
-1.23378 .3625 L
-1.23378 .33235 L
-1.23378 .3248 L
-1.23378 .34792 L
F
-1.23378 .3248 m
-1.23378 .33235 L
-1.23378 .3 L
-1.23378 .3 L
-1.23378 .3248 L
F
-1.23378 .3 m
-1.23378 .3 L
-1.23378 .26765 L
-1.23378 .2752 L
-1.23378 .3 L
F
-1.23378 .2752 m
-1.23378 .26765 L
-1.23378 .2375 L
-1.23378 .25208 L
-1.23378 .2752 L
F
-1.23378 .25208 m
-1.23378 .2375 L
-1.23378 .21161 L
-1.23378 .23224 L
-1.23378 .25208 L
F
-1.23378 .23224 m
-1.23378 .21161 L
-1.23378 .19175 L
-1.23378 .21701 L
-1.23378 .23224 L
F
-1.23378 .21701 m
-1.23378 .19175 L
-1.23378 .17926 L
-1.23378 .20743 L
-1.23378 .21701 L
F
-1.23378 .20743 m
-1.23378 .17926 L
-1.23378 .175 L
-1.23378 .20417 L
-1.23378 .20743 L
F
-1.23378 .20417 m
-1.23378 .175 L
-1.23378 .17926 L
-1.23378 .20743 L
-1.23378 .20417 L
F
-1.23378 .20743 m
-1.23378 .17926 L
-1.23378 .19175 L
-1.23378 .21701 L
-1.23378 .20743 L
F
-1.23378 .21701 m
-1.23378 .19175 L
-1.23378 .21161 L
-1.23378 .23224 L
-1.23378 .21701 L
F
-1.23378 .23224 m
-1.23378 .21161 L
-1.23378 .2375 L
-1.23378 .25208 L
-1.23378 .23224 L
F
-1.23378 .25208 m
-1.23378 .2375 L
-1.23378 .26765 L
-1.23378 .2752 L
-1.23378 .25208 L
F
-1.23378 .2752 m
-1.23378 .26765 L
-1.23378 .3 L
-1.23378 .3 L
-1.23378 .2752 L
F
-1.23378 .3 m
-1.23378 .3 L
-1.23378 .33235 L
-1.23378 .3248 L
-1.23378 .3 L
F
-1.23378 .3248 m
-1.23378 .33235 L
-1.23378 .3625 L
-1.23378 .34792 L
-1.23378 .3248 L
F
-1.23378 .34792 m
-1.23378 .3625 L
-1.23378 .38839 L
-1.23378 .36776 L
-1.23378 .34792 L
F
-1.23378 .36776 m
-1.23378 .38839 L
-1.23378 .40825 L
-1.23378 .38299 L
-1.23378 .36776 L
F
-1.23378 .38299 m
-1.23378 .40825 L
-1.23378 .42074 L
-1.23378 .39257 L
-1.23378 .38299 L
F
-1.23378 .39257 m
-1.23378 .42074 L
-1.23378 .425 L
-1.23378 .39583 L
-1.23378 .39257 L
F
0 g
.5 g
-1.1633 .175 m
-1.17298 .175 L
-1.17298 .21667 L
-1.20026 .21667 L
-1.1633 .175 L
F
-1.20026 .21667 m
-1.17298 .21667 L
-1.17298 .25833 L
-1.21824 .25833 L
-1.20026 .21667 L
F
-1.21824 .25833 m
-1.17298 .25833 L
-1.17298 .3 L
-1.22378 .3 L
-1.21824 .25833 L
F
-1.22378 .3 m
-1.17298 .3 L
-1.17298 .34167 L
-1.21824 .34167 L
-1.22378 .3 L
F
-1.21824 .34167 m
-1.17298 .34167 L
-1.17298 .38333 L
-1.20026 .38333 L
-1.21824 .34167 L
F
-1.20026 .38333 m
-1.17298 .38333 L
-1.17298 .425 L
-1.1633 .425 L
-1.20026 .38333 L
F
0 g
.5 g
-1.1633 .3 m
-1.17298 .3 L
-1.17298 .3 L
-1.20026 .3 L
-1.1633 .3 L
F
-1.20026 .3 m
-1.17298 .3 L
-1.17298 .3 L
-1.21824 .3 L
-1.20026 .3 L
F
-1.21824 .3 m
-1.17298 .3 L
-1.17298 .3 L
-1.22378 .3 L
-1.21824 .3 L
F
-1.22378 .3 m
-1.17298 .3 L
-1.17298 .3 L
-1.21824 .3 L
-1.22378 .3 L
F
-1.21824 .3 m
-1.17298 .3 L
-1.17298 .3 L
-1.20026 .3 L
-1.21824 .3 L
F
-1.20026 .3 m
-1.17298 .3 L
-1.17298 .3 L
-1.1633 .3 L
-1.20026 .3 L
F
0 g
.5 g
.11892 .05 m
.16297 .05 L
.18877 .13333 L
.13462 .13333 L
.11892 .05 L
F
.13462 .13333 m
.18877 .13333 L
.20378 .21667 L
.14393 .21667 L
.13462 .13333 L
F
.14393 .21667 m
.20378 .21667 L
.20872 .3 L
.14702 .3 L
.14393 .21667 L
F
.14702 .3 m
.20872 .3 L
.20378 .38333 L
.14393 .38333 L
.14702 .3 L
F
.14393 .38333 m
.20378 .38333 L
.18877 .46667 L
.13462 .46667 L
.14393 .38333 L
F
.13462 .46667 m
.18877 .46667 L
.16297 .55 L
.11892 .55 L
.13462 .46667 L
F
0 g
.11892 .05 m
.13462 .13333 L
.14393 .21667 L
.14702 .3 L
.14393 .38333 L
.13462 .46667 L
.11892 .55 L
.16297 .55 L
.18877 .46667 L
.20378 .38333 L
.20872 .3 L
.20378 .21667 L
.18877 .13333 L
.16297 .05 L
.11892 .05 L
s
.5 g
.11892 .3 m
.16297 .3 L
.18877 .3 L
.13462 .3 L
.11892 .3 L
F
.13462 .3 m
.18877 .3 L
.20378 .3 L
.14393 .3 L
.13462 .3 L
F
.14393 .3 m
.20378 .3 L
.20872 .3 L
.14702 .3 L
.14393 .3 L
F
.14702 .3 m
.20872 .3 L
.20378 .3 L
.14393 .3 L
.14702 .3 L
F
.14393 .3 m
.20378 .3 L
.18877 .3 L
.13462 .3 L
.14393 .3 L
F
.13462 .3 m
.18877 .3 L
.16297 .3 L
.11892 .3 L
.13462 .3 L
F
0 g
.11892 .3 m
.13462 .3 L
.14393 .3 L
.14702 .3 L
.14393 .3 L
.13462 .3 L
.11892 .3 L
.16297 .3 L
.18877 .3 L
.20378 .3 L
.20872 .3 L
.20378 .3 L
.18877 .3 L
.16297 .3 L
.11892 .3 L
s
.11892 .55 m
.16297 .55 L
.16297 .54148 L
.11892 .54148 L
.11892 .55 L
s
.11892 .54148 m
.16297 .54148 L
.16297 .51651 L
.11892 .51651 L
.11892 .54148 L
s
.11892 .51651 m
.16297 .51651 L
.16297 .47678 L
.11892 .47678 L
.11892 .51651 L
s
.11892 .47678 m
.16297 .47678 L
.16297 .425 L
.11892 .425 L
.11892 .47678 L
s
.11892 .425 m
.16297 .425 L
.16297 .3647 L
.11892 .3647 L
.11892 .425 L
s
.11892 .3647 m
.16297 .3647 L
.16297 .3 L
.11892 .3 L
.11892 .3647 L
s
.11892 .3 m
.16297 .3 L
.16297 .2353 L
.11892 .2353 L
.11892 .3 L
s
.11892 .2353 m
.16297 .2353 L
.16297 .175 L
.11892 .175 L
.11892 .2353 L
s
.11892 .175 m
.16297 .175 L
.16297 .12322 L
.11892 .12322 L
.11892 .175 L
s
.11892 .12322 m
.16297 .12322 L
.16297 .08349 L
.11892 .08349 L
.11892 .12322 L
s
.11892 .08349 m
.16297 .08349 L
.16297 .05852 L
.11892 .05852 L
.11892 .08349 L
s
.11892 .05852 m
.16297 .05852 L
.16297 .05 L
.11892 .05 L
.11892 .05852 L
s
.11892 .05 m
.16297 .05 L
.16297 .05852 L
.11892 .05852 L
.11892 .05 L
s
.11892 .05852 m
.16297 .05852 L
.16297 .08349 L
.11892 .08349 L
.11892 .05852 L
s
.11892 .08349 m
.16297 .08349 L
.16297 .12322 L
.11892 .12322 L
.11892 .08349 L
s
.11892 .12322 m
.16297 .12322 L
.16297 .175 L
.11892 .175 L
.11892 .12322 L
s
.11892 .175 m
.16297 .175 L
.16297 .2353 L
.11892 .2353 L
.11892 .175 L
s
.11892 .2353 m
.16297 .2353 L
.16297 .3 L
.11892 .3 L
.11892 .2353 L
s
.11892 .3 m
.16297 .3 L
.16297 .3647 L
.11892 .3647 L
.11892 .3 L
s
.11892 .3647 m
.16297 .3647 L
.16297 .425 L
.11892 .425 L
.11892 .3647 L
s
.11892 .425 m
.16297 .425 L
.16297 .47678 L
.11892 .47678 L
.11892 .425 L
s
.11892 .47678 m
.16297 .47678 L
.16297 .51651 L
.11892 .51651 L
.11892 .47678 L
s
.11892 .51651 m
.16297 .51651 L
.16297 .54148 L
.11892 .54148 L
.11892 .51651 L
s
.11892 .54148 m
.16297 .54148 L
.16297 .55 L
.11892 .55 L
.11892 .54148 L
s
.5 g
.25032 .05 m
.3106 .05 L
.29502 .13333 L
.23895 .13333 L
.25032 .05 L
F
.23895 .13333 m
.29502 .13333 L
.28578 .21667 L
.23217 .21667 L
.23895 .13333 L
F
.23217 .21667 m
.28578 .21667 L
.28272 .3 L
.22992 .3 L
.23217 .21667 L
F
.22992 .3 m
.28272 .3 L
.28578 .38333 L
.23217 .38333 L
.22992 .3 L
F
.23217 .38333 m
.28578 .38333 L
.29502 .46667 L
.23895 .46667 L
.23217 .38333 L
F
.23895 .46667 m
.29502 .46667 L
.3106 .55 L
.25032 .55 L
.23895 .46667 L
F
0 g
.25032 .05 m
.23895 .13333 L
.23217 .21667 L
.22992 .3 L
.23217 .38333 L
.23895 .46667 L
.25032 .55 L
.3106 .55 L
.29502 .46667 L
.28578 .38333 L
.28272 .3 L
.28578 .21667 L
.29502 .13333 L
.3106 .05 L
.25032 .05 L
s
.5 g
.25032 .3 m
.3106 .3 L
.29502 .3 L
.23895 .3 L
.25032 .3 L
F
.23895 .3 m
.29502 .3 L
.28578 .3 L
.23217 .3 L
.23895 .3 L
F
.23217 .3 m
.28578 .3 L
.28272 .3 L
.22992 .3 L
.23217 .3 L
F
.22992 .3 m
.28272 .3 L
.28578 .3 L
.23217 .3 L
.22992 .3 L
F
.23217 .3 m
.28578 .3 L
.29502 .3 L
.23895 .3 L
.23217 .3 L
F
.23895 .3 m
.29502 .3 L
.3106 .3 L
.25032 .3 L
.23895 .3 L
F
0 g
.25032 .3 m
.23895 .3 L
.23217 .3 L
.22992 .3 L
.23217 .3 L
.23895 .3 L
.25032 .3 L
.3106 .3 L
.29502 .3 L
.28578 .3 L
.28272 .3 L
.28578 .3 L
.29502 .3 L
.3106 .3 L
.25032 .3 L
s
.25032 .55 m
.3106 .55 L
.3106 .54148 L
.25032 .54148 L
.25032 .55 L
s
.25032 .54148 m
.3106 .54148 L
.3106 .51651 L
.25032 .51651 L
.25032 .54148 L
s
.25032 .51651 m
.3106 .51651 L
.3106 .47678 L
.25032 .47678 L
.25032 .51651 L
s
.25032 .47678 m
.3106 .47678 L
.3106 .425 L
.25032 .425 L
.25032 .47678 L
s
.25032 .425 m
.3106 .425 L
.3106 .3647 L
.25032 .3647 L
.25032 .425 L
s
.25032 .3647 m
.3106 .3647 L
.3106 .3 L
.25032 .3 L
.25032 .3647 L
s
.25032 .3 m
.3106 .3 L
.3106 .2353 L
.25032 .2353 L
.25032 .3 L
s
.25032 .2353 m
.3106 .2353 L
.3106 .175 L
.25032 .175 L
.25032 .2353 L
s
.25032 .175 m
.3106 .175 L
.3106 .12322 L
.25032 .12322 L
.25032 .175 L
s
.25032 .12322 m
.3106 .12322 L
.3106 .08349 L
.25032 .08349 L
.25032 .12322 L
s
.25032 .08349 m
.3106 .08349 L
.3106 .05852 L
.25032 .05852 L
.25032 .08349 L
s
.25032 .05852 m
.3106 .05852 L
.3106 .05 L
.25032 .05 L
.25032 .05852 L
s
.25032 .05 m
.3106 .05 L
.3106 .05852 L
.25032 .05852 L
.25032 .05 L
s
.25032 .05852 m
.3106 .05852 L
.3106 .08349 L
.25032 .08349 L
.25032 .05852 L
s
.25032 .08349 m
.3106 .08349 L
.3106 .12322 L
.25032 .12322 L
.25032 .08349 L
s
.25032 .12322 m
.3106 .12322 L
.3106 .175 L
.25032 .175 L
.25032 .12322 L
s
.25032 .175 m
.3106 .175 L
.3106 .2353 L
.25032 .2353 L
.25032 .175 L
s
.25032 .2353 m
.3106 .2353 L
.3106 .3 L
.25032 .3 L
.25032 .2353 L
s
.25032 .3 m
.3106 .3 L
.3106 .3647 L
.25032 .3647 L
.25032 .3 L
s
.25032 .3647 m
.3106 .3647 L
.3106 .425 L
.25032 .425 L
.25032 .3647 L
s
.25032 .425 m
.3106 .425 L
.3106 .47678 L
.25032 .47678 L
.25032 .425 L
s
.25032 .47678 m
.3106 .47678 L
.3106 .51651 L
.25032 .51651 L
.25032 .47678 L
s
.25032 .51651 m
.3106 .51651 L
.3106 .54148 L
.25032 .54148 L
.25032 .51651 L
s
.25032 .54148 m
.3106 .54148 L
.3106 .55 L
.25032 .55 L
.25032 .54148 L
s
.5 g
.30719 .05 m
.37265 .05 L
.39327 .13333 L
.30315 .13333 L
.30719 .05 L
F
.30315 .13333 m
.39327 .13333 L
.40541 .21667 L
.30073 .21667 L
.30315 .13333 L
F
.30073 .21667 m
.40541 .21667 L
.40942 .3 L
.29992 .3 L
.30073 .21667 L
F
.29992 .3 m
.40942 .3 L
.40541 .38333 L
.30073 .38333 L
.29992 .3 L
F
.30073 .38333 m
.40541 .38333 L
.39327 .46667 L
.30315 .46667 L
.30073 .38333 L
F
.30315 .46667 m
.39327 .46667 L
.37265 .55 L
.30719 .55 L
.30315 .46667 L
F
0 g
.30719 .05 m
.30315 .13333 L
.30073 .21667 L
.29992 .3 L
.30073 .38333 L
.30315 .46667 L
.30719 .55 L
.37265 .55 L
.39327 .46667 L
.40541 .38333 L
.40942 .3 L
.40541 .21667 L
.39327 .13333 L
.37265 .05 L
.30719 .05 L
s
.5 g
.30719 .3 m
.37265 .3 L
.39327 .3 L
.30315 .3 L
.30719 .3 L
F
.30315 .3 m
.39327 .3 L
.40541 .3 L
.30073 .3 L
.30315 .3 L
F
.30073 .3 m
.40541 .3 L
.40942 .3 L
.29992 .3 L
.30073 .3 L
F
.29992 .3 m
.40942 .3 L
.40541 .3 L
.30073 .3 L
.29992 .3 L
F
.30073 .3 m
.40541 .3 L
.39327 .3 L
.30315 .3 L
.30073 .3 L
F
.30315 .3 m
.39327 .3 L
.37265 .3 L
.30719 .3 L
.30315 .3 L
F
0 g
.30719 .3 m
.30315 .3 L
.30073 .3 L
.29992 .3 L
.30073 .3 L
.30315 .3 L
.30719 .3 L
.37265 .3 L
.39327 .3 L
.40541 .3 L
.40942 .3 L
.40541 .3 L
.39327 .3 L
.37265 .3 L
.30719 .3 L
s
.30719 .55 m
.37265 .55 L
.37265 .54148 L
.30719 .54148 L
.30719 .55 L
s
.30719 .54148 m
.37265 .54148 L
.37265 .51651 L
.30719 .51651 L
.30719 .54148 L
s
.30719 .51651 m
.37265 .51651 L
.37265 .47678 L
.30719 .47678 L
.30719 .51651 L
s
.30719 .47678 m
.37265 .47678 L
.37265 .425 L
.30719 .425 L
.30719 .47678 L
s
.30719 .425 m
.37265 .425 L
.37265 .3647 L
.30719 .3647 L
.30719 .425 L
s
.30719 .3647 m
.37265 .3647 L
.37265 .3 L
.30719 .3 L
.30719 .3647 L
s
.30719 .3 m
.37265 .3 L
.37265 .2353 L
.30719 .2353 L
.30719 .3 L
s
.30719 .2353 m
.37265 .2353 L
.37265 .175 L
.30719 .175 L
.30719 .2353 L
s
.30719 .175 m
.37265 .175 L
.37265 .12322 L
.30719 .12322 L
.30719 .175 L
s
.30719 .12322 m
.37265 .12322 L
.37265 .08349 L
.30719 .08349 L
.30719 .12322 L
s
.30719 .08349 m
.37265 .08349 L
.37265 .05852 L
.30719 .05852 L
.30719 .08349 L
s
.30719 .05852 m
.37265 .05852 L
.37265 .05 L
.30719 .05 L
.30719 .05852 L
s
.30719 .05 m
.37265 .05 L
.37265 .05852 L
.30719 .05852 L
.30719 .05 L
s
.30719 .05852 m
.37265 .05852 L
.37265 .08349 L
.30719 .08349 L
.30719 .05852 L
s
.30719 .08349 m
.37265 .08349 L
.37265 .12322 L
.30719 .12322 L
.30719 .08349 L
s
.30719 .12322 m
.37265 .12322 L
.37265 .175 L
.30719 .175 L
.30719 .12322 L
s
.30719 .175 m
.37265 .175 L
.37265 .2353 L
.30719 .2353 L
.30719 .175 L
s
.30719 .2353 m
.37265 .2353 L
.37265 .3 L
.30719 .3 L
.30719 .2353 L
s
.30719 .3 m
.37265 .3 L
.37265 .3647 L
.30719 .3647 L
.30719 .3 L
s
.30719 .3647 m
.37265 .3647 L
.37265 .425 L
.30719 .425 L
.30719 .3647 L
s
.30719 .425 m
.37265 .425 L
.37265 .47678 L
.30719 .47678 L
.30719 .425 L
s
.30719 .47678 m
.37265 .47678 L
.37265 .51651 L
.30719 .51651 L
.30719 .47678 L
s
.30719 .51651 m
.37265 .51651 L
.37265 .54148 L
.30719 .54148 L
.30719 .51651 L
s
.30719 .54148 m
.37265 .54148 L
.37265 .55 L
.30719 .55 L
.30719 .54148 L
s
.5 g
1.98742 -0.02476 m
1.98742 -0.02476 L
1.92492 .08349 L
1.92492 .08349 L
1.98742 -0.02476 L
F
1.92492 .08349 m
1.92492 .08349 L
1.86242 .19175 L
1.86242 .19175 L
1.92492 .08349 L
F
1.86242 .19175 m
1.86242 .19175 L
1.79992 .3 L
1.79992 .3 L
1.86242 .19175 L
F
1.79992 .3 m
1.79992 .3 L
1.73742 .40825 L
1.73742 .40825 L
1.79992 .3 L
F
1.73742 .40825 m
1.73742 .40825 L
1.67492 .51651 L
1.67492 .51651 L
1.73742 .40825 L
F
1.67492 .51651 m
1.67492 .51651 L
1.61242 .62476 L
1.61242 .62476 L
1.67492 .51651 L
F
0 g
.5 g
1.79992 .3 m
1.79992 .3 L
1.79992 .3 L
1.79992 .3 L
1.79992 .3 L
F
1.79992 .3 m
1.79992 .3 L
1.79992 .3 L
1.79992 .3 L
1.79992 .3 L
F
1.79992 .3 m
1.79992 .3 L
1.79992 .3 L
1.79992 .3 L
1.79992 .3 L
F
1.79992 .3 m
1.79992 .3 L
1.79992 .3 L
1.79992 .3 L
1.79992 .3 L
F
1.79992 .3 m
1.79992 .3 L
1.79992 .3 L
1.79992 .3 L
1.79992 .3 L
F
1.79992 .3 m
1.79992 .3 L
1.79992 .3 L
1.79992 .3 L
1.79992 .3 L
F
0 g
.5 g
3.48742 -0.02476 m
3.48742 -0.02476 L
3.42492 .08349 L
3.42492 .08349 L
3.48742 -0.02476 L
F
3.42492 .08349 m
3.42492 .08349 L
3.36242 .19175 L
3.36242 .19175 L
3.42492 .08349 L
F
3.36242 .19175 m
3.36242 .19175 L
3.29992 .3 L
3.29992 .3 L
3.36242 .19175 L
F
3.29992 .3 m
3.29992 .3 L
3.23742 .40825 L
3.23742 .40825 L
3.29992 .3 L
F
3.23742 .40825 m
3.23742 .40825 L
3.17492 .51651 L
3.17492 .51651 L
3.23742 .40825 L
F
3.17492 .51651 m
3.17492 .51651 L
3.11242 .62476 L
3.11242 .62476 L
3.17492 .51651 L
F
0 g
.5 g
3.29992 .3 m
3.29992 .3 L
3.29992 .3 L
3.29992 .3 L
3.29992 .3 L
F
3.29992 .3 m
3.29992 .3 L
3.29992 .3 L
3.29992 .3 L
3.29992 .3 L
F
3.29992 .3 m
3.29992 .3 L
3.29992 .3 L
3.29992 .3 L
3.29992 .3 L
F
3.29992 .3 m
3.29992 .3 L
3.29992 .3 L
3.29992 .3 L
3.29992 .3 L
F
3.29992 .3 m
3.29992 .3 L
3.29992 .3 L
3.29992 .3 L
3.29992 .3 L
F
3.29992 .3 m
3.29992 .3 L
3.29992 .3 L
3.29992 .3 L
3.29992 .3 L
F
0 g
.5 g
1.12139 -1.52476 m
1.12139 -1.52476 L
1.05889 -1.41651 L
1.05889 -1.41651 L
1.12139 -1.52476 L
F
1.05889 -1.41651 m
1.05889 -1.41651 L
.99639 -1.30825 L
.99639 -1.30825 L
1.05889 -1.41651 L
F
.99639 -1.30825 m
.99639 -1.30825 L
.93389 -1.2 L
.93389 -1.2 L
.99639 -1.30825 L
F
.93389 -1.2 m
.93389 -1.2 L
.87139 -1.09175 L
.87139 -1.09175 L
.93389 -1.2 L
F
.87139 -1.09175 m
.87139 -1.09175 L
.80889 -0.98349 L
.80889 -0.98349 L
.87139 -1.09175 L
F
.80889 -0.98349 m
.80889 -0.98349 L
.74639 -0.87524 L
.74639 -0.87524 L
.80889 -0.98349 L
F
0 g
.5 g
.93389 -1.2 m
.93389 -1.2 L
.93389 -1.2 L
.93389 -1.2 L
.93389 -1.2 L
F
.93389 -1.2 m
.93389 -1.2 L
.93389 -1.2 L
.93389 -1.2 L
.93389 -1.2 L
F
.93389 -1.2 m
.93389 -1.2 L
.93389 -1.2 L
.93389 -1.2 L
.93389 -1.2 L
F
.93389 -1.2 m
.93389 -1.2 L
.93389 -1.2 L
.93389 -1.2 L
.93389 -1.2 L
F
.93389 -1.2 m
.93389 -1.2 L
.93389 -1.2 L
.93389 -1.2 L
.93389 -1.2 L
F
.93389 -1.2 m
.93389 -1.2 L
.93389 -1.2 L
.93389 -1.2 L
.93389 -1.2 L
F
0 g
.5 g
5.25271 .05 m
5.25992 .05 L
5.25992 .13333 L
5.21686 .13333 L
5.25271 .05 L
F
5.21686 .13333 m
5.25992 .13333 L
5.25992 .21667 L
5.19652 .21667 L
5.21686 .13333 L
F
5.19652 .21667 m
5.25992 .21667 L
5.25992 .3 L
5.18992 .3 L
5.19652 .21667 L
F
5.18992 .3 m
5.25992 .3 L
5.25992 .38333 L
5.19652 .38333 L
5.18992 .3 L
F
5.19652 .38333 m
5.25992 .38333 L
5.25992 .46667 L
5.21686 .46667 L
5.19652 .38333 L
F
5.21686 .46667 m
5.25992 .46667 L
5.25992 .55 L
5.25271 .55 L
5.21686 .46667 L
F
0 g
.5 g
5.25271 .3 m
5.25992 .3 L
5.25992 .3 L
5.21686 .3 L
5.25271 .3 L
F
5.21686 .3 m
5.25992 .3 L
5.25992 .3 L
5.19652 .3 L
5.21686 .3 L
F
5.19652 .3 m
5.25992 .3 L
5.25992 .3 L
5.18992 .3 L
5.19652 .3 L
F
5.18992 .3 m
5.25992 .3 L
5.25992 .3 L
5.19652 .3 L
5.18992 .3 L
F
5.19652 .3 m
5.25992 .3 L
5.25992 .3 L
5.21686 .3 L
5.19652 .3 L
F
5.21686 .3 m
5.25992 .3 L
5.25992 .3 L
5.25271 .3 L
5.21686 .3 L
F
0 g
.5 g
2.88668 -1.45 m
2.89389 -1.45 L
2.89389 -1.36667 L
2.85083 -1.36667 L
2.88668 -1.45 L
F
2.85083 -1.36667 m
2.89389 -1.36667 L
2.89389 -1.28333 L
2.8305 -1.28333 L
2.85083 -1.36667 L
F
2.8305 -1.28333 m
2.89389 -1.28333 L
2.89389 -1.2 L
2.82389 -1.2 L
2.8305 -1.28333 L
F
2.82389 -1.2 m
2.89389 -1.2 L
2.89389 -1.11667 L
2.8305 -1.11667 L
2.82389 -1.2 L
F
2.8305 -1.11667 m
2.89389 -1.11667 L
2.89389 -1.03333 L
2.85083 -1.03333 L
2.8305 -1.11667 L
F
2.85083 -1.03333 m
2.89389 -1.03333 L
2.89389 -0.95 L
2.88668 -0.95 L
2.85083 -1.03333 L
F
0 g
.5 g
2.88668 -1.2 m
2.89389 -1.2 L
2.89389 -1.2 L
2.85083 -1.2 L
2.88668 -1.2 L
F
2.85083 -1.2 m
2.89389 -1.2 L
2.89389 -1.2 L
2.8305 -1.2 L
2.85083 -1.2 L
F
2.8305 -1.2 m
2.89389 -1.2 L
2.89389 -1.2 L
2.82389 -1.2 L
2.8305 -1.2 L
F
2.82389 -1.2 m
2.89389 -1.2 L
2.89389 -1.2 L
2.8305 -1.2 L
2.82389 -1.2 L
F
2.8305 -1.2 m
2.89389 -1.2 L
2.89389 -1.2 L
2.85083 -1.2 L
2.8305 -1.2 L
F
2.85083 -1.2 m
2.89389 -1.2 L
2.89389 -1.2 L
2.88668 -1.2 L
2.85083 -1.2 L
F
0 g
0 0 1 r
0 1 0 r
1 0 0 r
1 0 1 r
0 0 1 r
0 1 0 r
1 0 0 r
1 0 1 r
0 0 1 r
0 1 0 r
1 0 0 r
1 0 1 r
0 0 1 r
0 1 0 r
1 0 0 r
1 0 1 r
0 0 1 r
0 1 0 r
1 0 0 r
1 0 1 r
0 0 1 r
0 1 0 r
1 0 0 r
1 0 1 r
0 0 1 r
0 1 0 r
1 0 0 r
1 0 1 r
0 0 1 r
0 .44248 m
.13565 .45958 L
s
0 0 0 r
2 Mabswid
.13565 .45958 Mdot
0 0 1 r
.5 Mabswid
0 .36164 m
.14489 .36916 L
s
0 0 0 r
2 Mabswid
.14489 .36916 Mdot
0 0 1 r
.5 Mabswid
0 .23836 m
.14489 .23084 L
s
0 0 0 r
2 Mabswid
.14489 .23084 Mdot
0 0 1 r
.5 Mabswid
0 .15752 m
.13565 .14042 L
s
0 0 0 r
2 Mabswid
.13565 .14042 Mdot
0 1 0 r
.5 Mabswid
0 .44506 m
.13524 .46244 L
s
0 0 0 r
2 Mabswid
.13524 .46244 Mdot
0 1 0 r
.5 Mabswid
0 .37682 m
.14372 .3862 L
s
0 0 0 r
2 Mabswid
.14372 .3862 Mdot
0 1 0 r
.5 Mabswid
0 .22318 m
.14372 .2138 L
s
0 0 0 r
2 Mabswid
.14372 .2138 Mdot
0 1 0 r
.5 Mabswid
0 .15494 m
.13524 .13756 L
s
0 0 0 r
2 Mabswid
.13524 .13756 Mdot
1 0 0 r
.5 Mabswid
0 .44777 m
.1348 .46544 L
s
0 0 0 r
2 Mabswid
.1348 .46544 Mdot
1 0 0 r
.5 Mabswid
0 .38824 m
.14266 .39902 L
s
0 0 0 r
2 Mabswid
.14266 .39902 Mdot
1 0 0 r
.5 Mabswid
0 .21176 m
.14266 .20098 L
s
0 0 0 r
2 Mabswid
.14266 .20098 Mdot
1 0 0 r
.5 Mabswid
0 .15223 m
.1348 .13456 L
s
0 0 0 r
2 Mabswid
.1348 .13456 Mdot
1 0 1 r
.5 Mabswid
0 .45042 m
.13436 .46838 L
s
0 0 0 r
2 Mabswid
.13436 .46838 Mdot
1 0 1 r
.5 Mabswid
0 .39737 m
.14171 .40925 L
s
0 0 0 r
2 Mabswid
.14171 .40925 Mdot
1 0 1 r
.5 Mabswid
0 .3545 m
.14536 .36115 L
s
0 0 0 r
2 Mabswid
.14536 .36115 Mdot
1 0 1 r
.5 Mabswid
0 .2455 m
.14536 .23885 L
s
0 0 0 r
2 Mabswid
.14536 .23885 Mdot
1 0 1 r
.5 Mabswid
0 .20263 m
.14171 .19075 L
s
0 0 0 r
2 Mabswid
.14171 .19075 Mdot
1 0 1 r
.5 Mabswid
0 .14958 m
.13436 .13162 L
s
0 0 0 r
2 Mabswid
.13436 .13162 Mdot
0 0 1 r
.5 Mabswid
.13565 .45958 m
.18879 .46657 L
s
0 0 0 r
2 Mabswid
.18879 .46657 Mdot
0 0 1 r
.5 Mabswid
.14489 .36916 m
.20499 .37247 L
s
0 0 0 r
2 Mabswid
.20499 .37247 Mdot
0 0 1 r
.5 Mabswid
.14489 .23084 m
.20499 .22753 L
s
0 0 0 r
2 Mabswid
.20499 .22753 Mdot
0 0 1 r
.5 Mabswid
.13565 .14042 m
.18879 .13343 L
s
0 0 0 r
2 Mabswid
.18879 .13343 Mdot
0 1 0 r
.5 Mabswid
.13524 .46244 m
.18807 .46952 L
s
0 0 0 r
2 Mabswid
.18807 .46952 Mdot
0 1 0 r
.5 Mabswid
.14372 .3862 m
.20292 .39029 L
s
0 0 0 r
2 Mabswid
.20292 .39029 Mdot
0 1 0 r
.5 Mabswid
.14372 .2138 m
.20292 .20971 L
s
0 0 0 r
2 Mabswid
.20292 .20971 Mdot
0 1 0 r
.5 Mabswid
.13524 .13756 m
.18807 .13048 L
s
0 0 0 r
2 Mabswid
.18807 .13048 Mdot
1 0 0 r
.5 Mabswid
.1348 .46544 m
.18729 .47262 L
s
0 0 0 r
2 Mabswid
.18729 .47262 Mdot
1 0 0 r
.5 Mabswid
.14266 .39902 m
.20107 .40367 L
s
0 0 0 r
2 Mabswid
.20107 .40367 Mdot
1 0 0 r
.5 Mabswid
.14266 .20098 m
.20107 .19633 L
s
0 0 0 r
2 Mabswid
.20107 .19633 Mdot
1 0 0 r
.5 Mabswid
.1348 .13456 m
.18729 .12738 L
s
0 0 0 r
2 Mabswid
.18729 .12738 Mdot
1 0 1 r
.5 Mabswid
.13436 .46838 m
.18652 .47565 L
s
0 0 0 r
2 Mabswid
.18652 .47565 Mdot
1 0 1 r
.5 Mabswid
.14171 .40925 m
.1994 .41434 L
s
0 0 0 r
2 Mabswid
.1994 .41434 Mdot
1 0 1 r
.5 Mabswid
.14536 .36115 m
.20581 .36409 L
s
0 0 0 r
2 Mabswid
.20581 .36409 Mdot
1 0 1 r
.5 Mabswid
.14536 .23885 m
.20581 .23591 L
s
0 0 0 r
2 Mabswid
.20581 .23591 Mdot
1 0 1 r
.5 Mabswid
.14171 .19075 m
.1994 .18566 L
s
0 0 0 r
2 Mabswid
.1994 .18566 Mdot
1 0 1 r
.5 Mabswid
.13436 .13162 m
.18652 .12435 L
s
0 0 0 r
2 Mabswid
.18652 .12435 Mdot
0 0 1 r
.5 Mabswid
.18879 .46657 m
.23938 .47059 L
s
0 0 0 r
2 Mabswid
.23938 .47059 Mdot
0 0 1 r
.5 Mabswid
.20499 .37247 m
.23166 .37333 L
s
0 0 0 r
2 Mabswid
.23166 .37333 Mdot
0 0 1 r
.5 Mabswid
.20499 .22753 m
.23166 .22667 L
s
0 0 0 r
2 Mabswid
.23166 .22667 Mdot
0 0 1 r
.5 Mabswid
.18879 .13343 m
.23938 .12941 L
s
0 0 0 r
2 Mabswid
.23938 .12941 Mdot
0 1 0 r
.5 Mabswid
.18807 .46952 m
.23974 .47372 L
s
0 0 0 r
2 Mabswid
.23974 .47372 Mdot
0 1 0 r
.5 Mabswid
.20292 .39029 m
.23264 .3915 L
s
0 0 0 r
2 Mabswid
.23264 .3915 Mdot
0 1 0 r
.5 Mabswid
.20292 .20971 m
.23264 .2085 L
s
0 0 0 r
2 Mabswid
.23264 .2085 Mdot
0 1 0 r
.5 Mabswid
.18807 .13048 m
.23974 .12628 L
s
0 0 0 r
2 Mabswid
.23974 .12628 Mdot
1 0 0 r
.5 Mabswid
.18729 .47262 m
.24011 .47701 L
s
0 0 0 r
2 Mabswid
.24011 .47701 Mdot
1 0 0 r
.5 Mabswid
.20107 .40367 m
.23351 .4052 L
s
0 0 0 r
2 Mabswid
.23351 .4052 Mdot
1 0 0 r
.5 Mabswid
.20107 .19633 m
.23351 .1948 L
s
0 0 0 r
2 Mabswid
.23351 .1948 Mdot
1 0 0 r
.5 Mabswid
.18729 .12738 m
.24011 .12299 L
s
0 0 0 r
2 Mabswid
.24011 .12299 Mdot
1 0 1 r
.5 Mabswid
.18652 .47565 m
.24049 .48024 L
s
0 0 0 r
2 Mabswid
.24049 .48024 Mdot
1 0 1 r
.5 Mabswid
.1994 .41434 m
.2343 .41618 L
s
0 0 0 r
2 Mabswid
.2343 .41618 Mdot
1 0 1 r
.5 Mabswid
.20581 .36409 m
.23128 .36481 L
s
0 0 0 r
2 Mabswid
.23128 .36481 Mdot
1 0 1 r
.5 Mabswid
.20581 .23591 m
.23128 .23519 L
s
0 0 0 r
2 Mabswid
.23128 .23519 Mdot
1 0 1 r
.5 Mabswid
.1994 .18566 m
.2343 .18382 L
s
0 0 0 r
2 Mabswid
.2343 .18382 Mdot
1 0 1 r
.5 Mabswid
.18652 .12435 m
.24049 .11976 L
s
0 0 0 r
2 Mabswid
.24049 .11976 Mdot
0 0 1 r
.5 Mabswid
.23938 .47059 m
.29576 .47157 L
s
0 0 0 r
2 Mabswid
.29576 .47157 Mdot
0 0 1 r
.5 Mabswid
.23166 .37333 m
.28511 .37367 L
s
0 0 0 r
2 Mabswid
.28511 .37367 Mdot
0 0 1 r
.5 Mabswid
.23166 .22667 m
.28511 .22633 L
s
0 0 0 r
2 Mabswid
.28511 .22633 Mdot
0 0 1 r
.5 Mabswid
.23938 .12941 m
.29576 .12843 L
s
0 0 0 r
2 Mabswid
.29576 .12843 Mdot
0 1 0 r
.5 Mabswid
.23974 .47372 m
.29625 .47476 L
s
0 0 0 r
2 Mabswid
.29625 .47476 Mdot
0 1 0 r
.5 Mabswid
.23264 .3915 m
.28645 .39196 L
s
0 0 0 r
2 Mabswid
.28645 .39196 Mdot
0 1 0 r
.5 Mabswid
.23264 .2085 m
.28645 .20804 L
s
0 0 0 r
2 Mabswid
.28645 .20804 Mdot
0 1 0 r
.5 Mabswid
.23974 .12628 m
.29625 .12524 L
s
0 0 0 r
2 Mabswid
.29625 .12524 Mdot
1 0 0 r
.5 Mabswid
.24011 .47701 m
.29678 .47809 L
s
0 0 0 r
2 Mabswid
.29678 .47809 Mdot
1 0 0 r
.5 Mabswid
.23351 .4052 m
.28766 .40576 L
s
0 0 0 r
2 Mabswid
.28766 .40576 Mdot
1 0 0 r
.5 Mabswid
.23351 .1948 m
.28766 .19424 L
s
0 0 0 r
2 Mabswid
.28766 .19424 Mdot
1 0 0 r
.5 Mabswid
.24011 .12299 m
.29678 .12191 L
s
0 0 0 r
2 Mabswid
.29678 .12191 Mdot
1 0 1 r
.5 Mabswid
.24049 .48024 m
.29731 .48137 L
s
0 0 0 r
2 Mabswid
.29731 .48137 Mdot
1 0 1 r
.5 Mabswid
.2343 .41618 m
.28875 .41682 L
s
0 0 0 r
2 Mabswid
.28875 .41682 Mdot
1 0 1 r
.5 Mabswid
.23128 .36481 m
.28459 .36513 L
s
0 0 0 r
2 Mabswid
.28459 .36513 Mdot
1 0 1 r
.5 Mabswid
.23128 .23519 m
.28459 .23487 L
s
0 0 0 r
2 Mabswid
.28459 .23487 Mdot
1 0 1 r
.5 Mabswid
.2343 .18382 m
.28875 .18318 L
s
0 0 0 r
2 Mabswid
.28875 .18318 Mdot
1 0 1 r
.5 Mabswid
.24049 .11976 m
.29731 .11863 L
s
0 0 0 r
2 Mabswid
.29731 .11863 Mdot
0 0 1 r
.5 Mabswid
.29576 .47157 m
.30337 .47233 L
s
0 0 0 r
2 Mabswid
.30337 .47233 Mdot
0 0 1 r
.5 Mabswid
.28511 .37367 m
.30056 .3743 L
s
0 0 0 r
2 Mabswid
.30056 .3743 Mdot
0 0 1 r
.5 Mabswid
.28511 .22633 m
.30056 .2257 L
s
0 0 0 r
2 Mabswid
.30056 .2257 Mdot
0 0 1 r
.5 Mabswid
.29576 .12843 m
.30337 .12767 L
s
0 0 0 r
2 Mabswid
.30337 .12767 Mdot
0 1 0 r
.5 Mabswid
.29625 .47476 m
.3035 .4755 L
s
0 0 0 r
2 Mabswid
.3035 .4755 Mdot
0 1 0 r
.5 Mabswid
.28645 .39196 m
.30092 .3927 L
s
0 0 0 r
2 Mabswid
.30092 .3927 Mdot
0 1 0 r
.5 Mabswid
.28645 .20804 m
.30092 .2073 L
s
0 0 0 r
2 Mabswid
.30092 .2073 Mdot
0 1 0 r
.5 Mabswid
.29625 .12524 m
.3035 .1245 L
s
0 0 0 r
2 Mabswid
.3035 .1245 Mdot
1 0 0 r
.5 Mabswid
.29678 .47809 m
.30364 .47881 L
s
0 0 0 r
2 Mabswid
.30364 .47881 Mdot
1 0 0 r
.5 Mabswid
.28766 .40576 m
.30124 .40656 L
s
0 0 0 r
2 Mabswid
.30124 .40656 Mdot
1 0 0 r
.5 Mabswid
.28766 .19424 m
.30124 .19344 L
s
0 0 0 r
2 Mabswid
.30124 .19344 Mdot
1 0 0 r
.5 Mabswid
.29678 .12191 m
.30364 .12119 L
s
0 0 0 r
2 Mabswid
.30364 .12119 Mdot
1 0 1 r
.5 Mabswid
.29731 .48137 m
.30378 .48206 L
s
0 0 0 r
2 Mabswid
.30378 .48206 Mdot
1 0 1 r
.5 Mabswid
.28875 .41682 m
.30153 .41767 L
s
0 0 0 r
2 Mabswid
.30153 .41767 Mdot
1 0 1 r
.5 Mabswid
.28459 .36513 m
.30042 .3657 L
s
0 0 0 r
2 Mabswid
.30042 .3657 Mdot
1 0 1 r
.5 Mabswid
.28459 .23487 m
.30042 .2343 L
s
0 0 0 r
2 Mabswid
.30042 .2343 Mdot
1 0 1 r
.5 Mabswid
.28875 .18318 m
.30153 .18233 L
s
0 0 0 r
2 Mabswid
.30153 .18233 Mdot
1 0 1 r
.5 Mabswid
.29731 .11863 m
.30378 .11794 L
s
0 0 0 r
2 Mabswid
.30378 .11794 Mdot
0 0 1 r
.5 Mabswid
.30337 .47233 m
.39116 .47711 L
s
0 0 0 r
2 Mabswid
.39116 .47711 Mdot
0 0 1 r
.5 Mabswid
.30056 .3743 m
.40603 .3766 L
s
0 0 0 r
2 Mabswid
.40603 .3766 Mdot
0 0 1 r
.5 Mabswid
.30056 .2257 m
.40603 .2234 L
s
0 0 0 r
2 Mabswid
.40603 .2234 Mdot
0 0 1 r
.5 Mabswid
.30337 .12767 m
.39116 .12289 L
s
0 0 0 r
2 Mabswid
.39116 .12289 Mdot
0 1 0 r
.5 Mabswid
.3035 .4755 m
.39048 .48036 L
s
0 0 0 r
2 Mabswid
.39048 .48036 Mdot
0 1 0 r
.5 Mabswid
.30092 .3927 m
.40414 .39557 L
s
0 0 0 r
2 Mabswid
.40414 .39557 Mdot
0 1 0 r
.5 Mabswid
.30092 .2073 m
.40414 .20443 L
s
0 0 0 r
2 Mabswid
.40414 .20443 Mdot
0 1 0 r
.5 Mabswid
.3035 .1245 m
.39048 .11964 L
s
0 0 0 r
2 Mabswid
.39048 .11964 Mdot
1 0 0 r
.5 Mabswid
.30364 .47881 m
.38976 .48373 L
s
0 0 0 r
2 Mabswid
.38976 .48373 Mdot
1 0 0 r
.5 Mabswid
.30124 .40656 m
.40244 .40984 L
s
0 0 0 r
2 Mabswid
.40244 .40984 Mdot
1 0 0 r
.5 Mabswid
.30124 .19344 m
.40244 .19016 L
s
0 0 0 r
2 Mabswid
.40244 .19016 Mdot
1 0 0 r
.5 Mabswid
.30364 .12119 m
.38976 .11627 L
s
0 0 0 r
2 Mabswid
.38976 .11627 Mdot
1 0 1 r
.5 Mabswid
.30378 .48206 m
.38903 .48706 L
s
0 0 0 r
2 Mabswid
.38903 .48706 Mdot
1 0 1 r
.5 Mabswid
.30153 .41767 m
.40091 .42126 L
s
0 0 0 r
2 Mabswid
.40091 .42126 Mdot
1 0 1 r
.5 Mabswid
.30042 .3657 m
.40677 .36777 L
s
0 0 0 r
2 Mabswid
.40677 .36777 Mdot
1 0 1 r
.5 Mabswid
.30042 .2343 m
.40677 .23223 L
s
0 0 0 r
2 Mabswid
.40677 .23223 Mdot
1 0 1 r
.5 Mabswid
.30153 .18233 m
.40091 .17874 L
s
0 0 0 r
2 Mabswid
.40091 .17874 Mdot
1 0 1 r
.5 Mabswid
.30378 .11794 m
.38903 .11294 L
s
0 0 0 r
2 Mabswid
.38903 .11294 Mdot
0 0 1 r
.5 Mabswid
.39116 .47711 m
0 0 rlineto s
.39116 .47711 m
1 .46576 L
s
.40603 .3766 m
0 0 rlineto s
.40603 .3766 m
1 .37072 L
s
.40603 .2234 m
0 0 rlineto s
.40603 .2234 m
1 .22928 L
s
.39116 .12289 m
0 0 rlineto s
.39116 .12289 m
1 .13424 L
s
0 1 0 r
.39048 .48036 m
0 0 rlineto s
.39048 .48036 m
1 .46944 L
s
.40414 .39557 m
0 0 rlineto s
.40414 .39557 m
1 .38874 L
s
.40414 .20443 m
0 0 rlineto s
.40414 .20443 m
1 .21126 L
s
.39048 .11964 m
0 0 rlineto s
.39048 .11964 m
1 .13056 L
s
1 0 0 r
.38976 .48373 m
0 0 rlineto s
.38976 .48373 m
1 .47296 L
s
.40244 .40984 m
0 0 rlineto s
.40244 .40984 m
1 .40236 L
s
.40244 .19016 m
0 0 rlineto s
.40244 .19016 m
1 .19764 L
s
.38976 .11627 m
0 0 rlineto s
.38976 .11627 m
1 .12704 L
s
1 0 1 r
.38903 .48706 m
0 0 rlineto s
.38903 .48706 m
1 .47665 L
s
.40091 .42126 m
0 0 rlineto s
.40091 .42126 m
1 .41348 L
s
.40677 .36777 m
0 0 rlineto s
.40677 .36777 m
1 .36295 L
s
.40677 .23223 m
0 0 rlineto s
.40677 .23223 m
1 .23705 L
s
.40091 .17874 m
0 0 rlineto s
.40091 .17874 m
1 .18652 L
s
.38903 .11294 m
0 0 rlineto s
.38903 .11294 m
1 .12335 L
s
0 0 1 r
0 1 0 r
1 0 0 r
1 0 1 r
0 0 1 r
0 1 0 r
1 0 0 r
1 0 1 r
0 1 0 r
1 0 1 r
0 1 0 r
1 0 1 r
0 0 0 r
[(BS2)] 3.79242 -0.55304 0 0 Mshowa
[(FL2)] 5.22492 -0.56 0 0 Mshowa
[(BS3)] 1.42639 -2.05304 0 0 Mshowa
[(FL1)] 2.85889 -2.06 0 0 Mshowa
[(Primary)] -2.76378 .3 0 0 Mshowa
[(Secondary)] -13.125 2.2435 0 0 Mshowa
[(Field)] -1.19838 -0.435 0 0 Mshowa
[(Coll Set)] .17787 -0.56 0 0 Mshowa
[(BS1)] 2.29242 -0.55304 0 0 Mshowa
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{676.125, 405.688},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:T0001UB000`400?l00000o`00003oo`3ooooo
0?ooojH0oooo002@0?ooo`<00000103oool00`000000oooo0000000300000080oooo0P00001^0?oo
o`<00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00800000K`3oool30000
00@0oooo00<000000?ooo`3oool00P0000030?ooo`800000KP3oool3000000@0oooo00<000000?oo
o`3oool00P0000030?ooo`800000K`3oool300000080oooo0P0000030?ooo`8000000`3oool20000
00D0oooo002A0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000P3oool00`000000
oooo000000020?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`020?ooo`030000003oool000000080oooo00<000000?ooo`3oool0K@3oool00`000000
oooo0?ooo`030?ooo`030000003oool000000080oooo00<000000?ooo`0000000P3oool00`000000
oooo0?ooo`1/0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000P3oool00`000000
oooo000000020?ooo`030000003oool0oooo06d0oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo000000020?ooo`030000003oool000000080oooo00<000000?ooo`3oool00P3oool00940
oooo00<000000?ooo`3oool0100000020?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`1/0?ooo`030000003oool0oooo00@0000000<0oooo0000000000000P0000001@3o
ool000000?ooo`3oool0000006l0oooo00<000000?ooo`3oool0100000001`3oool000000?ooo`3o
ool000000?ooo`0000000P3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo00@00000
00L0oooo0000003oool0oooo0000003oool000000080oooo00<000000?ooo`3oool0K@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool000000080oooo00<000000?ooo`0000000P3oool00`00
0000oooo0?ooo`020?ooo`00T@3oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo
0?ooo`0000000P3oool010000000oooo0?ooo`00001^0?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`0000000P3oool00`000000oooo000000020?ooo`030000003oool0oooo06d0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo000000020?ooo`030000003oool000000080
oooo00<000000?ooo`3oool0K03oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
008000000P3oool010000000oooo0?ooo`00001_0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`0000000P3oool00`000000oooo000000020?ooo`030000003oool0oooo0080oooo002A0?oo
o`070000003oool0oooo0?ooo`000000oooo000000040?ooo`030000003oool000000080oooo00<0
00000?ooo`3oool0K03oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool01@000000
oooo0000003oool000000080oooo00<000000?ooo`3oool0K@3oool020000000oooo0?ooo`3oool0
00000?ooo`000000oooo0`0000020?ooo`040000003oool0oooo000006h0oooo00T000000?ooo`3o
ool0oooo0000003oool000000?ooo`0000000P3oool00`000000oooo000000020?ooo`030000003o
ool0oooo06d0oooo00<000000?ooo`3oool00`0000020?ooo`060000003oool0oooo0000003oool0
00000P3oool00`000000oooo0?ooo`020?ooo`00T03oool2000000@0oooo0P0000001`3oool00000
0?ooo`3oool000000?ooo`0000000P3oool00`000000oooo0?ooo`1[0?ooo`800000103oool20000
00<0oooo0P0000001@3oool000000?ooo`3oool0000006h0oooo0P0000040?ooo`80000000<0oooo
0000003oool00`3oool010000000oooo0?ooo`00001]0?ooo`800000103oool2000000070?ooo`00
0000oooo0?ooo`000000oooo000000020?ooo`030000003oool0oooo06`0oooo0P0000020?ooo`03
0000003oool0oooo0080oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`030000003oool0
oooo0080oooo002A0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P0000030?oo
o`800000K`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P00001`0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P0000030?oo
o`800000K`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo008000000`3oool20000
0700oooo00<000000?ooo`3oool0100000020?ooo`8000000`3oool2000000D0oooo003o0?ooool0
ooooYP3oool00?l0ooooo`3ooonV0?ooo`00o`3ooooo0?ooojH0oooo003o0?ooool0ooooYP3oool0
0?l0ooooo`3ooonV0?ooo`00o`3ooooo0?ooojH0oooo003o0?ooool0ooooYP3oool00?l0ooooo`3o
oonV0?ooo`00o`3ooooo0?ooojH0oooo000I0?ooool00000o`000021000000`0oooo000I0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0:0?ooo`00
6@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
2P3oool001T0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo00X0oooo000I0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0O03oool0
0`000000oooo0?ooo`1m0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0O@3oool0
0`000000oooo0?ooo`0:0?ooo`006@3oool00`000000oooo0?ooo`3o0?ooool0ooooO@3oool00`00
0000oooo0?ooo`0:0?ooo`006@3oool00`000000oooo0?ooo`3o0?ooool0ooooO@3oool00`000000
oooo0?ooo`0:0?ooo`006@3oool00`000000oooo0?ooo`3o0?ooool0ooooO@3oool00`000000oooo
0?ooo`0:0?ooo`006@3oool00`000000oooo0?ooo`3o0?ooool0ooooO@3oool00`000000oooo0?oo
o`0:0?ooo`006@3oool00`000000oooo0?ooo`3o0?ooool0ooooO@3oool00`000000oooo0?ooo`0:
0?ooo`006@3oool00`000000oooo0?ooo`3o0?ooool0ooooO@3oool00`000000oooo0?ooo`0:0?oo
o`006@3oool00`000000oooo0?ooo`3o0?ooool0ooooO@3oool00`000000oooo0?ooo`0:0?ooo`00
6@3oool00`000000oooo0?ooo`3o0?ooool0ooooO@3oool00`000000oooo0?ooo`0:0?ooo`006@3o
ool400000?l0ooooo`3ooomi0?ooo`@00000303oool001T0oooo00<000000?ooo`3oool0o`3ooooo
0?ooogd0oooo00<000000?ooo`3oool02P3oool001T0oooo00<000000?ooo`3oool0o`3ooooo0?oo
ogd0oooo00<000000?ooo`3oool02P3oool001T0oooo00<000000?ooo`3oool0o`3ooooo0?ooogd0
oooo00<000000?ooo`3oool02P3oool001T0oooo00<000000?ooo`3oool0o`3ooooo0?ooogd0oooo
00<000000?ooo`3oool02P3oool001T0oooo00<000000?ooo`3oool0o`3ooooo0?ooogd0oooo00<0
00000?ooo`3oool02P3oool001T0oooo00<000000?ooo`3oool0o`3ooooo0?ooogd0oooo00<00000
0?ooo`3oool02P3oool001T0oooo00<000000?ooo`3oool0o`3ooooo0?ooogd0oooo00<000000?oo
o`3oool02P3oool001T0oooo00<000000?ooo`3oool0o`3ooooo0?ooogd0oooo00<000000?ooo`3o
ool02P3oool001T0oooo00<000000?ooo`3oool0o`3ooooo0?ooogd0oooo00<000000?ooo`3oool0
2P3oool001T0oooo00<000000?ooo`3oool0o`3ooooo0?ooogd0oooo00<000000?ooo`3oool02P3o
ool001T0oooo00<000000?ooo`3oool0o`3ooooo0?ooogd0oooo00<000000?ooo`3oool02P3oool0
01T0oooo00<000000?ooo`3oool0o`3ooooo0?ooogd0oooo00<000000?ooo`3oool02P3oool001T0
oooo1000003o0?ooool0ooooN@3oool4000000`0oooo000I0?ooo`030000003oool0oooo0?l0oooo
o`3ooomm0?ooo`030000003oool0oooo00X0oooo000I0?ooo`030000003oool0oooo0?l0ooooo`3o
oomm0?ooo`030000003oool0oooo00X0oooo000I0?ooo`030000003oool0oooo0?l0ooooo`3ooomm
0?ooo`030000003oool0oooo00X0oooo000I0?ooo`030000003oool0oooo0?l0ooooo`3ooomm0?oo
o`030000003oool0oooo00X0oooo000I0?ooo`030000003oool0oooo0?l0ooooo`3ooomm0?ooo`03
0000003oool0oooo00X0oooo000I0?ooo`030000003oool0oooo04T0oooo7@00000g0?ooodl00000
o`3ooon@0?ooo`030000003oool0oooo00X0oooo000I0?ooo`030000003oool0oooo04T0oooo00<0
000007moO`1oOgl06@1oOgl00`000000oooo0?ooo`0e0?ooo`030000001oOgl0Ogmo0240Ogmo00<0
000007moO`1oOgl09`1oOgl00`000000oooo0?ooo`3o0?ooohh0oooo00<000000?ooo`3oool02P3o
ool001T0oooo00<000000?ooo`3oool0B@3oool00`000000Ogmo07moO`0I07moO`030000003oool0
oooo03D0oooo00<0000007moO`1oOgl08@1oOgl00`000000Ogmo07moO`0W07moO`030000003oool0
oooo0?l0ooooSP3oool00`000000oooo0?ooo`0:0?ooo`006@3oool00`000000oooo0?ooo`190?oo
o`030000001oOgl0Ogmo01T0Ogmo0P00000f0?ooo`030000001oOgl0Ogmo0240Ogmo00<0000007mo
O`1oOgl09`1oOgl200000?l0ooooS`3oool00`000000oooo0?ooo`0:0?ooo`006@3oool00`000000
oooo0?ooo`190?ooo`8000006P1oOgl2000003H0oooo00<0000007moO`1oOgl08@1oOgl00`000000
Ogmo07moO`0W07moO`800000o`3ooon?0?ooo`030000003oool0oooo00X0oooo000I0?ooo`030000
003oool0oooo04T0oooo0P00000J07moO`800000=@3oool2000002<0Ogmo00<0000007moO`1oOgl0
9`1oOgl200000?l0ooooS`3oool00`000000oooo0?ooo`0:0?ooo`006@3oool4000004P0oooo7@00
00000`1oOgl000000?ooo`0c0?oooe400000o`3ooon<0?ooo`@00000303oool001T0oooo00<00000
0?ooo`3oool0B@3oool2000001X0Ogmo00<0000007moO`000000=03oool2000002<0Ogmo00<00000
07moO`1oOgl09`1oOgl00`000000Ogmo0000003o0?ooohh0oooo00<000000?ooo`3oool02P3oool0
01T0oooo00<000000?ooo`3oool0B@3oool2000001X0Ogmo00<0000007moO`000000=03oool20000
02<0Ogmo00<0000007moO`1oOgl09`1oOgl00`000000Ogmo0000003o0?ooohh0oooo00<000000?oo
o`3oool02P3oool001T0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0000000I07moO`04
0000001oOgl0Ogmo000003<0oooo0P00000S07moO`030000001oOgl0Ogmo02L0Ogmo00<0000007mo
O`000000o`3ooon>0?ooo`030000003oool0oooo00X0oooo000I0?ooo`030000003oool0oooo04T0
oooo00<000000?ooo`0000006@1oOgl010000000Ogmo07moO`00000c0?ooo`8000008`1oOgl00`00
0000Ogmo07moO`0W07moO`030000001oOgl000000?l0ooooSP3oool00`000000oooo0?ooo`0:0?oo
o`006@3oool00`000000oooo0?ooo`190?ooo`030000003oool0000001T0Ogmo00@0000007moO`1o
Ogl00000<`3oool2000002<0Ogmo00<0000007moO`1oOgl09`1oOgl010000000Ogmo07moO`00003o
0?ooohd0oooo00<000000?ooo`3oool02P3oool001T0oooo00<000000?ooo`3oool0B@3oool00`00
0000oooo0000000I07moO`050000001oOgl0Ogmo07moO`000000<@3oool00`000000Ogmo0000000S
07moO`030000001oOgl0Ogmo02L0Ogmo00@0000007moO`1oOgl00000o`3ooon=0?ooo`030000003o
ool0oooo00X0oooo000I0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`0000006@1oOgl0
1@000000Ogmo07moO`1oOgl000000340oooo00<0000007moO`0000008`1oOgl00`000000Ogmo07mo
O`0W07moO`040000001oOgl0Ogmo00000?l0ooooS@3oool00`000000oooo0?ooo`0:0?ooo`006@3o
ool00`000000oooo0?ooo`190?ooo`040000003oool0oooo000001P0Ogmo00D0000007moO`1oOgl0
Ogmo0000000a0?ooo`030000001oOgl000000280Ogmo0P00000Y07moO`040000001oOgl0Ogmo0000
0?l0ooooS@3oool00`000000oooo0?ooo`0:0?ooo`006@3oool00`000000oooo0?ooo`190?ooo`04
0000003oool0oooo000001P0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`0^0?oo
o`030000001oOgl000000280Ogmo0P00000Y07moO`050000001oOgl0Ogmo07moO`000000o`3ooon<
0?ooo`030000003oool0oooo00X0oooo000I0?ooo`030000003oool0oooo04T0oooo00@000000?oo
o`3oool00000601oOgl00`000000Ogmo07moO`0207moO`030000003oool0oooo02h0oooo00<00000
07moO`0000008P1oOgl2000002T0Ogmo00D0000007moO`1oOgl0Ogmo0000003o0?oooh`0oooo00<0
00000?ooo`3oool02P3oool001T0oooo00<000000?ooo`3oool0B@3oool010000000oooo0?ooo`00
000H07moO`030000001oOgl0Ogmo0080Ogmo00<000000?ooo`3oool0;P3oool00`000000Ogmo0000
000R07moO`800000:@1oOgl01@000000Ogmo07moO`1oOgl000000?l0ooooS03oool00`000000oooo
0?ooo`0:0?ooo`006@3oool00`000000oooo0?ooo`190?ooo`040000003oool0oooo000001P0Ogmo
00<0000007moO`1oOgl00`1oOgl00`000000oooo0?ooo`0]0?ooo`030000001oOgl000000280Ogmo
0P00000Y07moO`050000001oOgl0Ogmo07moO`000000o`3ooon<0?ooo`030000003oool0oooo00X0
oooo000I0?ooo`@00000B03oool010000000oooo0?ooo`00000H07moO`030000001oOgl0Ogmo00<0
Ogmo00<000000?ooo`3oool0;@3oool00`000000Ogmo0000000R07moO`800000:@1oOgl00`000000
Ogmo07moO`0207moO`030000003oool0oooo0?l0ooooQP3oool4000000`0oooo000I0?ooo`030000
003oool0oooo04T0oooo00D000000?ooo`3oool0oooo0000000G07moO`030000001oOgl0Ogmo00<0
Ogmo00<000000?ooo`3oool0;03oool010000000Ogmo07moO`00000Q07moO`<00000:@1oOgl00`00
0000Ogmo07moO`0207moO`030000003oool0oooo0?l0ooooR@3oool00`000000oooo0?ooo`0:0?oo
o`006@3oool00`000000oooo0?ooo`190?oooad000001P1oOgl00`000000oooo0?ooo`0[0?ooo`03
0000001oOgl0Ogmo04l00000101oOgl00`000000oooo0?ooo`3o0?ooohT0oooo00<000000?ooo`3o
ool02P3oool001T0oooo00<000000?ooo`3oool0B@3oool01@000000oooo0?ooo`3oool0000001L0
Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0[0?ooo`040000001oOgl0Ogmo0000
0240Ogmo0`00000Y07moO`030000001oOgl0Ogmo0080Ogmo00<000000?ooo`3oool0o`3ooon90?oo
o`030000003oool0oooo00X0oooo000I0?ooo`030000003oool0oooo04T0oooo00D000000?ooo`3o
ool0oooo0000000G07moO`030000001oOgl0Ogmo00@0Ogmo00<000000?ooo`3oool0:`3oool01000
0000Ogmo07moO`00000Q07moO`<00000:@1oOgl00`000000Ogmo07moO`0307moO`030000003oool0
oooo0?l0ooooR03oool00`000000oooo0?ooo`0:0?ooo`006@3oool00`000000oooo0?ooo`190?oo
o`050000003oool0oooo0?ooo`0000005`1oOgl00`000000Ogmo07moO`0507moO`030000003oool0
oooo02X0oooo00@0000007moO`1oOgl000008@1oOgl3000002T0Ogmo00<0000007moO`1oOgl00`1o
Ogl00`000000oooo0?ooo`3o0?ooohP0oooo00<000000?ooo`3oool02P3oool001T0oooo00<00000
0?ooo`3oool0B@3oool00`000000oooo0?ooo`020?ooo`030000001oOgl0Ogmo01@0Ogmo00<00000
07moO`1oOgl01@1oOgl00`000000oooo0?ooo`0Z0?ooo`040000001oOgl0Ogmo00000200Ogmo00@0
00000?ooo`0000000000:@1oOgl00`000000Ogmo07moO`0307moO`030000003oool0oooo0?l0oooo
R03oool00`000000oooo0?ooo`0:0?ooo`006@3oool00`000000oooo0?ooo`190?ooo`030000003o
ool0oooo0080oooo00<0000007moO`1oOgl0501oOgl00`000000Ogmo07moO`0507moO`030000003o
ool0oooo02X0oooo00@0000007moO`1oOgl00000801oOgl010000000oooo00000000000Y07moO`03
0000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0o`3ooon80?ooo`030000003oool0oooo00X0
oooo000I0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool00P3oool00`000000Ogmo
07moO`0D07moO`030000001oOgl0Ogmo00H0Ogmo00<000000?ooo`3oool0:03oool01@000000Ogmo
07moO`1oOgl000000200Ogmo00@000000?ooo`0000000000:@1oOgl00`000000Ogmo07moO`0407mo
O`030000003oool0oooo0?l0ooooQ`3oool00`000000oooo0?ooo`0:0?ooo`006@3oool00`000000
oooo0?ooo`190?ooo`030000003oool0oooo0080oooo00<0000007moO`1oOgl0501oOgl00`000000
Ogmo07moO`0607moO`030000003oool0oooo02P0oooo00D0000007moO`1oOgl0Ogmo0000000P07mo
O`040000003oool00000000002T0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`3o
0?ooohL0oooo00<000000?ooo`3oool02P3oool000P0oooo100000020?ooo`8000002@3oool00`00
0000oooo0?ooo`190?ooo`030000003oool0oooo0080oooo00<0000007moO`1oOgl0501oOgl00`00
0000Ogmo07moO`0607moO`030000003oool0oooo02P0oooo00D0000007moO`1oOgl0Ogmo0000000P
07moO`040000003oool00000000002T0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?oo
o`3o0?ooohL0oooo00<000000?ooo`3oool02P3oool000P0oooo00H000000?ooo`3oool000000?oo
o`0000020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0B@3oool00`000000oooo
0?ooo`030?ooo`030000001oOgl0Ogmo01<0Ogmo00<0000007moO`1oOgl01P1oOgl00`000000oooo
0?ooo`0X0?ooo`050000001oOgl0Ogmo07moO`0000007`1oOgl00`000000oooo0?ooo`02000002T0
Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`3o0?ooohL0oooo00<000000?ooo`3o
ool02P3oool000D0oooo0`0000000`3oool000000?ooo`020?ooo`040000003oool0oooo000000P0
oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`030?ooo`030000001oOgl0Ogmo01<0
Ogmo00<0000007moO`1oOgl01`1oOgl00`000000oooo0?ooo`0W0?ooo`050000001oOgl0Ogmo07mo
O`0000007`1oOgl00`000000oooo0?ooo`02000002T0Ogmo00<0000007moO`1oOgl0101oOgl00`00
0000oooo0?ooo`3o0?ooohL0oooo00<000000?ooo`3oool02P3oool000X0oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`060?ooo`D00000A`3oool00`000000oooo0?ooo`030?oo
o`030000001oOgl0Ogmo01<0Ogmo00<0000007moO`1oOgl01`1oOgl00`000000oooo0?ooo`0W0?oo
o`050000001oOgl0Ogmo07moO`0000007`1oOgl00`000000oooo0?ooo`02000002T0Ogmo00<00000
07moO`1oOgl01@1oOgl00`000000oooo0?ooo`3o0?oooh80oooo1@00000<0?ooo`002`3oool00`00
0000oooo000000020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0B@3oool00`00
0000oooo0?ooo`030?ooo`030000001oOgl0Ogmo01<0Ogmo00<0000007moO`1oOgl01`1oOgl00`00
0000oooo0?ooo`0W0?ooo`050000001oOgl0Ogmo07moO`0000007`1oOgl00`000000oooo0?ooo`02
000002T0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000oooo0?ooo`3o0?ooohH0oooo00<00000
0?ooo`3oool02P3oool000P0oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`030?ooo`030000001o
Ogl0Ogmo01<0Ogmo00<0000007moO`1oOgl0201oOgl00`000000oooo0?ooo`0V0?ooo`050000001o
Ogl0Ogmo07moO`0000007`1oOgl00`000000oooo0?ooo`02000002T0Ogmo00<0000007moO`1oOgl0
1@1oOgl00`000000oooo0?ooo`3o0?ooohH0oooo00<000000?ooo`3oool02P3oool000T0oooo0P00
00030?ooo`8000002@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00@0oooo00<0
000007moO`1oOgl04P1oOgl00`000000Ogmo07moO`0807moO`030000003oool0oooo02D0oooo00<0
000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0L07moO`040000003oool0oooo0?ooo`800000
:@1oOgl00`000000Ogmo07moO`0507moO`030000003oool0oooo0?l0ooooQP3oool00`000000oooo
0?ooo`0:0?ooo`006@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00@0oooo00<0
000007moO`1oOgl04P1oOgl00`000000Ogmo07moO`0807moO`030000003oool0oooo02D0oooo00<0
000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0L07moO`040000003oool0oooo0?ooo`800000
:@1oOgl00`000000Ogmo07moO`0607moO`030000003oool0oooo0?l0ooooQ@3oool00`000000oooo
0?ooo`0:0?ooo`006@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00@0oooo00<0
000007moO`1oOgl04P1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo02@0oooo00<0
000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0L07moO`040000003oool0oooo0?ooo`800000
:@1oOgl00`000000Ogmo07moO`0607moO`030000003oool0oooo0?l0ooooQ@3oool00`000000oooo
0?ooo`0:0?ooo`006@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00@0oooo00<0
000007moO`1oOgl04P1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo02@0oooo00<0
000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0L07moO`040000003oool0oooo0?ooo`800000
:@1oOgl00`000000Ogmo07moO`0607moO`030000003oool0oooo0?l0ooooQ@3oool00`000000oooo
0?ooo`0:0?ooo`006@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00@0oooo00<0
000007moO`1oOgl04P1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo02@0oooo00<0
000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0L07moO`040000003oool0oooo0?ooo`800000
:@1oOgl00`000000Ogmo07moO`0607moO`030000003oool0oooo0?l0ooooQ@3oool00`000000oooo
0?ooo`0:0?ooo`006@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00@0oooo00<0
000007moO`1oOgl04P1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo02<0oooo00<0
000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0L07moO`040000003oool0oooo0?ooo`800000
:@1oOgl00`000000o`3o0?l0o`0T0?l0ool0ooooJP3oool00`000000oooo0?ooo`0:0?ooo`006@3o
ool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00D0oooo00<0000007moO`1oOgl04@1o
Ogl00`000000Ogmo07moO`0:07moO`030000003oool0oooo02<0oooo00<0000007moO`1oOgl00P1o
Ogl00`000000Ogmo07moO`0K07moO`070000003oool0oooo0?ooo`000000Ogmo0000000H07moOa80
o`3o2@1oOgl2000001/0oooo>03o0?oo0?oooc80oooo00<000000?ooo`3oool02P3oool001T0oooo
00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`050?ooo`030000001oOgl0Ogmo0140Ogmo
00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`0S0?ooo`030000001oOgl0Ogmo0080Ogmo
00<0000007moO`1oOgl06`1oOgl01`000000oooo0?ooo`3oool0000007moO`0000001P1oOglB0?l0
oa40Ogmo00<0000007moO`3o00001`3o00000`000000o`000?l0000K0?l003L0oooo=`3o0?oj0?oo
o`030000003oool0oooo00X0oooo000I0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3o
ool01@3oool00`000000Ogmo07moO`0A07moO`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3o
ool08@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo01X0Ogmo0P0000000`3oool0
o`3o0?l0o`090?l0oa80Ogmo4`3o000807moO`800000703ooolg0?l003L0oooo>03o0?o20?ooo`03
0000003oool0oooo00X0oooo000I0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0
1@3oool00`000000Ogmo07moO`0A07moO`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0
803oool2000000D0Ogmo00<0000007moO`1oOgl02@1oOglA0?l0o`030000003o0?l0o`3o0080oooo
0`00000607moOa80o`004@1oOgl010000000Ogmo07moO`1oOglT003o03L0oooo>03o000g0?ooocP0
o`3oRP3oool00`000000oooo0?ooo`0:0?ooo`006@3oool4000004P0oooo00<000000?ooo`3oool0
1@3oool00`000000Ogmo07moO`0A07moO`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3oool0
603oool80?l0o`030000003o0?l0o`3o0100o`3o4@1oOgl2000000030?ooo`3o0000000000T0o`00
6@1oOgl>003o00L0Ogmo0P00000K0?ooocL00?l0>03ooolh0?l003L0oooo=`3o0?m@0?ooo`@00000
303oool001T0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`060?ooo`030000001o
Ogl0Ogmo0100Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`060?oooa40o`3o203o
ool2000000D0Ogmo00<0000007moO`1oOgl02@1oOglA0?l000040000003o0000o`000?ooo`800000
00<0Ogmo0000001oOgl04@1oOgl=003o00X0Ogmo00<0000007moO`1oOgl0201oOgl00`000000003o
0?ooo`1A0?ooocP00?l0>03ooolg0?l003L0oooo>03o0?lK0?ooo`030000003oool0oooo00X0oooo
000I0?ooo`030000003oool0oooo04T0oooo7@00000;07moO``0o`3o4@3ooolK0?l001L0000000<0
Ogmo0000000000000`00000>003o01P000000P1oOgl80000o`03000000000?l0003o01/0003oKP3o
oolh003o03L0oooo>03o000g0?oooa`0o`3o303oool001T0oooo00<000000?ooo`3oool0B@3oool0
0`000000oooo0?ooo`060?ooo`030000001oOgl0Ogmo0100Ogmo00<0000007moO`1oOgl00P1oOgl7
0?l0o`<0Ogmo0P0000070?oooa40o`00203oool2000000D0Ogmo00<0000007moO`1oOgl0201oOglF
003o000300000000o`000?l000D00?l05@1oOglC0000o`T0Ogmo00<000000?ooo`3oool06P3ooolg
0000ofl0oooo=`00o`0h0?ooocL0o`006`3oool00`000000oooo0?ooo`0:0?ooo`006@3oool00`00
0000oooo0?ooo`190?ooo`030000003oool0oooo00H0oooo00<0000007moO`1oOgl03P1oOgl70?l0
o`P0Ogmo0P3o00000`000000o`000?l000060?l00140oooo6P00o`0B07moO`8000000P3oool20000
000307moO`000000Ogmo00D0Ogmo4`000?l@07moO`030000001oOgl0Ogmo00T0Ogmo00<000000?oo
o`3oool0D@3ooolh0000ofh0oooo>000o`0g0?oooa`0o`00303oool001T0oooo00<000000?ooo`3o
ool0B@3oool00`000000oooo0?ooo`060?ooo`030000001oOgl0Ogmo00P0Ogmo1P3o0?l207moO`03
0000001oOgl0Ogmo00<0Ogmo1`3o000207moO`8000001`3ooolA003o00L0oooo0P00000607moO`03
0000001oOgl0Ogmo00P0Ogmo4@000?l00`000000003o0000o`020000o`03000000000?l0003o00L0
003o8`1oOgl00`000000Ogmo07moO`0907moO`030000003oool0oooo08T0oooo=`000?m_0?ooocL0
0?l06`3oool00`000000oooo0?ooo`0:0?ooo`006@3oool00`000000oooo0?ooo`190?ooo`030000
003oool0oooo00L0oooo00<0000007moO`1oOgl01`3o0?l707moO`L0o`001`1oOgl;003o0140oooo
1`000?l00`000000003o0000o`0@0000oa40Ogmo0P0000040?ooo`030000001oOgl0000002T0Ogmo
00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`300?ooocL0003oK`3ooolL003o00`0oooo
000I0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool00`3oool70?l0o`L0Ogmo1`3o
00000`1oOgl0000007moO`0407moO`L00?l00`1oOgl2000000L0oooo40000?l80?ooo`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl06@1oOgl00`000000oooo0?ooo`030?ooo`030000001o
Ogl0000002T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`3f0?ooocP0003oDP3o
ool00`000000oooo0?ooo`0:0?ooo`006@3oool00`000000oooo0?ooo`180?ooo`L0o`3o103oool2
0000000307moO`3o0000o`0000D0o`001`1oOgl7003o00P0Ogmo0P000?l00`000000003o0000o`06
0000oaP0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0I07moO`030000003oool0
oooo00<0oooo00<0000007moO`000000:@1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0
oooo0?l0oooo;`3ooolg0000oa/0oooo00<000000?ooo`3oool02P3oool001T0oooo00<000000?oo
o`3oool0@@3oool70?l0o`030?ooo`000000oooo00@0oooo1`3o000807moO`H00?l000<0Ogmo0000
001oOgl01@1oOgl70000o`80Ogmo0P00000O0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007mo
O`1oOgl06@1oOgl00`000000oooo0?ooo`030?ooo`030000001oOgl0000002T0Ogmo00<0000007mo
O`1oOgl02P1oOgl00`000000oooo0?ooo`3o0?ooofH0oooo70000?l<0?ooo`006@3oool00`000000
oooo0?ooo`0j0?ooo`L0o`3o1P3oool80?l000@0oooo0P00000207moO`L00?l01`1oOgl70000o`X0
Ogmo00<000000?ooo`3oool07@3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo01T0
Ogmo00<000000?ooo`3oool00`3oool00`000000Ogmo0000000Y07moO`030000001oOgl0Ogmo00X0
Ogmo00<000000?ooo`3oool0o`3ooon10?ooo`030000003oool0oooo00X0oooo000I0?ooo`030000
003oool0oooo03<0oooo1`3o0?l50?ooo`P0o`000P3oool00`000000oooo0?ooo`040?ooo`<00?l0
00@00000003o0000o`000?l01`1oOgl70000o`030000001oOgl0Ogmo00h0Ogmo00<000000?ooo`3o
ool07@3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo01T0Ogmo00<000000?ooo`3o
ool00`3oool00`000000Ogmo0000000Y07moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3o
ool0o`3ooon10?ooo`030000003oool0oooo00X0oooo000I0?ooo`@00000:`3oool70?l0o`D0oooo
1`3o00090?ooo`P00?l00`3oool200000080Ogmo1`000?l707moO`030000001oOgl0Ogmo00l0Ogmo
00<000000?ooo`3oool0703oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo01T0Ogmo
00<000000?ooo`3oool00`3oool00`000000Ogmo0000000Y07moO`030000001oOgl0Ogmo00/0Ogmo
00<000000?ooo`3oool0o`3ooomm0?ooo`@00000303oool001T0oooo00<000000?ooo`3oool0903o
ool80?l0o`@0oooo203o00080?ooo`P00?l000<0oooo0000003oool01@3oool30000o`0400000000
0?l0003o0000o`h0Ogmo00<0000007moO`1oOgl03`1oOgl00`000000oooo0?ooo`0L0?ooo`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl06@1oOgl00`000000oooo0?ooo`030?ooo`030000
001oOgl0000002T0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000oooo0?ooo`3o0?oooh00oooo
00<000000?ooo`3oool02P3oool001T0oooo00<000000?ooo`3oool07@3oool70?l0o`@0oooo203o
00080?ooo`P00?l0203oool80000o`@0oooo00<0000007moO`1oOgl03P1oOgl00`000000Ogmo07mo
O`0?07moO`030000003oool0oooo01/0oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07mo
O`0H07moO`030000003oool0oooo00@0oooo00<0000007moO`000000:@1oOgl00`000000Ogmo07mo
O`0;07moO`030000003oool0oooo0?l0ooooP03oool00`000000oooo0?ooo`0:0?ooo`006@3oool0
0`000000oooo0?ooo`0F0?ooo`L0o`3o0`3oool80?l000P0oooo2000o`080?ooo`P0003o00<0oooo
0000003oool02@3oool00`000000Ogmo07moO`0>07moO`030000001oOgl0Ogmo00l0Ogmo00<00000
0?ooo`3oool06`3oool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo01P0Ogmo00<00000
0?ooo`3oool0103oool00`000000Ogmo0000000Y07moO`030000001oOgl0Ogmo00/0Ogmo00<00000
0?ooo`3oool0o`3ooon00?ooo`030000003oool0oooo00X0oooo000I0?ooo`030000003oool0oooo
00l0oooo1`3o0?l20?ooo`P0o`00203oool8003o00P0oooo20000?l90?ooo`030000003oool0oooo
00P0oooo00<0000007moO`1oOgl03P1oOgl00`000000Ogmo07moO`0?07moO`030000003oool0oooo
01/0oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0H07moO`030000003oool0oooo
00@0oooo00<0000007moO`000000:@1oOgl00`000000Ogmo07moO`0;07moO`030000003oool0oooo
0?l0ooooP03oool00`000000oooo0?ooo`0:0?ooo`006@3oool00`000000oooo0?ooo`080?ooo`L0
o`3o0P3oool70?l000T0oooo1`00o`080?ooo`P0003o4@3oool00`000000oooo0?ooo`080?ooo`03
0000001oOgl0Ogmo00h0Ogmo00<0000007moO`1oOgl03`1oOgl00`000000oooo0?ooo`0K0?ooo`03
0000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0601oOgl00`000000oooo0?ooo`040?ooo`03
0000001oOgl0000002T0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000oooo0?ooo`3o0?oooh00
oooo00<000000?ooo`3oool02P3oool001T0oooo00@000000?ooo`3oool0oooo1`3o0?l00`3oool0
o`000?l000060?l000P0oooo2000o`070?ooo`P0003o6@3oool00`000000oooo0?ooo`080?ooo`03
0000001oOgl0Ogmo00h0Ogmo00<0000007moO`1oOgl0401oOgl00`000000oooo0?ooo`0J0?ooo`03
0000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0601oOgl00`000000oooo0?ooo`040?ooo`03
0000001oOgl0000002T0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000oooo0?ooo`3o0?oooh00
oooo00<000000?ooo`3oool02P3oool001T0oooo103o0?l80?l000P0oooo2000o`080?ooo`L0003o
8@3oool00`000000oooo0?ooo`080?ooo`030000001oOgl0Ogmo00h0Ogmo00<0000007moO`1oOgl0
401oOgl00`000000oooo0?ooo`0J0?ooo`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0
601oOgl00`000000oooo0?ooo`040?ooo`030000001oOgl0000002T0Ogmo00<0000007moO`1oOgl0
301oOgl00`000000oooo0?ooo`3o0?ooogl0oooo00<000000?ooo`3oool02P3oool001T0oooo103o
00080?ooo`P00?l0203oool80000obP0oooo00<000000?ooo`3oool0203oool00`000000Ogmo07mo
O`0>07moO`030000001oOgl0Ogmo0100Ogmo00<000000?ooo`3oool06P3oool00`000000Ogmo07mo
O`0507moO`030000001oOgl0Ogmo01P0Ogmo00<000000?ooo`3oool0103oool00`000000Ogmo0000
000Y07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0o`3ooomo0?ooo`030000003o
ool0oooo00X0oooo000I0?ooo`040000003oool0oooo0?ooo`P00?l0203oool80000oc00oooo00<0
00000?ooo`3oool0203oool00`000000Ogmo07moO`0>07moO`030000001oOgl0Ogmo0100Ogmo00<0
00000?ooo`3oool06P3oool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo01P0Ogmo00<0
00000?ooo`3oool0103oool00`000000Ogmo0000000Y07moO`030000001oOgl0Ogmo00`0Ogmo00<0
00000?ooo`3oool0o`3ooomo0?ooo`030000003oool0oooo00X0oooo000I0?ooo`@00?l0203oool8
0000ocP0oooo00<000000?ooo`3oool02@3oool00`000000Ogmo07moO`0=07moO`030000001oOgl0
Ogmo0100Ogmo00<000000?ooo`3oool06P3oool00`000000Ogmo07moO`0507moO`030000001oOgl0
Ogmo01P0Ogmo00<000000?ooo`3oool00`3oool010000000Ogmo07moO`00000Y07moO`030000001o
Ogl0Ogmo00`0Ogmo00<000000?ooo`3oool0o`3ooomo0?ooo`030000003oool0oooo00X0oooo000I
0?ooo`040000003oool0oooo0?ooo`P0003o@03oool00`000000oooo0?ooo`090?ooo`030000001o
Ogl0Ogmo00d0Ogmo00<0000007moO`1oOgl0401oOgl00`000000oooo0?ooo`0J0?ooo`030000001o
Ogl0Ogmo00D0Ogmo00<0000007moO`1oOgl0601oOgl00`000000oooo0?ooo`030?ooo`040000001o
Ogl0Ogmo000002T0Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`3o0?ooogl0oooo
00<000000?ooo`3oool02P3oool001T0oooo10000?m80?ooo`030000003oool0oooo00T0oooo00<0
000007moO`1oOgl03@1oOgl00`000000Ogmo07moO`0A07moO`030000003oool0oooo01T0oooo00<0
000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0H07moO`030000003oool0oooo00<0oooo00@0
000007moO`1oOgl00000:@1oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo0?l0oooo
O`3oool00`000000oooo0?ooo`0:0?ooo`006@3oool4000004P0oooo00<000000?ooo`3oool02@3o
ool00`000000Ogmo07moO`0=07moO`030000001oOgl0Ogmo0140Ogmo00<000000?ooo`3oool0603o
ool00`000000Ogmo07moO`0607moO`030000001oOgl0Ogmo01L0Ogmo00<000000?ooo`3oool0103o
ool010000000Ogmo07moO`00000Y07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0
o`3oooml0?ooo`@00000303oool001T0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?oo
o`090?ooo`030000001oOgl0Ogmo00d0Ogmo00<0000007moO`1oOgl04@1oOgl00`000000oooo0?oo
o`0H0?ooo`030000001oOgl0Ogmo00H0Ogmo00<0000007moO`1oOgl05`1oOgl00`000000oooo0?oo
o`040?ooo`040000001oOgl0Ogmo000002T0Ogmo00<0000007moO`1oOgl03@1oOgl00`000000oooo
0?ooo`3o0?ooogh0oooo00<000000?ooo`3oool02P3oool001T0oooo00<000000?ooo`3oool0B@3o
ool00`000000oooo0?ooo`090?ooo`030000001oOgl0Ogmo00d0Ogmo00<0000007moO`1oOgl04@1o
Ogl00`000000oooo0?ooo`0H0?ooo`030000001oOgl0Ogmo00H0Ogmo00<0000007moO`1oOgl05`1o
Ogl00`000000oooo0?ooo`040?ooo`040000001oOgl0Ogmo000002T0Ogmo00<0000007moO`1oOgl0
3@1oOgl00`000000oooo0?ooo`3o0?ooogh0oooo00<000000?ooo`3oool02P3oool001T0oooo00<0
00000?ooo`3oool0B@3oool00`000000oooo0?ooo`090?ooo`030000001oOgl0Ogmo00d0Ogmo00<0
000007moO`1oOgl04@1oOgl00`000000oooo0?ooo`0H0?ooo`030000001oOgl0Ogmo00H0Ogmo00<0
000007moO`1oOgl05`1oOgl00`000000oooo0?ooo`040?ooo`040000001oOgl0Ogmo000002T0Ogmo
00<0000007moO`1oOgl03@1oOgl00`000000oooo0?ooo`3o0?ooogh0oooo00<000000?ooo`3oool0
2P3oool001T0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`090?ooo`030000001o
Ogl0Ogmo00d0Ogmo00<0000007moO`1oOgl04@1oOgl00`000000oooo0?ooo`0H0?ooo`030000001o
Ogl0Ogmo00H0Ogmo00<0000007moO`1oOgl05`1oOgl00`000000oooo0?ooo`040?ooo`040000001o
Ogl0Ogmo000002T0Ogmo00<0000007moO`1oOgl03@1oOgl00`000000oooo0?ooo`3o0?ooogh0oooo
00<000000?ooo`3oool02P3oool001T0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?oo
o`090?ooo`030000001oOgl0Ogmo00d0Ogmo00<0000007moO`1oOgl04P1oOgl00`000000oooo0?oo
o`0G0?ooo`030000001oOgl0Ogmo00H0Ogmo00<0000007moO`1oOgl05`1oOgl00`000000oooo0?oo
o`040?ooo`040000001oOgl0Ogmo000002T0Ogmo00<0000007moO`1oOgl03@1oOgl00`000000oooo
0?ooo`3o0?ooogh0oooo00<000000?ooo`3oool02P3oool001T0oooo00<000000?ooo`3oool0B@3o
ool00`000000oooo0?ooo`0:0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl04P1o
Ogl00`000000oooo0?ooo`0G0?ooo`030000001oOgl0Ogmo00H0Ogmo00<0000007moO`1oOgl05`1o
Ogl00`000000oooo0?ooo`040?ooo`040000001oOgl0Ogmo000002T0Ogmo00<0000007moO`1oOgl0
3@1oOgl00`000000oooo0?ooo`3o0?ooogh0oooo00<000000?ooo`3oool02P3oool001T0oooo00<0
00000?ooo`3oool0B@3oool00`000000oooo0?ooo`0:0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0
000007moO`1oOgl04P1oOgl00`000000oooo0?ooo`0G0?ooo`030000001oOgl0Ogmo00H0Ogmo00<0
000007moO`1oOgl05`1oOgl00`000000oooo0?ooo`040?ooo`040000001oOgl0Ogmo000002T0Ogmo
00<0000007moO`1oOgl03P1oOgl00`000000oooo0?ooo`3o0?ooogd0oooo00<000000?ooo`3oool0
2P3oool001T0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0:0?ooo`030000001o
Ogl0Ogmo00`0Ogmo00<0000007moO`1oOgl04P1oOgl00`000000oooo0?ooo`0G0?ooo`030000001o
Ogl0Ogmo00H0Ogmo00<0000007moO`1oOgl05`1oOgl00`000000oooo0?ooo`040?ooo`040000001o
Ogl0Ogmo000002T0Ogmo00<0000007moO`1oOgl03P1oOgl00`000000oooo0?ooo`3o0?ooogd0oooo
00<000000?ooo`3oool02P3oool001T0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?oo
o`0:0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl04P1oOgl00`000000oooo0?oo
o`0G0?ooo`030000001oOgl0Ogmo00H0Ogmo00<0000007moO`1oOgl05`1oOgl00`000000oooo0?oo
o`040?ooo`040000001oOgl0Ogmo000002T0Ogmo00<0000007moO`1oOgl03P1oOgl00`000000oooo
0?ooo`3o0?ooogd0oooo00<000000?ooo`3oool02P3oool001T0oooo00<000000?ooo`3oool0B@3o
oolM000001D0Ogmo00<000000?ooo`3oool05@3oool00`000000Ogmo07moO`0707moOb8000000P1o
Ogl[00000100Ogmo00<000000?ooo`3oool0o`3ooomm0?ooo`030000003oool0oooo00X0oooo000I
0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool02P3oool00`000000Ogmo07moO`0<
07moO`030000001oOgl0Ogmo01<0Ogmo00<000000?ooo`3oool05@3oool00`000000Ogmo07moO`07
07moO`030000001oOgl0Ogmo01H0Ogmo00<000000?ooo`3oool01@3oool010000000Ogmo07moO`00
000Y07moO`030000001oOgl0Ogmo00h0Ogmo00<000000?ooo`3oool0o`3ooomm0?ooo`030000003o
ool0oooo00X0oooo000I0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool02P3oool0
0`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo01<0Ogmo00<000000?ooo`3oool05@3oool0
0`000000Ogmo07moO`0707moO`030000001oOgl0Ogmo01H0Ogmo00<000000?ooo`3oool01@3oool0
10000000Ogmo07moO`00000Y07moO`030000001oOgl0o`3o00h0o`3o00<000000?l0o`3o0?l09@3o
0?oo0?oooeP0oooo00<000000?ooo`3oool02P3oool001T0oooo100000180?ooo`030000003oool0
oooo00X0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0C07moO`030000003oool0
oooo01D0oooo00<0000007moO`1oOgl01`1oOgl00`000000Ogmo07moO`0F07moO`030000003oool0
oooo00D0oooo00@0000007moO`1oOgl00000301oOglO0?l0o`l0Ogmo0P00000V0?ooodd0o`3oo`3o
ool80?ooo`@00000303oool001T0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0:
0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl04`1oOgl00`000000oooo0?ooo`0E
0?ooo`030000001oOgl0Ogmo00L0Ogmo00<0000007moO`1oOgl05@1oOgl2000000<0oooo0`3o0?l0
0`000000o`3o0?l0o`0>0?l0oad0Ogmo00<0000007moO`1oOgl03`1oOgl00`000000oooo0?ooo`1a
0?oood`0o`3o_P3oool00`000000oooo0?ooo`0:0?ooo`006@3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo00/0oooo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0C07mo
O`030000003oool0oooo0100oooo103o0?l00`000000o`3o0?l0o`0U0?l0o`<0oooo0P00000207mo
O`030000001oOgl0Ogmo02L0Ogmo00<0000007moO`1oOgl03`1oOgl00`000000oooo0?ooo`2m0?oo
od`0o`3oLP3oool00`000000oooo0?ooo`0:0?ooo`006@3oool00`000000oooo0?ooo`190?ooo`03
0000003oool0oooo00/0oooo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0D07moO`80
00001@3oool;0?l0o`@0oooo0P00000907moO`030000001oOgl0Ogmo01H0Ogmo00<000000?ooo`3o
ool01@3oool010000000Ogmo07moO`00000Y07moO`030000001oOgl0Ogmo00l0Ogmo00<000000?oo
o`3oool0o`3oool:0?ooodd0o`3o9@3oool00`000000oooo0?ooo`0:0?ooo`006@3oool00`000000
oooo0?ooo`190?ooo`030000003oool0oooo00/0oooo00<0000007moO`1oOgl02`1oOgl00`000000
Ogmo07moO`0?07moO`D0o`3o00<000000?l0o`3o0?l0103o0?l@0?ooo`030000001oOgl0Ogmo00L0
Ogmo00<0000007moO`1oOgl05P1oOgl00`000000oooo0?ooo`050?ooo`040000001oOgl0Ogmo0000
02T0Ogmo00<0000007moO`1oOgl03`1oOgl00`000000oooo0?ooo`3o0?oooeL0oooo9P3o0?l<0?oo
o`006@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00/0oooo00<0000007moO`1o
Ogl02`1oOgl00`000000Ogmo07moO`0207moO`d0o`3o1@1oOgl00`000000oooo0?ooo`0D0?ooo`03
0000001oOgl0Ogmo00L0Ogmo00<0000007moO`1oOgl05P1oOgl00`000000oooo0?ooo`050?ooo`04
0000001oOgl0Ogmo000002T0Ogmo00<0000007moO`1oOgl03`1oOgl00`000000oooo0?ooo`3o0?oo
og`0oooo00<000000?ooo`3oool02P3oool001T0oooo00<000000?ooo`3oool0B@3oool00`000000
oooo0?ooo`0;0?ooo`8000001@1oOgl<0?l0oa80Ogmo00<000000?ooo`3oool0503oool00`000000
Ogmo07moO`0707moO`030000001oOgl0Ogmo01H0Ogmo00<000000?ooo`3oool01@3oool010000000
Ogmo07moO`00000Y07moO`030000001oOgl0Ogmo00l0o`0000<000000?l0003o00009@3o003o0?oo
oeL0oooo00<000000?ooo`3oool02P3oool001T0oooo00<000000?ooo`3oool0B@3oool00`000000
oooo0?ooo`060?ooo`D0o`3o00<000000?l0o`3o0?l0103o0?l707moO`030000001oOgl0Ogmo01@0
Ogmo00<000000?ooo`3oool0503oool00`000000Ogmo07moO`0707moO`030000001oOgl0Ogmo01H0
Ogmo00<000000?ooo`3oool01@3oool010000000Ogmo07moO`00000;07moOb40o`003`1oOgl20000
02H0ooooC03o003o0?ooo`/0oooo00<000000?ooo`3oool02P3oool001T0oooo00<000000?ooo`3o
ool0A@3oool=0?l0o`D0oooo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0D07moO`03
0000003oool0oooo01<0oooo00<0000007moO`1oOgl0201oOgl00`000000Ogmo07moO`0E07moO`04
0000003oool0oooo0?oooa@0o`007P1oOgl00`000000Ogmo07moO`0@07moO`030000003oool0oooo
0700ooooC@3o002m0?ooo`030000003oool0oooo00X0oooo000I0?ooo`030000003oool0oooo03P0
oooo3@3o0?l40?ooo`030000003oool0oooo00/0oooo00<0000007moO`1oOgl02`1oOgl00`000000
Ogmo07moO`0E07moO`030000003oool0oooo00P0oooo;03o00000`000000o`000?l000020?l000@0
oooo0P00000207moO`030000001oOgl0Ogmo02L0Ogmo00<0000007moO`1oOgl0401oOgl00`000000
oooo0?ooo`2m0?oood`0o`00L@3oool00`000000oooo0?ooo`0:0?ooo`002@3oool300000080oooo
0P0000090?ooo`030000003oool0oooo02/0oooo3@3o0?lA0?ooo`030000003oool0oooo00/0oooo
00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07moO`0@07moO`D0o`0000<000000?l0003o0000
203o000:0?ooo`8000002@1oOgl00`000000Ogmo07moO`0D07moO`800000203oool010000000Ogmo
07moO`00000Y07moO`030000001oOgl0Ogmo0100Ogmo00<000000?ooo`3oool0o`3oool:0?oood`0
o`009@3oool00`000000oooo0?ooo`0:0?ooo`002P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool07P3oool=0?l0oah0oooo00<000000?ooo`3o
ool0303oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00<0Ogmo3@3o000507moO`80
00004`3oool00`000000Ogmo07moO`0807moO`030000001oOgl0Ogmo01D0Ogmo00<000000?ooo`3o
ool01@3oool01@000000Ogmo07moO`1oOgl0000002T0Ogmo00<0000007moO`1oOgl0401oOgl00`00
0000oooo0?ooo`3o0?oooeH0oooo9P3o000<0?ooo`001@3oool300000080oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0140oooo3@3o0?l[0?oo
o`030000003oool0oooo00`0oooo00<0000007moO`1oOgl00`1oOgl=0?l00180Ogmo00<000000?oo
o`3oool04P3oool00`000000Ogmo07moO`0807moO`030000001oOgl0Ogmo01D0Ogmo00<000000?oo
o`3oool01@3oool01@000000Ogmo07moO`1oOgl0000002T0Ogmo00<0000007moO`1oOgl0401oOgl0
0`000000oooo0?ooo`3o0?ooog/0oooo00<000000?ooo`3oool02P3oool000X0oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`060?ooo`D000000P3oool=0?l0ocP0oooo00<00000
0?ooo`3oool01P3oool<0?l000L0Ogmo00<0000007moO`1oOgl05@1oOgl00`000000oooo0?ooo`0B
0?ooo`030000001oOgl0Ogmo00P0Ogmo00<0000007moO`1oOgl05@1oOgl00`000000oooo0?ooo`05
0?ooo`050000001oOgl0Ogmo07moO`000000:@1oOgl00`000000Ogmo07moO`0@07moO`030000003o
ool0oooo0?l0ooooM`3oool5000000`0oooo000:0?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool01P3oool70?l0od40oooo3@3o00060?ooo`8000002`1oOgl00`000000Ogmo07mo
O`0E07moO`030000003oool0oooo0180oooo00<0000007moO`1oOgl0201oOgl00`000000Ogmo07mo
O`0E07moO`030000003oool0oooo00D0oooo00D0000007moO`1oOgl0Ogmo0000000Y07moO`030000
001oOgl0Ogmo0140Ogmo00<000000?ooo`3oool0o`3ooomj0?ooo`030000003oool0oooo00X0oooo
00090?ooo`8000000P3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo03P0oooo
3@3o00040?ooo`030000003oool0oooo00`0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo
07moO`0F07moO`030000003oool0oooo0140oooo00<0000007moO`1oOgl0201oOgl00`000000Ogmo
07moO`0E07moO`030000003oool0oooo00D0oooo00D0000007moO`1oOgl0Ogmo0000000Y07moO`04
0000001oOgl0Ogmo07moO`l00?l000<00000003o0000o`009@00o`3o0?oooeH0oooo00<000000?oo
o`3oool02P3oool000X0oooo00@000000?ooo`3oool0oooo0P0000090?ooo`030000003oool0oooo
02/0oooo3@3o000A0?ooo`030000003oool0oooo00`0oooo00<0000007moO`1oOgl02P1oOgl00`00
0000Ogmo07moO`0F07moO`030000003oool0oooo0140oooo00<0000007moO`1oOgl0201oOgl00`00
0000Ogmo07moO`0E07moO`030000003oool0oooo00D0oooo00D0000007moO`1oOgl0Ogmo0000000<
07moOb400?l03`1oOgl2000002H0ooooC000o`3o0?ooo`X0oooo00<000000?ooo`3oool02P3oool0
01T0oooo00<000000?ooo`3oool07P3oool=0?l001h0oooo00<000000?ooo`3oool0303oool00`00
0000Ogmo07moO`0:07moO`030000001oOgl0Ogmo01H0Ogmo00<000000?ooo`3oool04@3oool00`00
0000Ogmo07moO`0807moO`030000001oOgl0Ogmo01<0Ogmo0`0000030?oooaD00?l07@1oOgl00`00
0000Ogmo07moO`0A07moO`030000003oool0oooo0700ooooC000o`2m0?ooo`030000003oool0oooo
00X0oooo000I0?ooo`030000003oool0oooo0140oooo3@3o000[0?ooo`030000003oool0oooo00`0
oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0F07moO`8000002@3oool8003o0003
00000000o`000?l001l00?l000<00000003o0000o`000`00o`040?ooo`8000000P1oOgl00`000000
Ogmo07moO`0W07moO`030000001oOgl0Ogmo0140Ogmo00<000000?ooo`3oool0_03ooom<003o0740
oooo00<000000?ooo`3oool02P3oool001T0oooo00<000000?ooo`3oool0103oool=0?l003P0oooo
00<000000?ooo`3oool0303oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00h0Ogmo
2000o`000`0000000?l0003o0008003o00P0oooo0P00000:07moO`030000001oOgl0Ogmo01@0Ogmo
00<000000?ooo`3oool01P3oool01@000000Ogmo07moO`1oOgl0000002T0Ogmo00<0000007moO`1o
Ogl04@1oOgl00`000000oooo0?ooo`3o0?ooo`T0ooooC000o`0U0?ooo`030000003oool0oooo00X0
oooo000I0?ooo`L0o`00A@3oool00`000000oooo0?ooo`0=0?ooo`030000001oOgl0Ogmo00L0Ogmo
4`00o`0807moO`030000003oool0oooo0100oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo
07moO`0D07moO`030000003oool0oooo00H0oooo00D0000007moO`1oOgl0Ogmo0000000Y07moO`03
0000001oOgl0Ogmo0140Ogmo00<000000?ooo`3oool0o`3ooomE0?ooobH00?l0303oool001T0oooo
00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`050?oooa800?l00P1oOgl00`000000Ogmo
07moO`0G07moO`030000003oool0oooo00l0oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo
07moO`0D07moO`030000003oool0oooo00H0oooo00D0000007moO`1oOgl0Ogmo0000000Y07moO`03
0000001oOgl0Ogmo0180Ogmo00<000000?ooo`3oool0o`3ooomi0?ooo`030000003oool0oooo00X0
oooo000I0?ooo`030000003oool0oooo0480oooo3`00o`080?ooo`8000002P1oOgl00`000000Ogmo
07moO`0G07moO`030000003oool0oooo00l0oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo
07moO`0D07moO`030000003oool0oooo00H0oooo00D0000007moO`1oOgl0Ogmo0000000Y07moO`03
0000001oOgl0Ogmo0180Ogmo00<000000?ooo`3oool0o`3ooomi0?ooo`030000003oool0oooo00X0
oooo000I0?ooo`030000003oool0oooo03<0oooo3`00o`070?ooo`030000003oool0oooo00d0oooo
00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0G07moO`030000003oool0oooo00l0oooo
00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0D07moO`030000003oool0oooo00H0oooo
00D0000007moO`1oOgl0Ogmo0000000Y07moO`030000001oOgl0Ogmo0180Ogmo00<000000?ooo`3o
ool0o`3ooomi0?ooo`030000003oool0oooo00X0oooo000I0?ooo`030000003oool0oooo02<0oooo
4000o`0F0?ooo`030000003oool0oooo00d0oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo
07moO`0G07moO`030000003oool0oooo00l0oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo
07moO`0D07moO`030000003oool0oooo00H0oooo00D0000007moO`1oOgl0Ogmo0000000Y07moO`03
0000001oOgl0Ogmo0180Ogmo00<000000?ooo`3oool0o`3ooomi0?ooo`030000003oool0oooo00X0
oooo000I0?ooo`@000004`3oool?003o02H0oooo00<000000?ooo`3oool03@3oool00`000000Ogmo
07moO`0907moO`030000001oOgl0Ogmo01L0Ogmo00<000000?ooo`3oool03`3oool00`000000Ogmo
07moO`0907moO`030000001oOgl0Ogmo01@0Ogmo00<000000?ooo`3oool01P3oool01@000000Ogmo
07moO`1oOgl0000002T0Ogmo00<0000007moO`1oOgl04P1oOgl00`000000oooo0?ooo`3o0?ooogH0
oooo1000000<0?ooo`006@3oool00`000000oooo0?ooo`050?ooo`l00?l0=@3oool00`000000oooo
0?ooo`0=0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl05`1oOgl00`000000oooo
0?ooo`0?0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl0501oOgl00`000000oooo
0?ooo`060?ooo`050000001oOgl0Ogmo07moO`000000:@1oOgl00`000000Ogmo07moO`0B07moO`03
0000003oool0oooo0?l0ooooN@3oool00`000000oooo0?ooo`0:0?ooo`006@3oool8003o04@0oooo
00<000000?ooo`3oool03@3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo01L0Ogmo
00<000000?ooo`3oool03`3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo01@0Ogmo
00<000000?ooo`3oool01P3oool01@000000Ogmo07moO`1oOgl0000002T0Ogmo00<0000007moO`1o
Ogl04P1oOgl00`000?l000000?ooo`3o0?ooogT0oooo00<000000?ooo`3oool02P3oool001T0oooo
00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0=0?ooo`030000001oOgl0Ogmo00T0Ogmo
00<0000007moO`1oOgl05`1oOgl00`000000oooo0?ooo`0?0?ooo`030000001oOgl0Ogmo00T0Ogmo
00<0000007moO`1oOgl0501oOgl00`000000oooo0?ooo`060?ooo`050000001oOgl0Ogmo07moO`00
00007@1oOgmQ0000ool0oooo?03oool00`000000oooo0?ooo`0:0?ooo`006@3oool00`000000oooo
0?ooo`190?ooo`030000003oool0oooo00d0oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo
07moO`0G07moO`030000003oool0oooo00l0oooo0P00000:07moO`030000001oOgl0Ogmo0080Ogmo
6P000?l00`000000003o0000o`0P0000o``0Ogmo00<0000007moO`1oOgl04P1oOgl00`000000oooo
0?ooo`0m0?ooogl0003o_03oool00`000000oooo0?ooo`0:0?ooo`006@3oool00`000000oooo0?oo
o`190?ooo`030000003oool0oooo00d0oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07mo
O`0?07moOb/0003o4@1oOgl2000000L0oooo0P00000307moO`030000001oOgl0Ogmo02L0Ogmo00<0
000007moO`1oOgl04P1oOgl00`000000oooo0?ooo`2l0?ooogh0003o?P3oool00`000000oooo0?oo
o`0:0?ooo`006@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00d0oooo00<00000
07moO`1oOgl0201oOglC0000o`P0Ogmo0`00000?0?ooo`030000001oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl0501oOgl00`000000oooo0?ooo`060?ooo`050000001oOgl0Ogmo07moO`000000:@1o
Ogl00`000000Ogmo07moO`0B07moO`030000003oool0oooo0?l0oooo>`3ooolo0000o``0oooo000I
0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool01@3oool80000o`03000000000?l0
003o00P0003o00<0Ogmo0000001oOgl0601oOgl00`000000oooo0?ooo`0?0?ooo`030000001oOgl0
Ogmo00T0Ogmo00<0000007moO`1oOgl0501oOgl00`000000oooo0?ooo`060?ooo`050000001oOgl0
Ogmo07moO`000000:@1oOgl00`000000Ogmo07moO`0B07moO`030000003oool0oooo0?l0ooooN@3o
ool00`000000oooo0?ooo`0:0?ooo`006@3oool00`000000oooo0?ooo`0n0?oooa<0003o203oool2
000000X0Ogmo00<0000007moO`1oOgl0601oOgl00`000000oooo0?ooo`0>0?ooo`030000001oOgl0
Ogmo00T0Ogmo00<0000007moO`1oOgl0501oOgl00`000000oooo0?ooo`060?ooo`050000001oOgl0
Ogmo07moO`000000:@1oOgl00`000000Ogmo07moO`0207moOa00o`3o00<000000?l0o`3o0?l0?P3o
0?oo0?oooc/0oooo00<000000?ooo`3oool02P3oool001T0oooo00<000000?ooo`3oool0:`3ooolC
0000o`/0oooo00<000000?ooo`3oool03@3oool00`000000Ogmo07moO`0907moO`030000001oOgl0
Ogmo01P0Ogmo00<000000?ooo`3oool03P3oool00`000000Ogmo07moO`0907moO`030000001oOgl0
Ogmo0180Ogmo0`0000070?ooo`8000000`1oOgl00`000000Ogmo07moO`0:07moOb80o`3o401oOgl2
000003l0ooooOP3o0?nl0?ooo`030000003oool0oooo00X0oooo000I0?ooo`030000003oool0oooo
01T0oooo4P000?lN0?oooad000006P1oOgl2000000L0oooo1`3o0?l00`000000o`3o0?l0o`0O0?l0
o`030000003o0?l0o`3o00L0o`3o00<000000?l0o`3o0?l03`3o0?lN000001@0Ogmo00<000000?oo
o`3oool0_03ooomn0?l0och0oooo00<000000?ooo`3oool02P3oool001T0oooo00<000000?ooo`3o
ool01P3ooolC0000oc00oooo00<000000?ooo`3oool03@3oool00`000000Ogmo07moO`0907moO`03
0000001oOgl0Ogmo00H0Ogmo4P3o0?l00`000000o`3o0?l0o`060?l0o`L0oooo0P00000;07moO`03
0000001oOgl0Ogmo01@0Ogmo00<000000?ooo`3oool01P3oool01@000000Ogmo07moO`1oOgl00000
02T0Ogmo00<0000007moO`1oOgl04P1oOgl00`000000oooo0?ooo`3o0?oooc/0oooo?`3o0?l<0?oo
o`006@3oool90000od<0oooo00<000000?ooo`3oool01@3ooolM0?l0oa80Ogmo00<000000?ooo`3o
ool03P3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo01<0Ogmo00<000000?ooo`3o
ool01`3oool01@000000Ogmo07moO`1oOgl0000002T0Ogmo00<0000007moO`1oOgl04`1oOgl00`00
0000oooo0?ooo`3o0?ooogP0oooo00<000000?ooo`3oool02P3oool001T0oooo1000000m0?oooa<0
o`3o2@3oool2000000T0Ogmo00<0000007moO`1oOgl0601oOgl00`000000oooo0?ooo`0>0?ooo`03
0000001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl04`1oOgl00`000000oooo0?ooo`070?ooo`05
0000001oOgl0Ogmo07moO`000000:@1oOgl00`000000Ogmo07moO`0C07moO`030000003oool0oooo
0?l0ooooM@3oool4000000`0oooo000I0?ooo`030000003oool0oooo02/0oooo4`3o0?l;0?ooo`03
0000003oool0oooo00h0oooo00<0000007moO`1oOgl0201oOgl00`000000Ogmo07moO`0H07moO`03
0000003oool0oooo00h0oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0C07moO`03
0000003oool0oooo00L0oooo00D0000007moO`1oOgl0Ogmo0000000Y07moO`030000001oOgl0Ogmo
01<0Ogmo00<000000?ooo`3oool0o`3ooomh0?ooo`030000003oool0oooo00X0oooo000I0?ooo`03
0000003oool0oooo01T0oooo4P3o0?lN0?ooo`030000003oool0oooo00h0oooo00<0000007moO`1o
Ogl0201oOgl00`000000Ogmo07moO`0H07moO`030000003oool0oooo00h0oooo00<0000007moO`1o
Ogl02@1oOgl00`000000Ogmo07moO`0C07moO`030000003oool0oooo00L0oooo00D0000007moO`1o
Ogl0Ogmo0000000Y07moO`030000001oOgl0Ogmo01<0Ogmo00<000000?ooo`3oool0o`3ooomh0?oo
o`030000003oool0oooo00X0oooo000I0?ooo`030000003oool0oooo00H0oooo4`3o0?l`0?ooo`03
0000003oool0oooo00h0oooo00<0000007moO`1oOgl0201oOgl00`000000Ogmo07moO`0H07moO`03
0000003oool0oooo00h0oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0C07moO`03
0000003oool0oooo00L0oooo00D0000007moO`1oOgl0Ogmo0000000Y07moO`030000001oOgl0Ogmo
01<0Ogmo00<000000?ooo`3oool0o`3ooomh0?ooo`030000003oool0oooo00X0oooo000I0?ooo`T0
o`3o@`3oool00`000000oooo0?ooo`0>0?ooo`030000001oOgl0Ogmo00P0Ogmo00<0000007moO`1o
Ogl0601oOgl00`000000oooo0?ooo`0>0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1o
Ogl04`1oOgl00`000000oooo0?ooo`070?ooo`050000001oOgl0Ogmo07moO`000000:@1oOgl00`00
0000Ogmo07moO`0C07moO`030000003oool0oooo0?l0ooooN03oool00`000000oooo0?ooo`0:0?oo
o`006@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00h0oooo00<0000007moO`1o
Ogl0201oOgl00`000000Ogmo07moO`0H07moO`030000003oool0oooo00h0oooo00<0000007moO`1o
Ogl02@1oOgl00`000000Ogmo07moO`0C07moO`030000003oool0oooo00L0oooo00D0000007moO`1o
Ogl0Ogmo0000000Y07moO`030000001oOgl0Ogmo01<0Ogmo00<000000?ooo`3oool0o`3ooomh0?oo
o`030000003oool0oooo00X0oooo000I0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3o
ool03P3oool00`000000Ogmo07moO`0807moO`030000001oOgl0Ogmo01P0Ogmo00<000000?ooo`3o
ool03P3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo01<0Ogmo00<000000?ooo`3o
ool01`3oool01@000000Ogmo07moO`1oOgl0000002T0Ogmo00<0000007moO`1oOgl04`1oOgl00`00
0000oooo0?ooo`3o0?ooogP0oooo00<000000?ooo`3oool02P3oool001T0oooo00<000000?ooo`3o
ool0B@3oool00`000000oooo0?ooo`0>0?ooo`030000001oOgl0Ogmo00P0Ogmo00<0000007moO`1o
Ogl0601oOgl00`000000oooo0?ooo`0>0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1o
Ogl04`1oOgl00`000000oooo0?ooo`070?ooo`050000001oOgl0Ogmo07moO`000000:@1oOgl00`00
0000Ogmo07moO`0C07moO`030000003oool0oooo0?l0ooooN03oool00`000000oooo0?ooo`0:0?oo
o`006@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00h0oooo00<0000007moO`1o
Ogl0201oOgl00`000000Ogmo07moO`0H07moO`030000003oool0oooo00h0oooo00<0000007moO`1o
Ogl02@1oOgl00`000000Ogmo07moO`0C07moO`030000003oool0oooo00L0oooo00D0000007moO`1o
Ogl0Ogmo0000000Y07moO`030000001oOgl0Ogmo01<0Ogmo00<000000?ooo`3oool0o`3ooomh0?oo
o`030000003oool0oooo00X0oooo000I0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3o
ool03P3oool00`000000Ogmo07moO`0807moO`030000001oOgl0Ogmo01P0Ogmo00<000000?ooo`3o
ool03P3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo01<0Ogmo00<000000?ooo`3o
ool01`3oool01@000000Ogmo07moO`1oOgl0000002T0Ogmo00<0000007moO`1oOgl04`1oOgl00`00
0000oooo0?ooo`3o0?ooogP0oooo00<000000?ooo`3oool02P3oool001T0oooo00<000000?ooo`3o
ool0B@3oool00`000000oooo0?ooo`0>0?ooo`030000001oOgl0Ogmo00P0Ogmo00<0000007moO`1o
Ogl0601oOgl00`000000oooo0?ooo`0>0?ooo`030000001oOgl0Ogmo00T0Ogmo00<0000007moO`1o
Ogl04`1oOgl00`000000oooo0?ooo`070?ooo`050000001oOgl0Ogmo07moO`000000:@1oOgl00`00
0000Ogmo07moO`0C07moO`030000003oool0oooo0?l0ooooN03oool00`000000oooo0?ooo`0:0?oo
o`006@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00h0oooo00<0000007moO`1o
Ogl0201oOgl00`000000Ogmo07moO`0H07moO`030000003oool0oooo00h0oooo00<0000007moO`1o
Ogl02@1oOgl00`000000Ogmo07moO`0C07moO`030000003oool0oooo00L0oooo00D0000007moO`1o
Ogl0Ogmo0000000Y07moO`030000001oOgl0Ogmo01<0Ogmo00<000000?ooo`3oool0o`3ooomh0?oo
o`030000003oool0oooo00X0oooo000I0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3o
ool03P3oool00`000000Ogmo07moO`0807moO`030000001oOgl0Ogmo01T0Ogmo00<000000?ooo`3o
ool0303oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo01<0Ogmo00<000000?ooo`3o
ool01`3oool01@000000Ogmo07moO`1oOgl0000002T0Ogmo00<0000007moO`1oOgl04`1oOgl00`00
0000oooo0?ooo`3o0?ooogP0oooo00<000000?ooo`3oool02P3oool001T0oooo100000180?ooo`03
0000003oool0oooo00h0oooo00<0000007moO`1oOgl0201oOgl00`000000Ogmo07moO`0I07moO`03
0000003oool0oooo00`0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0C07moO`03
0000003oool0oooo00L0oooo00D0000007moO`1oOgl0Ogmo0000000Y07moO`030000001oOgl0Ogmo
01<0Ogmo00<000000?ooo`3oool0o`3ooome0?ooo`@00000303oool001T0oooo00<000000?ooo`3o
ool0B@3oool00`000000oooo0?ooo`0>0?ooo`030000001oOgl0Ogmo00P0Ogmo00<0000007moO`1o
Ogl06@1oOgl00`000000oooo0?ooo`0<0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1o
Ogl04`1oOgl00`000000oooo0?ooo`070?ooo`050000001oOgl0Ogmo07moO`000000:@1oOgl00`00
0000Ogmo07moO`0C07moO`030000003oool0oooo0?l0ooooN03oool00`000000oooo0?ooo`0:0?oo
o`006@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00h0oooo00<0000007moO`1o
Ogl0201oOgl00`000000Ogmo07moO`0I07moO`030000003oool0oooo00`0oooo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0C07moO`030000003oool0oooo00L0oooo00D0000007moO`1o
Ogl0Ogmo0000000Y07moO`030000001oOgl0Ogmo01<0Ogmo00<000000?ooo`3oool0o`3ooomh0?oo
o`030000003oool0oooo00X0oooo000I0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3o
ool03P3oool00`000000Ogmo07moO`0807moO`030000001oOgl0Ogmo01T0Ogmo00<000000?ooo`3o
ool0303oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo01<0Ogmo00<000000?ooo`3o
ool01`3oool01@000000Ogmo07moO`1oOgl0000002T0Ogmo00<0000007moO`1oOgl04`1oOgl00`00
0000oooo0?ooo`3o0?ooogP0oooo00<000000?ooo`3oool02P3oool001T0oooo00<000000?ooo`3o
ool0B@3oool00`000000oooo0?ooo`0>0?ooo`030000001oOgl0Ogmo00P0Ogmo00<0000007moO`1o
Ogl06@1oOgl00`000000oooo0?ooo`0<0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1o
Ogl04`1oOgl00`000000oooo0?ooo`070?ooo`050000001oOgl0Ogmo07moO`000000:@1oOgl00`00
0000Ogmo07moO`0C07moO`030000003oool0oooo0?l0ooooN03oool00`000000oooo0?ooo`0:0?oo
o`006@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00h0oooo00<0000007moO`1o
Ogl0201oOgl00`000000Ogmo07moO`0I07moO`030000003oool0oooo00`0oooo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0C07moO`030000003oool0oooo00L0oooo00D0000007moO`1o
Ogl0Ogmo0000000Y07moO`030000001oOgl0Ogmo01<0Ogmo00<000000?ooo`3oool0o`3ooomh0?oo
o`030000003oool0oooo00X0oooo000I0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3o
ool03P3oool00`000000Ogmo07moO`0807moO`030000001oOgl0Ogmo01T0Ogmo00<000000?ooo`3o
ool0303oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo01<0Ogmo00<000000?ooo`3o
ool01`3oool01@000000Ogmo07moO`1oOgl0000002T0Ogmo00<0000007moO`1oOgl04`1oOgl00`00
0000oooo0?ooo`3o0?ooogP0oooo00<000000?ooo`3oool02P3oool001T0oooo00<000000?ooo`3o
ool0B@3oool00`000000oooo0?ooo`0>0?ooo`030000001oOgl0Ogmo00P0Ogmo00<0000007moO`1o
Ogl06@1oOgl00`000000oooo0?ooo`0<0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1o
Ogl04`1oOgl00`000000oooo0?ooo`070?ooo`050000001oOgl0Ogmo07moO`000000:@1oOgl00`00
0000Ogmo07moO`0C07moO`030000003oool0oooo0?l0ooooN03oool00`000000oooo0?ooo`0:0?oo
o`006@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00h0oooo00<0000007moO`1o
Ogl0201oOgl00`000000Ogmo07moO`0I07moO`030000003oool0oooo00`0oooo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0C07moO`030000003oool0oooo00L0oooo00D0000007moO`1o
Ogl0Ogmo0000000Y07moO`030000001oOgl0Ogmo01<0Ogmo00<000000?ooo`3oool0o`3ooomh0?oo
o`030000003oool0oooo00X0oooo000I0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3o
ool03P3oool00`000000Ogmo07moO`0807moO`030000001oOgl0Ogmo01T0Ogmo00<000000?ooo`3o
ool0303oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo01<0Ogmo00<000000?ooo`3o
ool01`3oool01@000000Ogmo07moO`1oOgl0000002T0Ogmo00<0000007moO`1oOgl04`1oOgl00`00
0000oooo0?ooo`3o0?ooogP0oooo00<000000?ooo`3oool02P3oool001T0oooo00<000000?ooo`3o
ool0B@3oool00`000000oooo0?ooo`0>0?ooo`030000001oOgl0Ogmo00P0Ogmo00<0000007moO`1o
Ogl06@1oOgl00`000000oooo0?ooo`0<0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1o
Ogl04`1oOgl00`000000oooo0?ooo`070?ooo`050000001oOgl0Ogmo07moO`000000:@1oOgl00`00
0000Ogmo07moO`0C07moO`030000003oool0oooo0?l0ooooN03oool00`000000oooo0?ooo`0:0?oo
o`006@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00h0oooo00<0000007moO`1o
Ogl0201oOgl00`000000Ogmo07moO`0I07moO`030000003oool0oooo00`0oooo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0C07moO`030000003oool0oooo00L0oooo00D0000007moO`1o
Ogl0Ogmo0000000Y07moO`030000001oOgl0Ogmo01<0Ogmo00<000000?ooo`3oool0o`3ooomh0?oo
o`030000003oool0oooo00X0oooo000I0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3o
ool03P3oool00`000000Ogmo07moO`0807moO`030000001oOgl0Ogmo01T0Ogmo00<000000?ooo`3o
ool0303oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo01<0Ogmo00<000000?ooo`3o
ool01`3oool01@000000Ogmo07moO`1oOgl0000002T0Ogmo00<0000007moO`1oOgl04`1oOgl00`00
0000oooo0?ooo`3o0?ooogP0oooo00<000000?ooo`3oool02P3oool001T0oooo100000180?ooo`03
0000003oool0oooo00l0oooo00<0000007moO`1oOgl01`1oOgl00`000000Ogmo07moO`0I07moO`03
0000003oool0oooo00`0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0B07moO`03
0000003oool0oooo00P0oooo00D0000007moO`1oOgl0Ogmo0000000Y07moO`030000001oOgl0Ogmo
01@0Ogmo00<000000?ooo`3oool0o`3ooomd0?ooo`@00000303oool001T0oooo00<000000?ooo`3o
ool0B@3oool00`000000oooo0?ooo`0?0?ooo`030000001oOgl0Ogmo00L0Ogmo00<0000007moO`1o
Ogl06@1oOgl00`000000oooo0?ooo`0<0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1o
Ogl04P1oOgl00`000000oooo0?ooo`080?ooo`050000001oOgl0Ogmo07moO`000000:@1oOgl00`00
0000Ogmo07moO`0D07moO`030000003oool0oooo0?l0ooooM`3oool00`000000oooo0?ooo`0:0?oo
o`006@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo00<0000007moO`1o
Ogl01`1oOgl00`000000Ogmo07moO`0I07moO`030000003oool0oooo00`0oooo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0B07moO`030000003oool0oooo00P0oooo00D0000007moO`1o
Ogl0Ogmo0000000Y07moO`030000001oOgl0Ogmo01@0Ogmo00<000000?ooo`3oool0o`3ooomg0?oo
o`030000003oool0oooo00X0oooo000I0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3o
ool03`3oool00`000000Ogmo07moO`0707moO`030000001oOgl0Ogmo01T0Ogmo00<000000?ooo`3o
ool0303oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo0180Ogmo00<000000?ooo`3o
ool0203oool01@000000Ogmo07moO`1oOgl0000002T0Ogmo00<0000007moO`1oOgl0501oOgl00`00
0000oooo0?ooo`3o0?ooogL0oooo00<000000?ooo`3oool02P3oool001T0oooo00<000000?ooo`3o
ool0B@3oool00`000000oooo0?ooo`0?0?ooo`030000001oOgl0Ogmo00L0Ogmo00<0000007moO`1o
Ogl06P1oOgl00`000000oooo0?ooo`0;0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1o
Ogl04P1oOgl00`000000oooo0?ooo`080?ooo`050000001oOgl0Ogmo07moO`000000:@1oOgl00`00
0000Ogmo07moO`0D07moO`030000003oool0oooo0?l0ooooM`3oool00`000000oooo0?ooo`0:0?oo
o`006@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo00<0000007moO`1o
Ogl01`1oOgl00`000000Ogmo07moO`0J07moO`030000003oool0oooo00/0oooo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0B07moO`030000003oool0oooo00P0oooo00D0000007moO`1o
Ogl0Ogmo0000000Y07moO`030000001oOgl0Ogmo01@0Ogmo00<000000?ooo`3oool0o`3ooomg0?oo
o`030000003oool0oooo00X0oooo000I0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3o
ool03`3oool00`000000Ogmo07moO`0707moO`030000001oOgl0Ogmo01X0Ogmo00<000000?ooo`3o
ool02`3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo0180Ogmo00<000000?ooo`3o
ool0203oool01@000000Ogmo07moO`1oOgl0000002T0Ogmo00<0000007moO`1oOgl0501oOgl00`00
0000oooo0?ooo`3o0?ooogL0oooo00<000000?ooo`3oool02P3oool001T0oooo00<000000?ooo`3o
ool0B@3oool00`000000oooo0?ooo`0?0?ooo`030000001oOgl0Ogmo00L0Ogmo00<0000007moO`1o
Ogl06P1oOgl00`000000oooo0?ooo`0;0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1o
Ogl04P1oOgl00`000000oooo0?ooo`080?ooo`050000001oOgl0Ogmo07moO`000000:@1oOgl00`00
0000Ogmo07moO`0D07moO`030000003oool0oooo0?l0ooooM`3oool00`000000oooo0?ooo`0:0?oo
o`006@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo00<0000007moO`1o
Ogl01`1oOgl00`000000Ogmo07moO`0J07moO`030000003oool0oooo00/0oooo00<0000007moO`1o
Ogl02P1oOgl00`000000Ogmo07moO`0B07moO`030000003oool0oooo00P0oooo00D0000007moO`1o
Ogl0Ogmo0000000Y07moO`030000001oOgl0Ogmo01@0Ogmo00<000000?ooo`3oool0o`3ooomg0?oo
o`030000003oool0oooo00X0oooo000I0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3o
ool03`3oool00`000000Ogmo07moO`0707moO`030000001oOgl0Ogmo01X0Ogmo00<000000?ooo`3o
ool02`3oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo0180Ogmo00<000000?ooo`3o
ool0203oool01@000000Ogmo07moO`1oOgl0000002T0Ogmo00<0000007moO`1oOgl0501oOgl00`00
0000oooo0?ooo`3o0?ooogL0oooo00<000000?ooo`3oool02P3oool000h0oooo0P0000090?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool00`000000Ogmo07moO`0707moO`03
0000001oOgl0Ogmo01X0Ogmo00<000000?ooo`3oool02`3oool00`000000Ogmo07moO`0:07moO`03
0000001oOgl0Ogmo0180Ogmo00<000000?ooo`3oool0203oool01@000000Ogmo07moO`1oOgl00000
02T0Ogmo00<0000007moO`1oOgl0501oOgl00`000000oooo0?ooo`3o0?ooogL0oooo00<000000?oo
o`3oool02P3oool000d0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo00l0oooo00<0000007moO`1oOgl01`1oOgl00`000000Ogmo07moO`0J07mo
O`030000003oool0oooo00/0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0B07mo
O`030000003oool0oooo00P0oooo00D0000007moO`1oOgl0Ogmo0000000Y07moO`030000001oOgl0
Ogmo01@0Ogmo00<000000?ooo`3oool0o`3ooomg0?ooo`030000003oool0oooo00X0oooo000=0?oo
o`040000003oool0oooo000000P0oooo1@0000170?ooocX000003@3ooomc00000?l0ooooM@3oool5
000000`0oooo000=0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool0B@3oool0
0`000000oooo0?ooo`0?0?ooo`030000001oOgl0Ogmo00L0Ogmo00<0000007moO`1oOgl06P1oOgl0
0`000000oooo0?ooo`0;0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl04P1oOgl0
0`000000oooo0?ooo`080?ooo`050000001oOgl0Ogmo07moO`000000:@1oOgl00`000000Ogmo07mo
O`0D07moO`030000003oool0oooo0?l0ooooM`3oool00`000000oooo0?ooo`0:0?ooo`003@3oool0
10000000oooo0?ooo`0000080?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool03`3o
ool00`000000Ogmo07moO`0707moO`030000001oOgl0Ogmo01X0Ogmo00<000000?ooo`3oool02`3o
ool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo0180Ogmo00<000000?ooo`3oool0203o
ool01@000000Ogmo07moO`1oOgl0000002T0Ogmo00<0000007moO`1oOgl0501oOgl00`000000oooo
0?ooo`3o0?ooogL0oooo00<000000?ooo`3oool02P3oool000d0oooo00@000000?ooo`3oool00000
203oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo00<0000007moO`1oOgl0
1`1oOgl00`000000Ogmo07moO`0J07moO`030000003oool0oooo00/0oooo00<0000007moO`1oOgl0
2P1oOgl00`000000Ogmo07moO`0B07moO`030000003oool0oooo00P0oooo00D0000007moO`1oOgl0
Ogmo0000000Y07moO`030000001oOgl0Ogmo01@0Ogmo00<000000?ooo`3oool0o`3ooomg0?ooo`03
0000003oool0oooo00X0oooo000>0?ooo`8000002@3oool00`000000oooo0?ooo`190?ooo`030000
003oool0oooo00l0oooo00<0000007moO`1oOgl01`1oOgl00`000000Ogmo07moO`0J07moO`030000
003oool0oooo00/0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0B07moO`030000
003oool0oooo00P0oooo00D0000007moO`1oOgl0Ogmo0000000Y07moO`030000001oOgl0Ogmo01@0
Ogmo00<000000?ooo`3oool0o`3ooomg0?ooo`030000003oool0oooo00X0oooo000I0?ooo`030000
003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool00`000000Ogmo07moO`0707moO`030000
001oOgl0Ogmo01X0Ogmo00<000000?ooo`3oool02`3oool00`000000Ogmo07moO`0:07moO`030000
001oOgl0Ogmo0180Ogmo00<000000?ooo`3oool0203oool01@000000Ogmo07moO`1oOgl0000002T0
Ogmo00<0000007moO`1oOgl0501oOgl00`000000oooo0?ooo`3o0?ooogL0oooo00<000000?ooo`3o
ool02P3oool001T0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?ooo`030000
001oOgl0Ogmo00L0Ogmo00<0000007moO`1oOgl06P1oOgl00`000000oooo0?ooo`0;0?ooo`030000
001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl04P1oOgl00`000000oooo0?ooo`080?ooo`050000
001oOgl0Ogmo07moO`000000:@1oOgl00`000000Ogmo07moO`0D07moO`030000003oool0oooo0?l0
ooooM`3oool00`000000oooo0?ooo`0:0?ooo`006@3oool00`000000oooo0?ooo`190?ooo`030000
003oool0oooo00l0oooo00<0000007moO`1oOgl01`1oOgl00`000000Ogmo07moO`0J07moO`030000
003oool0oooo00/0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0B07moO`030000
003oool0oooo00P0oooo00D0000007moO`1oOgl0Ogmo0000000Y07moO`030000001oOgl0Ogmo01@0
Ogmo00<000000?ooo`3oool0o`3ooomg0?ooo`030000003oool0oooo00X0oooo000I0?ooo`030000
003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool00`000000Ogmo07moO`0707moO`030000
001oOgl0Ogmo01X0Ogmo00<000000?ooo`3oool02`3oool00`000000Ogmo07moO`0:07moO`030000
001oOgl0Ogmo0180Ogmo00<000000?ooo`3oool0203oool01@000000Ogmo07moO`1oOgl0000002T0
Ogmo00<0000007moO`1oOgl0501oOgl00`000000oooo0?ooo`3o0?ooogL0oooo00<000000?ooo`3o
ool02P3oool001T0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?ooo`030000
001oOgl0Ogmo00L0Ogmo00<0000007moO`1oOgl06P1oOgl00`000000oooo0?ooo`0;0?ooo`030000
001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl04P1oOgl00`000000oooo0?ooo`080?ooo`050000
001oOgl0Ogmo07moO`000000:@1oOgl00`000000Ogmo07moO`0D07moO`030000003oool0oooo0?l0
ooooM`3oool00`000000oooo0?ooo`0:0?ooo`006@3oool00`000000oooo0?ooo`190?ooo`030000
003oool0oooo00l0oooo00<0000007moO`1oOgl01`1oOgl00`000000Ogmo07moO`0I07moO`030000
003oool0oooo00`0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0B07moO`030000
003oool0oooo00P0oooo00D0000007moO`1oOgl0Ogmo0000000Y07moO`030000001oOgl0Ogmo01@0
Ogmo00<000000?ooo`3oool0o`3ooomg0?ooo`030000003oool0oooo00X0oooo000I0?ooo`030000
003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool00`000000Ogmo07moO`0707moO`030000
001oOgl0Ogmo01T0Ogmo00<000000?ooo`3oool0303oool00`000000Ogmo07moO`0:07moO`030000
001oOgl0Ogmo0180Ogmo00<000000?ooo`3oool0203oool01@000000Ogmo07moO`1oOgl0000002T0
Ogmo00<0000007moO`1oOgl0501oOgl00`000000oooo0?ooo`3o0?ooogL0oooo00<000000?ooo`3o
ool02P3oool001T0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?ooo`030000
001oOgl0Ogmo00L0Ogmo00<0000007moO`1oOgl06@1oOgl00`000000oooo0?ooo`0<0?ooo`030000
001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl04P1oOgl00`000000oooo0?ooo`080?ooo`050000
001oOgl0Ogmo07moO`000000:@1oOgl00`000000Ogmo07moO`0D07moO`030000003oool0oooo0?l0
ooooM`3oool00`000000oooo0?ooo`0:0?ooo`006@3oool4000004P0oooo00<000000?ooo`3oool0
3`3oool00`000000Ogmo07moO`0707moO`030000001oOgl0Ogmo01T0Ogmo00<000000?ooo`3oool0
303oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo0180Ogmo00<000000?ooo`3oool0
203oool01@000000Ogmo07moO`1oOgl0000002T0Ogmo00<0000007moO`1oOgl0501oOgl00`000000
oooo0?ooo`3o0?ooog@0oooo1000000<0?ooo`006@3oool00`000000oooo0?ooo`190?ooo`030000
003oool0oooo00h0oooo00<0000007moO`1oOgl0201oOgl00`000000Ogmo07moO`0I07moO`030000
003oool0oooo00`0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0C07moO`030000
003oool0oooo00L0oooo00D0000007moO`1oOgl0Ogmo0000000Y07moO`030000001oOgl0Ogmo01<0
Ogmo00<000000?ooo`3oool0o`3ooomh0?ooo`030000003oool0oooo00X0oooo000I0?ooo`030000
003oool0oooo04T0oooo00<000000?ooo`3oool03P3oool00`000000Ogmo07moO`0807moO`030000
001oOgl0Ogmo01T0Ogmo00<000000?ooo`3oool0303oool00`000000Ogmo07moO`0:07moO`030000
001oOgl0Ogmo01<0Ogmo00<000000?ooo`3oool01`3oool01@000000Ogmo07moO`1oOgl0000002T0
Ogmo00<0000007moO`1oOgl04`1oOgl00`000000oooo0?ooo`3o0?ooogP0oooo00<000000?ooo`3o
ool02P3oool001T0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0>0?ooo`030000
001oOgl0Ogmo00P0Ogmo00<0000007moO`1oOgl06@1oOgl00`000000oooo0?ooo`0<0?ooo`030000
001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl04`1oOgl00`000000oooo0?ooo`070?ooo`050000
001oOgl0Ogmo07moO`000000:@1oOgl00`000000Ogmo07moO`0C07moO`030000003oool0oooo0?l0
ooooN03oool00`000000oooo0?ooo`0:0?ooo`006@3oool00`000000oooo0?ooo`190?ooo`030000
003oool0oooo00h0oooo00<0000007moO`1oOgl0201oOgl00`000000Ogmo07moO`0I07moO`030000
003oool0oooo00`0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0C07moO`030000
003oool0oooo00L0oooo00D0000007moO`1oOgl0Ogmo0000000Y07moO`030000001oOgl0Ogmo01<0
Ogmo00<000000?ooo`3oool0o`3ooomh0?ooo`030000003oool0oooo00X0oooo000I0?ooo`030000
003oool0oooo04T0oooo00<000000?ooo`3oool03P3oool00`000000Ogmo07moO`0807moO`030000
001oOgl0Ogmo01T0Ogmo00<000000?ooo`3oool0303oool00`000000Ogmo07moO`0:07moO`030000
001oOgl0Ogmo01<0Ogmo00<000000?ooo`3oool01`3oool01@000000Ogmo07moO`1oOgl0000002T0
Ogmo00<0000007moO`1oOgl04`1oOgl00`000000oooo0?ooo`3o0?ooogP0oooo00<000000?ooo`3o
ool02P3oool001T0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0>0?ooo`030000
001oOgl0Ogmo00P0Ogmo00<0000007moO`1oOgl06@1oOgl00`000000oooo0?ooo`0<0?ooo`030000
001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl04`1oOgl00`000000oooo0?ooo`070?ooo`050000
001oOgl0Ogmo07moO`000000:@1oOgl00`000000Ogmo07moO`0C07moO`030000003oool0oooo0?l0
ooooN03oool00`000000oooo0?ooo`0:0?ooo`006@3oool00`000000oooo0?ooo`190?ooo`030000
003oool0oooo00h0oooo00<0000007moO`1oOgl0201oOgl00`000000Ogmo07moO`0I07moO`030000
003oool0oooo00`0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0C07moO`030000
003oool0oooo00L0oooo00D0000007moO`1oOgl0Ogmo0000000Y07moO`030000001oOgl0Ogmo01<0
Ogmo00<000000?ooo`3oool0o`3ooomh0?ooo`030000003oool0oooo00X0oooo000I0?ooo`030000
003oool0oooo04T0oooo00<000000?ooo`3oool03P3oool00`000000Ogmo07moO`0807moO`030000
001oOgl0Ogmo01T0Ogmo00<000000?ooo`3oool0303oool00`000000Ogmo07moO`0:07moO`030000
001oOgl0Ogmo01<0Ogmo00<000000?ooo`3oool01`3oool01@000000Ogmo07moO`1oOgl0000002T0
Ogmo00<0000007moO`1oOgl04`1oOgl00`000000oooo0?ooo`3o0?ooogP0oooo00<000000?ooo`3o
ool02P3oool001T0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0>0?ooo`030000
001oOgl0Ogmo00P0Ogmo00<0000007moO`1oOgl06@1oOgl00`000000oooo0?ooo`0<0?ooo`030000
001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl04`1oOgl00`000000oooo0?ooo`070?ooo`050000
001oOgl0Ogmo07moO`000000:@1oOgl00`000000Ogmo07moO`0C07moO`030000003oool0oooo0?l0
ooooN03oool00`000000oooo0?ooo`0:0?ooo`006@3oool00`000000oooo0?ooo`190?ooo`030000
003oool0oooo00h0oooo00<0000007moO`1oOgl0201oOgl00`000000Ogmo07moO`0I07moO`030000
003oool0oooo00`0oooo00<0000007moO`1oOgl02P1oOgl00`000000Ogmo07moO`0C07moO`030000
003oool0oooo00L0oooo00D0000007moO`1oOgl0Ogmo0000000Y07moO`030000001oOgl0Ogmo01<0
Ogmo00<000000?ooo`3oool0o`3ooomh0?ooo`030000003oool0oooo00X0oooo000I0?ooo`030000
003oool0oooo04T0oooo00<000000?ooo`3oool03P3oool00`000000Ogmo07moO`0807moO`030000
001oOgl0Ogmo01T0Ogmo00<000000?ooo`3oool0303oool00`000000Ogmo07moO`0:07moO`030000
001oOgl0Ogmo01<0Ogmo00<000000?ooo`3oool01`3oool01@000000Ogmo07moO`1oOgl0000002T0
Ogmo00<0000007moO`1oOgl04`1oOgl00`000000oooo0?ooo`3o0?ooogP0oooo00<000000?ooo`3o
ool02P3oool001T0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0>0?ooo`030000
001oOgl0Ogmo00P0Ogmo00<0000007moO`1oOgl06@1oOgl00`000000oooo0?ooo`0<0?ooo`030000
001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl04`1oOgl00`000000oooo0?ooo`070?ooo`050000
001oOgl0Ogmo07moO`000000:@1oOgl00`000000Ogmo07moO`0C07moO`030000003oool0oooo0?l0
ooooN03oool00`000000oooo0?ooo`0:0?ooo`006@3oool4000004P0oooo00<000000?ooo`3oool0
3P3oool00`000000Ogmo07moO`0807moO`030000001oOgl0Ogmo01T0Ogmo00<000000?ooo`3oool0
303oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo01<0Ogmo00<000000?ooo`3oool0
1`3oool01@000000Ogmo07moO`1oOgl0000002T0Ogmo00<0000007moO`1oOgl04`1oOgl00`000000
oooo0?ooo`3o0?ooogD0oooo1000000<0?ooo`006@3oool00`000000oooo0?ooo`190?ooo`030000
003oool0oooo00h0oooo00<0000007moO`1oOgl0201oOgl00`000000Ogmo07moO`0H07moO`030000
003oool0oooo00h0oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0C07moO`030000
003oool0oooo00L0oooo00D0000007moO`1oOgl0Ogmo0000000Y07moO`030000001oOgl0Ogmo01<0
Ogmo00<000000?ooo`3oool0o`3ooomh0?ooo`030000003oool0oooo00X0oooo000I0?ooo`030000
003oool0oooo04T0oooo00<000000?ooo`3oool03P3oool00`000000Ogmo07moO`0807moO`030000
001oOgl0Ogmo01P0Ogmo00<000000?ooo`3oool03P3oool00`000000Ogmo07moO`0907moO`030000
001oOgl0Ogmo01<0Ogmo00<000000?ooo`3oool01`3oool01@000000Ogmo07moO`1oOgl0000002T0
Ogmo00<0000007moO`1oOgl04`1oOgl00`000000oooo0?ooo`3o0?ooogP0oooo00<000000?ooo`3o
ool02P3oool001T0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0>0?ooo`030000
001oOgl0Ogmo00P0Ogmo00<0000007moO`1oOgl0601oOgl00`000000oooo0?ooo`0>0?ooo`030000
001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl04`1oOgl00`000000oooo0?ooo`070?ooo`050000
001oOgl0Ogmo07moO`000000:@1oOgl00`000000Ogmo07moO`0C07moO`030000003oool0oooo0?l0
ooooN03oool00`000000oooo0?ooo`0:0?ooo`006@3oool00`000000oooo0?ooo`190?ooo`030000
003oool0oooo00h0oooo00<0000007moO`1oOgl0201oOgl00`000000Ogmo07moO`0H07moO`030000
003oool0oooo00h0oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0C07moO`030000
003oool0oooo00L0oooo00D0000007moO`1oOgl0Ogmo0000000Y07moO`030000001oOgl0Ogmo01<0
Ogmo00<000000?ooo`3oool0o`3ooomh0?ooo`030000003oool0oooo00X0oooo000I0?ooo`030000
003oool0oooo04T0oooo00<000000?ooo`3oool03P3oool00`000000Ogmo07moO`0807moO`030000
001oOgl0Ogmo01P0Ogmo00<000000?ooo`3oool03P3oool00`000000Ogmo07moO`0907moO`030000
001oOgl0Ogmo01<0Ogmo00<000000?ooo`3oool01`3oool01@000000Ogmo07moO`1oOgl0000002T0
Ogmo00<0000007moO`1oOgl04`1oOgl00`000000oooo0?ooo`3o0?ooogP0oooo00<000000?ooo`3o
ool02P3oool001T0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0>0?ooo`030000
001oOgl0Ogmo00P0Ogmo00<0000007moO`1oOgl0601oOgl00`000000oooo0?ooo`0>0?ooo`030000
001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl04`1oOgl00`000000oooo0?ooo`070?ooo`050000
001oOgl0Ogmo07moO`000000:@1oOgl00`000000Ogmo07moO`0C07moO`030000003oool0oooo0?l0
ooooN03oool00`000000oooo0?ooo`0:0?ooo`006@3oool00`000000oooo0?ooo`190?ooo`030000
003oool0oooo00h0oooo00<0000007moO`1oOgl0201oOgl00`000000Ogmo07moO`0H07moO`030000
003oool0oooo00h0oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0C07moO`030000
003oool0oooo00L0oooo00D0000007moO`1oOgl0Ogmo0000000Y07moO`030000001oOgl0Ogmo01<0
Ogmo00<000000?ooo`3oool0o`3ooomh0?ooo`030000003oool0oooo00X0oooo000I0?ooo`030000
003oool0oooo04T0oooo00<000000?ooo`3oool03P3oool00`000000Ogmo07moO`0807moO`030000
001oOgl0Ogmo01P0Ogmo00<000000?ooo`3oool03P3oool00`000000Ogmo07moO`0907moO`030000
001oOgl0Ogmo01<0Ogmo00<000000?ooo`3oool01`3oool01@000000Ogmo07moO`1oOgl0000002T0
Ogmo00<0000007moO`1oOgl04`1oOgl00`000000oooo0?ooo`3o0?ooogP0oooo00<000000?ooo`3o
ool02P3oool001T0oooo3@3o0?lo0?ooo`030000003oool0oooo00h0oooo00<0000007moO`1oOgl0
201oOgl00`000000Ogmo07moO`0H07moO`030000003oool0oooo00h0oooo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0C07moO`030000003oool0oooo00L0oooo00D0000007moO`1oOgl0
Ogmo0000000Y07moO`030000001oOgl0Ogmo01<0Ogmo00<000000?ooo`3oool0o`3ooomh0?ooo`03
0000003oool0oooo00X0oooo000I0?ooo`030000003oool0oooo00X0oooo5`3o0?lX0?ooo`030000
003oool0oooo00h0oooo00<0000007moO`1oOgl0201oOgl00`000000Ogmo07moO`0H07moO`030000
003oool0oooo00h0oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0C07moO`030000
003oool0oooo00L0oooo00D0000007moO`1oOgl0Ogmo0000000Y07moO`030000001oOgl0Ogmo01<0
Ogmo00<000000?ooo`3oool0o`3ooomh0?ooo`030000003oool0oooo00X0oooo000I0?ooo`030000
003oool0oooo0240oooo5`3o0?lA0?ooo`030000003oool0oooo00h0oooo00<0000007moO`1oOgl0
201oOgl00`000000Ogmo07moO`0H07moO`030000003oool0oooo00h0oooo00<0000007moO`1oOgl0
2@1oOgl00`000000Ogmo07moO`0C07moO`030000003oool0oooo00L0oooo00D0000007moO`1oOgl0
Ogmo0000000Y07moO`030000001oOgl0Ogmo01<0Ogmo00<000000?ooo`3oool0o`3ooomh0?ooo`03
0000003oool0oooo00X0oooo000I0?ooo`030000003oool0oooo03P0oooo5`3o0?l;0?ooo`030000
001oOgl0Ogmo00P0Ogmo00<0000007moO`1oOgl0601oOgl00`000000oooo0?ooo`0>0?ooo`030000
001oOgl0Ogmo00T0Ogmo00<0000007moO`1oOgl04`1oOgl00`000000oooo0?ooo`070?ooo`050000
001oOgl0Ogmo07moO`000000:@1oOgl00`000000Ogmo07moO`0C07moO`030000003oool0oooo0?l0
ooooN03oool00`000000oooo0?ooo`0:0?ooo`006@3oool4000004P0oooo00<000000?ooo`3oool0
0`3ooolF0?l0o`030000001oOgl0Ogmo01P0Ogmo00<000000?ooo`3oool03P3oool00`000000Ogmo
07moO`0907moO`030000001oOgl0Ogmo01<0Ogmo00<000000?ooo`3oool01`3oool01@000000Ogmo
07moO`1oOgl0000002T0Ogmo00<0000007moO`1oOgl04`1oOgl00`000000oooo0?ooo`3o0?ooogD0
oooo1000000<0?ooo`006@3oool=0000ocl0oooo00<000000?ooo`3oool03P3oool2000000T0Ogmo
4`3o0?l807moO`030000003oool0oooo00h0oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo
07moO`0C07moO`030000003oool0oooo00L0oooo00D0000007moO`1oOgl0Ogmo0000000Y07moO`03
0000001oOgl0Ogmo01<0Ogmo00<000000?ooo`3oool0o`3ooom90?oooc00o`3o303oool001T0oooo
00<000000?ooo`3oool02P3ooolG0000obP0oooo00<000000?ooo`3oool03@3oool00`000000Ogmo
07moO`0907moO`030000001oOgl0Ogmo0100Ogmo203o0?l00`000000o`3o0?l0o`070?l0o`H0oooo
0P00000;07moO`030000001oOgl0Ogmo0180Ogmo0`0000080?ooo`050000001oOgl0Ogmo07moO`00
0000:@1oOgl00`000000Ogmo07moO`0B07moO`030000003oool0oooo0>X0ooooG`3o0?l_0?ooo`03
0000003oool0oooo00X0oooo000I0?ooo`030000003oool0oooo0240oooo5`000?lA0?oooad00000
6P1oOgl2000000P0oooo1P3o0?l00`000000o`3o0?l0o`0O0?l0o`030000003o0?l0o`3o00L0o`3o
00<000000?l0o`3o0?l0403o0?lM000001@0Ogmo00<000000?ooo`3oool0S03ooomN0?l0ohh0oooo
00<000000?ooo`3oool02P3oool001T0oooo00<000000?ooo`3oool0>03ooolG0000o`X0oooo00<0
000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0H07moO`030000003oool0oooo00h0oooo00<0
000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0D07moO`030000003oool0oooo00D0oooo0P00
000307moO`030000001oOgl0Ogmo00/0Ogmo8P3o0?l?07moO`030000003o0?l0oooo02d0ooooG`3o
0?o/0?ooo`030000003oool0oooo00X0oooo000I0?ooo`030000003oool0oooo04T0oooo00<00000
0?ooo`3oool00`3oool:0000o`03000000000?l0003o00D0003o101oOgl00`000000Ogmo07moO`0H
07moO`030000003oool0oooo00h0oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0D
07moO`030000003oool0oooo00H0oooo00D0000007moO`1oOgl0Ogmo0000000Y07moO`030000001o
Ogl0Ogmo00<0Ogmo3`3o0?l00`000000o`3o0?l0o`0]0?l0ool0ooooC03oool00`000000oooo0?oo
o`0:0?ooo`006@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00d0oooo0P000006
07moO`d0003o4@1oOgl00`000000oooo0?ooo`0?0?ooo`030000001oOgl0Ogmo00T0Ogmo00<00000
07moO`1oOgl0501oOgl00`000000oooo0?ooo`060?ooo`050000001oOgl0Ogmo07moO`000000:@1o
Ogl00`000000Ogmo07moO`0B07moO`030000003oool0oooo0?l0ooooBP3oool`0000o``0oooo000I
0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool03@3oool00`000000Ogmo07moO`09
07moO`030000001oOgl0Ogmo00H0Ogmo3@000?l407moO`<000003`3oool00`000000Ogmo07moO`09
07moO`030000001oOgl0Ogmo01@0Ogmo00<000000?ooo`3oool01P3oool01@000000Ogmo07moO`1o
Ogl0000002T0Ogmo00<0000007moO`1oOgl04P1oOgl00`000000oooo0?ooo`3Z0?oooel0003o;`3o
ool00`000000oooo0?ooo`0:0?ooo`006@3oool00`000000oooo0?ooo`190?ooo`030000003oool0
oooo00d0oooo00<0000007moO`1oOgl02@1oOgl00`000000Ogmo07moO`0C07moOch0003o0`3oool2
000000<0Ogmo00<0000007moO`1oOgl09`1oOgl00`000000Ogmo07moO`0B07moO`030000003oool0
oooo08/0ooooG`000?n>0?ooo`030000003oool0oooo00X0oooo000I0?ooo`030000003oool0oooo
04T0oooo00<000000?ooo`3oool03@3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo
01L0Ogmo00<000000?ooo`3oool03`3oool2000000X0Ogmo00<0000007moO`1oOgl04`1oOgl20000
00@0oooo0`000?l00`000000003o0000o`0Q0000o`/0Ogmo00<0000007moO`1oOgl04P1oOgl00`00
0000oooo0?ooo`0/0?oooel0003ok@3oool00`000000oooo0?ooo`0:0?ooo`006@3oool9003o04<0
oooo00<000000?ooo`3oool03@3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo01L0
Ogmo00<000000?ooo`3oool03`3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo01@0
Ogmo00<000000?ooo`3oool01P3oool01@000000Ogmo07moO`1oOgl0000001h0OgmoC`000?oo0?oo
odd0oooo00<000000?ooo`3oool02P3oool001T0oooo00<000000?ooo`3oool01P3oool?003o03@0
oooo00<000000?ooo`3oool03@3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo01L0
Ogmo00<000000?ooo`3oool03`3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo01@0
Ogmo00<000000?ooo`3oool01P3oool01@000000Ogmo07moO`1oOgl0000002T0Ogmo00<0000007mo
O`1oOgl04P1oOgl200000?l0ooooNP3oool00`000000oooo0?ooo`0:0?ooo`006@3oool4000001@0
oooo3`00o`0U0?ooo`030000003oool0oooo00d0oooo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0G07moO`030000003oool0oooo00l0oooo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0D07moO`030000003oool0oooo00H0oooo00D0000007moO`1oOgl0Ogmo0000000Y07mo
O`030000001oOgl0Ogmo0180Ogmo00<000000?ooo`3oool0o`3ooomf0?ooo`@00000303oool001T0
oooo00<000000?ooo`3oool0903oool@003o01D0oooo00<000000?ooo`3oool03@3oool00`000000
Ogmo07moO`0907moO`030000001oOgl0Ogmo01L0Ogmo00<000000?ooo`3oool03`3oool00`000000
Ogmo07moO`0907moO`030000001oOgl0Ogmo01@0Ogmo00<000000?ooo`3oool01P3oool01@000000
Ogmo07moO`1oOgl0000002T0Ogmo00<0000007moO`1oOgl04P1oOgl00`000000oooo0?ooo`3o0?oo
ogT0oooo00<000000?ooo`3oool02P3oool001T0oooo00<000000?ooo`3oool0=03oool?003o00H0
oooo00<000000?ooo`3oool03@3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo01L0
Ogmo00<000000?ooo`3oool03`3oool00`000000Ogmo07moO`0907moO`030000001oOgl0Ogmo01@0
Ogmo00<000000?ooo`3oool01P3oool01@000000Ogmo07moO`1oOgl0000002T0Ogmo00<0000007mo
O`1oOgl04P1oOgl00`000000oooo0?ooo`3o0?ooogT0oooo00<000000?ooo`3oool02P3oool001T0
oooo00<000000?ooo`3oool0@`3oool?003o00L0oooo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0G07moO`030000003oool0oooo00l0oooo00<0000007moO`1oOgl02@1oOgl00`000000
Ogmo07moO`0D07moO`030000003oool0oooo00H0oooo00D0000007moO`1oOgl0Ogmo0000000Y07mo
O`030000001oOgl0Ogmo0180Ogmo00<000000?ooo`3oool0o`3ooomi0?ooo`030000003oool0oooo
00X0oooo000I0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool01P3oool>003o00D0
Ogmo00<0000007moO`1oOgl05`1oOgl00`000000oooo0?ooo`0?0?ooo`030000001oOgl0Ogmo00T0
Ogmo00<0000007moO`1oOgl0501oOgl00`000000oooo0?ooo`060?ooo`050000001oOgl0Ogmo07mo
O`000000:@1oOgl00`000000Ogmo07moO`0B07moO`030000003oool0oooo0?l0ooooN@3oool00`00
0000oooo0?ooo`0:0?ooo`006@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00d0
oooo0P00000507moO`d00?l04P1oOgl00`000000oooo0?ooo`0?0?ooo`030000001oOgl0Ogmo00T0
Ogmo00<0000007moO`1oOgl0501oOgl00`000000oooo0?ooo`060?ooo`050000001oOgl0Ogmo07mo
O`000000:@1oOgl00`000000Ogmo07moO`0B07moO`030000003oool0oooo0?l0ooooN@3oool00`00
0000oooo0?ooo`0:0?ooo`006@3oool90?l004<0oooo00<000000?ooo`3oool03@3oool00`000000
Ogmo07moO`0907moO`030000001oOgl0Ogmo00D0Ogmo3@00o`0407moO`8000004@3oool00`000000
Ogmo07moO`0907moO`030000001oOgl0Ogmo01@0Ogmo00<000000?ooo`3oool01P3oool01@000000
Ogmo07moO`1oOgl0000002T0Ogmo00<0000007moO`1oOgl04@1oOgl00`000000oooo0?ooo`3o0?oo
od/0oooo<000o`0<0?ooo`006@3oool00`000000oooo0?ooo`060?ooo`l0o`00=03oool00`000000
oooo0?ooo`0<0?ooo`030000001oOgl0Ogmo00X0Ogmo00<0000007moO`1oOgl04P1oOgl4003o0003
00000000o`000?l000T00?l01`3oool2000000X0Ogmo00<0000007moO`1oOgl04`1oOgl2000000P0
oooo00D0000007moO`1oOgl0Ogmo0000000Y07moO`030000001oOgl0Ogmo0140Ogmo00<000000?oo
o`3oool0j`3ooomO003o02l0oooo00<000000?ooo`3oool02P3oool001T0oooo00<000000?ooo`3o
ool05@3oool?0?l002D0oooo00<000000?ooo`3oool0303oool00`000000Ogmo07moO`0:07moO`03
0000001oOgl0Ogmo01H0Ogmo00<000000?ooo`3oool02@3oool7003o000300000000o`000?l001l0
0?l000<00000003o0000o`006@00o`0L07moO`030000001oOgl0Ogmo0140Ogmo00<000000?ooo`3o
ool0S03ooomO003o08h0oooo00<000000?ooo`3oool02P3oool001T0oooo00<000000?ooo`3oool0
903oool?0?l001H0oooo00<000000?ooo`3oool0303oool00`000000Ogmo07moO`0:07moO`030000
001oOgl0Ogmo01H0Ogmo00<000000?ooo`3oool04@3oool00`000000Ogmo07moO`0807moO`030000
001oOgl0Ogmo01D0Ogmo00<000000?ooo`3oool01@3oool200000080Ogmo00<0000007moO`1oOgl0
2`1oOglQ003o00l0Ogmo00<000000?ooo`3oool0;@3ooomO003o0>d0oooo00<000000?ooo`3oool0
2P3oool001T0oooo00<000000?ooo`3oool0<`3oool?0?l000L0oooo00<000000?ooo`3oool0303o
ool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo01H0Ogmo00<000000?ooo`3oool04@3o
ool00`000000Ogmo07moO`0807moO`030000001oOgl0Ogmo01D0Ogmo00<000000?ooo`3oool01@3o
ool01@000000Ogmo07moO`1oOgl0000002T0Ogmo00<0000007moO`1oOgl00P1oOgl>003o00030000
0000o`000?l002h00?l0o`3ooom=0?ooo`030000003oool0oooo00X0oooo00090?ooo`<000000P3o
ool2000000T0oooo1`3o0?ln0?ooo`l0o`001`3oool00`000000Ogmo07moO`0:07moO`030000001o
Ogl0Ogmo01H0Ogmo00<000000?ooo`3oool04@3oool00`000000Ogmo07moO`0807moO`030000001o
Ogl0Ogmo01D0Ogmo00<000000?ooo`3oool01@3oool01@000000Ogmo07moO`1oOgl0000002T0Ogmo
00<0000007moO`1oOgl0401oOgl200000?l0ooooO03oool00`000000oooo0?ooo`0:0?ooo`002P3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
103oool;0?l0ocX0oooo00<000000?ooo`3oool01@3oool>0?l000H0Ogmo00<0000007moO`1oOgl0
5@1oOgl00`000000oooo0?ooo`0B0?ooo`030000001oOgl0Ogmo00P0Ogmo00<0000007moO`1oOgl0
5@1oOgl00`000000oooo0?ooo`050?ooo`050000001oOgl0Ogmo07moO`000000:@1oOgl00`000000
Ogmo07moO`0A07moO`030000003oool0oooo0?l0ooooNP3oool00`000000oooo0?ooo`0:0?ooo`00
2P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00H0oooo1@00000=0?ooo`/0
o`3o;`3oool00`000000oooo0?ooo`0<0?ooo`8000001@1oOgl=0?l00140Ogmo00<000000?ooo`3o
ool04P3oool00`000000Ogmo07moO`0807moO`030000001oOgl0Ogmo01D0Ogmo00<000000?ooo`3o
ool01@3oool01@000000Ogmo07moO`1oOgl0000002T0Ogmo00<0000007moO`1oOgl0401oOgl00`00
0000oooo0?ooo`3o0?ooogL0oooo1@00000<0?ooo`002P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool06P3oool<0?l0ob<0oooo00<000000?oo
o`3oool0303oool00`000000Ogmo07moO`0:07moO`030000001oOgl0Ogmo00@0Ogmo3@3o000407mo
O`030000003oool0oooo0180oooo00<0000007moO`1oOgl0201oOgl00`000000Ogmo07moO`0E07mo
O`030000003oool0oooo00D0oooo00D0000007moO`1oOgl0Ogmo0000000Y07moO`030000001oOgl0
Ogmo0100Ogmo00<000000?ooo`3oool0o`3ooomk0?ooo`030000003oool0oooo00X0oooo000:0?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0V
0?ooo`/0o`3o603oool00`000000oooo0?ooo`0<0?ooo`030000001oOgl0Ogmo00X0Ogmo00<00000
07moO`1oOgl04@1oOgl40?l000030000003o0000o`0000T0o`002@3oool00`000000Ogmo07moO`08
07moO`030000001oOgl0Ogmo01D0Ogmo00<000000?ooo`3oool01@3oool01@000000Ogmo07moO`1o
Ogl0000002T0Ogmo00<0000007moO`1oOgl0401oOgl00`000000oooo0?ooo`3o0?oood/0oooo<@3o
000<0?ooo`002@3oool200000080oooo00@000000?ooo`3oool00000203oool00`000000oooo0?oo
o`0a0?ooo``0o`3o303oool00`000000oooo0?ooo`0;0?ooo`030000001oOgl0Ogmo00/0Ogmo00<0
000007moO`1oOgl05@1oOgl2000000X0oooo703o000?07moO`800000203oool010000000Ogmo07mo
O`00000Y07moO`030000001oOgl0Ogmo0100Ogmo00<000000?ooo`3oool0j`3ooomO0?l00300oooo
00<000000?ooo`3oool02P3oool000X0oooo00@000000?ooo`3oool0oooo0P0000090?ooo`030000
003oool0oooo03d0oooo2`3o0?l00`3oool000000?ooo`0<0?ooo`030000001oOgl0Ogmo00/0Ogmo
00<0000007moO`1oOgl05@1oOgl00`000000oooo0?ooo`0B0?ooo`8000002@1oOgl00`000000Ogmo
07moO`0507moO`l0o`0000<000000?l0003o00005`3o000M07moO`030000001oOgl0Ogmo0100Ogmo
00<000000?ooo`3oool0S03ooomO0?l008l0oooo00<000000?ooo`3oool02P3oool001T0oooo00<0
00000?ooo`3oool0B03oool;0?l0o`@0oooo0P00000<07moO`030000001oOgl0Ogmo01@0Ogmo00<0
00000?ooo`3oool04`3oool00`000000Ogmo07moO`0807moO`030000001oOgl0Ogmo01D0Ogmo00<0
00000?ooo`3oool01@3oool200000080Ogmo00<0000007moO`1oOgl02P1oOglQ0?l000l0Ogmo00<0
00000?ooo`3oool0;@3ooomO0?l00>h0oooo00<000000?ooo`3oool02P3oool001T0oooo00<00000
0?ooo`3oool0B@3oool00`000000oooo0?ooo`070?ooo`@0o`3o00<000000?l0o`3o0?l01@3o0?l6
07moO`030000001oOgl0Ogmo01@0Ogmo00<000000?ooo`3oool0503oool00`000000Ogmo07moO`07
07moO`030000001oOgl0Ogmo01H0Ogmo00<000000?ooo`3oool01@3oool010000000Ogmo07moO`00
000Y07moO`040000001oOgl0Ogmo07moO`h0o`0000<000000?l0003o0000;P3o003o0?ooodh0oooo
00<000000?ooo`3oool02P3oool001T0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?oo
o`0;0?ooo`030000001oOgl0Ogmo00D0Ogmo3@3o0?l@07moO`030000003oool0oooo01@0oooo00<0
000007moO`1oOgl01`1oOgl00`000000Ogmo07moO`0F07moO`030000003oool0oooo00D0oooo00@0
000007moO`1oOgl00000:@1oOgl00`000000Ogmo07moO`0?07moO`800000o`3ooomm0?ooo`030000
003oool0oooo00X0oooo000I0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool02`3o
ool00`000000Ogmo07moO`0;07moO`030000001oOgl0Ogmo00@0Ogmo303o0?l407moO`030000003o
ool0oooo01@0oooo00<0000007moO`1oOgl01`1oOgl00`000000Ogmo07moO`0F07moO`030000003o
ool0oooo00D0oooo00@0000007moO`1oOgl00000:@1oOgl00`000000Ogmo07moO`0?07moO`030000
003oool0oooo0?l0ooooO03oool00`000000oooo0?ooo`0:0?ooo`006@3oool00`000000oooo0?oo
o`190?ooo`030000003oool0oooo00/0oooo00<0000007moO`1oOgl02`1oOgl00`000000Ogmo07mo
O`0@07moO`@0o`3o00<000000?l0o`3o0?l02P3o0?l:0?ooo`030000001oOgl0Ogmo00L0Ogmo00<0
000007moO`1oOgl05P1oOgl00`000000oooo0?ooo`050?ooo`040000001oOgl0Ogmo000002T0Ogmo
00<0000007moO`1oOgl03`1oOgl00`000000oooo0?ooo`3o0?oooeH0oooo9`3o0?l<0?ooo`006@3o
ool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00/0oooo00<0000007moO`1oOgl02`1o
Ogl00`000000Ogmo07moO`0D07moO`8000002`3oool90?l0o`030000003o0?l0o`3o0100o`3o401o
Ogl2000000L0oooo00@0000007moO`1oOgl00000:@1oOgl00`000000Ogmo07moO`0?07moO`030000
003oool0oooo0?l0oooo2@3ooom=0?l0obH0oooo00<000000?ooo`3oool02P3oool001T0oooo00<0
00000?ooo`3oool0B@3oool00`000000oooo0?ooo`0;0?ooo`030000001oOgl0Ogmo00/0Ogmo00<0
000007moO`1oOgl04`1oOgl00`000000oooo0?ooo`0D0?ooo`8000002@1oOgl00`000000Ogmo07mo
O`0507moOaP0o`3o00<000000?l0o`3o0?l02P3o0?lQ07moO`030000001oOgl0Ogmo00l0Ogmo00<0
00000?ooo`3oool0_03ooom<0?l0og<0oooo00<000000?ooo`3oool02P3oool001T0oooo00<00000
0?ooo`3oool0B@3oool00`000000oooo0?ooo`0:0?ooo`030000001oOgl0Ogmo00`0Ogmo00<00000
07moO`1oOgl04`1oOgl00`000000oooo0?ooo`0E0?ooo`030000001oOgl0Ogmo00L0Ogmo00<00000
07moO`1oOgl05P1oOgl00`000000oooo0?ooo`040?ooo`8000000P1oOgl00`000000Ogmo07moO`06
07moOaD0o`3o301oOgl00`000000Ogmo07moO`0?07moO`030000003oool0oooo0700ooooC03o0?no
0?ooo`030000003oool0oooo00X0oooo000I0?ooo`@00000B03oool00`000000oooo0?ooo`0:0?oo
o`030000001oOgl0Ogmo00`0Ogmo00<0000007moO`1oOgl04`1oOgl00`000000oooo0?ooo`0E0?oo
o`030000001oOgl0Ogmo00L0Ogmo00<0000007moO`1oOgl05P1oOgl00`000000oooo0?ooo`050?oo
o`040000001oOgl0Ogmo000001d0Ogmo5@3o0?l807moO`030000003o0?l0oooo02@0ooooC@3o0?oo
0?ooo`T0oooo1000000<0?ooo`006@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo
00X0oooo00<0000007moO`1oOgl0301oOgl00`000000Ogmo07moO`0C07moO`030000003oool0oooo
01D0oooo00<0000007moO`1oOgl01`1oOgl00`000000Ogmo07moO`0F07moO`030000003oool0oooo
00D0oooo00@0000007moO`1oOgl00000:@1oOgl00`000000Ogmo07moO`0607moO`P0o`3o00<00000
0?l0o`3o0?l0903o0?oo0?oooeT0oooo00<000000?ooo`3oool02P3oool001T0oooo00<000000?oo
o`3oool0B@3oool00`000000oooo0?ooo`0:0?ooo`030000001oOgl0Ogmo00`0Ogmo00<0000007mo
O`1oOgl04`1oOgl00`000000oooo0?ooo`0E0?ooo`030000001oOgl0Ogmo00L0Ogmo00<0000007mo
O`1oOgl05P1oOgl00`000000oooo0?ooo`050?ooo`040000001oOgl0Ogmo000002T0Ogmo00<00000
07moO`1oOgl03P1oOgl00`000000oooo0?ooo`3o0?ooogd0oooo00<000000?ooo`3oool02P3oool0
01T0oooo00<000000?ooo`3oool0B@3ooolM000001D0Ogmo00<000000?ooo`3oool05@3oool00`00
0000Ogmo07moO`0707moOb8000000P1oOgl[00000100Ogmo00<000000?ooo`3oool0o`3ooomm0?oo
o`030000003oool0oooo00X0oooo000I0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3o
ool02P3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo0180Ogmo00<000000?ooo`3o
ool05`3oool00`000000Ogmo07moO`0607moO`030000001oOgl0Ogmo01L0Ogmo00<000000?ooo`3o
ool0103oool010000000Ogmo07moO`00000Y07moO`030000001oOgl0Ogmo00h0Ogmo00<000000?oo
o`3oool0o`3ooomm0?ooo`030000003oool0oooo00X0oooo000I0?ooo`030000003oool0oooo04T0
oooo00<000000?ooo`3oool02P3oool00`000000Ogmo07moO`0<07moO`030000001oOgl0Ogmo0180
Ogmo00<000000?ooo`3oool05`3oool00`000000Ogmo07moO`0607moO`030000001oOgl0Ogmo01L0
Ogmo00<000000?ooo`3oool0103oool010000000Ogmo07moO`00000Y07moO`030000001oOgl0Ogmo
00h0Ogmo00<000000?ooo`3oool0o`3ooomm0?ooo`030000003oool0oooo00X0oooo000I0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool02P3oool00`000000Ogmo07moO`0<07moO`03
0000001oOgl0Ogmo0180Ogmo00<000000?ooo`3oool05`3oool00`000000Ogmo07moO`0607moO`03
0000001oOgl0Ogmo01L0Ogmo00<000000?ooo`3oool0103oool010000000Ogmo07moO`00000Y07mo
O`030000001oOgl0Ogmo00h0Ogmo00<000000?ooo`3oool0o`3ooomm0?ooo`030000003oool0oooo
00X0oooo000I0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool02P3oool00`000000
Ogmo07moO`0<07moO`030000001oOgl0Ogmo0180Ogmo00<000000?ooo`3oool05`3oool00`000000
Ogmo07moO`0607moO`030000001oOgl0Ogmo01L0Ogmo00<000000?ooo`3oool0103oool010000000
Ogmo07moO`00000Y07moO`030000001oOgl0Ogmo00d0Ogmo00<000000?ooo`3oool0o`3ooomn0?oo
o`030000003oool0oooo00X0oooo000I0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3o
ool02@3oool00`000000Ogmo07moO`0=07moO`030000001oOgl0Ogmo0180Ogmo00<000000?ooo`3o
ool05`3oool00`000000Ogmo07moO`0607moO`030000001oOgl0Ogmo01L0Ogmo00<000000?ooo`3o
ool0103oool010000000Ogmo07moO`00000Y07moO`030000001oOgl0Ogmo00d0Ogmo00<000000?oo
o`3oool0o`3ooomn0?ooo`030000003oool0oooo00X0oooo000I0?ooo`030000003oool0oooo04T0
oooo00<000000?ooo`3oool02@3oool00`000000Ogmo07moO`0=07moO`030000001oOgl0Ogmo0180
Ogmo00<000000?ooo`3oool05`3oool00`000000Ogmo07moO`0607moO`030000001oOgl0Ogmo01L0
Ogmo00<000000?ooo`3oool0103oool010000000Ogmo07moO`00000Y07moO`030000001oOgl0Ogmo
00d0Ogmo00<000000?ooo`3oool0o`3ooomn0?ooo`030000003oool0oooo00X0oooo000I0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool02@3oool00`000000Ogmo07moO`0=07moO`03
0000001oOgl0Ogmo0140Ogmo00<000000?ooo`3oool0603oool00`000000Ogmo07moO`0607moO`03
0000001oOgl0Ogmo01L0Ogmo00<000000?ooo`3oool0103oool010000000Ogmo07moO`00000Y07mo
O`030000001oOgl0Ogmo00d0Ogmo00<000000?ooo`3oool0o`3ooomn0?ooo`030000003oool0oooo
00X0oooo000I0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool02@3oool00`000000
Ogmo07moO`0=07moO`030000001oOgl0Ogmo0140Ogmo00<000000?ooo`3oool0603oool00`000000
Ogmo07moO`0607moO`030000001oOgl0Ogmo01L0Ogmo00<000000?ooo`3oool0103oool010000000
Ogmo07moO`00000Y07moO`030000001oOgl0Ogmo00d0Ogmo00<000000?ooo`3oool0o`3ooomn0?oo
o`030000003oool0oooo00X0oooo000I0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3o
ool02@3oool00`000000Ogmo07moO`0=07moO`030000001oOgl0Ogmo0140Ogmo00<000000?ooo`3o
ool0603oool00`000000Ogmo07moO`0607moO`030000001oOgl0Ogmo01L0Ogmo00<000000?ooo`3o
ool0103oool010000000Ogmo07moO`00000Y07moO`030000001oOgl0Ogmo00d0Ogmo00<000000?oo
o`3oool0o`3ooomn0?ooo`030000003oool0oooo00X0oooo000I0?ooo`@00000B03oool00`000000
oooo0?ooo`090?ooo`030000001oOgl0Ogmo00d0Ogmo00<0000007moO`1oOgl04@1oOgl00`000000
oooo0?ooo`0H0?ooo`030000001oOgl0Ogmo00H0Ogmo00<0000007moO`1oOgl05`1oOgl00`000000
oooo0?ooo`040?ooo`040000001oOgl0Ogmo000002T0Ogmo00<0000007moO`1oOgl03@1oOgl00`00
0000oooo0?ooo`3o0?ooog/0oooo1000000<0?ooo`006@3oool50000odL0oooo00<000000?ooo`3o
ool02@3oool00`000000Ogmo07moO`0=07moO`030000001oOgl0Ogmo0140Ogmo00<000000?ooo`3o
ool0603oool00`000000Ogmo07moO`0607moO`030000001oOgl0Ogmo01L0Ogmo00<000000?ooo`3o
ool0103oool010000000Ogmo07moO`00000Y07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?oo
o`3oool0o`3ooomo0?ooo`030000003oool0oooo00X0oooo000I0?ooo`030000003oool0oooo0080
oooo20000?lo0?ooo`030000003oool0oooo00T0oooo00<0000007moO`1oOgl03@1oOgl00`000000
Ogmo07moO`0A07moO`030000003oool0oooo01T0oooo00<0000007moO`1oOgl01@1oOgl00`000000
Ogmo07moO`0H07moO`030000003oool0oooo00<0oooo00@0000007moO`1oOgl00000:@1oOgl00`00
0000Ogmo07moO`0<07moO`030000003oool0oooo0?l0ooooO`3oool00`000000oooo0?ooo`0:0?oo
o`006@3oool5003o00P0oooo20000?lg0?ooo`030000003oool0oooo00T0oooo00<0000007moO`1o
Ogl03@1oOgl00`000000Ogmo07moO`0@07moO`030000003oool0oooo01X0oooo00<0000007moO`1o
Ogl01@1oOgl00`000000Ogmo07moO`0H07moO`030000003oool0oooo00<0oooo00@0000007moO`1o
Ogl00000:@1oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo0?l0ooooO`3oool00`00
0000oooo0?ooo`0:0?ooo`006@3oool00`000000oooo0?ooo`020?ooo`P00?l0203oool80000obl0
oooo00<000000?ooo`3oool0203oool00`000000Ogmo07moO`0>07moO`030000001oOgl0Ogmo0100
Ogmo00<000000?ooo`3oool06P3oool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo01P0
Ogmo00<000000?ooo`3oool0103oool00`000000Ogmo0000000Y07moO`030000001oOgl0Ogmo00`0
Ogmo00<000000?ooo`3oool0o`3ooomo0?ooo`030000003oool0oooo00X0oooo000I0?ooo`D0o`00
203oool8003o00P0oooo20000?lW0?ooo`030000003oool0oooo00P0oooo00<0000007moO`1oOgl0
3P1oOgl00`000000Ogmo07moO`0@07moO`030000003oool0oooo01X0oooo00<0000007moO`1oOgl0
1@1oOgl00`000000Ogmo07moO`0H07moO`030000003oool0oooo00@0oooo00<0000007moO`000000
:@1oOgl00`000000Ogmo07moO`0<07moO`030000003oool0oooo0?l0ooooO`3oool00`000000oooo
0?ooo`0:0?ooo`006@3oool50?l0o`P0o`00203oool8003o00P0oooo20000?lO0?ooo`030000003o
ool0oooo00P0oooo00<0000007moO`1oOgl03P1oOgl00`000000Ogmo07moO`0@07moO`030000003o
ool0oooo01X0oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0H07moO`030000003o
ool0oooo00@0oooo00<0000007moO`000000:@1oOgl00`000000Ogmo07moO`0<07moO`030000003o
ool0oooo0?l0ooooO`3oool00`000000oooo0?ooo`0:0?ooo`006@3oool00`000000oooo0?ooo`02
0?ooo`L0o`3o00<0oooo0?l0003o00001P3o00080?ooo`P00?l0203oool70000oaP0oooo00<00000
0?ooo`3oool0203oool00`000000Ogmo07moO`0>07moO`030000001oOgl0Ogmo0100Ogmo00<00000
0?ooo`3oool06P3oool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo01P0Ogmo00<00000
0?ooo`3oool0103oool00`000000Ogmo0000000Y07moO`030000001oOgl0Ogmo00`0Ogmo00<00000
0?ooo`3oool0o`3ooomo0?ooo`030000003oool0oooo00X0oooo000I0?ooo`030000003oool0oooo
00T0oooo1`3o0?l20?ooo`L0o`002@3oool8003o00L0oooo20000?l@0?ooo`030000003oool0oooo
00P0oooo00<0000007moO`1oOgl03P1oOgl00`000000Ogmo07moO`0@07moO`030000003oool0oooo
01X0oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0H07moO`030000003oool0oooo
00@0oooo00<0000007moO`000000:@1oOgl00`000000Ogmo07moO`0;07moO`030000003oool0oooo
0?l0ooooP03oool00`000000oooo0?ooo`0:0?ooo`006@3oool00`000000oooo0?ooo`0@0?ooo`L0
o`3o0P3oool80?l000T0oooo1`00o`080?ooo`P0003o203oool00`000000oooo0?ooo`080?ooo`03
0000001oOgl0Ogmo00h0Ogmo00<0000007moO`1oOgl03`1oOgl00`000000oooo0?ooo`0K0?ooo`03
0000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0601oOgl00`000000oooo0?ooo`040?ooo`03
0000001oOgl0000002T0Ogmo00<0000007moO`1oOgl02`1oOgl00`000000oooo0?ooo`3o0?oooh00
oooo00<000000?ooo`3oool02P3oool001T0oooo00<000000?ooo`3oool05`3oool70?l0o`<0oooo
203o00080?ooo`P00?l0203oool80000o`030000003oool0oooo00P0oooo00<0000007moO`1oOgl0
3P1oOgl00`000000Ogmo07moO`0?07moO`030000003oool0oooo01/0oooo00<0000007moO`1oOgl0
1@1oOgl00`000000Ogmo07moO`0H07moO`030000003oool0oooo00@0oooo00<0000007moO`000000
:@1oOgl00`000000Ogmo07moO`0;07moO`030000003oool0oooo0?l0ooooP03oool00`000000oooo
0?ooo`0:0?ooo`006@3oool00`000000oooo0?ooo`0N0?ooo`L0o`3o103oool80?l000P0oooo2000
o`080?ooo`P0003o0`3oool00`000000Ogmo07moO`0>07moO`030000001oOgl0Ogmo00l0Ogmo00<0
00000?ooo`3oool06`3oool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo01P0Ogmo00<0
00000?ooo`3oool0103oool00`000000Ogmo0000000Y07moO`030000001oOgl0Ogmo00/0Ogmo00<0
00000?ooo`3oool0o`3ooon00?ooo`030000003oool0oooo00X0oooo000I0?ooo`@00000903oool8
0?l0o`@0oooo203o00080?ooo`P00?l000<000000?ooo`3oool01@3oool20000o`03000000000?l0
003o0080003o3@1oOgl00`000000Ogmo07moO`0?07moO`030000003oool0oooo01/0oooo00<00000
07moO`1oOgl01@1oOgl00`000000Ogmo07moO`0H07moO`030000003oool0oooo00@0oooo00<00000
07moO`000000:@1oOgl00`000000Ogmo07moO`0;07moO`030000003oool0oooo0?l0ooooO@3oool4
000000`0oooo000I0?ooo`030000003oool0oooo02d0oooo1`3o0?l50?ooo`L0o`002@3oool8003o
0080oooo0P00000307moO`L0003o1P1oOgl00`000000Ogmo07moO`0?07moO`030000003oool0oooo
01`0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0I07moO`030000003oool0oooo
00<0oooo00<0000007moO`000000:@1oOgl00`000000Ogmo07moO`0;07moO`030000003oool0oooo
0?l0ooooP03oool00`000000oooo0?ooo`0:0?ooo`006@3oool00`000000oooo0?ooo`0d0?ooo`L0
o`3o1@3oool80?l000030?ooo`000000oooo00H0oooo0P00o`000`0000000?l0003o0003003o00H0
Ogmo1`000?lA07moO`030000003oool0oooo01`0oooo00<0000007moO`1oOgl0101oOgl00`000000
Ogmo07moO`0I07moO`030000003oool0oooo00<0oooo00<0000007moO`000000:@1oOgl00`000000
Ogmo07moO`0;07moO`030000003oool0oooo0?l0ooooP03oool00`000000oooo0?ooo`0:0?ooo`00
6@3oool00`000000oooo0?ooo`0k0?ooo`L0o`3o1P3oool80?l000<0oooo0P00000407moO`P00?l0
101oOgl00`000000003o0000o`050000o`T0Ogmo00<000000?ooo`3oool07@3oool00`000000Ogmo
07moO`0407moO`030000001oOgl0Ogmo01T0Ogmo00<000000?ooo`3oool00`3oool00`000000Ogmo
0000000Y07moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0o`3ooon10?ooo`030000
003oool0oooo00X0oooo000I0?ooo`030000003oool0oooo0480oooo1`3o0?l00`000000oooo0?oo
o`040?ooo`P0o`002@1oOgl9003o00<0Ogmo1`000?l00`1oOgl000000000000O0?ooo`030000001o
Ogl0Ogmo00@0Ogmo00<0000007moO`1oOgl06@1oOgl00`000000oooo0?ooo`030?ooo`030000001o
Ogl0000002T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`3o0?ooofD0oooo7@00
0?l<0?ooo`006@3oool00`000000oooo0?ooo`190?ooo`L0o`3o0`3oool2000000<0Ogmo2@3o0004
07moO`030000001oOgl0Ogmo0080Ogmo2000o`0207moO`030000o`000000003o00P0003o5`3oool0
0`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo01T0Ogmo00<000000?ooo`3oool00`3oool0
0`000000Ogmo0000000Y07moO`030000001oOgl0Ogmo00X0Ogmo00<000000?ooo`3oool0o`3oool^
0?ooocL0003o703oool00`000000oooo0?ooo`0:0?ooo`006@3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo00@0oooo203o0?l907moO`P0o`002@1oOgl:003o00<0oooo40000?l70?oo
o`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl06@1oOgl00`000000oooo0?ooo`030?oo
o`030000001oOgl0000002T0Ogmo00<0000007moO`1oOgl02P1oOgl00`000000oooo0?ooo`3e0?oo
ocP0003o=`3ooolM003o00`0oooo000I0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3o
ool01`3oool00`000000Ogmo07moO`0207moO`P0o`3o1@1oOgl010000000Ogmo07moO`1oOgl90?l0
00<0Ogmo0P0000050?ooo`/00?l0203oool60000o`03000000000?l0003o0140003o401oOgl20000
00@0oooo00<0000007moO`000000:@1oOgl00`000000Ogmo07moO`0:07moO`030000003oool0oooo
0;h0oooo=`000?lh0?ooocL00?l0703oool00`000000oooo0?ooo`0:0?ooo`006@3oool00`000000
oooo0?ooo`190?ooo`030000003oool0oooo00L0oooo00<0000007moO`1oOgl02P1oOgl90?l0o`T0
Ogmo0P3o00000`000000o`000?l000050?l000/0oooo2`00o`030?ooo`8000001P1oOgl00`000000
Ogmo07moO`0907moOa00003o00<000000000o`000?l00P000?l00`000000003o0000o`080000ob80
Ogmo00<0000007moO`1oOgl02@1oOgl00`000000oooo0?ooo`280?ooocL0003o=`3ooolh003o05<0
oooo00<000000?ooo`3oool02P3oool001T0oooo00<000000?ooo`3oool0B@3oool00`000000oooo
0?ooo`060?ooo`030000001oOgl0Ogmo0100Ogmo00@0000007moO`1oOgl0Ogmo203o0?l307moO`80
00001P3oool;0?l000/0oooo5`00o`0A07moO`8000000P3oool20000000307moO`000000Ogmo00H0
Ogmo4`000?l?07moO`030000001oOgl0Ogmo00T0Ogmo00<000000?ooo`3oool0D03ooolh0000ocH0
oooo>000o`1[0?ooob40o`00303oool001T0oooo00<000000?ooo`3oool0B@3oool00`000000oooo
0?ooo`060?ooo`030000001oOgl0Ogmo0100Ogmo00<0000007moO`1oOgl02@1oOgl:0?l0o``0oooo
2`3o00040?ooo`8000001@1oOgl00`000000Ogmo07moO`0907moOaD00?l000<00000003o0000o`00
2000o`0C07moOa<0003o201oOgl00`000000oooo0?ooo`0I0?ooocL0003o=`3ooolg003o0680oooo
@@3o000P0?ooo`030000003oool0oooo00X0oooo000I0?ooo`030000003oool0oooo04T0oooo7@00
000>07moO`8000001@3oool<0?l0o`/0oooo603o000F0000000307moO`000000000000H000004`00
o`0@000000<0Ogmo1`000?l00`000000003o0000o`0J0000ocH0oooo>000o`1H0?oood40o`00A@3o
oolM0?l0o``0oooo000I0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool01P3oool0
0`000000Ogmo07moO`0@07moO`030000001oOgl0Ogmo00`0Ogmo00<000000?ooo`3oool0403oool;
0?l0o`@0oooo0P00000507moO`030000001oOgl0Ogmo00X0Ogmo403o00001@000000o`000?l0003o
0000000000X0o`004`1oOglB003o00P0Ogmo0P00000J0?ooocL00?l0C`3ooom10?l004h0oooo>03o
0?lL0?ooo`030000003oool0oooo00X0oooo000I0?ooo`@00000B03oool00`000000oooo0?ooo`06
0?ooo`030000001oOgl0Ogmo0100Ogmo00<0000007moO`1oOgl0301oOgl00`000000oooo0?ooo`0K
0?ooo`@0o`3o00<000000?l0o`3o0?l04@3o0?l@07moO`8000000P3oool20000000307moO`000000
Ogmo00H0Ogmo4`3o000?07moO`030000001oOgl0Ogmo02@00?l0A@3ooom10?l005P0oooo=`3o0?mA
0?ooo`@00000303oool001T0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`050?oo
o`030000001oOgl0Ogmo0140Ogmo00<0000007moO`1oOgl02`1oOgl00`000000oooo0?ooo`0P0?oo
o`8000001@1oOgl00`000000Ogmo07moO`0:07moOa00o`3o00<000000?l0o`3o0?l02P3o0?lE07mo
Oa80o`00201oOgl2000001h0oooo@@3o001Q0?ooocP0o`3oR`3oool00`000000oooo0?ooo`0:0?oo
o`006@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00D0oooo00<0000007moO`1o
Ogl04@1oOgl00`000000Ogmo07moO`0;07moO`030000003oool0oooo0240oooo00<0000007moO`1o
Ogl00`1oOgl00`000000Ogmo07moO`0K07moO`040000003oool0oooo0?ooo`<000001@1oOgl=0?l0
oaL0Ogmo00<0000007moO`1oOgl01`3o00000`000000o`000?l0000N0?l006X0oooo>03o0?o30?oo
o`030000003oool0oooo00X0oooo000I0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3o
ool01@3oool00`000000Ogmo07moO`0A07moO`030000001oOgl0Ogmo00/0Ogmo00<000000?ooo`3o
ool08@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo01/0Ogmo00L000000?ooo`3o
ool0oooo0000001oOgl000000180Ogmo3P3o0?l907moO`030000001oOgl0Ogmo00L0Ogmo0P00001B
0?ooocL0o`3on`3oool00`000000oooo0?ooo`0:0?ooo`006@3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo00D0oooo00<0000007moO`1oOgl04@1oOgl00`000000Ogmo07moO`0:07mo
O`030000003oool0oooo02<0oooo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0K07mo
O`070000003oool0oooo0?ooo`000000Ogmo0000000P07moO`d0o`3o1P1oOgl00`000000o`3o0?oo
o`0I0?ooocP0o`3oo`3ooolc0?ooo`030000003oool0oooo00X0oooo000I0?ooo`030000003oool0
oooo04T0oooo00<000000?ooo`3oool01@3oool00`000000Ogmo07moO`0A07moO`030000001oOgl0
Ogmo00X0Ogmo00<000000?ooo`3oool08`3oool00`000000Ogmo07moO`0207moO`030000001oOgl0
Ogmo01/0Ogmo00L000000?ooo`3oool0oooo0000001oOgl0000002T0Ogmo00@0000007moO`1oOgl0
Ogmo8P3o0?oo0?ooof/0oooo00<000000?ooo`3oool02P3oool001T0oooo00<000000?ooo`3oool0
B@3oool00`000000oooo0?ooo`040?ooo`030000001oOgl0Ogmo0180Ogmo00<0000007moO`1oOgl0
2P1oOgl00`000000oooo0?ooo`0S0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl0
701oOgl010000000oooo0?ooo`3oool2000002T0Ogmo00<0000007moO`1oOgl01`1oOgl00`000000
oooo0?ooo`3o0?oooh@0oooo00<000000?ooo`3oool02P3oool001T0oooo00<000000?ooo`3oool0
B@3oool00`000000oooo0?ooo`040?ooo`030000001oOgl0Ogmo0180Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000oooo0?ooo`0T0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl0
701oOgl010000000oooo0?ooo`3oool2000002T0Ogmo00<0000007moO`1oOgl01P1oOgl00`000000
oooo0?ooo`3o0?ooohD0oooo00<000000?ooo`3oool02P3oool001T0oooo00<000000?ooo`3oool0
B@3oool00`000000oooo0?ooo`040?ooo`030000001oOgl0Ogmo0180Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000oooo0?ooo`0T0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl0
701oOgl010000000oooo0?ooo`3oool2000002T0Ogmo00<0000007moO`1oOgl01P1oOgl00`000000
oooo0?ooo`3o0?ooohD0oooo00<000000?ooo`3oool02P3oool001T0oooo00<000000?ooo`3oool0
B@3oool00`000000oooo0?ooo`040?ooo`030000001oOgl0Ogmo0180Ogmo00<0000007moO`1oOgl0
2@1oOgl00`000000oooo0?ooo`0T0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl0
701oOgl010000000oooo0?ooo`3oool2000002T0Ogmo00<0000007moO`1oOgl01P1oOgl00`000000
oooo0?ooo`3o0?ooohD0oooo00<000000?ooo`3oool02P3oool000P0oooo100000020?ooo`800000
2@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00@0oooo00<0000007moO`1oOgl0
4P1oOgl00`000000Ogmo07moO`0807moO`030000003oool0oooo02D0oooo00<0000007moO`1oOgl0
0P1oOgl00`000000Ogmo07moO`0L07moO`040000003oool0oooo0?ooo`800000:@1oOgl00`000000
Ogmo07moO`0607moO`030000003oool0oooo0?l0ooooQ@3oool00`000000oooo0?ooo`0:0?ooo`00
203oool01P000000oooo0?ooo`000000oooo00000080oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`190?ooo`030000003oool0oooo00@0oooo00<0000007moO`1oOgl04P1oOgl00`00
0000Ogmo07moO`0807moO`030000003oool0oooo02D0oooo00<0000007moO`1oOgl00P1oOgl00`00
0000Ogmo07moO`0L07moO`040000003oool0oooo0?ooo`800000:@1oOgl00`000000Ogmo07moO`05
07moO`030000003oool0oooo0?l0ooooQP3oool00`000000oooo0?ooo`0:0?ooo`002@3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`19
0?ooo`030000003oool0oooo00<0oooo00<0000007moO`1oOgl04`1oOgl00`000000Ogmo07moO`08
07moO`030000003oool0oooo02H0oooo00D0000007moO`1oOgl0Ogmo0000000O07moO`030000003o
ool0oooo00800000:@1oOgl00`000000Ogmo07moO`0507moO`030000003oool0oooo0?l0ooooQP3o
ool00`000000oooo0?ooo`0:0?ooo`002P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo00H0oooo1@0000170?ooo`030000003oool0oooo00<0oooo00<0000007moO`1oOgl04`1o
Ogl00`000000Ogmo07moO`0707moO`030000003oool0oooo02L0oooo00D0000007moO`1oOgl0Ogmo
0000000O07moO`030000003oool0oooo00800000:@1oOgl00`000000Ogmo07moO`0507moO`030000
003oool0oooo0?l0ooooPP3oool5000000`0oooo000;0?ooo`030000003oool000000080oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00<0oooo00<0
000007moO`1oOgl04`1oOgl00`000000Ogmo07moO`0707moO`030000003oool0oooo02L0oooo00D0
000007moO`1oOgl0Ogmo0000000O07moO`030000003oool0oooo00800000:@1oOgl00`000000Ogmo
07moO`0507moO`030000003oool0oooo0?l0ooooQP3oool00`000000oooo0?ooo`0:0?ooo`00203o
ool01P000000oooo0?ooo`000000oooo00000080oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`190?ooo`030000003oool0oooo00<0oooo00<0000007moO`1oOgl04`1oOgl00`000000
Ogmo07moO`0707moO`030000003oool0oooo02L0oooo00D0000007moO`1oOgl0Ogmo0000000O07mo
O`030000003oool0oooo00800000:@1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo
0?l0ooooQ`3oool00`000000oooo0?ooo`0:0?ooo`002@3oool2000000<0oooo0P0000090?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool00`3oool00`000000Ogmo07moO`0C07moO`03
0000001oOgl0Ogmo00H0Ogmo00<000000?ooo`3oool0:03oool01@000000Ogmo07moO`1oOgl00000
01l0Ogmo00<000000?ooo`3oool00P00000Y07moO`030000001oOgl0Ogmo00@0Ogmo00<000000?oo
o`3oool0o`3ooon70?ooo`030000003oool0oooo00X0oooo000I0?ooo`030000003oool0oooo04T0
oooo00<000000?ooo`3oool00P3oool00`000000Ogmo07moO`0D07moO`030000001oOgl0Ogmo00H0
Ogmo00<000000?ooo`3oool0:03oool01@000000Ogmo07moO`1oOgl000000200Ogmo00@000000?oo
o`0000000000:@1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo0?l0ooooQ`3oool0
0`000000oooo0?ooo`0:0?ooo`006@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo
0080oooo00<0000007moO`1oOgl0501oOgl00`000000Ogmo07moO`0607moO`030000003oool0oooo
02P0oooo00D0000007moO`1oOgl0Ogmo0000000P07moO`040000003oool00000000002T0Ogmo00<0
000007moO`1oOgl0101oOgl00`000000oooo0?ooo`3o0?ooohL0oooo00<000000?ooo`3oool02P3o
ool001T0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`020?ooo`030000001oOgl0
Ogmo01@0Ogmo00<0000007moO`1oOgl01@1oOgl00`000000oooo0?ooo`0Z0?ooo`040000001oOgl0
Ogmo00000200Ogmo00@000000?ooo`0000000000:@1oOgl00`000000Ogmo07moO`0307moO`030000
003oool0oooo0?l0ooooR03oool00`000000oooo0?ooo`0:0?ooo`006@3oool00`000000oooo0?oo
o`190?ooo`030000003oool0oooo0080oooo00<0000007moO`1oOgl0501oOgl00`000000Ogmo07mo
O`0507moO`030000003oool0oooo02X0oooo00@0000007moO`1oOgl00000801oOgl010000000oooo
00000000000Y07moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0o`3ooon80?ooo`03
0000003oool0oooo00X0oooo000I0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0
0P3oool00`000000Ogmo07moO`0D07moO`030000001oOgl0Ogmo00D0Ogmo00<000000?ooo`3oool0
:P3oool010000000Ogmo07moO`00000P07moO`040000003oool00000000002T0Ogmo00<0000007mo
O`1oOgl00`1oOgl00`000000oooo0?ooo`3o0?ooohP0oooo00<000000?ooo`3oool02P3oool001T0
oooo00<000000?ooo`3oool0B@3oool01@000000oooo0?ooo`3oool0000001L0Ogmo00<0000007mo
O`1oOgl01@1oOgl00`000000oooo0?ooo`0Z0?ooo`040000001oOgl0Ogmo00000240Ogmo0`00000Y
07moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0o`3ooon80?ooo`030000003oool0
oooo00X0oooo000I0?ooo`030000003oool0oooo04T0oooo7@00000607moO`030000003oool0oooo
02/0oooo00<0000007moO`1oOgl0C`00000507moO`030000003oool0oooo0?l0ooooR03oool00`00
0000oooo0?ooo`0:0?ooo`006@3oool00`000000oooo0?ooo`190?ooo`050000003oool0oooo0?oo
o`0000005`1oOgl00`000000Ogmo07moO`0407moO`030000003oool0oooo02/0oooo00@0000007mo
O`1oOgl000008@1oOgl3000002T0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`3o
0?ooohT0oooo00<000000?ooo`3oool02P3oool001T0oooo00<000000?ooo`3oool0B@3oool01@00
0000oooo0?ooo`3oool0000001L0Ogmo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`0[
0?ooo`040000001oOgl0Ogmo00000240Ogmo0`00000Y07moO`030000001oOgl0Ogmo0080Ogmo00<0
00000?ooo`3oool0o`3ooon90?ooo`030000003oool0oooo00X0oooo000I0?ooo`@00000B03oool0
1@000000oooo0?ooo`3oool0000001L0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo0?oo
o`0/0?ooo`040000001oOgl0Ogmo00000240Ogmo0`00000Y07moO`030000001oOgl0Ogmo0080Ogmo
00<000000?ooo`3oool0o`3ooon60?ooo`@00000303oool001T0oooo00<000000?ooo`3oool0B@3o
ool010000000oooo0?ooo`00000H07moO`030000001oOgl0Ogmo00<0Ogmo00<000000?ooo`3oool0
;@3oool00`000000Ogmo0000000R07moO`800000:@1oOgl00`000000Ogmo07moO`0207moO`030000
003oool0oooo0?l0ooooR@3oool00`000000oooo0?ooo`0:0?ooo`006@3oool00`000000oooo0?oo
o`190?ooo`040000003oool0oooo000001P0Ogmo00<0000007moO`1oOgl00`1oOgl00`000000oooo
0?ooo`0]0?ooo`030000001oOgl000000280Ogmo0P00000Y07moO`050000001oOgl0Ogmo07moO`00
0000o`3ooon<0?ooo`030000003oool0oooo00X0oooo000I0?ooo`030000003oool0oooo04T0oooo
00@000000?ooo`3oool00000601oOgl00`000000Ogmo07moO`0207moO`030000003oool0oooo02h0
oooo00<0000007moO`0000008P1oOgl2000002T0Ogmo00D0000007moO`1oOgl0Ogmo0000003o0?oo
oh`0oooo00<000000?ooo`3oool02P3oool001T0oooo00<000000?ooo`3oool0B@3oool010000000
oooo0?ooo`00000H07moO`030000001oOgl0Ogmo0080Ogmo00<000000?ooo`3oool0;P3oool00`00
0000Ogmo0000000R07moO`800000:@1oOgl01@000000Ogmo07moO`1oOgl000000?l0ooooS03oool0
0`000000oooo0?ooo`0:0?ooo`006@3oool00`000000oooo0?ooo`190?ooo`040000003oool0oooo
000001P0Ogmo00<0000007moO`1oOgl00P1oOgl00`000000oooo0?ooo`0^0?ooo`030000001oOgl0
00000280Ogmo0P00000Y07moO`050000001oOgl0Ogmo07moO`000000o`3ooon<0?ooo`030000003o
ool0oooo00X0oooo000I0?ooo`030000003oool0oooo04T0oooo00@000000?ooo`3oool00000601o
Ogl01@000000Ogmo07moO`1oOgl000000340oooo00<0000007moO`0000008P1oOgl2000002T0Ogmo
00@0000007moO`1oOgl00000o`3ooon=0?ooo`030000003oool0oooo00X0oooo000I0?ooo`030000
003oool0oooo04T0oooo00<000000?ooo`0000006@1oOgl01@000000Ogmo07moO`1oOgl000000340
oooo00<0000007moO`0000008`1oOgl00`000000Ogmo07moO`0W07moO`040000001oOgl0Ogmo0000
0?l0ooooS@3oool00`000000oooo0?ooo`0:0?ooo`006@3oool00`000000oooo0?ooo`190?ooo`03
0000003oool0000001T0Ogmo00D0000007moO`1oOgl0Ogmo0000000a0?ooo`030000001oOgl00000
02<0Ogmo00<0000007moO`1oOgl09`1oOgl010000000Ogmo07moO`00003o0?ooohd0oooo00<00000
0?ooo`3oool02P3oool001T0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0000000I07mo
O`040000001oOgl0Ogmo000003<0oooo0P00000S07moO`030000001oOgl0Ogmo02L0Ogmo00@00000
07moO`1oOgl00000o`3ooon=0?ooo`030000003oool0oooo00X0oooo000I0?ooo`030000003oool0
oooo04T0oooo00<000000?ooo`0000006@1oOgl010000000Ogmo07moO`00000c0?ooo`8000008`1o
Ogl00`000000Ogmo07moO`0W07moO`030000001oOgl000000?l0ooooSP3oool00`000000oooo0?oo
o`0:0?ooo`006@3oool00`000000oooo0?ooo`190?ooo`030000003oool0000001T0Ogmo00@00000
07moO`1oOgl00000<`3oool2000002<0Ogmo00<0000007moO`1oOgl09`1oOgl00`000000Ogmo0000
003o0?ooohh0oooo00<000000?ooo`3oool02P3oool001T0oooo100000180?ooo`8000006P1oOgl0
0`000000Ogmo0000000d0?ooo`8000008`1oOgl00`000000Ogmo07moO`0W07moO`030000001oOgl0
00000?l0ooooR`3oool4000000`0oooo000I0?ooo`030000003oool0oooo04T0oooo7@0000000`1o
Ogl000000?ooo`0c0?oooe00000000<0Ogmo0000003oool0o`3ooon=0?ooo`030000003oool0oooo
00X0oooo000I0?ooo`030000003oool0oooo04T0oooo0P00000J07moO`030000001oOgl0000003@0
oooo0P00000S07moO`030000001oOgl0Ogmo02L0Ogmo0P00003o0?ooohl0oooo00<000000?ooo`3o
ool02P3oool001T0oooo00<000000?ooo`3oool0B@3oool2000001X0Ogmo0P00000e0?ooo`800000
8`1oOgl00`000000Ogmo07moO`0W07moO`800000o`3ooon?0?ooo`030000003oool0oooo00X0oooo
000I0?ooo`030000003oool0oooo04T0oooo0P00000J07moO`800000=P3oool00`000000Ogmo07mo
O`0Q07moO`030000001oOgl0Ogmo02L0Ogmo0P00003o0?ooohl0oooo00<000000?ooo`3oool02P3o
ool001T0oooo00<000000?ooo`3oool0B@3oool00`000000Ogmo07moO`0I07moO`800000=P3oool0
0`000000Ogmo07moO`0Q07moO`030000001oOgl0Ogmo02L0Ogmo0P00003o0?ooohl0oooo00<00000
0?ooo`3oool02P3oool001T0oooo00<000000?ooo`3oool0B@3oool00`000000Ogmo07moO`0I07mo
O`030000003oool0oooo03D0oooo00<0000007moO`1oOgl08@1oOgl00`000000Ogmo07moO`0W07mo
O`030000003oool0oooo0?l0ooooSP3oool00`000000oooo0?ooo`0:0?ooo`006@3oool00`000000
oooo0?ooo`190?oooad00000=`3ooom?00000?l0ooooT03oool00`000000oooo0?ooo`0:0?ooo`00
6@3oool00`000000oooo0?ooo`3o0?ooool0ooooO@3oool00`000000oooo0?ooo`0:0?ooo`006@3o
ool00`000000oooo0?ooo`3o0?ooool0ooooO@3oool00`000000oooo0?ooo`0:0?ooo`006@3oool0
0`000000oooo0?ooo`3o0?ooool0ooooO@3oool00`000000oooo0?ooo`0:0?ooo`006@3oool00`00
0000oooo0?ooo`3o0?ooool0ooooO@3oool00`000000oooo0?ooo`0:0?ooo`006@3oool00`000000
oooo0?ooo`3o0?ooool0ooooO@3oool00`000000oooo0?ooo`0:0?ooo`006@3oool400000?l0oooo
o`3ooomi0?ooo`@00000303oool001T0oooo00<000000?ooo`3oool0o`3ooooo0?ooogd0oooo00<0
00000?ooo`3oool02P3oool001T0oooo00<000000?ooo`3oool0o`3ooooo0?ooogd0oooo00<00000
0?ooo`3oool02P3oool001T0oooo00<000000?ooo`3oool0o`3ooooo0?ooogd0oooo00<000000?oo
o`3oool02P3oool001T0oooo00<000000?ooo`3oool0o`3ooooo0?ooogd0oooo00<000000?ooo`3o
ool02P3oool001T0oooo00<000000?ooo`3oool0o`3ooooo0?ooogd0oooo00<000000?ooo`3oool0
2P3oool001T0oooo00<000000?ooo`3oool0o`3ooooo0?ooogd0oooo00<000000?ooo`3oool02P3o
ool001T0oooo00<000000?ooo`3oool0o`3ooooo0?ooogd0oooo00<000000?ooo`3oool02P3oool0
01T0oooo00<000000?ooo`3oool0o`3ooooo0?ooogd0oooo00<000000?ooo`3oool02P3oool001T0
oooo00<000000?ooo`3oool0o`3ooooo0?ooogd0oooo00<000000?ooo`3oool02P3oool001T0oooo
00<000000?ooo`3oool0o`3ooooo0?ooogd0oooo00<000000?ooo`3oool02P3oool001T0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooogd0oooo00<000000?ooo`3oool02P3oool001T0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooogd0oooo00<000000?ooo`3oool02P3oool001T0oooo1000003o0?oo
ool0ooooN@3oool4000000`0oooo000I0?ooo`030000003oool0oooo0?l0ooooo`3ooomm0?ooo`03
0000003oool0oooo00X0oooo000I0?ooo`030000003oool0oooo0?l0ooooo`3ooomm0?ooo`030000
003oool0oooo00X0oooo000I0?ooo`030000003oool0oooo0?l0ooooo`3ooomm0?ooo`030000003o
ool0oooo00X0oooo000I0?ooo`030000003oool0oooo0?l0ooooo`3ooomm0?ooo`030000003oool0
oooo00X0oooo000I0?ooo`030000003oool0oooo0?l0ooooo`3ooomm0?ooo`030000003oool0oooo
00X0oooo000I0?ooo`030000003oool0oooo0?l0ooooo`3ooomm0?ooo`030000003oool0oooo00X0
oooo000I0?ooo`030000003oool0oooo0?l0ooooo`3ooomm0?ooo`030000003oool0oooo00X0oooo
000I0?ooo`030000003oool0oooo0?l0ooooo`3ooomm0?ooo`030000003oool0oooo00X0oooo000I
0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`1m
0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`0:
0?ooo`002@3oool2000000<0oooo0P0000090?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0:0?ooo`00203oool01P000000oooo0?ooo`000000oooo
00000080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool02P3oool000/0oooo00<000000?ooo`0000000P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0:0?ooo`002@3oool200000080oooo00@000000?ooo`3oool00000203ooooo0000
0?l00000P@00000<0?ooo`002`3oool00`000000oooo000000020?ooo`030000003oool0oooo0?l0
ooooo`3ooonC0?ooo`00203oool01P000000oooo0?ooo`000000oooo00000080oooo00<000000?oo
o`3oool0o`3ooooo0?oooi<0oooo00090?ooo`8000000`3oool200000?l0ooooo`3ooonF0?ooo`00
o`3ooooo0?ooojH0oooo0000\
\>"],
  ImageRangeCache->{{{0, 675.125}, {404.688, 0}} -> {1395.92, -32.7356, \
0.156948, 0.156948}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ShowSystem[testsys, PlotType \[Rule] TopView, \ Axes \[Rule] False, 
        Frame \[Rule] True, ShowArrows \[Rule] False];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .4186 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.000442968 0.209302 0.000442968 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.24529 -0.0125 -9 -9 ]
[.24529 -0.0125 9 0 ]
[.46678 -0.0125 -12 -9 ]
[.46678 -0.0125 12 0 ]
[.68826 -0.0125 -12 -9 ]
[.68826 -0.0125 12 0 ]
[.90975 -0.0125 -12 -9 ]
[.90975 -0.0125 12 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .03212 -24 -4.5 ]
[-0.0125 .03212 0 4.5 ]
[-0.0125 .12071 -24 -4.5 ]
[-0.0125 .12071 0 4.5 ]
[-0.0125 .2093 -6 -4.5 ]
[-0.0125 .2093 0 4.5 ]
[-0.0125 .2979 -18 -4.5 ]
[-0.0125 .2979 0 4.5 ]
[-0.0125 .38649 -18 -4.5 ]
[-0.0125 .38649 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .4186 .125 0 ]
[ 1 0 .125 0 ]
[.81196 .17152 -9 -4.5 ]
[.81196 .17152 9 4.5 ]
[.87541 .17121 -9 -4.5 ]
[.87541 .17121 9 4.5 ]
[.70715 .10507 -9 -4.5 ]
[.70715 .10507 9 4.5 ]
[.7706 .10476 -9 -4.5 ]
[.7706 .10476 9 4.5 ]
[.52154 .2093 -21 -4.5 ]
[.52154 .2093 21 4.5 ]
[.06257 .29539 -27 -4.5 ]
[.06257 .29539 27 4.5 ]
[.59088 .17674 -15 -4.5 ]
[.59088 .17674 15 4.5 ]
[.65184 .17121 -24 -4.5 ]
[.65184 .17121 24 4.5 ]
[.74551 .17152 -9 -4.5 ]
[.74551 .17152 9 4.5 ]
[ 0 0 0 0 ]
[ 1 .4186 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.24529 0 m
.24529 .00625 L
s
[(500)] .24529 -0.0125 0 1 Mshowa
.46678 0 m
.46678 .00625 L
s
[(1000)] .46678 -0.0125 0 1 Mshowa
.68826 0 m
.68826 .00625 L
s
[(1500)] .68826 -0.0125 0 1 Mshowa
.90975 0 m
.90975 .00625 L
s
[(2000)] .90975 -0.0125 0 1 Mshowa
.125 Mabswid
.06811 0 m
.06811 .00375 L
s
.1124 0 m
.1124 .00375 L
s
.1567 0 m
.1567 .00375 L
s
.201 0 m
.201 .00375 L
s
.28959 0 m
.28959 .00375 L
s
.33389 0 m
.33389 .00375 L
s
.37818 0 m
.37818 .00375 L
s
.42248 0 m
.42248 .00375 L
s
.51107 0 m
.51107 .00375 L
s
.55537 0 m
.55537 .00375 L
s
.59967 0 m
.59967 .00375 L
s
.64396 0 m
.64396 .00375 L
s
.73256 0 m
.73256 .00375 L
s
.77685 0 m
.77685 .00375 L
s
.82115 0 m
.82115 .00375 L
s
.86545 0 m
.86545 .00375 L
s
.95404 0 m
.95404 .00375 L
s
.99834 0 m
.99834 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .03212 m
.00625 .03212 L
s
[(-400)] -0.0125 .03212 1 0 Mshowa
0 .12071 m
.00625 .12071 L
s
[(-200)] -0.0125 .12071 1 0 Mshowa
0 .2093 m
.00625 .2093 L
s
[(0)] -0.0125 .2093 1 0 Mshowa
0 .2979 m
.00625 .2979 L
s
[(200)] -0.0125 .2979 1 0 Mshowa
0 .38649 m
.00625 .38649 L
s
[(400)] -0.0125 .38649 1 0 Mshowa
.125 Mabswid
0 .05426 m
.00375 .05426 L
s
0 .07641 m
.00375 .07641 L
s
0 .09856 m
.00375 .09856 L
s
0 .14286 m
.00375 .14286 L
s
0 .16501 m
.00375 .16501 L
s
0 .18715 m
.00375 .18715 L
s
0 .23145 m
.00375 .23145 L
s
0 .2536 m
.00375 .2536 L
s
0 .27575 m
.00375 .27575 L
s
0 .32004 m
.00375 .32004 L
s
0 .34219 m
.00375 .34219 L
s
0 .36434 m
.00375 .36434 L
s
0 .00997 m
.00375 .00997 L
s
0 .40864 m
.00375 .40864 L
s
.25 Mabswid
0 0 m
0 .4186 L
s
.02381 .41235 m
.02381 .4186 L
s
.24529 .41235 m
.24529 .4186 L
s
.46678 .41235 m
.46678 .4186 L
s
.68826 .41235 m
.68826 .4186 L
s
.90975 .41235 m
.90975 .4186 L
s
.125 Mabswid
.06811 .41485 m
.06811 .4186 L
s
.1124 .41485 m
.1124 .4186 L
s
.1567 .41485 m
.1567 .4186 L
s
.201 .41485 m
.201 .4186 L
s
.28959 .41485 m
.28959 .4186 L
s
.33389 .41485 m
.33389 .4186 L
s
.37818 .41485 m
.37818 .4186 L
s
.42248 .41485 m
.42248 .4186 L
s
.51107 .41485 m
.51107 .4186 L
s
.55537 .41485 m
.55537 .4186 L
s
.59967 .41485 m
.59967 .4186 L
s
.64396 .41485 m
.64396 .4186 L
s
.73256 .41485 m
.73256 .4186 L
s
.77685 .41485 m
.77685 .4186 L
s
.82115 .41485 m
.82115 .4186 L
s
.86545 .41485 m
.86545 .4186 L
s
.95404 .41485 m
.95404 .4186 L
s
.99834 .41485 m
.99834 .4186 L
s
.25 Mabswid
0 .4186 m
1 .4186 L
s
.99375 .03212 m
1 .03212 L
s
.99375 .12071 m
1 .12071 L
s
.99375 .2093 m
1 .2093 L
s
.99375 .2979 m
1 .2979 L
s
.99375 .38649 m
1 .38649 L
s
.125 Mabswid
.99625 .05426 m
1 .05426 L
s
.99625 .07641 m
1 .07641 L
s
.99625 .09856 m
1 .09856 L
s
.99625 .14286 m
1 .14286 L
s
.99625 .16501 m
1 .16501 L
s
.99625 .18715 m
1 .18715 L
s
.99625 .23145 m
1 .23145 L
s
.99625 .2536 m
1 .2536 L
s
.99625 .27575 m
1 .27575 L
s
.99625 .32004 m
1 .32004 L
s
.99625 .34219 m
1 .34219 L
s
.99625 .36434 m
1 .36434 L
s
.99625 .00997 m
1 .00997 L
s
.99625 .40864 m
1 .40864 L
s
.25 Mabswid
1 0 m
1 .4186 L
s
.5 g
.51047 .03654 m
.55476 .03654 L
.55476 .06349 L
.51365 .06349 L
.51047 .03654 L
F
.51365 .06349 m
.55476 .06349 L
.55476 .09044 L
.5163 .09044 L
.51365 .06349 L
F
.5163 .09044 m
.55476 .09044 L
.55476 .11739 L
.51841 .11739 L
.5163 .09044 L
F
.51841 .11739 m
.55476 .11739 L
.55476 .14433 L
.51997 .14433 L
.51841 .11739 L
F
.51997 .14433 m
.55476 .14433 L
.55476 .17128 L
.521 .17128 L
.51997 .14433 L
F
.521 .17128 m
.55476 .17128 L
.55476 .19823 L
.52149 .19823 L
.521 .17128 L
F
0 g
.5 Mabswid
.51047 .03654 m
.51365 .06349 L
.5163 .09044 L
.51841 .11739 L
.51997 .14433 L
.521 .17128 L
.52149 .19823 L
.55476 .19823 L
.55476 .17128 L
.55476 .14433 L
.55476 .11739 L
.55476 .09044 L
.55476 .06349 L
.55476 .03654 L
.51047 .03654 L
s
.5 g
.52149 .22038 m
.55476 .22038 L
.55476 .24732 L
.521 .24732 L
.52149 .22038 L
F
.521 .24732 m
.55476 .24732 L
.55476 .27427 L
.51997 .27427 L
.521 .24732 L
F
.51997 .27427 m
.55476 .27427 L
.55476 .30122 L
.51841 .30122 L
.51997 .27427 L
F
.51841 .30122 m
.55476 .30122 L
.55476 .32817 L
.5163 .32817 L
.51841 .30122 L
F
.5163 .32817 m
.55476 .32817 L
.55476 .35511 L
.51365 .35511 L
.5163 .32817 L
F
.51365 .35511 m
.55476 .35511 L
.55476 .38206 L
.51047 .38206 L
.51365 .35511 L
F
0 g
.52149 .22038 m
.521 .24732 L
.51997 .27427 L
.51841 .30122 L
.5163 .32817 L
.51365 .35511 L
.51047 .38206 L
.55476 .38206 L
.55476 .35511 L
.55476 .32817 L
.55476 .30122 L
.55476 .27427 L
.55476 .24732 L
.55476 .22038 L
.52149 .22038 L
s
.5 g
.51047 .2093 m
.55476 .2093 L
.55476 .2093 L
.51365 .2093 L
.51047 .2093 L
F
.51365 .2093 m
.55476 .2093 L
.55476 .2093 L
.5163 .2093 L
.51365 .2093 L
F
.5163 .2093 m
.55476 .2093 L
.55476 .2093 L
.51841 .2093 L
.5163 .2093 L
F
.51841 .2093 m
.55476 .2093 L
.55476 .2093 L
.51997 .2093 L
.51841 .2093 L
F
.51997 .2093 m
.55476 .2093 L
.55476 .2093 L
.521 .2093 L
.51997 .2093 L
F
.521 .2093 m
.55476 .2093 L
.55476 .2093 L
.52149 .2093 L
.521 .2093 L
F
0 g
.51047 .2093 m
.51365 .2093 L
.5163 .2093 L
.51841 .2093 L
.51997 .2093 L
.521 .2093 L
.52149 .2093 L
.55476 .2093 L
.55476 .2093 L
.55476 .2093 L
.55476 .2093 L
.55476 .2093 L
.55476 .2093 L
.55476 .2093 L
.51047 .2093 L
s
.5 g
.52149 .2093 m
.55476 .2093 L
.55476 .2093 L
.521 .2093 L
.52149 .2093 L
F
.521 .2093 m
.55476 .2093 L
.55476 .2093 L
.51997 .2093 L
.521 .2093 L
F
.51997 .2093 m
.55476 .2093 L
.55476 .2093 L
.51841 .2093 L
.51997 .2093 L
F
.51841 .2093 m
.55476 .2093 L
.55476 .2093 L
.5163 .2093 L
.51841 .2093 L
F
.5163 .2093 m
.55476 .2093 L
.55476 .2093 L
.51365 .2093 L
.5163 .2093 L
F
.51365 .2093 m
.55476 .2093 L
.55476 .2093 L
.51047 .2093 L
.51365 .2093 L
F
0 g
.52149 .2093 m
.521 .2093 L
.51997 .2093 L
.51841 .2093 L
.5163 .2093 L
.51365 .2093 L
.51047 .2093 L
.55476 .2093 L
.55476 .2093 L
.55476 .2093 L
.55476 .2093 L
.55476 .2093 L
.55476 .2093 L
.55476 .2093 L
.52149 .2093 L
s
.5 g
.06584 .26837 m
.05703 .26837 L
.05703 .24868 L
.0671 .24868 L
.06584 .26837 L
F
.0671 .24868 m
.05703 .24868 L
.05703 .22899 L
.06785 .22899 L
.0671 .24868 L
F
.06785 .22899 m
.05703 .22899 L
.05703 .2093 L
.06811 .2093 L
.06785 .22899 L
F
.06811 .2093 m
.05703 .2093 L
.05703 .18961 L
.06785 .18961 L
.06811 .2093 L
F
.06785 .18961 m
.05703 .18961 L
.05703 .16992 L
.0671 .16992 L
.06785 .18961 L
F
.0671 .16992 m
.05703 .16992 L
.05703 .15023 L
.06584 .15023 L
.0671 .16992 L
F
0 g
.06584 .26837 m
.0671 .24868 L
.06785 .22899 L
.06811 .2093 L
.06785 .18961 L
.0671 .16992 L
.06584 .15023 L
.05703 .15023 L
.05703 .16992 L
.05703 .18961 L
.05703 .2093 L
.05703 .22899 L
.05703 .24868 L
.05703 .26837 L
.06584 .26837 L
s
.5 g
.06584 .2093 m
.05703 .2093 L
.05703 .2093 L
.0671 .2093 L
.06584 .2093 L
F
.0671 .2093 m
.05703 .2093 L
.05703 .2093 L
.06785 .2093 L
.0671 .2093 L
F
.06785 .2093 m
.05703 .2093 L
.05703 .2093 L
.06811 .2093 L
.06785 .2093 L
F
.06811 .2093 m
.05703 .2093 L
.05703 .2093 L
.06785 .2093 L
.06811 .2093 L
F
.06785 .2093 m
.05703 .2093 L
.05703 .2093 L
.0671 .2093 L
.06785 .2093 L
F
.0671 .2093 m
.05703 .2093 L
.05703 .2093 L
.06584 .2093 L
.0671 .2093 L
F
0 g
.06584 .2093 m
.0671 .2093 L
.06785 .2093 L
.06811 .2093 L
.06785 .2093 L
.0671 .2093 L
.06584 .2093 L
.05703 .2093 L
.05703 .2093 L
.05703 .2093 L
.05703 .2093 L
.05703 .2093 L
.05703 .2093 L
.05703 .2093 L
.06584 .2093 L
s
.5 g
.52149 .22038 m
.51997 .27427 L
.51997 .27206 L
.52149 .22 L
.52149 .22038 L
F
.52149 .22 m
.51997 .27206 L
.51997 .26557 L
.52149 .21889 L
.52149 .22 L
F
.52149 .21889 m
.51997 .26557 L
.51997 .25524 L
.52149 .21713 L
.52149 .21889 L
F
.52149 .21713 m
.51997 .25524 L
.51997 .24179 L
.52149 .21484 L
.52149 .21713 L
F
.52149 .21484 m
.51997 .24179 L
.51997 .22612 L
.52149 .21217 L
.52149 .21484 L
F
.52149 .21217 m
.51997 .22612 L
.51997 .2093 L
.52149 .2093 L
.52149 .21217 L
F
.52149 .2093 m
.51997 .2093 L
.51997 .19249 L
.52149 .20644 L
.52149 .2093 L
F
.52149 .20644 m
.51997 .19249 L
.51997 .17682 L
.52149 .20377 L
.52149 .20644 L
F
.52149 .20377 m
.51997 .17682 L
.51997 .16336 L
.52149 .20147 L
.52149 .20377 L
F
.52149 .20147 m
.51997 .16336 L
.51997 .15304 L
.52149 .19971 L
.52149 .20147 L
F
.52149 .19971 m
.51997 .15304 L
.51997 .14655 L
.52149 .19861 L
.52149 .19971 L
F
.52149 .19861 m
.51997 .14655 L
.51997 .14433 L
.52149 .19823 L
.52149 .19861 L
F
.52149 .19823 m
.51997 .14433 L
.51997 .14655 L
.52149 .19861 L
.52149 .19823 L
F
.52149 .19861 m
.51997 .14655 L
.51997 .15304 L
.52149 .19971 L
.52149 .19861 L
F
.52149 .19971 m
.51997 .15304 L
.51997 .16336 L
.52149 .20147 L
.52149 .19971 L
F
.52149 .20147 m
.51997 .16336 L
.51997 .17682 L
.52149 .20377 L
.52149 .20147 L
F
.52149 .20377 m
.51997 .17682 L
.51997 .19249 L
.52149 .20644 L
.52149 .20377 L
F
.52149 .20644 m
.51997 .19249 L
.51997 .2093 L
.52149 .2093 L
.52149 .20644 L
F
.52149 .2093 m
.51997 .2093 L
.51997 .22612 L
.52149 .21217 L
.52149 .2093 L
F
.52149 .21217 m
.51997 .22612 L
.51997 .24179 L
.52149 .21484 L
.52149 .21217 L
F
.52149 .21484 m
.51997 .24179 L
.51997 .25524 L
.52149 .21713 L
.52149 .21484 L
F
.52149 .21713 m
.51997 .25524 L
.51997 .26557 L
.52149 .21889 L
.52149 .21713 L
F
.52149 .21889 m
.51997 .26557 L
.51997 .27206 L
.52149 .22 L
.52149 .21889 L
F
.52149 .22 m
.51997 .27206 L
.51997 .27427 L
.52149 .22038 L
.52149 .22 L
F
.51997 .27427 m
.5163 .32817 L
.5163 .32412 L
.51997 .27206 L
.51997 .27427 L
F
.51997 .27206 m
.5163 .32412 L
.5163 .31224 L
.51997 .26557 L
.51997 .27206 L
F
.51997 .26557 m
.5163 .31224 L
.5163 .29335 L
.51997 .25524 L
.51997 .26557 L
F
.51997 .25524 m
.5163 .29335 L
.5163 .26873 L
.51997 .24179 L
.51997 .25524 L
F
.51997 .24179 m
.5163 .26873 L
.5163 .24007 L
.51997 .22612 L
.51997 .24179 L
F
.51997 .22612 m
.5163 .24007 L
.5163 .2093 L
.51997 .2093 L
.51997 .22612 L
F
.51997 .2093 m
.5163 .2093 L
.5163 .17854 L
.51997 .19249 L
.51997 .2093 L
F
.51997 .19249 m
.5163 .17854 L
.5163 .14987 L
.51997 .17682 L
.51997 .19249 L
F
.51997 .17682 m
.5163 .14987 L
.5163 .12525 L
.51997 .16336 L
.51997 .17682 L
F
.51997 .16336 m
.5163 .12525 L
.5163 .10636 L
.51997 .15304 L
.51997 .16336 L
F
.51997 .15304 m
.5163 .10636 L
.5163 .09449 L
.51997 .14655 L
.51997 .15304 L
F
.51997 .14655 m
.5163 .09449 L
.5163 .09044 L
.51997 .14433 L
.51997 .14655 L
F
.51997 .14433 m
.5163 .09044 L
.5163 .09449 L
.51997 .14655 L
.51997 .14433 L
F
.51997 .14655 m
.5163 .09449 L
.5163 .10636 L
.51997 .15304 L
.51997 .14655 L
F
.51997 .15304 m
.5163 .10636 L
.5163 .12525 L
.51997 .16336 L
.51997 .15304 L
F
.51997 .16336 m
.5163 .12525 L
.5163 .14987 L
.51997 .17682 L
.51997 .16336 L
F
.51997 .17682 m
.5163 .14987 L
.5163 .17854 L
.51997 .19249 L
.51997 .17682 L
F
.51997 .19249 m
.5163 .17854 L
.5163 .2093 L
.51997 .2093 L
.51997 .19249 L
F
.51997 .2093 m
.5163 .2093 L
.5163 .24007 L
.51997 .22612 L
.51997 .2093 L
F
.51997 .22612 m
.5163 .24007 L
.5163 .26873 L
.51997 .24179 L
.51997 .22612 L
F
.51997 .24179 m
.5163 .26873 L
.5163 .29335 L
.51997 .25524 L
.51997 .24179 L
F
.51997 .25524 m
.5163 .29335 L
.5163 .31224 L
.51997 .26557 L
.51997 .25524 L
F
.51997 .26557 m
.5163 .31224 L
.5163 .32412 L
.51997 .27206 L
.51997 .26557 L
F
.51997 .27206 m
.5163 .32412 L
.5163 .32817 L
.51997 .27427 L
.51997 .27206 L
F
.5163 .32817 m
.51047 .38206 L
.51047 .37617 L
.5163 .32412 L
.5163 .32817 L
F
.5163 .32412 m
.51047 .37617 L
.51047 .35891 L
.5163 .31224 L
.5163 .32412 L
F
.5163 .31224 m
.51047 .35891 L
.51047 .33146 L
.5163 .29335 L
.5163 .31224 L
F
.5163 .29335 m
.51047 .33146 L
.51047 .29568 L
.5163 .26873 L
.5163 .29335 L
F
.5163 .26873 m
.51047 .29568 L
.51047 .25402 L
.5163 .24007 L
.5163 .26873 L
F
.5163 .24007 m
.51047 .25402 L
.51047 .2093 L
.5163 .2093 L
.5163 .24007 L
F
.5163 .2093 m
.51047 .2093 L
.51047 .16459 L
.5163 .17854 L
.5163 .2093 L
F
.5163 .17854 m
.51047 .16459 L
.51047 .12292 L
.5163 .14987 L
.5163 .17854 L
F
.5163 .14987 m
.51047 .12292 L
.51047 .08714 L
.5163 .12525 L
.5163 .14987 L
F
.5163 .12525 m
.51047 .08714 L
.51047 .05969 L
.5163 .10636 L
.5163 .12525 L
F
.5163 .10636 m
.51047 .05969 L
.51047 .04243 L
.5163 .09449 L
.5163 .10636 L
F
.5163 .09449 m
.51047 .04243 L
.51047 .03654 L
.5163 .09044 L
.5163 .09449 L
F
.5163 .09044 m
.51047 .03654 L
.51047 .04243 L
.5163 .09449 L
.5163 .09044 L
F
.5163 .09449 m
.51047 .04243 L
.51047 .05969 L
.5163 .10636 L
.5163 .09449 L
F
.5163 .10636 m
.51047 .05969 L
.51047 .08714 L
.5163 .12525 L
.5163 .10636 L
F
.5163 .12525 m
.51047 .08714 L
.51047 .12292 L
.5163 .14987 L
.5163 .12525 L
F
.5163 .14987 m
.51047 .12292 L
.51047 .16459 L
.5163 .17854 L
.5163 .14987 L
F
.5163 .17854 m
.51047 .16459 L
.51047 .2093 L
.5163 .2093 L
.5163 .17854 L
F
.5163 .2093 m
.51047 .2093 L
.51047 .25402 L
.5163 .24007 L
.5163 .2093 L
F
.5163 .24007 m
.51047 .25402 L
.51047 .29568 L
.5163 .26873 L
.5163 .24007 L
F
.5163 .26873 m
.51047 .29568 L
.51047 .33146 L
.5163 .29335 L
.5163 .26873 L
F
.5163 .29335 m
.51047 .33146 L
.51047 .35891 L
.5163 .31224 L
.5163 .29335 L
F
.5163 .31224 m
.51047 .35891 L
.51047 .37617 L
.5163 .32412 L
.5163 .31224 L
F
.5163 .32412 m
.51047 .37617 L
.51047 .38206 L
.5163 .32817 L
.5163 .32412 L
F
0 g
.52149 .22038 m
.52149 .22 L
.52149 .21889 L
.52149 .21713 L
.52149 .21484 L
.52149 .21217 L
.52149 .2093 L
.52149 .20644 L
.52149 .20377 L
.52149 .20147 L
.52149 .19971 L
.52149 .19861 L
.52149 .19823 L
.52149 .19861 L
.52149 .19971 L
.52149 .20147 L
.52149 .20377 L
.52149 .20644 L
.52149 .2093 L
.52149 .21217 L
.52149 .21484 L
.52149 .21713 L
.52149 .21889 L
.52149 .22 L
.52149 .22038 L
s
.51047 .38206 m
.51047 .37617 L
.51047 .35891 L
.51047 .33146 L
.51047 .29568 L
.51047 .25402 L
.51047 .2093 L
.51047 .16459 L
.51047 .12292 L
.51047 .08714 L
.51047 .05969 L
.51047 .04243 L
.51047 .03654 L
.51047 .04243 L
.51047 .05969 L
.51047 .08714 L
.51047 .12292 L
.51047 .16459 L
.51047 .2093 L
.51047 .25402 L
.51047 .29568 L
.51047 .33146 L
.51047 .35891 L
.51047 .37617 L
.51047 .38206 L
s
.55476 .22038 m
.55476 .22 L
.55476 .21889 L
.55476 .21713 L
.55476 .21484 L
.55476 .21217 L
.55476 .2093 L
.55476 .20644 L
.55476 .20377 L
.55476 .20147 L
.55476 .19971 L
.55476 .19861 L
.55476 .19823 L
.55476 .19861 L
.55476 .19971 L
.55476 .20147 L
.55476 .20377 L
.55476 .20644 L
.55476 .2093 L
.55476 .21217 L
.55476 .21484 L
.55476 .21713 L
.55476 .21889 L
.55476 .22 L
.55476 .22038 L
s
.55476 .38206 m
.55476 .37617 L
.55476 .35891 L
.55476 .33146 L
.55476 .29568 L
.55476 .25402 L
.55476 .2093 L
.55476 .16459 L
.55476 .12292 L
.55476 .08714 L
.55476 .05969 L
.55476 .04243 L
.55476 .03654 L
.55476 .04243 L
.55476 .05969 L
.55476 .08714 L
.55476 .12292 L
.55476 .16459 L
.55476 .2093 L
.55476 .25402 L
.55476 .29568 L
.55476 .33146 L
.55476 .35891 L
.55476 .37617 L
.55476 .38206 L
s
.51047 .38206 m
.55476 .38206 L
.55476 .37617 L
.51047 .37617 L
.51047 .38206 L
s
.51047 .37617 m
.55476 .37617 L
.55476 .35891 L
.51047 .35891 L
.51047 .37617 L
s
.51047 .35891 m
.55476 .35891 L
.55476 .33146 L
.51047 .33146 L
.51047 .35891 L
s
.51047 .33146 m
.55476 .33146 L
.55476 .29568 L
.51047 .29568 L
.51047 .33146 L
s
.51047 .29568 m
.55476 .29568 L
.55476 .25402 L
.51047 .25402 L
.51047 .29568 L
s
.51047 .25402 m
.55476 .25402 L
.55476 .2093 L
.51047 .2093 L
.51047 .25402 L
s
.51047 .2093 m
.55476 .2093 L
.55476 .16459 L
.51047 .16459 L
.51047 .2093 L
s
.51047 .16459 m
.55476 .16459 L
.55476 .12292 L
.51047 .12292 L
.51047 .16459 L
s
.51047 .12292 m
.55476 .12292 L
.55476 .08714 L
.51047 .08714 L
.51047 .12292 L
s
.51047 .08714 m
.55476 .08714 L
.55476 .05969 L
.51047 .05969 L
.51047 .08714 L
s
.51047 .05969 m
.55476 .05969 L
.55476 .04243 L
.51047 .04243 L
.51047 .05969 L
s
.51047 .04243 m
.55476 .04243 L
.55476 .03654 L
.51047 .03654 L
.51047 .04243 L
s
.51047 .03654 m
.55476 .03654 L
.55476 .04243 L
.51047 .04243 L
.51047 .03654 L
s
.51047 .04243 m
.55476 .04243 L
.55476 .05969 L
.51047 .05969 L
.51047 .04243 L
s
.51047 .05969 m
.55476 .05969 L
.55476 .08714 L
.51047 .08714 L
.51047 .05969 L
s
.51047 .08714 m
.55476 .08714 L
.55476 .12292 L
.51047 .12292 L
.51047 .08714 L
s
.51047 .12292 m
.55476 .12292 L
.55476 .16459 L
.51047 .16459 L
.51047 .12292 L
s
.51047 .16459 m
.55476 .16459 L
.55476 .2093 L
.51047 .2093 L
.51047 .16459 L
s
.51047 .2093 m
.55476 .2093 L
.55476 .25402 L
.51047 .25402 L
.51047 .2093 L
s
.51047 .25402 m
.55476 .25402 L
.55476 .29568 L
.51047 .29568 L
.51047 .25402 L
s
.51047 .29568 m
.55476 .29568 L
.55476 .33146 L
.51047 .33146 L
.51047 .29568 L
s
.51047 .33146 m
.55476 .33146 L
.55476 .35891 L
.51047 .35891 L
.51047 .33146 L
s
.51047 .35891 m
.55476 .35891 L
.55476 .37617 L
.51047 .37617 L
.51047 .35891 L
s
.51047 .37617 m
.55476 .37617 L
.55476 .38206 L
.51047 .38206 L
.51047 .37617 L
s
.52149 .22038 m
.55476 .22038 L
.55476 .22 L
.52149 .22 L
.52149 .22038 L
s
.52149 .22 m
.55476 .22 L
.55476 .21889 L
.52149 .21889 L
.52149 .22 L
s
.52149 .21889 m
.55476 .21889 L
.55476 .21713 L
.52149 .21713 L
.52149 .21889 L
s
.52149 .21713 m
.55476 .21713 L
.55476 .21484 L
.52149 .21484 L
.52149 .21713 L
s
.52149 .21484 m
.55476 .21484 L
.55476 .21217 L
.52149 .21217 L
.52149 .21484 L
s
.52149 .21217 m
.55476 .21217 L
.55476 .2093 L
.52149 .2093 L
.52149 .21217 L
s
.52149 .2093 m
.55476 .2093 L
.55476 .20644 L
.52149 .20644 L
.52149 .2093 L
s
.52149 .20644 m
.55476 .20644 L
.55476 .20377 L
.52149 .20377 L
.52149 .20644 L
s
.52149 .20377 m
.55476 .20377 L
.55476 .20147 L
.52149 .20147 L
.52149 .20377 L
s
.52149 .20147 m
.55476 .20147 L
.55476 .19971 L
.52149 .19971 L
.52149 .20147 L
s
.52149 .19971 m
.55476 .19971 L
.55476 .19861 L
.52149 .19861 L
.52149 .19971 L
s
.52149 .19861 m
.55476 .19861 L
.55476 .19823 L
.52149 .19823 L
.52149 .19861 L
s
.52149 .19823 m
.55476 .19823 L
.55476 .19861 L
.52149 .19861 L
.52149 .19823 L
s
.52149 .19861 m
.55476 .19861 L
.55476 .19971 L
.52149 .19971 L
.52149 .19861 L
s
.52149 .19971 m
.55476 .19971 L
.55476 .20147 L
.52149 .20147 L
.52149 .19971 L
s
.52149 .20147 m
.55476 .20147 L
.55476 .20377 L
.52149 .20377 L
.52149 .20147 L
s
.52149 .20377 m
.55476 .20377 L
.55476 .20644 L
.52149 .20644 L
.52149 .20377 L
s
.52149 .20644 m
.55476 .20644 L
.55476 .2093 L
.52149 .2093 L
.52149 .20644 L
s
.52149 .2093 m
.55476 .2093 L
.55476 .21217 L
.52149 .21217 L
.52149 .2093 L
s
.52149 .21217 m
.55476 .21217 L
.55476 .21484 L
.52149 .21484 L
.52149 .21217 L
s
.52149 .21484 m
.55476 .21484 L
.55476 .21713 L
.52149 .21713 L
.52149 .21484 L
s
.52149 .21713 m
.55476 .21713 L
.55476 .21889 L
.52149 .21889 L
.52149 .21713 L
s
.52149 .21889 m
.55476 .21889 L
.55476 .22 L
.52149 .22 L
.52149 .21889 L
s
.52149 .22 m
.55476 .22 L
.55476 .22038 L
.52149 .22038 L
.52149 .22 L
s
.5 g
.06811 .2093 m
.06785 .18961 L
.06785 .19028 L
.06811 .2093 L
.06811 .2093 L
F
.06785 .18961 m
.0671 .16992 L
.0671 .17126 L
.06785 .19028 L
.06785 .18961 L
F
.0671 .16992 m
.06584 .15023 L
.06584 .15225 L
.0671 .17126 L
.0671 .16992 L
F
.06811 .2093 m
.06785 .19028 L
.06785 .19225 L
.06811 .2093 L
.06811 .2093 L
F
.06785 .19028 m
.0671 .17126 L
.0671 .1752 L
.06785 .19225 L
.06785 .19028 L
F
.0671 .17126 m
.06584 .15225 L
.06584 .15815 L
.0671 .1752 L
.0671 .17126 L
F
.06811 .2093 m
.06785 .19225 L
.06785 .19538 L
.06811 .2093 L
.06811 .2093 L
F
.06785 .19225 m
.0671 .1752 L
.0671 .18146 L
.06785 .19538 L
.06785 .19225 L
F
.0671 .1752 m
.06584 .15815 L
.06584 .16753 L
.0671 .18146 L
.0671 .1752 L
F
.06811 .2093 m
.06785 .19538 L
.06785 .19946 L
.06811 .2093 L
.06811 .2093 L
F
.06785 .19538 m
.0671 .18146 L
.0671 .18961 L
.06785 .19946 L
.06785 .19538 L
F
.0671 .18146 m
.06584 .16753 L
.06584 .17977 L
.0671 .18961 L
.0671 .18146 L
F
.06811 .2093 m
.06785 .19946 L
.06785 .20421 L
.06811 .2093 L
.06811 .2093 L
F
.06785 .19946 m
.0671 .18961 L
.0671 .19911 L
.06785 .20421 L
.06785 .19946 L
F
.0671 .18961 m
.06584 .17977 L
.06584 .19401 L
.0671 .19911 L
.0671 .18961 L
F
.06811 .2093 m
.06785 .20421 L
.06785 .2093 L
.06811 .2093 L
.06811 .2093 L
F
.06785 .20421 m
.0671 .19911 L
.0671 .2093 L
.06785 .2093 L
.06785 .20421 L
F
.0671 .19911 m
.06584 .19401 L
.06584 .2093 L
.0671 .2093 L
.0671 .19911 L
F
.06811 .2093 m
.06785 .2093 L
.06785 .2144 L
.06811 .2093 L
.06811 .2093 L
F
.06785 .2093 m
.0671 .2093 L
.0671 .21949 L
.06785 .2144 L
.06785 .2093 L
F
.0671 .2093 m
.06584 .2093 L
.06584 .22459 L
.0671 .21949 L
.0671 .2093 L
F
.06811 .2093 m
.06785 .2144 L
.06785 .21915 L
.06811 .2093 L
.06811 .2093 L
F
.06785 .2144 m
.0671 .21949 L
.0671 .22899 L
.06785 .21915 L
.06785 .2144 L
F
.0671 .21949 m
.06584 .22459 L
.06584 .23884 L
.0671 .22899 L
.0671 .21949 L
F
.06811 .2093 m
.06785 .21915 L
.06785 .22323 L
.06811 .2093 L
.06811 .2093 L
F
.06785 .21915 m
.0671 .22899 L
.0671 .23715 L
.06785 .22323 L
.06785 .21915 L
F
.0671 .22899 m
.06584 .23884 L
.06584 .25107 L
.0671 .23715 L
.0671 .22899 L
F
.06811 .2093 m
.06785 .22323 L
.06785 .22635 L
.06811 .2093 L
.06811 .2093 L
F
.06785 .22323 m
.0671 .23715 L
.0671 .24341 L
.06785 .22635 L
.06785 .22323 L
F
.0671 .23715 m
.06584 .25107 L
.06584 .26046 L
.0671 .24341 L
.0671 .23715 L
F
.06811 .2093 m
.06785 .22635 L
.06785 .22832 L
.06811 .2093 L
.06811 .2093 L
F
.06785 .22635 m
.0671 .24341 L
.0671 .24734 L
.06785 .22832 L
.06785 .22635 L
F
.0671 .24341 m
.06584 .26046 L
.06584 .26636 L
.0671 .24734 L
.0671 .24341 L
F
.06811 .2093 m
.06785 .22832 L
.06785 .22899 L
.06811 .2093 L
.06811 .2093 L
F
.06785 .22832 m
.0671 .24734 L
.0671 .24868 L
.06785 .22899 L
.06785 .22832 L
F
.0671 .24734 m
.06584 .26636 L
.06584 .26837 L
.0671 .24868 L
.0671 .24734 L
F
.06811 .2093 m
.06785 .22899 L
.06785 .22832 L
.06811 .2093 L
.06811 .2093 L
F
.06785 .22899 m
.0671 .24868 L
.0671 .24734 L
.06785 .22832 L
.06785 .22899 L
F
.0671 .24868 m
.06584 .26837 L
.06584 .26636 L
.0671 .24734 L
.0671 .24868 L
F
.06811 .2093 m
.06785 .22832 L
.06785 .22635 L
.06811 .2093 L
.06811 .2093 L
F
.06785 .22832 m
.0671 .24734 L
.0671 .24341 L
.06785 .22635 L
.06785 .22832 L
F
.0671 .24734 m
.06584 .26636 L
.06584 .26046 L
.0671 .24341 L
.0671 .24734 L
F
.06811 .2093 m
.06785 .22635 L
.06785 .22323 L
.06811 .2093 L
.06811 .2093 L
F
.06785 .22635 m
.0671 .24341 L
.0671 .23715 L
.06785 .22323 L
.06785 .22635 L
F
.0671 .24341 m
.06584 .26046 L
.06584 .25107 L
.0671 .23715 L
.0671 .24341 L
F
.06811 .2093 m
.06785 .22323 L
.06785 .21915 L
.06811 .2093 L
.06811 .2093 L
F
.06785 .22323 m
.0671 .23715 L
.0671 .22899 L
.06785 .21915 L
.06785 .22323 L
F
.0671 .23715 m
.06584 .25107 L
.06584 .23884 L
.0671 .22899 L
.0671 .23715 L
F
.06811 .2093 m
.06785 .21915 L
.06785 .2144 L
.06811 .2093 L
.06811 .2093 L
F
.06785 .21915 m
.0671 .22899 L
.0671 .21949 L
.06785 .2144 L
.06785 .21915 L
F
.0671 .22899 m
.06584 .23884 L
.06584 .22459 L
.0671 .21949 L
.0671 .22899 L
F
.06811 .2093 m
.06785 .2144 L
.06785 .2093 L
.06811 .2093 L
.06811 .2093 L
F
.06785 .2144 m
.0671 .21949 L
.0671 .2093 L
.06785 .2093 L
.06785 .2144 L
F
.0671 .21949 m
.06584 .22459 L
.06584 .2093 L
.0671 .2093 L
.0671 .21949 L
F
.06811 .2093 m
.06785 .2093 L
.06785 .20421 L
.06811 .2093 L
.06811 .2093 L
F
.06785 .2093 m
.0671 .2093 L
.0671 .19911 L
.06785 .20421 L
.06785 .2093 L
F
.0671 .2093 m
.06584 .2093 L
.06584 .19401 L
.0671 .19911 L
.0671 .2093 L
F
.06811 .2093 m
.06785 .20421 L
.06785 .19946 L
.06811 .2093 L
.06811 .2093 L
F
.06785 .20421 m
.0671 .19911 L
.0671 .18961 L
.06785 .19946 L
.06785 .20421 L
F
.0671 .19911 m
.06584 .19401 L
.06584 .17977 L
.0671 .18961 L
.0671 .19911 L
F
.06811 .2093 m
.06785 .19946 L
.06785 .19538 L
.06811 .2093 L
.06811 .2093 L
F
.06785 .19946 m
.0671 .18961 L
.0671 .18146 L
.06785 .19538 L
.06785 .19946 L
F
.0671 .18961 m
.06584 .17977 L
.06584 .16753 L
.0671 .18146 L
.0671 .18961 L
F
.06811 .2093 m
.06785 .19538 L
.06785 .19225 L
.06811 .2093 L
.06811 .2093 L
F
.06785 .19538 m
.0671 .18146 L
.0671 .1752 L
.06785 .19225 L
.06785 .19538 L
F
.0671 .18146 m
.06584 .16753 L
.06584 .15815 L
.0671 .1752 L
.0671 .18146 L
F
.06811 .2093 m
.06785 .19225 L
.06785 .19028 L
.06811 .2093 L
.06811 .2093 L
F
.06785 .19225 m
.0671 .1752 L
.0671 .17126 L
.06785 .19028 L
.06785 .19225 L
F
.0671 .1752 m
.06584 .15815 L
.06584 .15225 L
.0671 .17126 L
.0671 .1752 L
F
.06811 .2093 m
.06785 .19028 L
.06785 .18961 L
.06811 .2093 L
.06811 .2093 L
F
.06785 .19028 m
.0671 .17126 L
.0671 .16992 L
.06785 .18961 L
.06785 .19028 L
F
.0671 .17126 m
.06584 .15225 L
.06584 .15023 L
.0671 .16992 L
.0671 .17126 L
F
0 g
.06584 .15023 m
.06584 .15225 L
.06584 .15815 L
.06584 .16753 L
.06584 .17977 L
.06584 .19401 L
.06584 .2093 L
.06584 .22459 L
.06584 .23884 L
.06584 .25107 L
.06584 .26046 L
.06584 .26636 L
.06584 .26837 L
.06584 .26636 L
.06584 .26046 L
.06584 .25107 L
.06584 .23884 L
.06584 .22459 L
.06584 .2093 L
.06584 .19401 L
.06584 .17977 L
.06584 .16753 L
.06584 .15815 L
.06584 .15225 L
.06584 .15023 L
s
.05703 .15023 m
.05703 .15225 L
.05703 .15815 L
.05703 .16753 L
.05703 .17977 L
.05703 .19401 L
.05703 .2093 L
.05703 .22459 L
.05703 .23884 L
.05703 .25107 L
.05703 .26046 L
.05703 .26636 L
.05703 .26837 L
.05703 .26636 L
.05703 .26046 L
.05703 .25107 L
.05703 .23884 L
.05703 .22459 L
.05703 .2093 L
.05703 .19401 L
.05703 .17977 L
.05703 .16753 L
.05703 .15815 L
.05703 .15225 L
.05703 .15023 L
s
.06584 .15023 m
.05703 .15023 L
.05703 .15225 L
.06584 .15225 L
.06584 .15023 L
s
.06584 .15225 m
.05703 .15225 L
.05703 .15815 L
.06584 .15815 L
.06584 .15225 L
s
.06584 .15815 m
.05703 .15815 L
.05703 .16753 L
.06584 .16753 L
.06584 .15815 L
s
.06584 .16753 m
.05703 .16753 L
.05703 .17977 L
.06584 .17977 L
.06584 .16753 L
s
.06584 .17977 m
.05703 .17977 L
.05703 .19401 L
.06584 .19401 L
.06584 .17977 L
s
.06584 .19401 m
.05703 .19401 L
.05703 .2093 L
.06584 .2093 L
.06584 .19401 L
s
.06584 .2093 m
.05703 .2093 L
.05703 .22459 L
.06584 .22459 L
.06584 .2093 L
s
.06584 .22459 m
.05703 .22459 L
.05703 .23884 L
.06584 .23884 L
.06584 .22459 L
s
.06584 .23884 m
.05703 .23884 L
.05703 .25107 L
.06584 .25107 L
.06584 .23884 L
s
.06584 .25107 m
.05703 .25107 L
.05703 .26046 L
.06584 .26046 L
.06584 .25107 L
s
.06584 .26046 m
.05703 .26046 L
.05703 .26636 L
.06584 .26636 L
.06584 .26046 L
s
.06584 .26636 m
.05703 .26636 L
.05703 .26837 L
.06584 .26837 L
.06584 .26636 L
s
.06584 .26837 m
.05703 .26837 L
.05703 .26636 L
.06584 .26636 L
.06584 .26837 L
s
.06584 .26636 m
.05703 .26636 L
.05703 .26046 L
.06584 .26046 L
.06584 .26636 L
s
.06584 .26046 m
.05703 .26046 L
.05703 .25107 L
.06584 .25107 L
.06584 .26046 L
s
.06584 .25107 m
.05703 .25107 L
.05703 .23884 L
.06584 .23884 L
.06584 .25107 L
s
.06584 .23884 m
.05703 .23884 L
.05703 .22459 L
.06584 .22459 L
.06584 .23884 L
s
.06584 .22459 m
.05703 .22459 L
.05703 .2093 L
.06584 .2093 L
.06584 .22459 L
s
.06584 .2093 m
.05703 .2093 L
.05703 .19401 L
.06584 .19401 L
.06584 .2093 L
s
.06584 .19401 m
.05703 .19401 L
.05703 .17977 L
.06584 .17977 L
.06584 .19401 L
s
.06584 .17977 m
.05703 .17977 L
.05703 .16753 L
.06584 .16753 L
.06584 .17977 L
s
.06584 .16753 m
.05703 .16753 L
.05703 .15815 L
.06584 .15815 L
.06584 .16753 L
s
.06584 .15815 m
.05703 .15815 L
.05703 .15225 L
.06584 .15225 L
.06584 .15815 L
s
.06584 .15225 m
.05703 .15225 L
.05703 .15023 L
.06584 .15023 L
.06584 .15225 L
s
.5 g
.58931 .21096 m
.58931 .21226 L
.58931 .21215 L
.58931 .21091 L
.58931 .21096 L
F
.58931 .21091 m
.58931 .21215 L
.58931 .21186 L
.58931 .21074 L
.58931 .21091 L
F
.58931 .21074 m
.58931 .21186 L
.58931 .21139 L
.58931 .21048 L
.58931 .21074 L
F
.58931 .21048 m
.58931 .21139 L
.58931 .21078 L
.58931 .21013 L
.58931 .21048 L
F
.58931 .21013 m
.58931 .21078 L
.58931 .21007 L
.58931 .20973 L
.58931 .21013 L
F
.58931 .20973 m
.58931 .21007 L
.58931 .2093 L
.58931 .2093 L
.58931 .20973 L
F
.58931 .2093 m
.58931 .2093 L
.58931 .20854 L
.58931 .20887 L
.58931 .2093 L
F
.58931 .20887 m
.58931 .20854 L
.58931 .20783 L
.58931 .20847 L
.58931 .20887 L
F
.58931 .20847 m
.58931 .20783 L
.58931 .20721 L
.58931 .20813 L
.58931 .20847 L
F
.58931 .20813 m
.58931 .20721 L
.58931 .20674 L
.58931 .20786 L
.58931 .20813 L
F
.58931 .20786 m
.58931 .20674 L
.58931 .20645 L
.58931 .2077 L
.58931 .20786 L
F
.58931 .2077 m
.58931 .20645 L
.58931 .20635 L
.58931 .20764 L
.58931 .2077 L
F
.58931 .20764 m
.58931 .20635 L
.58931 .20645 L
.58931 .2077 L
.58931 .20764 L
F
.58931 .2077 m
.58931 .20645 L
.58931 .20674 L
.58931 .20786 L
.58931 .2077 L
F
.58931 .20786 m
.58931 .20674 L
.58931 .20721 L
.58931 .20813 L
.58931 .20786 L
F
.58931 .20813 m
.58931 .20721 L
.58931 .20783 L
.58931 .20847 L
.58931 .20813 L
F
.58931 .20847 m
.58931 .20783 L
.58931 .20854 L
.58931 .20887 L
.58931 .20847 L
F
.58931 .20887 m
.58931 .20854 L
.58931 .2093 L
.58931 .2093 L
.58931 .20887 L
F
.58931 .2093 m
.58931 .2093 L
.58931 .21007 L
.58931 .20973 L
.58931 .2093 L
F
.58931 .20973 m
.58931 .21007 L
.58931 .21078 L
.58931 .21013 L
.58931 .20973 L
F
.58931 .21013 m
.58931 .21078 L
.58931 .21139 L
.58931 .21048 L
.58931 .21013 L
F
.58931 .21048 m
.58931 .21139 L
.58931 .21186 L
.58931 .21074 L
.58931 .21048 L
F
.58931 .21074 m
.58931 .21186 L
.58931 .21215 L
.58931 .21091 L
.58931 .21074 L
F
.58931 .21091 m
.58931 .21215 L
.58931 .21226 L
.58931 .21096 L
.58931 .21091 L
F
.58931 .21226 m
.58931 .21355 L
.58931 .2134 L
.58931 .21215 L
.58931 .21226 L
F
.58931 .21215 m
.58931 .2134 L
.58931 .21298 L
.58931 .21186 L
.58931 .21215 L
F
.58931 .21186 m
.58931 .21298 L
.58931 .2123 L
.58931 .21139 L
.58931 .21186 L
F
.58931 .21139 m
.58931 .2123 L
.58931 .21142 L
.58931 .21078 L
.58931 .21139 L
F
.58931 .21078 m
.58931 .21142 L
.58931 .2104 L
.58931 .21007 L
.58931 .21078 L
F
.58931 .21007 m
.58931 .2104 L
.58931 .2093 L
.58931 .2093 L
.58931 .21007 L
F
.58931 .2093 m
.58931 .2093 L
.58931 .2082 L
.58931 .20854 L
.58931 .2093 L
F
.58931 .20854 m
.58931 .2082 L
.58931 .20718 L
.58931 .20783 L
.58931 .20854 L
F
.58931 .20783 m
.58931 .20718 L
.58931 .2063 L
.58931 .20721 L
.58931 .20783 L
F
.58931 .20721 m
.58931 .2063 L
.58931 .20563 L
.58931 .20674 L
.58931 .20721 L
F
.58931 .20674 m
.58931 .20563 L
.58931 .2052 L
.58931 .20645 L
.58931 .20674 L
F
.58931 .20645 m
.58931 .2052 L
.58931 .20506 L
.58931 .20635 L
.58931 .20645 L
F
.58931 .20635 m
.58931 .20506 L
.58931 .2052 L
.58931 .20645 L
.58931 .20635 L
F
.58931 .20645 m
.58931 .2052 L
.58931 .20563 L
.58931 .20674 L
.58931 .20645 L
F
.58931 .20674 m
.58931 .20563 L
.58931 .2063 L
.58931 .20721 L
.58931 .20674 L
F
.58931 .20721 m
.58931 .2063 L
.58931 .20718 L
.58931 .20783 L
.58931 .20721 L
F
.58931 .20783 m
.58931 .20718 L
.58931 .2082 L
.58931 .20854 L
.58931 .20783 L
F
.58931 .20854 m
.58931 .2082 L
.58931 .2093 L
.58931 .2093 L
.58931 .20854 L
F
.58931 .2093 m
.58931 .2093 L
.58931 .2104 L
.58931 .21007 L
.58931 .2093 L
F
.58931 .21007 m
.58931 .2104 L
.58931 .21142 L
.58931 .21078 L
.58931 .21007 L
F
.58931 .21078 m
.58931 .21142 L
.58931 .2123 L
.58931 .21139 L
.58931 .21078 L
F
.58931 .21139 m
.58931 .2123 L
.58931 .21298 L
.58931 .21186 L
.58931 .21139 L
F
.58931 .21186 m
.58931 .21298 L
.58931 .2134 L
.58931 .21215 L
.58931 .21186 L
F
.58931 .21215 m
.58931 .2134 L
.58931 .21355 L
.58931 .21226 L
.58931 .21215 L
F
.58931 .21355 m
.58931 .21484 L
.58931 .21465 L
.58931 .2134 L
.58931 .21355 L
F
.58931 .2134 m
.58931 .21465 L
.58931 .2141 L
.58931 .21298 L
.58931 .2134 L
F
.58931 .21298 m
.58931 .2141 L
.58931 .21322 L
.58931 .2123 L
.58931 .21298 L
F
.58931 .2123 m
.58931 .21322 L
.58931 .21207 L
.58931 .21142 L
.58931 .2123 L
F
.58931 .21142 m
.58931 .21207 L
.58931 .21074 L
.58931 .2104 L
.58931 .21142 L
F
.58931 .2104 m
.58931 .21074 L
.58931 .2093 L
.58931 .2093 L
.58931 .2104 L
F
.58931 .2093 m
.58931 .2093 L
.58931 .20787 L
.58931 .2082 L
.58931 .2093 L
F
.58931 .2082 m
.58931 .20787 L
.58931 .20653 L
.58931 .20718 L
.58931 .2082 L
F
.58931 .20718 m
.58931 .20653 L
.58931 .20539 L
.58931 .2063 L
.58931 .20718 L
F
.58931 .2063 m
.58931 .20539 L
.58931 .20451 L
.58931 .20563 L
.58931 .2063 L
F
.58931 .20563 m
.58931 .20451 L
.58931 .20395 L
.58931 .2052 L
.58931 .20563 L
F
.58931 .2052 m
.58931 .20395 L
.58931 .20377 L
.58931 .20506 L
.58931 .2052 L
F
.58931 .20506 m
.58931 .20377 L
.58931 .20395 L
.58931 .2052 L
.58931 .20506 L
F
.58931 .2052 m
.58931 .20395 L
.58931 .20451 L
.58931 .20563 L
.58931 .2052 L
F
.58931 .20563 m
.58931 .20451 L
.58931 .20539 L
.58931 .2063 L
.58931 .20563 L
F
.58931 .2063 m
.58931 .20539 L
.58931 .20653 L
.58931 .20718 L
.58931 .2063 L
F
.58931 .20718 m
.58931 .20653 L
.58931 .20787 L
.58931 .2082 L
.58931 .20718 L
F
.58931 .2082 m
.58931 .20787 L
.58931 .2093 L
.58931 .2093 L
.58931 .2082 L
F
.58931 .2093 m
.58931 .2093 L
.58931 .21074 L
.58931 .2104 L
.58931 .2093 L
F
.58931 .2104 m
.58931 .21074 L
.58931 .21207 L
.58931 .21142 L
.58931 .2104 L
F
.58931 .21142 m
.58931 .21207 L
.58931 .21322 L
.58931 .2123 L
.58931 .21142 L
F
.58931 .2123 m
.58931 .21322 L
.58931 .2141 L
.58931 .21298 L
.58931 .2123 L
F
.58931 .21298 m
.58931 .2141 L
.58931 .21465 L
.58931 .2134 L
.58931 .21298 L
F
.58931 .2134 m
.58931 .21465 L
.58931 .21484 L
.58931 .21355 L
.58931 .2134 L
F
0 g
.58931 .21096 m
.58931 .21091 L
.58931 .21074 L
.58931 .21048 L
.58931 .21013 L
.58931 .20973 L
.58931 .2093 L
.58931 .20887 L
.58931 .20847 L
.58931 .20813 L
.58931 .20786 L
.58931 .2077 L
.58931 .20764 L
.58931 .2077 L
.58931 .20786 L
.58931 .20813 L
.58931 .20847 L
.58931 .20887 L
.58931 .2093 L
.58931 .20973 L
.58931 .21013 L
.58931 .21048 L
.58931 .21074 L
.58931 .21091 L
.58931 .21096 L
s
.58931 .21484 m
.58931 .21465 L
.58931 .2141 L
.58931 .21322 L
.58931 .21207 L
.58931 .21074 L
.58931 .2093 L
.58931 .20787 L
.58931 .20653 L
.58931 .20539 L
.58931 .20451 L
.58931 .20395 L
.58931 .20377 L
.58931 .20395 L
.58931 .20451 L
.58931 .20539 L
.58931 .20653 L
.58931 .20787 L
.58931 .2093 L
.58931 .21074 L
.58931 .21207 L
.58931 .21322 L
.58931 .2141 L
.58931 .21465 L
.58931 .21484 L
s
.5 g
.59243 .20377 m
.59201 .20377 L
.59201 .20561 L
.5908 .20561 L
.59243 .20377 L
F
.5908 .20561 m
.59201 .20561 L
.59201 .20746 L
.59 .20746 L
.5908 .20561 L
F
.59 .20746 m
.59201 .20746 L
.59201 .2093 L
.58976 .2093 L
.59 .20746 L
F
.58976 .2093 m
.59201 .2093 L
.59201 .21115 L
.59 .21115 L
.58976 .2093 L
F
.59 .21115 m
.59201 .21115 L
.59201 .21299 L
.5908 .21299 L
.59 .21115 L
F
.5908 .21299 m
.59201 .21299 L
.59201 .21484 L
.59243 .21484 L
.5908 .21299 L
F
0 g
.59243 .20377 m
.5908 .20561 L
.59 .20746 L
.58976 .2093 L
.59 .21115 L
.5908 .21299 L
.59243 .21484 L
.59201 .21484 L
.59201 .21299 L
.59201 .21115 L
.59201 .2093 L
.59201 .20746 L
.59201 .20561 L
.59201 .20377 L
.59243 .20377 L
s
.5 g
.59243 .2093 m
.59201 .2093 L
.59201 .2093 L
.5908 .2093 L
.59243 .2093 L
F
.5908 .2093 m
.59201 .2093 L
.59201 .2093 L
.59 .2093 L
.5908 .2093 L
F
.59 .2093 m
.59201 .2093 L
.59201 .2093 L
.58976 .2093 L
.59 .2093 L
F
.58976 .2093 m
.59201 .2093 L
.59201 .2093 L
.59 .2093 L
.58976 .2093 L
F
.59 .2093 m
.59201 .2093 L
.59201 .2093 L
.5908 .2093 L
.59 .2093 L
F
.5908 .2093 m
.59201 .2093 L
.59201 .2093 L
.59243 .2093 L
.5908 .2093 L
F
0 g
.59243 .2093 m
.5908 .2093 L
.59 .2093 L
.58976 .2093 L
.59 .2093 L
.5908 .2093 L
.59243 .2093 L
.59201 .2093 L
.59201 .2093 L
.59201 .2093 L
.59201 .2093 L
.59201 .2093 L
.59201 .2093 L
.59201 .2093 L
.59243 .2093 L
s
.59243 .21484 m
.59201 .21484 L
.59201 .21465 L
.59243 .21465 L
.59243 .21484 L
s
.59243 .21465 m
.59201 .21465 L
.59201 .2141 L
.59243 .2141 L
.59243 .21465 L
s
.59243 .2141 m
.59201 .2141 L
.59201 .21322 L
.59243 .21322 L
.59243 .2141 L
s
.59243 .21322 m
.59201 .21322 L
.59201 .21207 L
.59243 .21207 L
.59243 .21322 L
s
.59243 .21207 m
.59201 .21207 L
.59201 .21074 L
.59243 .21074 L
.59243 .21207 L
s
.59243 .21074 m
.59201 .21074 L
.59201 .2093 L
.59243 .2093 L
.59243 .21074 L
s
.59243 .2093 m
.59201 .2093 L
.59201 .20787 L
.59243 .20787 L
.59243 .2093 L
s
.59243 .20787 m
.59201 .20787 L
.59201 .20653 L
.59243 .20653 L
.59243 .20787 L
s
.59243 .20653 m
.59201 .20653 L
.59201 .20539 L
.59243 .20539 L
.59243 .20653 L
s
.59243 .20539 m
.59201 .20539 L
.59201 .20451 L
.59243 .20451 L
.59243 .20539 L
s
.59243 .20451 m
.59201 .20451 L
.59201 .20395 L
.59243 .20395 L
.59243 .20451 L
s
.59243 .20395 m
.59201 .20395 L
.59201 .20377 L
.59243 .20377 L
.59243 .20395 L
s
.59243 .20377 m
.59201 .20377 L
.59201 .20395 L
.59243 .20395 L
.59243 .20377 L
s
.59243 .20395 m
.59201 .20395 L
.59201 .20451 L
.59243 .20451 L
.59243 .20395 L
s
.59243 .20451 m
.59201 .20451 L
.59201 .20539 L
.59243 .20539 L
.59243 .20451 L
s
.59243 .20539 m
.59201 .20539 L
.59201 .20653 L
.59243 .20653 L
.59243 .20539 L
s
.59243 .20653 m
.59201 .20653 L
.59201 .20787 L
.59243 .20787 L
.59243 .20653 L
s
.59243 .20787 m
.59201 .20787 L
.59201 .2093 L
.59243 .2093 L
.59243 .20787 L
s
.59243 .2093 m
.59201 .2093 L
.59201 .21074 L
.59243 .21074 L
.59243 .2093 L
s
.59243 .21074 m
.59201 .21074 L
.59201 .21207 L
.59243 .21207 L
.59243 .21074 L
s
.59243 .21207 m
.59201 .21207 L
.59201 .21322 L
.59243 .21322 L
.59243 .21207 L
s
.59243 .21322 m
.59201 .21322 L
.59201 .2141 L
.59243 .2141 L
.59243 .21322 L
s
.59243 .2141 m
.59201 .2141 L
.59201 .21465 L
.59243 .21465 L
.59243 .2141 L
s
.59243 .21465 m
.59201 .21465 L
.59201 .21484 L
.59243 .21484 L
.59243 .21465 L
s
.5 g
.64923 .19823 m
.65118 .19823 L
.65233 .20192 L
.64993 .20192 L
.64923 .19823 L
F
.64993 .20192 m
.65233 .20192 L
.65299 .20561 L
.65034 .20561 L
.64993 .20192 L
F
.65034 .20561 m
.65299 .20561 L
.65321 .2093 L
.65048 .2093 L
.65034 .20561 L
F
.65048 .2093 m
.65321 .2093 L
.65299 .21299 L
.65034 .21299 L
.65048 .2093 L
F
.65034 .21299 m
.65299 .21299 L
.65233 .21669 L
.64993 .21669 L
.65034 .21299 L
F
.64993 .21669 m
.65233 .21669 L
.65118 .22038 L
.64923 .22038 L
.64993 .21669 L
F
0 g
.64923 .19823 m
.64993 .20192 L
.65034 .20561 L
.65048 .2093 L
.65034 .21299 L
.64993 .21669 L
.64923 .22038 L
.65118 .22038 L
.65233 .21669 L
.65299 .21299 L
.65321 .2093 L
.65299 .20561 L
.65233 .20192 L
.65118 .19823 L
.64923 .19823 L
s
.5 g
.64923 .2093 m
.65118 .2093 L
.65233 .2093 L
.64993 .2093 L
.64923 .2093 L
F
.64993 .2093 m
.65233 .2093 L
.65299 .2093 L
.65034 .2093 L
.64993 .2093 L
F
.65034 .2093 m
.65299 .2093 L
.65321 .2093 L
.65048 .2093 L
.65034 .2093 L
F
.65048 .2093 m
.65321 .2093 L
.65299 .2093 L
.65034 .2093 L
.65048 .2093 L
F
.65034 .2093 m
.65299 .2093 L
.65233 .2093 L
.64993 .2093 L
.65034 .2093 L
F
.64993 .2093 m
.65233 .2093 L
.65118 .2093 L
.64923 .2093 L
.64993 .2093 L
F
0 g
.64923 .2093 m
.64993 .2093 L
.65034 .2093 L
.65048 .2093 L
.65034 .2093 L
.64993 .2093 L
.64923 .2093 L
.65118 .2093 L
.65233 .2093 L
.65299 .2093 L
.65321 .2093 L
.65299 .2093 L
.65233 .2093 L
.65118 .2093 L
.64923 .2093 L
s
.64923 .22038 m
.65118 .22038 L
.65118 .22 L
.64923 .22 L
.64923 .22038 L
s
.64923 .22 m
.65118 .22 L
.65118 .21889 L
.64923 .21889 L
.64923 .22 L
s
.64923 .21889 m
.65118 .21889 L
.65118 .21713 L
.64923 .21713 L
.64923 .21889 L
s
.64923 .21713 m
.65118 .21713 L
.65118 .21484 L
.64923 .21484 L
.64923 .21713 L
s
.64923 .21484 m
.65118 .21484 L
.65118 .21217 L
.64923 .21217 L
.64923 .21484 L
s
.64923 .21217 m
.65118 .21217 L
.65118 .2093 L
.64923 .2093 L
.64923 .21217 L
s
.64923 .2093 m
.65118 .2093 L
.65118 .20644 L
.64923 .20644 L
.64923 .2093 L
s
.64923 .20644 m
.65118 .20644 L
.65118 .20377 L
.64923 .20377 L
.64923 .20644 L
s
.64923 .20377 m
.65118 .20377 L
.65118 .20147 L
.64923 .20147 L
.64923 .20377 L
s
.64923 .20147 m
.65118 .20147 L
.65118 .19971 L
.64923 .19971 L
.64923 .20147 L
s
.64923 .19971 m
.65118 .19971 L
.65118 .19861 L
.64923 .19861 L
.64923 .19971 L
s
.64923 .19861 m
.65118 .19861 L
.65118 .19823 L
.64923 .19823 L
.64923 .19861 L
s
.64923 .19823 m
.65118 .19823 L
.65118 .19861 L
.64923 .19861 L
.64923 .19823 L
s
.64923 .19861 m
.65118 .19861 L
.65118 .19971 L
.64923 .19971 L
.64923 .19861 L
s
.64923 .19971 m
.65118 .19971 L
.65118 .20147 L
.64923 .20147 L
.64923 .19971 L
s
.64923 .20147 m
.65118 .20147 L
.65118 .20377 L
.64923 .20377 L
.64923 .20147 L
s
.64923 .20377 m
.65118 .20377 L
.65118 .20644 L
.64923 .20644 L
.64923 .20377 L
s
.64923 .20644 m
.65118 .20644 L
.65118 .2093 L
.64923 .2093 L
.64923 .20644 L
s
.64923 .2093 m
.65118 .2093 L
.65118 .21217 L
.64923 .21217 L
.64923 .2093 L
s
.64923 .21217 m
.65118 .21217 L
.65118 .21484 L
.64923 .21484 L
.64923 .21217 L
s
.64923 .21484 m
.65118 .21484 L
.65118 .21713 L
.64923 .21713 L
.64923 .21484 L
s
.64923 .21713 m
.65118 .21713 L
.65118 .21889 L
.64923 .21889 L
.64923 .21713 L
s
.64923 .21889 m
.65118 .21889 L
.65118 .22 L
.64923 .22 L
.64923 .21889 L
s
.64923 .22 m
.65118 .22 L
.65118 .22038 L
.64923 .22038 L
.64923 .22 L
s
.5 g
.65505 .19823 m
.65772 .19823 L
.65703 .20192 L
.65455 .20192 L
.65505 .19823 L
F
.65455 .20192 m
.65703 .20192 L
.65662 .20561 L
.65425 .20561 L
.65455 .20192 L
F
.65425 .20561 m
.65662 .20561 L
.65649 .2093 L
.65415 .2093 L
.65425 .20561 L
F
.65415 .2093 m
.65649 .2093 L
.65662 .21299 L
.65425 .21299 L
.65415 .2093 L
F
.65425 .21299 m
.65662 .21299 L
.65703 .21669 L
.65455 .21669 L
.65425 .21299 L
F
.65455 .21669 m
.65703 .21669 L
.65772 .22038 L
.65505 .22038 L
.65455 .21669 L
F
0 g
.65505 .19823 m
.65455 .20192 L
.65425 .20561 L
.65415 .2093 L
.65425 .21299 L
.65455 .21669 L
.65505 .22038 L
.65772 .22038 L
.65703 .21669 L
.65662 .21299 L
.65649 .2093 L
.65662 .20561 L
.65703 .20192 L
.65772 .19823 L
.65505 .19823 L
s
.5 g
.65505 .2093 m
.65772 .2093 L
.65703 .2093 L
.65455 .2093 L
.65505 .2093 L
F
.65455 .2093 m
.65703 .2093 L
.65662 .2093 L
.65425 .2093 L
.65455 .2093 L
F
.65425 .2093 m
.65662 .2093 L
.65649 .2093 L
.65415 .2093 L
.65425 .2093 L
F
.65415 .2093 m
.65649 .2093 L
.65662 .2093 L
.65425 .2093 L
.65415 .2093 L
F
.65425 .2093 m
.65662 .2093 L
.65703 .2093 L
.65455 .2093 L
.65425 .2093 L
F
.65455 .2093 m
.65703 .2093 L
.65772 .2093 L
.65505 .2093 L
.65455 .2093 L
F
0 g
.65505 .2093 m
.65455 .2093 L
.65425 .2093 L
.65415 .2093 L
.65425 .2093 L
.65455 .2093 L
.65505 .2093 L
.65772 .2093 L
.65703 .2093 L
.65662 .2093 L
.65649 .2093 L
.65662 .2093 L
.65703 .2093 L
.65772 .2093 L
.65505 .2093 L
s
.65505 .22038 m
.65772 .22038 L
.65772 .22 L
.65505 .22 L
.65505 .22038 L
s
.65505 .22 m
.65772 .22 L
.65772 .21889 L
.65505 .21889 L
.65505 .22 L
s
.65505 .21889 m
.65772 .21889 L
.65772 .21713 L
.65505 .21713 L
.65505 .21889 L
s
.65505 .21713 m
.65772 .21713 L
.65772 .21484 L
.65505 .21484 L
.65505 .21713 L
s
.65505 .21484 m
.65772 .21484 L
.65772 .21217 L
.65505 .21217 L
.65505 .21484 L
s
.65505 .21217 m
.65772 .21217 L
.65772 .2093 L
.65505 .2093 L
.65505 .21217 L
s
.65505 .2093 m
.65772 .2093 L
.65772 .20644 L
.65505 .20644 L
.65505 .2093 L
s
.65505 .20644 m
.65772 .20644 L
.65772 .20377 L
.65505 .20377 L
.65505 .20644 L
s
.65505 .20377 m
.65772 .20377 L
.65772 .20147 L
.65505 .20147 L
.65505 .20377 L
s
.65505 .20147 m
.65772 .20147 L
.65772 .19971 L
.65505 .19971 L
.65505 .20147 L
s
.65505 .19971 m
.65772 .19971 L
.65772 .19861 L
.65505 .19861 L
.65505 .19971 L
s
.65505 .19861 m
.65772 .19861 L
.65772 .19823 L
.65505 .19823 L
.65505 .19861 L
s
.65505 .19823 m
.65772 .19823 L
.65772 .19861 L
.65505 .19861 L
.65505 .19823 L
s
.65505 .19861 m
.65772 .19861 L
.65772 .19971 L
.65505 .19971 L
.65505 .19861 L
s
.65505 .19971 m
.65772 .19971 L
.65772 .20147 L
.65505 .20147 L
.65505 .19971 L
s
.65505 .20147 m
.65772 .20147 L
.65772 .20377 L
.65505 .20377 L
.65505 .20147 L
s
.65505 .20377 m
.65772 .20377 L
.65772 .20644 L
.65505 .20644 L
.65505 .20377 L
s
.65505 .20644 m
.65772 .20644 L
.65772 .2093 L
.65505 .2093 L
.65505 .20644 L
s
.65505 .2093 m
.65772 .2093 L
.65772 .21217 L
.65505 .21217 L
.65505 .2093 L
s
.65505 .21217 m
.65772 .21217 L
.65772 .21484 L
.65505 .21484 L
.65505 .21217 L
s
.65505 .21484 m
.65772 .21484 L
.65772 .21713 L
.65505 .21713 L
.65505 .21484 L
s
.65505 .21713 m
.65772 .21713 L
.65772 .21889 L
.65505 .21889 L
.65505 .21713 L
s
.65505 .21889 m
.65772 .21889 L
.65772 .22 L
.65505 .22 L
.65505 .21889 L
s
.65505 .22 m
.65772 .22 L
.65772 .22038 L
.65505 .22038 L
.65505 .22 L
s
.5 g
.65757 .19823 m
.66047 .19823 L
.66139 .20192 L
.65739 .20192 L
.65757 .19823 L
F
.65739 .20192 m
.66139 .20192 L
.66192 .20561 L
.65729 .20561 L
.65739 .20192 L
F
.65729 .20561 m
.66192 .20561 L
.6621 .2093 L
.65725 .2093 L
.65729 .20561 L
F
.65725 .2093 m
.6621 .2093 L
.66192 .21299 L
.65729 .21299 L
.65725 .2093 L
F
.65729 .21299 m
.66192 .21299 L
.66139 .21669 L
.65739 .21669 L
.65729 .21299 L
F
.65739 .21669 m
.66139 .21669 L
.66047 .22038 L
.65757 .22038 L
.65739 .21669 L
F
0 g
.65757 .19823 m
.65739 .20192 L
.65729 .20561 L
.65725 .2093 L
.65729 .21299 L
.65739 .21669 L
.65757 .22038 L
.66047 .22038 L
.66139 .21669 L
.66192 .21299 L
.6621 .2093 L
.66192 .20561 L
.66139 .20192 L
.66047 .19823 L
.65757 .19823 L
s
.5 g
.65757 .2093 m
.66047 .2093 L
.66139 .2093 L
.65739 .2093 L
.65757 .2093 L
F
.65739 .2093 m
.66139 .2093 L
.66192 .2093 L
.65729 .2093 L
.65739 .2093 L
F
.65729 .2093 m
.66192 .2093 L
.6621 .2093 L
.65725 .2093 L
.65729 .2093 L
F
.65725 .2093 m
.6621 .2093 L
.66192 .2093 L
.65729 .2093 L
.65725 .2093 L
F
.65729 .2093 m
.66192 .2093 L
.66139 .2093 L
.65739 .2093 L
.65729 .2093 L
F
.65739 .2093 m
.66139 .2093 L
.66047 .2093 L
.65757 .2093 L
.65739 .2093 L
F
0 g
.65757 .2093 m
.65739 .2093 L
.65729 .2093 L
.65725 .2093 L
.65729 .2093 L
.65739 .2093 L
.65757 .2093 L
.66047 .2093 L
.66139 .2093 L
.66192 .2093 L
.6621 .2093 L
.66192 .2093 L
.66139 .2093 L
.66047 .2093 L
.65757 .2093 L
s
.65757 .22038 m
.66047 .22038 L
.66047 .22 L
.65757 .22 L
.65757 .22038 L
s
.65757 .22 m
.66047 .22 L
.66047 .21889 L
.65757 .21889 L
.65757 .22 L
s
.65757 .21889 m
.66047 .21889 L
.66047 .21713 L
.65757 .21713 L
.65757 .21889 L
s
.65757 .21713 m
.66047 .21713 L
.66047 .21484 L
.65757 .21484 L
.65757 .21713 L
s
.65757 .21484 m
.66047 .21484 L
.66047 .21217 L
.65757 .21217 L
.65757 .21484 L
s
.65757 .21217 m
.66047 .21217 L
.66047 .2093 L
.65757 .2093 L
.65757 .21217 L
s
.65757 .2093 m
.66047 .2093 L
.66047 .20644 L
.65757 .20644 L
.65757 .2093 L
s
.65757 .20644 m
.66047 .20644 L
.66047 .20377 L
.65757 .20377 L
.65757 .20644 L
s
.65757 .20377 m
.66047 .20377 L
.66047 .20147 L
.65757 .20147 L
.65757 .20377 L
s
.65757 .20147 m
.66047 .20147 L
.66047 .19971 L
.65757 .19971 L
.65757 .20147 L
s
.65757 .19971 m
.66047 .19971 L
.66047 .19861 L
.65757 .19861 L
.65757 .19971 L
s
.65757 .19861 m
.66047 .19861 L
.66047 .19823 L
.65757 .19823 L
.65757 .19861 L
s
.65757 .19823 m
.66047 .19823 L
.66047 .19861 L
.65757 .19861 L
.65757 .19823 L
s
.65757 .19861 m
.66047 .19861 L
.66047 .19971 L
.65757 .19971 L
.65757 .19861 L
s
.65757 .19971 m
.66047 .19971 L
.66047 .20147 L
.65757 .20147 L
.65757 .19971 L
s
.65757 .20147 m
.66047 .20147 L
.66047 .20377 L
.65757 .20377 L
.65757 .20147 L
s
.65757 .20377 m
.66047 .20377 L
.66047 .20644 L
.65757 .20644 L
.65757 .20377 L
s
.65757 .20644 m
.66047 .20644 L
.66047 .2093 L
.65757 .2093 L
.65757 .20644 L
s
.65757 .2093 m
.66047 .2093 L
.66047 .21217 L
.65757 .21217 L
.65757 .2093 L
s
.65757 .21217 m
.66047 .21217 L
.66047 .21484 L
.65757 .21484 L
.65757 .21217 L
s
.65757 .21484 m
.66047 .21484 L
.66047 .21713 L
.65757 .21713 L
.65757 .21484 L
s
.65757 .21713 m
.66047 .21713 L
.66047 .21889 L
.65757 .21889 L
.65757 .21713 L
s
.65757 .21889 m
.66047 .21889 L
.66047 .22 L
.65757 .22 L
.65757 .21889 L
s
.65757 .22 m
.66047 .22 L
.66047 .22038 L
.65757 .22038 L
.65757 .22 L
s
.5 g
.732 .19492 m
.732 .19492 L
.72923 .19971 L
.72923 .19971 L
.732 .19492 L
F
.72923 .19971 m
.72923 .19971 L
.72646 .20451 L
.72646 .20451 L
.72923 .19971 L
F
.72646 .20451 m
.72646 .20451 L
.7237 .2093 L
.7237 .2093 L
.72646 .20451 L
F
.7237 .2093 m
.7237 .2093 L
.72093 .2141 L
.72093 .2141 L
.7237 .2093 L
F
.72093 .2141 m
.72093 .2141 L
.71816 .21889 L
.71816 .21889 L
.72093 .2141 L
F
.71816 .21889 m
.71816 .21889 L
.71539 .22369 L
.71539 .22369 L
.71816 .21889 L
F
0 g
.732 .19492 m
.72923 .19971 L
.72646 .20451 L
.7237 .2093 L
.72093 .2141 L
.71816 .21889 L
.71539 .22369 L
.71539 .22369 L
.71816 .21889 L
.72093 .2141 L
.7237 .2093 L
.72646 .20451 L
.72923 .19971 L
.732 .19492 L
.732 .19492 L
s
.5 g
.7237 .2093 m
.7237 .2093 L
.7237 .2093 L
.7237 .2093 L
.7237 .2093 L
F
.7237 .2093 m
.7237 .2093 L
.7237 .2093 L
.7237 .2093 L
.7237 .2093 L
F
.7237 .2093 m
.7237 .2093 L
.7237 .2093 L
.7237 .2093 L
.7237 .2093 L
F
.7237 .2093 m
.7237 .2093 L
.7237 .2093 L
.7237 .2093 L
.7237 .2093 L
F
.7237 .2093 m
.7237 .2093 L
.7237 .2093 L
.7237 .2093 L
.7237 .2093 L
F
.7237 .2093 m
.7237 .2093 L
.7237 .2093 L
.7237 .2093 L
.7237 .2093 L
F
0 g
.7237 .2093 m
.7237 .2093 L
.7237 .2093 L
.7237 .2093 L
.7237 .2093 L
.7237 .2093 L
.7237 .2093 L
.7237 .2093 L
.7237 .2093 L
.7237 .2093 L
.7237 .2093 L
.7237 .2093 L
.7237 .2093 L
.7237 .2093 L
.7237 .2093 L
s
.71539 .22369 m
.71567 .2232 L
.7165 .22176 L
.71782 .21947 L
.71954 .2165 L
.72155 .21303 L
.7237 .2093 L
.72584 .20558 L
.72785 .20211 L
.72957 .19913 L
.73089 .19684 L
.73172 .19541 L
.732 .19492 L
.73172 .19541 L
.73089 .19684 L
.72957 .19913 L
.72785 .20211 L
.72584 .20558 L
.7237 .2093 L
.72155 .21303 L
.71954 .2165 L
.71782 .21947 L
.7165 .22176 L
.71567 .2232 L
.71539 .22369 L
s
.5 g
.79845 .19492 m
.79845 .19492 L
.79568 .19971 L
.79568 .19971 L
.79845 .19492 L
F
.79568 .19971 m
.79568 .19971 L
.79291 .20451 L
.79291 .20451 L
.79568 .19971 L
F
.79291 .20451 m
.79291 .20451 L
.79014 .2093 L
.79014 .2093 L
.79291 .20451 L
F
.79014 .2093 m
.79014 .2093 L
.78737 .2141 L
.78737 .2141 L
.79014 .2093 L
F
.78737 .2141 m
.78737 .2141 L
.7846 .21889 L
.7846 .21889 L
.78737 .2141 L
F
.7846 .21889 m
.7846 .21889 L
.78183 .22369 L
.78183 .22369 L
.7846 .21889 L
F
0 g
.79845 .19492 m
.79568 .19971 L
.79291 .20451 L
.79014 .2093 L
.78737 .2141 L
.7846 .21889 L
.78183 .22369 L
.78183 .22369 L
.7846 .21889 L
.78737 .2141 L
.79014 .2093 L
.79291 .20451 L
.79568 .19971 L
.79845 .19492 L
.79845 .19492 L
s
.5 g
.79014 .2093 m
.79014 .2093 L
.79014 .2093 L
.79014 .2093 L
.79014 .2093 L
F
.79014 .2093 m
.79014 .2093 L
.79014 .2093 L
.79014 .2093 L
.79014 .2093 L
F
.79014 .2093 m
.79014 .2093 L
.79014 .2093 L
.79014 .2093 L
.79014 .2093 L
F
.79014 .2093 m
.79014 .2093 L
.79014 .2093 L
.79014 .2093 L
.79014 .2093 L
F
.79014 .2093 m
.79014 .2093 L
.79014 .2093 L
.79014 .2093 L
.79014 .2093 L
F
.79014 .2093 m
.79014 .2093 L
.79014 .2093 L
.79014 .2093 L
.79014 .2093 L
F
0 g
.79014 .2093 m
.79014 .2093 L
.79014 .2093 L
.79014 .2093 L
.79014 .2093 L
.79014 .2093 L
.79014 .2093 L
.79014 .2093 L
.79014 .2093 L
.79014 .2093 L
.79014 .2093 L
.79014 .2093 L
.79014 .2093 L
.79014 .2093 L
.79014 .2093 L
s
.78183 .22369 m
.78212 .2232 L
.78295 .22176 L
.78427 .21947 L
.78599 .2165 L
.78799 .21303 L
.79014 .2093 L
.79229 .20558 L
.79429 .20211 L
.79601 .19913 L
.79733 .19684 L
.79816 .19541 L
.79845 .19492 L
.79816 .19541 L
.79733 .19684 L
.79601 .19913 L
.79429 .20211 L
.79229 .20558 L
.79014 .2093 L
.78799 .21303 L
.78599 .2165 L
.78427 .21947 L
.78295 .22176 L
.78212 .2232 L
.78183 .22369 L
s
.5 g
.69364 .12847 m
.69364 .12847 L
.69087 .13327 L
.69087 .13327 L
.69364 .12847 L
F
.69087 .13327 m
.69087 .13327 L
.6881 .13806 L
.6881 .13806 L
.69087 .13327 L
F
.6881 .13806 m
.6881 .13806 L
.68533 .14286 L
.68533 .14286 L
.6881 .13806 L
F
.68533 .14286 m
.68533 .14286 L
.68256 .14765 L
.68256 .14765 L
.68533 .14286 L
F
.68256 .14765 m
.68256 .14765 L
.6798 .15245 L
.6798 .15245 L
.68256 .14765 L
F
.6798 .15245 m
.6798 .15245 L
.67703 .15724 L
.67703 .15724 L
.6798 .15245 L
F
0 g
.69364 .12847 m
.69087 .13327 L
.6881 .13806 L
.68533 .14286 L
.68256 .14765 L
.6798 .15245 L
.67703 .15724 L
.67703 .15724 L
.6798 .15245 L
.68256 .14765 L
.68533 .14286 L
.6881 .13806 L
.69087 .13327 L
.69364 .12847 L
.69364 .12847 L
s
.5 g
.68533 .14286 m
.68533 .14286 L
.68533 .14286 L
.68533 .14286 L
.68533 .14286 L
F
.68533 .14286 m
.68533 .14286 L
.68533 .14286 L
.68533 .14286 L
.68533 .14286 L
F
.68533 .14286 m
.68533 .14286 L
.68533 .14286 L
.68533 .14286 L
.68533 .14286 L
F
.68533 .14286 m
.68533 .14286 L
.68533 .14286 L
.68533 .14286 L
.68533 .14286 L
F
.68533 .14286 m
.68533 .14286 L
.68533 .14286 L
.68533 .14286 L
.68533 .14286 L
F
.68533 .14286 m
.68533 .14286 L
.68533 .14286 L
.68533 .14286 L
.68533 .14286 L
F
0 g
.68533 .14286 m
.68533 .14286 L
.68533 .14286 L
.68533 .14286 L
.68533 .14286 L
.68533 .14286 L
.68533 .14286 L
.68533 .14286 L
.68533 .14286 L
.68533 .14286 L
.68533 .14286 L
.68533 .14286 L
.68533 .14286 L
.68533 .14286 L
.68533 .14286 L
s
.67703 .15724 m
.67731 .15675 L
.67814 .15532 L
.67946 .15303 L
.68118 .15005 L
.68318 .14658 L
.68533 .14286 L
.68748 .13913 L
.68949 .13566 L
.69121 .13268 L
.69253 .1304 L
.69336 .12896 L
.69364 .12847 L
.69336 .12896 L
.69253 .1304 L
.69121 .13268 L
.68949 .13566 L
.68748 .13913 L
.68533 .14286 L
.68318 .14658 L
.68118 .15005 L
.67946 .15303 L
.67814 .15532 L
.67731 .15675 L
.67703 .15724 L
s
.5 g
.87664 .19823 m
.87696 .19823 L
.87696 .20192 L
.87505 .20192 L
.87664 .19823 L
F
.87505 .20192 m
.87696 .20192 L
.87696 .20561 L
.87415 .20561 L
.87505 .20192 L
F
.87415 .20561 m
.87696 .20561 L
.87696 .2093 L
.87386 .2093 L
.87415 .20561 L
F
.87386 .2093 m
.87696 .2093 L
.87696 .21299 L
.87415 .21299 L
.87386 .2093 L
F
.87415 .21299 m
.87696 .21299 L
.87696 .21669 L
.87505 .21669 L
.87415 .21299 L
F
.87505 .21669 m
.87696 .21669 L
.87696 .22038 L
.87664 .22038 L
.87505 .21669 L
F
0 g
.87664 .19823 m
.87505 .20192 L
.87415 .20561 L
.87386 .2093 L
.87415 .21299 L
.87505 .21669 L
.87664 .22038 L
.87696 .22038 L
.87696 .21669 L
.87696 .21299 L
.87696 .2093 L
.87696 .20561 L
.87696 .20192 L
.87696 .19823 L
.87664 .19823 L
s
.5 g
.87664 .2093 m
.87696 .2093 L
.87696 .2093 L
.87505 .2093 L
.87664 .2093 L
F
.87505 .2093 m
.87696 .2093 L
.87696 .2093 L
.87415 .2093 L
.87505 .2093 L
F
.87415 .2093 m
.87696 .2093 L
.87696 .2093 L
.87386 .2093 L
.87415 .2093 L
F
.87386 .2093 m
.87696 .2093 L
.87696 .2093 L
.87415 .2093 L
.87386 .2093 L
F
.87415 .2093 m
.87696 .2093 L
.87696 .2093 L
.87505 .2093 L
.87415 .2093 L
F
.87505 .2093 m
.87696 .2093 L
.87696 .2093 L
.87664 .2093 L
.87505 .2093 L
F
0 g
.87664 .2093 m
.87505 .2093 L
.87415 .2093 L
.87386 .2093 L
.87415 .2093 L
.87505 .2093 L
.87664 .2093 L
.87696 .2093 L
.87696 .2093 L
.87696 .2093 L
.87696 .2093 L
.87696 .2093 L
.87696 .2093 L
.87696 .2093 L
.87664 .2093 L
s
.87664 .22038 m
.87696 .22038 L
.87696 .22 L
.87664 .22 L
.87664 .22038 L
s
.87664 .22 m
.87696 .22 L
.87696 .21889 L
.87664 .21889 L
.87664 .22 L
s
.87664 .21889 m
.87696 .21889 L
.87696 .21713 L
.87664 .21713 L
.87664 .21889 L
s
.87664 .21713 m
.87696 .21713 L
.87696 .21484 L
.87664 .21484 L
.87664 .21713 L
s
.87664 .21484 m
.87696 .21484 L
.87696 .21217 L
.87664 .21217 L
.87664 .21484 L
s
.87664 .21217 m
.87696 .21217 L
.87696 .2093 L
.87664 .2093 L
.87664 .21217 L
s
.87664 .2093 m
.87696 .2093 L
.87696 .20644 L
.87664 .20644 L
.87664 .2093 L
s
.87664 .20644 m
.87696 .20644 L
.87696 .20377 L
.87664 .20377 L
.87664 .20644 L
s
.87664 .20377 m
.87696 .20377 L
.87696 .20147 L
.87664 .20147 L
.87664 .20377 L
s
.87664 .20147 m
.87696 .20147 L
.87696 .19971 L
.87664 .19971 L
.87664 .20147 L
s
.87664 .19971 m
.87696 .19971 L
.87696 .19861 L
.87664 .19861 L
.87664 .19971 L
s
.87664 .19861 m
.87696 .19861 L
.87696 .19823 L
.87664 .19823 L
.87664 .19861 L
s
.87664 .19823 m
.87696 .19823 L
.87696 .19861 L
.87664 .19861 L
.87664 .19823 L
s
.87664 .19861 m
.87696 .19861 L
.87696 .19971 L
.87664 .19971 L
.87664 .19861 L
s
.87664 .19971 m
.87696 .19971 L
.87696 .20147 L
.87664 .20147 L
.87664 .19971 L
s
.87664 .20147 m
.87696 .20147 L
.87696 .20377 L
.87664 .20377 L
.87664 .20147 L
s
.87664 .20377 m
.87696 .20377 L
.87696 .20644 L
.87664 .20644 L
.87664 .20377 L
s
.87664 .20644 m
.87696 .20644 L
.87696 .2093 L
.87664 .2093 L
.87664 .20644 L
s
.87664 .2093 m
.87696 .2093 L
.87696 .21217 L
.87664 .21217 L
.87664 .2093 L
s
.87664 .21217 m
.87696 .21217 L
.87696 .21484 L
.87664 .21484 L
.87664 .21217 L
s
.87664 .21484 m
.87696 .21484 L
.87696 .21713 L
.87664 .21713 L
.87664 .21484 L
s
.87664 .21713 m
.87696 .21713 L
.87696 .21889 L
.87664 .21889 L
.87664 .21713 L
s
.87664 .21889 m
.87696 .21889 L
.87696 .22 L
.87664 .22 L
.87664 .21889 L
s
.87664 .22 m
.87696 .22 L
.87696 .22038 L
.87664 .22038 L
.87664 .22 L
s
.5 g
.77184 .13178 m
.77215 .13178 L
.77215 .13547 L
.77025 .13547 L
.77184 .13178 L
F
.77025 .13547 m
.77215 .13547 L
.77215 .13917 L
.76935 .13917 L
.77025 .13547 L
F
.76935 .13917 m
.77215 .13917 L
.77215 .14286 L
.76905 .14286 L
.76935 .13917 L
F
.76905 .14286 m
.77215 .14286 L
.77215 .14655 L
.76935 .14655 L
.76905 .14286 L
F
.76935 .14655 m
.77215 .14655 L
.77215 .15024 L
.77025 .15024 L
.76935 .14655 L
F
.77025 .15024 m
.77215 .15024 L
.77215 .15393 L
.77184 .15393 L
.77025 .15024 L
F
0 g
.77184 .13178 m
.77025 .13547 L
.76935 .13917 L
.76905 .14286 L
.76935 .14655 L
.77025 .15024 L
.77184 .15393 L
.77215 .15393 L
.77215 .15024 L
.77215 .14655 L
.77215 .14286 L
.77215 .13917 L
.77215 .13547 L
.77215 .13178 L
.77184 .13178 L
s
.5 g
.77184 .14286 m
.77215 .14286 L
.77215 .14286 L
.77025 .14286 L
.77184 .14286 L
F
.77025 .14286 m
.77215 .14286 L
.77215 .14286 L
.76935 .14286 L
.77025 .14286 L
F
.76935 .14286 m
.77215 .14286 L
.77215 .14286 L
.76905 .14286 L
.76935 .14286 L
F
.76905 .14286 m
.77215 .14286 L
.77215 .14286 L
.76935 .14286 L
.76905 .14286 L
F
.76935 .14286 m
.77215 .14286 L
.77215 .14286 L
.77025 .14286 L
.76935 .14286 L
F
.77025 .14286 m
.77215 .14286 L
.77215 .14286 L
.77184 .14286 L
.77025 .14286 L
F
0 g
.77184 .14286 m
.77025 .14286 L
.76935 .14286 L
.76905 .14286 L
.76935 .14286 L
.77025 .14286 L
.77184 .14286 L
.77215 .14286 L
.77215 .14286 L
.77215 .14286 L
.77215 .14286 L
.77215 .14286 L
.77215 .14286 L
.77215 .14286 L
.77184 .14286 L
s
.77184 .15393 m
.77215 .15393 L
.77215 .15355 L
.77184 .15355 L
.77184 .15393 L
s
.77184 .15355 m
.77215 .15355 L
.77215 .15245 L
.77184 .15245 L
.77184 .15355 L
s
.77184 .15245 m
.77215 .15245 L
.77215 .15069 L
.77184 .15069 L
.77184 .15245 L
s
.77184 .15069 m
.77215 .15069 L
.77215 .14839 L
.77184 .14839 L
.77184 .15069 L
s
.77184 .14839 m
.77215 .14839 L
.77215 .14572 L
.77184 .14572 L
.77184 .14839 L
s
.77184 .14572 m
.77215 .14572 L
.77215 .14286 L
.77184 .14286 L
.77184 .14572 L
s
.77184 .14286 m
.77215 .14286 L
.77215 .13999 L
.77184 .13999 L
.77184 .14286 L
s
.77184 .13999 m
.77215 .13999 L
.77215 .13732 L
.77184 .13732 L
.77184 .13999 L
s
.77184 .13732 m
.77215 .13732 L
.77215 .13503 L
.77184 .13503 L
.77184 .13732 L
s
.77184 .13503 m
.77215 .13503 L
.77215 .13327 L
.77184 .13327 L
.77184 .13503 L
s
.77184 .13327 m
.77215 .13327 L
.77215 .13216 L
.77184 .13216 L
.77184 .13327 L
s
.77184 .13216 m
.77215 .13216 L
.77215 .13178 L
.77184 .13178 L
.77184 .13216 L
s
.77184 .13178 m
.77215 .13178 L
.77215 .13216 L
.77184 .13216 L
.77184 .13178 L
s
.77184 .13216 m
.77215 .13216 L
.77215 .13327 L
.77184 .13327 L
.77184 .13216 L
s
.77184 .13327 m
.77215 .13327 L
.77215 .13503 L
.77184 .13503 L
.77184 .13327 L
s
.77184 .13503 m
.77215 .13503 L
.77215 .13732 L
.77184 .13732 L
.77184 .13503 L
s
.77184 .13732 m
.77215 .13732 L
.77215 .13999 L
.77184 .13999 L
.77184 .13732 L
s
.77184 .13999 m
.77215 .13999 L
.77215 .14286 L
.77184 .14286 L
.77184 .13999 L
s
.77184 .14286 m
.77215 .14286 L
.77215 .14572 L
.77184 .14572 L
.77184 .14286 L
s
.77184 .14572 m
.77215 .14572 L
.77215 .14839 L
.77184 .14839 L
.77184 .14572 L
s
.77184 .14839 m
.77215 .14839 L
.77215 .15069 L
.77184 .15069 L
.77184 .14839 L
s
.77184 .15069 m
.77215 .15069 L
.77215 .15245 L
.77184 .15245 L
.77184 .15069 L
s
.77184 .15245 m
.77215 .15245 L
.77215 .15355 L
.77184 .15355 L
.77184 .15245 L
s
.77184 .15355 m
.77215 .15355 L
.77215 .15393 L
.77184 .15393 L
.77184 .15355 L
s
.97619 .40864 m
.97619 .00997 L
.97619 .00997 L
.97619 .40864 L
.97619 .40864 L
s
.97619 .00997 m
.02381 .00997 L
.02381 .00997 L
.97619 .00997 L
.97619 .00997 L
s
.02381 .00997 m
.02381 .40864 L
.02381 .40864 L
.02381 .00997 L
.02381 .00997 L
s
.02381 .40864 m
.97619 .40864 L
.97619 .40864 L
.02381 .40864 L
.02381 .40864 L
s
.97619 .00997 m
.97619 .40864 L
.02381 .40864 L
.02381 .00997 L
.97619 .00997 L
s
.97619 .40864 m
.97619 .00997 L
.02381 .00997 L
.02381 .40864 L
.97619 .40864 L
s
0 0 1 r
.02381 .05426 m
.51262 .05426 L
s
0 0 0 r
2 Mabswid
.51262 .05426 Mdot
0 0 1 r
.5 Mabswid
.02381 .13178 m
.51931 .13178 L
s
0 0 0 r
2 Mabswid
.51931 .13178 Mdot
0 0 1 r
.5 Mabswid
.02381 .2093 m
.05703 .2093 L
s
0 0 0 r
2 Mabswid
.05703 .2093 Mdot
0 0 1 r
.5 Mabswid
.02381 .28682 m
.51931 .28682 L
s
0 0 0 r
2 Mabswid
.51931 .28682 Mdot
0 0 1 r
.5 Mabswid
.02381 .36434 m
.51262 .36434 L
s
0 0 0 r
2 Mabswid
.51262 .36434 Mdot
0 1 0 r
.5 Mabswid
.02381 .05205 m
.51237 .05205 L
s
0 0 0 r
2 Mabswid
.51237 .05205 Mdot
0 1 0 r
.5 Mabswid
.02381 .11495 m
.51824 .11495 L
s
0 0 0 r
2 Mabswid
.51824 .11495 Mdot
0 1 0 r
.5 Mabswid
.02381 .17785 m
.05703 .17785 L
s
0 0 0 r
2 Mabswid
.05703 .17785 Mdot
0 1 0 r
.5 Mabswid
.02381 .24075 m
.05703 .24075 L
s
0 0 0 r
2 Mabswid
.05703 .24075 Mdot
0 1 0 r
.5 Mabswid
.02381 .30365 m
.51824 .30365 L
s
0 0 0 r
2 Mabswid
.51824 .30365 Mdot
0 1 0 r
.5 Mabswid
.02381 .36656 m
.51237 .36656 L
s
0 0 0 r
2 Mabswid
.51237 .36656 Mdot
1 0 0 r
.5 Mabswid
.02381 .04983 m
.51211 .04983 L
s
0 0 0 r
2 Mabswid
.51211 .04983 Mdot
1 0 0 r
.5 Mabswid
.02381 .10299 m
.51735 .10299 L
s
0 0 0 r
2 Mabswid
.51735 .10299 Mdot
1 0 0 r
.5 Mabswid
.02381 .15615 m
.05703 .15615 L
s
0 0 0 r
2 Mabswid
.05703 .15615 Mdot
1 0 0 r
.5 Mabswid
.02381 .2093 m
.05703 .2093 L
s
0 0 0 r
2 Mabswid
.05703 .2093 Mdot
1 0 0 r
.5 Mabswid
.02381 .26246 m
.05703 .26246 L
s
0 0 0 r
2 Mabswid
.05703 .26246 Mdot
1 0 0 r
.5 Mabswid
.02381 .31561 m
.51735 .31561 L
s
0 0 0 r
2 Mabswid
.51735 .31561 Mdot
1 0 0 r
.5 Mabswid
.02381 .36877 m
.51211 .36877 L
s
0 0 0 r
2 Mabswid
.51211 .36877 Mdot
1 0 1 r
.5 Mabswid
.02381 .04762 m
.51184 .04762 L
s
0 0 0 r
2 Mabswid
.51184 .04762 Mdot
1 0 1 r
.5 Mabswid
.02381 .09381 m
.51659 .09381 L
s
0 0 0 r
2 Mabswid
.51659 .09381 Mdot
1 0 1 r
.5 Mabswid
.02381 .14001 m
.51976 .14001 L
s
0 0 0 r
2 Mabswid
.51976 .14001 Mdot
1 0 1 r
.5 Mabswid
.02381 .1862 m
.05703 .1862 L
s
0 0 0 r
2 Mabswid
.05703 .1862 Mdot
1 0 1 r
.5 Mabswid
.02381 .2324 m
.05703 .2324 L
s
0 0 0 r
2 Mabswid
.05703 .2324 Mdot
1 0 1 r
.5 Mabswid
.02381 .2786 m
.51976 .2786 L
s
0 0 0 r
2 Mabswid
.51976 .2786 Mdot
1 0 1 r
.5 Mabswid
.02381 .32479 m
.51659 .32479 L
s
0 0 0 r
2 Mabswid
.51659 .32479 Mdot
1 0 1 r
.5 Mabswid
.02381 .37099 m
.51184 .37099 L
s
0 0 0 r
2 Mabswid
.51184 .37099 Mdot
0 0 1 r
.5 Mabswid
.51262 .05426 m
.06641 .15826 L
s
0 0 0 r
2 Mabswid
.06641 .15826 Mdot
0 0 1 r
.5 Mabswid
.51931 .13178 m
.06769 .18383 L
s
0 0 0 r
2 Mabswid
.06769 .18383 Mdot
0 0 1 r
.5 Mabswid
.05703 .2093 m
.02381 .2093 L
s
0 0 0 r
2 Mabswid
.02381 .2093 Mdot
0 0 1 r
.5 Mabswid
.51931 .28682 m
.06769 .23477 L
s
0 0 0 r
2 Mabswid
.06769 .23477 Mdot
0 0 1 r
.5 Mabswid
.51262 .36434 m
.06641 .26035 L
s
0 0 0 r
2 Mabswid
.06641 .26035 Mdot
0 1 0 r
.5 Mabswid
.51237 .05205 m
.06637 .15752 L
s
0 0 0 r
2 Mabswid
.06637 .15752 Mdot
0 1 0 r
.5 Mabswid
.51824 .11495 m
.06748 .17829 L
s
0 0 0 r
2 Mabswid
.06748 .17829 Mdot
0 1 0 r
.5 Mabswid
.05703 .17785 m
.02381 .17785 L
s
0 0 0 r
2 Mabswid
.02381 .17785 Mdot
0 1 0 r
.5 Mabswid
.05703 .24075 m
.02381 .24075 L
s
0 0 0 r
2 Mabswid
.02381 .24075 Mdot
0 1 0 r
.5 Mabswid
.51824 .30365 m
.06748 .24031 L
s
0 0 0 r
2 Mabswid
.06748 .24031 Mdot
0 1 0 r
.5 Mabswid
.51237 .36656 m
.06637 .26108 L
s
0 0 0 r
2 Mabswid
.06637 .26108 Mdot
1 0 0 r
.5 Mabswid
.51211 .04983 m
.06632 .15679 L
s
0 0 0 r
2 Mabswid
.06632 .15679 Mdot
1 0 0 r
.5 Mabswid
.51735 .10299 m
.06731 .17435 L
s
0 0 0 r
2 Mabswid
.06731 .17435 Mdot
1 0 0 r
.5 Mabswid
.05703 .15615 m
.02381 .15615 L
s
0 0 0 r
2 Mabswid
.02381 .15615 Mdot
1 0 0 r
.5 Mabswid
.05703 .2093 m
.02381 .2093 L
s
0 0 0 r
2 Mabswid
.02381 .2093 Mdot
1 0 0 r
.5 Mabswid
.05703 .26246 m
.02381 .26246 L
s
0 0 0 r
2 Mabswid
.02381 .26246 Mdot
1 0 0 r
.5 Mabswid
.51735 .31561 m
.06731 .24425 L
s
0 0 0 r
2 Mabswid
.06731 .24425 Mdot
1 0 0 r
.5 Mabswid
.51211 .36877 m
.06632 .26182 L
s
0 0 0 r
2 Mabswid
.06632 .26182 Mdot
1 0 1 r
.5 Mabswid
.51184 .04762 m
.06626 .15606 L
s
0 0 0 r
2 Mabswid
.06626 .15606 Mdot
1 0 1 r
.5 Mabswid
.51659 .09381 m
.06717 .17133 L
s
0 0 0 r
2 Mabswid
.06717 .17133 Mdot
1 0 1 r
.5 Mabswid
.51976 .14001 m
.06777 .18654 L
s
0 0 0 r
2 Mabswid
.06777 .18654 Mdot
1 0 1 r
.5 Mabswid
.05703 .1862 m
.02381 .1862 L
s
0 0 0 r
2 Mabswid
.02381 .1862 Mdot
1 0 1 r
.5 Mabswid
.05703 .2324 m
.02381 .2324 L
s
0 0 0 r
2 Mabswid
.02381 .2324 Mdot
1 0 1 r
.5 Mabswid
.51976 .2786 m
.06777 .23206 L
s
0 0 0 r
2 Mabswid
.06777 .23206 Mdot
1 0 1 r
.5 Mabswid
.51659 .32479 m
.06717 .24728 L
s
0 0 0 r
2 Mabswid
.06717 .24728 Mdot
1 0 1 r
.5 Mabswid
.51184 .37099 m
.06626 .26255 L
s
0 0 0 r
2 Mabswid
.06626 .26255 Mdot
0 0 1 r
.5 Mabswid
.06641 .15826 m
.52152 .20228 L
s
0 0 0 r
2 Mabswid
.52152 .20228 Mdot
0 0 1 r
.5 Mabswid
.06769 .18383 m
.52153 .20593 L
s
0 0 0 r
2 Mabswid
.52153 .20593 Mdot
0 0 1 r
.5 Mabswid
.06769 .23477 m
.52153 .21267 L
s
0 0 0 r
2 Mabswid
.52153 .21267 Mdot
0 0 1 r
.5 Mabswid
.06641 .26035 m
.52152 .21633 L
s
0 0 0 r
2 Mabswid
.52152 .21633 Mdot
0 1 0 r
.5 Mabswid
.06637 .15752 m
.52152 .20216 L
s
0 0 0 r
2 Mabswid
.52152 .20216 Mdot
0 1 0 r
.5 Mabswid
.06748 .17829 m
.52153 .20517 L
s
0 0 0 r
2 Mabswid
.52153 .20517 Mdot
0 1 0 r
.5 Mabswid
.06748 .24031 m
.52153 .21343 L
s
0 0 0 r
2 Mabswid
.52153 .21343 Mdot
0 1 0 r
.5 Mabswid
.06637 .26108 m
.52152 .21644 L
s
0 0 0 r
2 Mabswid
.52152 .21644 Mdot
1 0 0 r
.5 Mabswid
.06632 .15679 m
.52152 .20205 L
s
0 0 0 r
2 Mabswid
.52152 .20205 Mdot
1 0 0 r
.5 Mabswid
.06731 .17435 m
.52153 .20462 L
s
0 0 0 r
2 Mabswid
.52153 .20462 Mdot
1 0 0 r
.5 Mabswid
.06731 .24425 m
.52153 .21398 L
s
0 0 0 r
2 Mabswid
.52153 .21398 Mdot
1 0 0 r
.5 Mabswid
.06632 .26182 m
.52152 .21655 L
s
0 0 0 r
2 Mabswid
.52152 .21655 Mdot
1 0 1 r
.5 Mabswid
.06626 .15606 m
.52152 .20194 L
s
0 0 0 r
2 Mabswid
.52152 .20194 Mdot
1 0 1 r
.5 Mabswid
.06717 .17133 m
.52153 .2042 L
s
0 0 0 r
2 Mabswid
.52153 .2042 Mdot
1 0 1 r
.5 Mabswid
.06777 .18654 m
.52153 .2063 L
s
0 0 0 r
2 Mabswid
.52153 .2063 Mdot
1 0 1 r
.5 Mabswid
.06777 .23206 m
.52153 .21231 L
s
0 0 0 r
2 Mabswid
.52153 .21231 Mdot
1 0 1 r
.5 Mabswid
.06717 .24728 m
.52153 .21441 L
s
0 0 0 r
2 Mabswid
.52153 .21441 Mdot
1 0 1 r
.5 Mabswid
.06626 .26255 m
.52152 .21667 L
s
0 0 0 r
2 Mabswid
.52152 .21667 Mdot
0 0 1 r
.5 Mabswid
.52152 .20228 m
.55476 .20549 L
s
0 0 0 r
2 Mabswid
.55476 .20549 Mdot
0 0 1 r
.5 Mabswid
.52153 .20593 m
.55476 .20755 L
s
0 0 0 r
2 Mabswid
.55476 .20755 Mdot
0 0 1 r
.5 Mabswid
.52153 .21267 m
.55476 .21105 L
s
0 0 0 r
2 Mabswid
.55476 .21105 Mdot
0 0 1 r
.5 Mabswid
.52152 .21633 m
.55476 .21311 L
s
0 0 0 r
2 Mabswid
.55476 .21311 Mdot
0 1 0 r
.5 Mabswid
.52152 .20216 m
.55476 .20542 L
s
0 0 0 r
2 Mabswid
.55476 .20542 Mdot
0 1 0 r
.5 Mabswid
.52153 .20517 m
.55476 .20714 L
s
0 0 0 r
2 Mabswid
.55476 .20714 Mdot
0 1 0 r
.5 Mabswid
.52153 .21343 m
.55476 .21146 L
s
0 0 0 r
2 Mabswid
.55476 .21146 Mdot
0 1 0 r
.5 Mabswid
.52152 .21644 m
.55476 .21318 L
s
0 0 0 r
2 Mabswid
.55476 .21318 Mdot
1 0 0 r
.5 Mabswid
.52152 .20205 m
.55476 .20536 L
s
0 0 0 r
2 Mabswid
.55476 .20536 Mdot
1 0 0 r
.5 Mabswid
.52153 .20462 m
.55476 .20684 L
s
0 0 0 r
2 Mabswid
.55476 .20684 Mdot
1 0 0 r
.5 Mabswid
.52153 .21398 m
.55476 .21177 L
s
0 0 0 r
2 Mabswid
.55476 .21177 Mdot
1 0 0 r
.5 Mabswid
.52152 .21655 m
.55476 .21325 L
s
0 0 0 r
2 Mabswid
.55476 .21325 Mdot
1 0 1 r
.5 Mabswid
.52152 .20194 m
.55476 .20529 L
s
0 0 0 r
2 Mabswid
.55476 .20529 Mdot
1 0 1 r
.5 Mabswid
.52153 .2042 m
.55476 .2066 L
s
0 0 0 r
2 Mabswid
.55476 .2066 Mdot
1 0 1 r
.5 Mabswid
.52153 .2063 m
.55476 .20775 L
s
0 0 0 r
2 Mabswid
.55476 .20775 Mdot
1 0 1 r
.5 Mabswid
.52153 .21231 m
.55476 .21086 L
s
0 0 0 r
2 Mabswid
.55476 .21086 Mdot
1 0 1 r
.5 Mabswid
.52153 .21441 m
.55476 .21201 L
s
0 0 0 r
2 Mabswid
.55476 .21201 Mdot
1 0 1 r
.5 Mabswid
.52152 .21667 m
.55476 .21332 L
s
0 0 0 r
2 Mabswid
.55476 .21332 Mdot
0 0 1 r
.5 Mabswid
.55476 .20549 m
.58931 .20883 L
s
0 0 0 r
2 Mabswid
.58931 .20883 Mdot
0 0 1 r
.5 Mabswid
.55476 .20755 m
.58931 .20923 L
s
0 0 0 r
2 Mabswid
.58931 .20923 Mdot
0 0 1 r
.5 Mabswid
.55476 .21105 m
.58931 .20937 L
s
0 0 0 r
2 Mabswid
.58931 .20937 Mdot
0 0 1 r
.5 Mabswid
.55476 .21311 m
.58931 .20977 L
s
0 0 0 r
2 Mabswid
.58931 .20977 Mdot
0 1 0 r
.5 Mabswid
.55476 .20542 m
.58931 .20881 L
s
0 0 0 r
2 Mabswid
.58931 .20881 Mdot
0 1 0 r
.5 Mabswid
.55476 .20714 m
.58931 .20919 L
s
0 0 0 r
2 Mabswid
.58931 .20919 Mdot
0 1 0 r
.5 Mabswid
.55476 .21146 m
.58931 .20942 L
s
0 0 0 r
2 Mabswid
.58931 .20942 Mdot
0 1 0 r
.5 Mabswid
.55476 .21318 m
.58931 .20979 L
s
0 0 0 r
2 Mabswid
.58931 .20979 Mdot
1 0 0 r
.5 Mabswid
.55476 .20536 m
.58931 .20879 L
s
0 0 0 r
2 Mabswid
.58931 .20879 Mdot
1 0 0 r
.5 Mabswid
.55476 .20684 m
.58931 .20914 L
s
0 0 0 r
2 Mabswid
.58931 .20914 Mdot
1 0 0 r
.5 Mabswid
.55476 .21177 m
.58931 .20946 L
s
0 0 0 r
2 Mabswid
.58931 .20946 Mdot
1 0 0 r
.5 Mabswid
.55476 .21325 m
.58931 .20981 L
s
0 0 0 r
2 Mabswid
.58931 .20981 Mdot
1 0 1 r
.5 Mabswid
.55476 .20529 m
.58931 .20877 L
s
0 0 0 r
2 Mabswid
.58931 .20877 Mdot
1 0 1 r
.5 Mabswid
.55476 .2066 m
.58931 .2091 L
s
0 0 0 r
2 Mabswid
.58931 .2091 Mdot
1 0 1 r
.5 Mabswid
.55476 .20775 m
.58931 .20925 L
s
0 0 0 r
2 Mabswid
.58931 .20925 Mdot
1 0 1 r
.5 Mabswid
.55476 .21086 m
.58931 .20935 L
s
0 0 0 r
2 Mabswid
.58931 .20935 Mdot
1 0 1 r
.5 Mabswid
.55476 .21201 m
.58931 .20951 L
s
0 0 0 r
2 Mabswid
.58931 .20951 Mdot
1 0 1 r
.5 Mabswid
.55476 .21332 m
.58931 .20983 L
s
0 0 0 r
2 Mabswid
.58931 .20983 Mdot
0 0 1 r
.5 Mabswid
.58931 .20883 m
.58977 .20888 L
s
0 0 0 r
2 Mabswid
.58977 .20888 Mdot
0 0 1 r
.5 Mabswid
.58931 .20923 m
.58976 .20925 L
s
0 0 0 r
2 Mabswid
.58976 .20925 Mdot
0 0 1 r
.5 Mabswid
.58931 .20937 m
.58976 .20935 L
s
0 0 0 r
2 Mabswid
.58976 .20935 Mdot
0 0 1 r
.5 Mabswid
.58931 .20977 m
.58977 .20973 L
s
0 0 0 r
2 Mabswid
.58977 .20973 Mdot
0 1 0 r
.5 Mabswid
.58931 .20881 m
.58977 .20886 L
s
0 0 0 r
2 Mabswid
.58977 .20886 Mdot
0 1 0 r
.5 Mabswid
.58931 .20919 m
.58976 .20921 L
s
0 0 0 r
2 Mabswid
.58976 .20921 Mdot
0 1 0 r
.5 Mabswid
.58931 .20942 m
.58976 .20939 L
s
0 0 0 r
2 Mabswid
.58976 .20939 Mdot
0 1 0 r
.5 Mabswid
.58931 .20979 m
.58977 .20975 L
s
0 0 0 r
2 Mabswid
.58977 .20975 Mdot
1 0 0 r
.5 Mabswid
.58931 .20879 m
.58977 .20884 L
s
0 0 0 r
2 Mabswid
.58977 .20884 Mdot
1 0 0 r
.5 Mabswid
.58931 .20914 m
.58976 .20917 L
s
0 0 0 r
2 Mabswid
.58976 .20917 Mdot
1 0 0 r
.5 Mabswid
.58931 .20946 m
.58976 .20943 L
s
0 0 0 r
2 Mabswid
.58976 .20943 Mdot
1 0 0 r
.5 Mabswid
.58931 .20981 m
.58977 .20977 L
s
0 0 0 r
2 Mabswid
.58977 .20977 Mdot
1 0 1 r
.5 Mabswid
.58931 .20877 m
.58977 .20882 L
s
0 0 0 r
2 Mabswid
.58977 .20882 Mdot
1 0 1 r
.5 Mabswid
.58931 .2091 m
.58976 .20913 L
s
0 0 0 r
2 Mabswid
.58976 .20913 Mdot
1 0 1 r
.5 Mabswid
.58931 .20925 m
.58976 .20927 L
s
0 0 0 r
2 Mabswid
.58976 .20927 Mdot
1 0 1 r
.5 Mabswid
.58931 .20935 m
.58976 .20934 L
s
0 0 0 r
2 Mabswid
.58976 .20934 Mdot
1 0 1 r
.5 Mabswid
.58931 .20951 m
.58976 .20947 L
s
0 0 0 r
2 Mabswid
.58976 .20947 Mdot
1 0 1 r
.5 Mabswid
.58931 .20983 m
.58977 .20979 L
s
0 0 0 r
2 Mabswid
.58977 .20979 Mdot
0 0 1 r
.5 Mabswid
.58977 .20888 m
.59201 .20907 L
s
0 0 0 r
2 Mabswid
.59201 .20907 Mdot
0 0 1 r
.5 Mabswid
.58976 .20925 m
.59201 .20933 L
s
0 0 0 r
2 Mabswid
.59201 .20933 Mdot
0 0 1 r
.5 Mabswid
.58976 .20935 m
.59201 .20927 L
s
0 0 0 r
2 Mabswid
.59201 .20927 Mdot
0 0 1 r
.5 Mabswid
.58977 .20973 m
.59201 .20954 L
s
0 0 0 r
2 Mabswid
.59201 .20954 Mdot
0 1 0 r
.5 Mabswid
.58977 .20886 m
.59201 .20905 L
s
0 0 0 r
2 Mabswid
.59201 .20905 Mdot
0 1 0 r
.5 Mabswid
.58976 .20921 m
.59201 .20931 L
s
0 0 0 r
2 Mabswid
.59201 .20931 Mdot
0 1 0 r
.5 Mabswid
.58976 .20939 m
.59201 .20929 L
s
0 0 0 r
2 Mabswid
.59201 .20929 Mdot
0 1 0 r
.5 Mabswid
.58977 .20975 m
.59201 .20955 L
s
0 0 0 r
2 Mabswid
.59201 .20955 Mdot
1 0 0 r
.5 Mabswid
.58977 .20884 m
.59201 .20904 L
s
0 0 0 r
2 Mabswid
.59201 .20904 Mdot
1 0 0 r
.5 Mabswid
.58976 .20917 m
.59201 .20929 L
s
0 0 0 r
2 Mabswid
.59201 .20929 Mdot
1 0 0 r
.5 Mabswid
.58976 .20943 m
.59201 .20932 L
s
0 0 0 r
2 Mabswid
.59201 .20932 Mdot
1 0 0 r
.5 Mabswid
.58977 .20977 m
.59201 .20957 L
s
0 0 0 r
2 Mabswid
.59201 .20957 Mdot
1 0 1 r
.5 Mabswid
.58977 .20882 m
.59201 .20902 L
s
0 0 0 r
2 Mabswid
.59201 .20902 Mdot
1 0 1 r
.5 Mabswid
.58976 .20913 m
.59201 .20926 L
s
0 0 0 r
2 Mabswid
.59201 .20926 Mdot
1 0 1 r
.5 Mabswid
.58976 .20927 m
.59201 .20934 L
s
0 0 0 r
2 Mabswid
.59201 .20934 Mdot
1 0 1 r
.5 Mabswid
.58976 .20934 m
.59201 .20927 L
s
0 0 0 r
2 Mabswid
.59201 .20927 Mdot
1 0 1 r
.5 Mabswid
.58976 .20947 m
.59201 .20935 L
s
0 0 0 r
2 Mabswid
.59201 .20935 Mdot
1 0 1 r
.5 Mabswid
.58977 .20979 m
.59201 .20958 L
s
0 0 0 r
2 Mabswid
.59201 .20958 Mdot
0 0 1 r
.5 Mabswid
.59201 .20907 m
.64997 .21637 L
s
0 0 0 r
2 Mabswid
.64997 .21637 Mdot
0 0 1 r
.5 Mabswid
.59201 .20933 m
.65038 .21237 L
s
0 0 0 r
2 Mabswid
.65038 .21237 Mdot
0 0 1 r
.5 Mabswid
.59201 .20927 m
.65038 .20624 L
s
0 0 0 r
2 Mabswid
.65038 .20624 Mdot
0 0 1 r
.5 Mabswid
.59201 .20954 m
.64997 .20223 L
s
0 0 0 r
2 Mabswid
.64997 .20223 Mdot
0 1 0 r
.5 Mabswid
.59201 .20905 m
.64996 .2165 L
s
0 0 0 r
2 Mabswid
.64996 .2165 Mdot
0 1 0 r
.5 Mabswid
.59201 .20931 m
.65033 .21312 L
s
0 0 0 r
2 Mabswid
.65033 .21312 Mdot
0 1 0 r
.5 Mabswid
.59201 .20929 m
.65033 .20548 L
s
0 0 0 r
2 Mabswid
.65033 .20548 Mdot
0 1 0 r
.5 Mabswid
.59201 .20955 m
.64996 .20211 L
s
0 0 0 r
2 Mabswid
.64996 .20211 Mdot
1 0 0 r
.5 Mabswid
.59201 .20904 m
.64994 .21663 L
s
0 0 0 r
2 Mabswid
.64994 .21663 Mdot
1 0 0 r
.5 Mabswid
.59201 .20929 m
.65028 .21369 L
s
0 0 0 r
2 Mabswid
.65028 .21369 Mdot
1 0 0 r
.5 Mabswid
.59201 .20932 m
.65028 .20492 L
s
0 0 0 r
2 Mabswid
.65028 .20492 Mdot
1 0 0 r
.5 Mabswid
.59201 .20957 m
.64994 .20197 L
s
0 0 0 r
2 Mabswid
.64994 .20197 Mdot
1 0 1 r
.5 Mabswid
.59201 .20902 m
.64992 .21676 L
s
0 0 0 r
2 Mabswid
.64992 .21676 Mdot
1 0 1 r
.5 Mabswid
.59201 .20926 m
.65024 .21414 L
s
0 0 0 r
2 Mabswid
.65024 .21414 Mdot
1 0 1 r
.5 Mabswid
.59201 .20934 m
.6504 .21201 L
s
0 0 0 r
2 Mabswid
.6504 .21201 Mdot
1 0 1 r
.5 Mabswid
.59201 .20927 m
.6504 .20659 L
s
0 0 0 r
2 Mabswid
.6504 .20659 Mdot
1 0 1 r
.5 Mabswid
.59201 .20935 m
.65024 .20446 L
s
0 0 0 r
2 Mabswid
.65024 .20446 Mdot
1 0 1 r
.5 Mabswid
.59201 .20958 m
.64992 .20184 L
s
0 0 0 r
2 Mabswid
.64992 .20184 Mdot
0 0 1 r
.5 Mabswid
.64997 .21637 m
.65233 .21668 L
s
0 0 0 r
2 Mabswid
.65233 .21668 Mdot
0 0 1 r
.5 Mabswid
.65038 .21237 m
.65304 .21251 L
s
0 0 0 r
2 Mabswid
.65304 .21251 Mdot
0 0 1 r
.5 Mabswid
.65038 .20624 m
.65304 .20609 L
s
0 0 0 r
2 Mabswid
.65304 .20609 Mdot
0 0 1 r
.5 Mabswid
.64997 .20223 m
.65233 .20192 L
s
0 0 0 r
2 Mabswid
.65233 .20192 Mdot
0 1 0 r
.5 Mabswid
.64996 .2165 m
.6523 .21681 L
s
0 0 0 r
2 Mabswid
.6523 .21681 Mdot
0 1 0 r
.5 Mabswid
.65033 .21312 m
.65295 .2133 L
s
0 0 0 r
2 Mabswid
.65295 .2133 Mdot
0 1 0 r
.5 Mabswid
.65033 .20548 m
.65295 .2053 L
s
0 0 0 r
2 Mabswid
.65295 .2053 Mdot
0 1 0 r
.5 Mabswid
.64996 .20211 m
.6523 .20179 L
s
0 0 0 r
2 Mabswid
.6523 .20179 Mdot
1 0 0 r
.5 Mabswid
.64994 .21663 m
.65226 .21695 L
s
0 0 0 r
2 Mabswid
.65226 .21695 Mdot
1 0 0 r
.5 Mabswid
.65028 .21369 m
.65287 .21389 L
s
0 0 0 r
2 Mabswid
.65287 .21389 Mdot
1 0 0 r
.5 Mabswid
.65028 .20492 m
.65287 .20471 L
s
0 0 0 r
2 Mabswid
.65287 .20471 Mdot
1 0 0 r
.5 Mabswid
.64994 .20197 m
.65226 .20166 L
s
0 0 0 r
2 Mabswid
.65226 .20166 Mdot
1 0 1 r
.5 Mabswid
.64992 .21676 m
.65223 .21708 L
s
0 0 0 r
2 Mabswid
.65223 .21708 Mdot
1 0 1 r
.5 Mabswid
.65024 .21414 m
.6528 .21437 L
s
0 0 0 r
2 Mabswid
.6528 .21437 Mdot
1 0 1 r
.5 Mabswid
.6504 .21201 m
.65308 .21214 L
s
0 0 0 r
2 Mabswid
.65308 .21214 Mdot
1 0 1 r
.5 Mabswid
.6504 .20659 m
.65308 .20646 L
s
0 0 0 r
2 Mabswid
.65308 .20646 Mdot
1 0 1 r
.5 Mabswid
.65024 .20446 m
.6528 .20424 L
s
0 0 0 r
2 Mabswid
.6528 .20424 Mdot
1 0 1 r
.5 Mabswid
.64992 .20184 m
.65223 .20152 L
s
0 0 0 r
2 Mabswid
.65223 .20152 Mdot
0 0 1 r
.5 Mabswid
.65233 .21668 m
.65457 .21686 L
s
0 0 0 r
2 Mabswid
.65457 .21686 Mdot
0 0 1 r
.5 Mabswid
.65304 .21251 m
.65423 .21255 L
s
0 0 0 r
2 Mabswid
.65423 .21255 Mdot
0 0 1 r
.5 Mabswid
.65304 .20609 m
.65423 .20605 L
s
0 0 0 r
2 Mabswid
.65423 .20605 Mdot
0 0 1 r
.5 Mabswid
.65233 .20192 m
.65457 .20175 L
s
0 0 0 r
2 Mabswid
.65457 .20175 Mdot
0 1 0 r
.5 Mabswid
.6523 .21681 m
.65458 .217 L
s
0 0 0 r
2 Mabswid
.65458 .217 Mdot
0 1 0 r
.5 Mabswid
.65295 .2133 m
.65427 .21336 L
s
0 0 0 r
2 Mabswid
.65427 .21336 Mdot
0 1 0 r
.5 Mabswid
.65295 .2053 m
.65427 .20525 L
s
0 0 0 r
2 Mabswid
.65427 .20525 Mdot
0 1 0 r
.5 Mabswid
.6523 .20179 m
.65458 .20161 L
s
0 0 0 r
2 Mabswid
.65458 .20161 Mdot
1 0 0 r
.5 Mabswid
.65226 .21695 m
.6546 .21714 L
s
0 0 0 r
2 Mabswid
.6546 .21714 Mdot
1 0 0 r
.5 Mabswid
.65287 .21389 m
.65431 .21396 L
s
0 0 0 r
2 Mabswid
.65431 .21396 Mdot
1 0 0 r
.5 Mabswid
.65287 .20471 m
.65431 .20464 L
s
0 0 0 r
2 Mabswid
.65431 .20464 Mdot
1 0 0 r
.5 Mabswid
.65226 .20166 m
.6546 .20146 L
s
0 0 0 r
2 Mabswid
.6546 .20146 Mdot
1 0 1 r
.5 Mabswid
.65223 .21708 m
.65462 .21729 L
s
0 0 0 r
2 Mabswid
.65462 .21729 Mdot
1 0 1 r
.5 Mabswid
.6528 .21437 m
.65434 .21445 L
s
0 0 0 r
2 Mabswid
.65434 .21445 Mdot
1 0 1 r
.5 Mabswid
.65308 .21214 m
.65421 .21217 L
s
0 0 0 r
2 Mabswid
.65421 .21217 Mdot
1 0 1 r
.5 Mabswid
.65308 .20646 m
.65421 .20643 L
s
0 0 0 r
2 Mabswid
.65421 .20643 Mdot
1 0 1 r
.5 Mabswid
.6528 .20424 m
.65434 .20416 L
s
0 0 0 r
2 Mabswid
.65434 .20416 Mdot
1 0 1 r
.5 Mabswid
.65223 .20152 m
.65462 .20132 L
s
0 0 0 r
2 Mabswid
.65462 .20132 Mdot
0 0 1 r
.5 Mabswid
.65457 .21686 m
.65707 .2169 L
s
0 0 0 r
2 Mabswid
.65707 .2169 Mdot
0 0 1 r
.5 Mabswid
.65423 .21255 m
.65659 .21257 L
s
0 0 0 r
2 Mabswid
.65659 .21257 Mdot
0 0 1 r
.5 Mabswid
.65423 .20605 m
.65659 .20604 L
s
0 0 0 r
2 Mabswid
.65659 .20604 Mdot
0 0 1 r
.5 Mabswid
.65457 .20175 m
.65707 .2017 L
s
0 0 0 r
2 Mabswid
.65707 .2017 Mdot
0 1 0 r
.5 Mabswid
.65458 .217 m
.65709 .21704 L
s
0 0 0 r
2 Mabswid
.65709 .21704 Mdot
0 1 0 r
.5 Mabswid
.65427 .21336 m
.65665 .21338 L
s
0 0 0 r
2 Mabswid
.65665 .21338 Mdot
0 1 0 r
.5 Mabswid
.65427 .20525 m
.65665 .20523 L
s
0 0 0 r
2 Mabswid
.65665 .20523 Mdot
0 1 0 r
.5 Mabswid
.65458 .20161 m
.65709 .20156 L
s
0 0 0 r
2 Mabswid
.65709 .20156 Mdot
1 0 0 r
.5 Mabswid
.6546 .21714 m
.65711 .21719 L
s
0 0 0 r
2 Mabswid
.65711 .21719 Mdot
1 0 0 r
.5 Mabswid
.65431 .21396 m
.65671 .21399 L
s
0 0 0 r
2 Mabswid
.65671 .21399 Mdot
1 0 0 r
.5 Mabswid
.65431 .20464 m
.65671 .20462 L
s
0 0 0 r
2 Mabswid
.65671 .20462 Mdot
1 0 0 r
.5 Mabswid
.6546 .20146 m
.65711 .20141 L
s
0 0 0 r
2 Mabswid
.65711 .20141 Mdot
1 0 1 r
.5 Mabswid
.65462 .21729 m
.65713 .21734 L
s
0 0 0 r
2 Mabswid
.65713 .21734 Mdot
1 0 1 r
.5 Mabswid
.65434 .21445 m
.65676 .21448 L
s
0 0 0 r
2 Mabswid
.65676 .21448 Mdot
1 0 1 r
.5 Mabswid
.65421 .21217 m
.65657 .21219 L
s
0 0 0 r
2 Mabswid
.65657 .21219 Mdot
1 0 1 r
.5 Mabswid
.65421 .20643 m
.65657 .20642 L
s
0 0 0 r
2 Mabswid
.65657 .20642 Mdot
1 0 1 r
.5 Mabswid
.65434 .20416 m
.65676 .20413 L
s
0 0 0 r
2 Mabswid
.65676 .20413 Mdot
1 0 1 r
.5 Mabswid
.65462 .20132 m
.65713 .20127 L
s
0 0 0 r
2 Mabswid
.65713 .20127 Mdot
0 0 1 r
.5 Mabswid
.65707 .2169 m
.6574 .21694 L
s
0 0 0 r
2 Mabswid
.6574 .21694 Mdot
0 0 1 r
.5 Mabswid
.65659 .21257 m
.65728 .21259 L
s
0 0 0 r
2 Mabswid
.65728 .21259 Mdot
0 0 1 r
.5 Mabswid
.65659 .20604 m
.65728 .20601 L
s
0 0 0 r
2 Mabswid
.65728 .20601 Mdot
0 0 1 r
.5 Mabswid
.65707 .2017 m
.6574 .20167 L
s
0 0 0 r
2 Mabswid
.6574 .20167 Mdot
0 1 0 r
.5 Mabswid
.65709 .21704 m
.65741 .21708 L
s
0 0 0 r
2 Mabswid
.65741 .21708 Mdot
0 1 0 r
.5 Mabswid
.65665 .21338 m
.65729 .21341 L
s
0 0 0 r
2 Mabswid
.65729 .21341 Mdot
0 1 0 r
.5 Mabswid
.65665 .20523 m
.65729 .2052 L
s
0 0 0 r
2 Mabswid
.65729 .2052 Mdot
0 1 0 r
.5 Mabswid
.65709 .20156 m
.65741 .20153 L
s
0 0 0 r
2 Mabswid
.65741 .20153 Mdot
1 0 0 r
.5 Mabswid
.65711 .21719 m
.65741 .21722 L
s
0 0 0 r
2 Mabswid
.65741 .21722 Mdot
1 0 0 r
.5 Mabswid
.65671 .21399 m
.65731 .21402 L
s
0 0 0 r
2 Mabswid
.65731 .21402 Mdot
1 0 0 r
.5 Mabswid
.65671 .20462 m
.65731 .20458 L
s
0 0 0 r
2 Mabswid
.65731 .20458 Mdot
1 0 0 r
.5 Mabswid
.65711 .20141 m
.65741 .20138 L
s
0 0 0 r
2 Mabswid
.65741 .20138 Mdot
1 0 1 r
.5 Mabswid
.65713 .21734 m
.65742 .21737 L
s
0 0 0 r
2 Mabswid
.65742 .21737 Mdot
1 0 1 r
.5 Mabswid
.65676 .21448 m
.65732 .21451 L
s
0 0 0 r
2 Mabswid
.65732 .21451 Mdot
1 0 1 r
.5 Mabswid
.65657 .21219 m
.65727 .21221 L
s
0 0 0 r
2 Mabswid
.65727 .21221 Mdot
1 0 1 r
.5 Mabswid
.65657 .20642 m
.65727 .20639 L
s
0 0 0 r
2 Mabswid
.65727 .20639 Mdot
1 0 1 r
.5 Mabswid
.65676 .20413 m
.65732 .20409 L
s
0 0 0 r
2 Mabswid
.65732 .20409 Mdot
1 0 1 r
.5 Mabswid
.65713 .20127 m
.65742 .20124 L
s
0 0 0 r
2 Mabswid
.65742 .20124 Mdot
0 0 1 r
.5 Mabswid
.6574 .21694 m
.66129 .21715 L
s
0 0 0 r
2 Mabswid
.66129 .21715 Mdot
0 0 1 r
.5 Mabswid
.65728 .21259 m
.66195 .2127 L
s
0 0 0 r
2 Mabswid
.66195 .2127 Mdot
0 0 1 r
.5 Mabswid
.65728 .20601 m
.66195 .20591 L
s
0 0 0 r
2 Mabswid
.66195 .20591 Mdot
0 0 1 r
.5 Mabswid
.6574 .20167 m
.66129 .20146 L
s
0 0 0 r
2 Mabswid
.66129 .20146 Mdot
0 1 0 r
.5 Mabswid
.65741 .21708 m
.66126 .21729 L
s
0 0 0 r
2 Mabswid
.66126 .21729 Mdot
0 1 0 r
.5 Mabswid
.65729 .21341 m
.66187 .21354 L
s
0 0 0 r
2 Mabswid
.66187 .21354 Mdot
0 1 0 r
.5 Mabswid
.65729 .2052 m
.66187 .20507 L
s
0 0 0 r
2 Mabswid
.66187 .20507 Mdot
0 1 0 r
.5 Mabswid
.65741 .20153 m
.66126 .20131 L
s
0 0 0 r
2 Mabswid
.66126 .20131 Mdot
1 0 0 r
.5 Mabswid
.65741 .21722 m
.66123 .21744 L
s
0 0 0 r
2 Mabswid
.66123 .21744 Mdot
1 0 0 r
.5 Mabswid
.65731 .21402 m
.66179 .21417 L
s
0 0 0 r
2 Mabswid
.66179 .21417 Mdot
1 0 0 r
.5 Mabswid
.65731 .20458 m
.66179 .20444 L
s
0 0 0 r
2 Mabswid
.66179 .20444 Mdot
1 0 0 r
.5 Mabswid
.65741 .20138 m
.66123 .20116 L
s
0 0 0 r
2 Mabswid
.66123 .20116 Mdot
1 0 1 r
.5 Mabswid
.65742 .21737 m
.6612 .21759 L
s
0 0 0 r
2 Mabswid
.6612 .21759 Mdot
1 0 1 r
.5 Mabswid
.65732 .21451 m
.66172 .21467 L
s
0 0 0 r
2 Mabswid
.66172 .21467 Mdot
1 0 1 r
.5 Mabswid
.65727 .21221 m
.66198 .2123 L
s
0 0 0 r
2 Mabswid
.66198 .2123 Mdot
1 0 1 r
.5 Mabswid
.65727 .20639 m
.66198 .2063 L
s
0 0 0 r
2 Mabswid
.66198 .2063 Mdot
1 0 1 r
.5 Mabswid
.65732 .20409 m
.66172 .20393 L
s
0 0 0 r
2 Mabswid
.66172 .20393 Mdot
1 0 1 r
.5 Mabswid
.65742 .20124 m
.6612 .20102 L
s
0 0 0 r
2 Mabswid
.6612 .20102 Mdot
0 0 1 r
.5 Mabswid
.66129 .21715 m
.7198 .21606 L
s
0 0 0 r
2 Mabswid
.7198 .21606 Mdot
0 0 1 r
.5 Mabswid
.66195 .2127 m
.72208 .2121 L
s
0 0 0 r
2 Mabswid
.72208 .2121 Mdot
0 0 1 r
.5 Mabswid
.66195 .20591 m
.72529 .20654 L
s
0 0 0 r
2 Mabswid
.72529 .20654 Mdot
0 0 1 r
.5 Mabswid
.66129 .20146 m
.72751 .20269 L
s
0 0 0 r
2 Mabswid
.72751 .20269 Mdot
0 1 0 r
.5 Mabswid
.66126 .21729 m
.71969 .21624 L
s
0 0 0 r
2 Mabswid
.71969 .21624 Mdot
0 1 0 r
.5 Mabswid
.66187 .21354 m
.72165 .21285 L
s
0 0 0 r
2 Mabswid
.72165 .21285 Mdot
0 1 0 r
.5 Mabswid
.66187 .20507 m
.72572 .2058 L
s
0 0 0 r
2 Mabswid
.72572 .2058 Mdot
0 1 0 r
.5 Mabswid
.66126 .20131 m
.72762 .2025 L
s
0 0 0 r
2 Mabswid
.72762 .2025 Mdot
1 0 0 r
.5 Mabswid
.66123 .21744 m
.71959 .21641 L
s
0 0 0 r
2 Mabswid
.71959 .21641 Mdot
1 0 0 r
.5 Mabswid
.66179 .21417 m
.72132 .21342 L
s
0 0 0 r
2 Mabswid
.72132 .21342 Mdot
1 0 0 r
.5 Mabswid
.66179 .20444 m
.72604 .20524 L
s
0 0 0 r
2 Mabswid
.72604 .20524 Mdot
1 0 0 r
.5 Mabswid
.66123 .20116 m
.72772 .20234 L
s
0 0 0 r
2 Mabswid
.72772 .20234 Mdot
1 0 1 r
.5 Mabswid
.6612 .21759 m
.71948 .2166 L
s
0 0 0 r
2 Mabswid
.71948 .2166 Mdot
1 0 1 r
.5 Mabswid
.66172 .21467 m
.72104 .2139 L
s
0 0 0 r
2 Mabswid
.72104 .2139 Mdot
1 0 1 r
.5 Mabswid
.66198 .2123 m
.72224 .21181 L
s
0 0 0 r
2 Mabswid
.72224 .21181 Mdot
1 0 1 r
.5 Mabswid
.66198 .2063 m
.72513 .20681 L
s
0 0 0 r
2 Mabswid
.72513 .20681 Mdot
1 0 1 r
.5 Mabswid
.66172 .20393 m
.72631 .20477 L
s
0 0 0 r
2 Mabswid
.72631 .20477 Mdot
1 0 1 r
.5 Mabswid
.6612 .20102 m
.72782 .20215 L
s
0 0 0 r
2 Mabswid
.72782 .20215 Mdot
0 0 1 r
.5 Mabswid
.7198 .21606 m
.68227 .14817 L
s
0 0 0 r
2 Mabswid
.68227 .14817 Mdot
0 0 1 r
.5 Mabswid
.72208 .2121 m
.68416 .14489 L
s
0 0 0 r
2 Mabswid
.68416 .14489 Mdot
0 0 1 r
.5 Mabswid
.72529 .20654 m
.68649 .14085 L
s
0 0 0 r
2 Mabswid
.68649 .14085 Mdot
0 0 1 r
.5 Mabswid
.72751 .20269 m
.68833 .13766 L
s
0 0 0 r
2 Mabswid
.68833 .13766 Mdot
0 1 0 r
.5 Mabswid
.71969 .21624 m
.78683 .21504 L
s
0 0 0 r
2 Mabswid
.78683 .21504 Mdot
0 1 0 r
.5 Mabswid
.72165 .21285 m
.78853 .21208 L
s
0 0 0 r
2 Mabswid
.78853 .21208 Mdot
0 1 0 r
.5 Mabswid
.72572 .2058 m
.79173 .20656 L
s
0 0 0 r
2 Mabswid
.79173 .20656 Mdot
0 1 0 r
.5 Mabswid
.72762 .2025 m
.79339 .20368 L
s
0 0 0 r
2 Mabswid
.79339 .20368 Mdot
1 0 0 r
.5 Mabswid
.71959 .21641 m
.78672 .21523 L
s
0 0 0 r
2 Mabswid
.78672 .21523 Mdot
1 0 0 r
.5 Mabswid
.72132 .21342 m
.78825 .21258 L
s
0 0 0 r
2 Mabswid
.78825 .21258 Mdot
1 0 0 r
.5 Mabswid
.72604 .20524 m
.79201 .20607 L
s
0 0 0 r
2 Mabswid
.79201 .20607 Mdot
1 0 0 r
.5 Mabswid
.72772 .20234 m
.79349 .2035 L
s
0 0 0 r
2 Mabswid
.79349 .2035 Mdot
1 0 1 r
.5 Mabswid
.71948 .2166 m
.68189 .14883 L
s
0 0 0 r
2 Mabswid
.68189 .14883 Mdot
1 0 1 r
.5 Mabswid
.72104 .2139 m
.68326 .14646 L
s
0 0 0 r
2 Mabswid
.68326 .14646 Mdot
1 0 1 r
.5 Mabswid
.72224 .21181 m
.68424 .14474 L
s
0 0 0 r
2 Mabswid
.68424 .14474 Mdot
1 0 1 r
.5 Mabswid
.72513 .20681 m
.68641 .14099 L
s
0 0 0 r
2 Mabswid
.68641 .14099 Mdot
1 0 1 r
.5 Mabswid
.72631 .20477 m
.68738 .13931 L
s
0 0 0 r
2 Mabswid
.68738 .13931 Mdot
1 0 1 r
.5 Mabswid
.72782 .20215 m
.68871 .137 L
s
0 0 0 r
2 Mabswid
.68871 .137 Mdot
0 0 1 r
.5 Mabswid
.68227 .14817 m
.60588 .00997 L
s
0 0 0 r
2 Mabswid
.60588 .00997 Mdot
0 0 1 r
.5 Mabswid
.68416 .14489 m
.60803 .00997 L
s
0 0 0 r
2 Mabswid
.60803 .00997 Mdot
0 0 1 r
.5 Mabswid
.68649 .14085 m
.60919 .00997 L
s
0 0 0 r
2 Mabswid
.60919 .00997 Mdot
0 0 1 r
.5 Mabswid
.68833 .13766 m
.6114 .00997 L
s
0 0 0 r
2 Mabswid
.6114 .00997 Mdot
0 1 0 r
.5 Mabswid
.78683 .21504 m
.87424 .21348 L
s
0 0 0 r
2 Mabswid
.87424 .21348 Mdot
0 1 0 r
.5 Mabswid
.78853 .21208 m
.87393 .21111 L
s
0 0 0 r
2 Mabswid
.87393 .21111 Mdot
0 1 0 r
.5 Mabswid
.79173 .20656 m
.87393 .2075 L
s
0 0 0 r
2 Mabswid
.87393 .2075 Mdot
0 1 0 r
.5 Mabswid
.79339 .20368 m
.87424 .20513 L
s
0 0 0 r
2 Mabswid
.87424 .20513 Mdot
1 0 0 r
.5 Mabswid
.78672 .21523 m
.673 .00997 L
s
0 0 0 r
2 Mabswid
.673 .00997 Mdot
1 0 0 r
.5 Mabswid
.78825 .21258 m
.67462 .00997 L
s
0 0 0 r
2 Mabswid
.67462 .00997 Mdot
1 0 0 r
.5 Mabswid
.79201 .20607 m
.67549 .00997 L
s
0 0 0 r
2 Mabswid
.67549 .00997 Mdot
1 0 0 r
.5 Mabswid
.79349 .2035 m
.67716 .00997 L
s
0 0 0 r
2 Mabswid
.67716 .00997 Mdot
1 0 1 r
.5 Mabswid
.68189 .14883 m
.76949 .14734 L
s
0 0 0 r
2 Mabswid
.76949 .14734 Mdot
1 0 1 r
.5 Mabswid
.68326 .14646 m
.76919 .14534 L
s
0 0 0 r
2 Mabswid
.76919 .14534 Mdot
1 0 1 r
.5 Mabswid
.68424 .14474 m
.76908 .14405 L
s
0 0 0 r
2 Mabswid
.76908 .14405 Mdot
1 0 1 r
.5 Mabswid
.68641 .14099 m
.76908 .14166 L
s
0 0 0 r
2 Mabswid
.76908 .14166 Mdot
1 0 1 r
.5 Mabswid
.68738 .13931 m
.76919 .14037 L
s
0 0 0 r
2 Mabswid
.76919 .14037 Mdot
1 0 1 r
.5 Mabswid
.68871 .137 m
.76949 .13838 L
s
0 0 0 r
2 Mabswid
.76949 .13838 Mdot
0 1 0 r
.5 Mabswid
.87424 .21348 m
.87696 .21329 L
s
0 0 0 r
2 Mabswid
.87696 .21329 Mdot
0 1 0 r
.5 Mabswid
.87393 .21111 m
.87696 .21101 L
s
0 0 0 r
2 Mabswid
.87696 .21101 Mdot
0 1 0 r
.5 Mabswid
.87393 .2075 m
.87696 .2076 L
s
0 0 0 r
2 Mabswid
.87696 .2076 Mdot
0 1 0 r
.5 Mabswid
.87424 .20513 m
.87696 .20532 L
s
0 0 0 r
2 Mabswid
.87696 .20532 Mdot
1 0 1 r
.5 Mabswid
.76949 .14734 m
.77215 .14714 L
s
0 0 0 r
2 Mabswid
.77215 .14714 Mdot
1 0 1 r
.5 Mabswid
.76919 .14534 m
.77215 .14521 L
s
0 0 0 r
2 Mabswid
.77215 .14521 Mdot
1 0 1 r
.5 Mabswid
.76908 .14405 m
.77215 .14399 L
s
0 0 0 r
2 Mabswid
.77215 .14399 Mdot
1 0 1 r
.5 Mabswid
.76908 .14166 m
.77215 .14173 L
s
0 0 0 r
2 Mabswid
.77215 .14173 Mdot
1 0 1 r
.5 Mabswid
.76919 .14037 m
.77215 .1405 L
s
0 0 0 r
2 Mabswid
.77215 .1405 Mdot
1 0 1 r
.5 Mabswid
.76949 .13838 m
.77215 .13857 L
s
0 0 0 r
2 Mabswid
.77215 .13857 Mdot
0 1 0 r
.5 Mabswid
.87696 .21329 m
.97619 .20302 L
s
0 0 0 r
2 Mabswid
.97619 .20302 Mdot
0 1 0 r
.5 Mabswid
.87696 .21101 m
.97619 .20625 L
s
0 0 0 r
2 Mabswid
.97619 .20625 Mdot
0 1 0 r
.5 Mabswid
.87696 .2076 m
.97619 .21236 L
s
0 0 0 r
2 Mabswid
.97619 .21236 Mdot
0 1 0 r
.5 Mabswid
.87696 .20532 m
.97619 .21559 L
s
0 0 0 r
2 Mabswid
.97619 .21559 Mdot
1 0 1 r
.5 Mabswid
.77215 .14714 m
.97619 .12504 L
s
0 0 0 r
2 Mabswid
.97619 .12504 Mdot
1 0 1 r
.5 Mabswid
.77215 .14521 m
.97619 .13236 L
s
0 0 0 r
2 Mabswid
.97619 .13236 Mdot
1 0 1 r
.5 Mabswid
.77215 .14399 m
.97619 .13743 L
s
0 0 0 r
2 Mabswid
.97619 .13743 Mdot
1 0 1 r
.5 Mabswid
.77215 .14173 m
.97619 .14828 L
s
0 0 0 r
2 Mabswid
.97619 .14828 Mdot
1 0 1 r
.5 Mabswid
.77215 .1405 m
.97619 .15335 L
s
0 0 0 r
2 Mabswid
.97619 .15335 Mdot
1 0 1 r
.5 Mabswid
.77215 .13857 m
.97619 .16067 L
s
0 0 0 r
2 Mabswid
.97619 .16067 Mdot
[(BS2)] .81196 .17152 0 0 Mshowa
[(FL2)] .87541 .17121 0 0 Mshowa
[(BS3)] .70715 .10507 0 0 Mshowa
[(FL1)] .7706 .10476 0 0 Mshowa
[(Primary)] .52154 .2093 0 0 Mshowa
[(Secondary)] .06257 .29539 0 0 Mshowa
[(Field)] .59088 .17674 0 0 Mshowa
[(Coll Set)] .65184 .17121 0 0 Mshowa
[(BS1)] .74551 .17152 0 0 Mshowa
0 0 m
1 0 L
1 .4186 L
0 .4186 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{828, 346.375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000<l0001FR000`400?l00000o`00003oo`3ooooo
0?ooool0oooo?`3oool003T0oooo0P00002V0?ooo`8000000`3oool2000000<0oooo0P00002N0?oo
o`<000000P3oool2000000<0oooo0P0000030?ooo`800000W03oool300000080oooo0P0000030?oo
o`8000000`3oool2000009/0oooo100000020?ooo`8000000`3oool2000000<0oooo0P0000160?oo
o`00>03oool010000000oooo0?ooo`00002T0?ooo`060000003oool0oooo0000003oool000000P3o
ool00`000000oooo000000020?ooo`030000003oool0oooo09`0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo000000020?ooo`030000003oool000000080oooo00<000000?ooo`3oool0
VP3oool010000000oooo0?ooo`0000020?ooo`030000003oool000000080oooo00<000000?ooo`00
00000P3oool00`000000oooo0?ooo`2H0?ooo`060000003oool0oooo0000003oool000000P3oool0
0`000000oooo000000020?ooo`030000003oool000000080oooo00<000000?ooo`3oool0@`3oool0
03P0oooo00@000000?ooo`3oool00000Y`3oool00`000000oooo000000020?ooo`030000003oool0
00000080oooo00<000000?ooo`3oool0W03oool010000000oooo0?ooo`0000020?ooo`030000003o
ool000000080oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`2J0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`0000000P3oool00`000000oooo000000020?ooo`030000003o
ool0oooo09T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool000000080oooo
00<000000?ooo`0000000P3oool00`000000oooo0?ooo`130?ooo`00>03oool010000000oooo0?oo
o`00002W0?ooo`030000003oool000000080oooo00<000000?ooo`0000000P3oool00`000000oooo
0?ooo`2L0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`0000000P3oool00`000000
oooo000000020?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3oool00`3oool00`000000
oooo000000020?ooo`030000003oool000000080oooo00<000000?ooo`3oool0VP3oool010000000
oooo0?ooo`0000020?ooo`030000003oool000000080oooo00<000000?ooo`0000000P3oool00`00
0000oooo0?ooo`130?ooo`00>03oool010000000oooo0?ooo`00002T0?ooo`<000000P3oool01P00
0000oooo0?ooo`000000oooo00000080oooo00<000000?ooo`3oool0W03oool010000000oooo0?oo
o`0000020?ooo`030000003oool000000080oooo00<000000?ooo`0000000P3oool00`000000oooo
0?ooo`2J0?ooo`030000003oool0oooo00<000000P3oool01P000000oooo0?ooo`000000oooo0000
0080oooo00<000000?ooo`3oool0V`3oool00`000000oooo000000020?ooo`030000003oool00000
0080oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`130?ooo`00>03oool010000000
oooo0?ooo`00002T0?ooo`030000003oool0oooo0080oooo00H000000?ooo`3oool000000?ooo`00
00020?ooo`030000003oool0oooo09/0oooo0P0000020?ooo`060000003oool0oooo0000003oool0
00000P3oool00`000000oooo000000020?ooo`030000003oool0oooo09T0oooo0P0000020?ooo`03
0000003oool0oooo0080oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`030000003oool0
oooo09P0oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`030000003oool000000080oooo
00<000000?ooo`0000000P3oool00`000000oooo0?ooo`130?ooo`00>@3oool200000:D0oooo1000
00020?ooo`8000000`3oool2000009l0oooo00@000000?ooo`3oool0oooo0P0000030?ooo`800000
0`3oool2000009d0oooo00<000000?ooo`3oool0100000020?ooo`8000000`3oool2000009`0oooo
0P0000030?ooo`8000000`3oool2000000<0oooo0P0000160?ooo`00o`3ooooo0?ooool0oooo?`3o
ool00?l0ooooo`3ooooo0?ooocl0oooo003o0?ooool0ooooo`3ooolo0?ooo`00o`3ooooo0?ooool0
oooo?`3oool00?l0ooooo`3ooooo0?ooocl0oooo003o0?ooool0ooooo`3ooolo0?ooo`00o`3ooooo
0?ooool0oooo?`3oool00?l0ooooo`3ooooo0?ooocl0oooo003o0?ooool0ooooo`3ooolo0?ooo`00
o`3ooooo0?ooool0oooo?`3oool00?l0ooooo`3ooooo0?ooocl0oooo000X0?ooool00000o`00003o
0000010000001`3oool002P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0P0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0P0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo0200oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0P0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0P0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo0200oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0P0?oo
o`030000003oool0oooo0200oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0P0?oo
o`8000001`3oool002P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0P0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0P0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0P0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0P0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0P0?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0P0?ooo`80
00001`3oool002P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo01l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo01l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo01l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo01l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0P0?ooo`800000
1`3oool002P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`2Z0?ooo`030000003o
ool0oooo0:X0oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`2Z0?ooo`030000003o
ool0oooo04<0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0ZP3oool0
0`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool01@3oool0
02P0oooo00<000000?ooo`3oool0o`3ooooo0?ooool0oooo303oool00`000000oooo0?ooo`050?oo
o`00:03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0?l0oooo``3oool6000002h0
oooo1P00003X0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01@3oool002P0oooo
1000000>0?ooool00000o`00003Z000000l0oooo100000070?ooo`00:03oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo0?l0ooooa03oool01P000?l0oooo0000o`000?l0oooo0000obl0
oooo103o003X0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool002P0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?ooolD0oooo00H0003o0?ooo`000?l0
003o0?ooo`000?l_0?ooo`@0o`00i`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
00D0oooo000X0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0o`3oooo50?ooo`04
0000o`3oool0003o0000o`80oooo00<0003o0?ooo`3oool0;03oool30?l000030?ooo`3o0000oooo
0>D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0ooooaP3oool01P000?l0oooo0000o`000?l0oooo
0000obl0oooo103o003V0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool0
02P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?ooolL0oooo00H0003o0?oo
o`000?l0003o0?ooo`000?l_0?ooo`@0o`00i@3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo00D0oooo000X0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0o`3oooo7
0?ooo`060000o`3oool0003o0000o`3oool0003o;`3oool40?l00>D0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo0?l0oooob03oool01P000?l0oooo0000o`000?l0oooo0000obl0oooo103o003T0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`3o0?ooolP0oooo00@0003o0?ooo`000?l0003o0P3oool00`000?l0
oooo0?ooo`0/0?ooo`<0o`0000<0oooo0?l0003oool0hP3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
o`3oooo90?ooo`060000o`3oool0003o0000o`3oool0003o;`3oool40?l00><0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo0?l0oooob@3oool01`000?l0oooo0000o`3oool0003o0?ooo`000?l0;P3oool2
0?l000030?ooo`3o0000o`000>80oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`05
0?ooo`00:03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0oooobP3oool01P00
0?l0oooo0000o`000?l0oooo0000obl0oooo103o003R0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3o
0?ooolX0oooo00<0003o0?ooo`3oool00P000?l00`3oool0003o0?ooo`0]0?ooo`80o`0000<0oooo
0?l0003o0000h@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo000X0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool0o`3oooo;0?ooo`040000o`3oool0003o
0000o`80oooo00<0003o0?ooo`3oool0;03oool30?l000030?ooo`3o0000oooo0=l0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`050?ooo`004P3oool00`000000oooo0?ooo`020000
00<0oooo0P00000<0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0o`3oooo<0?oo
o`060000o`3oool0003o0000o`3oool0003o;`3oool40?l00>00oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`050?ooo`004P3oool00`000000oooo000000020?ooo`030000003oool0
00000080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo0?l0ooooc03oool01`000?l0oooo0000o`3oool0003o0?ooo`000?l0;P3oool20?l000030?oo
o`3o0000o`000=l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`050?ooo`00303o
ool7000000070?ooo`000000oooo0?ooo`000000oooo000000020?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?ooold0oooo00H0003o0?ooo`00
0?l0003o0?ooo`000?l_0?ooo`@0o`00g`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo00D0oooo000?0?ooo`060000003oool0oooo0000003oool000000P3oool00`000000oooo0000
00020?ooo`030000003oool0oooo00T0oooo1P00000<0?ooo`030000003oool0oooo0?l0ooooc@3o
ool01`000?l0oooo0000o`3oool0003o0?ooo`000?l0;P3oool20?l000030?ooo`3o0000o`000=h0
oooo00<000000?ooo`3oool02`3oool6000000L0oooo000@0?ooo`050000003oool000000?ooo`00
00000P3oool00`000000oooo000000020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`3o0?ooolh0oooo00@0003o0?ooo`000?l0003o0P3oool00`00
0?l0oooo0?ooo`0/0?ooo`<0o`0000<0oooo0?l0003oool0g03oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo00D0oooo000A0?ooo`80000000L0oooo0000003oool0oooo0000003oool0
00000080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo0?l0oooocP3oool00`000?l0oooo0?ooo`020000o`030?ooo`000?l0oooo02d0oooo0P3o0000
0`3oool0o`000?l0003M0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool0
0180oooo00<000000?ooo`3oool00P0000030?ooo`800000303oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo0?l0ooooNP3ooolT00000340oooo00@0003o0?ooo`000?l0003o0P3oool0
0`000?l0oooo0?ooo`0/0?ooo`80o`0000<0oooo0?l0003o0000g03oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0o`3ooomj0?ooo`030000001oOgl0Ogmo0200Ogmo00<000000?ooo`3oool0;`3oool00`00
0?l0oooo0?ooo`020000o`030?ooo`000?l0oooo02d0oooo00<0o`000?ooo`3o00000P3o003L0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`3o0?ooogX0oooo00<0000007moO`1oOgl0801oOgl00`000000
oooo0?ooo`0`0?ooo`070000o`3oool0003o0?ooo`000?l0oooo0000o`0^0?ooo`80o`0000<0oooo
0?l0003o0000f`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo000X0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool0o`3ooomj0?ooo`030000001oOgl0Ogmo
0200Ogmo00<000000?ooo`3oool0<@3oool010000?l0oooo0000o`000?l20?ooo`030000o`3oool0
oooo02`0oooo0`3o00000`3oool0o`000?ooo`3I0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?oo
ogX0oooo00<0000007moO`1oOgl0801oOgl00`000000oooo0?ooo`0a0?ooo`070000o`3oool0003o
0?ooo`000?l0oooo0000o`0^0?ooo`80o`0000<0oooo0?l0003o0000fP3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0o`3ooomj0?ooob@00000=03oool010000?l0oooo0000o`000?l20?ooo`030000o`3o
ool0oooo02`0oooo0P3o00000`3oool0o`000?l0003I0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3o
0?ooogX0oooo0P00000Q07moO`030000003oool0oooo0380oooo00<0003o0?ooo`3oool00P000?l0
0`3oool0003o0?ooo`0]0?ooo`80o`0000<0oooo0?l0003o0000f@3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0o`3ooomj0?ooo`8000008@1oOgl00`000000oooo0?ooo`0c0?ooo`070000o`3oool0003o
0?ooo`000?l0oooo0000o`0^0?ooo`80o`0000<0oooo0?l0003o0000f03oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0o`3ooomj0?ooo`8000008@1oOgl00`000000oooo0?ooo`0c0?ooo`030000o`3oool0
oooo0080003o0P3oool00`000?l0oooo0?ooo`0[0?ooo`80o`0000@0oooo0?l0003oool0o`00e`3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0
oooo00l0ooooo`3o0?mo0?l0o`030000001oOgl0Ogmo01h0Ogmo00<000000?ooo`3oool0=03oool0
1`000?l0oooo0000o`3oool0003o0?ooo`000?l0;P3oool20?l000030?ooo`3o0000o`000=L0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo0?l0ooooM@3oool40?l0o`040?ooo`000000000000000200Ogmo
00<000000?ooo`3oool0=@3oool010000?l0oooo0000o`000?l20?ooo`030000o`3oool0oooo02/0
oooo00@0o`000?ooo`3o0000oooo0P3o003F0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool01@3oool002P0oooo00<000000?ooo`3oool03`3ooooo0?l007@0o`00103o0?l70?l00003
0000001oOgl0Ogmo01h0Ogmo00<000000?ooo`3oool0=@3oool01`000?l0oooo0000o`3oool0003o
0?ooo`000?l0;P3oool20?l000030?ooo`3o0000o`000=H0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`0?0?ooool00?l0L000o`040?l0
o`@00?l0103o0003003o00030000001oOgl0Ogmo01h0Ogmo00<000000?ooo`3oool0=P3oool01`00
0?l0oooo0000o`3oool0003o0?ooo`000?l0;P3oool20?l000030?ooo`3o0000o`000=D0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo0?l0ooooJ@3oool40?l0o`@0oooo103o0004003o00040?ooo`000000
000000000200Ogmo00<000000?ooo`3oool0=P3oool00`000?l0oooo0?ooo`020000o`80oooo00<0
003o0?ooo`3oool0:`3oool20?l000040?ooo`3o0000oooo0?l00=@0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`050?ooo`00:03oool4000000h0ooooo`000?mW0000o`D0o`3o0`00
0?l50?l000@00?l020000?lP07moO`030000003oool0oooo03L0oooo00L0003o0?ooo`000?l0oooo
0000o`3oool0003o02h0oooo0P3o00000`3oool0o`000?l0003D0?ooo`030000003oool0oooo00d0
oooo100000070?ooo`00:03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0oooo
H03oool40?l0o`@0oooo103o0005003o00D0oooo10000?l300000200Ogmo00<000000?ooo`3oool0
=`3oool00`000?l0oooo0?ooo`020000o`80oooo00<0003o0?ooo`3oool0:`3oool20?l00080oooo
0P3o003C0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool002P0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?oooe`0oooo103o0?l40?ooo`@0o`001000
o`050?ooo`D0003o103oool00`000000Ogmo07moO`0P07moO`030000003oool0oooo03P0oooo00D0
003o0?ooo`000?l0oooo0000o`020?ooo`030000o`3oool0oooo02/0oooo0P3o00000`3oool0o`00
0?l0003C0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool002P0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?oooeP0oooo103o0?l40?ooo`@0o`001000
o`050?ooo`@0003o2@3oool00`000000Ogmo0000000P07moO`030000003oool0oooo03P0oooo00<0
003o0?ooo`3oool00P000?l20?ooo`030000o`3oool0oooo02/0oooo00@0o`000?ooo`3o0000oooo
0P3o003B0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool002P0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?oooe@0oooo103o0?l40?ooo`@0o`001000
o`050?ooo`@0003o3@3ooolT000003/0oooo00D0003o0?ooo`000?l0oooo0000o`020?ooo`030000
o`3oool0oooo02/0oooo0P3o0000103oool0o`000?ooo`3o003A0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`3o0?oooe00oooo103o0?l30?ooo`D0o`001000o`040?ooo`D0003o4@3oool00`000000Ogmo
0000000P07moO`030000003oool0oooo03X0oooo00L0003o0?ooo`000?l0oooo0000o`3oool0003o
02d0oooo00@0o`000?ooo`3o0000oooo0P3o003A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?oo
od`0oooo103o0?l30?ooo`@0o`001@00o`040?ooo`@0003o5P3oool00`000000Ogmo0000000P07mo
O`030000003oool0oooo03X0oooo00<0003o0?ooo`3oool00P000?l20?ooo`030000o`3oool0oooo
02/0oooo0P3o0000103oool0o`000?ooo`3o003@0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?oo
odP0oooo103o0?l30?ooo`@0o`001000o`050?ooo`@0003o6P3oool00`000000Ogmo0000000P07mo
O`030000003oool0oooo03/0oooo00D0003o0?ooo`000?l0oooo0000o`020?ooo`030000o`3oool0
oooo02/0oooo0P3o00000`3oool0o`000?l0003@0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?oo
od@0oooo103o0?l30?ooo`@0o`001000o`040?ooo`D0003o7P3oool00`000000Ogmo07moO`0P07mo
O`030000003oool0oooo03/0oooo00<0003o0?ooo`3oool00P000?l20?ooo`030000o`3oool0oooo
02/0oooo0P3o00020?ooo`80o`00c`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
00D0oooo000X0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0o`3ooom00?ooo`@0
o`3o0`3oool40?l000@00?l0103oool40000ob<0oooo00<0000007moO`1oOgl0801oOgl00`000000
oooo0?ooo`0l0?ooo`050000o`3oool0003o0?ooo`000?l00P3oool00`000?l0oooo0?ooo`0[0?oo
o`80o`0000@0oooo0?l0003oool0o`00cP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo00D0oooo000X0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0o`3oooll0?oo
o`@0o`3o0P3oool50?l000@00?l0103oool40000obL0oooo00<0000007moO`1oOgl0801oOgl00`00
0000oooo0?ooo`0l0?ooo`080000o`3oool0oooo0000o`3oool0003o0?ooo`000?l]0?ooo`040?l0
003oool0o`000?ooo`80o`00cP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0
oooo000X0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0o`3ooolg0?ooo`D0o`3o
0P3oool40?l000D00?l0103oool40000ob/0oooo00@0000007moO`1oOgl000007`1oOgl00`000000
oooo0?ooo`0m0?ooo`050000o`3oool0003o0?ooo`000?l00P3oool00`000?l0oooo0?ooo`0[0?oo
o`80o`0000@0oooo0?l0003oool0o`00c@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo00D0oooo000X0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0o`3ooolc0?oo
o`@0o`3o0`3oool40?l000@00?l0103oool50000obl0oooo00@0000007moO`1oOgl000007`1oOgl0
0`000000oooo0?ooo`0n0?ooo`050000o`3oool0003o0?ooo`000?l00P3oool00`000?l0oooo0?oo
o`0Z0?ooo`040?l0003oool0o`000?ooo`80o`00c@3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0o`3o
ool_0?ooo`@0o`3o0`3oool40?l000@00?l0103oool40000oc@0oooo00@0000007moO`1oOgl00000
7`1oOgl00`000000oooo0?ooo`0n0?ooo`030000o`3oool0oooo0080003o0P3oool00`000?l0oooo
0?ooo`0[0?ooo`80o`000P3oool20?l00<`0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0oooo:`3o
ool40?l0o`<0oooo103o0004003o00@0oooo10000?lh0?ooo`040000001oOgl0Ogmo000001l0Ogmo
00<000000?ooo`3oool0?`3oool01@000?l0oooo0000o`3oool0003o0080oooo00<0003o0?ooo`3o
ool0:P3oool01`3o0000oooo0?l0003oool0o`000?ooo`3o0000b`3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0o`3ooolW0?ooo`@0o`3o0P3oool50?l000@00?l00`3oool50000oc`0oooo00@0000007mo
O`1oOgl000007`1oOgl00`000000oooo0?ooo`0o0?ooo`080000o`3oool0oooo0000o`3oool0003o
0?ooo`000?l]0?ooo`80o`000P3oool20?l00</0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0oooo
8`3oool40?l0o`80oooo103o0005003o00<0oooo10000?m10?ooo`030000001oOgl0Ogmo0200Ogmo
00<000000?ooo`3oool0@03oool01@000?l0oooo0000o`3oool0003o0080oooo00<0003o0?ooo`3o
ool0:`3oool20?l000040?ooo`3o0000oooo0?l00<X0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`050?ooo`00:03oool4000000h0oooo00<000000?ooo`3oool0o`3ooolO0?ooo`@0
o`3o0P3oool40?l000@00?l0103oool40000odD0oooo00<0000007moO`1oOgl0801oOgl00`000000
oooo0?ooo`100?ooo`060000o`3oool0oooo0000o`3oool0003o0P3oool00`000?l0oooo0?ooo`0Z
0?ooo`80o`000P3oool20?l00<X0oooo00<000000?ooo`3oool03@3oool4000000L0oooo000X0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool0o`3ooolK0?ooo`@0o`3o0P3oool40?l0
00@00?l0103oool40000odT0oooo00D0000007moO`1oOgl0Ogmo0000000N07moO`030000003oool0
oooo0440oooo00D0003o0?ooo`000?l0oooo0000o`020?ooo`030000o`3oool0oooo02/0oooo0P3o
00020?ooo`80o`00b@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo000X
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0o`3ooolG0?ooo`@0o`3o0P3oool4
0?l000@00?l00`3oool50000odd0oooo00D0000007moO`1oOgl0Ogmo0000000N07moO`030000003o
ool0oooo0440oooo00H0003o0?ooo`3oool0003o0?ooo`000?l20?ooo`030000o`3oool0oooo02X0
oooo00L0o`000?ooo`3o0000oooo0?l0003oool0o`000<P0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
0?l0oooo4`3oool40?l0o`030?ooo`3o0000o`0000<0o`001000o`030?ooo`@0003oDP3oool01@00
0000Ogmo07moO`1oOgl0000001h0Ogmo00<000000?ooo`3oool0@P3oool00`000?l0oooo0?ooo`02
0000o`80oooo00<0003o0?ooo`3oool0:`3oool20?l00080oooo0P3o00380?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`3o0?ooo`l0oooo103o0?l00`3oool0o`000?l000020?l000D00?l00`3oool40000
oeH0oooo00D0000007moO`1oOgl0Ogmo0000000N07moO`030000003oool0oooo04<0oooo00D0003o
0?ooo`000?l0oooo0000o`020?ooo`030000o`3oool0oooo02X0oooo00L0o`000?ooo`3o0000oooo
0?l0003oool0o`000<L0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`050?ooo`00
:03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0oooo2P3oool50?l0o`030?oo
o`3o0000o`000080o`001000o`030?ooo`D0003oFP3oool01@000000Ogmo07moO`1oOgl0000001h0
Ogmo00<000000?ooo`3oool0@`3oool01P000?l0oooo0?ooo`000?l0oooo0000o`80oooo00<0003o
0?ooo`3oool0:P3oool20?l00080oooo0P3o00370?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?oo
o`H0oooo103o0?l20?ooo`@0o`001000o`030?ooo`@0003oG`3oool01@000000Ogmo07moO`1oOgl0
000001h0Ogmo00<000000?ooo`3oool0A03oool01@000?l0oooo0000o`3oool0003o0080oooo00<0
003o0?ooo`3oool0:P3oool00`3o0000oooo0?l000020?ooo`80o`00aP3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0o`3oool20?ooo`@0o`3o0P3oool40?l000@00?l00`3oool40000of<0oooo00D00000
07moO`1oOgl0Ogmo0000000N07moO`030000003oool0oooo04@0oooo00H0003o0?ooo`3oool0003o
0?ooo`000?l20?ooo`030000o`3oool0oooo02X0oooo0P3o00020?ooo`030?l0003oool0o`000<D0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo0?d0oooo103o0?l20?ooo`@0o`001000o`020?ooo`D0003o
I`3oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo01/0Ogmo00<000000?ooo`3oool0
A@3oool01@000?l0oooo0000o`3oool0003o0080oooo00<0003o0?ooo`3oool0:`3oool20?l00080
oooo0P3o00350?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool002P0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3i0?ooo`@0o`3o00<0oooo0?l0003o0000
0`3o0004003o0080oooo10000?m/0?ooob@00000A`3oool01P000?l0oooo0?ooo`000?l0oooo0000
o`80oooo00<0003o0?ooo`3oool0:P3oool01`3o0000oooo0?l0003oool0o`000?ooo`3o0000a03o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0m@3oool40?l0o`030?ooo`3o0000o`000080o`001@00o`02
0?ooo`@0003oL03oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo01/0Ogmo00<00000
0?ooo`3oool0AP3oool01P000?l0oooo0?ooo`000?l0oooo0000o`80oooo00<0003o0?ooo`3oool0
:P3oool20?l00080oooo0P3o00340?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
1@3oool002P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3a0?ooo`@0o`3o00<0
oooo0?l0003o00000P3o0004003o00<0oooo10000?md0?ooo`030000001oOgl0Ogmo0080Ogmo00<0
000007moO`1oOgl06`1oOgl00`000000oooo0?ooo`160?ooo`060000o`3oool0oooo0000o`3oool0
003o0P3oool00`000?l0oooo0?ooo`0Z0?ooo`030?l0003oool0o`000080oooo0P3o00330?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`3]0?ooo`@0o`3o00<0oooo0?l0003o00000P3o0004003o0080oooo
1@000?mh0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl06`1oOgl00`000000oooo
0?ooo`170?ooo`060000o`3oool0oooo0000o`3oool0003o0P3oool00`000?l0oooo0?ooo`0Z0?oo
o`80o`000P3oool00`3o0000oooo0?l000320?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool01@3oool002P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3Y0?ooo`@0
o`3o00<0oooo0?l0003o00000P3o0004003o0080oooo10000?mm0?ooo`030000001oOgl0Ogmo0080
Ogmo00<0000007moO`1oOgl06`1oOgl00`000000oooo0?ooo`180?ooo`050000o`3oool0003o0?oo
o`000?l00P3oool00`000?l0oooo0?ooo`0Z0?ooo`030?l0003oool0o`000080oooo0P3o00320?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3o
ool03`3oooo/0?l0o`D0o`001000o`020?l0o`@0003oQ`3o0?lM07moO`030000003oool0oooo04P0
oooo00H0003o0?ooo`3oool0003o0?ooo`000?l20?ooo`030000o`3oool0oooo02X0oooo0P3o0002
0?ooo`030?l0003oool0o`000<40oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`05
0?ooo`00:03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0>00oooo1@3o0?l40?l0
00D00?l000<0oooo0000o`000?l00`000?n10?ooo`H0o`3o0P1oOgl2000001d0Ogmo00<000000?oo
o`3oool0B@3oool00`000?l0oooo0000o`020?ooo`040000o`3oool0oooo0000ob/0oooo00<0o`00
0?ooo`3o00000P3oool20?l00<40oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`05
0?ooo`00:03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0=`0oooo103o0?l00`3o
ool0o`000?l000020?l000@00?l00P3oool40000oh40oooo1@3o0?l40?ooo`030000001oOgl0Ogmo
0080Ogmo00<0000007moO`1oOgl06`1oOgl00`000000oooo0?ooo`190?ooo`060000o`3oool0oooo
0000o`3oool0003o0P3oool00`000?l0oooo0?ooo`0Z0?ooo`80o`000`3oool20?l00<00oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo0=P0oooo103o0?l00`3oool0o`000?l000020?l000@00?l00P3oool4
0000ogl0oooo1P3o0?l90?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl06`1oOgl0
0`000000oooo0?ooo`1:0?ooo`060000o`3oool0oooo0000o`3oool0003o0P3oool00`000?l0oooo
0?ooo`0Z0?ooo`80o`000P3oool00`3o0000oooo0?l0002o0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool01@3oool002P0oooo1000000>0?ooo`030000003oool0oooo0=@0oooo103o
0?l00`3oool0o`000?l000020?l000@00?l000<0oooo0000o`000?l00`000?mm0?ooo`H0o`3o3`3o
ool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo01/0Ogmo00<000000?ooo`3oool0BP3o
ool01P000?l0oooo0?ooo`000?l0oooo0000o`<0oooo00<0003o0?ooo`3oool0:@3oool00`3o0000
oooo0?l000020?ooo`80o`00_`3oool00`000000oooo0?ooo`0=0?ooo`@000001`3oool002P0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3@0?ooo`@0o`3o1@3o0004003o00030?oo
o`000?l0003o0080003oO03oool60?l0oaD0oooo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo
07moO`0K07moO`030000003oool0oooo04/0oooo00H0003o0?ooo`3oool0003o0?ooo`000?l20?oo
o`030000o`3oool0oooo02X0oooo0P3o00020?ooo`030?l0003oool0o`000;h0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo0<`0oooo103o0?l40?l000D00?l000<0oooo0000o`000?l00P000?mk0?ooo`D0
o`3o6`3oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo01/0Ogmo00<000000?ooo`3o
ool0C03oool01@000?l0oooo0000o`3oool0003o00<0oooo00<0003o0?ooo`3oool0503oool40000
0080oooo00@000000?ooo`00000000000`3oool2000000H0oooo00<0o`000?ooo`3o00000P3oool2
0?l001D0oooo0`0000030?ooo`D000000P3oool3000009T0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`0?0?oool/0o`00103o0?l40?l0
00@00?l00P3o00040000ogT0o`001P3o0?lV0?l000030000001oOgl0Ogmo01X0Ogmo00<000000?oo
o`3oool0C03oool01P000?l0oooo0?ooo`000?l0oooo0000o`80oooo00<0003o0?ooo`3oool05@3o
ool01@000000oooo0?ooo`000000oooo008000000P3oool00`000000oooo000000020?ooo`030000
003oool0oooo00@0oooo0P3o00030?ooo`80o`005@3oool00`000000oooo0?ooo`030?ooo`040000
003oool0oooo000000<0oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
a03oool40?l0o`@0o`001000o`000`3oool0003o0000o`030000ogL0oooo1P3o0?lR0?ooo`H0o`00
0`1oOgl2000001`0Ogmo00<000000?ooo`3oool0C@3oool00`000?l0oooo0000o`020?ooo`040000
o`3oool0oooo0000oaH0oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`800000103oool0
0`000000oooo0?ooo`040?ooo`030?l0003oool0o`000080oooo00<0o`000?ooo`3o0000503oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0V03oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0`03oool40?l0o`@0o`001000o`000`3oool0003o0000o`020000
ogH0oooo1P3o0?lQ0?ooo`L0o`00103oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo
01X0Ogmo00<000000?ooo`3oool0C@3oool01P000?l0oooo0?ooo`000?l0oooo0000o`<0oooo00<0
003o0?ooo`3oool04`3oool3000000<0oooo0`0000030?ooo`800000203oool20?l000<0oooo0P3o
000D0?ooo`<000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo09P0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo0;`0oooo103o0?l40?l000@00?l000<0oooo0000o`000?l00P000?me
0?ooo`D0o`3o8@3oool60?l000/0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0J
07moO`030000003oool0oooo04h0oooo00H0003o0?ooo`3oool0003o0?ooo`000?l20?ooo`030000
o`3oool0oooo01<0oooo00D000000?ooo`3oool000000?ooo`0200000080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`050?ooo`030?l0003oool0o`000080oooo00<0o`000?ooo`3o
00004`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0V03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0^03oool40?l0o`<0o`001@00o`050000og<0oooo
1P3o0?lP0?ooo`H0o`004@3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo01X0Ogmo
00<000000?ooo`3oool0CP3oool01P000?l0oooo0?ooo`000?l0oooo0000o`<0oooo00<0003o0?oo
o`3oool04P3oool01P000000oooo0?ooo`000000oooo00000080oooo0P0000001@3oool000000?oo
o`3oool0000000P0oooo00<0o`000?ooo`3o00000P3oool00`3o0000oooo0?l0000B0?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool2000009X0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo0;<0oooo1@3o0?l30?l000@00?l000<0oooo0000o`000?l00P000?mb0?ooo`H0o`3o
803oool60?l001L0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0J07moO`030000
003oool0oooo04l0oooo00H0003o0?ooo`3oool0003o0?ooo`000?l20?ooo`030000o`3oool0oooo
0140oooo100000030?ooo`80000000@0oooo0000003oool0oooo0P00000:0?ooo`80o`000`3oool2
0?l00140oooo1@000000103oool000000000000000050?ooo`030000003oool0oooo09P0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo0:l0oooo103o0?l40?l000@00?l000<0oooo0000o`000?l00P000?m`
0?ooo`H0o`3o7`3oool70?l001d0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0J
07moO`030000003oool0oooo04l0oooo00@0003o0?ooo`3oool0003o0P3oool010000?l0oooo0?oo
o`000?l[0?ooo`030?l0003oool0o`000080oooo00<0o`000?ooo`3o0000^@3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0Z`3oool40?l0o`@0o`001000o`000`3oool0003o0000o`020000ofl0oooo1@3o
0?lO0?ooo`H0o`00903oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo01X0Ogmo00<0
00000?ooo`3oool0D03oool01P000?l0oooo0?ooo`000?l0oooo0000o`<0oooo00<0003o0?ooo`3o
ool0:@3oool20?l000<0oooo0P3o002i0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool01@3oool002P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`2W0?ooo`@0o`3o
103o0004003o00D0003oK@3oool60?l0oah0oooo1P3o000Z0?ooo`030000001oOgl0Ogmo00<0Ogmo
00<0000007moO`1oOgl06P1oOgl00`000000oooo0?ooo`1A0?ooo`030000o`3oool0003o0080oooo
00@0003o0?ooo`3oool0003o:`3oool00`3o0000oooo0?l000020?ooo`030?l0003oool0o`000;P0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo0:<0oooo103o0?l30?l000D00?l010000?m/0?ooo`H0o`3o
7@3oool70?l00300oooo00<0000007moO`1oOgl00`1oOgl2000001/0Ogmo00<000000?ooo`3oool0
D@3oool01P000?l0oooo0?ooo`000?l0oooo0000o`<0oooo00<0003o0?ooo`3oool0:@3oool20?l0
00<0oooo00<0o`000?ooo`3o0000]`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
00D0oooo000X0?ooo`030000003oool0oooo00l0ooooXP00o`040?l0o`<0o`001@00o`040000ofX0
0?l01P3o0?lM003o00H0o`00?P00o`000`000000Ogmo07moO`0I07moO`030000003oool0oooo0580
oooo00H0003o0?ooo`3oool0003o0?ooo`000?l20?ooo`030000o`3oool0oooo02T0oooo00<0o`00
0?ooo`3o00000P3oool00`3o0000oooo0?l0002g0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`2K0?oo
o`@0o`3o0`3o0004003o00D0003oJ@3oool50?l0oad0oooo1P3o000h0?ooo`L00?l0101oOgl00`00
0000Ogmo07moO`0J07moO`030000003oool0oooo0580oooo00@0003o0?ooo`3oool0003o0P3oool0
10000?l0oooo0?ooo`000?l[0?ooo`80o`000`3oool00`3o0000oooo0?l0002f0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool01@3oool000l0oooo100000020?ooo`8000000`3oool2
000000`0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`2G0?ooo`@0o`3o0`3o0004
003o00@0003oJ03oool60?l0oa`0oooo1P3o000g0?ooo`L00?l01@3oool00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo01X0Ogmo00<000000?ooo`3oool0D`3oool01P000?l0oooo0?ooo`00
0?l0oooo0000o`<0oooo00<0003o0?ooo`3oool0:03oool00`3o0000oooo0?l000030?ooo`80o`00
]P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo000?0?ooo`060000003o
ool0oooo0000003oool000000P3oool00`000000oooo000000020?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`2C0?ooo`@0o`3o0`3o0004003o00@0
003oIP3oool60?l0oa/0oooo1`3o000f0?ooo`L00?l0303oool00`000000Ogmo07moO`0307moO`03
0000001oOgl0Ogmo01X0Ogmo00<000000?ooo`3oool0D`3oool010000?l0oooo0?ooo`000?l20?oo
o`040000o`3oool0oooo0000ob/0oooo00<0o`000?ooo`3o00000P3oool00`3o0000oooo0?l0002e
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool000`0oooo0`0000000`3o
ool000000?ooo`020?ooo`060000003oool0oooo0000003oool000000P3oool00`000000oooo0?oo
o`090?ooo`H00000303oool00`000000oooo0?ooo`2?0?ooo`@0o`3o0P3o0005003o00@0003oI03o
ool60?l0oa/0oooo1P3o000f0?ooo`L00?l04`3oool00`000000Ogmo07moO`0307moO`030000001o
Ogl0Ogmo01X0Ogmo00<000000?ooo`3oool0E03oool01P000?l0oooo0?ooo`000?l0oooo0000o`<0
oooo00<0003o0?ooo`3oool0:@3oool20?l000<0oooo00<0o`000?ooo`3o0000]03oool00`000000
oooo0?ooo`0;0?ooo`H000001`3oool00140oooo00@000000?ooo`3oool000000P3oool00`000000
oooo000000020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`2:0?ooo`D0o`3o0P3o0004003o00@0003oI03oool50?l0oa/0oooo1P3o000d0?ooo`P0
0?l06P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo01X0Ogmo00<000000?ooo`3o
ool0E@3oool00`000?l0oooo0000o`020?ooo`040000o`3oool0oooo0000ob/0oooo00<0o`000?oo
o`3o00000P3oool00`3o0000oooo0?l0002d0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool01@3oool00180oooo00<000000?ooo`0000000P3oool00`000000oooo000000020?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`260?ooo`@0
o`3o0`3o0004003o00@0003oHP3oool60?l0oaX0oooo1P3o000c0?ooo`L00?l08P3ooolT000005L0
oooo00H0003o0?ooo`3oool0003o0?ooo`000?l30?ooo`030000o`3oool0oooo02T0oooo0P3o0003
0?ooo`030?l0003oool0o`000;<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`05
0?ooo`003`3oool01P000000oooo0?ooo`000000oooo00000080oooo00<000000?ooo`0000000P3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0PP3o
ool40?l0o`<0o`001000o`040000of00oooo1P3o0?lI0?ooo`L0o`00<P3oool7003o02T0oooo00<0
000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0J07moO`030000003oool0oooo05H0oooo00H0
003o0?ooo`3oool0003o0?ooo`000?l30?ooo`030000o`3oool0oooo02P0oooo00<0o`000?ooo`3o
00000`3oool20?l00:l0oooo103o0?l200000140oooo00<000000?ooo`3oool01@3oool00100oooo
0P0000030?ooo`8000000`3oool2000000`0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`1n0?ooo`@0o`3o0`3o0004003o00@0003oGP3oool60?l0oaT0oooo1P3o000b0?ooo`L00?l0
<03oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo01X0Ogmo00<000000?ooo`3oool0
EP3oool010000?l0oooo0?ooo`000?l20?ooo`040000o`3oool0oooo0000ob/0oooo0P3o00030?oo
o`030?l0003oool0o`000:D0oooo2@3o0?l40?ooo`8000004@3oool00`000000oooo0?ooo`050?oo
o`00:03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo07X0oooo103o0?l30?l000@0
0?l00`000?mN0?ooo`D0o`3o6@3oool60?l00340oooo1`00o`0g0?ooo`030000001oOgl0Ogmo00<0
Ogmo00<0000007moO`1oOgl06P1oOgl00`000000oooo0?ooo`1G0?ooo`060000o`3oool0oooo0000
o`3oool0003o0`3oool00`000?l0oooo0?ooo`0X0?ooo`030?l0003oool0o`0000<0oooo00<0o`00
0?ooo`3o0000V`3oool90?l0o`d0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`05
0?ooo`00:03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo07H0oooo103o0?l20?l0
00D00?l00`000?mL0?ooo`H0o`3o603oool60?l00300oooo1`00o`0n0?ooo`030000001oOgl0Ogmo
00<0Ogmo00<0000007moO`1oOgl06P1oOgl00`000000oooo0?ooo`1G0?ooo`040000o`3oool0oooo
0000o`80oooo00@0003o0?ooo`3oool0003o203oool00`000000oooo0?ooo`0P0?ooo`030?l0003o
ool0o`000080oooo00<0o`000?ooo`3o0000TP3oool90?l0oaH0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo0780oooo103o0?l20?l000@00?l010000?mJ0?ooo`H0o`3o5`3oool70?l002h0oooo2000o`15
0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl06P1oOgl00`000000oooo0?ooo`1H
0?ooo`060000o`3oool0oooo0000o`3oool0003o0`3oool00`000?l0oooo0?ooo`050?ooo`030000
003oool0oooo0200oooo00<0o`000?ooo`3o00000`3oool00`3o0000oooo0?l000280?ooo`T0o`3o
7`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0KP3oool40?l0o`80o`001000o`030000oeT0oooo1P3o
0?lG0?ooo`H0o`00;P3oool7003o04d0oooo00<0000007moO`1oOgl00`1oOgl2000001/0Ogmo00<0
00000?ooo`3oool0F03oool010000?l0oooo0?ooo`000?l20?ooo`050000o`3oool0oooo0?ooo`00
0?l01@3oool00`000000oooo0?ooo`0R0?ooo`030?l0003oool0o`0000<0oooo0P3o001o0?ooo`T0
o`3o:03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000
003oool0oooo00l0ooooK@000?l40?l0o`80o`001000o`1J0000o`H0o`3o5`000?l60?l002d0003o
1`00o`1L0000oa/0Ogmo00<000000?ooo`3oool0F@3oool010000?l0oooo0?ooo`000?l20?ooo`04
0000o`3oool0oooo0000o`@0oooo0P00000U0?ooo`80o`000`3oool00`3o0000oooo0?l0000@0?oo
o`030000003oool0oooo06<0oooo203o0?lY0?ooo`P0o`3o0P00000A0?ooo`030000003oool0oooo
00D0oooo000X0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0IP3oool40?l0o`80
o`001000o`030000oeH0oooo1@3o0?lF0?ooo`L0o`00;03oool7003o05D0oooo2@000?l407moO`03
0000001oOgl0Ogmo01T0Ogmo00<000000?ooo`3oool0FP3oool01P000?l0oooo0?ooo`000?l0oooo
0000o`<0oooo00D0003o0?ooo`3oool0oooo0000000V0?ooo`030?l0003oool0o`0000<0oooo00<0
o`000?ooo`3o00003`3oool00`000000oooo0?ooo`1J0?ooo`T0o`3o8@3oool@0?l0o`P0oooo0P00
000A0?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0HP3oool40?l0o`030?l00000o`000?l000<00?l00P000?mE0?ooo`H0o`3o5@3oool6
0?l002`0oooo1`00o`1C0?ooo`T0003o1P3oool00`000000Ogmo07moO`0407moO`030000001oOgl0
Ogmo01T0Ogmo00<000000?ooo`3oool0FP3oool010000?l0oooo0?ooo`000?l20?ooo`040000o`3o
ool0oooo0000o`80oooo0P00000W0?ooo`80o`000`3oool00`3o0000oooo0?l0000>0?ooo`800000
D`3oool90?l0oaX0oooo403o0?lH0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
1@3oool002P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1M0?ooo`D0o`3o00<0
o`00003o0000o`000P00o`030000oe<0oooo1P3o0?lE0?ooo`H0o`00:P3oool8003o0540oooo2@00
0?l?0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl06@1oOgl00`000000oooo0?oo
o`1K0?ooo`060000o`3oool0oooo0000o`3oool0003o0`3oool00`000?l000000000000X0?ooo`03
0?l0003oool0o`0000<0oooo00<0o`000?ooo`3o00003@3oool2000004X0oooo2@3o0?lC0?oooa00
o`3o:03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0F@3oool40?l0o`80o`001000o`030000oe40oooo
1P3o0?lE0?ooo`H0o`00:@3oool7003o0500oooo2@000?lH0?ooo`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`1oOgl06@1oOgl00`000000oooo0?ooo`1K0?ooo`040000o`3oool0oooo0000o`80
oooo00@0003o0?ooo`3oool000008@3o0?l:0?ooo`80o`00103oool20?l000`0oooo100000100?oo
o`T0o`3o303oool@0?l0obP0oooo403o0?l200000140oooo00<000000?ooo`3oool01@3oool002P0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1E0?ooo`@0o`3o0P3o0004003o00<0
003oD03oool50?l0oa@0oooo1`3o000X0?ooo`L00?l0C`3oool80000ob40oooo00<0000007moO`1o
Ogl0101oOgl00`000000Ogmo07moO`0I07moO`030000003oool0oooo05`0oooo00@0003o0?ooo`3o
ool0003o0P3oool010000?l0oooo0000003o0?lP0?ooobH0o`3o<`3oool90?l0o`H0oooo3`3o0?lH
0?ooob00o`3o403oool200000140oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?oo
o`3oool03`3ooomH0?l0o`80o`001000o`020000ofP0o`3o1P3o000X0?l0o`L00?l0C@3o0?l90000
oc40o`3o00<0000007moO`1oOgl0601oOgl00`000000oooo0?ooo`1L0?ooo`040000o`3oool0oooo
0000o`80oooo00<0003o0000003o0?l0?P3o0?l00`000000o`3o0?l0o`02000000@0oooo2@3o0?lR
0?oooaL0o`3o1`3ooolP0?l0oc00oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`05
0?ooo`00:03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo04d0oooo103o0?l00`3o
00000?l0003o0003003o0080003oC@3oool60?l0oa<0oooo1P3o000W0?ooo`L00?l0B`3oool90000
obX0oooo2P3o0?l507moO`8000006P1oOgl00`000000oooo0?ooo`1M0?ooo`040000o`3oool0oooo
0000o`80oooo@03o0?l00`000000o`3o0?l0o`0>0?l0o`030?ooo`3o0?l0o`3o00L0o`3o403ooolW
0?l0oe00oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`050?ooo`00:03oool40000
00h0oooo00<000000?ooo`3oool0B@3oool40?l0o`030?l00000o`000?l000800?l00`000?m;0?oo
o`H0o`3o4`3oool60?l002H0oooo1`00o`190?ooo`T0003o:P3oool90?l0o`P0oooo00<0000007mo
O`1oOgl0101oOgl00`000000Ogmo07moO`0I07moO`030000003oool0oooo05d0oooo00/0003o0?oo
o`3oool0oooo0000o`000000o`3o0?ooo`3o0?l0oooo0?l0o`0Z0?ooo`030?l0003oool0o`0000<0
oooo00<0o`000?ooo`3o0000203oool5000000L0oooo9`3o0?m_0?ooo`030000003oool0oooo00d0
oooo100000070?ooo`00:03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo04D0oooo
103o0?l00`3o00000?l0003o0002003o0080003oB`3oool50?l0oa80oooo1`3o000T0?ooo`P00?l0
A`3oool90000obT0oooo2P3o0?lA0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0
6@1oOgl00`000000oooo0?ooo`1N0?ooo`060000o`3oool0oooo0000o`000000oooo0P3o0?l20?oo
o`030?l0o`3oool0oooo01P0oooo803o0?l00`000000o`3o0?l0o`130?l0oe`0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo0440oooo103o0?l00`3o00000?l0003o0002003o0080003oB@3oool60?l0oa40
oooo1P3o000T0?ooo`L00?l0A`3oool80000obP0oooo2P3o0?lK0?ooo`030000001oOgl0Ogmo00@0
Ogmo00<0000007moO`1oOgl06@1oOgl00`000000oooo0?ooo`1O0?ooo`030000o`3oool000000440
o`3o00<000000?l0o`3o0?l0203o0?l50?ooo`T0o`3o4`3oool@0?l0o`X0oooo6`3o0?m10?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0m0?ooo`@0o`3o00<0o`00003o0000o`000P00o`020000odL0oooo
1P3o0?lA0?ooo`H0o`008`3oool7003o04D0oooo2@000?lV0?ooo`X0o`3o9@3oool00`000000Ogmo
07moO`0407moO`030000001oOgl0Ogmo01T0Ogmo00<000000?ooo`3oool0G`3oool00`000?l00000
0?l0o`0Q0?l0oa40oooo0P3o00040?ooo`030?l0003oool0o`0000H0oooo1@0000020?ooo`T0o`3o
9`3ooolE0?l0oaD0oooo6P3o0?lW0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
1@3oool002P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0i0?ooo`@0o`3o1@00
o`020000odD0oooo1P3o0?l@0?ooo`L0o`008P3oool7003o04<0oooo2@000?lU0?ooo`X0o`3o;`3o
ool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo01T0Ogmo00<000000?ooo`3oool0H03o
ool010000?l000000?ooo`3o0?l20?ooo`80o`3o00<0oooo0000o`3o0?l05`3ooolX0?l0ocX0oooo
2@3o0?l20?ooo`l0o`3o803ooolK0?l0o``0oooo0P00000A0?ooo`030000003oool0oooo00D0oooo
000X0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0=@3oool40?l0o`@00?l00P00
0?m50?ooo`D0o`3o403oool60?l00280oooo1`00o`110?ooo`T0003o9@3oool90?l0ocT0oooo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0I07moO`030000003oool0oooo05l0oooo00<0
00000?l0o`3o0?l0803o0?lC0?ooo`030?l0003oool0o`0000<0oooo00<0o`000?ooo`3o00001`3o
ool2000004H0oooo2P3o0?l70?oooa00o`3o:`3oool<0?l0o`8000004@3oool00`000000oooo0?oo
o`050?ooo`00:03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01L0oooo2000000A
0?ooo`D0o`3o1000o`020000od<0oooo1P3o0?l?0?ooo`H0o`00803oool8003o03l0oooo2@000?lT
0?ooo`X0o`3o@P3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo01T0Ogmo00<00000
0?ooo`3oool0G`3oool2000000040000o`3o0?l0oooo0?l0o`80oooo0P3o0?l20?ooo`030?l0o`3o
ool0oooo02L0oooo00<0o`000?ooo`3o0000103oool20?l000L0oooo0P00001@0?ooo`T0o`3o3P3o
ool@0?l0obL0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`050?ooo`00:03oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01L0oooo00<0000007moO`1oOgl0101oOgl0
0`000000oooo0?ooo`0;0?ooo`@0o`3o00<0o`00003o0000o`000P00o`020000od40oooo1P3o0?l?
0?ooo`H0o`007`3oool7003o03l0oooo20000?lS0?ooo`X0o`3oC03oool00`000000Ogmo07moO`04
07moO`030000001oOgl0Ogmo01T0Ogmo00<000000?ooo`3oool0G`3oool03@000000oooo0?l0o`3o
ool0o`3o0?ooo`3o0?l0oooo0?l0o`000?l0o`3o0?ooo`3o0?l0:P3oool00`3o0000oooo0?l00003
0?ooo`030?l0003oool0o`0000H0oooo0P00001I0?ooo`T0o`3o5@3oool@0?l0oaL0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo01L0oooo200000090?ooo`@0o`3o00<0o`00003o0000o`000P00o`000`00
0?l0oooo0?ooo`0n0?ooo`H0o`3o3P3oool70?l001h0oooo1`00o`0m0?ooo`T0003o8@3oool:0?l0
oeH0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0I07moO`030000003oool0oooo
05h0oooo00P000000?ooo`3oool0o`3o0000o`3o0?l0oooo0?l0o`80oooo00D0o`3o0?ooo`3o0?l0
oooo0?l0o`0Y0?ooo`030?l0003oool0o`0000@0oooo00<0o`000?ooo`3o00001P3oool00`000000
oooo0?ooo`1P0?ooo`X0o`3o6`3oool@0?l0o`L0oooo0P00000A0?ooo`030000003oool0oooo00D0
oooo000X0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool05`3oool00`000000Ogmo
07moO`0407moO`030000003oool0oooo00<0oooo103o0?l5003o00030000o`3oool0oooo03d0oooo
1@3o0?l>0?ooo`H0o`007P3oool7003o03/0oooo2@000?lQ0?ooo`T0o`3oH03oool00`000000Ogmo
07moO`0407moO`030000001oOgl0Ogmo01T0Ogmo00<000000?ooo`3oool0GP3oool02@000000oooo
0?ooo`3oool0o`3o0?ooo`3o0?l0oooo0?l0o`020?ooo`80o`3o00<0oooo0000o`3o0?l0:@3oool0
0`3o0000oooo0?l000030?ooo`030?l0003oool0o`0000H0oooo00<000000?ooo`3oool0JP3oool9
0?l0ob80oooo1`3o0?l200000140oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?oo
o`3oool03`3oool2000001P0oooo0P00000507moO`800000103o0?l4003o0080003o?@3oool60?l0
o`d0oooo1P3o000M0?ooo`L00?l0>@3oool90000ob00oooo2P3o0?mY0?ooo`030000001oOgl0Ogmo
00@0Ogmo00<0000007moO`1oOgl06@1oOgl00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo
0080oooo00<0o`3o0000o`3oool00P3o0?l20?ooo`050?l0o`3oool0o`3o0?ooo`3o0?l0:P3oool2
0?l000@0oooo00<0o`000?ooo`3o0000N`3oool90?l0ob00oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`0?0?ooo`8000006@3o00000`00
0000Ogmo07moO`0307moO`H0o`3o00<0003o0?ooo`3oool0>P3oool60?l0o`d0oooo1P3o000L0?oo
o`L00?l0=`3oool90000oal0oooo2P3o0?mc0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007mo
O`1oOgl06@1oOgl00`000000oooo0?ooo`1L0?ooo`8000001@3oool01@3o0?l0003o0?l0o`3oool0
o`3o0080oooo0P3o0?l20?ooo`030?l0o`3oool0oooo02L0oooo00<0o`000?ooo`3o0000103oool2
0?l008@0oooo2P3o0?lF0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool0
02P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0G0?ooo`L000001P00o`0:0?l0
obd0oooo1P3o0?l<0?ooo`L0o`006P3oool8003o03H0oooo20000?lN0?ooo`X0o`3oO@3oool00`00
0000Ogmo07moO`0407moO`030000001oOgl0Ogmo01T0Ogmo00<000000?ooo`3oool0G03oool00`00
0000oooo0?ooo`050?ooo`040?l0o`3oool0o`3o0?l0o`80oooo00D0o`3o0000o`3o0?l0oooo0?l0
o`0Z0?ooo`80o`00103oool00`3o0000oooo0?l0002=0?ooo`T0o`3o3@3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool05`3oool00`000000Ogmo07moO`0407moO`800000103oool:003o00X0o`3o7P3oool5
0?l0o``0oooo1P3o000J0?ooo`L00?l0=@3oool90000oa`0oooo2P3o0?n70?ooo`030000001oOgl0
Ogmo00D0Ogmo00<0000007moO`1oOgl0601oOgl00`000000oooo0?ooo`1T0?ooo`050?l0o`000?l0
o`3o0?ooo`3o0?l00P3oool01@3o0?l0oooo0?l0o`3oool0o`3o02T0oooo00<0o`000?ooo`3o0000
103oool00`3o0000oooo0?l0002E0?ooo`T0o`3o103oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool05`3o
ool00`000000Ogmo07moO`0407moO`8000003P3oool:003o00/0o`3o3@3oool60?l0o`/0oooo1P3o
000I0?ooo`L00?l0<`3oool90000oa`0oooo2@3o0?nA0?ooo`030000001oOgl0Ogmo00D0Ogmo00<0
000007moO`1oOgl0601oOgl00`000000oooo0?ooo`1U0?ooo`040?l0o`3oool0o`3o0?l0o`<0oooo
0P3o0?l00`3oool0003o0?l0o`0Y0?ooo`030?l0003oool0o`0000<0oooo00<0o`000?ooo`3o0000
WP3oool40?l0o`8000004@3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo01L0oooo00<0000007moO`1oOgl0101oOgl2000001P0oooo2P00
o`000`3o0000o`3o0?l0o`0;0?l0o`/0oooo1P3o000H0?ooo`L00?l0<@3oool90000oa/0oooo2P3o
0?nJ0?ooo`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0601oOgl00`000000oooo0?oo
o`1U0?ooo`050?l0o`000?l0o`3o0?ooo`3o0?l00P3oool01@3o0?l0oooo0?l0o`3oool0o`3o02T0
oooo00<0o`000?ooo`3o0000103oool00`3o0000oooo0?l0002Q0?ooo`8000004@3oool00`000000
oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01L0oooo
00<0000007moO`1oOgl0101oOgl2000002<0oooo2@00o`000`3o0000o`3o0?l0o`080?l0o`@0o`00
5`3oool7003o02l0oooo2@000?lJ0?ooo`X0o`3oY03oool00`000000Ogmo07moO`0507moO`030000
001oOgl0Ogmo01P0Ogmo00<000000?ooo`3oool0IP3oool01@3o0?l0oooo0?l0o`3oool0o`3o0080
oooo0P3o0?l00`3oool0003o0?l0o`0Y0?ooo`030?l0003oool0o`0000<0oooo00<0o`000?ooo`3o
0000X@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool05`3oool00`000000Ogmo07moO`0407moO`800000
7`3oool50?l0o`T0oooo2000o`020?l000X0o`3o2@3oool8003o02h0oooo20000?lI0?ooo`X0o`3o
[P3ooolT000006P0oooo00D0o`3o0000o`3o0?l0oooo0?l0o`020?ooo`050?l0o`000?l0o`3o0?oo
o`3o0?l0:@3oool00`3o0000oooo0?l000040?ooo`030?l0003oool0o`000:00oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`050?ooo`00:03oool4000000h0oooo00<000000?ooo`3o
ool05`3oool00`000000Ogmo07moO`0407moO`8000006@3oool60?l0o`T0oooo1P3o00090?ooo`P0
0?l00P3o000:0?l0ob`0oooo2@000?lH0?ooo`T0o`3o^03oool00`000000Ogmo07moO`0507moO`03
0000001oOgl0Ogmo01P0Ogmo00<000000?ooo`3oool0I`3oool01@3o0?l0oooo0?l0o`3oool0o`3o
0080oooo0P3o0?l20?ooo`030?l0o`3oool0oooo02L0oooo00<0o`000?ooo`3o0000103oool00`3o
0000oooo0?l0002O0?ooo`030000003oool0oooo00d0oooo100000070?ooo`00:03oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo01L0oooo00<0000007moO`1oOgl0101oOgl2000001<0
oooo1P3o0?l80?ooo`L0o`00503oool=003o0080o`002P3o0?lI0?ooo`T0003o5`3oool:0?l0ol40
oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0H07moO`030000003oool0oooo06L0
oooo00D0o`3o0000o`3o0?l0oooo0?l0o`020?ooo`060?l0o`000?l0o`3o0?ooo`000?l0o`3o:@3o
ool20?l000@0oooo00<0o`000?ooo`3o0000W`3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo00D0oooo000X0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool05`3oool9
000000d0oooo1P3o0?l80?ooo`H0o`00503oool7003o00l0oooo2000o`020?l000/0o`3o1@3oool9
0000oaH0oooo2P3o0?o;0?ooo`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0601oOgl0
0`000000oooo0?ooo`0i0?ooo`<000000`3oool200000080oooo1P0000030?ooo`040000003oool0
0000000000<0oooo0P0000020?ooo`030000003oool0oooo00h0oooo00D0o`3o0?ooo`3o0?l0oooo
0?l0o`020?ooo`050?l0o`3oool0o`3o0?ooo`3o0?l05@3oool400000080oooo00@000000?ooo`00
000000000`3oool3000000@0oooo00<0o`000?ooo`3o0000103oool00`3o0000oooo0?l0000F0?oo
o`@000000P3oool010000000oooo0000000000020?ooo`@000008@3oool3000000<0oooo1@000000
0`3oool0000000000002000004L0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`05
0?ooo`00:03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01L0oooo00<0000007mo
O`1oOgl0101oOgl2000000P0oooo1@3o0?l80?ooo`H0o`004`3oool7003o0200oooo2000o`030?l0
00X0o`3o403oool:0?l0omD0oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0H07mo
O`030000003oool0oooo03P0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`8000000P3oool00`000000oooo
000000030?ooo`030000003oool0oooo00l0oooo00<0o`3o0000o`3oool00P3o0?l30?ooo`80o`3o
00<0oooo0000o`3o0?l05@3oool01@000000oooo0?ooo`000000oooo008000000P3oool01@000000
oooo0?ooo`3oool0000000H0oooo00<0o`000?ooo`3o00000`3oool00`3o0000oooo0?l0000G0?oo
o`050000003oool0oooo0000003oool00P0000020?ooo`030000003oool000000080oooo00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`030?ooo`060000003oool0oooo0000003oool00000
0P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
1@3oool002P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0G0?ooo`030000001o
Ogl0Ogmo00@0Ogmo0`0000000`3oool0o`3o0?l0o`040?l0o`L0oooo1P3o000B0?ooo`L00?l09P3o
ool80000o`@0oooo1`00o`030?l00100o`3og`3oool00`000000Ogmo07moO`0507moO`030000001o
Ogl0Ogmo01P0Ogmo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`040?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0200000006
0?ooo`00000000000000003oool000004P3oool01@3o0?l0003o0?l0o`3oool0o`3o0080oooo00H0
o`3o0000o`3o0?l0oooo0000o`3o0?lD0?ooo`060000003oool0oooo0000003oool000000P3oool2
000000<0oooo00<000000?ooo`3oool0103oool00`3o0000oooo0?l000040?ooo`030?l0003oool0
o`0001H0oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`8000000P3oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`170?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool002P0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0G0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0
00000?l0o`3o0?l01P3o0?l00`3oool0o`000?l000050?l00100oooo2000o`0T0?ooo`T0003o4`3o
ool30?l0o`L00?l00`3o000:0?l0om/0oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07mo
O`0H07moO`030000003oool0oooo03L0oooo00<000000?ooo`3oool0103oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo000000D0oooo0`0000020?ooo`050000003oool000000?oo
o`0000004`3oool0103o0?l0oooo0?l0o`3o0?l30?ooo`80o`3o0P3oool00`3o0?l0oooo0?ooo`0B
0?ooo`<000000`3oool3000000@0oooo00<000000?ooo`3oool01@3oool00`3o0000oooo0?l00004
0?ooo`030?l0003oool0o`0001D0oooo0`0000030?ooo`<00000103oool00`000000oooo0?ooo`0Q
0?ooo`<000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04H0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo01L0oooo00<0000007moO`1oOgl0101oOgl3000000030?ooo`3o0000o`00
00<0o`003P3o0?l30?ooo`L00?l08`3oool90000oa80oooo2P3o0?l=0?ooo`L00?l00`3o000:0?l0
om40oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0H07moO`030000003oool0oooo
00l0oooo0`0000030?ooo`<0000000@0oooo000000000000oooo0`000000103oool0000000000000
000D0?ooo`030000003oool0oooo00D0oooo0P0000030?ooo`040000003oool0oooo000000@0oooo
0P0000020?ooo`040000003oool0oooo00000080oooo0P00000B0?ooo`050?l0o`000?l0o`3o0?oo
o`3o0?l00P3oool01P3o0?l0003o0?l0o`3oool0003o0?l0oa<0oooo00D000000?ooo`3oool00000
0?ooo`0200000080oooo00D000000?ooo`3oool0oooo000000070?ooo`030?l0003oool0o`0000@0
oooo00<0o`000?ooo`3o00005@3oool01@000000oooo0?ooo`000000oooo008000000P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01L0
oooo00<0000007moO`1oOgl0101oOgl00`000000o`000?l000060?l000X0oooo1000o`0?0?l0oaD0
oooo2@000?lA0?ooo`X0o`3o8@3oool7003o00<0o`002P3o0?o70?ooo`030000001oOgl0Ogmo00D0
Ogmo00<0000007moO`1oOgl0601oOgl00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`000000103oool01@000000oooo0000003oool0000001H0oooo00D000000?oo
o`3oool0oooo000000070?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P00
00050?ooo`030000003oool0oooo0180oooo00D0o`3o0?ooo`3o0?l0oooo0?l0o`020?ooo`050?l0
o`000?l0o`3o0?ooo`3o0?l04`3oool01P000000oooo0?ooo`000000oooo00000080oooo0P000002
0?ooo`800000203oool00`3o0000oooo0?l000040?ooo`030?l0003oool0o`0001@0oooo00H00000
0?ooo`3oool000000?ooo`0000020?ooo`80000000D0oooo0000003oool0oooo0000000R0?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000017
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0G0?ooo`030000001oOgl0Ogmo00@0Ogmo0P0000070?oo
o`l0o`003P3oool>0?l0o`L0003o403oool:0?l0ocD0oooo1P00o`040?l000/0o`3o_03oool00`00
0000Ogmo07moO`0507moO`030000001oOgl0Ogmo01P0Ogmo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`030?ooo`030000003oool00000008000000P3oool01@000000oooo0000003oool0
000001L0oooo100000060?ooo`80000000<0oooo0000000000001@3oool2000000030?ooo`000000
oooo01T0oooo00D0o`3o0000o`3o0?l0oooo0?l0o`030?ooo`80o`3o00<0oooo0000o`3o0?l04@3o
ool4000000<0oooo0P0000000`3oool000000?ooo`020?ooo`030000003oool0oooo00H0oooo00<0
o`000?ooo`3o0000103oool00`3o0000oooo0?l0000C0?ooo`@000000`3oool2000000040?ooo`00
0000oooo0?ooo`8000008P3oool5000000040?ooo`0000000000000000@0oooo0P0000180?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0
3`3oool2000001P0oooo0P00000507moO`<000000P3oool7003o00`0oooo3`3o00030?ooo`P0003o
0P3ooolG0?l0odT0oooo1P00o`050?l000X0o`3o/P3oool00`000000Ogmo07moO`0507moO`030000
001oOgl0Ogmo01P0Ogmo00<000000?ooo`3oool0403oool3000000<0oooo00D000000?ooo`000000
oooo000000020?ooo`050000003oool000000?ooo`000000BP3oool01@3o0?l0oooo0?l0o`3oool0
o`3o0080oooo00H0o`3o0000o`3o0?l0oooo0000o`3o0?lX0?ooo`030?l0003oool0o`0000@0oooo
00<0o`000?ooo`3o0000VP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo
000X0?ooo`030000003oool0oooo00l0oooo0P00000I003o00030000001oOgl0Ogmo00<0Ogmo00<0
0000003o0000o`001`00o`0G0?ooo`H0003o3`3o00020?oooaP0o`3oC`3oool5003o00D0o`002P3o
0?nX0?ooo`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0601oOgl00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo0080oooo0P0000020?ooo`050000003oool0oooo0?ooo`000000
0P3oool2000004X0oooo00D0o`3o0000o`3o0?l0oooo0?l0o`030?ooo`80o`3o0P3oool00`3o0?l0
oooo0?ooo`0W0?ooo`030?l0003oool0o`0000@0oooo00<0o`000?ooo`3o0000V@3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool05`3oool9000000P0oooo4@00o`060000o`d0oooo203o0?l?0?l000/0oooo
3P3o0?m;0?ooo`D00?l01@3o000:0?l0oih0oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo
07moO`0H07moO`030000003oool0oooo0100oooo00@000000?ooo`3oool000002@3oool01@000000
oooo0?ooo`3oool0000004/0oooo00D0o`3o0?ooo`3o0?l0oooo0?l0o`020?ooo`060?l0o`000?l0
o`3o0?ooo`000?l0o`3o:03oool00`3o0000oooo0?l000040?ooo`030?l0003oool0o`0009T0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo01L0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo0000
000<0?ooo`T0003o0`3ooolA003o0080o`3o5`3oool>0?l000/0oooo3`3o0?m60?ooo`D00?l01@3o
000:0?l0oi@0oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0H07moO`030000003o
ool0oooo00l0oooo1@0000020?ooo`030000003oool0oooo00<0oooo0P0000020?ooo`800000B`3o
ool00`3o0?l0003o0?ooo`020?l0o`<0oooo00D0o`3o0000o`3o0?l0oooo0?l0o`0Y0?ooo`030?l0
003oool0o`0000@0oooo00<0o`000?ooo`3o0000V03oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool05`3o
ool00`000000Ogmo07moO`0407moO`030000001oOgl0000000<0oooo2@000?l;0?ooo`X0o`3o203o
oolA003o01H0oooo3`3o000;0?ooo`h0o`3o@P3oool5003o00D0o`002`3o0?n90?ooo`030000001o
Ogl0Ogmo00D0Ogmo00<0000007moO`1oOgl0601oOgl00`000000oooo0?ooo`1^0?ooo`050?l0o`00
0?l0o`3o0?ooo`3o0?l00`3oool20?l0o`030?ooo`000?l0o`3o02P0oooo00<0o`000?ooo`3o0000
103oool00`3o0000oooo0?l0002H0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
1@3oool002P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0G0?ooo`030000001o
Ogl0Ogmo00@0Ogmo0P00000;0000o`@0oooo2@3o0?lS0?oooa400?l0503oool?0?l000X0oooo3P3o
0?ln0?ooo`D00?l01P3o000:0?l0ogl0oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07mo
O`0H07moO`030000003oool0oooo06l0oooo00@0o`3o0?ooo`3o0?l0o`3o0`3oool01P3o0?l0003o
0?l0o`3oool0003o0?l0obP0oooo00<0o`000?ooo`3o0000103oool00`3o0000oooo0?l0002G0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0G0?ooo`030000001oOgl0Ogmo00@0Ogmo0`0000040?ooo`H0
o`3o50000?l]0?oooa400?l04P3oool?0?l000T0oooo3P3o0?lk0?ooo`@00?l01P3o000:0?l0ogD0
oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0H07moO`030000003oool0oooo06l0
oooo00D0o`3o0000o`3o0?l0oooo0?l0o`030?ooo`80o`3o00<0oooo0000o`3o0?l0:03oool00`3o
0000oooo0?l000050?ooo`030?l0003oool0o`0009H0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`0?0?ooo`8000006@3o0?l00`000000
Ogmo07moO`0307moO`800000303o0?lC0?oooa<0003o:`3ooolA003o0100oooo3`3o00080?ooo`h0
o`3o=`3oool4003o00H0o`002P3o0?m[0?ooo`030000001oOgl0Ogmo00H0Ogmo00<0000007moO`1o
Ogl05`1oOgl00`000000oooo0?ooo`1`0?ooo`050?l0o`3oool0o`3o0?ooo`3o0?l00P3oool01P3o
0?l0003o0?l0o`3oool0003o0?l0obP0oooo00<0o`000?ooo`3o0000103oool00`3o0000oooo0?l0
002F0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool002P0oooo1000000>
0?ooo`800000603oool2000000D0Ogmo0`00000;0?oooaH0o`3o403ooolD0000obP0oooo4@00o`0>
0?ooo`h0o`00203oool?0?l0oc80oooo0`00o`070?l000X0o`3oH@3oool00`000000Ogmo07moO`06
07moO`030000001oOgl0Ogmo01L0Ogmo00<000000?ooo`3oool0L03oool01@3o0?l0003o0?l0o`3o
ool0o`3o00<0oooo0P3o0?l20?ooo`030?l0o`3oool0oooo02H0oooo00<0o`000?ooo`3o00001@3o
ool00`3o0000oooo0?l0002E0?ooo`030000003oool0oooo00d0oooo100000070?ooo`00:03oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01L0oooo00<0000007moO`1oOgl0101oOgl0
0`000000Ogmo0000000Q0?oooaH0o`3o3P3ooolD0000obD0oooo4@00o`0;0?ooo`l0o`00203oool>
0?l0obh0oooo0`00o`070?l000X0o`3oE`3oool00`000000Ogmo07moO`0607moO`030000001oOgl0
Ogmo01L0Ogmo00<000000?ooo`3oool0L@3oool01@3o0?l0oooo0?l0o`3oool0o`3o0080oooo00H0
o`3o0000o`3o0?l0oooo0000o`3o0?lX0?ooo`030?l0003oool0o`0000@0oooo00<0o`000?ooo`3o
0000U@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool05`3oool00`000000Ogmo07moO`0407moO`030000
001oOgl0000003L0oooo5P3o0?l<0?oooa<0003o8`3ooolA003o00T0oooo3`3o00070?ooo`h0o`3o
:P3oool3003o00L0o`002`3o0?m<0?ooo`030000001oOgl0Ogmo00H0Ogmo00<0000007moO`1oOgl0
5`1oOgl00`000000oooo0?ooo`1a0?ooo`050?l0o`000?l0o`3o0?ooo`3o0?l00`3oool01P3o0?l0
003o0?l0o`3oool0003o0?l0obP0oooo00<0o`000?ooo`3o0000103oool00`3o0000oooo0?l0002D
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0G0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007mo
O`000000C@3ooolG0?l0o`P0oooo50000?lP0?oooa400?l01`3oool?0?l000H0oooo3P3o0?lV0?oo
o`<00?l0203o000:0?l0od80oooo00<0000007moO`1oOgl01P1oOgl00`000000Ogmo07moO`0G07mo
O`030000003oool0oooo0780oooo00D0o`3o0?ooo`3o0?l0oooo0?l0o`030?ooo`80o`3o00<0oooo
0000o`3o0?l0:03oool00`3o0000oooo0?l000050?ooo`030?l0003oool0o`0009<0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo01L0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo0000001T0?oo
oaH0o`3o1P3ooolD0000oad0oooo4000o`060?ooo`h0o`001P3oool>0?l0ob<0oooo0P00o`080?l0
00X0o`3o>03oool00`000000Ogmo07moO`0607moO`030000001oOgl0Ogmo01L0Ogmo00<000000?oo
o`3oool0LP3oool01@3o0?l0003o0?l0o`3oool0o`3o00<0oooo00H0o`3o0000o`3o0?l0oooo0000
o`3o0?lX0?ooo`030?l0003oool0o`0000@0oooo00<0o`000?ooo`3o0000T`3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool05`3oool80000000307moO`000000oooo07T0oooo5P3o0?l40?oooa<0003o6P3o
oolA003o00<0oooo3`3o00050?ooo`l0o`3o7P3oool2003o00P0o`002P3o0?l^0?ooo`030000001o
Ogl0Ogmo00H0Ogmo00<0000007moO`1oOgl05`1oOgl00`000000oooo0?ooo`1c0?ooo`050?l0o`3o
ool0o`3o0?ooo`3o0?l00`3oool20?l0o`80oooo00<0o`3o0?ooo`3oool09P3oool00`3o0000oooo
0?l000050?ooo`030?l0003oool0o`000980oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01L0oooo00<0
000007moO`1oOgl0101oOgl00`000000Ogmo0000002@0?oooaH0o`3o00<0oooo0000o`000?l04P00
0?lG0?oooa400?l000<0oooo0?l0003o00003@3o00050?ooo`h0o`3o6P3oool2003o00P0o`002P3o
0?lT0?ooo`030000001oOgl0Ogmo00H0Ogmo00<0000007moO`1oOgl05`1oOgl00`000000oooo0?oo
o`1c0?ooo`030?l0o`000?l0oooo0080o`3o0`3oool01P3o0?l0003o0?l0o`3oool0003o0?l0o`H0
oooo00<000000?ooo`3oool07`3oool00`3o0000oooo0?l000040?ooo`030?l0003oool0o`0000L0
oooo0P0000290?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool002P0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0G0?ooo`030000001oOgl0Ogmo00@0Ogmo
00<0000007moO`000000YP3ooolF0?l0oa<0003o503oool@003o00l0o`00103oool>0?l0oaH0oooo
0P00o`080?l000X0o`3o6P3oool00`000000Ogmo07moO`0607moO`030000001oOgl0Ogmo01L0Ogmo
00<000000?ooo`3oool0M03oool01@3o0?l0003o0?l0o`3oool0o`3o00<0oooo00H0o`3o0000o`3o
0?l0oooo0000o`3o0?l40?ooo`8000008@3oool00`3o0000oooo0?l000050?ooo`030?l0003oool0
o`0000H0oooo0P0000290?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool0
02P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0G0?ooo`030000001oOgl0Ogmo
00@0Ogmo00<0000007moO`000000_03ooolF0?l0oa00003o4P3oool>003o00l0o`000`3oool>0?l0
oa80oooo0P00o`080?l000/0o`3o3`3oool00`000000Ogmo07moO`0607moO`030000001oOgl0Ogmo
01L0Ogmo00<000000?ooo`3oool0M@3oool01@3o0?l0oooo0?l0o`3oool0o`3o00<0oooo0P3o0?l0
0`3oool0003o0?l0o`040?ooo`030000003oool0oooo0240oooo00<0o`000?ooo`3o00001@3oool0
0`3o0000oooo0?l000050?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
01L0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo0000003B0?oooaH0o`3o3P000?l?0?oo
o``00?l03P3o00030?ooo`h0o`3o3P3oool00`00o`00o`000?l000080?l000X0o`3o1@3oool00`00
0000Ogmo07moO`0607moOa/00000B03oool300000080oooo1@00000U0?ooo`050?l0o`000?l0o`3o
0?ooo`3o0?l00`3oool01P3o0?l0003o0?l0o`3oool0003o0?l0o`80oooo0P00000S0?ooo`040?l0
003oool0oooo0?l000@0oooo00<0o`000?ooo`3o0000103oool2000003d0oooo00<000000?ooo`3o
ool0BP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool05`3oool00`000000Ogmo07moO`0407moO`030000
001oOgl000000>P0oooo5P3o0?l<0000o``0oooo2@00o`0?0?l00080oooo3`3o0?l:0?ooo`X0o`00
2P3o0?l407moOa/00000B03oool3000000030?ooo`000000000000D000009@3oool01@3o0?l0oooo
0?l0o`3oool0o`3o00<0oooo0P3o0?l20?ooo`040?l0o`3oool0oooo000002D0oooo00<0o`000?oo
o`3o00001@3oool00`3o0000oooo0?l000030?ooo`030000003oool0oooo03/0oooo0P00001<0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0G0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`00
0000oP3ooolG0?l0o`P0003o2P3oool7003o00l0o`000P3oool>0?l0o`H0oooo2P3o00030?l0o`03
0000003o0?l0o`3o00<0o`3o5P0000150?ooo`<0o`3o00<000000?l0o`0000000`3o0?l010000000
o`3o0?l0o`00000K0?l0o`/0oooo00D0o`3o0000o`3o0?l0oooo0?l0o`030?ooo`060?l0o`000?l0
o`3o0?ooo`000?l0o`3o0P00000V0?ooo`030?l0003oool0o`0000@0oooo00<0o`000?ooo`3o0000
0P3oool00`000000oooo0?ooo`0k0?ooo`030000001oOgl0000004`0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo01L0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo0000003o0?oooaH0oooo5P3o
0?l60000o`L0oooo1@00o`0?0?l000030?ooo`3o0?l0o`3o00`0o`3o0P1oOgl30?l000030000003o
0000o`0000<0o`002@3o0?l<0?ooo`030000003oool0oooo03`0oooo1`3o0?l3003o000300000000
o`00000000D0000000@0Ogmo00000000000000006@3ooolE0?l0o`050000o`3o0?l0o`3o0?l0003o
0?l06@3o000>0?ooo`030?l0003oool0o`0000D0oooo00@0o`000?ooo`3o00000000?P3oool00`00
0000Ogmo000000170?ooo`D00?l00P00000A0?ooo`030000003oool0oooo00D0oooo000X0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool05`3oool00`000000Ogmo07moO`0407moO`03
0000001oOgl000000?l0oooo;03ooolF0?l0o`@0003o103oool3003o00l0o`001@3o0?l00`000000
o`3o0?l0o`060?l0o`@0o`0000<000000?l0003o0?l0203o0?l4000001X0oooo00<000000?ooo`00
00006@3oool80?l0o`D00?l02`3o0?l00`000000o`3o0?l0o`0K0?l0o`d0oooo00D0o`3o0000o`3o
0?l0oooo0?l0o`040?ooo`80o`3o0`00000I0?oooaP0o`0000<000000?l00000o`007`00o`0M0?oo
o`80000000<0Ogmo0000003oool0?@3oool9003o00D0oooo0P00000A0?ooo`030000003oool0oooo
00D0oooo000X0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool05`3oool00`000000
Ogmo07moO`0407moO`030000001oOgl000000?l0oooo@P3ooolF0?l0o`040000o`000000Ogmo003o
00D0o`0000<000000?l0003o00001P3o00050?l0o`030000003o0?l0o`3o00D0o`3o0P3o00020?l0
o`030000003o0?l0o`3o00@0o`3o5@3oool300000180oooo1`3o0?l2003o00/0o`3o2P3o00020000
0080o`006`00o`0G0?l0o`030000o`3o0?l0o`0001T0o`00403oool00`3o0000oooo0?l000050?oo
o`030?l000000000oooo0200oooo7@00o`000`0000000?l000000006003o02l0oooo2P00o`0>0?oo
o`8000004@3oool00`000000oooo0?ooo`050?ooo`006P3oool2000000`0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0G0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`00
0000o`3ooomB0?ooo`<000000`3oool00`000000o`3o0?l0o`0:000000040?l0o`00000000000?l0
o`800000103o0?l00`000000o`000?l000050?l000@0o`3o00<000000?l0o`3o0?l03@3o0?l<0?oo
o`<000002P3ooolA0?l0o`H0o`003`3o0?l2000002`0o`3o00<0003o0?l0o`3o0?l01P3o0?l00`00
0?l000000?ooo`0H0?oooaP0o`0000<00?l00?l00000o`007`00o`0N0?ooo`@000001@3oool9003o
01`0oooo2P00o`0>0?ooo`X00?l00P00000A0?ooo`030000003oool0oooo00D0oooo000I0?ooo`04
0000003oool0oooo000000/0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0G0?oo
o`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`000000o`3ooomC0?ooo`030000003oool0oooo
0080oooo0P00000207moO`050000001oOgl0Ogmo0000001oOgl00`0000020?ooo`050000003oool0
00000?ooo`0000000`3oool00`000000oooo0000000:0?l0o`030000003o0?l0o`3o01H0o`3o0P3o
ool4000000<0oooo7P3o0?l:0?ooo`P0000000<0Ogmo000000000000:03oool01@3o0?l0oooo0?l0
o`3oool0o`3o00<0oooo0P00000[0?ooo`030?l0003oool0o`0000@0oooo0P00000P0?oooah00?l0
00<00000003o000000002`00o`040?ooo`X00?l02@3oool9003o00D0oooo4`00o`0:0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool01@3oool001T0oooo00@000000?ooo`3oool00000
2`3oool6000000`0oooo0P00000I0?l000L0000000<0Ogmo0000003oool0o`3ooomB0?ooo`030000
003oool0oooo0080oooo9@00000=0?ooo``0o`3o00<000000?l0o`000000303o0?lP0?ooo`/00000
:03oool01`3o0?l0003o0?ooo`3o0?l0oooo0?l0o`3oool00P00000]0?ooo`030?l0003oool0o`00
0080oooo00<000000?ooo`3oool0?`3oool3000000X0oooo9@00o`0M0?ooo`030000003oool0oooo
00/0oooo1P0000070?ooo`006@3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo
00l0oooo0P00000H0?ooo`8000001@1oOgl00`000000Ogmo0000003o0?oooe<0oooo0`0000020?oo
o`8000000P1oOgl01@000000Ogmo07moO`000000Ogmo00<000000P3oool010000000oooo0000003o
ool200000080oooo00<000000?ooo`0000001@3oool50?l0o`030000003o0?l0o`3o01P0o`3o00@0
00000?l0o`0000000000103ooolN0?l0o`T0oooo200000000`1oOgl000000000000Y0?ooo`070?l0
o`000?l0o`3o0?ooo`3o0?l0oooo0000000^0?ooo`060?l0003oool0oooo0?l0003oool00000@03o
ool4000000T0oooo4`00o`000`3oool00?l0003o000A003o01`0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`050?ooo`006@3oool010000000oooo0?ooo`00000;0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool05`3oool00`000000Ogmo07moO`0407moO`030000001o
Ogl000000?l0ooooD`3oool01@000000oooo0?ooo`000000oooo00D0000000<0Ogmo000000000000
2@0000000`3o0?l000000?l0o`03000000030?l0o`000000000000T0o`3o00<000000?l0o`3o0?l0
4P3o0?l70?ooo`030000001oOgl0000000/0oooo4@3o0?l6003o00h0o`3o0P0000030?l0o`800000
5P3ooolH0?l0o`030000003oool0oooo01H0oooo5`00o`000`3o00000?l00?l00012003o00030000
0000o`00000000h00?l07P3ooolH003o00T0oooo0P00000A0?ooo`030000003oool0oooo00D0oooo
000I0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0G0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`000000o`3ooomC0?ooo`040000
003oool0oooo000000X0o`3o00<000000?l0o`3o0?l04P3o0?l20?ooo`<0o`3o00<000000?l0o`3o
0?l01@3o0?lD0?ooo`<000004`3oool70?l0o`80oooo2`3o0?l9003o008000000`00o`0H0?l0oa<0
o`0000@0o`3o0000o`3o0?l00000<`3o00000`000000o`000?ooo`0`0?oooa000?l000<00000003o
000000001@00o`0a0?ooo`X00?l0103oool9003o008000004@3oool00`000000oooo0?ooo`050?oo
o`006P3oool2000000`0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0G0?ooo`03
0000001oOgl0Ogmo00@0Ogmo00<0000007moO`000000o`3ooolo0?oooa<0o`3o10000004003o0003
0?l0003o0?l0000000@0o`3o00<000000?l0o`3o0?l01@3o0?l60?ooo`T0o`3o0`3oool2000001X0
oooo0`00000J0?ooo`P0o`3o1@3oool:0?l0o`030000003o0?l0o`3o0300o`3o00<000000?ooo`3o
ool0;`3oool00`3o000000000000000?0?ooob800?l0403oool4000003l0oooo2@00o`040?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0G0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`000000
o`3ooolW0?oooaP0o`3o2P00o`020?ooo`<0o`003@3o0?l607moO`D000002@3o0?l>000001X0oooo
00<000000?ooo`0000008P3oool70?l0o`80oooo3000000E0?oooaD0003o00<0o`3o0000o`000000
6@3ooolI0?l000030000003o00000?l000l00?l0<`3oool00`000000Ogmo000000180?ooo`@00?l0
0P00000A0?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool05`3oool00`000000Ogmo07moO`0407moO`030000001oOgl000000?l0oooo3`3o
oolH0?l0oa400?l00`3oool50?l000h0o`3o2`3oool010000000Ogmo07moO`1oOgl40?l0o`030000
003o0?l0o`3o0080o`3o5`0000160?ooo`80o`3o00<000000?l0o`0000000`3o0?l010000000o`3o
0?l0o`00000G003o01L0o`3o6P3o000I0?ooo`030000003oool0oooo0480oooo00<0000007moO`00
0000C03oool200000140oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0G0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`000000
m`3ooolG0?l0o`L0003o4@00o`050?ooo`H0o`003P3o0?lB0?ooo`030000o`3o0?l0o`3o00P0o`3o
1@1oOgl00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo04H0oooo200000000`1oOgl00000
0?l0o`0F0?l0oaH0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`120?ooo`030000
001oOgl0000004`0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`050?ooo`00:03o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01L0oooo00<0000007moO`1oOgl0101o
Ogl00`000000Ogmo0000003O0?oooaP0o`3o30000?l00`3oool00?l0003o000?003o00L0oooo203o
000=0?l0oaH0oooo00<0003o0?l0o`3o0?l0203o0?l60?ooo`030000001oOgl0Ogmo00H0Ogmo6`00
00180?ooo`<000000P3oool5000002`0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?oo
o`140?ooo`800000C03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo000X
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool05`3oool00`000000Ogmo07moO`04
07moO`030000001oOgl000000<P0oooo5`3o0?l?0000o`D0oooo4@00o`080?ooo`X0o`003P3o0?lH
0?ooo`030000o`3o0000o`3o00T0o`3o403oool00`000000Ogmo07moO`0607moOa/00000B03oool3
00000080oooo1@00000/0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0A@3oool0
0`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool0
02P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0G0?ooo`030000001oOgl0Ogmo
00@0Ogmo00<0000007moO`000000/03ooolH0?l0oa80003o203ooolA003o00X0oooo2`3o000>0?l0
oa`0oooo00<0003o0?l0003o0?l02@3o0?lJ0?ooo`030000001oOgl0Ogmo00H0Ogmo00<0000007mo
O`1oOgl05`1oOgl00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0340oooo00<000000?oo
o`3oool0T`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo000X0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool05`3oool00`000000Ogmo07moO`0407moO`03
0000001oOgl0000009P0oooo603o0?lE0000o``0oooo4@00o`0;0?ooo`h0o`003@3o0?lP0?ooo`03
0000o`3o0000o`0000T0o`3o903oool00`000000Ogmo07moO`0607moO`030000001oOgl0Ogmo01L0
Ogmo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo09@0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo01L0oooo200000000`1oOgl000000?ooo`200?oooaL0o`3o
0`3ooolE0000oa00oooo4@00o`0=0?ooo`l0o`003P3o0?lR0?ooo`80003o0P3o000:0?l0obd0oooo
00<0000007moO`1oOgl01P1oOgl00`000000Ogmo07moO`0G07moO`030000003oool0oooo0?l0oooo
AP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool05`3oool00`000000Ogmo07moO`0407moO`030000001o
Ogl0000006T0oooo603o0?l50?oooaD0003o503ooolA003o00h0oooo403o00000`3oool0o`3o0?l0
o`0<0?l0obH0oooo0P000?l20?l000X0o`3o=`3oool00`000000Ogmo07moO`0607moO`030000001o
Ogl0Ogmo01L0Ogmo00<000000?ooo`3oool0o`3ooom60?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0G
0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`000000DP3ooolG0?l0o`T0oooo50000?lI
0?oooa000?l0403oool?0?l000@0oooo3@3o0?lY0?ooo`<0003o0P3o000:0?l0od40oooo00<00000
07moO`1oOgl01P1oOgl00`000000Ogmo07moO`0G07moO`030000003oool0oooo0?l0ooooAP3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool05`3oool00`000000Ogmo07moO`0407moO`030000001oOgl00000
03X0oooo603o0?l;0?oooaD0003o703ooolA003o0100oooo403o00050?ooo`h0o`3o;03oool20000
o`<0o`002P3o0?m;0?ooo`030000001oOgl0Ogmo00H0Ogmo00<0000007moO`1oOgl05`1oOgl00`00
0000oooo0?ooo`3o0?ooodH0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`050?oo
o`00:03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01L0oooo00<0000007moO`1o
Ogl0101oOgl00`000000Ogmo0000000R0?oooaP0o`3o3P3ooolE0000ob00oooo4@00o`0B0?ooo`l0
o`001`3oool>0?l0obl0oooo0`000?l30?l000X0o`3oE@3oool00`000000Ogmo07moO`0607moO`03
0000001oOgl0Ogmo01L0Ogmo00<000000?ooo`3oool0o`3ooom60?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool01@3oool002P0oooo1000000>0?ooo`030000003oool0oooo01L0oooo
00<0000007moO`1oOgl0101oOgl3000000/0oooo5`3o0?lA0?oooaD0003o903ooolA003o01@0oooo
3`3o00090?ooo`d0o`3o<`3oool30000o`<0o`002P3o0?mO0?ooo`030000001oOgl0Ogmo00H0Ogmo
00<0000007moO`1oOgl05`1oOgl00`000000oooo0?ooo`3o0?ooodH0oooo00<000000?ooo`3oool0
3@3oool4000000L0oooo000X0?ooo`030000003oool0oooo00l0oooo0P00000I0?l0o`030000001o
Ogl0Ogmo00<0Ogmo0P00000<0?l0oa<0oooo5@000?lX0?oooa400?l05@3oool@0?l000X0oooo3P3o
0?le0?ooo`@0003o0`3o000:0?l0ofT0oooo00<0000007moO`1oOgl01P1oOgl00`000000Ogmo07mo
O`0G07moO`030000003oool0oooo0?l0ooooAP3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo00D0oooo000X0?ooo`030000003oool0oooo00l0oooo0P00000H0?ooo`8000001@1oOgl0
0`000000Ogmo000000050?ooo`@0o`3o5@000?l/0?oooa400?l05`3oool?0?l000`0oooo3P3o0?li
0?ooo`@0003o0`3o000:0?l0og<0oooo00<0000007moO`1oOgl01P1oOgl00`000000Ogmo07moO`0G
07moO`030000003oool0oooo0?l0ooooAP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo00D0oooo000X0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool05`3oool00`00
0000Ogmo07moO`0407moO`8000002P000?l60?ooo`T0o`3o8@3ooolA003o01P0oooo403o000>0?oo
o`d0o`3o?@3oool40000o`@0o`002@3o0?mm0?ooo`030000001oOgl0Ogmo0200Ogmo00<000000?oo
o`3oool0o`3ooom60?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool002P0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0G0?ooo`030000001oOgl0Ogmo00@0
Ogmo0`0000040?ooo`T0003o2`3oool:0?l0o`H0oooo4@00o`0J0?ooo`l0o`00403oool>0?l0ocl0
oooo10000?l50?l000X0o`3oQP3oool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo01P0
Ogmo00<000000?ooo`3oool0o`3ooom60?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool01@3oool002P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0G0?ooo`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`0000003@3oool80000o`80oooo4@00o`040?l0oaL0oooo
403o000A0?ooo`h0o`3o@`3oool40000o`D0o`002P3o0?n@0?ooo`030000001oOgl0Ogmo00D0Ogmo
00<0000007moO`1oOgl0601oOgl00`000000oooo0?ooo`3o0?ooodH0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo01L0oooo200000000`1oOgl000000?ooo`050?oooa400?l01`000?l>0?ooo`P0o`3o3`3o
000D0?ooo`d0o`3oAP3oool50000o`D0o`002P3o0?nJ0?ooo`030000001oOgl0Ogmo00D0Ogmo00<0
000007moO`1oOgl0601oOgl00`000000oooo0?ooo`3o0?ooodH0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`0?0?ooo`800000603oool2
000000D0Ogmo00<00000003o0000o`001P00o`0H0?ooo`L0003o3`3o00020?ooo`X0o`3o2@3oool>
0?l0odT0oooo1@000?l50?l000X0o`3oY03oool00`000000Ogmo07moO`0507moO`030000001oOgl0
Ogmo01P0Ogmo00<000000?ooo`3oool0o`3ooom60?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool03`3oool2000001T00?l000<0000007mo
O`1oOgl00`1oOgl3000000<0oooo1`00o`0;0?oooa00o`000P3oool80000o``0oooo3P3o0?m<0?oo
o`H0003o1@3o000:0?l0ojh0oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo07moO`0H07mo
O`030000003oool0oooo0?l0ooooAP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
00D0oooo000X0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool05`3oool00`000000
Ogmo07moO`0407moO`8000001`3oool?0?l001T0oooo3@3o0?l>0?ooo`X0o`3o>03oool50000o`H0
o`002P3o0?nh0?ooo`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0601oOgl00`000000
oooo0?ooo`3o0?ooodH0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`050?ooo`00
:03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01L0oooo00<0000007moO`1oOgl0
101oOgl00`000000o`000?l000060?l000/0oooo1`00o`080?ooo`h0o`3o2P3oool80000oa<0oooo
2P3o0?lT0?ooo`D0003o1P3o000:0?l0ol80oooo00<0000007moO`1oOgl01@1oOgl00`000000Ogmo
07moO`0H07moO`030000003oool0oooo0?l0ooooAP3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool05`3o
ool00`000000Ogmo07moO`0407moO`<000000P3oool60?l000X0oooo3P3o0?lP0?ooo`T0003o503o
ool:0?l0o`l0oooo1P000?l60?l000X0o`3oc03oool00`000000Ogmo07moO`0507moO`030000001o
Ogl0Ogmo01P0Ogmo00<000000?ooo`3oool0o`3ooom60?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0G
0?ooo`030000001oOgl0Ogmo00@0Ogmo0`0000050?ooo`d0o`3o3@3oool7003o02<0oooo2@000?lE
0?ooo`D0o`3o1P000?l70?l000T0o`3oeP3oool00`000000Ogmo07moO`0507moO`030000001oOgl0
Ogmo01P0Ogmo00<000000?ooo`3oool0o`3ooom60?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0G0?oo
o`030000001oOgl0Ogmo00@0Ogmo00<000000?l0o`3o0?l01@3o0?l:0?ooo`H0o`004@3oool7003o
02D0oooo20000?l70?ooo`L0003o1`3o000;0?l0omh0oooo00<0000007moO`1oOgl01@1oOgl00`00
0000Ogmo07moO`0H07moO`030000003oool0oooo0?l0ooooAP3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool05`3oool00`000000Ogmo07moO`0407moO`8000000`3oool60?l0o`d0oooo1P3o000B0?ooo`L0
0?l08`3oool70000o`L0o`002P3o0?l;0?ooo`X0o`3oe03oool00`000000Ogmo07moO`0507moO`03
0000001oOgl0Ogmo01P0Ogmo00<000000?ooo`3oool0o`3ooom60?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0G0?ooo`030000001oOgl0Ogmo00@0Ogmo0P0000090?ooo`H0o`3o3@3oool60?l001<0oooo
1`00o`0A0?ooo`L0003o203o000:0?l0o`H0003o6@3oool:0?l0olX0oooo00<0000007moO`1oOgl0
1@1oOgl00`000000Ogmo07moO`0H07moO`030000003oool0oooo0?l0ooooAP3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool05`3oool9000000l0oooo1@3o0?l>0?ooo`L0o`004`3oool7003o00L0003o203o
000:0?l0oa00oooo2@000?lJ0?ooo`X0o`3o`03oool00`000000Ogmo07moO`0507moO`030000001o
Ogl0Ogmo01P0Ogmo00<000000?ooo`3oool0o`3ooom60?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0G
0?ooo`030000001oOgl0Ogmo00@0Ogmo0P00000D0?ooo`H0o`3o3`3oool60?l000T0oooo20000?l8
0?l000X0o`3o8`3oool80000oa`0oooo2@3o0?ng0?ooo`030000001oOgl0Ogmo00D0Ogmo00<00000
07moO`1oOgl0601oOgl00`000000oooo0?ooo`3o0?ooodH0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`050?ooo`00:03oool4000000h0oooo00<000000?ooo`3oool05`3oool00`00
0000Ogmo07moO`0407moO`8000006P3oool60?l0o`h0oooo20000?l80?l000X0o`3o0P3oool7003o
02`0oooo2@000?lL0?ooo`X0o`3o[@3ooolT00000?l0ooooB03oool00`000000oooo0?ooo`0=0?oo
o`@000001`3oool002P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0G0?ooo`03
0000001oOgl0Ogmo00@0Ogmo0P00000P0?ooo`@0o`3o20000?l80?l000X0o`3o4`3oool7003o02h0
oooo2@000?lM0?ooo`X0o`3oX`3oool00`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo01P0
Ogmo00<000000?ooo`3oool0o`3ooom60?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool01@3oool002P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0G0?ooo`030000
001oOgl0Ogmo00@0Ogmo0P00000I0?ooo`T0003o203o000:0?l0o`P0oooo1P3o000F0?ooo`L00?l0
<03oool80000oal0oooo2P3o0?nI0?ooo`030000001oOgl0Ogmo00D0Ogmo00<0000007moO`1oOgl0
601oOgl00`000000oooo0?ooo`3o0?ooodH0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01L0oooo00<0
000007moO`1oOgl0101oOgl2000000l0oooo20000?l:0?l000T0o`3o0P3oool60?l0oa00oooo1P3o
000G0?ooo`L00?l0<@3oool90000ob00oooo2@3o0?n@0?ooo`030000001oOgl0Ogmo00D0Ogmo00<0
000007moO`1oOgl0601oOgl00`000000oooo0?ooo`3o0?ooodH0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo01L0oooo00<0000007moO`1oOgl0101oOgl00`000000oooo0?ooo`030?ooo`T0003o2P3o000:
0?l0oa40oooo1P3o0?l@0?ooo`H0o`00603oool7003o03<0oooo20000?lQ0?ooo`X0o`3oQP3oool0
0`000000Ogmo07moO`0507moO`030000001oOgl0Ogmo01P0Ogmo00<000000?ooo`3oool0o`3ooom6
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0G0?ooo`P0000010000?l:0?l000X0o`3o8@3oool50?l0
oa40oooo1`3o000H0?ooo`L00?l0=03oool90000ob80oooo2P3o0?ml0?ooo`030000001oOgl0Ogmo
00D0Ogmo00<0000007moO`1oOgl0601oOgl00`000000oooo0?ooo`3o0?ooodH0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`0?0?ooo`80
0000603oool2000000D0Ogmo1@3o000:0?l0oc00oooo1P3o0?lB0?ooo`H0o`006@3oool7003o03H0
oooo2@000?lS0?ooo`X0o`3oLP3oool00`000000Ogmo07moO`0P07moO`030000003oool0oooo0?l0
ooooAP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000
003oool0oooo00l0oooo0P00000I0?l000030000001oOgl0Ogmo00<0Ogmo1@3o0?l20?l000030?oo
o`000?l0003o00<0003o>03oool60?l0oa80oooo1P3o000J0?ooo`L00?l0>03oool80000obD0oooo
2P3o0?mX0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl06@1oOgl00`000000oooo
0?ooo`3o0?ooodH0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`050?ooo`00:03o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01L0oooo00<0000007moO`1oOgl0101o
Ogl00`000000oooo0?ooo`040?l0o`@0o`0000<00?l00?ooo`000?l00`000?lj0?ooo`H0o`3o4P3o
ool60?l001/0oooo1`00o`0i0?ooo`T0003o9P3oool90?l0oel0oooo00<0000007moO`1oOgl0101o
Ogl00`000000Ogmo07moO`0I07moO`030000003oool0oooo0?l0ooooAP3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool05`3oool00`000000Ogmo07moO`0407moO`030000003oool0oooo00@0oooo103o0?l5
0?l000030?ooo`000?l0003o0080003o?03oool60?l0oa80oooo1`3o000K0?ooo`L00?l0>`3oool8
0000obL0oooo2P3o0?mE0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl06@1oOgl0
0`000000oooo0?ooo`3o0?ooodH0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`05
0?ooo`00:03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01L0oooo2000000:0?oo
o`D0o`3o103o00000`3oool0003o0000o`030000ocd0oooo1P3o0?lC0?ooo`H0o`00703oool7003o
03`0oooo2@000?lX0?ooo`X0o`3oB`3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo
01T0Ogmo00<000000?ooo`3oool0o`3ooom60?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool01@3oool002P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0G0?ooo`P0
00003`3oool40?l0o`@0o`000P3oool40000ocl0oooo1P3o0?lC0?ooo`H0o`007@3oool7003o03h0
oooo2@000?lY0?ooo`X0o`3o@@3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo01T0
Ogmo00<000000?ooo`3oool0o`3ooom60?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool01@3oool002P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0b0?ooo`@0o`3o
103o00000`00o`00oooo0000o`030000od40oooo1@3o0?lD0?ooo`H0o`007P3oool7003o0400oooo
20000?l[0?ooo`T0o`3o>03oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo01T0Ogmo
00<000000?ooo`3oool0o`3ooom60?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
1@3oool002P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0f0?ooo`@0o`3o103o
00000`00o`00oooo0000o`040000od40oooo1P3o0?lD0?ooo`L0o`007P3oool7003o0440oooo2@00
0?l[0?ooo`X0o`3o;P3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo01T0Ogmo00<0
00000?ooo`3oool0o`3ooom60?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3o
ool002P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0j0?ooo`@0o`3o103o0000
0`00o`00oooo0?ooo`040000od<0oooo1P3o0?lE0?ooo`H0o`007`3oool8003o0480oooo20000?l]
0?ooo`X0o`3o903oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo01T0Ogmo00<00000
0?ooo`3oool0o`3ooom60?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool0
02P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0n0?ooo`@0o`3o103o00000`00
o`00oooo0?ooo`040000odD0oooo1P3o0?lE0?ooo`H0o`008@3oool7003o04<0oooo2@000?l^0?oo
o`X0o`3o6P3oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo01T0Ogmo00<000000?oo
o`3oool0o`3ooom60?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool002P0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`120?ooo`@0o`3o1@3o00000`00o`00
oooo0000o`030000odL0oooo1P3o0?lE0?ooo`L0o`008@3oool7003o04D0oooo20000?l`0?ooo`X0
o`3o403oool00`000000Ogmo07moO`0407moO`030000001oOgl0Ogmo01T0Ogmo00<000000?ooo`3o
ool0o`3ooom60?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool002P0oooo
1000000>0?ooo`030000003oool0oooo04H0oooo1@3o0?l40?l00003003o003oool0003o00@0003o
B03oool60?l0oaH0oooo1P3o000R0?ooo`L00?l0AP3oool90000oc40oooo2@3o0?l70?ooo`030000
001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl06@1oOgl00`000000oooo0?ooo`3o0?ooodH0oooo
00<000000?ooo`3oool03@3oool4000000L0oooo000X0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0B`3oool40?l0o`@0o`0000<00?l00?ooo`3oool010000?m:0?ooo`D0o`3o5`3o
ool60?l002<0oooo1`00o`180?ooo`T0003o<@3oool:0?l0o`@0Ogmo00<0000007moO`1oOgl06@1o
Ogl00`000000oooo0?ooo`3o0?ooodH0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`050?ooo`00:03oool00`000000oooo0?ooo`0?0?oooeH0o`3o103o00000`00o`00o`3o0?l0o`04
0000ofP0o`3o1P3o000T0?l0o`L00?l0BP3o0?l80000ocP0o`3o00<0000007moO`1oOgl0601oOgl0
0`000000oooo0?ooo`3o0?ooodH0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`05
0?ooo`00:03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo05<0oooo103o0?l40?l0
00800?l000<0oooo0000o`000?l00`000?m<0?ooo`H0o`3o5`3oool70?l002@0oooo1`00o`1;0?oo
o`T0003o9`3oool00`000000Ogmo07moO`0407moO`8000006P1oOgl00`000000oooo0?ooo`3o0?oo
odH0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo05L0oooo103o0?l40?l000800?l00P3oool40000odh0
oooo1P3o0?lH0?ooo`H0o`009@3oool7003o04d0oooo20000?lO0?ooo`030000001oOgl0Ogmo00@0
Ogmo00<0000007moO`1oOgl06@1oOgl00`000000oooo0?ooo`3o0?ooodH0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo05/0oooo103o0?l40?l000800?l00P3oool40000oe00oooo1P3o0?lH0?ooo`H0o`00
9P3oool7003o04h0oooo2@000?lF0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl0
6@1oOgl00`000000oooo0?ooo`3o0?ooodH0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo05l0oooo103o
0?l50?l00003003o003oool0oooo00@0003oDP3oool60?l0oaP0oooo1P3o000W0?ooo`L00?l0D03o
ool90000o`d0oooo00<0000007moO`1oOgl0101oOgl00`000000Ogmo07moO`0I07moO`030000003o
ool0oooo0?l0ooooAP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo000X
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0H`3oool50?l0o`@0o`000P00o`00
0`3oool0003o0000o`030000oe<0oooo1P3o0?lH0?ooo`L0o`009`3oool7003o0580oooo20000?l5
0?ooo`030000001oOgl0Ogmo00@0Ogmo00<0000007moO`1oOgl06@1oOgl00`000000oooo0?ooo`3o
0?ooodH0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`050?ooo`00:03oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo06P0oooo103o0?l40?l000800?l00P3oool40000
oeD0oooo1@3o0?lJ0?ooo`H0o`00:03oool7003o05<0oooo2@000?l207moO`8000006`1oOgl00`00
0000oooo0?ooo`3o0?ooodH0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`050?oo
o`00:03oool00`000000oooo0?ooo`0?0?ooofl0003o103o0?l40?l000800?l0G0000?l60?l0oaX0
003o1P3o000Y0000o`L00?l0F@000?lK07moO`030000003oool0oooo0?l0ooooAP3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0L03oool40?l0o`@0o`000P00o`020?ooo`D0003oE`3oool60?l0oaX0oooo
1`3o000Y0?ooo`L00?l0BP3oool00`000000Ogmo07moO`0P07moO`030000003oool0oooo0?l0oooo
AP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`150?ooo`@0o`3o103o
0002003o00<0oooo10000?mI0?ooo`H0o`3o6`3oool60?l002X0oooo1`00o`130?ooo`030000001o
Ogl0Ogmo00<0Ogmo00<0000007moO`1oOgl06P1oOgl00`000000oooo0?ooo`3o0?ooodH0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0B03oool40?l0o`@0o`000`00o`02
0?ooo`@0003oF`3oool60?l0oa/0oooo1P3o000[0?ooo`L00?l0?03oool00`000000Ogmo07moO`03
07moO`030000001oOgl0Ogmo01X0Ogmo00<000000?ooo`3oool0o`3ooom60?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`080?ooo`040000003oool00000000000<0oooo0P0000020?ooo`040000003oool0
oooo0?ooo`8000000P3oool5000000030?ooo`000000000000<0000000<0oooo000000000000103o
ool00`000000oooo0?ooo`1<0?ooo`@0o`3o1@3o0002003o0080oooo1@000?mL0?ooo`H0o`3o6`3o
ool60?l002`0oooo1`00o`0e0?ooo`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl06P1o
Ogl00`000000oooo0?ooo`3o0?ooodH0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`050?ooo`00:03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00P0oooo0P000002
0?ooo`030000003oool0000000<0oooo00D000000?ooo`000000oooo000000020?ooo`0@0000003o
ool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000<0
oooo00<000000?ooo`000000D@3oool50?l0o`@0o`000P00o`030?ooo`@0003oGP3oool60?l0oa/0
oooo1`3o000/0?ooo`L00?l0;P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo01X0
Ogmo00<000000?ooo`3oool0o`3ooom60?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool01@3oool000l0oooo100000020?ooo`8000000`3oool2000000`0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080000000H0oooo000000000000
00000?ooo`0000030?ooo`040000003oool0oooo00000080oooo00L000000?ooo`000000oooo0000
003oool000000080oooo0P0000000`3oool000000?ooo`020?ooo`030000003oool0000005H0oooo
103o0?l40?l000800?l00`3oool40000of00oooo1@3o0?lM0?ooo`H0o`00;@3oool7003o02L0oooo
00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07moO`0J07moO`030000003oool0oooo0?l0oooo
AP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo000?0?ooo`060000003o
ool0oooo0000003oool000000P3oool00`000000oooo000000020?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`090?ooo`<000000P3oool02@000000
oooo0000003oool000000?ooo`000000oooo000000020?ooo`0?0000003oool0oooo0000003oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo008000000P3oool00`000000oooo
0000001J0?ooo`@0o`3o103o0003003o0080oooo10000?mQ0?ooo`H0o`3o7@3oool60?l002h0oooo
1`00o`0P0?ooob@00000o`3ooom80?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
1@3oool00100oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool000000080oooo
00<000000?ooo`3oool02@3oool6000000`0oooo00<000000?ooo`3oool0203oool200000080oooo
00@000000?ooo`3oool000000`3oool200000080oooo0P0000020?ooo`<000000`3oool200000080
oooo00D000000?ooo`3oool000000?ooo`03000000030?ooo`000000000005d0oooo103o0?l40?l0
00<00?l00P3oool50000of80oooo1P3o0?lM0?ooo`H0o`00;`3oool7003o01T0oooo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0J07moO`030000003oool0oooo0?l0ooooAP3oool00`00
0000oooo0?ooo`0;0?ooo`H000001`3oool00140oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo000000020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo008000005@3oool00`000000oooo0?ooo`1/0?oo
o`@0o`3o103o0003003o00<0oooo10000?mT0?ooo`H0o`3o7@3oool70?l002l0oooo1`00o`0B0?oo
o`030000001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl06P1oOgl00`000000oooo0?ooo`3o0?oo
odH0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`050?ooo`004P3oool00`000000
oooo000000020?ooo`030000003oool000000080oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00T0oooo0P0000000`3oool000000?ooo`0C0?ooo`80
0000LP3oool40?l0o`@0o`000`00o`030?ooo`@0003oIP3oool60?l0oah0oooo1P3o000`0?ooo`L0
0?l02`3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo01X0Ogmo00<000000?ooo`3o
ool0o`3ooom60?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool000l0oooo
00H000000?ooo`3oool000000?ooo`0000020?ooo`030000003oool000000080oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo09T0oooo103o0?l50?l0
00<00?l00P3oool50000ofL0oooo1P3o0?lN0?ooo`H0o`00<@3oool7003o00@0oooo00<0000007mo
O`1oOgl00`1oOgl00`000000Ogmo07moO`0J07moO`030000003oool0oooo0?l0ooooAP3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo000@0?ooo`8000000`3oool2000000<0
oooo0P00000<0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0W@3oool50?l0o`@0
o`000`00o`030?ooo`@0003oJ@3oool50?l0oal0oooo1P3o000b0?ooo`L00?l00`1oOgl2000001/0
Ogmo00<000000?ooo`3oool0o`3ooom60?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool01@3oool002P0oooo00<000000?ooo`3oool03`3ooonU003o00@0o`3o103o0006003o00@0003o
JP00o`060?l0oal00?l01`3o000f003o00030000001oOgl0Ogmo01T0Ogmo00<000000?ooo`3oool0
o`3ooom60?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool002P0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`2V0?ooo`@0o`3o103o0003003o00<0oooo1@00
0?m[0?ooo`H0o`3o803oool60?l002T0oooo00<0000007moO`1oOgl00`1oOgl00`000000Ogmo07mo
O`0J07moO`030000003oool0oooo0?l0ooooAP3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo00D0oooo000X0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0ZP3oool4
0?l0o`@0o`001000o`030?ooo`@0003oK@3oool60?l0ob00oooo1P3o000S0?ooo`030000001oOgl0
Ogmo00<0Ogmo00<0000007moO`1oOgl06P1oOgl00`000000oooo0?ooo`3o0?ooodH0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo0:h0oooo103o0?l40?l000@00?l00`3oool40000ofl0oooo1P3o0?lP0?oo
o`L0o`00703oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo01X0Ogmo00<000000?oo
o`3oool0o`3ooom60?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool002P0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`2b0?ooo`@0o`3o103o0004003o00<0
oooo10000?ma0?ooo`H0o`3o8@3oool60?l001H0oooo00<0000007moO`1oOgl00`1oOgl00`000000
Ogmo07moO`0J07moO`030000003oool0oooo0?l0ooooAP3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
]P3oool40?l0o`D0o`000`00o`030?ooo`D0003oLP3oool60?l0ob40oooo1P3o000@0?ooo`030000
001oOgl0Ogmo00<0Ogmo00<0000007moO`1oOgl06P1oOgl00`000000oooo0?ooo`3o0?ooodH0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo0;X0oooo1@3o0?l40?l000@00?l00`3oool40000og@0oooo1@3o
0?lR0?ooo`H0o`002P3oool00`000000Ogmo07moO`0307moO`030000001oOgl0Ogmo01X0Ogmo00<0
00000?ooo`3oool0o`3ooom60?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3o
ool002P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`2o0?ooo`@0o`3o103o0004
003o00<0oooo10000?me0?ooo`H0o`3o8P3oool70?l000<0oooo00<0000007moO`1oOgl00`1oOgl0
0`000000Ogmo07moO`0J07moO`030000003oool0oooo0?l0ooooAP3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0``3oool40?l0o`@0o`001000o`030?ooo`D0003oMP3oool60?l0ob<0oooo1P3o000307mo
O`030000001oOgl0Ogmo01X0Ogmo00<000000?ooo`3oool0o`3ooom60?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool03`3oooo:0?l000@0
o`3o103o0004003o00@0o`0010000?mh0?l000H0o`3o9P3o00000`000000Ogmo07moO`0J07moO`03
0000003oool0oooo0?l0ooooAP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0
oooo000X0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0b`3oool40?l0o`@0o`00
1@00o`030?ooo`@0003oNP3oool60?l0oaX0oooo00<0000007moO`1oOgl00P1oOgl2000001`0Ogmo
00<000000?ooo`3oool0o`3ooom60?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
1@3oool002P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3?0?ooo`@0o`3o103o
00000`3oool00?l0003o0002003o00<0oooo10000?ml0?ooo`H0o`3o503oool00`000000Ogmo07mo
O`0207moO`030000001oOgl0Ogmo01/0Ogmo00<000000?ooo`3oool0o`3ooom60?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`3C0?ooo`@0o`3o1@3o0004003o00<0oooo1@000?mm0?ooo`H0o`3o3P3oool0
0`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo01/0Ogmo00<000000?ooo`3oool0o`3ooom6
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool002P0oooo1000000>0?oo
o`030000003oool0oooo0=L0oooo1@3o0?l40?l000@00?l0103oool40000ogl0oooo1@3o0?l90?oo
o`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1oOgl06`1oOgl00`000000oooo0?ooo`3o0?oo
odH0oooo00<000000?ooo`3oool03@3oool4000000L0oooo000X0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0g03oool40?l0o`@0o`001@00o`030?ooo`@0003oP03oool60?l0o`<0
oooo00<0000007moO`1oOgl00P1oOgl00`000000Ogmo07moO`0K07moO`030000003oool0oooo0?l0
ooooAP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0h03oool40?l0o`@0o`0000<0oooo003o0000o`00
0P00o`030?ooo`D0003oP@3oool60?l0o`80Ogmo00<0000007moO`1oOgl06`1oOgl00`000000oooo
0?ooo`3o0?ooodH0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`050?ooo`00:03o
ool00`000000oooo0?ooo`0?0?ooon/0o`3o103o00000`3o0?l00?l0003o0002003o00@0o`3o1000
0?n60?l0oad0Ogmo00<000000?ooo`3oool0o`3ooom60?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3X
0?ooo`@0o`3o103o00000`3oool00?l0003o0002003o00@0oooo10000?ml0?ooo`040000001oOgl0
Ogmo07moO`8000007@1oOgl00`000000oooo0?ooo`3o0?ooodH0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo0>`0oooo103o0?l40?l000030?ooo`00o`000?l000<00?l00`3oool50000ogL0oooo00<00000
07moO`1oOgl00P1oOgl00`000000Ogmo07moO`0K07moO`030000003oool0oooo0?l0ooooAP3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0l03oool40?l0o`D0o`0000<0oooo003o0000o`000P00o`040?oo
o`@0003oL`3oool00`000000Ogmo07moO`0207moO`030000001oOgl0Ogmo01/0Ogmo00<000000?oo
o`3oool0o`3ooom60?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool002P0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3d0?ooo`D0o`3o103o00000`3oool0
0?l0003o0002003o00@0oooo10000?m_0?ooo`030000001oOgl0Ogmo0080Ogmo00<0000007moO`1o
Ogl06`1oOgl00`000000oooo0?ooo`3o0?ooodH0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?T0oooo
103o0?l40?l000030?ooo`00o`000?l000800?l0103oool40000of/0oooo00<0000007moO`1oOgl0
0P1oOgl00`000000Ogmo07moO`0K07moO`030000003oool0oooo0?l0ooooAP3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0o@3oool40?l0o`@0o`0000<0oooo003o0000o`000`00o`030?ooo`D0003oIP3o
oolT00000?l0ooooB03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo000X
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0o`3oool20?ooo`@0o`3o103o0002
0?ooo`@00?l0103oool40000of80oooo00<0000007moO`1oOgl0801oOgl00`000000oooo0?ooo`3o
0?ooodH0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`050?ooo`00:03oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0oooo1P3oool40?l0o`@0o`000P3oool4003o
00@0oooo10000?mN0?ooo`030000001oOgl0Ogmo0200Ogmo00<000000?ooo`3oool0o`3ooom60?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`3o0?ooo`X0oooo103o0?l40?l00080oooo1000o`040?ooo`D0
003oF@3oool01@000000Ogmo07moO`1oOgl0000001h0Ogmo00<000000?ooo`3oool0o`3ooom60?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`3o0?ooo`h0oooo103o0?l50?l000030?ooo`00o`000?l000<0
0?l0103oool40000oeD0oooo00D0000007moO`1oOgl0Ogmo0000000N07moO`030000003oool0oooo
0?l0ooooAP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo000X0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0o`3ooolB0?ooo`D0o`3o103o00020?ooo`@0
0?l0103oool40000oe40oooo00D0000007moO`1oOgl0Ogmo0000000N07moO`030000003oool0oooo
0?l0ooooAP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo000X0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0o`3ooolG0?ooo`@0o`3o103o00020?ooo`@0
0?l0103oool50000od`0oooo00D0000007moO`1oOgl0Ogmo0000000N07moO`030000003oool0oooo
0?l0ooooAP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo000X0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0o`3ooolK0?ooo`@0o`3o103o00020?ooo`@0
0?l01@3oool40000odP0oooo00D0000007moO`1oOgl0Ogmo0000000N07moO`030000003oool0oooo
0?l0ooooAP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo000X0?ooo`@0
00003P3oool00`000000oooo0?ooo`3o0?oooal0oooo103o0?l40?l00080oooo1000o`050?ooo`@0
003oA03oool00`000000Ogmo07moO`0P07moO`030000003oool0oooo0?l0ooooAP3oool00`000000
oooo0?ooo`0=0?ooo`@000001`3oool002P0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`3o0?ooob<0oooo103o0?l40?l00080oooo1@00o`040?ooo`@0003o@03oool00`000000Ogmo
07moO`0P07moO`030000003oool0oooo0?l0ooooAP3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0o`3o
oolW0?ooo`@0o`3o103o00030?ooo`@00?l0103oool50000oc/0oooo00<0000007moO`1oOgl0801o
Ogl00`000000oooo0?ooo`3o0?ooodH0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`050?ooo`00:03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0oooo:`3oool4
0?l0o`D0o`000P3oool4003o00D0oooo10000?lg0?ooo`030000001oOgl0Ogmo0200Ogmo00<00000
0?ooo`3oool0o`3ooom60?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool0
02P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?ooobl0oooo1@3o0?l40?l0
0080oooo1000o`050?ooo`@0003o<`3oool010000000Ogmo07moO`00000O07moO`030000003oool0
oooo0?l0ooooAP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo000X0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool0o`3ooold0?ooo`@0o`3o103o00020?oo
o`D00?l0103oool50000obh0oooo00@0000007moO`1oOgl000007`1oOgl00`000000oooo0?ooo`3o
0?ooodH0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`050?ooo`00:03oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0oooo>03oool40?l0o`@0o`000`3oool4003o
00D0oooo10000?lZ0?ooo`040000001oOgl0Ogmo000001l0Ogmo00<000000?ooo`3oool0o`3ooom6
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`3o0?oooc`0oooo103o0?l40?l000<0oooo1000o`050?oo
o`@0003o9P3oool00`000000Ogmo07moO`0P07moO`030000003oool0oooo0?l0ooooAP3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0o`3ooom00?ooo`@0o`3o103o00030?ooo`@00?l01@3oool40000ob80
oooo00<0000007moO`1oOgl0801oOgl00`000000oooo0?ooo`3o0?ooodH0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo0?l0ooooA03oool40?l0o`@0o`000`3oool5003o00@0oooo1@000?lM0?ooo`030000
001oOgl0Ogmo0200Ogmo00<000000?ooo`3oool0o`3ooom60?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`3o0?ooodP0oooo103o0?l50?l000<0oooo1000o`050?ooo`@0003o6@3oool00`000000Ogmo07mo
O`0P07moO`030000003oool0oooo0?l0ooooAP3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo00D0oooo000X0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0o`3ooom<
0?ooo`D0o`3o103o00030?ooo`@00?l01@3oool40000oaD0oooo00<0000007moO`1oOgl0801oOgl0
0`000000oooo0?ooo`3o0?ooodH0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`05
0?ooo`00:03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0ooooD@3oool40?l0
o`@0o`000`3oool4003o00D0oooo1@000?l@0?ooo`030000001oOgl000000200Ogmo00<000000?oo
o`3oool0o`3ooom60?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool002P0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?oooeD0oooo103o0?l40?l000<0
oooo1@00o`050?ooo`@0003o303ooolT00000?l0ooooB03oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
o`3ooomI0?ooo`@0o`3o103o00040?ooo`@00?l01@3oool40000o`P0oooo00<0000007moO`000000
801oOgl00`000000oooo0?ooo`3o0?ooodH0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0ooooG@3o
ool40?l0o`@0o`00103oool4003o00D0oooo1@000?l30?ooo`030000001oOgl000000200Ogmo00<0
00000?ooo`3oool0o`3ooom60?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3o
ool002P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?ooof40oooo103o0?l4
0?l000@0oooo1000o`060?ooo`@0003o8P1oOgl00`000000oooo0?ooo`3o0?ooodH0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`050?ooo`00:03oool4000000h0ooooo`000?mX0000
o`@0o`3o1@3o00030000o`D00?l01`000?lP07moO`030000003oool0oooo0?l0ooooAP3oool00`00
0000oooo0?ooo`0=0?ooo`@000001`3oool002P0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`3o0?ooofT0oooo1@3o0?l40?l000@0oooo1000o`0300000200Ogmo00<000000?ooo`3o
ool0o`3ooom60?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool002P0oooo
00<000000?ooo`3oool03`3ooooo003o07400?l0103o0?l40?l000H00?l000<0000007moO`1oOgl0
7P1oOgl00`000000oooo0?ooo`3o0?ooodH0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0ooooLP3o
ool40?l0o`@0o`000`00000P07moO`030000003oool0oooo0?l0ooooAP3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00l0ooooo`3o001i
0?l000@0o`3o0P3o00000`000000Ogmo07moO`0N07moO`030000003oool0oooo0?l0ooooAP3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo
00l0ooooo`3o0?mo0?l0o`030000001oOgl0Ogmo01h0Ogmo00<000000?ooo`3oool0o`3ooom60?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`3o0?ooogX0oooo0`00000P07moO`030000003oool0oooo0?l0
ooooAP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0o`3ooomj0?ooo`8000008@1oOgl00`000000oooo
0?ooo`3o0?ooodH0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`050?ooo`00:03o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0ooooNP3oool200000240Ogmo00<0
00000?ooo`3oool0o`3ooom60?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3o
ool002P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?ooogX0oooo9000003o
0?ooodP0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`050?ooo`00:03oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0ooooNP3oool00`000000Ogmo07moO`0P07mo
O`030000003oool0oooo0?l0ooooAP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
00D0oooo000X0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0o`3ooomj0?ooo`03
0000001oOgl0Ogmo0200Ogmo00<000000?ooo`3oool0o`3ooom60?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`3o0?ooogX0oooo00<0000007moO`1oOgl0801oOgl00`000000oooo0?ooo`3o0?ooodH0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo0?l0ooooNP3oool00`000000Ogmo07moO`0P07moO`030000003o
ool0oooo0?l0ooooAP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo000X
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0o`3ooomj0?ooob@00000o`3ooom8
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool00180oooo00<000000?oo
o`3oool00P0000030?ooo`800000303oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
0?l0ooooo`3ooooV0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool00180
oooo00<000000?ooo`0000000P3oool00`000000oooo000000020?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?ooool0ooooiP3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo000?0?ooo`@0000000L0oooo0000003oool0
oooo0000003oool000000080oooo00<000000?ooo`3oool02@3oool6000000`0oooo00<000000?oo
o`3oool0o`3ooooo0?ooonH0oooo00<000000?ooo`3oool02`3oool6000000L0oooo000?0?ooo`06
0000003oool0oooo0000003oool000000P3oool00`000000oooo000000020?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?ooool0ooooiP3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo000@0?ooo`050000003oool00000
0?ooo`0000000P3oool00`000000oooo000000020?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?ooool0ooooiP3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo00D0oooo000A0?ooo`80000000L0oooo0000003oool0oooo0000003o
ool000000080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo0?l0ooooo`3ooooV0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3o
ool00180oooo00<000000?ooo`3oool00P0000030?ooo`800000303oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo0?l0ooooo`3ooooV0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?oo
ool0ooooiP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo000X0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0o`3ooooo0?ooonH0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo0?l0ooooo`3ooooV0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
1@3oool002P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?ooool0ooooiP3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0o`3ooooo0?ooonH0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
0?l0ooooo`3ooooV0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool002P0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?ooool0ooooiP3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0o`3ooooo0?ooonH0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0ooooo`3o
oooV0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool002P0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?ooool0ooooiP3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo00D0oooo000X0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0o`3ooooo0?ooonH0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`050?oo
o`00:03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0ooooo`3ooooV0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?ooo`3oool0
3`3oool200000?l0ooooo`3ooooW0?ooo`8000004@3oool00`000000oooo0?ooo`050?ooo`00:03o
ool4000000h0ooooo`00003o00000>X000003`3oool4000000L0oooo000X0?ooo`030000003oool0
oooo0?l0ooooo`3ooooo0?ooo``0oooo00<000000?ooo`3oool01@3oool002P0oooo00<000000?oo
o`3oool0o`3ooooo0?ooool0oooo303oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0ZP3oool00`000000
oooo0?ooo`2Z0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0@`3oool00`000000
oooo0?ooo`050?ooo`00:03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0:X0oooo
00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo0:X0oooo
00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`050?ooo`00:03oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`0P0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`0P0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`0P0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`0P0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0803oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo0200oooo0P0000070?ooo`00:03oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo0200oooo0P0000070?ooo`00:03ooooo00000?l00000o`00000@0000
00L0oooo0000\
\>"],
  ImageRangeCache->{{{0, 827}, {345.375, 0}} -> {-170.008, -526.762, 2.89325, \
2.89325}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ShowSystem[testsys, \ 
        PlotRange \[Rule] {{1200, 2200}, {\(-300\), 50}, {\(-50\), 50}}, 
        Axes \[Rule] True];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .51912 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.0202643 1.02026 -0.228584 1.02026 [
[.00971 .27759 -10.6817 -9 ]
[.00971 .27759 13.3183 0 ]
[.16399 .22474 -11.0943 -9 ]
[.16399 .22474 12.9057 0 ]
[.32537 .16946 -11.5369 -9 ]
[.32537 .16946 12.4631 0 ]
[.49437 .11159 -12.0129 -9 ]
[.49437 .11159 11.9871 0 ]
[.67154 .05093 -12.5261 -9 ]
[.67154 .05093 11.4739 0 ]
[.85748 -0.0127 -13.0811 -9 ]
[.85748 -0.0127 10.9189 0 ]
[.87069 -0.00412 0 -6.03618 ]
[.87069 -0.00412 24 2.96382 ]
[.91066 .05487 0 -5.99404 ]
[.91066 .05487 24 3.00596 ]
[.94888 .11127 0 -5.95416 ]
[.94888 .11127 24 3.04584 ]
[.98546 .16526 0 -5.91634 ]
[.98546 .16526 6 3.08366 ]
[1.00406 .199 0 -5.89365 ]
[1.00406 .199 18 3.10635 ]
[1.00585 .21428 0 -5.88458 ]
[1.00585 .21428 18 3.11542 ]
[1.00765 .22967 0 -5.87544 ]
[1.00765 .22967 6 3.12456 ]
[1.00947 .24518 0 -5.86624 ]
[1.00947 .24518 12 3.13376 ]
[1.01129 .26079 0 -5.85698 ]
[1.01129 .26079 12 3.14302 ]
[ 0 0 0 0 ]
[ 1 .51912 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00832 .29027 m
.85862 0 L
s
.00832 .29027 m
.00762 .29661 L
s
[(1200)] .00971 .27759 -0.10986 1 Mshowa
.16303 .23746 m
.16255 .24382 L
s
[(1400)] .16399 .22474 -0.07547 1 Mshowa
.32488 .18221 m
.32463 .18858 L
s
[(1600)] .32537 .16946 -0.03859 1 Mshowa
.49438 .12434 m
.49439 .13072 L
s
[(1800)] .49437 .11159 .00107 1 Mshowa
.6721 .06368 m
.67237 .07005 L
s
[(2000)] .67154 .05093 .04384 1 Mshowa
.85862 0 m
.8592 .00635 L
s
[(2200)] .85748 -0.0127 .09009 1 Mshowa
.125 Mabswid
.04635 .27729 m
.04596 .28109 L
s
.08481 .26416 m
.08445 .26797 L
s
.1237 .25088 m
.12338 .2547 L
s
.2028 .22388 m
.20255 .2277 L
s
.24303 .21015 m
.24281 .21397 L
s
.28372 .19626 m
.28354 .20008 L
s
.36652 .16799 m
.36641 .17182 L
s
.40864 .15361 m
.40857 .15744 L
s
.45126 .13906 m
.45123 .14289 L
s
.53802 .10945 m
.53806 .11327 L
s
.58218 .09437 m
.58226 .0982 L
s
.62687 .07912 m
.62699 .08294 L
s
.71788 .04805 m
.71809 .05187 L
s
.76422 .03223 m
.76447 .03605 L
s
.81113 .01621 m
.81143 .02003 L
s
.25 Mabswid
.85862 0 m
.99099 .19518 L
s
.85862 0 m
.85259 .00206 L
s
[(-300)] .87069 -0.00412 -1 .34137 Mshowa
.89856 .05889 m
.89251 .0609 L
s
[(-200)] .91066 .05487 -1 .33201 Mshowa
.93674 .1152 m
.93068 .11716 L
s
[(-100)] .94888 .11127 -1 .32315 Mshowa
.97329 .16909 m
.96721 .17101 L
s
[(0)] .98546 .16526 -1 .31474 Mshowa
.125 Mabswid
.86676 .01199 m
.86313 .01322 L
s
.87482 .02388 m
.87119 .0251 L
s
.8828 .03565 m
.87917 .03687 L
s
.89072 .04732 m
.88709 .04853 L
s
.90633 .07035 m
.9027 .07155 L
s
.91404 .08171 m
.9104 .0829 L
s
.92167 .09297 m
.91804 .09416 L
s
.92924 .10413 m
.9256 .10531 L
s
.94418 .12616 m
.94054 .12733 L
s
.95155 .13703 m
.94791 .1382 L
s
.95886 .14781 m
.95522 .14897 L
s
.96611 .1585 m
.96246 .15965 L
s
.98042 .17959 m
.97677 .18074 L
s
.98748 .19001 m
.98383 .19115 L
s
.25 Mabswid
.99099 .19518 m
1 .27231 L
s
.99187 .20277 m
.98578 .20466 L
s
[(-40)] 1.00406 .199 -1 .3097 Mshowa
.99366 .21803 m
.98756 .21991 L
s
[(-20)] 1.00585 .21428 -1 .30768 Mshowa
.99545 .2334 m
.98936 .23527 L
s
[(0)] 1.00765 .22967 -1 .30565 Mshowa
.99726 .24888 m
.99116 .25073 L
s
[(20)] 1.00947 .24518 -1 .30361 Mshowa
.99908 .26447 m
.99298 .26631 L
s
[(40)] 1.01129 .26079 -1 .30155 Mshowa
.125 Mabswid
.99232 .20658 m
.98866 .20771 L
s
.99276 .21039 m
.98911 .21152 L
s
.99321 .21421 m
.98955 .21533 L
s
.99411 .22186 m
.99045 .22299 L
s
.99455 .2257 m
.9909 .22682 L
s
.995 .22955 m
.99134 .23067 L
s
.9959 .23726 m
.99224 .23838 L
s
.99636 .24113 m
.9927 .24224 L
s
.99681 .245 m
.99315 .24611 L
s
.99772 .25277 m
.99406 .25388 L
s
.99817 .25666 m
.99451 .25777 L
s
.99863 .26056 m
.99496 .26167 L
s
.99143 .19897 m
.98778 .20011 L
s
.99954 .26839 m
.99588 .26949 L
s
0 0 m
1 0 L
1 .51912 L
0 .51912 L
closepath
clip
newpath
1 0 1 r
.5 Mabswid
.16166 .46523 m
.21466 .44444 L
s
1 0 0 r
.16159 .46517 m
.21464 .44442 L
s
0 1 0 r
.16152 .46511 m
.21462 .4444 L
s
0 0 1 r
.16145 .46504 m
.2146 .44438 L
s
1 0 1 r
.16026 .46401 m
.21431 .44413 L
s
1 0 0 r
.16001 .46379 m
.21427 .44409 L
s
0 1 0 r
.15968 .46351 m
.21422 .44404 L
s
0 0 1 r
.15925 .46312 m
.21417 .444 L
s
1 0 1 r
.15904 .46294 m
.21415 .44398 L
s
.15572 .46004 m
.21404 .44388 L
s
0 0 1 r
.15551 .45986 m
.21402 .44386 L
s
0 1 0 r
.15507 .45948 m
.21397 .44382 L
s
1 0 0 r
.15474 .45919 m
.21392 .44378 L
s
1 0 1 r
.15449 .45897 m
.21388 .44373 L
s
.2176 .44183 m .21867 .44119 L .21949 .44394 L .941 .685 .521 r
F
.21673 .43986 m .21867 .44119 L .2176 .44183 L F
.21673 .43986 m .21753 .43863 L .21867 .44119 L F
.21823 .44394 m .21949 .44394 L .21994 .44669 L F
.2176 .44183 m .21949 .44394 L .21823 .44394 L F
0 g
.21867 .44119 m
.21949 .44394 L
s
.21568 .43817 m .21753 .43863 L .21673 .43986 L .941 .685 .521 r
F
.21568 .43817 m .21616 .43642 L .21753 .43863 L F
0 g
.21753 .43863 m
.21867 .44119 L
s
.21858 .44605 m .21994 .44669 L .22 .44925 L .941 .685 .521 r
F
.21823 .44394 m .21994 .44669 L .21858 .44605 L F
0 g
.21949 .44394 m
.21994 .44669 L
s
.21452 .43687 m .21616 .43642 L .21568 .43817 L .941 .685 .521 r
F
.21452 .43687 m .21465 .43473 L .21616 .43642 L F
0 g
.21616 .43642 m
.21753 .43863 L
s
.22319 .43979 m
.22402 .44254 L
s
.22392 .43956 m
.22319 .43979 L
s
.22206 .43722 m
.22319 .43979 L
s
.22402 .44254 m
.22448 .44529 L
s
.22474 .44231 m
.22402 .44254 L
s
.21858 .44605 m .22 .44925 L .21863 .44801 L .941 .685 .521 r
F
.21863 .44801 m .22 .44925 L .21966 .45145 L F
0 g
.21994 .44669 m
.22 .44925 L
s
.21654 .44247 m .2176 .44183 L .21823 .44394 L .941 .685 .521 r
F
.21593 .4411 m .2176 .44183 L .21654 .44247 L F
.21593 .4411 m .21673 .43986 L .2176 .44183 L F
0 g
.22474 .44231 m
.22392 .43956 L
s
.22392 .43956 m
.22278 .437 L
s
.21698 .44393 m .21823 .44394 L .21858 .44605 L .941 .685 .521 r
F
.21654 .44247 m .21823 .44394 L .21698 .44393 L F
0 g
.2252 .44506 m
.22474 .44231 L
s
.22278 .437 m
.22206 .43722 L
s
.22069 .43502 m
.22206 .43722 L
s
.2152 .43992 m .21673 .43986 L .21593 .4411 L .941 .685 .521 r
F
.2152 .43992 m .21568 .43817 L .21673 .43986 L F
0 g
.2252 .44506 m
.22448 .44529 L
s
.22278 .437 m
.22142 .43479 L
s
.21722 .4454 m .21858 .44605 L .21863 .44801 L .941 .685 .521 r
F
.21698 .44393 m .21858 .44605 L .21722 .4454 L F
.21334 .43605 m .21465 .43473 L .21452 .43687 L F
.21334 .43605 m .21311 .43366 L .21465 .43473 L F
0 g
.21465 .43473 m
.21616 .43642 L
s
.21439 .43902 m .21568 .43817 L .2152 .43992 L .941 .685 .521 r
F
.21439 .43902 m .21452 .43687 L .21568 .43817 L F
0 g
.22142 .43479 m
.22069 .43502 L
s
.21863 .44801 m .21966 .45145 L .21836 .4497 L .941 .685 .521 r
F
.21722 .4454 m .21863 .44801 L .21725 .44677 L F
.21725 .44677 m .21863 .44801 L .21836 .4497 L F
.21836 .4497 m .21966 .45145 L .21894 .45315 L F
0 g
.21966 .45145 m
.22 .44925 L
s
.22054 .44671 m .22454 .44785 L .22526 .44763 L .656 .751 .92 r
F
0 g
.2252 .44506 m
.22526 .44763 L
s
.22448 .44529 m
.22453 .44749 L
s
.22054 .44671 m .22257 .44608 L .22454 .44785 L .656 .751 .92 r
F
0 g
.22454 .44785 m
.22526 .44763 L
s
.2242 .45006 m
.22454 .44785 L
s
.22492 .44983 m
.22526 .44763 L
s
.21547 .44311 m .21654 .44247 L .21698 .44393 L .941 .685 .521 r
F
.21513 .44234 m .21654 .44247 L .21547 .44311 L F
.21513 .44234 m .21593 .4411 L .21654 .44247 L F
.21572 .44393 m .21698 .44393 L .21722 .4454 L F
.21547 .44311 m .21698 .44393 L .21572 .44393 L F
.21472 .44167 m .21593 .4411 L .21513 .44234 L F
.21472 .44167 m .2152 .43992 L .21593 .4411 L F
.21357 .43845 m .21452 .43687 L .21439 .43902 L F
.21357 .43845 m .21334 .43605 L .21452 .43687 L F
.21585 .44476 m .21722 .4454 L .21725 .44677 L F
.21572 .44393 m .21722 .4454 L .21585 .44476 L F
.21836 .4497 m .21894 .45315 L .21781 .451 L F
.21707 .44795 m .21836 .4497 L .21781 .451 L F
.21725 .44677 m .21836 .4497 L .21707 .44795 L F
.21991 .4331 m .21919 .43332 L .219 .43638 L .553 .337 .541 r
F
0 g
.21969 .43389 m
.22069 .43502 L
s
.21426 .44117 m .2152 .43992 L .21472 .44167 L .941 .685 .521 r
F
.21426 .44117 m .21439 .43902 L .2152 .43992 L F
.2122 .43577 m .21311 .43366 L .21334 .43605 L F
.2122 .43577 m .21162 .43328 L .21311 .43366 L F
0 g
.21311 .43366 m
.21465 .43473 L
s
.21585 .44476 m .21725 .44677 L .21587 .44553 L .941 .685 .521 r
F
.21587 .44553 m .21725 .44677 L .21707 .44795 L F
.21991 .4331 m .219 .43638 L .21697 .43702 L .553 .337 .541 r
F
0 g
.21836 .43202 m
.21991 .4331 L
s
.21991 .4331 m
.22142 .43479 L
s
.21919 .43332 m
.21991 .4331 L
s
.21764 .43225 m
.21919 .43332 L
s
.21723 .44535 m .22257 .44608 L .22054 .44671 L .656 .751 .92 r
F
0 g
.22054 .44671 m
.22526 .44763 L
s
.2242 .45006 m
.22348 .45175 L
s
.22492 .44983 m
.2242 .45006 L
s
.21781 .451 m .21894 .45315 L .21789 .45422 L .941 .685 .521 r
F
0 g
.21894 .45315 m
.21966 .45145 L
s
.2242 .45153 m
.22492 .44983 L
s
.2138 .44085 m .21439 .43902 L .21426 .44117 L .941 .685 .521 r
F
.2138 .44085 m .21357 .43845 L .21439 .43902 L F
.21278 .43825 m .21334 .43605 L .21357 .43845 L F
.21278 .43825 m .2122 .43577 L .21334 .43605 L F
.21697 .43702 m .21882 .43945 L .21544 .4405 L .553 .337 .541 r
F
.21697 .43702 m .219 .43638 L .21882 .43945 L F
0 g
.21697 .43702 m
.21991 .4331 L
s
.219 .43638 m
.21919 .43332 L
s
.21723 .44535 m .22061 .4443 L .22257 .44608 L .656 .751 .92 r
F
0 g
.22257 .44608 m
.22454 .44785 L
s
.21707 .44795 m .21781 .451 L .21668 .44885 L .941 .685 .521 r
F
.21577 .44619 m .21707 .44795 L .21668 .44885 L F
.21587 .44553 m .21707 .44795 L .21577 .44619 L F
0 g
.21547 .44311 m
.21572 .44393 L
s
.21513 .44234 m
.21547 .44311 L
s
.21572 .44393 m
.21585 .44476 L
s
.21472 .44167 m
.21513 .44234 L
s
.21585 .44476 m
.21587 .44553 L
s
.21781 .451 m .21789 .45422 L .217 .45182 L .941 .685 .521 r
F
.21668 .44885 m .21781 .451 L .217 .45182 L F
0 g
.21426 .44117 m
.21472 .44167 L
s
.21335 .44074 m .21357 .43845 L .2138 .44085 L .941 .685 .521 r
F
.21335 .44074 m .21278 .43825 L .21357 .43845 L F
0 g
.21836 .43202 m
.21764 .43225 L
s
.21616 .43187 m
.21764 .43225 L
s
.21484 .4437 m .22061 .4443 L .21723 .44535 L .656 .751 .92 r
F
0 g
.21723 .44535 m
.22054 .44671 L
s
.2138 .44085 m
.21426 .44117 L
s
.21836 .43202 m
.21688 .43165 L
s
.21668 .44885 m .217 .45182 L .21612 .44942 L .941 .685 .521 r
F
.21555 .4467 m .21668 .44885 L .21612 .44942 L F
.21577 .44619 m .21668 .44885 L .21555 .4467 L F
0 g
.21577 .44619 m
.21587 .44553 L
s
.21119 .43604 m .21162 .43328 L .2122 .43577 L .941 .685 .521 r
F
.21119 .43604 m .2103 .43364 L .21162 .43328 L F
0 g
.21162 .43328 m
.21311 .43366 L
s
.21544 .4405 m .21864 .44253 L .21484 .4437 L .553 .337 .541 r
F
.21544 .4405 m .21882 .43945 L .21864 .44253 L F
0 g
.21544 .4405 m
.21697 .43702 L
s
.21882 .43945 m
.219 .43638 L
s
.22348 .45175 m
.22243 .45282 L
s
.2242 .45153 m
.22348 .45175 L
s
.21207 .43844 m .2122 .43577 L .21278 .43825 L .941 .685 .521 r
F
.21207 .43844 m .21119 .43604 L .2122 .43577 L F
0 g
.22315 .4526 m
.2242 .45153 L
s
.21555 .4467 m .21612 .44942 L .21523 .44702 L .941 .685 .521 r
F
0 g
.21555 .4467 m
.21577 .44619 L
s
.21296 .44084 m .21278 .43825 L .21335 .44074 L .941 .685 .521 r
F
0 g
.21335 .44074 m
.2138 .44085 L
s
.21296 .44084 m .21207 .43844 L .21278 .43825 L .941 .685 .521 r
F
.217 .45182 m .21789 .45422 L .21657 .45459 L F
0 g
.21789 .45422 m
.21894 .45315 L
s
0 0 0 r
2 Mabswid
.21466 .44444 Mdot
.21464 .44442 Mdot
.217 .45182 m .21657 .45459 L .21599 .4521 L .941 .685 .521 r
F
.21612 .44942 m .217 .45182 L .21599 .4521 L F
0 0 0 r
.21462 .4444 Mdot
.2146 .44438 Mdot
.21484 .4437 m .21864 .44253 L .22061 .4443 L .656 .751 .92 r
F
0 0 1 r
.5 Mabswid
.2146 .44438 m
.21532 .4441 L
s
0 1 0 r
.21462 .4444 m
.21534 .44412 L
s
1 0 0 r
.21464 .44442 m
.21536 .44414 L
s
1 0 1 r
.21466 .44444 m
.21539 .44416 L
s
0 g
.22061 .4443 m
.22257 .44608 L
s
.21612 .44942 m .21599 .4521 L .21542 .44961 L .941 .685 .521 r
F
.21523 .44702 m .21612 .44942 L .21542 .44961 L F
1 0 1 r
.21431 .44413 m
.21503 .44386 L
s
0 0 0 r
2 Mabswid
.21431 .44413 Mdot
.21523 .44702 m .21542 .44961 L .21484 .44713 L .941 .685 .521 r
F
0 g
.5 Mabswid
.21523 .44702 m
.21555 .4467 L
s
1 0 0 r
.21427 .44409 m
.21499 .44383 L
s
0 0 0 r
2 Mabswid
.21427 .44409 Mdot
0 1 0 r
.5 Mabswid
.21422 .44404 m
.21494 .44379 L
s
0 0 0 r
2 Mabswid
.21422 .44404 Mdot
0 0 1 r
.5 Mabswid
.21417 .444 m
.21489 .44375 L
s
0 0 0 r
2 Mabswid
.21417 .444 Mdot
1 0 1 r
.5 Mabswid
.21415 .44398 m
.21488 .44373 L
s
0 0 0 r
2 Mabswid
.21415 .44398 Mdot
.21404 .44388 Mdot
.21402 .44386 Mdot
.21397 .44382 Mdot
.21392 .44378 Mdot
.21264 .44116 m .21207 .43844 L .21296 .44084 L .941 .685 .521 r
F
0 g
.5 Mabswid
.21296 .44084 m
.21335 .44074 L
s
0 0 0 r
2 Mabswid
.21388 .44373 Mdot
0 g
.5 Mabswid
.21688 .43165 m
.21616 .43187 L
s
.21484 .43222 m
.21616 .43187 L
s
.21484 .4437 m .21845 .4456 L .21507 .44665 L .553 .337 .541 r
F
.21484 .4437 m .21864 .44253 L .21845 .4456 L F
.21328 .44179 m .21864 .44253 L .21484 .4437 L .656 .751 .92 r
F
1 0 0 r
.21863 .44255 m
.21865 .44254 L
s
1 0 1 r
.21863 .44258 m
.21868 .44257 L
s
0 0 1 r
.21862 .44286 m
.21889 .44275 L
s
0 1 0 r
.21861 .44288 m
.2189 .44277 L
s
1 0 0 r
.21861 .4429 m
.21892 .44278 L
s
1 0 1 r
.21861 .44292 m
.21894 .4428 L
s
0 g
.21515 .44205 m
.21544 .4405 L
s
1 0 1 r
.21388 .44373 m
.21466 .44353 L
s
1 0 0 r
.21392 .44378 m
.2147 .44357 L
s
0 1 0 r
.21397 .44382 m
.21475 .44361 L
s
0 0 1 r
.21402 .44386 m
.21479 .44365 L
s
1 0 1 r
.21404 .44388 m
.21481 .44367 L
s
.15308 .45774 m
.21353 .44342 L
s
1 0 0 r
.15315 .45781 m
.21355 .44344 L
s
0 1 0 r
.15323 .45787 m
.21357 .44346 L
s
0 0 1 r
.1533 .45793 m
.21359 .44348 L
s
1 0 1 r
.21481 .44367 m
.21664 .44314 L
s
.21863 .44257 m
.21867 .44256 L
s
0 0 0 r
2 Mabswid
.21481 .44367 Mdot
0 0 1 r
.5 Mabswid
.21479 .44365 m
.21715 .44299 L
s
.21863 .44257 m
.21867 .44255 L
s
0 0 0 r
2 Mabswid
.21479 .44365 Mdot
0 1 0 r
.5 Mabswid
.21475 .44361 m
.21829 .44263 L
s
.21863 .44254 m
.21865 .44253 L
s
0 0 0 r
2 Mabswid
.21475 .44361 Mdot
.21151 .43901 m .21119 .43604 L .21207 .43844 L .941 .685 .521 r
F
.21264 .44116 m .21151 .43901 L .21207 .43844 L F
.21484 .44713 m .21462 .44942 L .21439 .44702 L F
.21484 .44713 m .21542 .44961 L .21462 .44942 L F
0 g
.5 Mabswid
.21484 .44713 m
.21523 .44702 L
s
0 0 0 r
2 Mabswid
.2147 .44357 Mdot
.21466 .44353 Mdot
0 g
.5 Mabswid
.21688 .43165 m
.21556 .432 L
s
0 0 1 r
.21359 .44348 m
.21441 .44328 L
s
0 0 0 r
2 Mabswid
.21359 .44348 Mdot
0 1 0 r
.5 Mabswid
.21357 .44346 m
.21439 .44326 L
s
0 0 0 r
2 Mabswid
.21357 .44346 Mdot
.21038 .43685 m .2103 .43364 L .21119 .43604 L .941 .685 .521 r
F
.21151 .43901 m .21038 .43685 L .21119 .43604 L F
1 0 0 r
.5 Mabswid
.21355 .44344 m
.21437 .44324 L
s
0 0 0 r
2 Mabswid
.21355 .44344 Mdot
1 0 1 r
.5 Mabswid
.21353 .44342 m
.21435 .44322 L
s
0 0 0 r
2 Mabswid
.21353 .44342 Mdot
.21038 .43685 m .20924 .43469 L .2103 .43364 L .941 .685 .521 r
F
0 g
.5 Mabswid
.2103 .43364 m
.21162 .43328 L
s
.21542 .44961 m .21486 .45183 L .21462 .44942 L .941 .685 .521 r
F
.21542 .44961 m .21599 .4521 L .21486 .45183 L F
0 0 0 r
2 Mabswid
.21441 .44328 Mdot
.21439 .44326 Mdot
.21437 .44324 Mdot
.21435 .44322 Mdot
.21242 .44167 m .21151 .43901 L .21264 .44116 L .941 .685 .521 r
F
0 g
.5 Mabswid
.21264 .44116 m
.21296 .44084 L
s
.22243 .45282 m
.22112 .45319 L
s
.22315 .4526 m
.22243 .45282 L
s
.21439 .44702 m .2138 .44885 L .21393 .4467 L .941 .685 .521 r
F
.21439 .44702 m .21462 .44942 L .2138 .44885 L F
0 g
.21439 .44702 m
.21484 .44713 L
s
.21599 .4521 m .21509 .45423 L .21486 .45183 L .941 .685 .521 r
F
.21599 .4521 m .21657 .45459 L .21509 .45423 L F
0 g
.21657 .45459 m
.21789 .45422 L
s
.22184 .45297 m
.22315 .4526 L
s
0 0 0 r
2 Mabswid
.21894 .4428 Mdot
.21892 .44278 Mdot
.2189 .44277 Mdot
.21889 .44275 Mdot
.21242 .44167 m .21112 .43991 L .21151 .43901 L .941 .685 .521 r
F
.21232 .44233 m .21112 .43991 L .21242 .44167 L F
0 g
.5 Mabswid
.21242 .44167 m
.21264 .44116 L
s
.21112 .43991 m .21038 .43685 L .21151 .43901 L .941 .685 .521 r
F
.21393 .4467 m .21299 .44795 L .21347 .44619 L F
.21393 .4467 m .2138 .44885 L .21299 .44795 L F
0 g
.21393 .4467 m
.21439 .44702 L
s
1 0 1 r
.21868 .44257 m
.21951 .44226 L
s
0 0 0 r
2 Mabswid
.21868 .44257 Mdot
.21867 .44256 Mdot
.21867 .44255 Mdot
1 0 0 r
.5 Mabswid
.21865 .44254 m
.21901 .44241 L
s
0 0 0 r
2 Mabswid
.21865 .44254 Mdot
.21865 .44253 Mdot
.21328 .44179 m .21666 .44074 L .21864 .44253 L .656 .751 .92 r
F
1 0 1 r
.5 Mabswid
.21435 .44322 m
.21833 .44225 L
s
1 0 0 r
.21437 .44324 m
.21835 .44227 L
s
0 1 0 r
.21439 .44326 m
.21837 .44228 L
s
0 0 1 r
.21441 .44328 m
.21838 .4423 L
s
1 0 1 r
.21466 .44353 m
.21859 .44248 L
s
1 0 0 r
.2147 .44357 m
.21862 .44251 L
s
1 0 1 r
.21664 .44314 m
.2186 .44249 L
s
0 0 1 r
.21715 .44299 m
.2186 .4425 L
s
0 1 0 r
.21829 .44263 m
.21863 .44252 L
s
0 g
.21864 .44253 m
.21882 .43945 L
s
.21864 .44253 m
.22061 .4443 L
s
0 0 0 r
2 Mabswid
.21863 .44252 Mdot
.21862 .44251 Mdot
.2186 .4425 Mdot
.2186 .44249 Mdot
.21859 .44248 Mdot
.21462 .44942 m .21367 .45101 L .2138 .44885 L .941 .685 .521 r
F
.21462 .44942 m .21486 .45183 L .21367 .45101 L F
.21232 .44233 m .21093 .44108 L .21112 .43991 L F
.21233 .4431 m .21093 .44108 L .21232 .44233 L F
0 g
.5 Mabswid
.21232 .44233 m
.21242 .44167 L
s
0 0 0 r
2 Mabswid
.21838 .4423 Mdot
.21837 .44228 Mdot
.21835 .44227 Mdot
.21833 .44225 Mdot
.21347 .44619 m .21225 .44677 L .21306 .44553 L .941 .685 .521 r
F
.21347 .44619 m .21299 .44795 L .21225 .44677 L F
0 g
.5 Mabswid
.21347 .44619 m
.21393 .4467 L
s
.20982 .43814 m .20924 .43469 L .21038 .43685 L .941 .685 .521 r
F
.21112 .43991 m .20982 .43814 L .21038 .43685 L F
.21507 .44665 m .21827 .44868 L .21623 .44931 L .553 .337 .541 r
F
.21507 .44665 m .21845 .4456 L .21827 .44868 L F
0 g
.21484 .4437 m
.21507 .44665 L
s
.21845 .4456 m
.21864 .44253 L
s
.21233 .4431 m .21096 .44245 L .21093 .44108 L .941 .685 .521 r
F
.21247 .44393 m .21096 .44245 L .21233 .4431 L F
0 g
.21232 .44233 m
.21233 .4431 L
s
.21306 .44553 m .21165 .4454 L .21272 .44476 L .941 .685 .521 r
F
.21306 .44553 m .21225 .44677 L .21165 .4454 L F
0 g
.21306 .44553 m
.21347 .44619 L
s
.21556 .432 m
.21484 .43222 L
s
.21378 .43328 m
.21484 .43222 L
s
.21247 .44393 m .21121 .44393 L .21096 .44245 L .941 .685 .521 r
F
.21272 .44476 m .21121 .44393 L .21247 .44393 L F
0 g
.21233 .4431 m
.21247 .44393 L
s
.21272 .44476 m .21165 .4454 L .21121 .44393 L .941 .685 .521 r
F
0 g
.21272 .44476 m
.21306 .44553 L
s
.21247 .44393 m
.21272 .44476 L
s
.21093 .44108 m .20982 .43814 L .21112 .43991 L .941 .685 .521 r
F
.21265 .43959 m .21666 .44074 L .21328 .44179 L .656 .751 .92 r
F
0 g
.21328 .44179 m
.21484 .4437 L
s
.21486 .45183 m .21353 .45317 L .21367 .45101 L .941 .685 .521 r
F
.21486 .45183 m .21509 .45423 L .21353 .45317 L F
0 g
.21509 .45423 m
.21657 .45459 L
s
.21556 .432 m
.21451 .43305 L
s
.2138 .44885 m .2125 .44971 L .21299 .44795 L .941 .685 .521 r
F
.2138 .44885 m .21367 .45101 L .2125 .44971 L F
.20982 .43814 m .20851 .43638 L .20924 .43469 L F
0 g
.20924 .43469 m
.2103 .43364 L
s
.22112 .45319 m
.21963 .45283 L
s
.22184 .45297 m
.22112 .45319 L
s
.22036 .45261 m
.22184 .45297 L
s
.21093 .44108 m .20955 .43984 L .20982 .43814 L .941 .685 .521 r
F
.21096 .44245 m .20955 .43984 L .21093 .44108 L F
.21299 .44795 m .21145 .44802 L .21225 .44677 L F
.21299 .44795 m .2125 .44971 L .21145 .44802 L F
.20955 .43984 m .20851 .43638 L .20982 .43814 L F
.21265 .43959 m .21469 .43896 L .21666 .44074 L .656 .751 .92 r
F
0 g
.21666 .44074 m
.21864 .44253 L
s
.21096 .44245 m .20959 .44181 L .20955 .43984 L .941 .685 .521 r
F
.21121 .44393 m .20959 .44181 L .21096 .44245 L F
.21367 .45101 m .21202 .45148 L .2125 .44971 L F
.21367 .45101 m .21353 .45317 L .21202 .45148 L F
0 g
.21353 .45317 m
.21509 .45423 L
s
.21225 .44677 m .21057 .44604 L .21165 .4454 L .941 .685 .521 r
F
.21225 .44677 m .21145 .44802 L .21057 .44604 L F
.21121 .44393 m .20994 .44393 L .20959 .44181 L F
.21165 .4454 m .20994 .44393 L .21121 .44393 L F
.21165 .4454 m .21057 .44604 L .20994 .44393 L F
.21623 .44931 m .21808 .45177 L .21881 .45154 L .553 .337 .541 r
F
.21623 .44931 m .21827 .44868 L .21808 .45177 L F
0 g
.21507 .44665 m
.21623 .44931 L
s
.21623 .44931 m
.21881 .45154 L
s
.21827 .44868 m
.21845 .4456 L
s
.21451 .43305 m
.21378 .43328 L
s
.21305 .43497 m
.21378 .43328 L
s
.20955 .43984 m .20816 .43859 L .20851 .43638 L .941 .685 .521 r
F
0 g
.20851 .43638 m
.20924 .43469 L
s
.21451 .43305 m
.21378 .43474 L
s
.20959 .44181 m .20816 .43859 L .20955 .43984 L .941 .685 .521 r
F
0 g
.21808 .45177 m
.21963 .45283 L
s
.22036 .45261 m
.21963 .45283 L
s
.21343 .43695 m .21469 .43896 L .21265 .43959 L .656 .751 .92 r
F
0 g
.21265 .43959 m
.21328 .44179 L
s
.2125 .44971 m .21064 .44927 L .21145 .44802 L .941 .685 .521 r
F
.2125 .44971 m .21202 .45148 L .21064 .44927 L F
0 g
.21808 .45177 m
.21827 .44868 L
s
.21202 .45148 m
.21353 .45317 L
s
.21881 .45154 m
.22036 .45261 L
s
.20959 .44181 m .20821 .44116 L .20816 .43859 L .941 .685 .521 r
F
0 g
.20816 .43859 m
.20851 .43638 L
s
.20994 .44393 m .20821 .44116 L .20959 .44181 L .941 .685 .521 r
F
.21343 .43695 m .21271 .43717 L .21469 .43896 L .656 .751 .92 r
F
0 g
.21271 .43717 m
.21469 .43896 L
s
.21469 .43896 m
.21666 .44074 L
s
.21265 .43959 m
.21343 .43695 L
s
.21145 .44802 m .2095 .44669 L .21057 .44604 L .941 .685 .521 r
F
.21145 .44802 m .21064 .44927 L .2095 .44669 L F
.20994 .44393 m .20867 .44392 L .20821 .44116 L F
.21057 .44604 m .20867 .44392 L .20994 .44393 L F
.21057 .44604 m .2095 .44669 L .20867 .44392 L F
0 g
.20816 .43859 m
.20821 .44116 L
s
.21378 .43474 m
.21305 .43497 L
s
.21271 .43717 m
.21305 .43497 L
s
.21343 .43695 m
.21378 .43474 L
s
.21064 .44927 m
.21202 .45148 L
s
.21657 .45007 m
.21808 .45177 L
s
.21808 .45177 m
.21881 .45154 L
s
.21729 .44985 m
.21881 .45154 L
s
.20821 .44116 m
.20867 .44392 L
s
.2095 .44669 m
.21064 .44927 L
s
.21271 .43717 m
.21343 .43695 L
s
.21271 .43717 m
.21276 .43975 L
s
.20867 .44392 m
.2095 .44669 L
s
.21343 .43695 m
.21349 .43952 L
s
.21657 .45007 m
.21519 .44786 L
s
.21729 .44985 m
.21657 .45007 L
s
.21591 .44764 m
.21729 .44985 L
s
.21349 .43952 m
.21276 .43975 L
s
.21322 .44251 m
.21276 .43975 L
s
.21519 .44786 m
.21405 .44528 L
s
.21591 .44764 m
.21519 .44786 L
s
.21349 .43952 m
.21395 .44229 L
s
.21477 .44506 m
.21591 .44764 L
s
.21395 .44229 m
.21322 .44251 L
s
.21405 .44528 m
.21322 .44251 L
s
.21477 .44506 m
.21405 .44528 L
s
.21395 .44229 m
.21477 .44506 L
s
.32676 .41244 m
.32509 .40688 L
s
.32509 .40688 m
.32846 .40583 L
s
.32509 .40688 m
.32284 .40168 L
s
.32774 .41798 m
.32676 .41244 L
s
.32676 .41244 m
.33013 .41139 L
s
.32284 .40168 m
.3262 .40064 L
s
.32284 .40168 m
.32015 .39719 L
s
.32846 .40583 m
.33013 .41139 L
s
.3262 .40064 m
.32846 .40583 L
s
.33013 .41139 m
.33111 .41694 L
s
.32774 .41798 m
.33111 .41694 L
s
.32352 .39614 m
.3262 .40064 L
s
.32015 .39719 m
.32352 .39614 L
s
.33682 .40933 m
.33514 .40376 L
s
.33514 .40376 m
.33976 .40233 L
s
.33514 .40376 m
.33289 .39856 L
s
.32535 .41914 m .33133 .4221 L .32795 .42314 L .656 .751 .92 r
F
0 g
.32739 .42757 m
.32795 .42314 L
s
.32774 .41798 m
.32784 .42038 L
s
.3378 .41488 m
.33682 .40933 L
s
.33682 .40933 m
.34144 .4079 L
s
.33289 .39856 m
.33751 .39712 L
s
.33289 .39856 m
.33021 .39406 L
s
.32535 .41914 m .3295 .41786 L .33133 .4221 L .656 .751 .92 r
F
0 g
.33077 .42654 m
.33133 .4221 L
s
1 0 1 r
.21833 .44225 m
.32541 .41922 L
s
0 g
.33111 .41694 m
.33133 .4221 L
s
.32795 .42314 m
.33133 .4221 L
s
.3378 .41488 m
.34243 .41345 L
s
.34118 .40798 m
.3395 .40241 L
s
.3395 .40241 m
.34453 .40085 L
s
.3395 .40241 m
.33725 .3972 L
s
.33976 .40233 m
.34144 .4079 L
s
.33751 .39712 m
.33976 .40233 L
s
.34216 .41353 m
.34118 .40798 L
s
.34118 .40798 m
.3462 .40642 L
s
.34144 .4079 m
.34243 .41345 L
s
.31721 .39372 m .32233 .3982 L .31818 .39949 L .553 .337 .541 r
F
.31721 .39372 m .32058 .39266 L .32233 .3982 L F
0 g
.32058 .39266 m
.32352 .39614 L
s
.31721 .39372 m
.32058 .39266 L
s
.31422 .39149 m
.31721 .39372 L
s
.33725 .3972 m
.34228 .39564 L
s
.33725 .3972 m
.33457 .3927 L
s
.33483 .39262 m
.33751 .39712 L
s
.33021 .39406 m
.33483 .39262 L
s
.34216 .41353 m
.34719 .41198 L
s
.32609 .43097 m
.32739 .42757 L
s
.32739 .42757 m
.33077 .42654 L
s
.34228 .39564 m
.34453 .40085 L
s
.34453 .40085 m
.3462 .40642 L
s
.31759 .39043 m
.32058 .39266 L
s
.3462 .40642 m
.34719 .41198 L
s
.33336 .41667 m .34266 .41862 L .33803 .42004 L .656 .751 .92 r
F
0 g
.33748 .42448 m
.33803 .42004 L
s
.34216 .41353 m
.34239 .41856 L
s
.3378 .41488 m
.33792 .41763 L
s
.3396 .39113 m
.34228 .39564 L
s
.33457 .3927 m
.3396 .39113 L
s
.33077 .42654 m
.32947 .42994 L
s
.32225 .41528 m .3295 .41786 L .32535 .41914 L .656 .751 .92 r
F
1 0 1 r
.32541 .41922 m
.32974 .41831 L
s
0 g
.32535 .41914 m
.32795 .42314 L
s
1 0 0 r
.21835 .44227 m
.32531 .41909 L
s
0 1 0 r
.21837 .44228 m
.32521 .41894 L
s
0 0 1 r
.21838 .4423 m
.32511 .41881 L
s
1 0 0 r
.32531 .41909 m
.32966 .41816 L
s
0 1 0 r
.32521 .41894 m
.32958 .418 L
s
0 0 0 r
2 Mabswid
.32511 .41881 Mdot
.33829 .41515 m .34743 .41715 L .34239 .4187 L .656 .751 .92 r
F
0 g
.5 Mabswid
.34185 .42314 m
.34239 .4187 L
s
.34243 .41345 m
.34254 .41608 L
s
.33336 .41667 m .33767 .41535 L .34266 .41862 L .656 .751 .92 r
F
0 g
.34211 .42305 m
.34266 .41862 L
s
.33803 .42004 m
.34266 .41862 L
s
1 0 1 r
.32974 .41831 m
.3341 .41723 L
s
0 0 0 r
2 Mabswid
.32974 .41831 Mdot
.32728 .39057 m .33049 .39566 L .32618 .397 L .553 .337 .541 r
F
.32728 .39057 m .3319 .38913 L .33049 .39566 L F
0 g
.5 Mabswid
.32429 .38834 m
.32728 .39057 L
s
.33184 .38944 m
.33457 .3927 L
s
.31422 .39149 m
.31759 .39043 L
s
.31422 .39149 m
.31137 .39067 L
s
1 0 0 r
.32966 .41816 m
.33392 .4171 L
s
0 0 0 r
2 Mabswid
.32966 .41816 Mdot
0 1 0 r
.5 Mabswid
.32958 .418 m
.33374 .41696 L
s
0 0 0 r
2 Mabswid
.32958 .418 Mdot
.31818 .39949 m .32325 .40401 L .31866 .40544 L .553 .337 .541 r
F
.31818 .39949 m .32233 .3982 L .32325 .40401 L F
0 g
.5 Mabswid
.31721 .39372 m
.31818 .39949 L
s
.32058 .39266 m
.32233 .3982 L
s
.32225 .41528 m .32685 .41386 L .3295 .41786 L .656 .751 .92 r
F
0 0 1 r
.32511 .41881 m
.3295 .41786 L
s
0 1 0 r
.21865 .44253 m
.32236 .41541 L
s
1 0 0 r
.21862 .44251 m
.32287 .416 L
s
1 0 1 r
.21859 .44248 m
.32327 .41647 L
s
0 g
.3295 .41786 m
.33133 .4221 L
s
0 0 1 r
.3295 .41786 m
.33357 .41684 L
s
0 0 0 r
2 Mabswid
.3295 .41786 Mdot
0 g
.5 Mabswid
.33619 .42788 m
.33748 .42448 L
s
.33748 .42448 m
.34211 .42305 L
s
.31475 .38961 m
.31759 .39043 L
s
.33829 .41515 m .34523 .41301 L .34743 .41715 L .656 .751 .92 r
F
0 g
.34689 .42159 m
.34743 .41715 L
s
.34239 .4187 m
.34743 .41715 L
s
.34719 .41198 m
.34743 .41715 L
s
.32413 .43311 m
.32609 .43097 L
s
.32609 .43097 m
.32947 .42994 L
s
.33164 .38921 m .33805 .39331 L .33111 .39547 L .553 .337 .541 r
F
.33164 .38921 m .33667 .38764 L .33805 .39331 L F
0 g
.32728 .39057 m
.3319 .38913 L
s
.33667 .38764 m
.3396 .39113 L
s
.33164 .38921 m
.33667 .38764 L
s
.32866 .38697 m
.33164 .38921 L
s
.32892 .38689 m
.3319 .38913 L
s
.32903 .41319 m .33767 .41535 L .33336 .41667 L .656 .751 .92 r
F
0 0 1 r
.33357 .41684 m
.33795 .41554 L
s
0 1 0 r
.33374 .41696 m
.33813 .41567 L
s
1 0 0 r
.33392 .4171 m
.33832 .4158 L
s
1 0 1 r
.3341 .41723 m
.33851 .41593 L
s
0 g
.33336 .41667 m
.33803 .42004 L
s
1 0 1 r
.32327 .41647 m
.32793 .41532 L
s
0 0 0 r
2 Mabswid
.32327 .41647 Mdot
0 g
.5 Mabswid
.32947 .42994 m
.32752 .43207 L
s
0 0 0 r
2 Mabswid
.32287 .416 Mdot
0 g
.5 Mabswid
.34057 .42654 m
.34185 .42314 L
s
.34185 .42314 m
.34689 .42159 L
s
1 0 1 r
.33851 .41593 m
.33904 .41581 L
s
0 0 0 r
2 Mabswid
.33851 .41593 Mdot
0 g
.5 Mabswid
.34211 .42305 m
.34083 .42645 L
s
0 0 0 r
2 Mabswid
.33904 .41581 Mdot
1 0 0 r
.5 Mabswid
.33832 .4158 m
.33888 .41567 L
s
0 0 0 r
2 Mabswid
.33832 .4158 Mdot
.33888 .41567 Mdot
0 1 0 r
.5 Mabswid
.33813 .41567 m
.33872 .41553 L
s
0 0 0 r
2 Mabswid
.33813 .41567 Mdot
0 0 1 r
.5 Mabswid
.33795 .41554 m
.33857 .4154 L
s
0 0 0 r
2 Mabswid
.33795 .41554 Mdot
.33872 .41553 Mdot
.32618 .397 m .32956 .40205 L .32544 .40334 L .553 .337 .541 r
F
.32618 .397 m .33049 .39566 L .32956 .40205 L F
0 g
.5 Mabswid
.32618 .397 m
.32728 .39057 L
s
.33049 .39566 m
.3319 .38913 L
s
0 0 0 r
2 Mabswid
.33857 .4154 Mdot
.32903 .41319 m .33315 .41191 L .33767 .41535 L .656 .751 .92 r
F
0 g
.5 Mabswid
.33767 .41535 m
.34266 .41862 L
s
.3337 .3854 m
.33667 .38764 L
s
1 0 1 r
.32793 .41532 m
.3307 .41457 L
s
.31866 .41155 m .32685 .41386 L .32225 .41528 L .656 .751 .92 r
F
0 1 0 r
.32236 .41541 m
.3271 .41418 L
s
1 0 0 r
.32287 .416 m
.32757 .41482 L
s
0 g
.32225 .41528 m
.32535 .41914 L
s
0 0 1 r
.21867 .44255 m
.32167 .41464 L
s
1 0 1 r
.21867 .44256 m
.32134 .41427 L
s
.33431 .41156 m .34523 .41301 L .33829 .41515 L .656 .751 .92 r
F
0 0 1 r
.33857 .4154 m
.34555 .41352 L
s
0 1 0 r
.33872 .41553 m
.34564 .41368 L
s
1 0 0 r
.33888 .41567 m
.34574 .41384 L
s
1 0 1 r
.33904 .41581 m
.34583 .41401 L
s
0 g
.33829 .41515 m
.34239 .4187 L
s
.32429 .38834 m
.32892 .38689 L
s
.32429 .38834 m
.32146 .38751 L
s
1 0 0 r
.32757 .41482 m
.33013 .41411 L
s
.31866 .40544 m .3234 .41008 L .31866 .41155 L .553 .337 .541 r
F
.31866 .40544 m .32325 .40401 L .3234 .41008 L F
0 g
.31818 .39949 m
.31866 .40544 L
s
.32233 .3982 m
.32325 .40401 L
s
.31137 .39067 m
.31475 .38961 L
s
.31137 .39067 m
.30886 .39131 L
s
1 0 1 r
.3307 .41457 m
.33491 .41331 L
s
0 g
.34689 .42159 m
.34561 .42499 L
s
0 1 0 r
.3271 .41418 m
.32944 .41353 L
s
0 0 0 r
2 Mabswid
.33013 .41411 Mdot
0 g
.5 Mabswid
.33424 .43001 m
.33619 .42788 L
s
.33619 .42788 m
.34083 .42645 L
s
1 0 1 r
.34583 .41401 m
.44769 .38131 L
s
0 0 0 r
2 Mabswid
.34583 .41401 Mdot
.33111 .39547 m .33878 .39919 L .33071 .4017 L .553 .337 .541 r
F
.33111 .39547 m .33805 .39331 L .33878 .39919 L F
0 g
.5 Mabswid
.33111 .39547 m
.33164 .38921 L
s
.33667 .38764 m
.33805 .39331 L
s
.31866 .41155 m .3234 .41008 L .32685 .41386 L .656 .751 .92 r
F
0 0 1 r
.32167 .41464 m
.32644 .41335 L
s
0 g
.32685 .41386 m
.3295 .41786 L
s
1 0 0 r
.34574 .41384 m
.44769 .38106 L
s
0 0 0 r
2 Mabswid
.34574 .41384 Mdot
0 g
.5 Mabswid
.32866 .38697 m
.3337 .3854 L
s
.32866 .38697 m
.32583 .38614 L
s
0 1 0 r
.34564 .41368 m
.4477 .38084 L
s
0 0 0 r
2 Mabswid
.34564 .41368 Mdot
0 g
.5 Mabswid
.32609 .38606 m
.32892 .38689 L
s
.31225 .39025 m
.31475 .38961 L
s
0 0 0 r
2 Mabswid
.32944 .41353 Mdot
0 0 1 r
.5 Mabswid
.34555 .41352 m
.44771 .38059 L
s
0 0 0 r
2 Mabswid
.34555 .41352 Mdot
0 g
.5 Mabswid
.32164 .43382 m
.32413 .43311 L
s
.32413 .43311 m
.32752 .43207 L
s
1 0 1 r
.33491 .41331 m
.33593 .41304 L
s
.32504 .40958 m .33315 .41191 L .32903 .41319 L .656 .751 .92 r
F
0 0 1 r
.32644 .41335 m
.32853 .41276 L
s
0 1 0 r
.32944 .41353 m
.3336 .41227 L
s
1 0 1 r
.32134 .41427 m
.32612 .41297 L
s
0 g
.32903 .41319 m
.33336 .41667 L
s
.33431 .41156 m .34238 .40906 L .34523 .41301 L .656 .751 .92 r
F
1 0 0 r
.33013 .41411 m
.33432 .41285 L
s
0 g
.34523 .41301 m
.34743 .41715 L
s
1 0 1 r
.32612 .41297 m
.32811 .41239 L
s
1 0 0 r
.33432 .41285 m
.33541 .41256 L
s
0 g
.33862 .42867 m
.34057 .42654 L
s
.34057 .42654 m
.34561 .42499 L
s
.34083 .42645 m
.33889 .42858 L
s
.32544 .40334 m .3291 .40832 L .32504 .40958 L .553 .337 .541 r
F
.32544 .40334 m .32956 .40205 L .3291 .40832 L F
0 g
.32544 .40334 m
.32618 .397 L
s
.32956 .40205 m
.33049 .39566 L
s
.32752 .43207 m
.32503 .43278 L
s
0 1 0 r
.3336 .41227 m
.33475 .41196 L
s
0 g
.33087 .38456 m
.3337 .3854 L
s
.32504 .40958 m .3291 .40832 L .33315 .41191 L .656 .751 .92 r
F
0 g
.33315 .41191 m
.33767 .41535 L
s
.33043 .40791 m .34238 .40906 L .33431 .41156 L .656 .751 .92 r
F
0 0 1 r
.32853 .41276 m
.33266 .4115 L
s
1 0 1 r
.32811 .41239 m
.33223 .41114 L
s
0 1 0 r
.33475 .41196 m
.34284 .40963 L
s
1 0 0 r
.33541 .41256 m
.34336 .4103 L
s
0 g
.33431 .41156 m
.33829 .41515 L
s
1 0 1 r
.33593 .41304 m
.34376 .41084 L
s
.31866 .41155 m .32279 .4164 L .31819 .41783 L .553 .337 .541 r
F
.31866 .41155 m .3234 .41008 L .32279 .4164 L F
.31458 .40796 m .3234 .41008 L .31866 .41155 L .656 .751 .92 r
F
0 g
.31866 .40544 m
.31866 .40894 L
s
.32146 .38751 m
.32609 .38606 L
s
.32146 .38751 m
.31896 .38815 L
s
0 0 1 r
.33266 .4115 m
.33388 .41116 L
s
1 0 1 r
.33223 .41114 m
.33348 .41079 L
s
0 g
.34561 .42499 m
.34368 .42712 L
s
.33071 .4017 m .33888 .40529 L .33043 .40791 L .553 .337 .541 r
F
.33071 .4017 m .33878 .39919 L .33888 .40529 L F
0 g
.33071 .4017 m
.33111 .39547 L
s
.33805 .39331 m
.33878 .39919 L
s
.30886 .39131 m
.31225 .39025 L
s
.30886 .39131 m
.30687 .39338 L
s
1 0 1 r
.34376 .41084 m
.44779 .3777 L
s
0 0 0 r
2 Mabswid
.34376 .41084 Mdot
0 g
.5 Mabswid
.33177 .43072 m
.33424 .43001 L
s
.33424 .43001 m
.33889 .42858 L
s
1 0 0 r
.34336 .4103 m
.44781 .37705 L
s
0 0 0 r
2 Mabswid
.34336 .4103 Mdot
0 g
.5 Mabswid
.32583 .38614 m
.33087 .38456 L
s
.32583 .38614 m
.32334 .38678 L
s
.32361 .3867 m
.32609 .38606 L
s
.31458 .40796 m .31919 .40653 L .3234 .41008 L .656 .751 .92 r
F
0 0 1 r
.2186 .4425 m
.31531 .40856 L
s
1 0 1 r
.2186 .44249 m
.31571 .4089 L
s
0 g
.3234 .41008 m
.32685 .41386 L
s
.32325 .40401 m
.3234 .41008 L
s
.31026 .39232 m
.31225 .39025 L
s
.31879 .43306 m
.32164 .43382 L
s
.32164 .43382 m
.32503 .43278 L
s
0 1 0 r
.34284 .40963 m
.44783 .37629 L
s
0 0 0 r
2 Mabswid
.34284 .40963 Mdot
.32504 .40958 m .32912 .41445 L .32498 .41573 L .553 .337 .541 r
F
.32504 .40958 m .3291 .40832 L .32912 .41445 L F
.32138 .40585 m .3291 .40832 L .32504 .40958 L .656 .751 .92 r
F
0 g
.5 Mabswid
.3252 .40707 m
.32544 .40334 L
s
.33043 .40791 m .33888 .40529 L .34238 .40906 L .656 .751 .92 r
F
1 0 1 r
.33348 .41079 m
.34177 .40834 L
s
0 0 1 r
.33388 .41116 m
.34212 .40875 L
s
0 g
.34238 .40906 m
.34523 .41301 L
s
.33616 .42937 m
.33862 .42867 L
s
.33862 .42867 m
.34368 .42712 L
s
.33889 .42858 m
.33642 .42929 L
s
0 0 0 r
2 Mabswid
.31571 .4089 Mdot
0 0 1 r
.5 Mabswid
.34212 .40875 m
.44786 .37528 L
s
0 0 0 r
2 Mabswid
.34212 .40875 Mdot
0 g
.5 Mabswid
.32503 .43278 m
.32219 .43202 L
s
.32839 .3852 m
.33087 .38456 L
s
.31819 .41783 m .3214 .42298 L .31723 .42427 L .553 .337 .541 r
F
.31819 .41783 m .32279 .4164 L .3214 .42298 L F
0 g
.31819 .41783 m
.31866 .41155 L
s
.32279 .4164 m
.3234 .41008 L
s
0 0 0 r
2 Mabswid
.31531 .40856 Mdot
1 0 1 r
.5 Mabswid
.34177 .40834 m
.44787 .37489 L
s
0 0 0 r
2 Mabswid
.34177 .40834 Mdot
.32138 .40585 m .32551 .40457 L .3291 .40832 L .656 .751 .92 r
F
0 g
.5 Mabswid
.3291 .40832 m
.33315 .41191 L
s
.3291 .40832 m
.32956 .40205 L
s
.31001 .4045 m .31919 .40653 L .31458 .40796 L .656 .751 .92 r
F
0 0 1 r
.31531 .40856 m
.31978 .40698 L
s
1 0 1 r
.31571 .4089 m
.32023 .40733 L
s
0 g
.31458 .40796 m
.31866 .41155 L
s
0 1 0 r
.21863 .44252 m
.31443 .40784 L
s
1 0 0 r
.21901 .44241 m
.31376 .4073 L
s
1 0 1 r
.21951 .44226 m
.31321 .40687 L
s
.33043 .40791 m .33836 .4116 L .33027 .4141 L .553 .337 .541 r
F
.33043 .40791 m .33888 .40529 L .33836 .4116 L F
.32666 .40421 m .33888 .40529 L .33043 .40791 L .656 .751 .92 r
F
0 g
.33058 .40456 m
.33071 .4017 L
s
0 0 0 r
2 Mabswid
.31443 .40784 Mdot
0 g
.5 Mabswid
.31896 .38815 m
.32361 .3867 L
s
.31896 .38815 m
.31698 .39022 L
s
.34368 .42712 m
.34122 .42782 L
s
1 0 1 r
.32023 .40733 m
.32216 .40669 L
s
0 0 0 r
2 Mabswid
.32023 .40733 Mdot
.31376 .4073 Mdot
0 g
.5 Mabswid
.30687 .39338 m
.31026 .39232 L
s
.30687 .39338 m
.30553 .39675 L
s
0 0 1 r
.31978 .40698 m
.3218 .4063 L
s
0 0 0 r
2 Mabswid
.31978 .40698 Mdot
.31321 .40687 Mdot
.32216 .40669 Mdot
0 g
.5 Mabswid
.32893 .42996 m
.33177 .43072 L
s
.33177 .43072 m
.33642 .42929 L
s
.31001 .4045 m .31418 .4032 L .31919 .40653 L .656 .751 .92 r
F
1 0 1 r
.31321 .40687 m
.31742 .40526 L
s
1 0 0 r
.31376 .4073 m
.31804 .4057 L
s
0 1 0 r
.31443 .40784 m
.3188 .40624 L
s
1 0 0 r
.21892 .44278 m
.31008 .40455 L
s
0 1 0 r
.2189 .44277 m
.31025 .40467 L
s
0 0 1 r
.21889 .44275 m
.31042 .40479 L
s
0 g
.31919 .40653 m
.3234 .41008 L
s
.32498 .41573 m .32961 .42046 L .32528 .42179 L .553 .337 .541 r
F
.32498 .41573 m .32912 .41445 L .32961 .42046 L F
0 g
.32498 .41573 m
.32504 .40958 L
s
.3291 .40832 m
.32912 .41445 L
s
.32334 .38678 m
.32839 .3852 L
s
.32334 .38678 m
.32137 .38885 L
s
.32163 .38877 m
.32361 .3867 L
s
0 0 0 r
2 Mabswid
.3218 .4063 Mdot
.3188 .40624 Mdot
0 g
.5 Mabswid
.30892 .39569 m
.31026 .39232 L
s
.31879 .43306 m
.32219 .43202 L
s
.31805 .402 m .32551 .40457 L .32138 .40585 L .656 .751 .92 r
F
0 1 0 r
.3188 .40624 m
.32103 .40548 L
s
0 0 1 r
.3218 .4063 m
.3259 .40501 L
s
1 0 1 r
.32216 .40669 m
.32626 .4054 L
s
0 g
.32138 .40585 m
.32504 .40958 L
s
.31723 .42427 m .31918 .42983 L .31578 .43088 L .553 .337 .541 r
F
0 g
.31578 .43088 m
.31879 .43306 L
s
.31723 .42427 m .3214 .42298 L .31918 .42983 L .553 .337 .541 r
F
0 g
.31723 .42427 m
.31819 .41783 L
s
.31578 .43088 m
.31723 .42427 L
s
.3214 .42298 m
.32279 .4164 L
s
1 0 0 r
.31804 .4057 m
.32047 .40485 L
s
0 0 0 r
2 Mabswid
.31804 .4057 Mdot
.32103 .40548 Mdot
.32626 .4054 Mdot
.32666 .40421 m .33475 .4017 L .33888 .40529 L .656 .751 .92 r
F
1 0 1 r
.5 Mabswid
.32626 .4054 m
.32745 .405 L
s
0 g
.33878 .39919 m
.33888 .40529 L
s
.33888 .40529 m
.34238 .40906 L
s
.33333 .42861 m
.33616 .42937 L
s
.33616 .42937 m
.34122 .42782 L
s
0 0 0 r
2 Mabswid
.31742 .40526 Mdot
0 g
.5 Mabswid
.33642 .42929 m
.33359 .42853 L
s
.31918 .42983 m
.32219 .43202 L
s
0 0 1 r
.3259 .40501 m
.32707 .40461 L
s
0 0 0 r
2 Mabswid
.3259 .40501 Mdot
.32745 .405 Mdot
0 g
.5 Mabswid
.32643 .38727 m
.32839 .3852 L
s
0 0 0 r
2 Mabswid
.32047 .40485 Mdot
.33027 .4141 m .33721 .41812 L .33024 .42026 L .553 .337 .541 r
F
.33027 .4141 m .33836 .4116 L .33721 .41812 L F
0 g
.5 Mabswid
.33027 .4141 m
.33043 .40791 L
s
.33836 .4116 m
.33888 .40529 L
s
0 0 0 r
2 Mabswid
.31042 .40479 Mdot
.31025 .40467 Mdot
.32707 .40461 Mdot
.31805 .402 m .32238 .40065 L .32551 .40457 L .656 .751 .92 r
F
1 0 1 r
.5 Mabswid
.31742 .40526 m
.32003 .40435 L
s
0 g
.32551 .40457 m
.3291 .40832 L
s
0 0 0 r
2 Mabswid
.31008 .40455 Mdot
.30493 .40119 m .31418 .4032 L .31001 .4045 L .656 .751 .92 r
F
0 0 1 r
.5 Mabswid
.31042 .40479 m
.31419 .40321 L
s
0 g
.31001 .4045 m
.31458 .40796 L
s
1 0 1 r
.21894 .4428 m
.30991 .40443 L
s
0 g
.31918 .42983 m
.3214 .42298 L
s
0 0 0 r
2 Mabswid
.30991 .40443 Mdot
.32003 .40435 Mdot
.32301 .40046 m .33475 .4017 L .32666 .40421 L .656 .751 .92 r
F
1 0 1 r
.5 Mabswid
.32003 .40435 m
.3242 .40301 L
s
0 1 0 r
.32103 .40548 m
.32516 .40417 L
s
1 0 0 r
.32047 .40485 m
.32462 .40353 L
s
0 0 1 r
.32707 .40461 m
.33511 .40198 L
s
1 0 1 r
.32745 .405 m
.33557 .40236 L
s
0 g
.32666 .40421 m
.33043 .40791 L
s
0 1 0 r
.32516 .40417 m
.32625 .40379 L
s
0 0 0 r
2 Mabswid
.32516 .40417 Mdot
0 g
.5 Mabswid
.31698 .39022 m
.32163 .38877 L
s
.31698 .39022 m
.31565 .39359 L
s
.30553 .39675 m
.30892 .39569 L
s
0 0 0 r
2 Mabswid
.32625 .40379 Mdot
0 g
.5 Mabswid
.34122 .42782 m
.33839 .42705 L
s
1 0 0 r
.32462 .40353 m
.32563 .40317 L
s
0 0 0 r
2 Mabswid
.32462 .40353 Mdot
.32528 .42179 m .33059 .42633 L .32593 .42776 L .553 .337 .541 r
F
.32528 .42179 m .32961 .42046 L .33059 .42633 L F
0 g
.5 Mabswid
.32498 .41573 m
.32528 .42179 L
s
.32528 .42179 m
.32593 .42776 L
s
.32912 .41445 m
.32961 .42046 L
s
0 0 0 r
2 Mabswid
.31419 .40321 Mdot
.30493 .40119 m .30833 .40013 L .31418 .4032 L .656 .751 .92 r
F
0 g
.5 Mabswid
.30833 .40013 m
.31418 .4032 L
s
.30493 .40119 m
.30553 .39675 L
s
1 0 1 r
.30991 .40443 m
.31359 .40286 L
s
0 1 0 r
.31025 .40467 m
.314 .4031 L
s
0 g
.31418 .4032 m
.31919 .40653 L
s
1 0 0 r
.31008 .40455 m
.31379 .40298 L
s
0 g
.30493 .40119 m
.31001 .4045 L
s
0 0 0 r
2 Mabswid
.32563 .40317 Mdot
.314 .4031 Mdot
0 g
.5 Mabswid
.32593 .42776 m
.32893 .42996 L
s
.32893 .42996 m
.33359 .42853 L
s
.31281 .42741 m
.31578 .43088 L
s
.31578 .43088 m
.31918 .42983 L
s
1 0 1 r
.3242 .40301 m
.32514 .40267 L
s
0 0 0 r
2 Mabswid
.3242 .40301 Mdot
.31379 .40298 Mdot
0 g
.5 Mabswid
.30833 .40013 m
.30892 .39569 L
s
0 0 0 r
2 Mabswid
.31359 .40286 Mdot
0 g
.5 Mabswid
.32137 .38885 m
.32643 .38727 L
s
.32137 .38885 m
.32005 .39222 L
s
.32031 .39213 m
.32163 .38877 L
s
0 0 0 r
2 Mabswid
.32514 .40267 Mdot
1 0 1 r
.5 Mabswid
.33557 .40236 m
.44807 .36814 L
s
0 0 0 r
2 Mabswid
.33557 .40236 Mdot
.31507 .39803 m .32238 .40065 L .31805 .402 L .656 .751 .92 r
F
1 0 1 r
.5 Mabswid
.31359 .40286 m
.31754 .40136 L
s
1 0 0 r
.31379 .40298 m
.31766 .40151 L
s
0 1 0 r
.314 .4031 m
.31779 .40167 L
s
0 0 1 r
.31419 .40321 m
.3179 .40182 L
s
0 g
.31805 .402 m
.32138 .40585 L
s
0 0 1 r
.33511 .40198 m
.44808 .36777 L
s
0 0 0 r
2 Mabswid
.33511 .40198 Mdot
0 g
.5 Mabswid
.31621 .42636 m
.31918 .42983 L
s
0 0 0 r
2 Mabswid
.3179 .40182 Mdot
0 g
.5 Mabswid
.33333 .42861 m
.33839 .42705 L
s
.32301 .40046 m .32998 .39829 L .33475 .4017 L .656 .751 .92 r
F
1 0 0 r
.32563 .40317 m
.33331 .40059 L
s
0 1 0 r
.32625 .40379 m
.33409 .40119 L
s
0 g
.33475 .4017 m
.33888 .40529 L
s
.33024 .42026 m .3354 .42485 L .33033 .42641 L .553 .337 .541 r
F
0 g
.33033 .42641 m
.33333 .42861 L
s
.33024 .42026 m .33721 .41812 L .3354 .42485 L .553 .337 .541 r
F
0 g
.33024 .42026 m
.33027 .4141 L
s
.32961 .42046 m
.33059 .42633 L
s
.33024 .42026 m
.33033 .42641 L
s
.33721 .41812 m
.33836 .4116 L
s
0 0 0 r
2 Mabswid
.31779 .40167 Mdot
0 g
.5 Mabswid
.33059 .42633 m
.33359 .42853 L
s
0 0 0 r
2 Mabswid
.31766 .40151 Mdot
.31754 .40136 Mdot
0 g
.5 Mabswid
.32511 .39064 m
.32643 .38727 L
s
.30493 .40119 m
.30833 .40013 L
s
.30493 .40119 m
.30513 .40639 L
s
0 1 0 r
.33409 .40119 m
.44811 .36677 L
s
0 0 0 r
2 Mabswid
.33409 .40119 Mdot
0 g
.5 Mabswid
.31565 .39359 m
.32031 .39213 L
s
.31507 .39803 m .31973 .39658 L .32238 .40065 L .656 .751 .92 r
F
0 g
.31507 .39803 m
.31565 .39359 L
s
.32238 .40065 m
.32551 .40457 L
s
.31507 .39803 m
.31805 .402 L
s
1 0 0 r
.33331 .40059 m
.44813 .36601 L
s
0 0 0 r
2 Mabswid
.33331 .40059 Mdot
0 g
.5 Mabswid
.31009 .42289 m
.31281 .42741 L
s
.31281 .42741 m
.31621 .42636 L
s
.31947 .39666 m .32998 .39829 L .32301 .40046 L .656 .751 .92 r
F
0 0 1 r
.3179 .40182 m
.32221 .40042 L
s
0 1 0 r
.31779 .40167 m
.3221 .40027 L
s
1 0 0 r
.31766 .40151 m
.32199 .40011 L
s
1 0 1 r
.31754 .40136 m
.32188 .39995 L
s
0 g
.32301 .40046 m
.32666 .40421 L
s
1 0 1 r
.32514 .40267 m
.33266 .40012 L
s
0 0 1 r
.32221 .40042 m
.32277 .4002 L
s
0 0 0 r
2 Mabswid
.32221 .40042 Mdot
0 1 0 r
.5 Mabswid
.3221 .40027 m
.32263 .40006 L
s
0 0 0 r
2 Mabswid
.3221 .40027 Mdot
.32277 .4002 Mdot
0 g
.5 Mabswid
.30833 .40013 m
.30853 .40534 L
s
.3354 .42485 m
.33839 .42705 L
s
1 0 1 r
.33266 .40012 m
.44815 .36537 L
s
0 0 0 r
2 Mabswid
.33266 .40012 Mdot
1 0 0 r
.5 Mabswid
.32199 .40011 m
.32249 .39991 L
s
0 0 0 r
2 Mabswid
.32199 .40011 Mdot
.32263 .40006 Mdot
1 0 1 r
.5 Mabswid
.32188 .39995 m
.32235 .39976 L
s
0 0 0 r
2 Mabswid
.32188 .39995 Mdot
.32249 .39991 Mdot
0 g
.5 Mabswid
.32297 .42428 m
.32593 .42776 L
s
.32593 .42776 m
.33059 .42633 L
s
0 0 0 r
2 Mabswid
.32235 .39976 Mdot
0 g
.5 Mabswid
.3354 .42485 m
.33721 .41812 L
s
.32511 .39064 m
.32005 .39222 L
s
.31621 .42636 m
.31349 .42184 L
s
.30513 .40639 m
.30853 .40534 L
s
.30513 .40639 m
.30611 .412 L
s
.3078 .41763 m
.31009 .42289 L
s
.31009 .42289 m
.31349 .42184 L
s
.32737 .42293 m
.33033 .42641 L
s
.33033 .42641 m
.3354 .42485 L
s
.32763 .42284 m
.33059 .42633 L
s
.31947 .39666 m .32454 .39508 L .32998 .39829 L .656 .751 .92 r
F
0 g
.32454 .39508 m
.32998 .39829 L
s
.31973 .39658 m
.32031 .39213 L
s
.31947 .39666 m
.32005 .39222 L
s
1 0 1 r
.32235 .39976 m
.32871 .39749 L
s
1 0 0 r
.32249 .39991 m
.32892 .39762 L
s
0 1 0 r
.32263 .40006 m
.32913 .39775 L
s
0 0 1 r
.32277 .4002 m
.32934 .39788 L
s
0 g
.32998 .39829 m
.33475 .4017 L
s
.31973 .39658 m
.32238 .40065 L
s
.31947 .39666 m
.32301 .40046 L
s
.30951 .41095 m
.30853 .40534 L
s
.30611 .412 m
.30951 .41095 L
s
.30611 .412 m
.3078 .41763 L
s
.31507 .39803 m
.31973 .39658 L
s
.31507 .39803 m
.31528 .40324 L
s
.3078 .41763 m
.3112 .41658 L
s
0 0 1 r
.32934 .39788 m
.44824 .36255 L
s
0 0 0 r
2 Mabswid
.32934 .39788 Mdot
0 g
.5 Mabswid
.32454 .39508 m
.32511 .39064 L
s
0 1 0 r
.32913 .39775 m
.44824 .36229 L
s
0 0 0 r
2 Mabswid
.32913 .39775 Mdot
0 g
.5 Mabswid
.31349 .42184 m
.3112 .41658 L
s
1 0 0 r
.32892 .39762 m
.44825 .36207 L
s
0 0 0 r
2 Mabswid
.32892 .39762 Mdot
1 0 1 r
.5 Mabswid
.32871 .39749 m
.44826 .36182 L
s
0 0 0 r
2 Mabswid
.32871 .39749 Mdot
0 g
.5 Mabswid
.32025 .41975 m
.32297 .42428 L
s
.32297 .42428 m
.32763 .42284 L
s
.3112 .41658 m
.30951 .41095 L
s
.33244 .42136 m
.3354 .42485 L
s
.31947 .39666 m
.32454 .39508 L
s
.31947 .39666 m
.31968 .40187 L
s
.31973 .39658 m
.31995 .40179 L
s
.31528 .40324 m
.31995 .40179 L
s
.31528 .40324 m
.31626 .40885 L
s
.32465 .41839 m
.32737 .42293 L
s
.32737 .42293 m
.33244 .42136 L
s
.32763 .42284 m
.32492 .41831 L
s
.31796 .41449 m
.32025 .41975 L
s
.32025 .41975 m
.32492 .41831 L
s
.44762 .37423 m
.4475 .38287 L
s
.44776 .36541 m
.44762 .37423 L
s
.32454 .39508 m
.32475 .40029 L
s
.44792 .357 m
.44776 .36541 L
s
.31626 .40885 m
.32093 .4074 L
s
.31626 .40885 m
.31796 .41449 L
s
.31796 .41449 m
.32263 .41304 L
s
.31968 .40187 m
.32475 .40029 L
s
.31968 .40187 m
.32067 .40749 L
s
.32093 .4074 m
.31995 .40179 L
s
.33244 .42136 m
.32973 .41683 L
s
.32237 .41313 m
.32465 .41839 L
s
.32465 .41839 m
.32973 .41683 L
s
.32492 .41831 m
.32263 .41304 L
s
.4475 .38287 m
.44741 .39075 L
s
.32067 .40749 m
.32575 .40591 L
s
.32067 .40749 m
.32237 .41313 L
s
.32263 .41304 m
.32093 .4074 L
s
.32237 .41313 m
.32744 .41156 L
s
.44808 .34955 m
.44792 .357 L
s
.32575 .40591 m
.32475 .40029 L
s
.32973 .41683 m
.32744 .41156 L
s
.32744 .41156 m
.32575 .40591 L
s
.44741 .39075 m
.44736 .39736 L
s
.44741 .39075 m
.4476 .38438 L
s
.44741 .39075 m
.44741 .39075 L
s
.44824 .34356 m
.44808 .34955 L
s
.44736 .39736 m
.44735 .40225 L
s
.44837 .33944 m
.44824 .34356 L
s
.44824 .34356 m
.44824 .34356 L
s
.44815 .35284 m
.44824 .34356 L
s
.4476 .38438 m
.44778 .37796 L
s
1 0 1 r
.44769 .38131 m
.31004 .33195 L
s
0 0 0 r
2 Mabswid
.44769 .38131 Mdot
0 g
.5 Mabswid
.44735 .40225 m
.44739 .40507 L
s
1 0 0 r
.44769 .38106 m
.56876 .34213 L
s
0 0 0 r
2 Mabswid
.44769 .38106 Mdot
0 g
.5 Mabswid
.44806 .36215 m
.44815 .35284 L
s
0 1 0 r
.4477 .38084 m
.56878 .34187 L
s
0 0 0 r
2 Mabswid
.4477 .38084 Mdot
0 0 1 r
.5 Mabswid
.44771 .38059 m
.31001 .33102 L
s
0 0 0 r
2 Mabswid
.44771 .38059 Mdot
0 g
.5 Mabswid
.44849 .33749 m
.44837 .33944 L
s
.44778 .37796 m
.44797 .37151 L
s
1 0 1 r
.44779 .3777 m
.30993 .32862 L
s
0 0 0 r
2 Mabswid
.44779 .3777 Mdot
1 0 0 r
.5 Mabswid
.44781 .37705 m
.56906 .33847 L
s
0 0 0 r
2 Mabswid
.44781 .37705 Mdot
0 1 0 r
.5 Mabswid
.44783 .37629 m
.56912 .33777 L
s
0 0 0 r
2 Mabswid
.44783 .37629 Mdot
0 g
.5 Mabswid
.44797 .37151 m
.44806 .36215 L
s
0 0 1 r
.44786 .37528 m
.30986 .32643 L
s
0 0 0 r
2 Mabswid
.44786 .37528 Mdot
0 g
.5 Mabswid
.44739 .40507 m
.44746 .40561 L
s
1 0 1 r
.44787 .37489 m
.30986 .32622 L
s
0 0 0 r
2 Mabswid
.44787 .37489 Mdot
0 g
.5 Mabswid
.44856 .33784 m
.44849 .33749 L
s
.44789 .3809 m
.44797 .37151 L
s
.44797 .37151 m
.44816 .36502 L
s
.44746 .40561 m
.44757 .40382 L
s
1 0 1 r
.44807 .36814 m
.30969 .32094 L
s
0 0 0 r
2 Mabswid
.44807 .36814 Mdot
0 g
.5 Mabswid
.4486 .3405 m
.44856 .33784 L
s
0 0 1 r
.44808 .36777 m
.30969 .32074 L
s
0 0 0 r
2 Mabswid
.44808 .36777 Mdot
0 1 0 r
.5 Mabswid
.44811 .36677 m
.56975 .33006 L
s
0 0 0 r
2 Mabswid
.44811 .36677 Mdot
0 g
.5 Mabswid
.4478 .39034 m
.44789 .3809 L
s
1 0 0 r
.44813 .36601 m
.5698 .32938 L
s
0 0 0 r
2 Mabswid
.44813 .36601 Mdot
1 0 1 r
.5 Mabswid
.44815 .36537 m
.30962 .31857 L
s
0 0 0 r
2 Mabswid
.44815 .36537 Mdot
0 g
.5 Mabswid
.44816 .36502 m
.44835 .35849 L
s
.44757 .40382 m
.44771 .39981 L
s
0 0 1 r
.44824 .36255 m
.30954 .31624 L
s
0 0 0 r
2 Mabswid
.44824 .36255 Mdot
0 1 0 r
.5 Mabswid
.44824 .36229 m
.57008 .32603 L
s
0 0 0 r
2 Mabswid
.44824 .36229 Mdot
1 0 0 r
.5 Mabswid
.44825 .36207 m
.5701 .32577 L
s
0 0 0 r
2 Mabswid
.44825 .36207 Mdot
0 g
.5 Mabswid
.44771 .39981 m
.4478 .39034 L
s
1 0 1 r
.44826 .36182 m
.30952 .3153 L
s
0 0 0 r
2 Mabswid
.44826 .36182 Mdot
0 g
.5 Mabswid
.44859 .3453 m
.4486 .3405 L
s
.44835 .35849 m
.44855 .35193 L
s
.56778 .33706 m
.56774 .34582 L
s
.56793 .3281 m
.56778 .33706 L
s
.56818 .31952 m
.56793 .3281 L
s
.44771 .39981 m
.44786 .39383 L
s
.44771 .39981 m
.44771 .39981 L
s
.56774 .34582 m
.56781 .35379 L
s
.56852 .31189 m
.56818 .31952 L
s
.44855 .35193 m
.44859 .3453 L
s
.56781 .35379 m
.56799 .36043 L
s
.56781 .35379 m
.56835 .3472 L
s
.56781 .35379 m
.56781 .35379 L
s
.56893 .30573 m
.56852 .31189 L
s
.44786 .39383 m
.44803 .3863 L
s
.44846 .35992 m
.44855 .35193 L
s
.44855 .35193 m
.44855 .35193 L
s
.56799 .36043 m
.56827 .36531 L
s
.44803 .3863 m
.44819 .37773 L
s
.44834 .36873 m
.44846 .35992 L
s
.56937 .30145 m
.56893 .30573 L
s
.56893 .30573 m
.56893 .30573 L
s
.56909 .31508 m
.56893 .30573 L
s
.31089 .32686 m
.31068 .33565 L
s
.31103 .31786 m
.31089 .32686 L
s
.31108 .30923 m
.31103 .31786 L
s
.44819 .37773 m
.44834 .36873 L
s
.56835 .3472 m
.56889 .34057 L
s
.31068 .33565 m
.3104 .34364 L
s
.31105 .30155 m
.31108 .30923 L
s
.56827 .36531 m
.56864 .36807 L
s
.56926 .32447 m
.56909 .31508 L
s
.3104 .34364 m
.31008 .3503 L
s
.3104 .34364 m
.31019 .33699 L
s
.3104 .34364 m
.3104 .34364 L
s
.31092 .29534 m
.31105 .30155 L
s
.56981 .29935 m
.56937 .30145 L
s
0 0 0 r
2 Mabswid
.56876 .34213 Mdot
.56878 .34187 Mdot
0 g
.5 Mabswid
.56889 .34057 m
.56943 .3339 L
s
.31008 .3503 m
.30974 .35517 L
s
.56943 .3339 m
.56926 .32447 L
s
0 0 0 r
2 Mabswid
.56906 .33847 Mdot
0 g
.5 Mabswid
.31073 .29102 m
.31092 .29534 L
s
.31092 .29534 m
.31092 .29534 L
s
.31054 .30471 m
.31092 .29534 L
s
0 0 0 r
2 Mabswid
.56912 .33777 Mdot
0 g
.5 Mabswid
.56864 .36807 m
.56905 .36852 L
s
.31019 .33699 m
.30998 .3303 L
s
.57023 .29961 m
.56981 .29935 L
s
.5696 .34337 m
.56943 .3339 L
s
.56943 .3339 m
.56998 .32719 L
s
.30974 .35517 m
.3094 .35792 L
s
.31016 .31412 m
.31054 .30471 L
s
.31046 .28889 m
.31073 .29102 L
s
0 0 0 r
2 Mabswid
.31004 .33195 Mdot
0 g
.5 Mabswid
.56905 .36852 m
.5695 .3666 L
s
0 0 1 r
.15772 .2762 m
.31001 .33102 L
s
0 0 0 r
2 Mabswid
.31001 .33102 Mdot
0 g
.5 Mabswid
.30998 .3303 m
.30977 .32357 L
s
.5706 .30221 m
.57023 .29961 L
s
0 0 0 r
2 Mabswid
.56975 .33006 Mdot
.5698 .32938 Mdot
0 g
.5 Mabswid
.56977 .35288 m
.5696 .34337 L
s
0 0 0 r
2 Mabswid
.30993 .32862 Mdot
0 g
.5 Mabswid
.30977 .32357 m
.31016 .31412 L
s
.3094 .35792 m
.30909 .35834 L
s
.56998 .32719 m
.57053 .32044 L
s
0 0 1 r
.16297 .27443 m
.30986 .32643 L
s
0 0 0 r
2 Mabswid
.30986 .32643 Mdot
0 g
.5 Mabswid
.31015 .28911 m
.31046 .28889 L
s
0 0 0 r
2 Mabswid
.30986 .32622 Mdot
.57008 .32603 Mdot
.5701 .32577 Mdot
0 g
.5 Mabswid
.5695 .3666 m
.56995 .36243 L
s
.56995 .36243 m
.56977 .35288 L
s
.57089 .307 m
.5706 .30221 L
s
.30939 .33306 m
.30977 .32357 L
s
.30977 .32357 m
.30956 .3168 L
s
0 0 0 r
2 Mabswid
.30969 .32094 Mdot
0 g
.5 Mabswid
.30909 .35834 m
.30881 .35639 L
s
0 0 1 r
.16822 .27267 m
.30969 .32074 L
s
0 0 0 r
2 Mabswid
.30969 .32074 Mdot
0 g
.5 Mabswid
.57053 .32044 m
.57109 .31366 L
s
.30981 .29169 m
.31015 .28911 L
s
.56995 .36243 m
.57036 .35628 L
s
.56995 .36243 m
.56995 .36243 L
s
.309 .3426 m
.30939 .33306 L
s
0 0 0 r
2 Mabswid
.30962 .31857 Mdot
0 g
.5 Mabswid
.57109 .31366 m
.57089 .307 L
s
.30956 .3168 m
.30935 .31 L
s
0 0 1 r
.17363 .27085 m
.30954 .31624 L
s
0 0 0 r
2 Mabswid
.30954 .31624 Mdot
.30952 .3153 Mdot
0 g
.5 Mabswid
.30881 .35639 m
.30861 .35217 L
s
.57036 .35628 m
.57071 .34856 L
s
.57117 .32173 m
.57109 .31366 L
s
.57109 .31366 m
.57109 .31366 L
s
.30861 .35217 m
.309 .3426 L
s
.30946 .29648 m
.30981 .29169 L
s
.57071 .34856 m
.57097 .33982 L
s
.57113 .33066 m
.57117 .32173 L
s
.30935 .31 m
.30914 .30315 L
s
.57097 .33982 m
.57113 .33066 L
s
.30861 .35217 m
.30848 .34597 L
s
.30861 .35217 m
.30861 .35217 L
s
.30914 .30315 m
.30946 .29648 L
s
.30848 .34597 m
.30844 .3382 L
s
.30885 .31125 m
.30914 .30315 L
s
.30914 .30315 m
.30914 .30315 L
s
.30844 .3382 m
.30849 .32941 L
s
.30863 .32021 m
.30885 .31125 L
s
.74182 .2841 m
.74002 .27823 L
s
.74002 .27823 m
.74064 .27804 L
s
.74002 .27823 m
.7378 .27269 L
s
.74307 .2899 m
.74182 .2841 L
s
.74182 .2841 m
.74244 .28391 L
s
.74064 .27804 m
.74244 .28391 L
s
.73842 .2725 m
.74064 .27804 L
s
.30849 .32941 m
.30863 .32021 L
s
.74244 .28391 m
.74369 .28971 L
s
.7378 .27269 m
.73842 .2725 L
s
.7378 .27269 m
.7353 .26783 L
s
.73592 .26764 m
.73842 .2725 L
s
.74307 .2899 m
.74369 .28971 L
s
.7353 .26783 m
.73592 .26764 L
s
.73732 .29213 m .74431 .29505 L .74369 .29524 L .656 .751 .92 r
F
0 g
.74364 .29976 m
.74369 .29524 L
s
.74307 .2899 m
.74364 .29477 L
s
.73732 .29213 m .74101 .29099 L .74431 .29505 L .656 .751 .92 r
F
0 g
.74426 .29957 m
.74431 .29505 L
s
.74369 .28971 m
.74431 .29505 L
s
.74369 .29524 m
.74431 .29505 L
s
.73269 .264 m .73366 .27013 L .72997 .27128 L .553 .337 .541 r
F
.73269 .264 m .73331 .26381 L .73366 .27013 L F
0 g
.73338 .265 m
.7353 .26783 L
s
.73331 .26381 m
.73592 .26764 L
s
.73269 .264 m
.73331 .26381 L
s
.73015 .26145 m
.73269 .264 L
s
.73077 .26125 m
.73331 .26381 L
s
.74292 .30316 m
.74364 .29976 L
s
.74364 .29976 m
.74426 .29957 L
s
.73225 .28859 m .74101 .29099 L .73732 .29213 L .656 .751 .92 r
F
0 g
.73732 .29213 m
.74369 .29524 L
s
.74426 .29957 m
.74354 .30297 L
s
.73225 .28859 m .7377 .28691 L .74101 .29099 L .656 .751 .92 r
F
0 1 0 r
.56878 .34187 m
.73285 .28908 L
s
0 g
.74101 .29099 m
.74431 .29505 L
s
.72997 .27128 m .73402 .27647 L .72858 .27815 L .553 .337 .541 r
F
.72997 .27128 m .73366 .27013 L .73402 .27647 L F
0 g
.72997 .27128 m
.73269 .264 L
s
.73331 .26381 m
.73366 .27013 L
s
.73015 .26145 m
.73077 .26125 L
s
.73015 .26145 m
.72784 .26036 L
s
.72846 .26016 m
.73077 .26125 L
s
.72835 .28469 m .7377 .28691 L .73225 .28859 L .656 .751 .92 r
F
0 1 0 r
.73285 .28908 m
.73796 .28724 L
s
0 g
.73225 .28859 m
.73732 .29213 L
s
.74157 .3052 m
.74292 .30316 L
s
.74292 .30316 m
.74354 .30297 L
s
.74354 .30297 m
.74219 .30501 L
s
.47895 .27339 m
.47716 .2675 L
s
.47716 .2675 m
.47776 .2673 L
s
.47716 .2675 m
.47483 .26192 L
s
.48007 .27921 m
.47895 .27339 L
s
.47895 .27339 m
.47955 .2732 L
s
.47776 .2673 m
.47955 .2732 L
s
.47542 .26173 m
.47776 .2673 L
s
.72858 .27815 m .73437 .28282 L .72835 .28469 L .553 .337 .541 r
F
.72858 .27815 m .73402 .27647 L .73437 .28282 L F
0 g
.72858 .27815 m
.72997 .27128 L
s
.73366 .27013 m
.73402 .27647 L
s
.47955 .2732 m
.48067 .27902 L
s
.47483 .26192 m
.47542 .26173 L
s
.47483 .26192 m
.4721 .25704 L
s
0 1 0 r
.73796 .28724 m
.92687 .21422 L
s
0 0 0 r
2 Mabswid
.73796 .28724 Mdot
0 g
.5 Mabswid
.4727 .25684 m
.47542 .26173 L
s
.72835 .28469 m .73437 .28282 L .7377 .28691 L .656 .751 .92 r
F
0 1 0 r
.56912 .33777 m
.73012 .28664 L
s
0 g
.7377 .28691 m
.74101 .29099 L
s
.48007 .27921 m
.48067 .27902 L
s
0 1 0 r
.73012 .28664 m
.73591 .28471 L
s
0 g
.72784 .26036 m
.72846 .26016 L
s
.72784 .26036 m
.72593 .2608 L
s
.72655 .26061 m
.72846 .26016 L
s
.4721 .25704 m
.4727 .25684 L
s
0 1 0 r
.73591 .28471 m
.92956 .21802 L
s
0 0 0 r
2 Mabswid
.73591 .28471 Mdot
.72835 .28469 m .73473 .2892 L .72927 .29088 L .553 .337 .541 r
F
.72835 .28469 m .73437 .28282 L .73473 .2892 L F
.72558 .28041 m .73437 .28282 L .72835 .28469 L .656 .751 .92 r
F
0 g
.5 Mabswid
.72847 .2812 m
.72858 .27815 L
s
.47368 .28142 m .48104 .28437 L .48044 .28457 L .656 .751 .92 r
F
0 g
.48004 .2891 m
.48044 .28457 L
s
.48007 .27921 m
.48041 .28412 L
s
.73968 .30573 m
.74157 .3052 L
s
.74157 .3052 m
.74219 .30501 L
s
.47368 .28142 m .47726 .28027 L .48104 .28437 L .656 .751 .92 r
F
0 g
.48064 .2889 m
.48104 .28437 L
s
.48067 .27902 m
.48104 .28437 L
s
.48044 .28457 m
.48104 .28437 L
s
.74219 .30501 m
.7403 .30553 L
s
.72558 .28041 m .73104 .27872 L .73437 .28282 L .656 .751 .92 r
F
0 1 0 r
.56975 .33006 m
.72686 .28264 L
s
0 g
.73437 .28282 m
.7377 .28691 L
s
.73402 .27647 m
.73437 .28282 L
s
0 1 0 r
.72686 .28264 m
.73283 .28093 L
s
0 0 0 r
2 Mabswid
.72686 .28264 Mdot
.46916 .25317 m .46973 .25931 L .46615 .26047 L .542 .321 .53 r
F
1 0 0 r
.5 Mabswid
.29437 .23027 m
.44132 .28117 L
s
.2904 .23161 m
.43649 .28273 L
s
.43649 .28273 m
.5698 .32938 L
s
.28463 .23355 m
.4266 .28592 L
s
.4266 .28592 m
.56906 .33847 L
s
.28076 .23484 m
.42191 .28743 L
s
.42191 .28743 m
.56876 .34213 L
s
.46916 .25317 m .46976 .25298 L .46973 .25931 L .542 .321 .53 r
F
0 g
.46975 .25395 m
.4721 .25704 L
s
.46916 .25317 m
.46976 .25298 L
s
.4662 .25059 m
.46916 .25317 L
s
.46976 .25298 m
.4727 .25684 L
s
.4668 .2504 m
.46976 .25298 L
s
.72593 .2608 m
.72655 .26061 L
s
.72593 .2608 m
.72454 .26277 L
s
.4789 .29249 m
.48004 .2891 L
s
.48004 .2891 m
.48064 .2889 L
s
.4682 .27786 m .47726 .28027 L .47368 .28142 L .656 .751 .92 r
F
1 0 0 r
.44132 .28117 m
.5701 .32577 L
s
0 g
.47368 .28142 m
.48044 .28457 L
s
.72516 .26258 m
.72655 .26061 L
s
.48064 .2889 m
.4795 .2923 L
s
.72927 .29088 m .73509 .29559 L .73137 .29673 L .553 .337 .541 r
F
.72927 .29088 m .73473 .2892 L .73509 .29559 L F
0 g
.72835 .28469 m
.72927 .29088 L
s
.73437 .28282 m
.73473 .2892 L
s
0 1 0 r
.73283 .28093 m
.93463 .22516 L
s
0 0 0 r
2 Mabswid
.73283 .28093 Mdot
.72397 .27575 m .73104 .27872 L .72558 .28041 L .656 .751 .92 r
F
0 g
.5 Mabswid
.72558 .28041 m
.72835 .28469 L
s
0 1 0 r
.57008 .32603 m
.7253 .27982 L
s
0 g
.73738 .3047 m
.73968 .30573 L
s
.73968 .30573 m
.7403 .30553 L
s
.4682 .27786 m .47347 .27616 L .47726 .28027 L .656 .751 .92 r
F
1 0 1 r
.31004 .33195 m
.46927 .27865 L
s
0 g
.47726 .28027 m
.48104 .28437 L
s
.7403 .30553 m
.738 .30451 L
s
.46615 .26047 m .4697 .26566 L .46442 .26737 L .542 .321 .53 r
F
.46615 .26047 m .46973 .25931 L .4697 .26566 L F
0 g
.46615 .26047 m
.46916 .25317 L
s
.46973 .25931 m
.46976 .25298 L
s
0 0 0 r
2 Mabswid
.7253 .27982 Mdot
0 g
.5 Mabswid
.4662 .25059 m
.4668 .2504 L
s
.4662 .25059 m
.46344 .24948 L
s
.46404 .24928 m
.4668 .2504 L
s
.72397 .27575 m .72769 .2746 L .73104 .27872 L .656 .751 .92 r
F
0 1 0 r
.7253 .27982 m
.73077 .27839 L
s
0 g
.73104 .27872 m
.73437 .28282 L
s
0 1 0 r
.73077 .27839 m
.9373 .22892 L
s
0 0 0 r
2 Mabswid
.73077 .27839 Mdot
.46384 .27391 m .47347 .27616 L .4682 .27786 L .656 .751 .92 r
F
1 0 1 r
.5 Mabswid
.46927 .27865 m
.47408 .27682 L
s
0 g
.4682 .27786 m
.47368 .28142 L
s
1 0 1 r
.30993 .32862 m
.46665 .27661 L
s
0 g
.47708 .29452 m
.4789 .29249 L
s
.4789 .29249 m
.4795 .2923 L
s
.4795 .2923 m
.47768 .29432 L
s
.72454 .26277 m
.72516 .26258 L
s
.72454 .26277 m
.72378 .26613 L
s
.7244 .26594 m
.72516 .26258 L
s
.46442 .26737 m .46967 .27203 L .46384 .27391 L .542 .321 .53 r
F
.46442 .26737 m .4697 .26566 L .46967 .27203 L F
0 g
.46442 .26737 m
.46615 .26047 L
s
.4697 .26566 m
.46973 .25931 L
s
.73137 .29673 m .73544 .302 L .73482 .3022 L .553 .337 .541 r
F
.73137 .29673 m .73509 .29559 L .73544 .302 L F
0 g
.72927 .29088 m
.73137 .29673 L
s
.73137 .29673 m
.73482 .3022 L
s
.73473 .2892 m
.73509 .29559 L
s
0 0 0 r
2 Mabswid
.47408 .27682 Mdot
0 g
.5 Mabswid
.73482 .3022 m
.73738 .3047 L
s
.73738 .3047 m
.738 .30451 L
s
.46384 .27391 m .46967 .27203 L .47347 .27616 L .656 .751 .92 r
F
1 0 1 r
.46665 .27661 m
.4721 .27467 L
s
.30986 .32622 m
.46513 .27523 L
s
0 g
.47347 .27616 m
.47726 .28027 L
s
.73544 .302 m
.738 .30451 L
s
.73509 .29559 m
.73544 .302 L
s
.7237 .27066 m .72769 .2746 L .72397 .27575 L .656 .751 .92 r
F
0 g
.72397 .27575 m
.72558 .28041 L
s
.46344 .24948 m
.46404 .24928 L
s
.46344 .24948 m
.46104 .24991 L
s
.46164 .24971 m
.46404 .24928 L
s
0 0 0 r
2 Mabswid
.4721 .27467 Mdot
.7237 .27066 m .72433 .27046 L .72769 .2746 L .656 .751 .92 r
F
0 g
.5 Mabswid
.72433 .27046 m
.72769 .2746 L
s
1 0 1 r
.4721 .27467 m
.86577 .12818 L
s
0 g
.72769 .2746 m
.73104 .27872 L
s
1 0 1 r
.47408 .27682 m
.85918 .1189 L
s
0 g
.7237 .27066 m
.72397 .27575 L
s
.46384 .27391 m .46964 .27842 L .46435 .28012 L .542 .321 .53 r
F
.46384 .27391 m .46967 .27203 L .46964 .27842 L F
.46056 .2696 m .46967 .27203 L .46384 .27391 L .656 .751 .92 r
F
1 0 1 r
.46966 .2737 m
.47084 .2733 L
s
0 g
.46414 .27055 m
.46442 .26737 L
s
1 0 1 r
.30969 .32094 m
.46265 .27255 L
s
0 g
.72378 .26613 m
.7244 .26594 L
s
.7237 .27066 m
.72378 .26613 L
s
.47471 .29503 m
.47708 .29452 L
s
.47708 .29452 m
.47768 .29432 L
s
.72433 .27046 m
.7244 .26594 L
s
.47768 .29432 m
.47531 .29484 L
s
1 0 1 r
.47084 .2733 m
.87029 .13455 L
s
0 0 0 r
2 Mabswid
.47084 .2733 Mdot
0 g
.5 Mabswid
.73218 .29836 m
.73482 .3022 L
s
.73482 .3022 m
.73544 .302 L
s
0 0 0 r
2 Mabswid
.46265 .27255 Mdot
0 g
.5 Mabswid
.73281 .29817 m
.73544 .302 L
s
.46056 .2696 m .46585 .26789 L .46967 .27203 L .656 .751 .92 r
F
1 0 1 r
.46265 .27255 m
.4685 .27076 L
s
.30962 .31857 m
.46151 .27105 L
s
0 g
.46967 .27203 m
.4697 .26566 L
s
.46967 .27203 m
.47347 .27616 L
s
0 0 0 r
2 Mabswid
.46151 .27105 Mdot
1 0 1 r
.5 Mabswid
.4685 .27076 m
.87991 .1481 L
s
0 0 0 r
2 Mabswid
.4685 .27076 Mdot
0 g
.5 Mabswid
.46104 .24991 m
.46164 .24971 L
s
.46104 .24991 m
.45919 .25186 L
s
.7237 .27066 m
.72433 .27046 L
s
.7237 .27066 m
.72431 .27604 L
s
.45979 .25167 m
.46164 .24971 L
s
.72433 .27046 m
.72494 .27585 L
s
.46435 .28012 m .46961 .28483 L .46601 .28598 L .542 .321 .53 r
F
.46435 .28012 m .46964 .27842 L .46961 .28483 L F
0 g
.46384 .27391 m
.46435 .28012 L
s
.46964 .27842 m
.46967 .27203 L
s
.72965 .29347 m
.73218 .29836 L
s
.73218 .29836 m
.73281 .29817 L
s
.73281 .29817 m
.73027 .29328 L
s
.45842 .2649 m .46585 .26789 L .46056 .2696 L .656 .751 .92 r
F
1 0 1 r
.46151 .27105 m
.46723 .26939 L
s
0 g
.46056 .2696 m
.46384 .27391 L
s
1 0 1 r
.30952 .3153 m
.46001 .26863 L
s
0 g
.47195 .29398 m
.47471 .29503 L
s
.47471 .29503 m
.47531 .29484 L
s
1 0 1 r
.46723 .26939 m
.88437 .15437 L
s
0 0 0 r
2 Mabswid
.46723 .26939 Mdot
0 g
.5 Mabswid
.47531 .29484 m
.47255 .29379 L
s
0 0 0 r
2 Mabswid
.46001 .26863 Mdot
0 g
.5 Mabswid
.72431 .27604 m
.72494 .27585 L
s
.72431 .27604 m
.72557 .28191 L
s
.7262 .28172 m
.72494 .27585 L
s
.72739 .28786 m
.72965 .29347 L
s
.72965 .29347 m
.73027 .29328 L
s
.45842 .2649 m .46202 .26373 L .46585 .26789 L .656 .751 .92 r
F
1 0 1 r
.46001 .26863 m
.46524 .26722 L
s
0 g
.46585 .26789 m
.46967 .27203 L
s
.73027 .29328 m
.72802 .28767 L
s
1 0 1 r
.46524 .26722 m
.89077 .16338 L
s
0 0 0 r
2 Mabswid
.46524 .26722 Mdot
0 g
.5 Mabswid
.72557 .28191 m
.7262 .28172 L
s
.72557 .28191 m
.72739 .28786 L
s
.72739 .28786 m
.72802 .28767 L
s
.72802 .28767 m
.7262 .28172 L
s
.45919 .25186 m
.45979 .25167 L
s
.45919 .25186 m
.458 .25522 L
s
.45861 .25503 m
.45979 .25167 L
s
.46601 .28598 m .46958 .29125 L .46898 .29145 L .542 .321 .53 r
F
.46601 .28598 m .46961 .28483 L .46958 .29125 L F
0 g
.46435 .28012 m
.46601 .28598 L
s
.46601 .28598 m
.46898 .29145 L
s
.46961 .28483 m
.46964 .27842 L
s
.46898 .29145 m
.47195 .29398 L
s
.47195 .29398 m
.47255 .29379 L
s
.46958 .29125 m
.47255 .29379 L
s
.46958 .29125 m
.46961 .28483 L
s
.45757 .25975 m .46202 .26373 L .45842 .2649 L .656 .751 .92 r
F
0 g
.45842 .2649 m
.46056 .2696 L
s
.45757 .25975 m .45818 .25956 L .46202 .26373 L .656 .751 .92 r
F
0 g
.45818 .25956 m
.46202 .26373 L
s
.46202 .26373 m
.46585 .26789 L
s
.45757 .25975 m
.45842 .2649 L
s
.45757 .25975 m
.458 .25522 L
s
.45861 .25503 m
.458 .25522 L
s
.45818 .25956 m
.45861 .25503 L
s
.466 .28759 m
.46898 .29145 L
s
.46898 .29145 m
.46958 .29125 L
s
.46661 .28739 m
.46958 .29125 L
s
.45757 .25975 m
.45818 .25956 L
s
.45757 .25975 m
.45793 .26515 L
s
.45818 .25956 m
.45853 .26496 L
s
.46323 .28266 m
.466 .28759 L
s
.466 .28759 m
.46661 .28739 L
s
.46661 .28739 m
.46384 .28247 L
s
.45793 .26515 m
.45853 .26496 L
s
.45793 .26515 m
.45905 .27104 L
s
.45966 .27085 m
.45853 .26496 L
s
.46086 .27702 m
.46323 .28266 L
s
.46323 .28266 m
.46384 .28247 L
s
.46384 .28247 m
.46147 .27682 L
s
.45905 .27104 m
.45966 .27085 L
s
.45905 .27104 m
.46086 .27702 L
s
.46086 .27702 m
.46147 .27682 L
s
.46147 .27682 m
.45966 .27085 L
s
0 0 0 r
2 Mabswid
.9373 .22892 Mdot
.93463 .22516 Mdot
.92956 .21802 Mdot
.92687 .21422 Mdot
.89077 .16338 Mdot
.88437 .15437 Mdot
.87991 .1481 Mdot
.87029 .13455 Mdot
.86577 .12818 Mdot
.85918 .1189 Mdot
0 g
.25 Mabswid
.00832 .29027 m
.85862 0 L
s
.00832 .29027 m
.00762 .29661 L
s
[(1200)] .00971 .27759 -0.10986 1 Mshowa
.16303 .23746 m
.16255 .24382 L
s
[(1400)] .16399 .22474 -0.07547 1 Mshowa
.32488 .18221 m
.32463 .18858 L
s
[(1600)] .32537 .16946 -0.03859 1 Mshowa
.49438 .12434 m
.49439 .13072 L
s
[(1800)] .49437 .11159 .00107 1 Mshowa
.6721 .06368 m
.67237 .07005 L
s
[(2000)] .67154 .05093 .04384 1 Mshowa
.85862 0 m
.8592 .00635 L
s
[(2200)] .85748 -0.0127 .09009 1 Mshowa
.125 Mabswid
.04635 .27729 m
.04596 .28109 L
s
.08481 .26416 m
.08445 .26797 L
s
.1237 .25088 m
.12338 .2547 L
s
.2028 .22388 m
.20255 .2277 L
s
.24303 .21015 m
.24281 .21397 L
s
.28372 .19626 m
.28354 .20008 L
s
.36652 .16799 m
.36641 .17182 L
s
.40864 .15361 m
.40857 .15744 L
s
.45126 .13906 m
.45123 .14289 L
s
.53802 .10945 m
.53806 .11327 L
s
.58218 .09437 m
.58226 .0982 L
s
.62687 .07912 m
.62699 .08294 L
s
.71788 .04805 m
.71809 .05187 L
s
.76422 .03223 m
.76447 .03605 L
s
.81113 .01621 m
.81143 .02003 L
s
.25 Mabswid
.99099 .19518 m
1 .27231 L
s
.99187 .20277 m
.98578 .20466 L
s
[(-40)] 1.00406 .199 -1 .3097 Mshowa
.99366 .21803 m
.98756 .21991 L
s
[(-20)] 1.00585 .21428 -1 .30768 Mshowa
.99545 .2334 m
.98936 .23527 L
s
[(0)] 1.00765 .22967 -1 .30565 Mshowa
.99726 .24888 m
.99116 .25073 L
s
[(20)] 1.00947 .24518 -1 .30361 Mshowa
.99908 .26447 m
.99298 .26631 L
s
[(40)] 1.01129 .26079 -1 .30155 Mshowa
.125 Mabswid
.99232 .20658 m
.98866 .20771 L
s
.99276 .21039 m
.98911 .21152 L
s
.99321 .21421 m
.98955 .21533 L
s
.99411 .22186 m
.99045 .22299 L
s
.99455 .2257 m
.9909 .22682 L
s
.995 .22955 m
.99134 .23067 L
s
.9959 .23726 m
.99224 .23838 L
s
.99636 .24113 m
.9927 .24224 L
s
.99681 .245 m
.99315 .24611 L
s
.99772 .25277 m
.99406 .25388 L
s
.99817 .25666 m
.99451 .25777 L
s
.99863 .26056 m
.99496 .26167 L
s
.99143 .19897 m
.98778 .20011 L
s
.99954 .26839 m
.99588 .26949 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{843.812, 438},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000=;0001]R000`400?l00000o`00003oo`3ooooo
0?ooool0ooooCP3oool00?l0ooooo`3ooooo0?ooodh0oooo003o0?ooool0oooo/P3oool400000003
0?ooo`0000000000008000000P3oool2000000<0oooo0P0000290?ooo`00o`3ooooo0?oook80oooo
00H000000?ooo`3oool000000?ooo`0000020?ooo`030000003oool000000080oooo00<000000?oo
o`0000000P3oool00`000000oooo0?ooo`260?ooo`00o`3ooooo0?oook<0oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`0000000P3oool00`00
0000oooo0?ooo`260?ooo`00o`3ooooo0?oook@0oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`0000020?ooo`030000003oool000000080oooo00<000000?ooo`3oool0QP3oool00?l0
ooooo`3ooone0?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000000P3oool00`000000
oooo000000020?ooo`030000003oool0oooo08H0oooo003o0?ooool0oooo/P3oool01P000000oooo
0?ooo`000000oooo00000080oooo00<000000?ooo`0000000P3oool00`000000oooo000000020?oo
o`030000003oool0oooo08H0oooo003o0?ooool0oooo/`3oool2000000<0oooo0P0000030?ooo`80
00000`3oool2000008T0oooo003o0?ooool0ooooo`3ooom>0?ooo`00o`3ooooo0?ooool0ooooCP3o
ool00?l0ooooo`3ooooo0?ooodh0oooo003o0?ooool0oooob`3oool2000000<0oooo0P0000030?oo
o`800000MP3oool00?l0ooooo`3oooo:0?ooo`060000003oool0oooo0000003oool000000P3oool0
0`000000oooo000000020?ooo`030000003oool0oooo07<0oooo003o0?ooool0ooooa`3oool30000
00<0oooo00<000000?ooo`0000000P3oool00`000000oooo000000020?ooo`030000003oool0oooo
07<0oooo003o0?ooool0oooob`3oool200000080oooo00H000000?ooo`3oool000000?ooo`000002
0?ooo`030000003oool0oooo07<0oooo003o0?ooool0ooooc@3oool00`000000oooo000000020?oo
o`030000003oool000000080oooo00<000000?ooo`3oool0L`3oool00?l0ooooo`3oooo:0?ooo`06
0000003oool0oooo0000003oool000000P3oool00`000000oooo000000020?ooo`030000003oool0
oooo07<0oooo003o0?ooool0oooob`3oool2000000<0oooo0P0000030?ooo`800000MP3oool00?l0
ooooo`3ooooo0?ooodh0oooo003o0?ooool0oooo_03oool3000008h0oooo003o0?ooool0oooo^@3o
ool4000000030?ooo`000000oooo08d0oooo003o0?ooool0oooo]`3oool3000000@0oooo0P00002=
0?ooo`00o`3ooooo0?oook@0oooo0`0000070?ooo`030000003oool0000008`0oooo003o0?ooool0
oooo/@3oool3000000X0oooo00<000000?ooo`000000S03oool00?l0ooooo`3ooon^0?ooo`<00000
3@3oool010000000oooo0?ooo`00002;0?ooo`00o`3ooooo0?oooj/0oooo0`00000D0?ooo`030000
003oool0oooo08P0oooo003o0?ooool0ooooZ03oool3000001L0oooo00<000000?ooo`3oool0R03o
ool00?l0ooooo`3ooonU0?ooo`<000006`3oool00`000000oooo0?ooo`270?ooo`00o`3ooooo0?oo
oj80oooo0`00000N0?ooo`800000R03oool00?l0ooooo`3ooonO0?ooo`<000007`3oool200000003
0?ooo`000000oooo08L0oooo003o0?ooool0ooooW03oool3000002H0oooo00<000000?ooo`3oool0
Q@3oool00?l0ooooo`3ooonI0?ooo`<00000:P3oool00`000000oooo0?ooo`240?ooo`00o`3ooooo
0?oooiH0oooo0`00000]0?ooo`030000003oool0oooo08@0oooo003o0?ooool0ooooT`3oool30000
00030?ooo`000000oooo02h0oooo00<000000?ooo`3oool0P`3oool00?l0ooooo`3ooon@0?ooo`<0
00001@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0880oooo003o0?ooool0oooo
S@3oool3000000P0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`220?ooo`00o`3o
oooo0?oooh/0oooo0P00000l0?ooo`030000003oool0oooo0840oooo003o0?ooool0ooooR03oool3
000003l0oooo00<000000?ooo`3oool0P03oool00?l0ooooo`3ooon50?ooo`<00000@P3oool20000
0840oooo003o0?ooool0ooooPP3oool3000004<0oooo0P0000000`3oool000000?ooo`200?ooo`00
o`3ooooo0?ooogl0oooo0`00001:0?ooo`030000003oool0oooo07h0oooo003o0?ooool0ooooO03o
ool3000004h0oooo00<000000?ooo`3oool0O@3oool00?l0ooooo`3ooomi0?ooo`<00000D@3oool0
0`000000oooo0?ooo`1m0?ooo`00o`3ooooo0?ooogH0oooo0`00001E0?ooo`030000003oool0oooo
07`0oooo003o0?ooool0ooooL`3oool3000005T0oooo00<000000?ooo`3oool0N`3oool00?l0oooo
o`3ooom`0?ooo`<00000G03oool00`000000oooo0?ooo`1k0?ooo`00o`3ooooo0?ooofd0oooo0`00
00020?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0NP3oool00?l0ooooo`3ooomZ
0?ooo`<000001@3oool00`000000oooo0?ooo`1K0?ooo`800000N`3oool00?l0ooooo`3ooomW0?oo
o`<00000203oool00`000000oooo0?ooo`1I0?ooo`80000000<0oooo0000003oool0NP3oool00?l0
ooooo`3ooomT0?ooo`<00000J`3oool00`000000oooo0?ooo`1h0?ooo`00o`3ooooo0?ooof40oooo
0`00001_0?ooo`030000003oool0oooo07L0oooo003o0?ooool0ooooGP3oool300000780oooo00<0
00000?ooo`3oool0M`3oool00?l0ooooo`3ooolM0?ooo`@000000P3oool2000000<0oooo0P000003
0?ooo`800000;@3oool2000007H0oooo00<000000?ooo`3oool0MP3oool00?l0ooooo`3ooolM0?oo
o`060000003oool0oooo0000003oool000000P3oool00`000000oooo000000020?ooo`030000003o
ool000000080oooo00<000000?ooo`3oool09`3oool3000007T0oooo00<000000?ooo`3oool0M@3o
ool00?l0ooooo`3ooolN0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0000
00020?ooo`030000003oool000000080oooo00<000000?ooo`3oool0903oool3000007`0oooo00<0
00000?ooo`3oool0M@3oool00?l0ooooo`3ooolO0?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`0000000P3oool00`000000oooo000000020?ooo`030000003oool0oooo0240oooo0`00
00200?ooo`030000003oool0oooo07@0oooo003o0?ooool0oooo803oool00`000000oooo00000002
0?ooo`030000003oool000000080oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0N
0?ooo`<00000Q03oool00`000000oooo0?ooo`1c0?ooo`00o`3ooooo0?oooad0oooo00H000000?oo
o`3oool000000?ooo`0000020?ooo`030000003oool000000080oooo00<000000?ooo`0000000P3o
ool00`000000oooo0?ooo`0J0?ooo`@00000QP3oool2000007D0oooo003o0?ooool0oooo7P3oool2
000000<0oooo0P0000030?ooo`8000000`3oool2000001/0oooo0`0000280?ooo`040000003oool0
oooo000007@0oooo003o0?ooool0ooooA`3oool3000000<0oooo00<000000?ooo`3oool0R@3oool0
0`000000oooo0?ooo`0>0?ooo`@000000P3oool2000000<0oooo0P00001F0?ooo`00o`3ooooo0?oo
od@0oooo0`0000060?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool03P3oool01P00
0000oooo0?ooo`000000oooo00000080oooo00<000000?ooo`0000000P3oool00`000000oooo0?oo
o`1C0?ooo`00o`3ooooo0?oood40oooo0`00002F0?ooo`030000003oool0oooo00X0oooo0`000000
0`3oool000000?ooo`020?ooo`060000003oool0oooo0000003oool000000P3oool00`000000oooo
0?ooo`1C0?ooo`00o`3ooooo0?oooch0oooo0`00002J0?ooo`030000003oool0oooo00h0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo000000020?ooo`030000003oool0oooo05<0oooo
003o0?ooool0oooo>`3oool3000009d0oooo00<000000?ooo`3oool03`3oool00`000000oooo0000
00020?ooo`030000003oool000000080oooo00<000000?ooo`3oool0D`3oool00?l0ooooo`3ooolh
0?ooo`<00000X@3oool00`000000oooo0?ooo`0;0?ooo`060000003oool0oooo0000003oool00000
0P3oool00`000000oooo000000020?ooo`030000003oool0oooo05<0oooo003o0?ooool0oooo=@3o
ool300000:D0oooo00<000000?ooo`3oool02`3oool2000000<0oooo0P0000030?ooo`800000EP3o
ool00?l0ooooo`3ooolb0?ooo`<00000Z03oool2000006h0oooo003o0?ooool0oooo;`3oool30000
0:P0oooo0`0000000`3oool000000?ooo`1]0?ooo`00o`3ooooo0?ooob`0oooo0`00002Z0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0J`3oool00?l0ooooo`3ooolZ0?ooo`800000
/`3oool00`000000oooo0?ooo`1[0?ooo`00o`3ooooo0?ooobL0oooo0`00002f0?ooo`030000003o
ool0oooo06X0oooo003o0?ooool0oooo903oool400000;T0oooo00<000000?ooo`3oool0J@3oool0
0?l0ooooo`3ooolQ0?ooo`<000000`3oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo
06T0oooo003o0?ooool0oooo7P3oool3000000L0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`1X0?ooo`00o`3ooooo0?oooa/0oooo0`00000:0?ooo`030000003oool0oooo0;P0oooo
00<000000?ooo`3oool0I`3oool00?l0ooooo`3ooolH0?ooo`<000003@3oool00`000000oooo0?oo
o`2h0?ooo`800000J03oool00?l0ooooo`3ooolE0?ooo`<00000b@3oool2000000030?ooo`000000
oooo06L0oooo003o0?ooool0oooo4P3oool300000=00oooo00<000000?ooo`3oool0I@3oool00?l0
ooooo`3oool?0?ooo`<00000d`3oool00`000000oooo0?ooo`1U0?ooo`00o`3ooooo0?ooo``0oooo
0`00003G0?ooo`030000003oool0oooo06@0oooo003o0?ooool0oooo2@3oool300000=/0oooo00<0
00000?ooo`3oool0H`3oool00?l0ooooo`3oool60?ooo`<00000g`3oool00`000000oooo0?ooo`1R
0?ooo`00o`3ooooo0?ooo`<0oooo0`00003R0?ooo`030000003oool0oooo0680oooo003o0?ooool0
oooo1000003U0?ooo`030000003oool0oooo0640oooo003o0?oooo`0oooo0`0000030?ooo`030000
003oool0oooo0><0oooo0P00001R0?ooo`00o`3ooooi0?ooo`<000001P3oool00`000000oooo0?oo
o`3Q0?ooo`80000000<0oooo0000003oool0H@3oool00?l0oooom`3oool200000?40oooo00<00000
0?ooo`3oool0G`3oool00?l0oooom03oool300000?@0oooo00<000000?ooo`3oool0GP3oool00?l0
ooool@3oool300000?L0oooo00<000000?ooo`3oool0GP3oool00?l0ooookP3oool300000?/0oooo
00<000000?ooo`3oool0G@3oool00?l0ooooj`3oool300000?l0oooo00<000000?ooo`3oool0G03o
ool00?l0ooooj03oool300000?l0oooo0`3oool00`000000oooo0?ooo`1L0?ooo`00o`3ooooU0?oo
o`<00000o`3oool70?ooo`030000003oool0oooo05/0oooo003o0?ooon80oooo0`00003o0?ooo`/0
oooo00<000000?ooo`3oool0FP3oool00?l0oooog`3oool300000?l0oooo2`3oool4000005`0oooo
003o0?ooom`0oooo0`00003o0?oooa80oooo00<000000?ooo`3oool0F@3oool00?l0oooof@3oool3
00000080oooo00<000000?ooo`3oool0o`3ooolA0?ooo`030000003oool0oooo05P0oooo003o0?oo
omH0oooo0`0000050?ooo`030000003oool0oooo0?l0oooo4@3oool00`000000oooo0?ooo`1H0?oo
o`00o`3ooooC0?ooo`<00000203oool00`000000oooo0?ooo`3o0?oooa80oooo00<000000?ooo`3o
ool0E`3oool00?l0ooood03oool300000?l0oooo8@3oool00`000000oooo0?ooo`1F0?ooo`00o`3o
ooo=0?ooo`<00000o`3ooolT0?ooo`030000003oool0oooo05H0oooo003o0?ooohh0oooo0`000002
0?ooo`8000000`3oool2000000<0oooo0P00000[0?ooo`<00000o`3ooolX0?ooo`030000003oool0
oooo05D0oooo003o0?ooohl0oooo00@000000?ooo`3oool000000P3oool00`000000oooo00000002
0?ooo`030000003oool000000080oooo00<000000?ooo`3oool09P3oool200000?l0oooo;03oool0
0`000000oooo0?ooo`1D0?ooo`00o`3ooon?0?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`0000000P3oool00`000000oooo000000020?ooo`030000003oool0oooo02<0oooo0`00003o
0?ooob`0oooo0`00001F0?ooo`00o`3ooon?0?ooo`040000003oool0oooo0?ooo`8000000P3oool0
1P000000oooo0?ooo`000000oooo00000080oooo00<000000?ooo`3oool0803oool300000?l0oooo
<P3oool00`000000oooo0?ooo`0@0?ooo`<000000P3oool2000000<0oooo0P00000g0?ooo`00o`3o
oon?0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`0000000P3oool00`000000oooo
000000020?ooo`030000003oool0oooo01d0oooo0`00003o0?ooocH0oooo00<000000?ooo`3oool0
403oool010000000oooo0?ooo`0000020?ooo`030000003oool000000080oooo00<000000?ooo`3o
ool0=03oool00?l0ooooSP3oool200000080oooo00H000000?ooo`3oool000000?ooo`0000020?oo
o`030000003oool000000080oooo00<000000?ooo`3oool06P3oool300000?l0oooo>@3oool00`00
0000oooo0?ooo`0;0?ooo`<000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
00000080oooo00<000000?ooo`3oool0=03oool00?l0ooooS`3oool010000000oooo0?ooo`3oool2
000000<0oooo0P0000030?ooo`8000006P3oool300000?l0oooo?@3oool00`000000oooo0?ooo`0?
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`0000000P3oool00`000000oooo0?oo
o`0d0?ooo`00o`3ooonf0?ooo`<000000P3oool00`000000oooo0?ooo`3o0?oooc`0oooo00<00000
0?ooo`3oool03P3oool010000000oooo0?ooo`0000020?ooo`030000003oool000000080oooo00<0
00000?ooo`3oool0=03oool00?l0oooo/`3oool3000000D0oooo00<000000?ooo`3oool0o`3oooll
0?ooo`030000003oool0oooo00d0oooo0P0000020?ooo`060000003oool0oooo0000003oool00000
0P3oool00`000000oooo0?ooo`0d0?ooo`00o`3ooon`0?ooo`<00000203oool00`000000oooo0?oo
o`3o0?ooocd0oooo00<000000?ooo`3oool03@3oool010000000oooo0?ooo`3oool2000000<0oooo
0P00000g0?ooo`00o`3ooon]0?ooo`<00000o`3ooom;0?ooo`800000D03oool00?l0ooooZP3oool3
00000?l0ooooC03oool2000000030?ooo`000000oooo04l0oooo003o0?ooojL0oooo0`00003o0?oo
odh0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1=0?ooo`00o`3ooonT0?ooo`<0
0000o`3ooolF0?ooo`030?l0o`000000000003h0oooo00<000000?ooo`3oool0C03oool00?l0oooo
X@3oool300000?l0oooo5P3oool30?l0o`030?ooo`000000000003h0oooo00<000000?ooo`3oool0
C03oool00?l0ooooWP3oool300000?l0oooo5`3oool20?l0odD0oooo00<000000?ooo`3oool0B`3o
ool00?l0ooooV`3oool300000?l0oooo5`3oool30?l0odP0oooo00<000000?ooo`3oool0BP3oool0
0?l0ooooV03oool300000?l0oooo603oool20?l0od`0oooo00<000000?ooo`3oool0B@3oool00?l0
ooooUP3oool200000?l0oooo6@3oool20?l0odh0oooo00<000000?ooo`3oool0B@3oool00?l0oooo
T`3oool3000000030?ooo`000000oooo0?l0oooo5@3oool30?l0oe00oooo0P00001:0?ooo`00o`3o
oon@0?ooo`<00000103oool00`000000oooo0?ooo`3o0?oooa80oooo0P3o0?lE0?ooo`800000>`3o
ool010000000oooo0?ooo`0000190?ooo`00o`3ooon=0?ooo`<000001`3oool00`000000oooo0?oo
o`3o0?ooo`l0oooo0`3o0?lF0?ooo`030?l0o`000000000003h0oooo00<000000?ooo`3oool0A`3o
ool00?l0ooooRP3oool3000000X0oooo00<000000?ooo`3oool0o`3oool=0?ooo`80o`3o5P3oool3
0?l0od80oooo00<000000?ooo`3oool0AP3oool00?l0ooooQ`3oool3000000d0oooo00<000000?oo
o`3oool0o`3oool:0?ooo`<0o`3o5@3oool30?l0odH0oooo00<000000?ooo`3oool0A@3oool00?l0
ooooQ03oool300000?l0oooo6`3oool20?l0oaH0oooo0P3o0?m90?ooo`030000003oool0oooo04D0
oooo003o0?oooh40oooo0`00003o0?oooa/0oooo0`3o0?lE0?ooo`<0o`3oC03oool00`000000oooo
0?ooo`140?ooo`00o`3ooomn0?ooo`<00000o`3ooolL0?ooo`80o`3o5@3oool30?l0o`l0oooo0P00
000o0?ooo`030000003oool0oooo04<0oooo003o0?ooog/0oooo0`00003o0?oooad0oooo0P3o0?lE
0?ooo`80o`3o3`3oool30?l0o`800000?`3oool00`000000oooo0?ooo`130?ooo`00o`3ooomh0?oo
o`<00000o`3ooolM0?ooo`<0o`3o503oool30?l0o`h0oooo0`3o0?m40?ooo`800000A03oool00?l0
ooooM@3oool300000?l0oooo7P3oool20?l0oa@0oooo0`3o0?l>0?ooo`<0o`3oA@3oool200000080
oooo00<000000?ooo`3oool0@@3oool00?l0ooooLP3oool400000?l0oooo7@3oool30?l0oa@0oooo
0P3o0?l>0?ooo`<0o`3oC03oool00`000000oooo0?ooo`110?ooo`00o`3ooom_0?ooo`<000000`3o
ool00`000000oooo0?ooo`3o0?oooaT0oooo0P3o0?lD0?ooo`<0o`3o3@3oool30?l0oe00oooo00<0
00000?ooo`3oool0@03oool00?l0ooooK03oool3000000H0oooo00<000000?ooo`3oool0o`3ooolF
0?ooo`<0o`3o4`3oool30?l0o`d0oooo0`3o0?mD0?ooo`030000003oool0oooo03l0oooo003o0?oo
ofT0oooo0`0000090?ooo`030000003oool0oooo0?l0oooo503oool20?l0oa@0oooo0P3o0?l>0?oo
o`80o`3oE`3oool00`000000oooo0?ooo`0o0?ooo`00o`3ooomV0?ooo`<00000o`3ooolQ0?ooo`80
o`3o4`3oool30?l0o`d0oooo0`3o0?mJ0?ooo`030000003oool0oooo03h0oooo003o0?ooof@0oooo
0P00003o0?ooob40oooo0`3o0?lB0?ooo`<0o`3o3@3oool30?l0oeh0oooo00<000000?ooo`3oool0
?@3oool00?l0ooooH@3oool300000?l0oooo8@3oool20?l0oa80oooo0`3o0?l=0?ooo`<0o`3o8P3o
ool2000003d0oooo00<000000?ooo`3oool0?@3oool00?l0ooooGP3oool300000?l0oooo8@3oool3
0?l0oa80oooo0P3o0?l=0?ooo`<0o`3o903oool00`3o0?l000000000000m0?ooo`800000?P3oool0
0?l0ooooF`3oool300000?l0oooo8P3oool20?l0oa80oooo0`3o0?l<0?ooo`<0o`3o903oool30?l0
och0oooo0P0000020?ooo`030000003oool0oooo03/0oooo003o0?oooeP0oooo0`00003o0?ooob80
oooo0`3o0?lA0?ooo`<0o`3o303oool30?l0ob@0oooo0`3o0?m50?ooo`030000003oool0oooo03/0
oooo003o0?oooeD0oooo0`00003o0?ooob<0oooo0P3o0?lB0?ooo`80o`3o303oool30?l0ob<0oooo
103o0?m90?ooo`030000003oool0oooo03X0oooo003o0?oooe80oooo0`00003o0?ooob<0oooo0`3o
0?lA0?ooo`<0o`3o303oool20?l0ob<0oooo0`3o0?l?0?ooo`800000?@3oool00`000000oooo0?oo
o`0i0?ooo`00o`3ooom?0?ooo`@00000o`3ooolS0?ooo`80o`3o4@3oool30?l0o``0oooo0`3o0?lR
0?ooo`<0o`3o403oool20?l0o`800000?@3oool00`000000oooo0?ooo`0i0?ooo`00o`3ooom<0?oo
o`<000000`3oool00`000000oooo0?ooo`3o0?oooal0oooo0P3o0?lA0?ooo`80o`3o303oool30?l0
ob40oooo103o0?l@0?ooo`<0o`3o@P3oool00`000000oooo0?ooo`0h0?ooo`00o`3ooom90?ooo`<0
00001P3oool00`000000oooo0?ooo`3o0?oooa`0oooo0`3o0?l@0?ooo`<0o`3o2`3oool30?l0ob40
oooo0`3o0?l@0?ooo`@0o`3oAP3oool00`000000oooo0?ooo`0g0?ooo`00o`3ooom60?ooo`<00000
o`3ooolV0?ooo`80o`3o403oool30?l0o`/0oooo0`3o0?lQ0?ooo`<0o`3o3`3oool40?l0odX0oooo
0P00000h0?ooo`00o`3oool70?ooo`<000000P3oool2000000<0oooo0P0000030?ooo`800000:`3o
ool300000?l0oooo9P3oool30?l0oa00oooo0P3o0?l;0?ooo`<0o`3o803oool40?l0o`l0oooo0`3o
0?m<0?ooo`80000000<0oooo0000003oool0=`3oool00?l0oooo203oool010000000oooo0?ooo`00
00020?ooo`030000003oool000000080oooo00<000000?ooo`0000000P3oool00`000000oooo0?oo
o`0U0?ooo`<00000o`3ooolW0?ooo`80o`3o403oool30?l0o`X0oooo0`3o0?lP0?ooo`<0o`3o3`3o
ool40?l0oe<0oooo00<000000?ooo`3oool03@3oool2000002H0oooo003o0?ooo`P0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo000000020?ooo`030000003oool000000080oooo00<0
00000?ooo`3oool08P3oool300000?l0oooo9`3oool30?l0o`l0oooo0`3o0?l;0?ooo`80o`3o803o
ool30?l0o`l0oooo0`3o0?mG0?ooo`030000003oool0oooo00`0oooo00@000000?ooo`3oool00000
9@3oool00?l0oooo203oool010000000oooo0?ooo`0000020?ooo`030000003oool000000080oooo
00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0O0?ooo`<00000o`3ooolX0?ooo`80o`3o
403oool20?l0o`/0oooo0`3o0?lN0?ooo`@0o`3o3P3oool40?l0oaX0oooo0P3o0?l2000003d0oooo
00<000000?ooo`3oool02`3oool010000000oooo0?ooo`00000U0?ooo`00o`3oool80?ooo`030000
003oool0oooo00<000000P3oool01P000000oooo0?ooo`000000oooo00000080oooo00<000000?oo
o`3oool0703oool300000?l0oooo:03oool30?l0o`l0oooo0`3o0?l:0?ooo`<0o`3o7P3oool30?l0
o`h0oooo103o0?lJ0?ooo`@0o`3o0P3oool2000003h0oooo00<000000?ooo`3oool02P3oool01000
0000oooo0?ooo`00000U0?ooo`00o`3oool70?ooo`8000000P3oool00`000000oooo0?ooo`020?oo
o`060000003oool0oooo0000003oool000000P3oool00`000000oooo0?ooo`0J0?ooo`800000o`3o
oolY0?ooo`80o`3o3`3oool30?l0o`X0oooo0`3o0?lN0?ooo`<0o`3o3P3oool30?l0oaX0oooo103o
0?m60?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool000009@3oool00?l0oooo203o
ool010000000oooo0?ooo`3oool2000000<0oooo0P0000030?ooo`8000006P3oool300000?l0oooo
:@3oool20?l0o`l0oooo0P3o0?l:0?ooo`<0o`3o7@3oool40?l0o`d0oooo103o0?lI0?ooo`@0o`3o
B`3oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo000002D0oooo003o0?ooobl0oooo
0`00003o0?ooobT0oooo0`3o0?l>0?ooo`<0o`3o2@3oool30?l0oad0oooo0`3o0?l>0?ooo`<0o`3o
6@3oool40?l0oe00oooo00<000000?ooo`3oool02@3oool2000002H0oooo003o0?ooob`0oooo0`00
00020?ooo`030000003oool0oooo0?l0oooo9@3oool20?l0o`h0oooo0`3o0?l90?ooo`<0o`3o703o
ool40?l0o`d0oooo103o0?lH0?ooo`@0o`3oD`3oool300000380oooo003o0?ooobT0oooo0`000004
0?ooo`030000003oool0oooo0?l0oooo8`3oool30?l0o`h0oooo0P3o0?l90?ooo`<0o`3o703oool3
0?l0o`d0oooo103o0?lH0?ooo`@0o`3oE03oool300000080oooo00<000000?ooo`3oool0<03oool0
0?l0oooo9P3oool3000000L0oooo00<000000?ooo`3oool0o`3ooolQ0?ooo`80o`3o3P3oool30?l0
o`T0oooo0P3o0?lL0?ooo`<0o`3o3@3oool30?l0oaL0oooo1@3o0?mN0?ooo`030000003oool0oooo
02l0oooo003o0?ooob<0oooo0`00003o0?ooob/0oooo0`3o0?l=0?ooo`<0o`3o2@3oool30?l0oaX0
oooo103o0?l<0?ooo`@0o`3o5P3oool40?l0of@0oooo00<000000?ooo`3oool0;P3oool00?l0oooo
803oool300000?l0oooo;03oool20?l0o`h0oooo0P3o0?l90?ooo`<0o`3o6P3oool30?l0o`d0oooo
0`3o0?lF0?ooo`@0o`3oJ03oool00`000000oooo0?ooo`0^0?ooo`00o`3ooolM0?ooo`<00000o`3o
ool/0?ooo`<0o`3o3@3oool30?l0o`P0oooo0`3o0?lJ0?ooo`<0o`3o303oool40?l0oaD0oooo103o
0?m]0?ooo`030000003oool0oooo02d0oooo003o0?oooaX0oooo0`00003o0?ooobd0oooo0P3o0?l=
0?ooo`<0o`3o203oool30?l0oaT0oooo103o0?l;0?ooo`@0o`3o5@3oool40?l0og80oooo00<00000
0?ooo`3oool0;03oool00?l0oooo5`3oool300000?l0oooo;P3oool20?l0o`d0oooo0P3o0?l80?oo
o`<0o`3o6@3oool30?l0o``0oooo0`3o0?lE0?ooo`@0o`3oMP3oool00`000000oooo0?ooo`0/0?oo
o`00o`3ooolD0?ooo`<00000o`3oool^0?ooo`<0o`3o303oool30?l0o`L0oooo0`3o0?lI0?ooo`<0
o`3o2`3oool40?l0oa@0oooo103o0?mk0?ooo`800000;03oool00?l0oooo4@3oool300000?l0oooo
;`3oool20?l0o``0oooo0`3o0?l80?ooo`80o`3o603oool40?l0o`/0oooo0`3o0?lD0?ooo`@0o`3o
O@3oool2000000030?ooo`000000oooo02/0oooo003o0?ooo`h0oooo0`00003o0?ooobl0oooo0`3o
0?l<0?ooo`80o`3o203oool30?l0oaL0oooo0`3o0?l;0?ooo`@0o`3o4`3oool40?l0oh@0oooo00<0
00000?ooo`3oool0:P3oool00?l0oooo2`3oool3000000030?ooo`000000oooo0?l0oooo;@3oool2
0?l0o``0oooo0`3o0?l70?ooo`<0o`3o5`3oool30?l0o`X0oooo103o0?lC0?ooo`@0o`3oR@3oool0
0`000000oooo0?ooo`0Y0?ooo`00o`3oool80?ooo`<00000103oool00`000000oooo0?ooo`3o0?oo
obT0oooo0`3o0?l;0?ooo`<0o`3o1`3oool30?l0oaH0oooo103o0?l:0?ooo`<0o`3o4`3oool40?l0
ohh0oooo00<000000?ooo`3oool0:03oool00?l0oooo1@3oool3000000L0oooo00<000000?ooo`3o
ool0o`3ooolW0?ooo`80o`3o2`3oool30?l0o`L0oooo0`3o0?lF0?ooo`<0o`3o2P3oool40?l0oa80
oooo103o0?nB0?ooo`030000003oool0oooo02P0oooo003o0?ooo`<0oooo0P00000:0?ooo`030000
003oool0oooo0?l0oooo9@3oool20?l0o`/0oooo0P3o0?l70?ooo`<0o`3o5P3oool30?l0o`X0oooo
0`3o0?lB0?ooo`@0o`3oU`3oool00`000000oooo0?ooo`0W0?ooo`00o`3oool3000000`0oooo00<0
00000?ooo`3oool0o`3ooolR0?ooo`<0o`3o2P3oool30?l0o`H0oooo0`3o0?lE0?ooo`@0o`3o2@3o
ool40?l0oa40oooo103o0?nL0?ooo`030000003oool0oooo02H0oooo003l0?ooo`<00000o`3ooolb
0?ooo`80o`3o2P3oool30?l0o`H0oooo0`3o0?lE0?ooo`<0o`3o2@3oool40?l0oa00oooo1@3o0?nP
0?ooo`030000003oool0oooo02H0oooo003i0?ooo`<00000o`3ooolb0?ooo`<0o`3o2P3oool20?l0
o`L0oooo0P3o0?lE0?ooo`<0o`3o2@3oool30?l0oa00oooo103o0?nU0?ooo`8000009`3oool00?H0
oooo0`00003o0?oooc<0oooo0P3o0?l:0?ooo`<0o`3o1P3oool30?l0oa<0oooo103o0?l80?ooo`@0
o`3o3`3oool40?l0ojL0oooo0P0000020?ooo`030000003oool0oooo02@0oooo003c0?ooo`<00000
o`3ooolc0?ooo`<0o`3o2@3oool30?l0o`H0oooo0`3o0?lC0?ooo`<0o`3o2@3oool30?l0o`l0oooo
103o0?n_0?ooo`030000003oool0oooo02@0oooo003`0?ooo`<00000o`3ooold0?ooo`80o`3o2P3o
ool20?l0o`H0oooo0`3o0?lC0?ooo`<0o`3o203oool40?l0o`h0oooo103o0?nd0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool00P00000?0?ooo`00k@3oool300000?l0oooo=03oool3
0?l0o`T0oooo0`3o0?l50?ooo`<0o`3o4P3oool40?l0o`L0oooo103o0?l>0?ooo`@0o`3o^@3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool000000080oooo00<000000?ooo`3oool0303oool0
0>X0oooo1000003o0?oooc@0oooo0P3o0?l90?ooo`<0o`3o1@3oool30?l0oa80oooo0`3o0?l80?oo
o`<0o`3o3P3oool40?l0okd0oooo00<000000?ooo`3oool0203oool7000000050?ooo`000000oooo
0?ooo`0000003P3oool00>L0oooo0`0000030?ooo`030000003oool0oooo0?l0oooo<03oool20?l0
o`T0oooo0P3o0?l50?ooo`<0o`3o4P3oool30?l0o`L0oooo103o0?l=0?ooo`@0o`3o`@3oool00`00
0000oooo0?ooo`0;0?ooo`060000003oool0oooo0000003oool000000P3oool00`000000oooo0?oo
o`0<0?ooo`00i03oool3000000H0oooo00<000000?ooo`3oool0o`3oool]0?ooo`<0o`3o203oool3
0?l0o`D0oooo0P3o0?lA0?ooo`@0o`3o1`3oool30?l0o`d0oooo103o0?o40?ooo`8000003P3oool0
1@000000oooo0000003oool000000080oooo00<000000?ooo`3oool0303oool00>40oooo0`000009
0?ooo`030000003oool0oooo0?l0oooo:`3oool20?l0o`P0oooo0`3o0?l50?ooo`<0o`3o403oool3
0?l0o`L0oooo103o0?l<0?ooo`@0o`3oa`3oool00`000000oooo0000000?0?ooo`80000000D0oooo
0000003oool0oooo0000000>0?ooo`00gP3oool300000?l0oooo=`3oool30?l0o`P0oooo0P3o0?l5
0?ooo`<0o`3o403oool30?l0o`H0oooo103o0?l<0?ooo`@0o`3ocP3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo008000003`3oool00=/0oooo0`00003o0?ooocP0oooo0P3o0?l80?oo
o`<0o`3o103oool30?l0o`l0oooo103o0?l60?ooo`<0o`3o303oool40?l0om00oooo0`00000S0?oo
o`00f03oool300000?l0oooo>03oool30?l0o`L0oooo0`3o0?l40?ooo`<0o`3o3`3oool30?l0o`H0
oooo103o0?l;0?ooo`@0o`3od@3oool300000080oooo00<000000?ooo`3oool08@3oool00=D0oooo
0`00003o0?ooocT0oooo0P3o0?l80?ooo`80o`3o103oool30?l0o`l0oooo0`3o0?l60?ooo`<0o`3o
2`3oool40?l0omX0oooo00<000000?ooo`3oool08@3oool00=<0oooo0P00003o0?ooocT0oooo0`3o
0?l70?ooo`<0o`3o0`3oool30?l0o`h0oooo103o0?l50?ooo`@0o`3o2@3oool50?l0omd0oooo0P00
000S0?ooo`00d03oool300000?l0oooo>@3oool20?l0o`L0oooo0`3o0?l30?ooo`<0o`3o3P3oool3
0?l0o`D0oooo103o0?l90?ooo`@0o`3oh03oool2000000030?ooo`000000oooo0280oooo003=0?oo
o`<00000o`3ooolj0?ooo`80o`3o1`3oool20?l0o`@0oooo0P3o0?l=0?ooo`@0o`3o1@3oool30?l0
o`T0oooo103o0?oW0?ooo`030000003oool0oooo00/0oooo100000020?ooo`8000003P3oool00<X0
oooo0`00003o0?ooocX0oooo0`3o0?l60?ooo`<0o`3o0`3oool30?l0o``0oooo0`3o0?l50?ooo`@0
o`3o203oool40?l0on/0oooo0P00000<0?ooo`060000003oool0oooo0000003oool000000P3oool0
0`000000oooo0?ooo`0;0?ooo`00a`3oool300000080oooo00<000000?ooo`3oool0o`3ooolf0?oo
o`80o`3o1P3oool30?l0o`<0oooo0`3o0?l<0?ooo`<0o`3o103oool40?l0o`P0oooo103o0?o]0?oo
o`<000002P3oool3000000030?ooo`000000oooo0080oooo00@000000?ooo`3oool000003@3oool0
0<@0oooo0`0000050?ooo`030000003oool0oooo0?l0oooo<`3oool30?l0o`H0oooo0P3o0?l30?oo
o`<0o`3o2`3oool40?l0o`@0oooo0`3o0?l80?ooo`@0o`3om03oool00`000000oooo0?ooo`0<0?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool02`3oool00<40oooo0`0000080?oo
o`030000003oool0oooo0?l0oooo<@3oool20?l0o`H0oooo0`3o0?l20?ooo`<0o`3o2`3oool30?l0
o`@0oooo103o0?l70?ooo`@0o`3o`P3oool2000003<0oooo0P00000?0?ooo`030000003oool00000
0080oooo00<000000?ooo`3oool02`3oool008@0oooo0`0000040?ooo`030000003oool0oooo0080
00000`3oool2000002T0oooo0`00003o0?oooc`0oooo0`3o0?l50?ooo`<0o`3o0P3oool30?l0o`/0
oooo0`3o0?l40?ooo`<0o`3o1`3oool40?l0ol<0oooo0`00o`0200000340oooo0P0000000`3oool0
00000?ooo`0;0?ooo`060000003oool0oooo0000003oool000000P3oool00`000000oooo0?ooo`0;
0?ooo`00Q@3oool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00<000000?oo
o`0000000P3oool00`000000oooo0?ooo`0S0?ooo`<00000o`3ooolm0?ooo`80o`3o1P3oool20?l0
o`80oooo0`3o0?l:0?ooo`@0o`3o0`3oool40?l0o`H0oooo103o0?o50?ooo`800?l0>@3oool00`00
0000oooo0?ooo`0;0?ooo`8000000`3oool2000000h0oooo00250?ooo`030000003oool0oooo00@0
000000L0oooo0000003oool0oooo0000003oool000000080oooo00<000000?ooo`3oool0803oool3
00000?l0oooo?P3oool20?l0o`D0oooo0`3o0?l20?ooo`80o`3o2P3oool30?l0o`<0oooo103o0?l6
0?ooo`@0o`3oaP3oool3003o00L0oooo0P00000a0?ooo`8000008P3oool008D0oooo00@000000?oo
o`3oool000000P3oool00`000000oooo000000020?ooo`030000003oool000000080oooo00<00000
0?ooo`3oool07@3oool300000?l0oooo?P3oool30?l0o`@0oooo0`3o0?l20?ooo`<0o`3o2@3oool3
0?l0o`<0oooo0`3o0?l60?ooo`@0o`3oa`3oool3003o00L0oooo0`00o`02000002h0oooo0`000000
0`3oool000000?ooo`0Q0?ooo`00Q@3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo
000000020?ooo`030000003oool000000080oooo00<000000?ooo`3oool06P3oool300000?l0oooo
?`3oool20?l0o`@0oooo0`3o0?l20?ooo`<0o`3o203oool40?l0o`80oooo103o0?l50?ooo`@0o`3o
b@3oool2003o00L0oooo0`00o`0b0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
803oool008@0oooo0P0000040?ooo`80000000L0oooo0000003oool0oooo0000003oool000000080
oooo00<000000?ooo`3oool05`3oool300000?l0oooo?`3oool30?l0o`@0oooo0P3o0?l20?ooo`<0
o`3o203oool30?l0o`<0oooo0`3o0?l50?ooo`@0o`3obP3oool3003o00H0oooo0`00o`0j0?ooo`80
00008@3oool008D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02000000<0oooo
0P00000G0?ooo`<00000o`3ooom00?ooo`80o`3o103oool30?l0o`040?ooo`3o0?l0o`3o0?l0o`P0
oooo0`3o0?l20?ooo`@0o`3o103oool40?l0ol`0oooo0P00o`060?ooo`<00?l0>`3oool300000280
oooo002Y0?ooo`@00000o`3ooolo0?ooo`<0o`3o0`3oool30?l0o`040?ooo`3o0?l0o`3o0?l0o`L0
oooo103o0?l00`3oool0o`3o0?l0o`020?l0o`<0oooo1@3o0?o=0?ooo`<00?l01@3oool3003o0100
oooo0P00000_0?ooo`030000003oool0oooo00T0oooo0P00000D0?ooo`00YP3oool3000000<0oooo
00<000000?ooo`3oool0o`3ooolk0?ooo`80o`3o103oool20?l0o`040?ooo`3o0?l0o`3o0?l0o`L0
oooo0`3o0?l20?ooo`<0o`3o0`3oool40?l0oll0oooo0`00o`050?ooo`<00?l04P3oool00`00o`00
00000000000^0?ooo`8000002P3oool010000000oooo0?ooo`00000C0?ooo`00X`3oool3000000H0
oooo00<000000?ooo`3oool0o`3ooolh0?ooo`<0o`3o0`3oool60?l0o`L0oooo0`3o0?l00`3oool0
o`3o0?l0o`020?l0o`80oooo103o0?oA0?ooo`800?l01@3oool3003o0180oooo0`00o`0_0?ooo`80
000000<0oooo0000003oool02@3oool010000000oooo0?ooo`00000C0?ooo`00X@3oool2000000T0
oooo00<000000?ooo`3oool0o`3ooolf0?ooo`80o`3o0`3oool30?l0o`030?ooo`3o0?l0o`3o00H0
oooo103o0?l0103oool0o`3o0?l0o`3o0?l20?ooo`@0o`3odP3oool3003o00@0oooo0`00o`0A0?oo
o`@00?l01P3oool2000002d0oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`00000C
0?ooo`00WP3oool300000?l0oooo@P3oool20?l0o`<0oooo0P3o0?l0103oool0o`3o0?l0o`3o0?l5
0?ooo`<0o`3o00<0oooo0?l0o`3o0?l00P3o0?l00`3oool0o`3o0?l0o`020?l0om@0oooo0P00o`05
0?ooo`800?l0403oool4003o00T0oooo00<00?l0000000000000;03oool2000000X0oooo00@00000
0?ooo`3oool000004`3oool009/0oooo0`00001H0?ooo`80o`00i`3oool30?l0o`80oooo1P3o0?l5
0?ooo`L0o`3o00<0oooo0?l0o`3o0?l00P3o0?oE0?ooo`<00?l0103oool3003o00l0oooo0`00o`09
0?ooo`@00?l0;@3oool2000000030?ooo`000000oooo00T0oooo00@000000?ooo`3oool000004`3o
ool009P0oooo0`00001G0?ooo`80o`00103oool30?l00>80oooo0P3o0?l20?ooo`H0o`3o103oool7
0?l0o`030?ooo`3o0?l0o`3o0080o`3oeP3oool3003o00@0oooo0`00o`0>0?ooo`@00?l0203oool4
003o03@0oooo00<000000?ooo`3oool02@3oool2000001@0oooo002E0?ooo`<00000G03oool30?l0
00@0oooo0`3o003L0?ooo`<0o`3o0P3oool50?l0o`@0oooo2`3o0?oH0?ooo`800?l0103oool3003o
00d0oooo1000o`070?ooo`D00?l0>03oool00`000000oooo0?ooo`0O0?ooo`00TP3oool3000005T0
oooo0P3o00070?ooo`<0o`00103oool30?l00=L0oooo0P3o0?l20?ooo`D0o`3o103oool:0?l0omT0
oooo0`00o`030?ooo`<00?l03@3oool3003o00L0oooo1000o`0l0?ooo`<00000803oool008l0oooo
0`00001I0?ooo`80o`000`3oool30?l000L0oooo0`3o00040?ooo`<0o`00d@3oool30?l0o`030?oo
o`3o0?l0o`3o00<0o`3o0`3oool:0?l0om/0oooo0P00o`030?ooo`<00?l0303oool4003o00H0oooo
1000o`0m0?ooo`<000000P3oool00`000000oooo0?ooo`0N0?ooo`00S03oool3000005h0oooo0`3o
00030?ooo`<0o`001`3oool30?l000@0oooo0`3o003<0?ooo`80o`3o0P3oool40?l0o`<0oooo2@3o
0?oL0?ooo`<00?l00P3oool3003o00`0oooo0`00o`060?ooo`@00?l0AP3oool00`000000oooo0?oo
o`0N0?ooo`00R@3oool4000006<0oooo0`3o00030?ooo`<0o`001`3oool30?l000@0oooo0`3o0036
0?ooo`<0o`3o00<0oooo0?l0o`3o0?l00`3o0?l20?ooo`P0o`3og@3oool3003o0080oooo0`00o`0;
0?ooo`@00?l01@3oool4003o04T0oooo0P00000P0?ooo`00QP3oool3000000<0oooo00<000000?oo
o`3oool0I03oool20?l000@0oooo0P3o00080?ooo`<0o`00103oool30?l00<40oooo0P3o0?l00`3o
ool0o`3o0?l0o`030?l0o`030?ooo`3o0?l0o`3o00H0o`3og`3oool2003o0080oooo0`00o`0:0?oo
o`@00?l01@3oool4003o04/0oooo0P0000000`3oool000000?ooo`0O0?ooo`00P`3oool3000000H0
oooo00<000000?ooo`3oool0IP3oool30?l000<0oooo0`3o00080?ooo`<0o`00103oool20?l00;d0
oooo0P3o0?l00`3oool0o`3o0?l0o`020?l0o`030?ooo`3o0?l0o`3o00D0o`3oh03oool3003o0080
oooo0P00o`0:0?ooo`<00?l01@3oool4003o0580oooo00<000000?ooo`3oool0203oool400000080
oooo0P00000>0?ooo`00P03oool3000000P0oooo00<000000?ooo`3oool0JP3oool30?l000<0oooo
0`3o00080?ooo`80o`00103oool30?l00;L0oooo1`3o0?l00`3oool0o`3o0?l0o`040?l0on80oooo
0P00o`020?ooo`<00?l0203oool4003o00<0oooo1@00o`1E0?ooo`8000002P3oool01P000000oooo
0?ooo`000000oooo00000080oooo00<000000?ooo`3oool02`3oool007d0oooo0`00000;0?ooo`03
0000003oool0oooo06d0oooo0P3o00040?ooo`80o`00203oool30?l000@0oooo0`3o002b0?ooo`/0
o`3oi03oool3003o00040?ooo`00o`000?l0003o00L0oooo1000o`030?ooo`@00?l0F@3oool00`00
0000oooo0000000;0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0;
0?ooo`00NP3oool3000000h0oooo00<000000?ooo`3oool0K`3oool30?l000<0oooo0`3o00080?oo
o`<0o`00103oool30?l00:`0oooo2P3o0?oU0?ooo`<00?l000@0oooo003o0000o`000?l01`3oool3
003o00<0oooo1000o`1O0?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`0;0?ooo`00M`3oool3000008H0oooo0`3o00030?ooo`<0o`00203oool3
0?l000@0oooo0`3o002W0?ooo`T0o`3oiP3oool2003o00040?ooo`00o`000?l0003o00H0oooo1000
o`020?ooo`@00?l0H`3oool2000000`0oooo00<000000?ooo`0000000P3oool00`000000oooo0?oo
o`0;0?ooo`00M03oool3000008`0oooo0`3o00030?ooo`<0o`00203oool30?l000@0oooo0`3o002Q
0?ooo`P0o`3oi`3oool6003o00H0oooo0`00o`020?ooo`@00?l0I@3oool2000000030?ooo`000000
oooo00P0oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`030000003oool0oooo00/0oooo
001a0?ooo`<00000TP3oool20?l000@0oooo0P3o00090?ooo`<0o`00103oool30?l009`0oooo1`3o
0?oX0?ooo`D00?l01@3oool4003o00030?ooo`00o`000?l000800?l0K03oool00`000000oooo0?oo
o`080?ooo`8000000`3oool2000000h0oooo001_0?ooo`800000U`3oool30?l000<0oooo0`3o0009
0?ooo`<0o`00103oool30?l005T0oooo0`00000j0?ooo`H0o`3oj@3oool5003o00@0oooo1000o`00
0`3oool00?l0003o0002003o06l0oooo0P00000O0?ooo`00K03oool3000009`0oooo0`3o00030?oo
o`<0o`002@3oool30?l000@0oooo0P3o001E0?ooo`8000000`3oool2000003@0oooo1`3o0?oY0?oo
o`D00?l0103oool8003o0700oooo0`0000000`3oool000000?ooo`0N0?ooo`00J@3oool400000:40
oooo0P3o00040?ooo`80o`002P3oool20?l000@0oooo0`3o001A0?ooo`8000001@3oool2000002l0
oooo1`3o0?o[0?ooo`@00?l00`3oool7003o07@0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0M0?ooo`00IP3oool3000000<0oooo00<000000?ooo`3oool0X@3oool30?l000<0oooo
0`3o00090?ooo`<0o`00103oool30?l004h0oooo0P0000060?ooo`800000:P3oool90?l0onX0oooo
1@00o`000`3oool00?l0003o0005003o07d0oooo0P00000N0?ooo`00H`3oool3000000H0oooo00<0
00000?ooo`3oool0Y03oool30?l000<0oooo0`3o00090?ooo`<0o`00103oool30?l004X0oooo0P00
00070?ooo`8000009P3oool:0?l0on/0oooo1000o`000`3oool00?l0003o0004003o07l0oooo0`00
000O0?ooo`00H03oool3000000T0oooo00<000000?ooo`3oool0Y`3oool20?l000@0oooo0`3o0009
0?ooo`<0o`00103oool30?l004L0oooo0P0000060?ooo`040000002:DXL0000000000240oooo2`3o
0?o[0?ooo`X00?l0Q@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo008000003@3o
ool005d0oooo0`00002h0?ooo`<0o`00103oool20?l000X0oooo0`3o00040?ooo`<0o`00A03oool2
000000H0oooo00<0000008YBQ`0000000P00000L0?ooo`@0o`3o00<0oooo0?l0o`3o0?l01P3o0?o[
0?ooo`P00?l0R@3oool2000000`0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0:
0?ooo`00FP3oool300000;h0oooo0`3o00030?ooo`<0o`002P3oool30?l000@0oooo0`3o00110?oo
o`8000001P3oool01@000000RU:70000003oool0000001P0oooo103o0?l00`3oool0o`3o0?l0o`07
0?l0on/0oooo1`00o`2;0?ooo`80000000<0oooo0000003oool0203oool4000000050?ooo`000000
oooo0?ooo`000000303oool005L0oooo0`0000340?ooo`80o`00103oool30?l000X0oooo0`3o0004
0?ooo`<0o`00?P3oool00`000000oooo0?ooo`040?ooo`050000002:DXL0RU:70000003oool00P00
000B0?ooo`D0o`3o0P3oool90?l0on/0oooo1@00o`2C0?ooo`030000003oool0oooo00L0oooo00H0
00000?ooo`3oool000000?ooo`0000020?ooo`030000003oool0oooo00X0oooo001D0?ooo`<00000
b@3oool30?l000@0oooo0P3o000;0?ooo`<0o`00103oool30?l003/0oooo00<000000?ooo`3oool0
103oool010000000RU:708YBQ`0000020?ooo`030000003oool0oooo00`0oooo103o0?l30?ooo`/0
o`3oZP3oool4000003`0oooo1000o`2F0?ooo`8000002P3oool01@000000oooo0000003oool00000
0080oooo00<000000?ooo`3oool02P3oool00540oooo0`00003?0?ooo`<0o`000`3oool30?l000/0
oooo0`3o00040?ooo`80o`00>@3oool2000000D0oooo00@0000008YBQ`2:DXL000000P3oool20000
00T0oooo103o0?l30?ooo`H0o`3o00<0oooo0?l0o`3o0?l0103o0?n/0?ooo`030000003oool0oooo
00800000=`3oool5003o09L0oooo0P0000000`3oool000000?ooo`0:0?ooo`80000000D0oooo0000
003oool0oooo0000000<0?ooo`00CP3oool300000=D0oooo0`3o00030?ooo`<0o`002`3oool20?l0
00@0oooo0`3o000f0?ooo`030000002W`>/0000000<0oooo00D0000008YBQ`2:DXL0RU:700000003
0?ooo`030000003oool0oooo00<0oooo103o0?l40?ooo`H0o`3o00<0oooo0?l0o`3o0?l0103o0?n^
0?ooo`030000003oool0oooo0080oooo0P00000b0?ooo`H00?l0W@3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo008000003@3oool004/0oooo0`00003K0?ooo`80o`00103oool30?l0
00X0oooo0`3o00040?ooo`<0o`00<`3oool2000000050:O0j`00000000000?ooo`0000000`2:DXL0
10000000oooo0?ooo`3oool2000000@0o`3o103oool70?l0o`030?ooo`3o0?l0o`3o00D0o`3o/03o
ool00`000000oooo0?ooo`030?ooo`800000;@3oool8003o09l0oooo00<000000?ooo`3oool0703o
ool004P0oooo0`0000020?ooo`030000003oool0oooo0=/0oooo0`3o00040?ooo`80o`002`3oool3
0?l000@0oooo0`3o000`0?ooo`8000000`2W`>/2000000<0RU:700<000000?ooo`3o0?l00`3o0?l5
0?ooo`H0o`3o0`3oool60?l0ok80oooo0P0000050?ooo`800000:@3oool9003o0:40oooo0`00000M
0?ooo`00A@3oool3000000D0oooo00<000000?ooo`3oool0gP3oool30?l000<0oooo0`3o000;0?oo
o`<0o`00103oool30?l002d0oooo0P0000040:O0j`800000103o0?l30?ooo`030000003oool0o`3o
00H0o`3o0`3oool70?l0ok@0oooo0P0000040?ooo`040000002=EXX00000000002<0oooo2`00o`2Q
0?ooo`<0000000<0oooo0000003oool07@3oool000P0oooo0`0000000`3oool00000000000020000
0080oooo0P0000030?ooo`800000:@3oool3000000P0oooo00<000000?ooo`3oool0h@3oool20?l0
00@0oooo0`3o000;0?ooo`<0o`00103oool30?l002X0oooo0`0000000`2W`>/0o`3o0?l0o`020000
0080RU:700<000000?ooo`3oool0203o0?l30?ooo`L0o`3o]`3oool2000000@0oooo00<0000008eF
RP0000000P00000N0?ooo`d00?l0Y`3oool00`000000oooo0?ooo`0L0?ooo`002@3oool010000000
oooo0?ooo`0000020?ooo`030000003oool000000080oooo00<000000?ooo`0000000P3oool00`00
0000oooo0?ooo`0T0?ooo`800000l@3oool30?l000@0oooo0P3o000<0?ooo`<0o`00103oool30?l0
02L0oooo00@0o`3o000000000000o`3o0`2W`>/20000000508YBQ`3o0?l0o`3o0?l0o`3oool00`3o
0?l40?ooo`P0o`3o^@3oool2000000@0oooo00<0000008eFRP0000000P00000J0?ooo`P00?l000<0
oooo003o0000o`000`00o`2Z0?ooo`8000007@3oool000T0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`060000003oool0oooo0000003oool000000P3oool00`000000oooo0?ooo`0Q0?ooo`<0
0000mP3oool30?l000<0oooo0`3o000<0?ooo`<0o`00103oool30?l00240oooo0`3o0?l00`3oool0
000000000002000000060:O0j`3o0?l000000000003o0?l000000`3o0?l20?ooo`800000203o0?nl
0?ooo`8000000`3oool01@000000SEJ:08eFRP000000oooo008000005@3oool4003o00040?ooo`00
o`000?l0003o0080oooo1P00o`2Z0?ooo`80000000<0oooo0000003oool0703oool000T0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`030000003oool000000080oooo
00<000000?ooo`3oool07P3oool3000005L0oooo0`000?nR0?ooo`80o`00103oool30?l000`0oooo
0`3o00040?ooo`80o`00703oool30?l0o`@0oooo0`0000020?l0o`050:O0j`3o0?l000000000003o
0?l0103oool30?l0o`040?ooo`3o0?l0o`3o0?ooo`80o`3o_P3oool2000000<0oooo00D0000008eF
RP2=EXX000000?ooo`0200000140oooo1000o`000`3oool00?l0003o0002003o0080oooo1P00o`2`
0?ooo`030000003oool0oooo01/0oooo00090?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`0000000P3oool00`000000oooo000000020?ooo`030000003oool0oooo01/0oooo0`00001F0?oo
o`80003o1@3oool30000oj40oooo0`3o00040?ooo`<0o`00303oool20?l000@0oooo0`3o000F0?oo
o`<0o`3o103oool30?l0o`@000000P3o0?l30:O0j`8000000`3o0?l00`3oool0o`3o0?l0o`040?l0
ol00oooo0`0000020?ooo`040000002=EXX0SEJ:00000080oooo0P00000<0?ooo`@00?l00P3oool3
003o00<0oooo0`00o`000`3oool00?l0003o002c0?ooo`030000003oool0oooo01/0oooo00080?oo
o`8000000P3oool01P000000oooo0?ooo`000000oooo00000080oooo00<000000?ooo`0000000P3o
ool00`000000oooo0?ooo`0H0?ooo`<00000F`3oool30000o`D0oooo0`000?nQ0?ooo`<0o`00103o
ool20?l000`0oooo0`3o00040?ooo`<0o`003`3oool40?l0o`@0oooo0`3o0?l00`3oool0o`3o0?l0
o`0500000080Yl3[0P2:DXL3000000<0o`3o00<0oooo0?l0o`3o0?l0``3oool300000080oooo00@0
000008eFRP2=EXX000000P3oool2000000P0oooo1000o`020?ooo`@00?l0103oool2003o00040?oo
o`00o`000?l0003o0=<0oooo00090?ooo`040000003oool0oooo0?ooo`8000000`3oool2000000<0
oooo0P00000H0?ooo`<00000F03oool20000o`L0oooo0`000?l50?ooo`<0003oX@3oool20?l000@0
oooo0`3o000<0?ooo`<0o`00103oool30?l000T0oooo0`3o0?l50?ooo`<0o`3o00@0oooo0?l0o`3o
0?l0o`3o0`3oool2000000030?l0o`000000RU:700<0RU:70`000000103oool0o`3o0?l0o`3o0?l2
00000<<0oooo0P000000102W`>/000000?ooo`00000208eFRP040000003oool0oooo0?ooo`800000
0P3oool5003o0080oooo1000o`050?ooo`<00?l000<0oooo003o0000o`00eP3oool002h0oooo0`00
001G0?ooo`80003o103oool30000o`L0oooo0`000?l50?ooo`<0003oX03oool30?l000@0oooo0`3o
000<0?ooo`<0o`00103oool30?l000<0oooo0`3o0?l50?ooo`<0o`3o00@0oooo0?l0o`3o0?l0o`3o
1@3oool01@3o0?l000000000003oool0000000@0RU:700<000000:O0j`2W`>/00P0000020?ooo`80
0000``3oool200000080Yl3[00D0000008eFRP2=EXX0SEJ:000000030?ooo`@00?l0103oool3003o
00H0oooo0`00o`00103oool00?l0003o0000o`3H0?ooo`00:`3oool4000005/0oooo0`000?l40?oo
o`<0003o1`3oool30000o`D0oooo0`000?nP0?ooo`<0o`00103oool20?l000d0oooo0`3o00030?oo
o`@0o`3o103oool40?l0o`040?ooo`3o0?l0o`3o0?l0o`D0oooo0`3o0?l01@3oool000000000003o
0?l0000000@0RU:700<000000?l0o`2W`>/00P0000030?ooo`030000003oool0oooo0<40oooo0P00
00030:O0j`80000000<0SEJ:003o0000o`000P00o`0010000000oooo0000003oool4003o00H0oooo
0`00o`00103oool00?l0003o0000o`3K0?ooo`00:03oool3000000<0oooo00<000000?ooo`3oool0
G03oool30000o`@0oooo0`000?l70?ooo`<0003o1@3oool30000oj00oooo0`3o00030?ooo`<0o`00
3@3oool30?l0o`@0oooo00@0o`000?l0o`3o0?l0o`3o0P3oool30?l0o`D0oooo0`3o0?l20?ooo`80
o`3o00@000000?ooo`0000000000102:DXL2000000<0Yl3[00@000000?ooo`3oool00000a03oool2
000000060:O0j`00o`00000000000000o`0000000`3oool4003o00L0oooo0`00o`020?ooo`800?l0
gP3oool002D0oooo0`0000060?ooo`030000003oool0oooo05l0oooo0`000?l40?ooo`<0003o1`3o
ool30000o`D0oooo0`000?nP0?ooo`80o`00103oool30?l000L0oooo0`3o0?l30?ooo`80o`000`3o
0?l00`3oool0o`3o0?l0o`020?l0o`D0oooo0`3o0?l20?ooo`<0o`3o0`3oool3000000@0RU:700<0
00000?ooo`0000000`2W`>/00`000000oooo000000320?ooo`<00?l000<00000003o002W`>/00P2W
`>/2000000<00?l000<0oooo0000000000001@3oool3003o0080oooo0`00o`3P0?ooo`008P3oool3
000000T0oooo00<000000?ooo`3oool0HP3oool20000o`D0oooo0`000?l70?ooo`<0003o1@3oool3
0000oil0oooo0`3o00040?ooo`<0o`0000@0oooo0?l0o`3o0?l0o`3o1@3oool30?l0o`040?ooo`3o
0?l0o`3o0?l0o`@0oooo0P3o00030?l0o`80oooo0`3o0?l50?ooo`040?l0o`0000000000000000@0
RU:700<000000?ooo`3oool00P000000102W`>/000000?ooo`00002o0?ooo`<00?l00`3oool00`00
0000Yl3[00000002003o00<00000103oool2000000040?ooo`00o`000?l0003o00<0oooo0P00o`3S
0?ooo`007`3oool3000007<0oooo0`000?l50?ooo`<0003o1`3oool30000o`D0oooo0`000?nO0?oo
o`<0o`0000<0oooo0?l0o`3o0?l00P3o0?l0103o0000oooo0?ooo`3oool40?l0o`040?ooo`3o0?l0
o`3o0?l0o`<0oooo0P3o0000103oool0o`3o0?l0o`3o0?l20?l000<0o`3o1@3oool30?l0o`80oooo
0`00000308YBQ`030000003oool0oooo0080oooo1@00002k0?ooo`<00?l01@3oool01000o`000000
00000000o`040:O0j`030000003oool0oooo0080oooo0`00o`030?ooo`<00?l0i@3oool001`0oooo
0`00001i0?ooo`<0003o1@3oool30000o`L0oooo0`000?l50?ooo`<0003oW@3oool30?l0o`030?l0
003oool0oooo0080oooo0`3o0?l20?ooo`<0o`3o1P3oool30?l0o`80o`000`3o0?l01@3oool0o`00
0?l0003o0000oooo00<0o`3o1@3oool3000000<0RU:700<000000?ooo`3oool0103oool300000;L0
oooo1000o`050?ooo`<00?l000<0oooo000000000000102W`>/00`2=EXX0000000000003003o0003
0?ooo`000000oooo00<00?l0j03oool001T0oooo0`00001o0?ooo`<0003o1@3oool20000o`P0oooo
0`000?l50?ooo`<0003oU`3oool30?l0o`@0oooo00@0o`000?l0o`3o0?l0o`3o0P3oool30?l0o`03
0?l0003oool0oooo00<0oooo0`3o0?l20?ooo`<0o`3o0`3o00020?ooo`<0o`3o0P3o00070?ooo`80
00000`2:DXL00`000000oooo0?ooo`050?ooo`800000]03oool3003o00H0oooo0`00o`040?ooo`<0
0000102=EXX2000000@0oooo0P00o`3[0?ooo`005P3oool3000008D0oooo0`000?l40?ooo`<0003o
203oool30000o`D0oooo0`000?nA0?ooo`<0o`3o1@3oool30?l0o`80oooo0`3o0?l40?ooo`80o`00
0`3o0?l20?ooo`<0o`3o1@3oool30?l0o`030?l0003oool0oooo0080oooo0`3o00050?ooo`800000
0P2:DXL00`000000oooo0?ooo`050?ooo`800000/03oool4003o00D0oooo1000o`080?ooo`800000
102=EXX4000000800?l000<000000?ooo`3oool0jP3oool001<0oooo0`00002;0?ooo`80003o1@3o
ool30000o`P0oooo0`000?l50?ooo`<0003oRP3oool40?l0o`D0oooo0`3o0?l20?ooo`<0o`3o0`3o
ool20?l000040?ooo`3o0?l0o`3o0?l0o`80o`000`3o0?l50?ooo`<0o`3o103oool30?l000@0oooo
0`3o00030?ooo`040000002:DXL0RU:7000000L0oooo00<000000?ooo`3oool0[03oool3003o00H0
oooo0`00o`090?ooo`<00?l00P00000408eFRP040000002W`>/00000000000<0oooo00<000000?oo
o`3oool0j@3oool00100oooo0`00002@0?ooo`<0003o1@3oool30000o`P0oooo0P000?l60?ooo`<0
003o@@3oool00`000000oooo0?ooo`100?ooo`<0o`3o1@3oool40?l0o`030?ooo`3o0?l0o`3o0080
o`3o1P3oool30?l0o`80o`000`3o0?l01@3oool0o`000?l0003o0000oooo00<0o`3o2P3oool20?l0
00D0oooo0`3o00020000000308YBQ`000000oooo00H0oooo00<000000?ooo`3oool0Z@3oool3003o
00H0oooo0`00o`090?ooo`<00?l00`3oool2000000@0SEJ:00@000000:O0j`2W`>/000000`3oool0
0`000000oooo0?ooo`3Y0?ooo`003`3oool00`000000oooo0?ooo`2D0?ooo`<0003o1@3oool30000
o`L0oooo0`000?l60?ooo`<0003o?P3oool00`000000oooo0?ooo`0m0?ooo`<0o`3o1@3oool30?l0
o`80oooo0`3o0?l70?ooo`<0o`3o0P3oool30?l0o`<0o`000P3oool30?l0o`80o`003@3oool30?l0
00D0oooo00@0o`0000000000000000001`3oool00`000000oooo0?ooo`2U0?ooo`@00?l01@3oool4
003o00T0oooo0`00o`050?ooo`800?l000<0000008eFRP2=EXX00P2=EXX01@000000Yl3[0:O0j`2W
`>/000000080oooo00<000000?ooo`3oool0j@3oool000l0oooo00<000000?ooo`3oool0U`3oool3
0000o`D0oooo0`000?l70?ooo`<0003o1P3oool30000oc/0oooo0P00000j0?ooo`@0o`3o1@3oool3
0?l0o`80oooo0`3o0?l70?ooo`<0o`3o0P3oool30?l0o`D0oooo0`3o0?l50?ooo`80o`003P3oool3
0?l000@0oooo0P0000000`3o0000oooo0?ooo`030?ooo`030000003oool0oooo0:<0oooo0`00o`06
0?ooo`<00?l02P3oool3003o00D0oooo0`00o`020?ooo`030000002=EXX0SEJ:0080SEJ:0P000003
0:O0j`030000003oool000000>/0oooo000?0?ooo`030000003oool0oooo09X0oooo0P000?l60?oo
o`<0003o1`3oool30000o`H0oooo0`000?lh0?ooo`800000=`3oool30?l0o`H0oooo0`3o0?l20?oo
o`<0o`3o1`3oool30?l0o`80oooo0`3o0?l50?ooo`<0o`3o0`3oool30?l000@0oooo0`3o000>0?oo
o`<0o`000P3oool2000000<0o`000P3oool00`000000oooo0?ooo`2P0?ooo`<00?l01P3oool3003o
00X0oooo0`00o`050?ooo`<00?l01@3oool00`000000SEJ:08eFRP0208eFRP040000003oool00000
00000080Yl3[0P00003[0?ooo`003`3oool00`000000oooo0?ooo`2L0?ooo`<0003o1P3oool30000
o`L0oooo0`000?l60?ooo`@0003o=03oool2000003@0oooo0`3o0?l60?ooo`<0o`3o0P3oool30?l0
o`L0oooo0`3o0?l20?ooo`<0o`3o1@3oool30?l0o`T0oooo0`3o00040?ooo`<0o`003P3oool30?l0
00<0000000@0oooo0?l0003o00000000WP3oool4003o00D0oooo1000o`0:0?ooo`<00?l01@3oool3
003o00T0oooo00D0000008eFRP2=EXX0SEJ:000000030?ooo`D00000jP3oool000l0oooo00<00000
0?ooo`3oool0W`3oool30000o`H0oooo0P000?l80?ooo`<0003o1`3oool30000oc40oooo0P00000a
0?ooo`<0o`3o1@3oool40?l0o`80oooo0`3o0?l70?ooo`<0o`3o0P3oool30?l0o`D0oooo0`3o0?l?
0?ooo`80o`001@3oool30?l000h0oooo0`3o0003000000040?ooo`3o0000o`000?l009P0oooo0`00
o`060?ooo`<00?l02`3oool3003o00D0oooo0`00o`0<0?ooo`050000002=EXX0SEJ:08eFRP000000
1P3oool200000>X0oooo000?0?ooo`030000003oool0oooo0:80oooo0`000?l50?ooo`<0003o203o
ool30000o`L0oooo0`000?l^0?ooo`800000;@3oool40?l0o`D0oooo0`3o0?l20?ooo`@0o`3o1`3o
ool30?l0o`80oooo0`3o0?l50?ooo`<0o`3o503oool30?l000D0oooo0P3o000?0?ooo`80o`001@3o
ool30?l00940oooo1000o`060?ooo`<00?l02`3oool3003o00D0oooo0`00o`0?0?ooo`8000000P2=
EXX00`000000oooo0?ooo`040?ooo`800000jP3oool00;L0oooo0`000?l50?ooo`<0003o203oool3
0000o`L0oooo0`000?l[0?ooo`800000:P3oool30?l0o`H0oooo0`3o0?l20?ooo`<0o`3o203oool3
0?l0o`80oooo0`3o0?l50?ooo`<0o`3o6P3oool30?l000@0oooo0`3o000>0?ooo`<0o`001@3oool3
0?l008/0oooo0`00o`060?ooo`@00?l02`3oool3003o00D0oooo0`00o`0C0?ooo`040000002=EXX0
SEJ:000000H0oooo0P00003Z0?ooo`00^P3oool20000o`H0oooo0`000?l80?ooo`<0003o1`3oool3
0000obP0oooo0P00000W0?ooo`<0o`3o1P3oool30?l0o`80oooo0`3o0?l80?ooo`<0o`3o0P3oool3
0?l0o`D0oooo0`3o0?lP0?ooo`80o`001@3oool30?l000h0oooo0`3o00050?ooo`80o`00QP3oool3
003o00H0oooo0`00o`0<0?ooo`<00?l01@3oool3003o01H0oooo0P0000000`2=EXX000000?ooo`05
0?ooo`800000jP3oool00;`0oooo0`000?l60?ooo`<0003o203oool30000o`L0oooo0`000?lU0?oo
o`800000903oool30?l0o`H0oooo0`3o0?l20?ooo`<0o`3o1`3oool40?l0o`80oooo0`3o0?l50?oo
o`<0o`3o9@3oool30?l000D0oooo0P3o000?0?ooo`<0o`00103oool30?l003X0oooo0P0000130?oo
o`@00?l01P3oool3003o00`0oooo0`00o`050?ooo`<00?l06P3oool00`000000SEJ:000000060?oo
o`800000jP3oool00;l0oooo0`000?l60?ooo`<0003o203oool30000o`L0oooo0`000?lQ0?ooo`03
0000003oool000000200oooo103o0?l50?ooo`@0o`3o0P3oool30?l0o`L0oooo0`3o0?l30?ooo`<0
o`3o1@3oool30?l0ob/0oooo0`3o00040?ooo`<0o`003`3oool30?l000@0oooo0`3o000g0?ooo`80
0000@03oool3003o00H0oooo1000o`0<0?ooo`<00?l01@3oool3003o01h0oooo0P0000060?ooo`80
0000jP3oool00<80oooo0`000?l60?ooo`<0003o203oool30000o`L0oooo0`000?lN0?ooo`<00000
7@3oool30?l0o`H0oooo0`3o0?l30?ooo`<0o`3o1`3oool30?l0o`<0oooo0`3o0?l50?ooo`<0o`3o
<@3oool30?l000@0oooo0`3o000?0?ooo`80o`001@3oool30?l003@0oooo0P00000l0?ooo`@00?l0
1P3oool3003o00d0oooo0`00o`050?ooo`<00?l08P3oool2000000@0oooo0P00003[0?ooo`00a@3o
ool20000o`L0oooo0`000?l80?ooo`<0003o1`3oool30000oa/0oooo00<000000?ooo`0000006P3o
ool30?l0o`H0oooo0`3o0?l30?ooo`<0o`3o1`3oool30?l0o`<0oooo0`3o0?l50?ooo`<0o`3o=`3o
ool20?l000D0oooo0`3o000>0?ooo`<0o`001@3oool30?l00340oooo0P00000i0?ooo`<00?l01`3o
ool3003o00`0oooo1000o`050?ooo`<00?l09P3oool2000000<0oooo0P00003[0?ooo`00a`3oool3
0000o`L0oooo0`000?l80?ooo`80003o203oool30000oaP0oooo00<000000?ooo`0000005`3oool3
0?l0o`H0oooo0`3o0?l20?ooo`@0o`3o1`3oool30?l0o`<0oooo0`3o0?l50?ooo`<0o`3o?03oool3
0?l000D0oooo0P3o000?0?ooo`<0o`001@3oool30?l002d0oooo00<000000?ooo`000000=P3oool3
003o00H0oooo1000o`0<0?ooo`<00?l01P3oool3003o02X0oooo0P0000000`3oool000000000003/
0?ooo`00bP3oool30000o`L0oooo0P000?l80?ooo`<0003o203oool30000oaD0oooo00<000000?oo
o`0000004`3oool40?l0o`D0oooo103o0?l20?ooo`<0o`3o203oool30?l0o`<0oooo0`3o0?l50?oo
o`<0o`3o@P3oool30?l000@0oooo0`3o000?0?ooo`<0o`001@3oool30?l002X0oooo0`00000b0?oo
o`@00?l01P3oool3003o00d0oooo0`00o`050?ooo`@00?l0;`3oool00`000000oooo0?ooo`3/0?oo
o`00c@3oool30000o`H0oooo0`000?l80?ooo`<0003o203oool30000oa80oooo0`00000@0?ooo`<0
o`3o1P3oool30?l0o`<0oooo0`3o0?l80?ooo`<0o`3o0`3oool30?l0o`D0oooo0`3o0?m80?ooo`80
o`001@3oool30?l000l0oooo0`3o00050?ooo`<0o`009`3oool00`000000oooo0000000_0?ooo`<0
0?l01P3oool4003o00d0oooo0`00o`050?ooo`<00?l0o`3ooolS0?ooo`00d03oool20000o`L0oooo
0`000?l80?ooo`<0003o203oool30000o`l0oooo0`00000=0?ooo`<0o`3o1P3oool30?l0o`<0oooo
0`3o0?l80?ooo`<0o`3o0`3oool30?l0o`D0oooo0`3o0?m=0?ooo`<0o`001@3oool30?l000l0oooo
0`3o00050?ooo`80o`009@3oool00`000000oooo0000000/0?ooo`<00?l01P3oool3003o00h0oooo
0`00o`050?ooo`<00?l0o`3ooolV0?ooo`00dP3oool30000o`L0oooo0`000?l80?ooo`<0003o203o
ool30000o``0oooo0`0000090?ooo`@0o`3o1P3oool30?l0o`<0oooo0`3o0?l80?ooo`<0o`3o0`3o
ool30?l0o`D0oooo0`3o0?mC0?ooo`<0o`001@3oool20?l00100oooo0P3o00050?ooo`<0o`008P3o
ool00`000000oooo0000000X0?ooo`@00?l01P3oool3003o00h0oooo0`00o`050?ooo`<00?l0o`3o
oolY0?ooo`00e@3oool30000o`L0oooo0`000?l80?ooo`<0003o203oool30000o`T0oooo0`000006
0?ooo`<0o`3o1`3oool30?l0o`<0oooo0`3o0?l80?ooo`<0o`3o0`3oool30?l0o`D0oooo0`3o0?mI
0?ooo`80o`001@3oool30?l000l0oooo0`3o00050?ooo`<0o`007`3oool3000002D0oooo0`00o`06
0?ooo`@00?l03P3oool3003o00D0oooo0`00o`3o0?ooob`0oooo003H0?ooo`<0003o1`3oool30000
o`P0oooo0`000?l80?ooo`<0003o1P3oool3000000<0oooo0`3o0?l60?ooo`@0o`3o0P3oool40?l0
o`P0oooo0`3o0?l30?ooo`<0o`3o1@3oool30?l0oeh0oooo0`3o00050?ooo`<0o`003`3oool30?l0
00D0oooo0`3o000L0?ooo`<000008@3oool4003o00H0oooo0`00o`0?0?ooo`<00?l01@3oool3003o
0?l0oooo;`3oool00=/0oooo0`000?l70?ooo`<0003o203oool30000o`P0oooo0`000?l30?ooo`<0
00000`3o0?l60?ooo`<0o`3o0`3oool30?l0o`T0oooo0`3o0?l30?ooo`<0o`3o1@3oool30?l0of@0
oooo0`3o00050?ooo`<0o`003`3oool30?l000D0oooo0`3o000I0?ooo`<000007P3oool3003o00L0
oooo0`00o`0?0?ooo`<00?l01@3oool3003o0?l0oooo<P3oool00=h0oooo0P000?l80?ooo`<0003o
203oool30000o`P0oooo0`000?l00`000000o`3o0?l0o`060?ooo`<0o`3o0`3oool30?l0o`T0oooo
0`3o0?l30?ooo`<0o`3o1@3oool30?l0ofX0oooo0P3o00060?ooo`80o`00403oool30?l000D0oooo
0`3o000F0?ooo`<000006`3oool3003o00H0oooo1000o`0?0?ooo`<00?l01@3oool3003o0?l0oooo
=@3oool00>00oooo0`000?l80?ooo`80003o2@3oool30000o`P0oooo0`0000060?l0o`<0oooo0`3o
0?l90?ooo`<0o`3o0`3oool30?l0o`D0oooo0`3o0?m_0?ooo`<0o`001@3oool30?l00100oooo0P3o
00060?ooo`<0o`004`3oool3000001L0oooo1000o`060?ooo`<00?l0403oool3003o00D0oooo0`00
o`3o0?ooocP0oooo003S0?ooo`<0003o1`3oool30000o`T0oooo0`000?l50?ooo`<000002@3o0?l9
0?ooo`<0o`3o0`3oool30?l0o`D0oooo0`3o0?me0?ooo`<0o`001@3oool30?l000l0oooo0`3o0006
0?ooo`80o`004@3oool3000001@0oooo0`00o`070?ooo`<00?l0403oool3003o00D0oooo0`00o`3o
0?oooc/0oooo003V0?ooo`<0003o1`3oool30000o`T0oooo0`000?l20?ooo`030000003o0?l0o`3o
00<0oooo1P3o0?l60?ooo`<0o`3o0`3oool30?l0o`D0oooo0`3o0?mk0?ooo`80o`001P3oool30?l0
00l0oooo0`3o00050?ooo`<0o`003P3oool300000140oooo0`00o`060?ooo`@00?l0403oool3003o
00D0oooo0`00o`3o0?oooch0oooo003Y0?ooo`80003o203oool30000o`T0oooo0P000?l3000000<0
o`3o103oool20000o`H0o`3o0`3oool30?l0o`D0oooo0`3o0?n00?ooo`<0o`001P3oool20?l00100
oooo0`3o00050?ooo`<0o`002`3oool3000000d0oooo1000o`060?ooo`<00?l04@3oool3003o00D0
oooo0`00o`3o0?oood40oooo003[0?ooo`<0003o203oool30000o`P0oooo00<000000?l0o`3o0?l0
0`3oool30?l0o`<0oooo2@3o0?l50?ooo`<0o`3oQP3oool30?l000D0oooo0`3o000@0?ooo`<0o`00
1@3oool30?l000P0oooo0`00000:0?ooo`<00?l01`3oool3003o0100oooo1000o`050?ooo`<00?l0
o`3ooom40?ooo`00kP3oool30000o`P0oooo0`000?l50?ooo`<000000`000?l30?ooo`<0o`3o0`3o
ool60?l0o`80oooo0`3o0?n<0?ooo`80o`001P3oool30?l00100oooo0`3o00050?ooo`<0o`001@3o
ool3000000H0oooo1000o`060?ooo`@00?l0403oool3003o00H0oooo0`00o`3o0?ooodL0oooo003a
0?ooo`<0003o203oool30000o`80oooo0`0000030?ooo`<0o`3o0`3oool30?l0o`@0oooo00<0003o
0?l0o`3o0?l00P3o0?n@0?ooo`<0o`001P3oool30?l00100oooo0P3o00060?ooo`<0o`000P3oool3
000000<0oooo0`00o`070?ooo`<00?l04@3oool3003o00H0oooo0`00o`3o0?ooodX0oooo003d0?oo
o`<0003o203oool20000o`<000000`3o0?l30?ooo`<0o`3o0`3oool50?l0o`80oooo0P000?l30?l0
oi00oooo0`3o00060?ooo`80o`00403oool30?l000H0oooo0`3o0002000000<00?l01`3oool3003o
0140oooo0`00o`050?ooo`@00?l0o`3ooom=0?ooo`00m`3oool20000o`P0oooo00<000000?l0o`3o
0?l00`3oool30?l0o`<0oooo0P000?l30?l0o`040?ooo`3o0?l0o`3o0?l0o`@0oooo0P000?l30?l0
oi00oooo0P3o00060?ooo`<0o`00403oool30?l000@0oooo00@0o`0000000000o`000?l01P3oool4
003o0140oooo0`00o`050?ooo`<00?l0o`3ooomA0?ooo`00n@3oool30000o`D0oooo0`0000030?l0
o`D0oooo0`3o0?l0103oool0003o0000o`000?l30?ooo`<0o`3o103oool20000o`<0o`3oS`3oool3
0?l000H0oooo0`3o000@0?ooo`@0o`0000@0oooo00000000000000000`3oool3003o0180oooo0`00
o`050?ooo`<00?l0o`3ooomD0?ooo`00o03oool30000o`80oooo00<000000?l0o`3o0?l00`3oool5
0?l0o`L0oooo0`000?l30?ooo`<0o`3o103oool20000o`<0o`3oS`3oool30?l000H0oooo0P3o000<
0?ooo`<0o`000P3oool30?l0008000000`00o`0B0?ooo`<00?l01@3oool3003o0?l0ooooE`3oool0
0?l0oooo0P000?l3000000D0o`3o00@0oooo0?l0o`3o0?l0o`3o2@3oool30000o`<0oooo0`3o0?l4
0?ooo`80003o0`3o0?n?0?ooo`<0o`001@3oool30?l000D0oooo103o00060?ooo`040?l000000000
o`00003o0180oooo0`00o`050?ooo`<00?l0o`3ooomJ0?ooo`00o`3oool20?ooo`8000000`3o0?l0
103oool0o`3o0?l0o`3o0?l30?ooo`<0o`3o2@3oool30000o`<0oooo0`3o0?l40?ooo`80003o0P3o
0?n@0?ooo`80o`001P3oool50?l000L0oooo0`3o0000103oool0000000000000000?0?ooo`<00?l0
1@3oool3003o0?l0ooooG@3oool00?l0oooo0P3oool00`000000o`3o000000030000o`<0oooo0`3o
0?l20?ooo`040000o`3o0?l0o`3o0?l0o`T0oooo0`000?l30?ooo`<0o`3o103oool010000?l0o`3o
0?l0o`3o0?n?0?ooo`<0o`0000<0oooo0?l0003o00000P3o0000103oool0o`000?l0003o00030?oo
o`<0o`00103oool3000000`0oooo0`00o`050?ooo`<00?l0o`3ooomP0?ooo`00o`3oool20?ooo`<0
00000`3o0?l30000o`<0oooo0P3o0?l30?ooo`040000o`3o0?l0o`3o0?l0o`T0oooo0`000?l30?oo
o`<0o`3o103oool010000?l0o`3o0?l0o`3o0?n=0?ooo`D0o`001@3oool40?l000L0oooo0`000009
0?ooo`<00?l01@3oool3003o0?l0ooooH`3oool00?l0oooo0P3oool3000000<0oooo0`3o0?l30000
o`80oooo0`3o0?l30?ooo`030000o`3o0?l0o`3o00X0oooo0`000?l30?ooo`80o`3o1@3oool01000
0?l0o`3o0?l0o`3o0?n70?ooo`<0o`001@3oool50?l00003003o003oool0oooo00<0o`001@3oool3
000000H0oooo0`00o`050?ooo`<00?l0o`3ooomV0?ooo`00o`3oool20?ooo`<000001P3oool30?l0
o`80003o0`3oool30?l0o`<0oooo0`3o0?l:0?ooo`<0003o0P3oool30?l0o`D0oooo00@0003o0?l0
o`3o0?l0o`3oP03oool40?l000H0oooo1`3o00060?ooo`<0o`000P3oool3000000<0oooo0`00o`05
0?ooo`<00?l0o`3ooomY0?ooo`00o`3oool20?ooo`<000002@3oool20?l0o`<0003o0`3oool30?l0
o`<0oooo0`3o0?l:0?ooo`80003o0`3oool30?l0o`D0oooo00@0003o0?l0o`3o0?l0o`3o>@3oool0
0`000000oooo0?ooo`0n0?ooo`<0o`001`3oool30?l00003003o003oool0oooo00@0oooo0`3o0006
0?ooo`<0o`000P000003003o00D0oooo0`00o`3o0?ooof`0oooo003o0?ooo`80oooo0`00000;0?oo
o`<0o`3o0`000?l30?ooo`<0o`3o0P3oool010000?l0o`3o0?l0o`3o0?l90?ooo`<0003o0`3oool3
0?l0o`D0oooo00@0003o0?l0o`3o0?l0o`3o=P3oool00`000000oooo0?ooo`0k0?ooo`<0o`001`3o
ool30?l00003003o003oool0oooo00X0oooo0P3o00050?ooo`04003o00000000o`00003o00D0oooo
0`00o`3o0?ooofl0oooo003o0?ooo`80oooo0`00000>0?ooo`<0o`3o0`000?l30?ooo`80o`3o0`3o
ool010000?l0o`3o0?l0o`3o0?l90?ooo`<0003o0`3oool30?l0o`D0oooo00@0003o0?l0o`3o0?l0
o`3o<P3oool2000003T0oooo103o00060?ooo`@0o`004P3oool30?l000800?l000@0oooo00000000
000000000P3oool3003o0?l0ooooLP3oool00?l0oooo0P3oool200000180oooo0`3o0?l30000o`80
oooo0`3o0?l30?ooo`040000o`3o0?l0o`3o0?l0o`T0oooo0`000?l30?ooo`<0o`3o1@3oool01000
0?l0o`3o0?l0o`3o0?l_0?ooo`800000=P3oool30?l000L0oooo0`3o00000`00o`00oooo0?ooo`0B
0?ooo`<00?l000@0oooo0?l0003o0000o`000P000003003o0?l0ooooM@3oool00?l0oooo0P3oool2
000001D0oooo0`3o0?l20000o`<0oooo0`3o0?l30?ooo`030000o`3o0?l0o`3o00X0oooo0`000?l3
0?ooo`<0o`3o1@3oool010000?l0o`3o0?l0o`3o0?l/0?ooo`800000<P3oool40?l000L0oooo0`3o
00000`00o`00oooo0?ooo`0B0?ooo`<00?l01@3oool2003o00030?l00000o`0000000?l0ooooM`3o
ool00?l0oooo0P3oool3000001L0oooo0P3o0?l30000o`<0oooo0`3o0?l20?ooo`040000o`3o0?l0
o`3o0?l0o`X0oooo0`000?l30?ooo`<0o`3o1@3oool010000?l0o`3o0?l0o`3o0?lY0?ooo`800000
;`3oool30?l000L0oooo103o00000`00o`00oooo0?ooo`0B0?ooo`<00?l01@3oool3003o0080oooo
0`00003o0?ooogL0oooo003o0?ooo`80oooo0P00000J0?ooo`<0o`3o0`000?l30?ooo`80o`3o0`3o
ool010000?l0o`3o0?l0o`3o0?l:0?ooo`<0003o0`3oool30?l0o`D0oooo00@0003o0?l0o`3o0?l0
o`3o9P3oool2000002`0oooo0`3o00070?ooo`<0o`0000<00?l00?ooo`3oool04`3oool3003o00D0
oooo0`00o`050?ooo`<00000o`3ooomg0?ooo`00o`3oool20?ooo`8000007@3oool30?l0o`<0003o
0P3oool30?l0o`<0oooo00@0003o0?l0o`3o0?l0o`3o2P3oool30000o`<0oooo0`3o0?l50?ooo`03
0000o`3o0?l0o`3o02@0oooo0P00000X0?ooo`@0o`001P3oool40?l00003003o003oool0oooo0180
oooo1000o`050?ooo`<00?l0203oool300000?l0ooooM`3oool00?l0oooo0P3oool200000200oooo
0`3o0?l20000o`<0oooo0`3o0?l30?ooo`040000o`3o0?l0o`3o0?l0o`X0oooo0`000?l30?ooo`<0
o`3o1@3oool30?l0ob40oooo0P00000U0?ooo`<0o`001`3oool30?l000800?l0503oool3003o00H0
oooo0`00o`0;0?ooo`<00000o`3ooomg0?ooo`00o`3oool20?ooo`8000008`3oool20?l0o`<0003o
0`3oool30?l0o`<0oooo00@0003o0?l0o`3o0?l0o`3o2P3oool30000o`<0oooo0`3o0?l50?ooo`<0
o`3o7P3oool200000240oooo103o00070?ooo`<0o`000P00o`0D0?ooo`<00?l01P3oool3003o00h0
oooo0`00003o0?ooogL0oooo003o0?ooo`80oooo0P00000U0?ooo`<0o`3o0`000?l30?ooo`<0o`3o
0P3oool20000o`<0o`3o2P3oool30000o`<0oooo0P3o0?l60?ooo`<0o`3o6`3oool2000001h0oooo
0`3o00070?ooo`@0o`0000<00?l00?ooo`3oool04`3oool3003o00H0oooo0`00o`0A0?ooo`<00000
o`3ooomg0?ooo`00o`3oool20?ooo`800000:03oool30?l0o`<0003o0`3oool20?l0o`<0oooo0P00
0?l20?l0o`/0oooo0`000?l20?ooo`<0o`3o1P3oool30?l0oaP0oooo0P00000K0?ooo`<0o`001`3o
ool30?l000800?l05@3oool3003o00H0oooo0`00o`0D0?ooo`<00000o`3ooomg0?ooo`00o`3oool2
0?ooo`800000:`3oool30?l0o`<0003o0P3oool30?l0o`<0oooo00@0003o0?l0o`3o0?l0o`3o2`3o
ool20000o`<0oooo0`3o0?l60?ooo`<0o`3o5@3oool2000001L0oooo103o00060?ooo`@0o`000P00
o`0E0?ooo`<00?l01@3oool4003o01L0oooo0`00003o0?ooogL0oooo003o0?ooo`80oooo0P00000^
0?ooo`<0o`3o0P000?l30?ooo`<0o`3o0`3oool010000?l0o`3o0?l0o`3o0?l:0?ooo`<0003o0`3o
ool30?l0o`H0oooo0`3o0?lB0?ooo`800000503oool30?l000L0oooo0`3o0003003o01@0oooo1000
o`050?ooo`<00?l06`3oool300000?l0ooooM`3oool00?l0oooo0P3oool200000340oooo0P3o0?l3
0000o`<0oooo0`3o0?l20?ooo`80003o0`3o0?l:0?ooo`<0003o0`3oool30?l0o`H0oooo0`3o0?l?
0?ooo`8000004@3oool30?l000L0oooo0`3o0002003o01D0oooo0`00o`060?ooo`<00?l07P3oool3
00000?l0ooooM`3oool00?l0oooo0P3oool2000003<0oooo0`3o0?l30000o`<0oooo0P3o0?l30?oo
o`80003o0`3o0?l:0?ooo`<0003o0`3oool30?l0o`H0oooo0`3o0?l<0?ooo`8000003@3oool40?l0
00H0oooo103o0002003o01D0oooo0`00o`060?ooo`<00?l08@3oool300000?l0ooooM`3oool00?l0
oooo0P3oool2000003H0oooo0`3o0?l30000o`80oooo0`3o0?l30?ooo`80003o0`3o0?l:0?ooo`<0
003o0`3oool30?l0o`H0oooo0`3o0?l90?ooo`8000002P3oool30?l000L0oooo0`3o0003003o01D0
oooo0`00o`060?ooo`<00?l0903oool300000?l0ooooM`3oool00?l0oooo0P3oool2000003T0oooo
0`3o0?l20000o`<0oooo0`3o0?l30?ooo`80003o0P3o0?l;0?ooo`<0003o0`3oool30?l0o`H0oooo
0`3o0?l60?ooo`8000001P3oool40?l000L0oooo0`3o0002003o01H0oooo0`00o`060?ooo`<00?l0
9`3oool300000?l0ooooM`3oool00?l0oooo@03oool20?l0o`<0003o0`3oool30?l0o`<0oooo00@0
003o0?l0o`3o0?l0o`3o2`3oool30000o`<0oooo0`3o0?l60?ooo`<0o`3o0`3oool2000000<0oooo
0`3o00070?ooo`@0o`000P00o`0F0?ooo`<00?l01P3oool3003o02X0oooo0P00003o0?ooogP0oooo
003o0?oood80oooo0`3o0?l30000o`<0oooo0`3o0?l20?ooo`80003o0`3o0?l;0?ooo`<0003o0`3o
ool30?l0o`H0oooo0`3o0?l2000000<0o`001`3oool30?l000<00?l05P3oool3003o00D0oooo1000
o`0]0?ooo`800000o`3ooomh0?ooo`00o`3ooom50?ooo`<0o`3o0`000?l30?ooo`80o`3o0`3oool2
0000o`<0o`3o2`3oool30000o`<0oooo0`3o0?l40?ooo`80o`3o0P0000060?ooo`@0o`000`00o`0E
0?ooo`@00?l01@3oool3003o0340oooo0`00003o0?ooogL0oooo003o0?ooodP0oooo0`3o0?l30000
o`80oooo0`3o0?l30?ooo`80003o0`3o0?l;0?ooo`<0003o0`3oool40?l0o`80oooo0P0000030?oo
o`<0o`000`00o`0F0?ooo`<00?l01P3oool3003o03@0oooo0P00003o0?ooogP0oooo003o0?oood/0
oooo0`3o0?l20000o`<0oooo0`3o0?l30?ooo`80003o0`3o0?l;0?ooo`<0003o00<0o`3o0?ooo`3o
ool00`3o0?l2000000<0o`000`00o`0F0?ooo`<00?l01P3oool3003o03L0oooo0P00003o0?ooogP0
oooo003o0?ooodh0oooo0P3o0?l30000o`<0oooo0`3o0?l20?ooo`<0003o0`3o0?l50?ooo`@0o`3o
0P3oool30000o`030?ooo`3o0?l0o`3o008000000`00o`0F0?ooo`<00?l01P3oool3003o03X0oooo
0P00003o0?ooogP0oooo003o0?oooe00oooo0`3o0?l30000o`<0oooo0P3o0?l30?ooo`<0003o1@3o
0?l00`000?l0oooo0?ooo`040?ooo`80o`3o0`000?l2000001H0oooo0`00o`060?ooo`<00?l0?@3o
ool200000?l0ooooN03oool00?l0ooooD`3oool30?l0o`<0003o0P3oool30?l0o`80oooo00<0o`3o
0000o`000?l00`3o0?l40?ooo`<0o`3o0`00o`020000o`8000004`3oool3003o00H0oooo0`00o`10
0?ooo`800000o`3ooomh0?ooo`00o`3ooomF0?ooo`<0o`3o0P000?l00`3oool0o`3o0?l0o`030?l0
o`<0oooo0P000?l40?l0o`<00?l00`000?l20?ooo`030000003oool0oooo00h0oooo1000o`060?oo
o`<00?l0o`3ooonm0?ooo`00o`3ooomI0?ooo`80o`3o0`000?l30?ooo`D0o`3o00<00?l00000o`00
0?l00`3o0?l00`000?l0oooo0?ooo`030?ooo`030000003oool0oooo00/0oooo0`00o`060?ooo`@0
0?l0o`3oooo00?ooo`00o`3ooomF0?ooo`<0o`3o0P3oool30?l0o`<0003o0P3o0?l01000o`00o`3o
0?l0o`3o0?l50000o`<0o`3o0`3oool00`000000oooo0?ooo`080?ooo`<00?l01P3oool3003o0?l0
ooooa03oool00?l0ooooD`3oool30?l0o`H0oooo1@3o0?l50000o`<0o`3o0`3oool30000o`<0o`3o
00<000000?ooo`3oool01@3oool3003o00H0oooo0`00o`3o0?ooolL0oooo003o0?ooodl0oooo103o
0?l60?ooo`<0o`3o00D0o`00003o0000o`000?l00000o`030?l0o`<0003o0P3oool30?l0o`<0oooo
0`000?l2000000<0oooo0`00o`060?ooo`<00?l0o`3oooo:0?ooo`00o`3ooom<0?ooo`<0o`3o00<0
003o0?ooo`3oool0103oool30?l0o`@00?l00P000?l00`3o0?l0oooo0?ooo`020?ooo`<0o`3o0P00
0?l30?ooo`@0o`3o0P000?l2000000<00?l01P3oool3003o0?l0ooooc@3oool00?l0ooooB@3oool3
0?l0o`H0oooo103o0?l3003o00<0003o00<0o`3o0?ooo`3oool0203oool20?l0o`<0003o00<0o`3o
0000o`000?l00P3o0?l3000000H0oooo0`00o`3o0?ooom00oooo003o0?ooodD0oooo103o0?l60?oo
o`<0o`3o00@0o`00003o0000o`000?l00`000?l00`3o0?l0oooo0?ooo`0;0?ooo`D0o`3o0`000?l0
1000o`00o`3o0000000000040?ooo`<00?l0o`3ooooC0?ooo`00o`3ooom20?ooo`<0o`3o00<0003o
0?ooo`3oool0103oool30?l0o`@00?l00P000?l20?l0o`d0oooo0`3o0?l30000o`800?l00`3o0?l3
0000o`030000003oool00?l000800?l0o`3ooooF0?ooo`00o`3ooolo0?ooo`<0o`3o1P3oool40?l0
o`<00?l00`000?l00`3o0?l0oooo0?ooo`0<0?ooo`<0o`3o0`000?l3003o00<0o`3o0P3oool20?l0
o`80000000<00?l00?ooo`3oool0o`3ooooG0?ooo`00o`3ooolk0?ooo`@0o`3o1P3oool30?l0o`04
0?l00000o`000?l0003o00<0003o00<0o`3o0?ooo`3oool0303oool30?l0o`<0003o0`00o`030?l0
o`<0oooo0`000?l00`3o0?l000000000003o0?ooomX0oooo003o0?ooocP0oooo0`3o0?l00`000?l0
oooo0?ooo`040?ooo`<0o`3o00@0o`00003o0000o`000?l00P000?l20?l0o`d0oooo103o0?l30000
o`800?l000@0o`000?l0o`3o0?l0o`3o0`3oool30000o`<0o`3o0P3oool00`000000oooo0?ooo`3o
0?ooomP0oooo003o0?oooa80oooo1000000O0?ooo`<0o`3o00<0003o0?ooo`3oool0103oool30?l0
o`@00?l00P000?l20?l0o`d0oooo0`3o0?l40000o`800?l000<0o`000?l0o`3o0?l0103oool30000
o`<0o`3o1@3oool00`000000oooo0?ooo`3o0?ooomP0oooo003o0?ooo`l0oooo100000000`3oool0
000000000002000001T0oooo103o0?l60?ooo`@0o`3o0`00o`020000o`<0o`3o3@3oool30?l0o`<0
003o0`00o`000`3o0000o`3o0?l0o`040?ooo`<0003o0`3o0?l80?ooo`030000003oool0oooo0?l0
oooof03oool00?l0oooo303oool8000000@0oooo00<000000?ooo`3oool04`3oool30?l0o`030000
o`3oool0oooo00@0oooo0`3o0?l0103o00000?l0003o0000o`020000o`80o`3o3P3oool30?l0o`<0
003o0`00o`000`3o0000o`3o0?l0o`040?ooo`<0003o0`3o0?l;0?ooo`030000003oool0oooo0?l0
oooof03oool00?l0oooo2P3oool700000080oooo0P0000020?ooo`<000004@3oool30?l0o`030000
o`3oool0oooo00@0oooo0`3o0?l4003o0080003o0P3o0?l>0?ooo`<0o`3o0`000?l3003o00030?l0
003o0?l0o`3o00@0oooo0`000?l30?l0o`h0oooo00<000000?ooo`3oool0o`3ooooH0?ooo`00o`3o
ool60?ooo`<0000000@0oooo00000000000000000P3oool200000080oooo1000000208eFRP800000
3@3oool30?l0o`030000o`3oool0oooo00<0oooo103o0?l3003o0080003o0`3o0?l>0?ooo`<0o`3o
0`000?l2003o00040?l0003o0?l0o`3o0?l0o`@0oooo0`000?l30?l0oa40oooo00<000000?ooo`3o
ool0o`3ooooH0?ooo`00o`3oool30?ooo`<000000P3oool3000000030?ooo`000000000000800000
00@0oooo000000000000SEJ:0P00000308eFRP<00000203oool40?l0o`H0oooo0`3o0?l0103o0000
0?l0003o0000o`020000o`<0o`3o3@3oool40?l0o`<0003o0P00o`000`3o0000o`3o0?l0o`050?oo
o`<0003o0P3o0?lE0?ooo`030000003oool0oooo0?l0oooof03oool00?l0oooo0P3oool200000080
oooo0P0000000`3oool000000000000200000080oooo00<000000?ooo`0000000P2=EXX2000000@0
SEJ:0P0000050?ooo`<0o`3o00<0003o0?ooo`3oool0103oool30?l0o`040?l00000o`000?l0003o
0080003o0`3o0?l=0?ooo`<0o`3o10000?l2003o00030?l0003o0?l0o`3o00D0oooo0`000?l20?l0
oaP0oooo00<000000?ooo`3oool0o`3ooooH0?ooo`00o`3oool10?ooo`030000003oool0000000@0
oooo0P0000000`3oool00000000000020?ooo`030000003oool000000080SEJ:00<0000008eFRP2=
EXX00`2=EXX010000000oooo0000003oool30?l0o`030000o`3oool0oooo00<0oooo103o0?l4003o
00040000o`3o0?l0o`3o0?l0o`h0oooo0`3o0?l30000o`<00?l000<0o`000?l0o`3o0?l01@3oool3
0000o`80o`3o6`3oool00`000000oooo0?ooo`3o0?ooomP0oooo003o0?ooo`40oooo0P0000050?oo
o`D000000P3oool2000000<0SEJ:00<0000008eFRP2=EXX00`2=EXX40?l0o`H0oooo0`3o0?l0103o
00000?l0003o0000o`020000o`<0o`3o3P3oool30?l0o`<0003o0P00o`020?l00080o`3o1@3oool3
0000o`80o`3o7P3oool00`000000oooo0?ooo`3o0?ooomP0oooo003o0?ooo`<000001@3oool20000
000308eFRP000000000000@000000`2=EXX00`000000SEJ:08eFRP030?l0o`040000o`0000000000
000000<0oooo0`3o0?l0103o00000?l0003o0000o`020000o`<0o`3o3P3oool30?l0o`<0003o0P00
o`020?l000030?l0o`3oool0oooo00@0oooo0`000?l20?l0ob40oooo00<000000?ooo`3oool0o`3o
oooH0?ooo`00oP3oool2000000030?ooo`000000oooo00<0oooo00<000000?ooo`0000000`000002
0:O0j`030000002W`>/00000008000000`3o0?l010000?l0SEJ:08eFRP0000020?ooo`@0o`3o1000
o`000`000?l0o`3o0?l0o`020?l0o`h0oooo0`3o0?l30000o`800?l00P3o00000`3o0?l0oooo0?oo
o`040?ooo`<0003o0P3o0?lT0?ooo`030000003oool0oooo0?l0oooof03oool00?h0oooo00@00000
0?ooo`3oool00000103oool200000080Yl3[0P0000020:O0j`030000003o0?l00?l00080000000<0
003o08eFRP2=EXX00`2=EXX30?l0o`040?l00000o`000?l0003o0080003o0`3o0?l?0?ooo`<0o`3o
0`000?l2003o0080o`0000<0o`3o0?ooo`3oool0103oool30000o`80o`3o9`3oool00`000000oooo
0?ooo`3o0?ooomP0oooo003n0?ooo`040000003oool0oooo000000@0oooo0P0000020:O0j`<00000
00@00?l0000000000?l0003o0`2W`>/2000000<0o`3o00H0o`00003o0000o`000?l00000o`3oool3
0?l0o`h0oooo103o0?l30000o`05003o003o0000o`000?l0003o0?l01P3oool30000o`030?l0o`3o
ool0oooo02T0oooo00<000000?ooo`3oool0o`3ooooH0?ooo`00oP3oool00`000000oooo00000002
000000<0oooo00<000000?ooo`0000001P0000040:O0j`040?l0o`00000000000?l000<00?l000<0
003o0?ooo`3o0?l00P3o0?l>0?ooo`<0o`3o10000?l01000o`00o`000?l0003o0?l70?ooo`<0003o
00<0o`3o0?ooo`3oool0;03oool00`000000oooo0?ooo`3o0?ooomP0oooo003n0?ooo`80000000<0
Yl3[0000002W`>/0100000000`000?l0000000000002000000040:O0j`0000000000000000<0o`3o
00<0o`000000000000000P0000001`2=EXX0o`3o0?l0o`3o0?l000000?ooo`0000002`3oool30?l0
o`<0003o0P00o`020?l000030?l0o`3oool0oooo00D0oooo0`000?l00`3o0?l0oooo0?ooo`0_0?oo
o`030000003oool0oooo0?l0oooof03oool00?h0oooo00@000000?ooo`00000000000P2W`>/00`00
0000003o00000004000000060:O0j`3o0?l000000000003o0?l0o`000`00o`001@000?l0o`3o0000
00000000o`3o008000000`3oool00`000000oooo0?ooo`060?ooo`<0o`3o0`000?l2003o0080o`00
00<0o`3o0?ooo`3oool01@3oool30000o`030?l0o`3oool0oooo0380oooo00<000000?ooo`3oool0
o`3ooooH0?ooo`00oP3oool00`000000oooo0?ooo`02000000030?l0002W`>/0000000<0000000@0
o`3o0000003o0?l0o`000`0000000`00o`00003o0?l0o`020?l0o`<0Yl3[0`0000040?ooo`030000
003oool0oooo0080oooo0`3o0?l30000o`800?l00P3o00000`3o0?l0oooo0?ooo`050?ooo`<0003o
00<0o`3o0?ooo`3oool0=@3oool00`000000oooo0?ooo`3o0?ooomP0oooo003n0?ooo`030000003o
0?l0000000@0000000<0Yl3[0000003o0?l0100000001P00o`00Yl3[000000000000o`3o000000L0
Yl3[0P0000040?ooo`030000003oool0o`3o0080o`3o0`000?l01@00o`00o`000?l0003o0000o`3o
00L0oooo0`000?l00`3o0?l0oooo0?ooo`0h0?ooo`030000003oool0oooo0?l0oooof03oool00?`0
oooo0P3o0?l2000000040?ooo`000000oooo0?ooo`80000000<0o`000000000000001@0000000`2W
`>/0000000000002000000D0Yl3[00H0SEJ:00000000000000000?ooo`0000030?l0o`<0003o00@0
0?l00?l0003o0000o`00203oool30000ool0ooooo`3ooolJ0?ooo`00nP3oool20?l0o`80oooo00@0
00000?ooo`3oool000000P3o0?l01@000000o`00000000000000003o00D0000000<0Yl3[0000002W
`>/00`0000000`2W`>/0SEJ:08eFRP0208eFRP050000003o0?l000000000003o0?l00`000?l01000
o`00o`000?l0003o00080?ooo`<0003oo`3ooooo0?oooad0oooo003g0?ooo`<0o`3o103oool01`00
0000o`3o0?l0o`3o000000000?l00000o`000P000?l200000080Yl3[100000001@2W`>/000000000
002W`>/0000000D0SEJ:00H000000000o`00000000000000o`00o`030?l000P0oooo0`000?oo0?oo
ool0oooo803oool00?D0oooo0P3o0?l50?ooo`80o`3o00<0o`000000003o00000P0000030?l0o`03
0?ooo`00000000000080Yl3[00D000000:O0j`000000000008eFRP02000000030:O0j`000000SEJ:
00@0SEJ:00<00000003o002W`>/00P0000000`3o0000oooo000000060?ooo`<0003oo`3ooooo0?oo
ob<0oooo003c0?ooo`80o`3o103oool30?l0o`80o`0000D00?l0000000000000o`3o000000040?oo
o`050000003oool000000:O0j`2=EXX01`00000608eFRP040000003o0?l0o`3o0:O0j`@000000`3o
ool30000ool0ooooo`3ooolV0?ooo`00l03oool30?l0o`@0oooo0P3o0?l20?l00005003o00000?l0
o`3o0?l0o`0000000P3oool00`000000oooo0?ooo`030?ooo`L0000000@0SEJ:0000000000000000
1P2=EXX00`000000Yl3[0:O0j`020:O0j`<000000`000?oo0?ooool0oooo:@3oool00>h0oooo0P3o
0?l40?ooo`<0o`3o0P3o00001000o`00o`3o0?l0o`3o0?l20?ooo`050000003oool0oooo0?ooo`00
0000103oool200000080SEJ:00<000000:O0j`0000000P2=EXX2000000H0SEJ:00<000000:O0j`2W
`>/00P3o0?l2000000030000o`3oool0oooo0?l0ooooo`3ooolZ0?ooo`00k03oool20?l0o`<0oooo
0`3o0?l20?l00004003o003o0?l0o`3o0?l0o`H0oooo00@000000?ooo`3oool000000P3oool20?l0
o`8000000P2=EXX300000080SEJ:0P00000508eFRP8000000P3o0?l30:O0j`800000o`3ooooo0?oo
ob`0oooo003Y0?ooo`<0o`3o0`3oool20?l0o`80o`0000@00?l00?l0o`3o0?l0o`3o2@3oool01000
0000oooo0000000000020?l0o`<00?l000<0000008eFRP2=EXX00`000000102=EXX0000000000000
000508eFRP<0000000@0Yl3[0000002W`>/0Yl3[0P00003o0?ooool0oooo;03oool00>L0oooo0P3o
0?l30?ooo`<0o`3o0P3o00030?l0o`/0oooo00D0o`3o000000000000oooo00000002003o00040?l0
003o0?l0o`3o00000080SEJ:1000000208eFRP030000002=EXX0SEJ:00<0SEJ:00D000000:O0j`2W
`>/000000:O0j`02000000030?ooo`000000oooo0?l0ooooo`3oool[0?ooo`00i@3oool20?l0o`80
oooo0`3o0?l20?l00003003o003o0?l0o`3o00X0oooo103o0?l01P00o`000000003o003o0000o`3o
00000080o`3o0P3oool01P000000SEJ:000000000000003o000000<0SEJ:0P00000408eFRP030000
002W`>/0Yl3[008000000`3oool00`000000oooo0?ooo`3o0?ooool0oooo:P3oool00>80oooo0`3o
0?l20?ooo`80o`3o0P3o00000`00o`00o`3o0?l0o`090?ooo`@0o`3o0`00o`001`3o0000o`3o0?l0
o`000000o`3o0?ooo`0000000P3oool20000o`<000000P3oool200000080SEJ:0P00000408eFRP<0
000000<0oooo0000003oool00P3oool00`000000oooo0?ooo`3o0?ooool0oooo:P3oool00>00oooo
0P3o0?l20?ooo`<0o`3o00<0o`00003o003o0?l00P3o0?l80?ooo`<0o`3o0`00o`000`3o0000o`3o
0?l0o`020?l0o`80oooo00<000000?ooo`000?l00P0000000`000?l0oooo0000000208eFRP030000
003oool0oooo008000000P2=EXX3000000<0SEJ:0P0000020?ooo`030000003oool0000000800000
o`3ooooo0?ooob`0oooo003M0?ooo`<0o`3o0P3oool20?l0o`80o`000`3o0?l70?ooo`@0o`3o0P00
o`000`3o0000o`3o0?l0o`020?l0o`<0oooo10000?l2000000050?ooo`000000oooo0?ooo`000000
0P2=EXX2000000030?ooo`000000000000<000000P2=EXX01@000000SEJ:000000000000oooo00@0
00000P3oool00`000000oooo0?ooo`3o0?ooool0oooo:P3oool00=/0oooo0P3o0?l20?ooo`<0o`3o
00@0o`00003o003o0?l0o`3o1`3oool30?l0o`800?l000<0o`000?l0o`3o0?l00P3o0?l30?ooo`@0
003o103oool01`000000oooo0?ooo`3oool000000?ooo`0000000P2=EXX01@000000oooo00000000
0000SEJ:00@000000P2=EXX400000080oooo00@000000?ooo`3oool00000o`3ooooo0?ooobd0oooo
003I0?ooo`80o`3o00H0oooo0?l0o`3o0?l0o`3o0?l00000o`020?l0o`H0oooo103o0?l00`00o`00
o`000?l0o`030?l0o`80oooo1@000?l90?ooo`080000003oool0oooo0000003oool0000008eFRP00
00020?ooo`040000003oool0000008eFRP<0000000<0SEJ:0000000000000P0000020?ooo`030000
003oool0000000800000o`3ooooo0?ooobd0oooo003F0?ooo`<0o`3o00<0oooo0?l0o`3o0?l00P3o
00020?l0o`H0oooo0`3o0?l00`00o`00o`000?l0o`030?l0o`80oooo10000?l>0?ooo`030000003o
ool0oooo00<0000000<0SEJ:0000003oool00P3oool20000000308eFRP0000000000008000000P3o
ool700000?l0ooooo`3oool_0?ooo`00e03oool20?l0o`050?ooo`3o0?l0o`3o0?l0o`3o00000P3o
0?l50?ooo`@0o`3o00<0o`000?l0o`3o0?l00P3o0?l00`3oool0003o0000o`030000oa<0oooo0P00
00001@3oool0000008eFRP2=EXX0000000@0oooo0`000000103oool000000000003oool600000?l0
ooooo`3ooola0?ooo`00dP3oool20?l0o`060?ooo`3o0?l0o`3o0?l00000o`00o`3o103oool40?l0
o`030?l0003o0?l0o`3o0080o`3o00<0oooo0000o`000?l00P000?lJ0?ooo`@000001P3oool00`00
0000oooo0000000700000?l0ooooo`3ooolc0?ooo`00c`3oool60?l0o`03003o003o0?l0oooo00<0
oooo0`3o0?l00`00o`00o`3o0?l0o`020?l0o`D0003o7`3oool5000000<0oooo00<000000?ooo`00
00001P00003o0?ooool0oooo=@3oool00;H0oooo1000000C0?ooo`D0o`3o00<0o`000?l0o`3oool0
0P3oool80?l0o`@0003o9@3oool00`000000oooo0?ooo`0600000?l0ooooo`3oooll0?ooo`00/`3o
ool00`000000oooo000000020?ooo`<00000403oool40?l0o`030?l0003o0?l0o`3o0080oooo1`3o
0?l30000ob/0oooo0P000000103oool0000000000000003o0?ooool0oooo?P3oool00;80oooo00@0
00000?2_Q@00000000000`3oool2000000d0oooo1@3o0?l00`00o`00o`3o0?ooo`070?l0o`<0003o
<@3oool200000?l0ooooo`3ooom00?ooo`00/@3oool00`000000l:n50?2_Q@03000000030?ooo`00
00000000008000002P3oool40?l0o`030?l0003o0?l0oooo00H0o`3o0P000?oo0?ooool0ooooN03o
ool00;00oooo00D000000?2_Q@3`[hD0l:n5000000020?2_Q@060000002=EXX000000000003oool0
00001`3oool30?l0o`030?l0003o0?l0o`3o00D0o`3o0P000?oo0?ooool0ooooO03oool00;00oooo
00D000000?2_Q@3`[hD0l:n5000000020?2_Q@040000002=EXX000000?ooo`800000103oool:0?l0
o`030000o`3oool0oooo0?l0ooooo`3ooomo0?ooo`00/03oool010000000l:n50?2_Q@3`[hD30000
0080SEJ:00H000000?ooo`000000oooo0000003oool30?l0o`03003o003o0?l0o`3o0080o`3o00<0
003o0?ooo`3oool0o`3ooooo0?oooh<0oooo002`0?ooo`050000003`[hD0l:n50?2_Q@0000000P2W
`>/00`000000SEJ:000000020?ooo`030000003o0?l0o`3o00@0o`3oo`3ooooo0?ooohX0oooo002`
0?ooo`040000003`[hD0l:n50?2_Q@8000000P2W`>/2000000D0o`3oo`3ooooo0?ooohh0oooo002`
0?ooo`030000003`[hD0l:n500<000000`000?l20?l0o`80oooo00<000000?ooo`3oool0o`3ooooo
0?ooohd0oooo002a0?ooo`030000003`[hD0l:n50080000000<0o`0008eFRP0000000P0000020?oo
o`030000003oool0oooo0?l0ooooo`3ooon=0?ooo`00[@3oool40000o`030000003`[hD0l:n50080
00000P2=EXX2000000030:O0j`000000oooo00800000o`3ooooo0?ooohh0oooo002Y0?ooo`@0003o
0P3o0?l00`000?l0o`3o000000020?2_Q@<0000000D0SEJ:0000003`[hD000000:O0j`0300000?l0
ooooo`3ooon>0?ooo`00Y@3oool40000o`80o`3o00@0003o0?l0o`3o0?l0003o0P3oool010000000
l:n50?2_Q@3`[hD20000000408eFRP000000l:n500000080oooo0P00003o0?ooool0ooooSP3oool0
0:00oooo1@000?l20?l0o`030000o`3o0?l0o`3o0080o`3o1P3oool010000000l:n50?2_Q@3`[hD3
000000040?2_Q@000000oooo0?ooo`800000o`3ooooo0?ooohh0oooo002L0?ooo`@0003o0`3o0?l2
0000o`<0o`3o00<00?l00000o`3oool01`3oool00`000000l:n50?2_Q@020?2_Q@80000000@0l:n5
0000003oool0oooo0P00003o0?ooool0ooooSP3oool009P0oooo10000?l30?l0o`80003o00H0oooo
0?l0o`3o0?l0o`3o003o00000?l<0?ooo`030000003`[hD0l:n50080l:n50P0000020?ooo`800000
o`3ooooo0?ooohl0oooo002C0?ooo`D0003o0`3o0?l20000o`80oooo0`3o0?l00`00o`00o`3o0000
o`0?0?ooo`8000000`3`[hD400000?l0ooooo`3ooon@0?ooo`00S`3oool40000o`@0o`3o0`000?l2
0?ooo`<0o`3o00<00?l00?l0o`000?l0503oool00`000000l:n50000003o0?ooool0ooooU03oool0
08/0oooo10000?l40?l0o`<0003o0`3oool30?l0o`800?l00P000?lG0?ooo`030000003oool0oooo
0?l0ooooo`3ooonC0?ooo`00QP3oool50000o`@0o`3o10000?l30?ooo`<0o`3o0P00o`030000ool0
ooooo`3ooon_0?ooo`00Q03oool20000o`030?ooo`3o0?l0o`3o0080o`3o10000?l40?ooo`<0o`3o
0P00o`000`3o0?l0003o0000o`3o0?ooool0oooo/P3oool008D0oooo0P3o0?l0103oool0003o0000
o`000?l50?ooo`<0o`3o0P00o`00103o0?l0003o0000o`000?oo0?ooool0oooo]03oool008H0oooo
0P000?l50?ooo`<0o`3o0`00o`000`3oool0003o0000o`3o0?ooool0oooo]`3oool008X0oooo0`3o
0?l3003o00040?l0o`000?l0003o0000ool0ooooo`3oooni0?ooo`00R@3oool01P3o0?l00?l0003o
0000o`00o`3o0?ooo`80003oo`3ooooo0?oook`0oooo00290?ooo`03003o003o0?l0oooo00<0003o
o`3ooooo0?oookh0oooo002;0?ooo`030000o`3oool0oooo0?l0ooooo`3ooono0?ooo`00o`3ooooo
0?ooool0ooooCP3oool00?l0ooooo`3ooooo0?ooodh0oooo003o0?ooool0ooooo`3ooom>0?ooo`00
o`3ooooo0?ooool0ooooCP3oool00?l0ooooo`3ooooo0?ooodh0oooo003o0?ooool0ooooo`3ooom>
0?ooo`00o`3ooooo0?ooool0ooooCP3oool00?l0ooooo`3ooooo0?ooodh0oooo003o0?ooool0oooo
o`3ooom>0?ooo`00o`3ooooo0?ooool0ooooCP3oool00?l0ooooo`3ooooo0?ooodh0oooo003o0?oo
ool0ooooo`3ooom>0?ooo`00o`3ooooo0?ooool0ooooCP3oool00?l0ooooo`3ooooo0?ooodh0oooo
003o0?ooool0ooooo`3ooom>0?ooo`00o`3ooooo0?ooool0ooooCP3oool00?l0ooooo`3ooooo0?oo
odh0oooo003o0?ooool0ooooo`3ooom>0?ooo`00o`3ooooo0?ooool0ooooCP3oool00?l0ooooo`3o
oooo0?ooodh0oooo003o0?ooool0ooooo`3ooom>0?ooo`00o`3ooooo0?ooool0ooooCP3oool00?l0
ooooo`3ooooo0?ooodh0oooo003o0?ooool0ooooo`3ooom>0?ooo`00o`3ooooo0?ooool0ooooCP3o
ool00?l0ooooo`3ooooo0?ooodh0oooo003o0?ooool0ooooo`3ooom>0?ooo`00o`3ooooo0?ooool0
ooooCP3oool00?l0ooooo`3ooooo0?ooodh0oooo003o0?ooool0ooooo`3ooom>0?ooo`00o`3ooooo
0?ooool0ooooCP3oool00?l0ooooo`3ooooo0?ooodh0oooo003o0?ooool0ooooo`3ooom>0?ooo`00
o`3ooooo0?ooool0ooooCP3oool00?l0ooooo`3ooooo0?ooodh0oooo003o0?ooool0ooooo`3ooom>
0?ooo`00o`3ooooo0?ooool0ooooCP3oool00?l0ooooo`3ooooo0?ooodh0oooo003o0?ooool0oooo
o`3ooom>0?ooo`00o`3ooooo0?ooool0ooooCP3oool00?l0ooooo`3ooooo0?ooodh0oooo003o0?oo
ool0ooooo`3ooom>0?ooo`00o`3ooooo0?ooool0ooooCP3oool00001\
\>"],
  ImageRangeCache->{{{0, 842.812}, {437, 0}} -> {0.00878115, 0.200633, \
0.00121791, 0.00121791}}]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{956, 721},
WindowMargins->{{-2, Automatic}, {Automatic, 1}},
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000BL?00400@0000000000000006P801T1T00000000000
00000000000000000000000000000000\>"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Info3251831079-3187082"->{
    Cell[3265, 102, 2006, 27, 307, "Print",
      CellTags->"Info3251831079-3187082"]},
  "Info3251831079-1006014"->{
    Cell[5358, 137, 484, 7, 82, "Print",
      CellTags->"Info3251831079-1006014"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Info3251831079-3187082", 770843, 29001},
  {"Info3251831079-1006014", 770961, 29004}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 115, 3, 87, "Subtitle"],
Cell[1894, 58, 51, 0, 30, "Text"],
Cell[1948, 60, 253, 5, 43, "Input"],
Cell[2204, 67, 150, 3, 27, "Input"],
Cell[2357, 72, 103, 2, 27, "Input"],
Cell[2463, 76, 170, 3, 27, "Input"],
Cell[2636, 81, 198, 4, 27, "Input"],
Cell[2837, 87, 170, 3, 27, "Input"],
Cell[3010, 92, 174, 3, 27, "Input"],

Cell[CellGroupData[{
Cell[3209, 99, 53, 1, 27, "Input"],
Cell[3265, 102, 2006, 27, 307, "Print",
  CellTags->"Info3251831079-3187082"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5308, 134, 47, 1, 27, "Input"],
Cell[5358, 137, 484, 7, 82, "Print",
  CellTags->"Info3251831079-1006014"]
}, Open  ]],
Cell[5857, 147, 554, 10, 91, "Input"],
Cell[6414, 159, 535, 9, 91, "Input"],
Cell[6952, 170, 535, 9, 91, "Input"],
Cell[7490, 181, 164, 3, 27, "Input"],
Cell[7657, 186, 784, 13, 203, "Input"],

Cell[CellGroupData[{
Cell[8466, 203, 1484, 25, 203, "Input"],
Cell[9953, 230, 250625, 8819, 552, 101583, 6974, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[260615, 9054, 198, 3, 27, "Input"],
Cell[260816, 9059, 167207, 5571, 414, 52240, 4147, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[428060, 14635, 160, 2, 27, "Input"],
Cell[428223, 14639, 203123, 8574, 355, 90607, 7180, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[631383, 23218, 161, 3, 27, "Input"],
Cell[631547, 23223, 138471, 5755, 446, 65917, 4855, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

